-- SCDData dump
-- Schema: 2.1
-- Date: 2023-03-01

CREATE TABLE "metadata" (
  "id" integer NOT NULL PRIMARY KEY,
  "key" varchar(32) NOT NULL,
  "value" varchar(64) NOT NULL
);
-- START METADATA
INSERT INTO metadata VALUES (1, "schema_major", 2);
INSERT INTO metadata VALUES (2, "schema_minor", 1);
INSERT INTO metadata VALUES (3, "dump_version", 20230301);
-- END METADATA

BEGIN TRANSACTION;
CREATE TABLE album (
    id integer NOT NULL,
    created timestamp with time zone,
    last_modified timestamp with time zone,
    name character varying(256) NOT NULL,
    shortname character varying(128) NOT NULL,
    artist_id integer NOT NULL,
    verifier character varying(16) NOT NULL,
    verified boolean NOT NULL,
    alphaorder integer NOT NULL,
    productionyear integer NOT NULL,
    ramsayindexverno smallint NOT NULL,
    notes text NOT NULL,
    CONSTRAINT album_alphaorder_check CHECK ((alphaorder >= 0)),
    CONSTRAINT album_productionyear_check CHECK ((productionyear >= 0)),
    CONSTRAINT album_ramsayindexverno_check CHECK ((ramsayindexverno >= 0))
);
CREATE TABLE albumsrecordingsmap (
    id integer NOT NULL,
    album_id integer NOT NULL,
    recording_id integer NOT NULL,
    tracknumber smallint NOT NULL,
    CONSTRAINT albumsrecordingsmap_tracknumber_check CHECK ((tracknumber >= 0))
);
CREATE TABLE couples (
    id integer NOT NULL,
    name character varying(32) NOT NULL
);
CREATE TABLE couplesshape (
    id integer NOT NULL,
    couples_id integer NOT NULL,
    shape_id integer NOT NULL,
    description character varying(32) NOT NULL
);
CREATE TABLE dance (
    id integer NOT NULL,
    created timestamp with time zone,
    last_modified timestamp with time zone,
    name character varying(128) NOT NULL,
    ucname character varying(128) NOT NULL,
    type_id integer NOT NULL,
    barsperrepeat smallint NOT NULL,
    medleytype_id integer,
    shape_id integer,
    couples_id integer,
    progression_id integer,
    devisor_id integer NOT NULL,
    devised date,
    notes text NOT NULL,
    intensity smallint NOT NULL,
    intensity_bars character varying(256) NOT NULL,
    data_verified smallint NOT NULL,
    steps_verified smallint NOT NULL,
    formations_verified smallint NOT NULL,
    tunes_verified smallint NOT NULL,
    intensity_per_turn smallint NOT NULL,
    CONSTRAINT dance_barsperrepeat_check CHECK ((barsperrepeat >= 0)),
    CONSTRAINT dance_data_verified_check CHECK ((data_verified >= 0)),
    CONSTRAINT dance_formations_verified_check CHECK ((formations_verified >= 0)),
    CONSTRAINT dance_steps_verified_check CHECK ((steps_verified >= 0)),
    CONSTRAINT dance_tunes_verified_check CHECK ((tunes_verified >= 0))
);
CREATE TABLE dancealias (
    id integer NOT NULL,
    dance_id integer NOT NULL,
    name character varying(128) NOT NULL,
    ucname character varying(128) NOT NULL,
    status smallint NOT NULL,
    CONSTRAINT dancealias_status_check CHECK ((status >= 0))
);
CREATE TABLE dancecrib (
    id integer NOT NULL,
    created timestamp with time zone,
    last_modified timestamp with time zone,
    dance_id integer NOT NULL,
    source_id integer NOT NULL,
    user_id integer,
    format character varying(10) NOT NULL,
    text text NOT NULL,
    reliability smallint NOT NULL,
    CONSTRAINT dancecrib_reliability_check CHECK ((reliability >= 0))
);
CREATE TABLE dancecribsource (
    id integer NOT NULL,
    created timestamp with time zone,
    last_modified timestamp with time zone,
    name character varying(64) NOT NULL,
    editor character varying(256) NOT NULL,
    slug character varying(50) NOT NULL,
    url character varying(256),
    email character varying(256),
    group_id integer
);
CREATE TABLE dancesformationsmap (
    id integer NOT NULL,
    dance_id integer NOT NULL,
    formation_id integer NOT NULL,
    number smallint NOT NULL,
    instancenum smallint NOT NULL,
    CONSTRAINT dancesformationsmap_instancenum_check CHECK ((instancenum >= 0)),
    CONSTRAINT dancesformationsmap_number_check CHECK ((number >= 0))
);
CREATE TABLE dancespublicationsmap (
    id integer NOT NULL,
    dance_id integer NOT NULL,
    publication_id integer NOT NULL,
    number smallint NOT NULL,
    priority smallint NOT NULL,
    CONSTRAINT dancespublicationsmap_number_check CHECK ((number >= 0)),
    CONSTRAINT dancespublicationsmap_priority_check CHECK ((priority >= 0))
);
CREATE TABLE dancesrecordingsmap (
    id integer NOT NULL,
    dance_id integer NOT NULL,
    alias_id integer,
    recording_id integer NOT NULL
);
CREATE TABLE dancesstepsmap (
    id integer NOT NULL,
    dance_id integer NOT NULL,
    step_id integer NOT NULL
);
CREATE TABLE dancestunesmap (
    id integer NOT NULL,
    dance_id integer NOT NULL,
    tune_id integer NOT NULL,
    priority smallint NOT NULL,
    comment character varying(64) NOT NULL,
    CONSTRAINT dancestunesmap_priority_check CHECK ((priority >= 0))
);
CREATE TABLE dancetype (
    id integer NOT NULL,
    name character varying(16) NOT NULL,
    short_name character varying(4) NOT NULL,
    rectype boolean NOT NULL,
    dnctype boolean NOT NULL
);
CREATE TABLE danceurl (
    id integer NOT NULL,
    url character varying(200) NOT NULL,
    priority smallint NOT NULL,
    dance_id integer NOT NULL,
    CONSTRAINT danceurl_priority_check CHECK ((priority >= 0))
);
CREATE TABLE dancevideo (
    id integer NOT NULL,
    created timestamp with time zone,
    last_modified timestamp with time zone,
    dance_id integer NOT NULL,
    number smallint DEFAULT 0 NOT NULL,
    uploader_id integer NOT NULL,
    upload_file character varying(100) NOT NULL,
    quality character varying(1) NOT NULL,
    comment text NOT NULL,
    encoded boolean NOT NULL,
    published boolean NOT NULL,
    source character varying(1) NOT NULL,
    external character varying(32) NOT NULL,
    "offset" integer NOT NULL,
    "end" integer NOT NULL,
    channel_id integer,
    CONSTRAINT dancevideo_end_check CHECK (("end" >= 0)),
    CONSTRAINT dancevideo_number_check CHECK ((number >= 0)),
    CONSTRAINT dancevideo_offset_check CHECK (("offset" >= 0))
);
CREATE TABLE formation (
    id integer NOT NULL,
    created timestamp with time zone,
    last_modified timestamp with time zone,
    napiername character varying(8) NOT NULL,
    name character varying(64) NOT NULL,
    searchid character varying(32) NOT NULL,
    notes text NOT NULL
);
CREATE TABLE formationmodifier (
    id integer NOT NULL,
    key character varying(16) NOT NULL,
    name character varying(64) NOT NULL
);
CREATE TABLE formationroot (
    id integer NOT NULL,
    key character varying(16) NOT NULL,
    name character varying(64) NOT NULL
);
CREATE TABLE formationstepmap (
    id integer NOT NULL,
    formation_id integer,
    type_id integer NOT NULL,
    step_id integer NOT NULL
);
CREATE TABLE 'group' (
    id integer NOT NULL,
    group_id integer NOT NULL,
    person_id integer NOT NULL
);
CREATE TABLE media (
    id integer NOT NULL,
    album_id integer NOT NULL,
    media_id integer NOT NULL,
    catalognumber character varying(64) NOT NULL,
    year integer NOT NULL,
    available boolean,
    CONSTRAINT media_year_check CHECK ((year >= 0))
);
CREATE TABLE mediatype (
    id integer NOT NULL,
    name character varying(32) NOT NULL,
    abbreviation character varying(4) NOT NULL,
    priority smallint NOT NULL,
    CONSTRAINT mediatype_priority_check CHECK ((priority >= 0))
);
CREATE TABLE medleytype (
    id integer NOT NULL,
    description character varying(32) NOT NULL,
    sortstring character varying(32) NOT NULL
);
CREATE TABLE person (
    id integer NOT NULL,
    created timestamp with time zone,
    last_modified timestamp with time zone,
    name character varying(128) NOT NULL,
    shortname character varying(64) NOT NULL,
    display_name character varying(128) NOT NULL,
    location character varying(64) NOT NULL,
    email character varying(64) NOT NULL,
    isdev boolean NOT NULL,
    ispub boolean NOT NULL,
    iscmp boolean NOT NULL,
    ismus boolean NOT NULL,
    sameas_id integer,
    byear integer NOT NULL,
    dyear integer NOT NULL,
    user_id integer,
    notes text NOT NULL,
    CONSTRAINT person_byear_check CHECK ((byear >= 0)),
    CONSTRAINT person_dyear_check CHECK ((dyear >= 0))
);
CREATE TABLE personurl (
    id integer NOT NULL,
    url character varying(200) NOT NULL,
    priority smallint NOT NULL,
    person_id integer NOT NULL,
    CONSTRAINT personurl_priority_check CHECK ((priority >= 0))
);
CREATE TABLE phrasing (
    id integer NOT NULL,
    name character varying(16) NOT NULL
);
CREATE TABLE progression (
    id integer NOT NULL,
    name character varying(16) NOT NULL
);
CREATE TABLE publication (
    id integer NOT NULL,
    created timestamp with time zone,
    last_modified timestamp with time zone,
    name character varying(128) NOT NULL,
    shortname character varying(128) NOT NULL,
    devisor_id integer NOT NULL,
    hasdances boolean NOT NULL,
    hastunes boolean NOT NULL,
    pagenumbering boolean NOT NULL,
    onpaper boolean NOT NULL,
    adopted_by_id integer,
    adopted_date timestamp with time zone,
    tlc_level smallint NOT NULL,
    notes text NOT NULL,
    rscds boolean NOT NULL,
    year integer NOT NULL,
    CONSTRAINT publication_tlc_level_check CHECK ((tlc_level >= 0))
);
CREATE TABLE publicationurl (
    id integer NOT NULL,
    url character varying(200) NOT NULL,
    priority smallint NOT NULL,
    publication_id integer NOT NULL,
    CONSTRAINT publicationurl_priority_check CHECK ((priority >= 0))
);
CREATE TABLE recording (
    id integer NOT NULL,
    created timestamp with time zone,
    last_modified timestamp with time zone,
    name character varying(128) NOT NULL,
    artist_id integer NOT NULL,
    type_id integer NOT NULL,
    repetitions smallint NOT NULL,
    barsperrepeat smallint NOT NULL,
    medleytype_id integer,
    phrasing_id integer,
    playingseconds integer NOT NULL,
    twochords boolean NOT NULL,
    notes text NOT NULL,
    CONSTRAINT recording_barsperrepeat_check CHECK ((barsperrepeat >= 0)),
    CONSTRAINT recording_playingseconds_check CHECK ((playingseconds >= 0)),
    CONSTRAINT recording_repetitions_check CHECK ((repetitions >= 0))
);
CREATE TABLE shape (
    id integer NOT NULL,
    name character varying(32) NOT NULL,
    shortname character varying(8) NOT NULL
);
CREATE TABLE shapeprogressionsmap (
    id integer NOT NULL,
    shape_id integer NOT NULL,
    progression_id integer NOT NULL,
    couples_id integer NOT NULL
);
CREATE TABLE step (
    id integer NOT NULL,
    name character varying(32) NOT NULL,
    shortname character varying(8) NOT NULL
);
CREATE TABLE tune (
    id integer NOT NULL,
    created timestamp with time zone,
    last_modified timestamp with time zone,
    name character varying(128) NOT NULL,
    composer_id integer NOT NULL,
    notes text NOT NULL
);
CREATE TABLE tunealias (
    id integer NOT NULL,
    tune_id integer NOT NULL,
    name character varying(128) NOT NULL,
    status smallint NOT NULL,
    CONSTRAINT tunealias_status_check CHECK ((status >= 0))
);
CREATE TABLE tunespublicationsmap (
    id integer NOT NULL,
    tune_id integer NOT NULL,
    publication_id integer NOT NULL,
    priority smallint NOT NULL,
    number integer NOT NULL,
    CONSTRAINT tunespublicationsmap_number_check CHECK ((number >= 0)),
    CONSTRAINT tunespublicationsmap_priority_check CHECK ((priority >= 0))
);
CREATE TABLE tunesrecordingsmap (
    id integer NOT NULL,
    tune_id integer NOT NULL,
    alias_id integer,
    recording_id integer NOT NULL,
    number smallint NOT NULL,
    CONSTRAINT tunesrecordingsmap_number_check CHECK ((number >= 0))
);
CREATE TABLE tuneurl (
    id integer NOT NULL,
    url character varying(200) NOT NULL,
    priority smallint NOT NULL,
    tune_id integer NOT NULL,
    CONSTRAINT tuneurl_priority_check CHECK ((priority >= 0))
);
INSERT INTO 'album' VALUES (1, '1998-05-17 22:00:00+00', '2012-01-20 12:57:53.282069+00', 'Scottish Celebration, A', 'Scot Celeb', 3016, 'AP', 1, 430, 1993, 1, '');
INSERT INTO 'album' VALUES (2, '1998-05-24 22:00:00+00', '2012-01-20 12:57:53.289188+00', 'After the Chord', 'After Chord', 3014, 'AP', 1, 67, 0, 1, '');
INSERT INTO 'album' VALUES (3, '1998-05-18 22:00:00+00', '2012-01-20 12:57:53.298285+00', 'Dance Through The Miscellanies - First Part', 'Miscellanies 1', 3002, 'AP', 1, 230, 1996, 1, '');
INSERT INTO 'album' VALUES (4, '1998-05-17 22:00:00+00', '2012-01-20 12:57:53.304906+00', 'Dance Through The Miscellanies - Second Part', 'Miscellanies 2', 3002, 'AP', 1, 231, 1996, 1, '');
INSERT INTO 'album' VALUES (5, '1998-05-18 22:00:00+00', '2012-01-20 12:57:53.311166+00', 'Dances from the Collections of Mary Isdale MacNab Vol 1', 'MacNab 1', 3015, 'AP', 1, 224, 1996, 1, '');
INSERT INTO 'album' VALUES (6, '1998-05-18 22:00:00+00', '2012-01-20 12:57:53.317409+00', 'Dances from the Collections of Mary Isdale MacNab Vol 2', 'MacNab 2', 3015, 'AP', 1, 225, 1996, 1, '');
INSERT INTO 'album' VALUES (7, '1998-05-26 22:00:00+00', '2012-01-20 12:57:53.323799+00', 'Free Spirit', 'Free Spirit', 3003, 'AP', 1, 392, 1996, 1, '');
INSERT INTO 'album' VALUES (8, '1998-05-17 22:00:00+00', '2012-01-20 12:57:53.333295+00', 'Highlander Music Old Masters Volume 1', 'Old Masters 1', 3001, 'AP', 1, 290, 1996, 1, '');
INSERT INTO 'album' VALUES (9, '1998-05-18 22:00:00+00', '2012-01-20 12:57:53.339562+00', 'Highlander Music Old Masters Volume 2', 'Old Masters 2', 3016, 'AP', 1, 423, 1996, 1, '');
INSERT INTO 'album' VALUES (15, '1998-05-18 22:00:00+00', '2012-01-20 12:57:53.377653+00', 'Scotland - The Dances and Dance Bands', 'Scotland D & DB', 3016, 'AP', 1, 428, 1987, 1, '');
INSERT INTO 'album' VALUES (16, '1998-05-18 22:00:00+00', '2012-01-20 12:57:53.386687+00', 'Scottish Dance Favourites Volume 1', 'SD Favourites 1', 3016, 'AP', 1, 435, 1995, 1, '');
INSERT INTO 'album' VALUES (17, '1998-05-17 22:00:00+00', '2012-01-20 12:57:53.393064+00', 'Scottish Dance Favourites Volume 2', 'SD Favourites 2', 3016, 'AP', 1, 436, 1995, 1, '');
INSERT INTO 'album' VALUES (18, '1998-05-18 22:00:00+00', '2012-01-20 12:57:53.399312+00', 'Scottish Dance Favourites Volume 3', 'SD Favourites 3', 3016, 'AP', 1, 437, 1995, 1, '');
INSERT INTO 'album' VALUES (19, '1999-03-09 23:00:00+00', '2012-01-20 12:57:53.405557+00', 'Terpsichore, Scottish Dance Music', 'SD Music (Terp)', 3017, 'AP', 1, 400, 1994, 1, '');
INSERT INTO 'album' VALUES (20, '1998-05-18 22:00:00+00', '2012-01-20 12:57:53.414706+00', 'Scottish Reflections', 'Sc.Reflections', 3016, 'AP', 1, 439, 1996, 1, '');
INSERT INTO 'album' VALUES (21, '1999-10-05 22:00:00+00', '2012-01-20 12:57:53.423758+00', 'Selected Scottish Country Dances', 'Selected SCD', 3009, 'AP', 1, 277, 1989, 1, '');
INSERT INTO 'album' VALUES (22, '1998-05-25 22:00:00+00', '2012-01-20 12:57:53.435721+00', 'Special Requests Volume 1', 'Sp.Requests 1', 3013, 'AP', 1, 109, 1996, 1, '');
INSERT INTO 'album' VALUES (23, '1998-05-17 22:00:00+00', '2012-01-20 12:57:53.445019+00', 'Best of Scottish Dance Bands, The', 'Best of SDB', 3016, 'AP', 1, 413, 1997, 1, '');
INSERT INTO 'album' VALUES (24, '1999-05-08 22:00:00+00', '2012-01-20 12:57:53.454084+00', 'Legendary Jimmy Shand, The', 'Legendary JS', 3010, 'IS', 1, 373, 1997, 1, '');
INSERT INTO 'album' VALUES (25, '1998-05-17 22:00:00+00', '2012-01-20 12:57:53.460455+00', 'World of Scottish Dance, The', 'World of SD', 3016, 'AP', 1, 443, 1993, 1, '');
INSERT INTO 'album' VALUES (27, '1998-05-25 22:00:00+00', '2012-01-20 12:57:53.472931+00', 'Complete Caledonian Ball, The', 'Caled. Ball', 3026, 'AP', 1, 161, 1988, 1, '');
INSERT INTO 'album' VALUES (28, '1998-05-26 22:00:00+00', '2012-01-20 12:57:53.482092+00', 'Scottish Dance Music', 'MM SD Music', 3030, 'AP', 1, 308, 1995, 1, '');
INSERT INTO 'album' VALUES (29, '1998-05-18 22:00:00+00', '2012-01-20 12:57:53.491125+00', 'Come Scottish Country Dancing', 'SCD Adamson', 3032, 'AP', 1, 3, 1996, 1, '');
INSERT INTO 'album' VALUES (30, '2002-05-23 22:00:00+00', '2012-01-20 12:57:53.500325+00', 'Diamond Jubilee', 'Diamond Jblee', 1396, 'AP', 1, 174, 1995, 1, '');
INSERT INTO 'album' VALUES (31, '1998-05-26 22:00:00+00', '2012-01-20 12:57:53.510064+00', 'Magic Medicine', 'Magic Medicine', 3012, 'AP', 1, 311, 1994, 1, '');
INSERT INTO 'album' VALUES (1028, '2012-12-27 21:01:08.224856+00', '2012-12-28 11:15:45.731051+00', 'Just As It Was 3', 'Just 3', 903, '', 0, 0, 2012, 0, '');
INSERT INTO 'album' VALUES (33, '1999-05-25 22:00:00+00', '2012-01-20 12:57:53.525833+00', 'Scottish Fancy, A', 'Scot Fancy CD', 3010, 'RS', 1, 382, 0, 1, '');
INSERT INTO 'album' VALUES (1017, '2012-02-28 14:41:29.196973+00', '2012-02-28 14:51:33.421887+00', 'Just As It Was - Sampler', 'Just-Sampler', 903, '', 0, 0, 2011, 0, '');
INSERT INTO 'album' VALUES (1033, '2013-01-02 14:53:12.825276+00', '2013-01-02 16:55:18.98949+00', 'Favourite SCDs Vol. 4 Dancer''s Choice', '', 3678, '', 0, 0, 2012, 0, '');
INSERT INTO 'album' VALUES (1021, '2012-05-31 07:12:40.857606+00', '2012-05-31 08:23:55.255011+00', 'Take Your Partners For Vol 3', 'Take Your Partners 3', 10034, '', 0, 0, 2012, 0, '');
INSERT INTO 'album' VALUES (1032, '2012-12-31 15:25:07.493738+00', '2012-12-31 16:43:57.979674+00', 'Diamond Jubilee Year, The', 'Queen''s Diamond Jubilee', 2944, '', 0, 0, 2012, 0, '');
INSERT INTO 'album' VALUES (1018, '2012-04-23 09:22:36.463219+00', '2012-04-23 10:00:53.411427+00', 'Let''s Go Scottish Country Dancing Vol 4', 'Let''s Go SCD 4', 10614, '', 0, 1, 2012, 1, '');
INSERT INTO 'album' VALUES (1025, '2012-09-26 14:05:18.683879+00', '2012-09-26 14:29:47.091215+00', 'Magazine Dances 2005-2009', 'Magazine Dances', 3016, '', 0, 1, 2012, 1, '');
INSERT INTO 'album' VALUES (32, '1998-10-18 22:00:00+00', '2012-09-27 11:27:03.939893+00', 'Reel Friends', 'Reel Friends', 3014, 'AP', 1, 72, 1993, 1, '');
INSERT INTO 'album' VALUES (1019, '2012-04-29 12:38:11.466786+00', '2012-04-29 14:31:43.286447+00', '6 x Through the Dance', '6xThrough', 1502, '', 0, 1, 2011, 0, '');
INSERT INTO 'album' VALUES (26, '1998-05-17 22:00:00+00', '2012-10-04 10:13:01.918537+00', 'Tweedside', 'Tweedside', 3016, 'AP', 1, 442, 1996, 1, '');
INSERT INTO 'album' VALUES (1040, '2013-01-16 12:42:18.896233+00', '2013-01-16 14:25:38.27306+00', 'Memories of Jim Johnstone', '', 3016, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (1029, '2012-12-28 13:25:39.577143+00', '2012-12-28 15:07:07.272869+00', 'Hairst Blinks', 'Hairst', 10679, '', 0, 0, 2011, 0, '');
INSERT INTO 'album' VALUES (1020, '2012-05-09 15:22:08.371662+00', '2012-05-09 16:10:02.457146+00', 'Dancing on Air', 'Dancing Air', 1502, '', 0, 1, 2011, 1, '');
INSERT INTO 'album' VALUES (1023, '2012-06-17 14:20:47.762768+00', '2012-06-17 15:15:12.688849+00', 'Dance for Joy Encore!', 'Dance for Joy Enc', 10000, '', 0, 0, 2012, 0, '');
INSERT INTO 'album' VALUES (1026, '2012-12-27 11:17:12.922844+00', '2012-12-27 12:20:24.689857+00', 'Just As It Was 1', 'Just 1', 903, '', 0, 0, 2012, 0, '');
INSERT INTO 'album' VALUES (1038, '2013-01-06 13:40:23.422612+00', '2013-01-06 14:49:54.556185+00', 'Legendary Scottish Dance Bands Vol 1', 'Legendary Bands 1', 3016, '', 0, 0, 2012, 0, '');
INSERT INTO 'album' VALUES (1034, '2013-01-03 08:15:56.085385+00', '2013-01-03 11:24:21.369627+00', 'Birling', 'Birling', 2088, '', 0, 0, 2012, 0, '');
INSERT INTO 'album' VALUES (1027, '2012-12-27 12:51:01.340905+00', '2012-12-27 20:33:04.711539+00', 'Just As It Was 2', 'Just 2', 903, '', 0, 0, 2012, 0, '');
INSERT INTO 'album' VALUES (1031, '2012-12-28 18:09:37.074079+00', '2013-01-01 19:16:04.95419+00', 'Diversity', '', 10687, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (1030, '2012-12-28 15:36:29.906157+00', '2012-12-28 16:59:03.047308+00', 'Let''s Dance ...', '', 2583, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (1037, '2013-01-05 16:28:14.188844+00', '2013-01-05 17:59:58.964243+00', 'Over the Waves to Shetland', 'Over the Waves', 10108, '', 0, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (1036, '2013-01-04 15:33:15.009003+00', '2013-01-04 16:36:17.585813+00', 'Hello & Goodbye', 'H&G', 10695, '', 0, 0, 2012, 0, '');
INSERT INTO 'album' VALUES (1043, '2013-02-03 15:07:44.710503+00', '2013-02-03 15:56:18.425864+00', 'In West Coast Style', 'West Coast Style', 10547, '', 0, 0, 0, 0, '');
INSERT INTO 'album' VALUES (1044, '2013-02-03 17:23:03.343379+00', '2013-02-03 17:32:54.811707+00', 'Scottish Dance Frolic', 'Frolic', 2060, '', 0, 0, 0, 0, '');
INSERT INTO 'album' VALUES (1045, '2013-02-04 13:48:55.551595+00', '2013-02-04 13:58:05.435729+00', 'Let''s Go Scottish Country Dancing Vol 6', 'Let''s Go 6', 3016, '', 0, 0, 2012, 0, '');
INSERT INTO 'album' VALUES (1046, '2013-02-04 15:25:34.945637+00', '2013-02-04 15:38:08.457086+00', 'Let''s Go Scottish Country Dancing Vol 5', 'Let''s Go 5', 3016, '', 0, 1, 2012, 1, '');
INSERT INTO 'album' VALUES (1047, '2013-02-05 14:30:41.064821+00', '2013-02-05 16:10:12.831482+00', 'National Odyssey', 'Odyssey', 3016, '', 0, 1, 2012, 1, '');
INSERT INTO 'album' VALUES (1048, '2013-02-06 11:31:12.529514+00', '2013-02-06 14:46:22.489579+00', 'Scottish Accordion Favourites', '', 10748, '', 0, 1, 2012, 1, '');
INSERT INTO 'album' VALUES (1049, '2013-02-15 17:42:29.465195+00', '2013-02-15 17:51:03.405961+00', 'Scottish Dance Music', 'Scottish Dance Music', 3024, '', 0, 0, 2012, 0, 'Exists as LP "Meet the Olympains" too');
INSERT INTO 'album' VALUES (36, '1998-12-04 23:00:00+00', '2012-01-20 12:57:53.560879+00', 'Kirkbrae Collection, The', 'Kirkbrae 1', 3060, 'AH', 1, 388, 1997, 1, '');
INSERT INTO 'album' VALUES (37, '1998-05-25 22:00:00+00', '2012-01-20 12:57:53.567374+00', 'Let''s Meet Again', 'Meet Again', 3034, 'AP', 1, 141, 1996, 1, '');
INSERT INTO 'album' VALUES (38, '1998-07-16 22:00:00+00', '2012-01-20 12:57:53.576513+00', 'True Reflection, A', 'True Reflection', 3036, 'PA', 1, 140, 0, 1, '');
INSERT INTO 'album' VALUES (173, '1998-12-20 23:00:00+00', '2012-01-20 12:57:54.762404+00', 'Fine Fettle', 'Fine Fettle', 2505, '', 0, 303, 0, 1, '');
INSERT INTO 'album' VALUES (10, '2000-04-04 22:00:00+00', '2013-04-10 09:57:17.293928+00', 'Highlander Music Scottish Dances Vol 1', 'Highlander SD 1', 3012, 'AP', 1, 309, 1996, 1, '');
INSERT INTO 'album' VALUES (11, '2000-04-04 22:00:00+00', '2013-04-10 09:57:31.454363+00', 'Highlander Music Scottish Dances Vol 2', 'Highlander SD 2', 3011, 'AP', 1, 14, 1996, 1, '');
INSERT INTO 'album' VALUES (13, '2000-04-04 22:00:00+00', '2013-04-10 09:58:01.384987+00', 'Highlander Music Scottish Dances Vol 4', 'Highlander SD 4', 3007, 'AP', 1, 191, 1996, 1, '');
INSERT INTO 'album' VALUES (14, '2000-04-04 22:00:00+00', '2013-04-10 09:58:15.845943+00', 'Highlander Music Scottish Dances Vol 5', 'Highlander SD 5', 3008, 'AP', 1, 283, 1996, 1, '');
INSERT INTO 'album' VALUES (1039, '2013-01-06 16:55:34.206502+00', '2013-08-09 13:34:36.88104+00', 'Macadians Dancing Master, The', 'Macadians D M', 2029, '', 0, 1, 2011, 1, '');
INSERT INTO 'album' VALUES (1042, '2013-02-02 15:20:40.131927+00', '2014-05-13 10:07:58.19421+00', 'Very Best of George Bell''s Scottish Dance Band, The - Vol 2', 'George Bell 2', 10146, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (1041, '2013-01-17 15:22:48.869496+00', '2014-05-13 10:08:33.283746+00', 'Very Best of George Bell''s Scottish Dance Band, The - Vol 1', 'George Bell 1', 10146, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (1022, '2012-06-12 14:22:24.332147+00', '2014-09-10 23:55:35.281436+00', 'Berkhamsted Diamond Collection, The', 'Berkhamsted Diamond', 3012, '', 0, 0, 2011, 0, '');
INSERT INTO 'album' VALUES (39, '1998-10-25 23:00:00+00', '2012-01-20 12:57:53.582753+00', 'Shores of Loch Alvie, The', 'Loch Alvie', 3018, 'BC', 1, 89, 1991, 1, '');
INSERT INTO 'album' VALUES (40, '1999-09-12 22:00:00+00', '2012-01-20 12:57:53.593424+00', 'Repeat Prescription', 'Rept Prescript', 3012, 'AP', 1, 312, 1992, 1, '');
INSERT INTO 'album' VALUES (41, '1998-06-16 22:00:00+00', '2012-01-20 12:57:53.603364+00', 'Dancer''s Miscellany Vol IV, A', 'Dancer''s Misc 4', 3002, 'AP', 1, 235, 1994, 1, '');
INSERT INTO 'album' VALUES (42, '1998-06-16 22:00:00+00', '2012-01-20 12:57:53.609604+00', 'Book 18. Music for Twelve Scottish Country Dances', 'RSCDS 18', 3023, 'AP', 1, 112, 1995, 1, '');
INSERT INTO 'album' VALUES (43, '1999-05-25 22:00:00+00', '2012-01-20 12:57:53.618725+00', 'Book 17. Music for Twelve Scottish Country Dances', 'RSCDS 17', 3022, 'AP', 1, 461, 1994, 1, '');
INSERT INTO 'album' VALUES (44, '1999-05-25 22:00:00+00', '2012-01-20 12:57:53.62795+00', 'Book 13/14. Eight Scottish Country Dances', 'RSCDS 13/14', 3018, 'AP', 1, 82, 1990, 1, '');
INSERT INTO 'album' VALUES (45, '2002-05-23 22:00:00+00', '2012-01-20 12:57:53.637451+00', 'Manchester Medley, A', 'Manchester Med.', 1396, 'AP', 1, 175, 1990, 1, '');
INSERT INTO 'album' VALUES (46, '1998-06-16 22:00:00+00', '2012-01-20 12:57:53.64418+00', 'Dancer''s Miscellany Vol II, A', 'Dancer''s Misc 2', 3002, 'AP', 1, 233, 1991, 1, '');
INSERT INTO 'album' VALUES (47, '1998-06-16 22:00:00+00', '2012-01-20 12:57:53.650618+00', 'Dancer''s Miscellany Vol III, A', 'Dancer''s Misc 3', 3002, 'AP', 1, 234, 1993, 1, '');
INSERT INTO 'album' VALUES (48, '2001-05-16 22:00:00+00', '2012-01-20 12:57:53.657278+00', 'Dancing Fingers 3', 'Fingers 3', 1502, 'AP', 1, 218, 1992, 1, '');
INSERT INTO 'album' VALUES (49, '1999-10-09 22:00:00+00', '2012-01-20 12:57:53.666362+00', 'Book 16. Music for Twelve Scottish Country Dances', 'RSCDS 16', 3018, 'AP', 1, 83, 1993, 1, '');
INSERT INTO 'album' VALUES (50, '1999-05-25 22:00:00+00', '2012-01-20 12:57:53.681333+00', 'Book 37. Frae a'' the Airts, Vol 2', 'RSCDS 37', 3021, 'AP', 1, 130, 1992, 1, '');
INSERT INTO 'album' VALUES (51, '1998-06-16 22:00:00+00', '2012-01-20 12:57:53.6932+00', 'Let''s Dance Again...', 'Dance Again', 3038, 'AP', 1, 200, 1992, 1, '');
INSERT INTO 'album' VALUES (52, '1998-06-16 22:00:00+00', '2012-01-20 12:57:53.69963+00', 'Life begins at Forty', 'Life begins 40', 3039, 'AP', 1, 452, 1991, 1, '');
INSERT INTO 'album' VALUES (53, '1998-06-16 22:00:00+00', '2012-01-20 12:57:53.705828+00', 'In Strict Tempo', 'In Strict Tempo', 3040, 'AP', 1, 249, 1981, 1, '');
INSERT INTO 'album' VALUES (54, '1998-06-16 22:00:00+00', '2012-01-20 12:57:53.714819+00', 'Dancer''s Miscellany Vol I, A', 'Dancer''s Misc 1', 3002, 'AP', 1, 232, 1990, 1, '');
INSERT INTO 'album' VALUES (55, '1999-05-25 22:00:00+00', '2012-01-20 12:57:53.721179+00', 'Book 36. Frae a'' the Airts, Vol 1', 'RSCDS 36', 3038, 'AP', 1, 198, 1990, 1, '');
INSERT INTO 'album' VALUES (56, '1999-05-25 22:00:00+00', '2012-01-20 12:57:53.730182+00', 'Book 35. Music for Eight Scottish Country Dances', 'RSCDS 35', 3009, 'AP', 1, 267, 1988, 1, '');
INSERT INTO 'album' VALUES (60, '1999-05-25 22:00:00+00', '2012-01-20 12:57:53.764009+00', 'Book 13. Music for Eight Scottish Country Dances', 'RSCDS 13', 3018, 'AP', 1, 81, 1989, 1, '');
INSERT INTO 'album' VALUES (61, '1998-06-16 22:00:00+00', '2012-01-20 12:57:53.773114+00', 'Crystal Collection, The', 'Crystal Coll', 3040, 'AP', 1, 247, 1993, 1, '');
INSERT INTO 'album' VALUES (62, '1998-06-16 22:00:00+00', '2012-01-20 12:57:53.779321+00', 'Best Foot Forward', 'Best Foot Fwd', 3003, 'AP', 1, 391, 1992, 1, '');
INSERT INTO 'album' VALUES (64, '2002-05-23 22:00:00+00', '2012-01-20 12:57:53.794804+00', 'Taste of Andrew Rankine, A', 'Taste of AR', 3016, 'AP', 1, 440, 1993, 1, '');
INSERT INTO 'album' VALUES (65, '2002-05-11 22:00:00+00', '2012-01-20 12:57:53.803844+00', 'Book 39. Music for Nine Scottish Country Dances', 'RSCDS 39', 3019, 'AP', 1, 406, 1996, 1, '');
INSERT INTO 'album' VALUES (66, '1998-10-13 22:00:00+00', '2012-01-20 12:57:53.812981+00', 'Music for Fifteen Dances', '15 Dances', 3016, 'AP', 1, 421, 1990, 1, '');
INSERT INTO 'album' VALUES (67, '1999-05-25 22:00:00+00', '2012-04-14 15:40:23.120855+00', 'Book 38. Music for Eight Scottish Country Dances', 'RSCDS 38', 3002, 'AP', 1, 229, 1994, 1, '');
INSERT INTO 'album' VALUES (243, '2002-06-10 22:00:00+00', '2012-01-20 12:57:55.258735+00', 'To Dance To', 'To Dance To', 3051, 'CG', 1, 190, 0, 1, '');
INSERT INTO 'album' VALUES (35, '2001-05-14 22:00:00+00', '2012-09-27 12:21:22.949573+00', 'Dancing Fingers 2', 'Fingers 2', 1502, 'AP', 1, 217, 2001, 1, '');
INSERT INTO 'album' VALUES (68, '1999-05-25 22:00:00+00', '2012-01-20 12:57:53.828205+00', 'Book 34. Music for Eight Traditional Dances', 'RSCDS 34', 3022, 'AP', 1, 463, 1986, 1, '');
INSERT INTO 'album' VALUES (70, '1998-05-26 22:00:00+00', '2012-01-20 12:57:53.849378+00', 'Craigievar Dances', 'Craigievar', 3045, 'AP', 1, 301, 1997, 1, '');
INSERT INTO 'album' VALUES (71, '1999-05-25 22:00:00+00', '2012-01-20 12:57:53.85842+00', 'Special Requests Volume 2', 'Sp.Requests 2', 3046, 'AP', 1, 107, 1997, 1, '');
INSERT INTO 'album' VALUES (72, '1999-05-25 22:00:00+00', '2012-01-20 12:57:53.867486+00', 'Muckle Carfuffle', 'Muckle C.', 3047, 'AP', 1, 59, 1992, 1, '');
INSERT INTO 'album' VALUES (73, '1998-09-02 22:00:00+00', '2012-01-20 12:57:53.87646+00', 'Strictly Scottish Volume One', 'Strictly Scot 1', 3039, 'AP', 1, 453, 1997, 1, '');
INSERT INTO 'album' VALUES (76, '2002-05-11 22:00:00+00', '2012-01-20 12:57:53.903749+00', 'Book 22. Twelve Modern Scottish Country Dances', 'RSCDS 22', 3006, 'AP', 1, 97, 1997, 1, '');
INSERT INTO 'album' VALUES (81, '1998-05-18 22:00:00+00', '2012-01-20 12:57:53.952895+00', 'Dancing Forth', 'Dancing Forth', 3050, 'AP', 1, 355, 1997, 1, '');
INSERT INTO 'album' VALUES (82, '1998-09-02 22:00:00+00', '2012-01-20 12:57:53.959299+00', 'Lorne Choice', 'Lorne Choice', 3038, 'AP', 1, 201, 1997, 1, '');
INSERT INTO 'album' VALUES (86, '1999-02-24 23:00:00+00', '2012-01-20 12:57:53.993386+00', 'Tae Gar Ye Loup', 'Tae Gar', 2570, 'RC', 1, 66, 1984, 1, '');
INSERT INTO 'album' VALUES (87, '1998-11-17 23:00:00+00', '2012-01-20 12:57:54.002359+00', 'Come Scottish Country Dancing', 'Come SCD (JC)', 3065, 'PM', 1, 51, 1961, 1, '');
INSERT INTO 'album' VALUES (88, '1998-11-21 23:00:00+00', '2012-01-20 12:57:54.011336+00', 'Dancing World of Iain MacPhail, The', 'Dancing World', 3008, 'PM', 1, 282, 1993, 1, '');
INSERT INTO 'album' VALUES (89, '1998-11-19 23:00:00+00', '2012-01-20 12:57:54.020403+00', 'Take the Floor', 'Take the Floor', 3037, 'PM', 1, 214, 1992, 1, '');
INSERT INTO 'album' VALUES (90, '1999-01-30 23:00:00+00', '2012-01-20 12:57:54.026593+00', 'Let''s Dance Again. Volume 2', 'Dance Again 2', 3038, 'IS', 1, 199, 1994, 1, '');
INSERT INTO 'album' VALUES (91, '1998-10-11 22:00:00+00', '2012-01-20 12:57:54.032846+00', 'Dancer''s Choice', 'Dancer''s Choice', 2303, 'RC', 1, 202, 0, 1, '');
INSERT INTO 'album' VALUES (92, '1998-10-20 22:00:00+00', '2012-01-20 12:57:54.039143+00', 'Alastair Hunter and the Lorne Scottish Dance Band', 'AH & Lorne SDB', 3038, 'IS', 1, 195, 1989, 1, '');
INSERT INTO 'album' VALUES (94, '2000-08-01 22:00:00+00', '2012-01-20 12:57:54.051625+00', 'Island Fling, The', 'Island Fling', 3067, 'AP', 1, 40, 1979, 1, '');
INSERT INTO 'album' VALUES (95, '2000-08-01 22:00:00+00', '2012-01-20 12:57:54.060999+00', 'Maid of the Mill, The', 'Maid of Mill', 3067, 'DS', 1, 41, 1980, 1, '');
INSERT INTO 'album' VALUES (96, '2000-08-01 22:00:00+00', '2012-01-20 12:57:54.073218+00', 'Tarry a While', 'Tarry Awhile', 3067, 'DS', 1, 45, 1981, 1, '');
INSERT INTO 'album' VALUES (97, '1998-09-02 22:00:00+00', '2012-01-20 12:57:54.085296+00', 'Saint Andrew''s Ball - Volume 1', 'St. A. Ball 1', 3068, '', 0, 61, 0, 1, '');
INSERT INTO 'album' VALUES (98, '1998-11-23 23:00:00+00', '2012-01-20 12:57:54.093492+00', 'Lindsay Ross & his Scottish Dance Band', 'LR & his SDB', 3069, 'BL', 1, 346, 1967, 1, '');
INSERT INTO 'album' VALUES (99, '1999-01-31 23:00:00+00', '2012-01-20 12:57:54.101872+00', 'Highland Airs', 'Highland Airs', 3070, 'IS', 1, 324, 1994, 1, '');
INSERT INTO 'album' VALUES (100, '1998-11-23 23:00:00+00', '2012-01-20 12:57:54.110177+00', 'Best in Scottish Dance Music, The, Volume 1', 'Best in SDM 1', 3016, 'BC', 1, 410, 1981, 1, '');
INSERT INTO 'album' VALUES (101, '1998-11-20 23:00:00+00', '2012-01-20 12:57:54.118535+00', 'Best in Scottish Dance Music, The, Volume 2', 'Best in SDM 2', 3016, 'MK', 1, 411, 1982, 1, '');
INSERT INTO 'album' VALUES (102, '1998-12-04 23:00:00+00', '2012-01-20 12:57:54.126724+00', 'Best in Scottish Dance Music, The, Volume 3', 'Best in SDM 3', 3016, 'AH', 1, 412, 1989, 1, '');
INSERT INTO 'album' VALUES (84, '1998-05-26 22:00:00+00', '2012-04-14 14:53:42.806972+00', 'North of the Tweed', 'N of Tweed', 3002, 'AP', 1, 237, 1995, 1, '');
INSERT INTO 'album' VALUES (83, '1998-11-25 23:00:00+00', '2012-04-14 15:03:30.012558+00', 'Skye Collection, A', 'Skye Coll', 3002, 'AP', 1, 239, 1997, 1, '');
INSERT INTO 'album' VALUES (75, '1998-06-15 22:00:00+00', '2012-12-26 11:32:01.540301+00', 'Book 21. Music for Twelve Scottish Country Dances', 'RSCDS 21', 3049, 'AP', 1, 343, 2002, 1, '');
INSERT INTO 'album' VALUES (103, '2001-01-15 23:00:00+00', '2012-01-20 12:57:54.135209+00', 'Music for Scottish Dancing', 'Music for SD', 3011, 'AP', 1, 15, 1993, 1, '');
INSERT INTO 'album' VALUES (80, '1999-05-25 22:00:00+00', '2013-04-10 06:23:23.932661+00', 'Book 4. Music for Twelve Scottish Country Dances', 'RSCDS 4', 3011, 'AP', 1, 12, 1985, 1, '');
INSERT INTO 'album' VALUES (63, '1999-05-25 22:00:00+00', '2013-04-10 06:19:59.402453+00', 'Book 9. Music for Twelve Scottish Country Dances', 'RSCDS 9', 3018, 'AP', 1, 80, 1988, 1, '');
INSERT INTO 'album' VALUES (69, '1999-05-25 22:00:00+00', '2013-04-10 06:27:06.365472+00', 'Book 5. Music for Twelve Traditional Dances', 'RSCDS 5', 3019, 'AP', 1, 404, 1986, 1, '');
INSERT INTO 'album' VALUES (58, '1998-06-15 22:00:00+00', '2013-12-07 09:33:24.24227+00', 'Book 14/15. Music for Scottish Country Dances (2)', 'RSCDS 14/15 (2)', 3021, 'AP', 1, 129, 1991, 1, 'The full title of the MC is: 

MUSIC FOR SCOTTISH COUNTRY DANCES 

From Books 14 and 15. 

CASSETTE 2 - SIX DANCES



FIDDLERS THREE PLUS TWO

');
INSERT INTO 'album' VALUES (74, '1998-05-25 22:00:00+00', '2014-03-13 09:35:42.503649+00', 'Ghillies on the Golden Gate', 'Ghillies', 3048, 'AP', 1, 131, 1992, 1, '');
INSERT INTO 'album' VALUES (107, '1999-05-25 22:00:00+00', '2012-01-20 12:57:54.190549+00', 'Book 10.', 'RSCDS 10', 3020, 'RS', 1, 133, 1988, 1, '');
INSERT INTO 'album' VALUES (108, '1999-05-25 22:00:00+00', '2012-01-20 12:57:54.202459+00', 'Book 11.', 'RSCDS 11', 3038, 'AP', 1, 196, 1988, 1, '');
INSERT INTO 'album' VALUES (109, '1999-05-25 22:00:00+00', '2012-01-20 12:57:54.214648+00', 'Book 12.', 'RSCDS 12', 3023, 'PM', 1, 110, 1988, 1, '');
INSERT INTO 'album' VALUES (110, '1998-11-20 23:00:00+00', '2012-01-20 12:57:54.22651+00', 'Book 14.', 'RSCDS 14', 3023, 'PM', 1, 111, 1990, 1, '');
INSERT INTO 'album' VALUES (78, '1999-06-30 22:00:00+00', '2017-02-23 12:34:06.717852+00', 'Book 2. Music for Eleven Traditional Dances', 'RSCDS 2', 3018, 'AP', 1, 78, 1982, 1, '');
INSERT INTO 'album' VALUES (1050, '2013-02-22 14:26:12.460462+00', '2017-07-27 15:19:43.024618+00', 'Ah''m Dancin''! - Old Time Dances', 'Ah ''m Dancin''!', 10209, '', 0, 0, 2012, 0, '');
INSERT INTO 'album' VALUES (1110, '2018-03-30 08:21:17.947806+00', '2018-04-29 12:57:41.82364+00', 'Swans of Atlanta, The', '', 11613, '', 0, 0, 2016, 0, '');
INSERT INTO 'album' VALUES (111, '2002-03-12 23:00:00+00', '2012-01-20 12:57:54.238717+00', 'Book 19. Music for Twelve Scottish Country Dances', 'RSCDS 19', 3028, 'MB', 1, 240, 1996, 1, '');
INSERT INTO 'album' VALUES (112, '2001-05-12 22:00:00+00', '2012-01-20 12:57:54.247223+00', 'Book 20. Music for Twelve Scottish Country Dances', 'RSCDS 20', 3071, 'IS', 1, 297, 1996, 1, '');
INSERT INTO 'album' VALUES (113, '1999-01-19 23:00:00+00', '2012-01-20 12:57:54.255603+00', 'Book 27. Music for Twelve Traditional Dances', 'RSCDS 27', 3024, 'JW', 1, 317, 1975, 1, '');
INSERT INTO 'album' VALUES (115, '1999-05-25 22:00:00+00', '2012-01-20 12:57:54.283304+00', 'Book 29. Music for Ten Traditional Dances', 'RSCDS 29', 3018, 'AP', 1, 84, 2002, 1, '');
INSERT INTO 'album' VALUES (116, '1998-11-15 23:00:00+00', '2012-01-20 12:57:54.299087+00', 'Book 30.', 'RSCDS 30', 3018, 'JW', 1, 85, 0, 1, '');
INSERT INTO 'album' VALUES (117, '2001-05-12 22:00:00+00', '2012-01-20 12:57:54.310948+00', 'Book 31. Music for Eight Scottish Country Dances', 'RSCDS 31', 3026, 'RM', 1, 156, 1983, 1, '');
INSERT INTO 'album' VALUES (119, '1999-05-25 22:00:00+00', '2012-01-20 12:57:54.338698+00', 'Music for 12 Trad. Dances from the Graded Book', 'RSCDS Gr', 3026, 'IS', 1, 167, 1984, 1, '');
INSERT INTO 'album' VALUES (121, '1998-10-26 23:00:00+00', '2012-01-20 12:57:54.363446+00', 'Music for Eight Scottish Country Dances 1987', '8 SCD (1987)', 3018, 'MK', 1, 87, 1987, 1, '');
INSERT INTO 'album' VALUES (123, '1998-10-26 23:00:00+00', '2012-01-20 12:57:54.387622+00', 'Music for Ten Scottish Country Dances', '10 SCD (Crowe)', 3018, 'AP', 1, 88, 1978, 1, '');
INSERT INTO 'album' VALUES (124, '2003-02-15 23:00:00+00', '2012-01-20 12:57:54.399582+00', 'Scotland Dances', 'Scotland Dances', 2328, 'EN', 1, 264, 0, 1, '');
INSERT INTO 'album' VALUES (125, '1998-11-25 23:00:00+00', '2012-01-20 12:57:54.407774+00', 'Burns'' Night in the Annapolis Valley', 'Annapolis', 2029, 'AP', 1, 287, 0, 1, '');
INSERT INTO 'album' VALUES (126, '2001-10-31 23:00:00+00', '2012-01-20 12:57:54.416168+00', 'Camp of Pleasure, A', 'Camp / Pleasure', 2035, 'DS', 1, 19, 1976, 1, '');
INSERT INTO 'album' VALUES (127, '1998-10-06 22:00:00+00', '2012-01-20 12:57:54.429377+00', 'Reel Dram, A', 'Reel Dram', 3002, 'PM', 1, 238, 1989, 1, '');
INSERT INTO 'album' VALUES (128, '1999-06-30 22:00:00+00', '2012-01-20 12:57:54.43756+00', 'Another Celebration', 'Another Celeb', 3040, 'JW', 1, 246, 1988, 1, '');
INSERT INTO 'album' VALUES (129, '1998-10-12 22:00:00+00', '2012-01-20 12:57:54.446094+00', 'Argyll''s Fancy', 'Argyll''s Fancy', 3008, 'RC', 1, 281, 1985, 1, '');
INSERT INTO 'album' VALUES (130, '1998-10-11 22:00:00+00', '2012-01-20 12:57:54.458078+00', 'Authentic Scottish Dancing Music', 'Authentic SDM', 2058, 'RC', 1, 294, 0, 1, '');
INSERT INTO 'album' VALUES (131, '1999-01-21 23:00:00+00', '2012-01-20 12:57:54.466332+00', 'Barmkin. The Dancing Years & other Leeds'' Branch Dances', 'Barmkin', 3002, 'JW', 1, 227, 0, 1, '');
INSERT INTO 'album' VALUES (132, '1998-12-01 23:00:00+00', '2012-01-20 12:57:54.475127+00', 'Bath Scottish Dancers', 'Bath SD', 3014, 'PM', 1, 68, 1988, 1, '');
INSERT INTO 'album' VALUES (133, '1999-05-25 22:00:00+00', '2012-01-20 12:57:54.483631+00', 'Something Old - Something New', 'Something Old', 2414, '', 0, 339, 0, 1, '');
INSERT INTO 'album' VALUES (134, '2003-01-28 23:00:00+00', '2012-01-20 12:57:54.491247+00', 'Scottish Country Dances (Vol. 1)', 'AM - SCD 1', 3001, '00', 1, 291, 1978, 1, '');
INSERT INTO 'album' VALUES (135, '1998-10-11 22:00:00+00', '2012-01-20 12:57:54.497514+00', 'Boston Hospitality', 'Boston Hosp', 2061, 'RC', 1, 321, 1987, 1, '');
INSERT INTO 'album' VALUES (136, '1998-11-14 23:00:00+00', '2012-01-20 12:57:54.506624+00', 'Caber Feidh', 'Caber Feidh', 2041, 'IM', 1, 48, 1977, 1, '');
INSERT INTO 'album' VALUES (137, '1999-05-25 22:00:00+00', '2012-01-20 12:57:54.512837+00', 'Caledonian Ball, The - Vol 1', 'Cale Ball 1', 3026, 'PM', 1, 157, 0, 1, '');
INSERT INTO 'album' VALUES (120, '1998-07-16 22:00:00+00', '2012-08-30 12:16:03.517266+00', 'Eight Scottish Country Dances', '8 SCD Gonnella', 3044, 'HO', 1, 154, 1983, 1, '');
INSERT INTO 'album' VALUES (114, '1998-11-23 23:00:00+00', '2012-09-16 15:45:42.032273+00', 'Book 28.', 'RSCDS 28', 3025, 'AH', 1, 243, 1977, 1, '');
INSERT INTO 'album' VALUES (138, '1999-05-25 22:00:00+00', '2012-01-20 12:57:54.519011+00', 'Caledonian Ball, The - Vol 3', 'Cale Ball 3', 3026, 'FM', 1, 159, 0, 1, '');
INSERT INTO 'album' VALUES (139, '1999-05-25 22:00:00+00', '2012-01-20 12:57:54.525748+00', 'Caledonian Ball, The - Vol 2', 'Cale Ball 2', 3026, 'PM', 1, 158, 0, 1, '');
INSERT INTO 'album' VALUES (141, '1999-06-24 22:00:00+00', '2012-01-20 12:57:54.541161+00', 'Come Scottish Country Dancing with the Great Jim MacLeod Band', 'JM - Come SCD', 3009, 'MK', 1, 268, 1979, 1, '');
INSERT INTO 'album' VALUES (142, '1999-01-23 23:00:00+00', '2012-01-20 12:57:54.547432+00', 'Dance Date No 4', 'Dance Date 4', 3065, 'BL', 1, 55, 0, 1, '');
INSERT INTO 'album' VALUES (143, '1999-05-25 22:00:00+00', '2012-01-20 12:57:54.553965+00', 'Come Scottish Country Dancing with Andrew Rankine', 'Come SCD w AR', 3042, 'RS', 1, 329, 1976, 1, '');
INSERT INTO 'album' VALUES (144, '2002-05-23 22:00:00+00', '2012-01-20 12:57:54.563295+00', 'Come Scottish Country Dancing with Robert Whitehead', 'Come SCD w RW', 3039, 'BL', 1, 455, 1979, 1, '');
INSERT INTO 'album' VALUES (145, '1998-11-03 23:00:00+00', '2012-01-20 12:57:54.569558+00', 'Something Else', 'Something Else', 2414, 'CG', 1, 338, 1990, 1, '');
INSERT INTO 'album' VALUES (146, '1998-09-02 22:00:00+00', '2012-01-20 12:57:54.578548+00', 'From Scotia''s Shores We''re Noo Awa''', 'Scotia''s Shores', 3067, 'AP', 1, 38, 0, 1, '');
INSERT INTO 'album' VALUES (147, '2002-05-23 22:00:00+00', '2012-01-20 12:57:54.587618+00', 'Come Scottish Country Dancing with Robert Whitehead (2)', 'Come SCD w RW 2', 3039, 'EC', 1, 456, 1983, 1, '');
INSERT INTO 'album' VALUES (148, '1998-10-26 23:00:00+00', '2012-01-20 12:57:54.59381+00', 'Craigellachie in Oxford', 'Craig in Oxford', 3014, 'BC', 1, 69, 1992, 1, '');
INSERT INTO 'album' VALUES (149, '1998-12-01 23:00:00+00', '2012-01-20 12:57:54.600006+00', 'Dance Time', 'Dance Time', 2414, 'PM', 1, 336, 1976, 1, '');
INSERT INTO 'album' VALUES (150, '1998-10-06 22:00:00+00', '2012-01-20 12:57:54.606318+00', 'Dance to Bobby Crowe''s Band', 'Dance BCrowe', 3018, 'MC', 1, 86, 0, 1, 'Title of CD is <First Album>');
INSERT INTO 'album' VALUES (151, '1999-01-22 23:00:00+00', '2012-01-20 12:57:54.615286+00', 'Dram o'' Scotch, A', 'Dram o'' Scotch', 3061, 'BL', 1, 358, 0, 1, '');
INSERT INTO 'album' VALUES (152, '1998-12-01 23:00:00+00', '2012-01-20 12:57:54.621477+00', 'Dances Frae the North Vols. 1 & 2', 'Frae N 1 & 2', 3016, '', 0, 415, 0, 1, '');
INSERT INTO 'album' VALUES (153, '1998-09-20 22:00:00+00', '2012-01-20 12:57:54.624915+00', 'Dances Old, Dances New', 'Dances Old', 3024, 'GS', 1, 318, 1983, 1, '');
INSERT INTO 'album' VALUES (155, '1998-12-29 23:00:00+00', '2012-01-20 12:57:54.637353+00', 'Dances of Scotland Volume 1', 'D of Scotland 1', 2032, 'PM', 1, 8, 1986, 1, '');
INSERT INTO 'album' VALUES (156, '1998-10-05 22:00:00+00', '2012-01-20 12:57:54.643713+00', 'Dances of Scotland', 'D of Scotland', 3006, 'MC', 1, 98, 1975, 1, '');
INSERT INTO 'album' VALUES (157, '2001-11-19 23:00:00+00', '2012-01-20 12:57:54.649924+00', 'Sound of Feolin', 'Feolin', 1396, 'AP', 1, 176, 1998, 1, '');
INSERT INTO 'album' VALUES (158, '1998-12-04 23:00:00+00', '2012-01-20 12:57:54.656136+00', 'Dances of Scotland Volume 2', 'D of Scotland 2', 3016, 'AH', 1, 417, 1973, 1, '');
INSERT INTO 'album' VALUES (159, '1998-07-16 22:00:00+00', '2012-01-20 12:57:54.662298+00', 'Dancin'' Music', 'Dancin'' Music', 2068, 'PM', 1, 390, 1988, 1, '');
INSERT INTO 'album' VALUES (161, '1999-10-05 22:00:00+00', '2012-01-20 12:57:54.67508+00', 'Dancing Strings of Scotland', 'Dancing Strings', 2069, 'IS', 1, 101, 1989, 1, '');
INSERT INTO 'album' VALUES (162, '1998-01-26 23:00:00+00', '2012-01-20 12:57:54.684522+00', 'Dancing Throu'' Scotland', 'Dancing / Scot', 3016, '', 0, 418, 0, 1, '');
INSERT INTO 'album' VALUES (163, '1998-07-16 22:00:00+00', '2012-01-20 12:57:54.687986+00', 'Dancing Through Scotland', 'Dancing / Scot (JS)', 3010, 'BL', 1, 364, 1972, 1, '');
INSERT INTO 'album' VALUES (168, '1998-05-17 22:00:00+00', '2012-01-20 12:57:54.725265+00', 'Tartan Capers', 'Tartan Capers', 2042, 'AP', 1, 445, 1997, 1, '');
INSERT INTO 'album' VALUES (169, '1998-11-30 23:00:00+00', '2012-01-20 12:57:54.731636+00', 'Encore', 'Encore', 3014, 'PM', 1, 70, 1989, 1, '');
INSERT INTO 'album' VALUES (171, '1998-07-16 22:00:00+00', '2012-01-20 12:57:54.749919+00', 'Favourite Scottish Dance Music Vol. 1', 'Favourite SDM 1', 2039, 'MC', 1, 30, 1971, 1, '');
INSERT INTO 'album' VALUES (140, '1998-07-22 22:00:00+00', '2012-10-02 14:58:09.719198+00', 'Caller Herrin'' and seven other SCD/Foss', 'Caller Herrin', 2067, 'WT', 1, 448, 2011, 1, '');
INSERT INTO 'album' VALUES (160, '2001-06-07 22:00:00+00', '2012-10-10 13:29:56.009311+00', 'Dancing Fingers', 'Fingers', 1502, 'AP', 1, 216, 1988, 1, '');
INSERT INTO 'album' VALUES (165, '2000-02-27 23:00:00+00', '2012-10-11 18:02:43.265348+00', 'Play Favourites', 'Play Favourites', 2033, 'JW', 1, 17, 1979, 1, '2 CDs - In Triumph & Play Favourites');
INSERT INTO 'album' VALUES (166, '1999-05-25 22:00:00+00', '2012-10-11 18:03:13.556373+00', 'In Triumph', 'In Triumph', 2033, 'DS', 1, 16, 1978, 1, '2 CDs - In Triumph & Play Favourites');
INSERT INTO 'album' VALUES (154, '1999-01-20 23:00:00+00', '2012-11-10 01:50:17.173441+00', 'Dances from the Galloway Album', 'Galloway', 2067, 'JW', 1, 449, 0, 1, '');
INSERT INTO 'album' VALUES (105, '1998-11-17 23:00:00+00', '2013-04-10 06:28:13.583265+00', 'Book 7.', 'RSCDS 7', 3020, 'PM', 1, 132, 1987, 1, '');
INSERT INTO 'album' VALUES (106, '1998-11-20 23:00:00+00', '2013-04-10 06:28:54.209486+00', 'Book 8.', 'RSCDS 8', 3009, 'PM', 1, 266, 1987, 1, '');
INSERT INTO 'album' VALUES (122, '1999-05-25 22:00:00+00', '2013-04-10 09:18:02.592294+00', 'Nine Scottish Country Dances (1981) - Leaflets', '9 SCD Leaflets', 3042, 'MK', 1, 331, 1981, 1, '');
INSERT INTO 'album' VALUES (170, '1998-12-01 23:00:00+00', '2014-05-13 10:32:32.34805+00', 'Farewell to the Tay (CD: Early Days)', 'Farewell Tay', 2036, 'PM', 1, 22, 2005, 1, '');
INSERT INTO 'album' VALUES (174, '1998-11-09 23:00:00+00', '2012-01-20 12:57:54.767361+00', 'Gateway to the Forth', 'Gateway', 3010, 'BL', 1, 366, 1967, 1, '');
INSERT INTO 'album' VALUES (1109, '2018-03-18 08:51:00.860112+00', '2018-03-31 11:42:04.687986+00', 'Traditionally Inspired', '', 11611, '', 0, 1, 2014, 1, '');
INSERT INTO 'album' VALUES (176, '2002-04-08 22:00:00+00', '2012-01-20 12:57:54.779932+00', 'Grandfather Mountain Gala', 'G''ather Mount', 3067, 'EC', 1, 39, 1986, 1, '');
INSERT INTO 'album' VALUES (178, '1999-06-30 22:00:00+00', '2012-01-20 12:57:54.795295+00', 'Australian Ladies', 'Aust Ladies', 2055, 'BC', 1, 184, 1983, 1, '');
INSERT INTO 'album' VALUES (179, '1999-05-25 22:00:00+00', '2012-01-20 12:57:54.801539+00', 'Heather and Yon', 'Heather / Yon', 2035, 'MH', 1, 20, 1978, 1, '');
INSERT INTO 'album' VALUES (180, '1998-10-06 22:00:00+00', '2012-01-20 12:57:54.807725+00', 'Hey Johnnie Cope and seven other SCD/Foss', 'Johnnie Cope', 2067, 'MH', 1, 451, 0, 1, '');
INSERT INTO 'album' VALUES (181, '1999-04-20 22:00:00+00', '2012-01-20 12:57:54.813994+00', 'Highland Party', 'Highland Party', 2038, 'PM', 1, 25, 0, 1, '');
INSERT INTO 'album' VALUES (182, '1998-10-27 23:00:00+00', '2012-01-20 12:57:54.820179+00', 'Honour the Piper', 'Honour Piper', 1556, 'RS', 1, 63, 1967, 1, '');
INSERT INTO 'album' VALUES (917, '2009-11-22 23:00:00+00', '2012-01-20 12:57:58.076252+00', 'Tarry A While', 'Tarry A While', 3032, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (177, '1998-09-19 22:00:00+00', '2022-08-23 22:13:19.648441+00', 'H.I.S.C.D.', 'H.I.S.C.D.', 2040, 'EC', 1, 34, 0, 1, '');
INSERT INTO 'album' VALUES (183, '1998-10-25 23:00:00+00', '2012-01-20 12:57:54.829168+00', 'Ian Powrie''s Farewell to Scotland', 'IP''s Farewell', 2062, 'EN', 1, 326, 1967, 1, '');
INSERT INTO 'album' VALUES (184, '1998-10-06 22:00:00+00', '2012-01-20 12:57:54.835456+00', 'Ian Reid and his Scottish Dance Band', 'I Reid and SDB', 2060, 'MH', 1, 341, 0, 1, '');
INSERT INTO 'album' VALUES (185, '1999-01-10 23:00:00+00', '2012-01-20 12:57:54.841685+00', 'Invitation to a Scottish Dance', 'Invitation', 2057, 'EC', 1, 256, 0, 1, '');
INSERT INTO 'album' VALUES (187, '1998-05-04 22:00:00+00', '2012-01-20 12:57:54.854612+00', 'Scottish Favourites', 'Scot Favourites', 3016, '', 0, 438, 0, 1, '');
INSERT INTO 'album' VALUES (188, '1998-10-19 22:00:00+00', '2012-01-20 12:57:54.860825+00', 'King of the Melodeon Men', 'Melodeon', 3010, 'JW', 1, 371, 1994, 1, '');
INSERT INTO 'album' VALUES (189, '1998-10-11 22:00:00+00', '2012-01-20 12:57:54.867074+00', 'Reel Kick, A', 'Reel Kick', 3056, 'RC', 1, 122, 1982, 1, '');
INSERT INTO 'album' VALUES (190, '1999-01-11 23:00:00+00', '2012-01-20 12:57:54.876171+00', 'Kelpie Magic', 'Kelpie', 3016, '', 0, 424, 0, 1, '');
INSERT INTO 'album' VALUES (191, '1998-11-23 23:00:00+00', '2012-01-20 12:57:54.879536+00', 'Lad o'' Kyle, The', 'Lad o'' Kyle', 3044, 'PM', 1, 155, 1986, 1, '');
INSERT INTO 'album' VALUES (192, '1998-07-16 22:00:00+00', '2012-01-20 12:57:54.885721+00', 'Ladies of Dunse, The', 'Ladies / Dunse', 1502, 'DM', 1, 219, 1995, 1, '');
INSERT INTO 'album' VALUES (193, '1998-10-28 23:00:00+00', '2012-01-20 12:57:54.891998+00', 'Legends of Scotland - Best of Ian Powrie Band', 'Legends', 2062, 'RS', 1, 327, 1967, 1, '');
INSERT INTO 'album' VALUES (194, '1998-10-06 22:00:00+00', '2012-01-20 12:57:54.901163+00', 'Let''s Dance in Strict Tempo', 'Strict Tempo', 3051, 'MC', 1, 188, 1979, 1, '');
INSERT INTO 'album' VALUES (195, '1998-10-06 22:00:00+00', '2012-01-20 12:57:54.910305+00', 'London Highland Club Diamond Jubilee', 'London Highland', 3042, 'EC', 1, 330, 1984, 1, '');
INSERT INTO 'album' VALUES (196, '1999-08-04 22:00:00+00', '2012-01-20 12:57:54.919616+00', 'Looking For a Partner', 'Look Part (1)', 1815, 'CG', 1, 113, 1978, 1, '');
INSERT INTO 'album' VALUES (199, '1998-12-19 23:00:00+00', '2012-01-20 12:57:54.944333+00', 'Any Good Dance, Any Good Tune', 'Any Good Dance', 3067, 'FC', 1, 35, 1998, 1, '');
INSERT INTO 'album' VALUES (200, '1998-10-19 22:00:00+00', '2012-01-20 12:57:54.951001+00', 'Jig for Joy', 'Jig for Joy', 3030, 'AP', 1, 307, 1998, 1, '');
INSERT INTO 'album' VALUES (201, '1999-02-01 23:00:00+00', '2012-01-20 12:57:54.957319+00', 'Scottish Country Dances (Vol. 2)', 'SCD 2 (AM)', 3001, 'PM', 1, 292, 1979, 1, '');
INSERT INTO 'album' VALUES (202, '1998-10-13 22:00:00+00', '2012-01-20 12:57:54.963853+00', 'Music for Scottish Country Dancing', 'Music for SCD', 2034, 'RM', 1, 11, 1971, 1, '');
INSERT INTO 'album' VALUES (204, '1998-10-20 22:00:00+00', '2012-01-20 12:57:54.976655+00', 'Northern Jubilee', 'Northern Jub', 2046, 'PM', 1, 137, 1982, 1, '');
INSERT INTO 'album' VALUES (205, '1998-10-06 22:00:00+00', '2012-01-20 12:57:54.982932+00', 'Presenting the Lothian Scottish Dance Band', 'Present Lothian', 3040, 'EC', 1, 250, 1977, 1, '');
INSERT INTO 'album' VALUES (206, '2001-12-11 23:00:00+00', '2012-01-20 12:57:54.989236+00', 'Ready...And!', 'Ready...And!', 3067, 'FM', 1, 43, 0, 1, '');
INSERT INTO 'album' VALUES (207, '1999-05-25 22:00:00+00', '2012-01-20 12:57:54.998297+00', 'Caledonian Ball, The - Vol 4', 'Cale Ball 4', 3026, 'PM', 1, 160, 0, 1, '');
INSERT INTO 'album' VALUES (197, '1998-10-06 22:00:00+00', '2012-03-06 12:51:08.917574+00', 'MacGregor''s Gathering', 'Gathering', 2057, 'MC', 1, 257, 0, 1, '');
INSERT INTO 'album' VALUES (209, '1998-12-06 23:00:00+00', '2012-01-20 12:57:55.010765+00', 'San Francisco Collection Vol 2', 'San Francisco 2', 3016, 'PM', 1, 427, 1997, 1, '');
INSERT INTO 'album' VALUES (211, '1998-10-28 23:00:00+00', '2012-01-20 12:57:55.02323+00', 'Footnotes', 'Footnotes', 2088, 'PM', 1, 316, 1992, 1, '');
INSERT INTO 'album' VALUES (212, '1998-09-13 22:00:00+00', '2012-01-20 12:57:55.029438+00', 'Scottish Band Showcase', 'Showcase', 3016, 'OO', 1, 429, 1976, 1, '');
INSERT INTO 'album' VALUES (213, '1998-10-27 23:00:00+00', '2012-01-20 12:57:55.035699+00', 'Capital Reels', 'Capital Reels', 2090, 'AT', 1, 9, 1995, 1, '');
INSERT INTO 'album' VALUES (215, '1998-10-27 23:00:00+00', '2012-01-20 12:57:55.050954+00', 'Scottish Country Dances for Children', 'SCD Children', 1502, 'RS', 1, 221, 1983, 1, '');
INSERT INTO 'album' VALUES (216, '1998-10-26 23:00:00+00', '2012-01-20 12:57:55.05724+00', 'Scottish Dance Masters, The Vol 1', 'SD Masters 1', 2252, 'BC', 1, 153, 1982, 1, '');
INSERT INTO 'album' VALUES (217, '1998-12-19 23:00:00+00', '2012-01-20 12:57:55.063439+00', 'Virtuoso Piper of Scotland', 'Virtuoso Piper', 1556, 'BC', 1, 64, 1987, 1, '');
INSERT INTO 'album' VALUES (218, '1998-10-26 23:00:00+00', '2012-01-20 12:57:55.069629+00', 'Scottish Dance Masters, The Vol 3', 'SD Masters 3', 2231, 'BC', 1, 150, 0, 1, '');
INSERT INTO 'album' VALUES (219, '1998-10-27 23:00:00+00', '2012-01-20 12:57:55.075823+00', 'Scottish Dance Masters, The Vol 4', 'SD Masters 4', 2398, 'RS', 1, 149, 1988, 1, '');
INSERT INTO 'album' VALUES (220, '1998-10-22 22:00:00+00', '2012-01-20 12:57:55.082107+00', 'Scottish Dance Time Vol 1', 'Dance Time 1', 2053, 'IM', 1, 179, 0, 1, '');
INSERT INTO 'album' VALUES (221, '2000-11-13 23:00:00+00', '2012-01-20 12:57:55.088304+00', 'Scottish Dance Time Vol 2', 'Dance Time 2', 2053, 'CG', 1, 180, 0, 1, '');
INSERT INTO 'album' VALUES (222, '1998-10-27 23:00:00+00', '2012-01-20 12:57:55.094478+00', 'Scottish Dance Time Vol 3', 'Dance Time 3', 2053, 'RS', 1, 181, 0, 1, '');
INSERT INTO 'album' VALUES (223, '1998-10-25 23:00:00+00', '2012-01-20 12:57:55.100748+00', 'Scottish Dance Time Vol 4', 'Dance Time 4', 2053, 'CG', 1, 182, 0, 1, '');
INSERT INTO 'album' VALUES (224, '1998-10-25 23:00:00+00', '2012-01-20 12:57:55.106923+00', 'Scottish Dance Time Vol 5', 'Dance Time 5', 2053, 'CG', 1, 183, 1970, 1, '');
INSERT INTO 'album' VALUES (225, '1999-05-25 22:00:00+00', '2012-01-20 12:57:55.113106+00', 'Scottish Dance Favourites', 'SD Favourites', 3009, 'AP', 1, 275, 0, 1, '');
INSERT INTO 'album' VALUES (226, '1998-10-29 23:00:00+00', '2012-01-20 12:57:55.122144+00', 'Scottish Jigs and Reels for Children', 'J & R / Child', 2045, 'PM', 1, 127, 0, 1, '');
INSERT INTO 'album' VALUES (227, '1998-10-11 22:00:00+00', '2012-01-20 12:57:55.128355+00', 'Scottish Welcome, A', 'Sco Welcome', 3037, 'RC', 1, 212, 1975, 1, '');
INSERT INTO 'album' VALUES (228, '1998-11-22 23:00:00+00', '2012-01-20 12:57:55.137368+00', 'Second Celebration', 'Second Celeb', 3040, 'BC', 1, 251, 1986, 1, '');
INSERT INTO 'album' VALUES (229, '1998-10-26 23:00:00+00', '2012-01-20 12:57:55.143626+00', 'Silver Jubilee Oxford Book of Dances', 'Silver Jubilee', 1590, 'BC', 1, 305, 1994, 1, '');
INSERT INTO 'album' VALUES (230, '1999-05-25 22:00:00+00', '2012-01-20 12:57:55.150727+00', 'Something to Celebrate', 'Something to C', 3040, 'BC', 1, 252, 0, 1, '');
INSERT INTO 'album' VALUES (232, '1999-07-26 22:00:00+00', '2012-01-20 12:57:55.166352+00', 'Saint Andrews'' Branch Golden Jubilee 37-87', 'Gold Jub 37-87', 2044, 'GS', 1, 95, 1987, 1, '');
INSERT INTO 'album' VALUES (234, '2000-11-17 23:00:00+00', '2012-01-20 12:57:55.185268+00', 'Teachers Certificate Examination', 'Teachers Cert', 1502, 'OO', 1, 222, 1983, 1, '');
INSERT INTO 'album' VALUES (235, '1999-01-22 23:00:00+00', '2012-01-20 12:57:55.193956+00', 'Teachers Certificate Examination (1990)', 'Tchrs Cert (90)', 1502, 'RS', 1, 223, 1990, 1, '');
INSERT INTO 'album' VALUES (236, '1998-11-11 23:00:00+00', '2012-01-20 12:57:55.202272+00', 'Ten SCD - Leeds Branch Silver Jubilee', '10 SCD - Leeds', 2043, 'OO', 1, 76, 1987, 1, '');
INSERT INTO 'album' VALUES (237, '1998-10-28 23:00:00+00', '2012-01-20 12:57:55.211202+00', 'Canadian West Coast Sound, The', 'West Coast', 883, 'AP', 1, 347, 1982, 1, '');
INSERT INTO 'album' VALUES (238, '2000-03-16 23:00:00+00', '2012-01-20 12:57:55.219863+00', 'Scotch Piano, The', 'Scotch Piano', 2054, 'EC', 1, 178, 0, 1, '');
INSERT INTO 'album' VALUES (239, '1998-10-06 22:00:00+00', '2012-01-20 12:57:55.227947+00', 'Scottish Sound of the Bill Hendry Band, The', 'Scottish Sound', 10277, 'MH', 1, 187, 0, 1, '');
INSERT INTO 'album' VALUES (240, '1998-11-30 23:00:00+00', '2012-01-20 12:57:55.236077+00', 'Shepherd''s Choice, The', 'Shepherd', 2037, 'PM', 1, 24, 0, 1, '');
INSERT INTO 'album' VALUES (241, '1999-10-05 22:00:00+00', '2012-01-20 12:57:55.243477+00', 'Vancouver Collection of Scottish Music, The', 'Vancouver', 883, 'PM', 1, 348, 1978, 1, '');
INSERT INTO 'album' VALUES (242, '1998-10-27 23:00:00+00', '2012-01-20 12:57:55.252514+00', 'White Cockade, The', 'White Cockade', 2042, 'RS', 1, 447, 1991, 1, '');
INSERT INTO 'album' VALUES (210, '1998-09-20 22:00:00+00', '2013-02-15 17:59:07.564112+00', 'Scotland''s Fancy', 'Scot Fancy', 2048, 'GS', 1, 142, 0, 1, '');
INSERT INTO 'album' VALUES (244, '1998-12-20 23:00:00+00', '2012-01-20 12:57:55.264935+00', 'Eighteen of the Best', '18 Best', 3016, 'BC', 1, 419, 1989, 1, '');
INSERT INTO 'album' VALUES (246, '1998-10-05 22:00:00+00', '2012-01-20 12:57:55.277374+00', 'Westering Home', 'Westering Home', 3042, 'MC', 1, 334, 1976, 1, '');
INSERT INTO 'album' VALUES (247, '1998-10-22 22:00:00+00', '2012-01-20 12:57:55.283565+00', 'Jimmy''s Fancy', 'Jimmy''s Fancy', 3010, 'HW', 1, 370, 1961, 1, '');
INSERT INTO 'album' VALUES (248, '1998-10-13 22:00:00+00', '2012-01-20 12:57:55.289743+00', 'Scotland on Parade', 'Scot Parade', 1595, 'RM', 1, 4, 1975, 1, '');
INSERT INTO 'album' VALUES (250, '1998-10-06 22:00:00+00', '2012-01-20 12:57:55.302085+00', 'Gates of Edinburgh', 'Gates / Edin', 2092, 'MC', 1, 29, 0, 1, '');
INSERT INTO 'album' VALUES (251, '1998-10-06 22:00:00+00', '2012-01-20 12:57:55.308254+00', 'Favourite Scottish Dance Music Vol. 2', 'Favourite SDM 2', 2039, 'MC', 1, 31, 1972, 1, '');
INSERT INTO 'album' VALUES (252, '2000-07-30 22:00:00+00', '2012-01-20 12:57:55.314436+00', 'Lassie Come and Dance Wi'' Me', 'Lassie Come', 2188, 'BC', 1, 93, 1997, 1, '');
INSERT INTO 'album' VALUES (253, '1998-12-01 23:00:00+00', '2012-01-20 12:57:55.320606+00', 'Down South', 'Down South', 2303, 'PM', 1, 203, 1976, 1, '');
INSERT INTO 'album' VALUES (203, '1998-12-06 23:00:00+00', '2019-09-25 16:33:40.325579+00', 'None So Pretty', 'None So Pretty', 2035, 'BL', 1, 21, 1979, 1, '');
INSERT INTO 'album' VALUES (254, '1999-08-08 22:00:00+00', '2012-01-20 12:57:55.326845+00', 'Memories of Scottish Weekend', 'Memories', 2162, 'AP', 1, 1, 1999, 1, '');
INSERT INTO 'album' VALUES (255, '1999-01-23 23:00:00+00', '2012-01-20 12:57:55.333051+00', 'Fiddle', 'Fiddle', 2094, 'BL', 1, 57, 0, 1, '');
INSERT INTO 'album' VALUES (256, '1998-10-11 22:00:00+00', '2012-01-20 12:57:55.342971+00', 'Bow and Curtsy', 'Bow & Curtsy', 2095, 'EN', 1, 104, 0, 1, '');
INSERT INTO 'album' VALUES (257, '1998-12-19 23:00:00+00', '2012-01-20 12:57:55.351985+00', 'John Ellis', 'J Ellis & HCB', 3056, 'JW', 1, 121, 1968, 1, '');
INSERT INTO 'album' VALUES (258, '1998-11-14 23:00:00+00', '2012-01-20 12:57:55.358164+00', 'Tartan Stew', 'Tartan Stew', 2042, 'DS', 1, 446, 1993, 1, '');
INSERT INTO 'album' VALUES (233, '1999-03-09 23:00:00+00', '2020-06-17 22:35:46.591665+00', 'Steppin'' Out', 'Steppin'' Out', 2065, 'GS', 1, 399, 1988, 1, '');
INSERT INTO 'album' VALUES (259, '1999-08-07 22:00:00+00', '2012-01-20 12:57:55.364352+00', 'John Ellis and his Highland Country Band', 'J Ellis & HDB', 3056, 'RC', 1, 125, 1980, 1, '');
INSERT INTO 'album' VALUES (260, '2001-11-19 23:00:00+00', '2012-01-20 12:57:55.37619+00', 'Portrait of a Scottish Fiddler', 'Portrait', 1782, 'AP', 1, 135, 0, 1, '');
INSERT INTO 'album' VALUES (262, '1998-12-01 23:00:00+00', '2012-01-20 12:57:55.388626+00', 'Golden Fiddle Awards', 'Golden Fiddle', 2098, 'M', 1, 147, 1976, 1, '');
INSERT INTO 'album' VALUES (263, '1999-10-09 22:00:00+00', '2012-01-20 12:57:55.394836+00', 'Kilt is my Delight, The', 'Kilt is Delight', 3026, 'PM', 1, 165, 1971, 1, '');
INSERT INTO 'album' VALUES (264, '1998-10-11 22:00:00+00', '2012-01-20 12:57:55.401031+00', 'Scotch Mist', 'Scotch Mist', 3026, 'EN', 1, 169, 0, 1, '');
INSERT INTO 'album' VALUES (265, '1999-05-25 22:00:00+00', '2012-01-20 12:57:55.4072+00', 'Scottish Dance Party Vol 1', 'SD Party 1', 3026, '', 0, 170, 0, 1, '');
INSERT INTO 'album' VALUES (266, '1999-05-25 22:00:00+00', '2012-01-20 12:57:55.413376+00', 'Scottish Dance Party Vol 2', 'SD Party 2', 3026, '', 0, 171, 0, 1, '');
INSERT INTO 'album' VALUES (267, '1998-11-14 23:00:00+00', '2012-01-20 12:57:55.419544+00', 'Elma''s Tunes', 'Elma''s Tunes', 2124, 'DS', 1, 173, 0, 1, '');
INSERT INTO 'album' VALUES (270, '1998-10-11 22:00:00+00', '2012-01-20 12:57:55.438074+00', 'Come Dance With Me', 'Come Dance', 3037, 'RC', 1, 207, 1977, 1, '');
INSERT INTO 'album' VALUES (271, '1999-06-24 22:00:00+00', '2012-01-20 12:57:55.447399+00', 'Favourite Tunes - Favourite Dances', 'Favourite Tunes', 3037, 'M', 1, 209, 1983, 1, '');
INSERT INTO 'album' VALUES (272, '1998-09-19 22:00:00+00', '2012-01-20 12:57:55.455524+00', 'Preliminary Test', 'Prelim Test', 1502, 'OO', 1, 220, 1983, 1, '');
INSERT INTO 'album' VALUES (273, '1999-01-23 23:00:00+00', '2012-01-20 12:57:55.463644+00', 'Complete Scottish Dance Master No. 1, The', 'SD Master 1', 2328, 'JW', 1, 263, 1963, 1, '');
INSERT INTO 'album' VALUES (274, '1998-10-14 22:00:00+00', '2012-01-20 12:57:55.471929+00', 'Scottish Dance-Along', 'Dance-Along', 2328, 'RM', 1, 265, 1972, 1, '');
INSERT INTO 'album' VALUES (275, '1999-06-24 22:00:00+00', '2012-01-20 12:57:55.480096+00', 'Keep on Scottish Country Dancing with...', 'Keep on SD', 3009, 'MH', 1, 272, 0, 1, '');
INSERT INTO 'album' VALUES (276, '1998-10-11 22:00:00+00', '2012-01-20 12:57:55.488561+00', 'Pride of Edinburgh', 'Pride / Edin', 3008, 'RC', 1, 284, 1979, 1, '');
INSERT INTO 'album' VALUES (277, '1999-01-23 23:00:00+00', '2012-01-20 12:57:55.497005+00', 'Salute t'' Scottish Dancing', 'Salute', 3008, 'JW', 1, 285, 1976, 1, '');
INSERT INTO 'album' VALUES (278, '1998-10-06 22:00:00+00', '2012-01-20 12:57:55.505363+00', 'Scottish Country Dance', 'Scottish CD', 1549, 'MC', 1, 253, 0, 1, '');
INSERT INTO 'album' VALUES (279, '1998-12-01 23:00:00+00', '2012-01-20 12:57:55.513742+00', 'Country Dance Style', 'Dance Style', 2057, 'M', 1, 255, 0, 1, '');
INSERT INTO 'album' VALUES (249, '1998-10-14 22:00:00+00', '2012-04-22 17:59:45.075179+00', 'Scottish Dances', 'Scottish Dances', 2038, 'RM', 1, 28, 1958, 1, '');
INSERT INTO 'album' VALUES (280, '1998-10-17 22:00:00+00', '2012-01-20 12:57:55.522069+00', 'Scottish Country Dance Music', 'SCD MacKinnon', 2356, 'MC', 1, 258, 0, 1, '');
INSERT INTO 'album' VALUES (282, '1998-11-15 23:00:00+00', '2012-01-20 12:57:55.538595+00', 'Guid Luck Go Wi'' Ye', 'Guid Luck', 3010, 'JW', 1, 367, 1968, 1, '');
INSERT INTO 'album' VALUES (283, '1998-10-19 22:00:00+00', '2012-01-20 12:57:55.550559+00', 'Scottish Dance Party', 'SD Party', 3042, 'OO', 1, 333, 1969, 1, '');
INSERT INTO 'album' VALUES (284, '1998-11-09 23:00:00+00', '2012-01-20 12:57:55.55886+00', 'Scottish Country Dances Volume 2', 'SCDances 2', 2038, 'AT', 0, 27, 0, 1, '');
INSERT INTO 'album' VALUES (285, '1998-10-27 23:00:00+00', '2012-01-20 12:57:55.567075+00', 'Step We Gaily', 'Step We Gaily', 3010, 'RS', 1, 384, 1960, 1, '');
INSERT INTO 'album' VALUES (286, '1998-09-20 22:00:00+00', '2012-01-20 12:57:55.579043+00', 'Step in Time', 'Step in Time', 3018, 'DM', 1, 90, 0, 1, '');
INSERT INTO 'album' VALUES (287, '1998-10-06 22:00:00+00', '2012-01-20 12:57:55.587146+00', 'Music for Scottish Country Dancing', 'Music SCD (BB)', 3067, 'IS', 1, 42, 1978, 1, '');
INSERT INTO 'album' VALUES (289, '1999-01-23 23:00:00+00', '2012-01-20 12:57:55.604614+00', 'Back Hame Tae Auchtermuchty', 'Back Hame', 3010, 'BL', 1, 362, 1965, 1, '');
INSERT INTO 'album' VALUES (290, '1998-12-29 23:00:00+00', '2012-01-20 12:57:55.612777+00', 'Jigtime', 'Jigtime', 3010, 'PM', 1, 368, 1970, 1, '');
INSERT INTO 'album' VALUES (291, '1998-12-19 23:00:00+00', '2012-01-20 12:57:55.621197+00', 'Magic Sounds of Jimmy Shand and His Band, The', 'Magic Sounds', 3010, 'MK', 1, 374, 1983, 1, '');
INSERT INTO 'album' VALUES (292, '1998-10-06 22:00:00+00', '2012-01-20 12:57:55.629316+00', 'My Scotland', 'My Scotland', 3010, 'RM', 1, 375, 0, 1, '');
INSERT INTO 'album' VALUES (294, '1998-10-18 22:00:00+00', '2012-01-20 12:57:55.649581+00', 'Seven Favourite Dances #4', '7 Favourite 4', 1456, 'EE', 1, 396, 2011, 1, '');
INSERT INTO 'album' VALUES (295, '1998-10-11 22:00:00+00', '2012-01-20 12:57:55.661528+00', 'Garple Burn and 7 other SCD by Hugh Foss', 'Garple Burn', 2067, 'RC', 1, 450, 0, 1, '');
INSERT INTO 'album' VALUES (296, '1999-01-13 23:00:00+00', '2012-01-20 12:57:55.669726+00', 'Scottish Gems', 'Scottish Gems', 2131, 'M', 1, 185, 1970, 1, '');
INSERT INTO 'album' VALUES (297, '1999-04-19 22:00:00+00', '2012-01-20 12:57:55.677983+00', 'Scotland''s Own Jimmy Shand', 'Scotland''s Own', 3010, 'IS', 1, 378, 1985, 1, '');
INSERT INTO 'album' VALUES (298, '1998-12-01 23:00:00+00', '2012-01-20 12:57:55.689936+00', 'Stalking the Wild Bagpipe', 'Stalking', 2468, 'M', 1, 409, 1981, 1, '');
INSERT INTO 'album' VALUES (299, '1998-12-04 23:00:00+00', '2012-01-20 12:57:55.698155+00', 'On Stage With..., Volume 1', 'On Stage 1', 2133, 'AH', 1, 401, 1985, 1, '');
INSERT INTO 'album' VALUES (300, '1998-10-05 22:00:00+00', '2012-01-20 12:57:55.706315+00', 'Salute to Scotland, A', 'Salute (BB)', 3067, 'RM', 1, 44, 0, 1, '');
INSERT INTO 'album' VALUES (301, '1998-10-14 22:00:00+00', '2012-01-20 12:57:55.71514+00', 'Fire in the Kilt', 'Fire/Kilt', 3056, 'FM', 1, 119, 1987, 1, '');
INSERT INTO 'album' VALUES (302, '1998-11-03 23:00:00+00', '2012-01-20 12:57:55.727658+00', 'On Stage With..., Volume 3', 'On Stage 3', 2133, 'CG', 1, 403, 1987, 1, '');
INSERT INTO 'album' VALUES (303, '1998-12-04 23:00:00+00', '2012-01-20 12:57:55.739925+00', 'On Stage With..., Volume 2', 'On Stage 2', 2133, 'AH', 1, 402, 0, 1, '');
INSERT INTO 'album' VALUES (304, '1999-06-24 22:00:00+00', '2012-01-20 12:57:55.752176+00', 'Sound of Scotland, The', 'Sound / Scotland', 3009, 'EN', 1, 278, 0, 1, '');
INSERT INTO 'album' VALUES (305, '1998-11-14 23:00:00+00', '2012-01-20 12:57:55.760719+00', 'Broadswords', 'Broadswords', 1556, 'DS', 1, 62, 0, 1, '');
INSERT INTO 'album' VALUES (306, '1998-12-01 23:00:00+00', '2012-01-20 12:57:55.769191+00', 'Fiddle Volume 2', 'Fiddle 2', 2094, 'M', 1, 58, 0, 1, '');
INSERT INTO 'album' VALUES (307, '1998-05-11 22:00:00+00', '2012-01-20 12:57:55.781088+00', 'South of the Grampians', 'Grampians', 2173, '', 0, 115, 0, 1, '');
INSERT INTO 'album' VALUES (308, '1998-12-29 23:00:00+00', '2012-01-20 12:57:55.789219+00', 'Scottish Choice, A', 'Scottish Choice', 3016, 'PB', 1, 431, 1974, 1, '');
INSERT INTO 'album' VALUES (309, '1998-09-16 22:00:00+00', '2012-01-20 12:57:55.797337+00', 'Sound of the North', 'Sound / North', 3063, 'GS', 1, 458, 1970, 1, '');
INSERT INTO 'album' VALUES (310, '1999-05-25 22:00:00+00', '2012-01-20 12:57:55.80545+00', 'It''s Just for Fun', 'Just for Fun 1', 2171, 'AP', 1, 6, 1986, 1, '');
INSERT INTO 'album' VALUES (311, '1999-01-09 23:00:00+00', '2012-01-20 12:57:55.817403+00', 'In Top Gear', 'In Top Gear', 3050, 'AP', 1, 356, 0, 1, '');
INSERT INTO 'album' VALUES (312, '1999-02-22 23:00:00+00', '2012-01-20 12:57:55.825506+00', 'From Manse to Danse', 'Manse to Danse', 3060, 'AP', 1, 387, 0, 1, '');
INSERT INTO 'album' VALUES (313, '1999-05-25 22:00:00+00', '2012-01-20 12:57:55.83362+00', 'Second Kirkbrae Collection, The', 'Kirkbrae 2', 2566, 'AP', 1, 306, 1998, 1, '');
INSERT INTO 'album' VALUES (314, '1998-11-23 23:00:00+00', '2012-01-20 12:57:55.845443+00', 'Hold The Lass Til I Get At Her', 'Hold The Lass', 2136, 'BC', 1, 323, 1989, 1, '');
INSERT INTO 'album' VALUES (316, '1998-10-26 23:00:00+00', '2012-01-20 12:57:55.861695+00', 'Farewell to Paternoster Square', 'Paternoster', 3014, 'BC', 1, 71, 0, 1, '');
INSERT INTO 'album' VALUES (318, '2000-04-04 22:00:00+00', '2013-04-10 09:58:48.294722+00', 'Highlander Music Scottish Dances Vol 7', 'Highlander SD 7', 3036, 'AP', 1, 139, 1999, 1, '');
INSERT INTO 'album' VALUES (269, '1998-11-15 23:00:00+00', '2014-08-05 16:47:16.393109+00', 'Measure of Scotch, A', 'Measure', 3037, 'JW', 1, 211, 1971, 1, '');
INSERT INTO 'album' VALUES (288, '1999-05-25 22:00:00+00', '2014-10-19 15:39:53.896825+00', 'Dances of Scotland Volume 1', 'Dances 1', 2032, 'GS', 1, 7, 1966, 1, '');
INSERT INTO 'album' VALUES (319, '1999-08-08 22:00:00+00', '2012-01-20 12:57:55.886357+00', 'Silver Thistle Collection', 'Silver Thistle', 3006, 'AP', 1, 100, 1998, 1, '');
INSERT INTO 'album' VALUES (320, '2000-07-05 22:00:00+00', '2012-01-20 12:57:55.898265+00', 'Valley Gold', 'Valley Gold', 2583, 'AP', 1, 186, 0, 1, '');
INSERT INTO 'album' VALUES (321, '1998-11-30 23:00:00+00', '2012-01-20 12:57:55.906383+00', 'Scottish Dance Party', 'SD Party (JM)', 3009, 'HW', 1, 276, 1965, 1, '');
INSERT INTO 'album' VALUES (324, '1998-09-08 22:00:00+00', '2012-01-20 12:57:55.931151+00', 'On Track', 'On Track', 3003, 'AP', 1, 393, 1998, 1, '');
INSERT INTO 'album' VALUES (325, '1999-10-18 22:00:00+00', '2012-01-20 12:57:55.939387+00', 'Highlander Music Scottish Dances Vol 10', 'Highlander SD10', 3040, 'AP', 1, 248, 1999, 1, '');
INSERT INTO 'album' VALUES (327, '1998-11-30 23:00:00+00', '2012-01-20 12:57:55.955837+00', 'Swing Your Partners', 'Swing', 3029, 'BC', 1, 397, 1987, 1, '');
INSERT INTO 'album' VALUES (328, '1999-06-10 22:00:00+00', '2012-01-20 12:57:55.963972+00', 'Cairngorms', 'Cairngorms', 2586, 'AP', 1, 215, 1999, 1, '');
INSERT INTO 'album' VALUES (329, '1998-11-30 23:00:00+00', '2012-01-20 12:57:55.972136+00', 'Ken and Friends', 'Ken and Friends', 1734, 'BC', 1, 389, 1975, 1, '');
INSERT INTO 'album' VALUES (268, '1999-09-27 22:00:00+00', '2018-07-31 14:11:36.673289+00', '12 Scottish Country Dances', '12 SCD Johnston', 1701, 'MC', 1, 205, 0, 1, '');
INSERT INTO 'album' VALUES (331, '1999-05-25 22:00:00+00', '2012-01-20 12:57:55.992185+00', 'Mooiste Muziek uit Schotland, De', 'Mooiste Muz (1)', 2592, '', 0, 314, 1990, 1, '');
INSERT INTO 'album' VALUES (332, '1999-04-19 22:00:00+00', '2012-01-20 12:57:56.00407+00', 'Calum Wilson & his Scottish Country Dance Band', 'Wilson & SCDB', 3055, 'EN', 1, 459, 1980, 1, '');
INSERT INTO 'album' VALUES (333, '1998-12-01 23:00:00+00', '2012-01-20 12:57:56.015836+00', 'Dances Frae the North', 'Frae the North', 2059, 'BC', 1, 18, 1986, 1, '');
INSERT INTO 'album' VALUES (334, '1998-12-01 23:00:00+00', '2012-01-20 12:57:56.024369+00', 'Swan River Selection', 'Swan River', 2462, 'BC', 1, 353, 0, 1, '');
INSERT INTO 'album' VALUES (335, '1999-06-30 22:00:00+00', '2012-01-20 12:57:56.032856+00', 'Alastair Hunter and his Caledonian Ceilidh Band', 'AH & Ceilidh B', 2596, 'EN', 1, 194, 0, 1, '');
INSERT INTO 'album' VALUES (336, '1999-05-26 22:00:00+00', '2012-01-20 12:57:56.041907+00', 'Mooiste Muziek uit Schotland, Deel 2, De', 'Mooiste Muz (2)', 3026, 'WT', 1, 166, 0, 1, '');
INSERT INTO 'album' VALUES (337, '1999-06-24 22:00:00+00', '2012-01-20 12:57:56.050391+00', 'Scottish Country Dances in Strict Tempo (No. 2)', 'Strict Tempo 2', 3010, 'IM', 1, 380, 0, 1, '');
INSERT INTO 'album' VALUES (330, '1999-06-10 22:00:00+00', '2022-12-09 10:41:32.671948+00', 'Strictly Scottish Volume Two', 'Strictly Scot 2', 3039, '', 0, 454, 0, 1, '');
INSERT INTO 'album' VALUES (338, '1999-06-24 22:00:00+00', '2012-01-20 12:57:56.059228+00', 'Comin'' Thro'' the Rye', 'Thro'' the Rye', 3010, 'IM', 1, 363, 0, 1, '');
INSERT INTO 'album' VALUES (339, '1999-06-24 22:00:00+00', '2012-01-20 12:57:56.067594+00', 'Scottish Dance Programme', 'SD Progr.', 2611, '', 0, 279, 0, 1, '');
INSERT INTO 'album' VALUES (340, '1998-11-11 23:00:00+00', '2012-01-20 12:57:56.076262+00', 'Tunes from The Newcastle Collection', 'Newcastle', 3016, 'JW', 1, 441, 1974, 1, '');
INSERT INTO 'album' VALUES (341, '1999-06-24 22:00:00+00', '2012-01-20 12:57:56.084683+00', 'Scottish Dance Programme Vol. 2', 'SD Progr. 2', 2611, 'IM', 1, 280, 0, 1, '');
INSERT INTO 'album' VALUES (342, '1999-06-24 22:00:00+00', '2012-01-20 12:57:56.093282+00', 'On With The Dance', 'On With', 2182, 'IM', 0, 47, 0, 1, '');
INSERT INTO 'album' VALUES (343, '1998-10-13 22:00:00+00', '2012-01-20 12:57:56.101992+00', 'Encore', 'Encore (DS)', 2069, 'AS', 1, 102, 1993, 1, '');
INSERT INTO 'album' VALUES (344, '1999-06-24 22:00:00+00', '2012-01-20 12:57:56.114516+00', 'Jimmy Shand Jr. Invites You To Come To The Dance', 'JS Jr. Invites', 3061, 'IM', 1, 360, 0, 1, '');
INSERT INTO 'album' VALUES (345, '1998-12-01 23:00:00+00', '2012-01-20 12:57:56.1231+00', 'Scottish and Colonial Dance Music', 'Scot & Colon', 2465, 'BC', 1, 444, 0, 1, '');
INSERT INTO 'album' VALUES (346, '1999-08-08 22:00:00+00', '2012-01-20 12:57:56.132212+00', 'Book 25. Twelve Scottish Country Dances', 'RSCDS 25', 3038, 'AP', 1, 197, 1999, 1, '');
INSERT INTO 'album' VALUES (347, '1999-08-26 22:00:00+00', '2012-01-20 12:57:56.144227+00', 'Book 26. Twelve Scottish Country Dances', 'RSCDS 26-2', 3036, 'AP', 1, 138, 1999, 1, '');
INSERT INTO 'album' VALUES (349, '1999-08-04 22:00:00+00', '2012-01-20 12:57:56.159604+00', 'Dancing Thro'' Scotland', 'Dancing / Scot (MH)', 3064, 'IP', 1, 193, 1972, 1, '');
INSERT INTO 'album' VALUES (350, '1999-08-04 22:00:00+00', '2012-01-20 12:57:56.16584+00', 'More Sounds of the North', 'Sound / North 2', 3063, 'IP', 1, 457, 0, 1, '');
INSERT INTO 'album' VALUES (326, '1998-11-02 23:00:00+00', '2012-02-11 14:20:29.429663+00', 'Scotland Dances to Alasdair Downie and his Scottish Band', 'SD (A Downie)', 2246, 'HO', 1, 116, 1960, 1, '');
INSERT INTO 'album' VALUES (351, '1999-08-04 22:00:00+00', '2012-01-20 12:57:56.169225+00', 'Scottish Country Dance Music - Vol 2', 'SCD Vol2 (RE)', 2045, 'IP', 1, 126, 0, 1, '');
INSERT INTO 'album' VALUES (353, '1999-08-05 22:00:00+00', '2012-01-20 12:57:56.176023+00', 'Play the St. Andrew''s Ball', 'St Andrews (RK)', 2645, 'AP', 1, 241, 1999, 1, '');
INSERT INTO 'album' VALUES (355, '2001-12-11 23:00:00+00', '2012-01-20 12:57:56.191521+00', 'Kardinia Capers', 'Kardinia', 2681, '', 0, 531, 1999, 2, '');
INSERT INTO 'album' VALUES (356, '2002-06-30 22:00:00+00', '2012-01-20 12:57:56.200497+00', 'Tin Woodman, The', 'Tin Woodman', 2583, '', 0, 517, 1999, 2, '');
INSERT INTO 'album' VALUES (357, '2002-07-03 22:00:00+00', '2012-01-20 12:57:56.206665+00', 'Gang on the Same Gate', 'Gang Same Gate', 2696, 'AP', 1, 515, 1999, 2, '');
INSERT INTO 'album' VALUES (358, '2002-04-25 22:00:00+00', '2012-01-20 12:57:56.212866+00', 'Hielan'' Laddie', 'Hielan'' Laddie', 2038, 'AP', 1, 505, 0, 2, '');
INSERT INTO 'album' VALUES (361, '2000-07-30 22:00:00+00', '2012-01-20 12:57:56.234156+00', 'Highlander Music Scottish Dances Vol 11', 'Highlander SD11', 2583, '', 0, 518, 2000, 2, '');
INSERT INTO 'album' VALUES (363, '2002-07-21 22:00:00+00', '2012-01-20 12:57:56.246501+00', 'Special Requests Volume 4', 'Sp.Requests 4', 3023, 'AP', 1, 512, 1999, 2, '');
INSERT INTO 'album' VALUES (364, '2000-07-01 22:00:00+00', '2012-01-20 12:57:56.255884+00', 'Dozen Dances, A', 'Dozen Dances', 2036, 'AP', 1, 504, 0, 2, '');
INSERT INTO 'album' VALUES (367, '2002-04-25 22:00:00+00', '2012-01-20 12:57:56.274493+00', 'Bobby Brown Collection, The', 'Bobby Brown Coll.', 3067, 'AP', 1, 506, 2000, 2, 'This CD set (of 2 CDs) is a reissue of Island Fling, Maid of the Mill and Tarry Awhile.');
INSERT INTO 'album' VALUES (369, '2000-11-09 23:00:00+00', '2012-01-20 12:57:56.286843+00', 'Book 41. The Millennium Dances', 'RSCDS 41', 3006, 'AP', 1, 511, 2000, 2, '');
INSERT INTO 'album' VALUES (370, '1998-10-27 23:00:00+00', '2012-01-20 12:57:56.293047+00', 'More Sounds of Scotland', 'More Sounds', 3009, 'EC', 1, 273, 1967, 1, '');
INSERT INTO 'album' VALUES (372, '1998-10-11 22:00:00+00', '2012-01-20 12:57:56.305423+00', 'Jimmy MacGovern Country Dance Orchestra, The', 'JMacGov CD Orch', 2291, 'JW', 1, 254, 1977, 1, '');
INSERT INTO 'album' VALUES (373, '2000-09-05 22:00:00+00', '2012-01-20 12:57:56.311612+00', 'Piper''s Choice', 'Piper''s Choice', 1556, '', 0, 509, 2000, 2, '');
INSERT INTO 'album' VALUES (374, '1998-11-03 23:00:00+00', '2012-01-20 12:57:56.317783+00', 'Scottish Dance Music', 'SD Music (GM)', 2412, 'HO', 1, 299, 1976, 1, '');
INSERT INTO 'album' VALUES (376, '1999-05-25 22:00:00+00', '2012-01-20 12:57:56.332982+00', 'Host of the Air, The', 'Host / Air', 2418, 'SP', 1, 172, 1998, 1, '');
INSERT INTO 'album' VALUES (377, '2000-09-10 22:00:00+00', '2012-01-20 12:57:56.339159+00', '15 Social Dances', '15 Social Dances', 3002, 'AP', 1, 523, 2000, 2, '');
INSERT INTO 'album' VALUES (378, '2000-12-04 23:00:00+00', '2012-01-20 12:57:56.34538+00', 'Water Aid Set Dances Vol. 1', 'Wateraid', 2566, 'MM', 1, 527, 1994, 2, '');
INSERT INTO 'album' VALUES (379, '1998-10-12 22:00:00+00', '2012-01-20 12:57:56.351545+00', 'Pride of Scotland, The', 'Pride Scotland', 3010, 'JW', 1, 377, 0, 1, '');
INSERT INTO 'album' VALUES (380, '2000-12-04 23:00:00+00', '2012-01-20 12:57:56.357739+00', 'Friendship Dances', 'Friendship', 2197, '', 0, 525, 1998, 2, '');
INSERT INTO 'album' VALUES (381, '1998-11-14 23:00:00+00', '2012-01-20 12:57:56.36391+00', 'Legendary Jimmy Shand, The', 'Legendary', 3010, 'RC', 1, 372, 1968, 1, '');
INSERT INTO 'album' VALUES (383, '1999-01-30 23:00:00+00', '2012-01-20 12:57:56.383324+00', 'Rose and Thistle Collection, The', 'Rose & Thistle', 2188, 'IS', 1, 94, 1995, 1, '');
INSERT INTO 'album' VALUES (385, '1999-02-01 23:00:00+00', '2012-01-20 12:57:56.399935+00', 'Village Hall to Royal Ball', 'Village Hall', 2189, 'PM', 1, 342, 1952, 1, '');
INSERT INTO 'album' VALUES (384, '2001-12-11 23:00:00+00', '2012-04-14 15:00:42.656603+00', 'Memories of Fife', 'Memories of Fife', 3002, '', 0, 522, 2000, 2, '');
INSERT INTO 'album' VALUES (382, '2001-03-18 23:00:00+00', '2012-04-27 17:27:16.188636+00', 'Etive Selection of Scottish Country Dancing, The', 'Etive', 3038, '', 0, 519, 2001, 2, '');
INSERT INTO 'album' VALUES (354, '1999-08-26 22:00:00+00', '2012-04-27 19:02:43.231656+00', 'Book 40. SC Dances for young people and new dancers', 'RSCDS 40', 2137, 'AP', 1, 74, 1999, 1, '');
INSERT INTO 'album' VALUES (362, '2001-12-11 23:00:00+00', '2012-10-18 21:32:13.3629+00', 'Celebrate Fifty Years of Dancing with the Boston Branch', 'Celebrate 50', 3016, 'AP', 1, 536, 2000, 2, '');
INSERT INTO 'album' VALUES (368, '1998-10-20 22:00:00+00', '2013-02-15 17:50:07.011835+00', 'Meet the Olympians', 'Meet Olympians', 3024, 'EC', 1, 320, 0, 1, '');
INSERT INTO 'album' VALUES (386, '2002-06-02 22:00:00+00', '2012-01-20 12:57:56.406133+00', '12th Night Ball 2001', '12th Night', 2846, '', 0, 501, 0, 2, '');
INSERT INTO 'album' VALUES (457, '2004-10-12 22:00:00+00', '2012-01-20 12:57:56.880196+00', 'Book 12.', 'RSCDS 12', 3067, 'AP', 1, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (323, '2000-04-04 22:00:00+00', '2013-04-10 09:59:18.961858+00', 'Highlander Music Scottish Dances Vol 9', 'Highlander SD 9', 2585, 'AP', 1, 242, 1999, 1, '');
INSERT INTO 'album' VALUES (387, '2002-04-25 22:00:00+00', '2012-01-20 12:57:56.412405+00', 'Dancing Fingers 1', 'Fingers 1-CD', 1502, '', 1, 521, 2001, 2, 'This CD is a re-issue of Dancing Fingers (formerly on tape) with extra material');
INSERT INTO 'album' VALUES (388, '1998-09-02 22:00:00+00', '2012-01-20 12:57:56.418617+00', 'Saint Andrew''s Ball - Volume 2', 'St. A. Ball 2', 3016, '', 0, 426, 0, 1, '');
INSERT INTO 'album' VALUES (389, '2002-04-02 22:00:00+00', '2012-01-20 12:57:56.424831+00', 'Reel Friends Book 2', 'Reel Friends 2', 1396, 'AP', 1, 516, 2000, 2, '');
INSERT INTO 'album' VALUES (390, '2001-05-30 22:00:00+00', '2012-01-20 12:57:56.431011+00', 'Live and Well', 'Live & Well', 3030, 'AP', 1, 528, 2001, 2, '');
INSERT INTO 'album' VALUES (392, '2002-04-25 22:00:00+00', '2012-01-20 12:57:56.443483+00', 'Country Dance, Ceilidh Dance', 'Country, Ceilidh', 3026, 'AP', 1, 514, 2001, 2, '');
INSERT INTO 'album' VALUES (393, '2002-04-25 22:00:00+00', '2012-01-20 12:57:56.449679+00', 'Aberdeen Collection, An', 'Aberdeen', 2944, 'AP', 1, 532, 2001, 2, '');
INSERT INTO 'album' VALUES (395, '2001-11-17 23:00:00+00', '2012-01-20 12:57:56.462024+00', 'Morino Magic', 'Morino Magic', 3012, '', 0, 529, 1999, 2, '');
INSERT INTO 'album' VALUES (352, '1999-08-04 22:00:00+00', '2015-07-28 13:00:05.662353+00', 'Sound of Jim Johnstone and His Band, The', 'Sound of JJ', 3037, 'IP', 1, 213, 1974, 1, '');
INSERT INTO 'album' VALUES (365, '1998-11-11 23:00:00+00', '2015-10-08 14:48:57.288521+00', 'Just What the Doctor Ordered', 'Doctor', 3012, '', 1, 310, 1991, 1, '');
INSERT INTO 'album' VALUES (396, '2001-11-18 23:00:00+00', '2012-01-20 12:57:56.468203+00', 'Fife Fairing, A', 'Fife Fairing', 3016, '', 0, 534, 0, 2, '');
INSERT INTO 'album' VALUES (398, '1999-07-18 22:00:00+00', '2012-01-20 12:57:56.480597+00', 'Book 26. Scottish Country Dance Music', 'RSCDS 26-1', 2184, 'BL', 1, 350, 1973, 1, '');
INSERT INTO 'album' VALUES (399, '1999-05-25 22:00:00+00', '2012-01-20 12:57:56.486767+00', 'Awa'' Frae Hame', 'Awa'' Frae Hame', 3010, 'BL', 1, 361, 1963, 1, '');
INSERT INTO 'album' VALUES (400, '2001-12-18 23:00:00+00', '2012-01-20 12:57:56.492951+00', 'Clashmadin Volume One', 'Clashmadin1', 3045, '', 1, 526, 2001, 2, '');
INSERT INTO 'album' VALUES (401, '2002-02-24 23:00:00+00', '2012-01-20 12:57:56.499147+00', 'Delft Book of Scottish Country Dances, The', 'Delft', 3016, 'AP', 1, 535, 2001, 2, '');
INSERT INTO 'album' VALUES (402, '2002-07-02 22:00:00+00', '2012-01-20 12:57:56.50534+00', 'Reflections of Dalriada', 'Dalriada', 2993, 'AP', 1, 513, 0, 2, '');
INSERT INTO 'album' VALUES (404, '2002-03-12 23:00:00+00', '2012-01-20 12:57:56.518398+00', 'Dances with a Difference, Volume 1', 'Difference 1', 3002, '', 0, 524, 2002, 2, '');
INSERT INTO 'album' VALUES (405, '2002-04-03 22:00:00+00', '2012-01-20 12:57:56.524609+00', 'March Hare, The', 'March Hare', 3092, 'AP', 1, 520, 2001, 2, '');
INSERT INTO 'album' VALUES (406, '1998-10-13 22:00:00+00', '2012-01-20 12:57:56.530825+00', 'Scottish Collection: Dance Music', 'S Coll: Dance', 3016, 'AS', 1, 432, 1996, 1, '');
INSERT INTO 'album' VALUES (407, '2002-05-14 22:00:00+00', '2012-01-20 12:57:56.537017+00', 'Music for Leaflet Dances Vol. 1', 'Leaflet 1', 3016, 'AP', 1, 0, 2002, 2, '');
INSERT INTO 'album' VALUES (408, '1998-10-13 22:00:00+00', '2012-01-20 12:57:56.543256+00', 'Lilt O'' Scotland', 'Lilt Scotland', 2173, 'AS', 1, 114, 1994, 1, '');
INSERT INTO 'album' VALUES (409, '2002-06-19 22:00:00+00', '2012-01-20 12:57:56.549436+00', 'Music for Leaflet Dances Vol. 2', 'Leaflet 2', 3137, 'PM', 1, 0, 2002, 2, '');
INSERT INTO 'album' VALUES (410, '2002-06-04 22:00:00+00', '2012-01-20 12:57:56.555701+00', 'First Dram, A', 'First Dram', 3139, 'AP', 1, 0, 2002, 2, '');
INSERT INTO 'album' VALUES (360, '2000-03-18 23:00:00+00', '2022-08-23 22:45:00.110855+00', 'Nice to See You', 'Nice to See You', 2188, '', 0, 510, 2000, 2, '');
INSERT INTO 'album' VALUES (348, '1999-08-04 22:00:00+00', '2022-12-21 14:57:33.152114+00', 'Looking For a Partner', 'Look Part (2)', 2631, 'IP', 1, 394, 1968, 1, '');
INSERT INTO 'album' VALUES (411, '2002-07-02 22:00:00+00', '2012-01-20 12:57:56.561921+00', 'Skye Collection, A', 'Skye Coll (CD)', 3016, 'PM', 1, 0, 2001, 2, '');
INSERT INTO 'album' VALUES (413, '2002-06-25 22:00:00+00', '2012-01-20 12:57:56.574285+00', 'Scottish Country Dancing', 'SCD (Crowe)', 3018, 'IS', 1, 0, 1991, 2, '');
INSERT INTO 'album' VALUES (414, '1999-08-04 22:00:00+00', '2012-01-20 12:57:56.580694+00', 'Dance Party Favourites', 'DancePartyFavs', 3009, 'BC', 1, 270, 0, 1, '');
INSERT INTO 'album' VALUES (415, '1998-11-15 23:00:00+00', '2012-01-20 12:57:56.586873+00', 'Scottish Country Dances', 'SCD (various)', 3016, 'BL', 1, 434, 1964, 1, '');
INSERT INTO 'album' VALUES (416, '2002-06-30 22:00:00+00', '2012-01-20 12:57:56.593108+00', 'Iain MacPhail Celebrates in South America', 'MacPhail in SA', 3008, 'PM', 1, 0, 2000, 2, '');
INSERT INTO 'album' VALUES (417, '1998-10-21 22:00:00+00', '2012-01-20 12:57:56.599294+00', 'Scottish Country Dance', 'SCD (Glenda)', 3057, 'EC', 1, 146, 1979, 1, '');
INSERT INTO 'album' VALUES (418, '1999-06-24 22:00:00+00', '2012-01-20 12:57:56.6064+00', 'Scottish Country Dances in Strict Tempo (No. 3)', 'Strict Tempo 3', 3010, 'EC', 1, 381, 0, 1, '');
INSERT INTO 'album' VALUES (419, '1999-01-13 23:00:00+00', '2012-01-20 12:57:56.6126+00', 'Scotland: The Sound of John Ellis and his HC Band Vol. 2', 'Scotland: Ellis2', 3056, 'EN', 1, 124, 1975, 1, '');
INSERT INTO 'album' VALUES (397, '2001-12-18 23:00:00+00', '2012-10-02 16:01:28.708245+00', 'Come Forth to the Scottish Country Dance', 'Come Forth', 3032, 'AP', 1, 502, 2000, 2, '');
INSERT INTO 'album' VALUES (420, '1998-10-25 23:00:00+00', '2012-01-20 12:57:56.618782+00', 'Cavendish Dance Band Plays SCD in Traditional Style', 'Cavendish DB', 3068, 'EN', 1, 60, 1973, 1, '');
INSERT INTO 'album' VALUES (421, '1998-10-25 23:00:00+00', '2012-01-20 12:57:56.625669+00', 'Scotland: The Sound of John Ellis and his HC Band', 'Scotland: Ellis', 3056, 'EN', 1, 123, 1974, 1, '');
INSERT INTO 'album' VALUES (423, '2003-01-01 23:00:00+00', '2012-01-20 12:57:56.63846+00', 'Dancing Fingers 4. The Blackadder Collection', 'Fingers 4', 1502, 'IM', 1, 0, 2002, 2, '');
INSERT INTO 'album' VALUES (424, '2003-01-01 23:00:00+00', '2012-01-20 12:57:56.644741+00', 'Dancing Fingers 5. The Merse Collection', 'Fingers 5', 1502, 'IM', 1, 0, 2002, 2, '');
INSERT INTO 'album' VALUES (425, '2002-08-20 22:00:00+00', '2012-01-20 12:57:56.650926+00', 'I Love Scottish Country Dance Music', 'I Love SCD Music', 3185, 'IM', 1, 0, 1997, 2, '');
INSERT INTO 'album' VALUES (426, '2002-10-20 22:00:00+00', '2012-01-20 12:57:56.657104+00', 'Dancing Feet', 'Dancing Feet', 2184, '', 0, 0, 2002, 2, '');
INSERT INTO 'album' VALUES (427, '2002-11-13 23:00:00+00', '2012-01-20 12:57:56.663287+00', 'Book 42.', 'RSCDS 42', 3217, 'PM', 1, 0, 2002, 2, '');
INSERT INTO 'album' VALUES (428, '2003-01-01 23:00:00+00', '2012-01-20 12:57:56.66946+00', 'Dancers'' Choice 1', 'Dancers C.:Anderson', 3217, 'AP', 1, 0, 2002, 2, '');
INSERT INTO 'album' VALUES (429, '2003-02-11 23:00:00+00', '2012-01-20 12:57:56.675666+00', 'Miss Ogilvie''s Fancy', 'Miss Ogilvie', 2696, 'AP', 1, 0, 2002, 2, '');
INSERT INTO 'album' VALUES (430, '2003-02-11 23:00:00+00', '2012-01-20 12:57:56.681876+00', 'Special Requests Volume 5', 'Sp.Requests 5', 3023, 'AP', 1, 0, 2002, 2, '');
INSERT INTO 'album' VALUES (431, '2003-02-11 23:00:00+00', '2012-01-20 12:57:56.688074+00', 'Book 36. Frae a'' the Airts, Vol 1', 'RSCDS 36 (CD)', 3008, 'AP', 1, 0, 2002, 2, '');
INSERT INTO 'album' VALUES (432, '2003-02-12 23:00:00+00', '2012-01-20 12:57:56.694652+00', 'Book 37. Frae a'' the Airts, Vol 2', 'RSCDS 37', 3008, '', 0, 0, 2002, 2, '');
INSERT INTO 'album' VALUES (434, '2003-02-15 23:00:00+00', '2012-01-20 12:57:56.707105+00', 'Road to Forfar, The', 'Road to Forfar', 3032, 'IM', 1, 0, 2002, 2, '');
INSERT INTO 'album' VALUES (437, '2003-05-19 22:00:00+00', '2012-01-20 12:57:56.72592+00', 'Best of Scottish Dance Bands, The', 'Best of SDB (LP)', 3016, '', 0, 0, 0, 2, '');
INSERT INTO 'album' VALUES (1111, '2018-04-10 10:33:52.122952+00', '2018-04-10 13:24:32.030271+00', 'More Swans of Atlanta', '', 11613, '', 0, 0, 2018, 0, '');
INSERT INTO 'album' VALUES (436, '2003-02-24 23:00:00+00', '2019-04-09 16:58:45.207593+00', 'Waverley Station: First Stop!', 'First Stop', 2885, '', 0, 0, 2003, 2, 'Can be purchased from 

http://rscdsleeds.uk/index.php?id_product=972&controller=product

');
INSERT INTO 'album' VALUES (441, '2003-11-17 23:00:00+00', '2012-01-20 12:57:56.751399+00', 'Book 43', 'RSCDS 43', 3008, '', 0, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (442, '2003-11-17 23:00:00+00', '2012-01-20 12:57:56.757582+00', 'Quick Here''s Anither Yin', 'Anither Yin', 3019, '', 0, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (445, '2003-12-18 23:00:00+00', '2012-01-20 12:57:56.778958+00', 'Many Happy Returns', 'Happy Returns', 3399, '', 0, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (446, '2003-12-21 23:00:00+00', '2012-01-20 12:57:56.817734+00', 'In a Different Light', 'Different Light', 3071, 'AP', 1, 0, 1990, 0, '');
INSERT INTO 'album' VALUES (448, '2004-04-26 22:00:00+00', '2012-01-20 12:57:56.830493+00', 'Book 38. Music for Eight Scottish Country Dances', 'Book 38', 3002, 'AP', 1, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (450, '2004-05-02 22:00:00+00', '2012-01-20 12:57:56.842864+00', 'Delaware Valley Spring Ball 2003', 'Delaware', 2586, 'AP', 1, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (451, '2004-08-15 22:00:00+00', '2012-01-20 12:57:56.849126+00', 'Dance Through The Miscellanies - Part 3', 'Miscellanies 3', 3002, 'LH', 1, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (452, '2004-08-15 22:00:00+00', '2012-01-20 12:57:56.855349+00', 'Book 44 - Music for Ten Scottish Country Dances', 'RSCDS 44', 3039, 'LH', 1, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (453, '2004-08-24 22:00:00+00', '2012-01-20 12:57:56.86155+00', 'Luckenbooth Brooch, The', 'Luckenbooth', 3012, 'LH', 1, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (422, '2002-07-02 22:00:00+00', '2012-10-02 15:22:54.494014+00', 'Ceilidh Round the Steeple', 'Ceilidh Steeple', 3050, 'BB', 1, 0, 2001, 2, '');
INSERT INTO 'album' VALUES (444, '2003-11-23 23:00:00+00', '2012-10-10 14:15:18.23552+00', 'Devil''s Quandary, The', 'Devil''s Quandary', 3403, '', 0, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (435, '2003-02-15 23:00:00+00', '2012-12-26 15:44:48.453269+00', 'Vintage 78''s', 'Vintage 78s', 2328, '', 0, 0, 2001, 2, '');
INSERT INTO 'album' VALUES (456, '2004-10-12 22:00:00+00', '2012-01-20 12:57:56.873934+00', 'Book 31/32', 'RSCDS 31/32', 3022, 'AP', 1, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (391, '2001-06-13 22:00:00+00', '2014-05-13 09:45:31.19738+00', 'Reel Party, The', 'Reel Party', 3011, 'AP', 1, 503, 1999, 2, '');
INSERT INTO 'album' VALUES (458, '2004-10-31 23:00:00+00', '2012-01-20 12:57:56.886397+00', 'Dancers'' Choice 2', 'Dancers'' Ch 2', 3039, '', 0, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (459, '2004-10-31 23:00:00+00', '2012-01-20 12:57:56.892637+00', 'Berkhamsted Strathspey & Reel Club: Golden Jubilee Book of', 'Berkhamsted', 3459, '', 0, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (460, '2004-11-01 23:00:00+00', '2012-01-20 12:57:56.898848+00', 'Dancing Forth Too', 'Dancing Forth 2', 3464, 'AP', 1, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (461, '2004-11-02 23:00:00+00', '2012-01-20 12:57:56.905019+00', 'Music for Graded Scottish Country Dances', 'Graded (CD)', 3016, 'AP', 1, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (463, '2004-11-24 23:00:00+00', '2012-01-20 12:57:56.917838+00', 'Special Requests Volume 6', 'Sp. Requests 6', 3023, '', 0, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (466, '2004-12-07 23:00:00+00', '2012-01-20 12:57:56.936594+00', 'Breakdown, The', 'Breakdown', 3483, '', 0, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (467, '2004-12-14 23:00:00+00', '2012-01-20 12:57:56.943288+00', 'Really Jiggin''', '', 3060, '', 0, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (468, '2005-01-05 23:00:00+00', '2012-01-20 12:57:56.949514+00', 'Old Favourites and Odd Couples', 'Favourites/Couples', 3496, 'LH', 1, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (471, '2005-02-03 23:00:00+00', '2012-01-20 12:57:56.96805+00', 'One Step at a Time', 'One Step', 3420, '', 0, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (403, '2002-03-12 23:00:00+00', '2017-12-15 23:06:43.104325+00', 'Book 19. Music for Twelve Scottish Country Dances', 'RSCDS 19', 3028, '', 1, 240, 1996, 1, '');
INSERT INTO 'album' VALUES (462, '2004-11-24 23:00:00+00', '2017-11-19 18:40:00.685109+00', 'Birl Roond Forfar, A', 'Birl Roond Forfar', 3032, '', 0, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (472, '2005-02-22 23:00:00+00', '2012-01-20 12:57:56.974226+00', 'What You Hear is What You Get', 'What You See', 1836, '', 0, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (473, '2005-03-22 23:00:00+00', '2012-01-20 12:57:56.9804+00', 'Domino Five', 'Domino 5', 3019, '', 0, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (474, '2005-03-24 23:00:00+00', '2012-01-20 12:57:56.986608+00', 'Music for Quadrilles', 'Quadrilles', 3530, '', 0, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (475, '2005-04-13 22:00:00+00', '2012-01-20 12:57:56.992839+00', 'Frank Reid plays Just For You', '', 1557, '', 0, 0, 1979, 0, '');
INSERT INTO 'album' VALUES (476, '2005-05-01 22:00:00+00', '2012-01-20 12:57:56.999013+00', 'Scottish Fancy, A', 'Scot Fancy LP', 3010, '', 0, 0, 1971, 0, '');
INSERT INTO 'album' VALUES (478, '2005-05-01 22:00:00+00', '2012-01-20 12:57:57.014274+00', 'Jimmy Shand Favourites', 'Shand Favs', 3010, '', 0, 0, 0, 0, '');
INSERT INTO 'album' VALUES (479, '2005-05-03 22:00:00+00', '2012-01-20 12:57:57.020543+00', 'Industrial Strength', 'Industrial Strength', 3604, '', 0, 0, 0, 0, '');
INSERT INTO 'album' VALUES (480, '2005-06-29 22:00:00+00', '2012-01-20 12:57:57.026814+00', 'Book 45', 'RSCDS 45', 3040, 'AP', 1, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (483, '2005-08-25 22:00:00+00', '2012-01-20 12:57:57.045856+00', 'Live in Moffat', 'Live in Moffat', 3619, 'AP', 1, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (484, '2005-11-13 23:00:00+00', '2012-01-20 12:57:57.052125+00', 'It''s Just for Fun', 'Just for Fun 2', 3650, '', 0, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (485, '2005-12-18 23:00:00+00', '2012-01-20 12:57:57.058357+00', 'Dancing Master Remembered, A', 'Dancing Master', 3653, 'WT', 1, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (486, '2006-01-05 23:00:00+00', '2012-01-20 12:57:57.064544+00', 'Highlander Music Scottish Dances Vol 12', 'Highlander SD 12', 3217, 'LH', 1, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (487, '2006-01-11 23:00:00+00', '2012-01-20 12:57:57.070723+00', 'Southern Touch, The', 'Southern Touch', 2681, 'LH', 1, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (488, '2006-01-19 23:00:00+00', '2012-01-20 12:57:57.076925+00', 'Highlander Music Scottish Dances Vol 13', 'Highlander SD 13', 3039, 'AP', 1, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (491, '2006-03-07 23:00:00+00', '2012-01-20 12:57:57.096574+00', 'We Twa', 'We Twa', 3019, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (489, '2006-02-16 23:00:00+00', '2012-12-26 11:42:49.037292+00', 'Book 15', 'RSCDS 15', 3011, 'AP', 1, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (492, '2006-03-30 22:00:00+00', '2012-01-20 12:57:57.102811+00', 'Odds, The', 'The Odds', 3185, '', 0, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (433, '2003-02-14 23:00:00+00', '2022-12-11 20:07:08.374822+00', 'Music for the Scotia Centenary', 'Scotia Cent.', 3016, 'AP', 1, 0, 2002, 2, '');
INSERT INTO 'album' VALUES (477, '2005-05-01 22:00:00+00', '2022-12-16 14:07:37.155538+00', 'Scottish Country Dancing', 'SCD: McBain', 2058, 'AP', 1, 0, 1973, 0, '');
INSERT INTO 'album' VALUES (495, '2006-05-17 22:00:00+00', '2012-01-20 12:57:57.121789+00', 'Lochiel Collection, The', 'Lochiel', 3420, 'AP', 1, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (496, '2006-05-21 22:00:00+00', '2012-01-20 12:57:57.128009+00', 'Let''s Dance', 'Let''s Dance', 3185, 'LH', 1, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (497, '2006-05-22 22:00:00+00', '2012-01-20 12:57:57.134196+00', '80 Years of Dundee Dancing', 'Dundee 80', 3683, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (498, '2006-05-25 22:00:00+00', '2012-01-20 12:57:57.14043+00', 'Leaflet 32 Dances, The', 'Leaflet 32', 3685, '', 0, 0, 0, 0, '');
INSERT INTO 'album' VALUES (500, '2006-06-27 22:00:00+00', '2012-01-20 12:57:57.153126+00', 'A'' the best fae Banffshire', 'Banffshire', 3023, 'AP', 1, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (506, '2006-08-13 22:00:00+00', '2012-01-20 12:57:57.225431+00', 'From Glenamond to Glenquaich', 'Glenalmond', 3025, '', 0, 0, 1995, 0, '');
INSERT INTO 'album' VALUES (507, '2006-08-24 22:00:00+00', '2012-01-20 12:57:57.231709+00', 'Blackwater Collection, The', 'Blackwater', 3014, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (508, '2006-10-12 22:00:00+00', '2012-01-20 12:57:57.237932+00', 'Diamond Jubilee', 'Diamond (Lothian)', 3040, 'LH', 1, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (509, '2006-10-25 22:00:00+00', '2012-01-20 12:57:57.244171+00', 'Vallin Suite 1, The', 'Vallin', 3011, 'AP', 1, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (510, '2006-12-05 23:00:00+00', '2012-01-20 12:57:57.250359+00', 'Reel Friends Book 3', 'Reel Friends 3', 3040, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (511, '2006-12-17 23:00:00+00', '2012-01-20 12:57:57.256542+00', '75th Anniversary of London Branch', 'London 75', 3016, 'AP', 1, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (513, '2007-01-03 23:00:00+00', '2012-01-20 12:57:57.268911+00', 'Piano Dance', 'Piano Dance', 1846, 'AP', 1, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (702, '1998-11-15 23:00:00+00', '2012-01-20 12:57:57.287501+00', 'Breath of Shetland, A', 'Shetland', 2177, 'EE', 1, 177, 1975, 1, '');
INSERT INTO 'album' VALUES (703, '1998-10-15 22:00:00+00', '2012-01-20 12:57:57.293679+00', 'Jimmy Shand Dance Party, A', 'JS Dance Party', 3010, 'WE', 1, 369, 0, 1, '');
INSERT INTO 'album' VALUES (705, '1998-11-20 23:00:00+00', '2012-01-20 12:57:57.299881+00', 'Across the Tay', 'AcrossTay', 2178, 'BC', 1, 298, 0, 1, '');
INSERT INTO 'album' VALUES (706, '1998-10-11 22:00:00+00', '2012-01-20 12:57:57.306073+00', 'Evening of Scottish Country Dancing, An', 'Evening of SCD', 2303, 'EN', 1, 204, 1974, 1, '');
INSERT INTO 'album' VALUES (709, '1998-11-14 23:00:00+00', '2012-01-20 12:57:57.312258+00', 'Artistic License', 'Artistic License', 2179, 'DS', 1, 300, 1996, 1, '');
INSERT INTO 'album' VALUES (712, '1999-10-05 22:00:00+00', '2012-01-20 12:57:57.327402+00', 'Barn Dance Party', 'Barn Dance', 3042, '??', 1, 328, 0, 1, '');
INSERT INTO 'album' VALUES (714, '1999-08-06 22:00:00+00', '2012-01-20 12:57:57.333602+00', 'Bobby MacLeod''s Highland Dance Band', 'MacLeod HDB', 2328, 'EN', 1, 261, 0, 1, '');
INSERT INTO 'album' VALUES (715, '1998-10-14 22:00:00+00', '2012-01-20 12:57:57.339807+00', 'Bobby''s Kind of Music', 'Kind of Music', 2328, 'BS', 1, 262, 1970, 1, '');
INSERT INTO 'album' VALUES (716, '1999-06-30 22:00:00+00', '2012-01-20 12:57:57.346151+00', 'Bonnie Scotland', 'Bonnie Scot', 3016, 'PB', 1, 414, 1974, 1, '');
INSERT INTO 'album' VALUES (717, '1998-10-10 22:00:00+00', '2012-01-20 12:57:57.352435+00', 'Canada on Tour', 'Canada on Tour', 3067, 'JW', 1, 36, 0, 1, '');
INSERT INTO 'album' VALUES (718, '1998-12-29 23:00:00+00', '2012-01-20 12:57:57.358622+00', 'Come Dance Wi'' Me', 'Dance Wi'' Me', 2180, 'EN', 1, 386, 0, 1, '');
INSERT INTO 'album' VALUES (719, '1998-10-12 22:00:00+00', '2012-01-20 12:57:57.364811+00', 'Come Home to Scotland', 'Come Home', 3064, 'EN', 1, 192, 1968, 1, '');
INSERT INTO 'album' VALUES (721, '1998-11-14 23:00:00+00', '2012-01-20 12:57:57.370998+00', 'Come Scottish Country Dancing with the Tillside Trio', 'Come SCD/Till', 2064, 'DS', 1, 407, 1980, 1, '');
INSERT INTO 'album' VALUES (722, '1999-06-24 22:00:00+00', '2012-01-20 12:57:57.377187+00', 'Come to Fiona''s Wedding', 'Fiona Wedding', 3009, 'IM', 1, 269, 1969, 1, '');
INSERT INTO 'album' VALUES (723, '1999-01-05 23:00:00+00', '2012-01-20 12:57:57.383398+00', 'Country Dancers Delight', 'CD Delight', 3041, 'HO', 1, 103, 0, 1, '');
INSERT INTO 'album' VALUES (512, '2007-09-03 22:00:00+00', '2012-03-25 08:49:44.872605+00', 'Platinum - 70 Years of Dancing in St Andrews', 'St Andrews Platinum', 3016, 'LH', 1, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (516, '2007-11-15 23:00:00+00', '2012-09-16 15:48:23.328995+00', 'Scottish Christmas Dance Party', 'Christmas Party', 10659, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (501, '2006-07-27 22:00:00+00', '2012-09-28 16:13:51.982825+00', 'Book 10. Music for Twelve Scottish Country Dances', 'RSCDS 10 (CD)', 1396, '', 0, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (504, '2006-07-30 22:00:00+00', '2012-10-02 14:40:13.259915+00', 'Caledonian Muse', 'Caledonian Muse', 3017, 'LH', 1, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (505, '2006-07-31 22:00:00+00', '2012-10-11 16:07:19.538577+00', 'Kangaroo Paw, The', 'Kangaroo Paw', 3217, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (482, '2005-08-08 22:00:00+00', '2013-04-10 06:23:00.658451+00', 'Book 4. Music for Twelve Scottish Country Dances', 'RSCDS 4', 3011, '', 0, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (470, '2005-02-01 23:00:00+00', '2013-05-12 12:32:41.967101+00', 'Clapyerhands ''n'' Stampyerfeet', 'Clapyerhands', 3420, '', 0, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (502, '2006-07-27 22:00:00+00', '2014-02-14 13:59:35.701365+00', 'Scottish Country Dances Vol 1-2', 'SCD Vol 1-2 Ian Muir', 2566, '', 0, 0, 1992, 0, '');
INSERT INTO 'album' VALUES (469, '2005-01-27 23:00:00+00', '2014-02-14 14:11:30.708178+00', 'Third Kirkbrae Collection, The', 'Kirkbrae 3', 2566, '', 0, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (503, '2006-07-27 22:00:00+00', '2014-02-14 14:00:56.192322+00', 'Scottish Country Dances Vol 3', 'SCD Vol 3 Ian Muir', 2566, '', 0, 0, 1994, 0, '');
INSERT INTO 'album' VALUES (465, '2004-11-24 23:00:00+00', '2014-07-30 13:40:40.357058+00', 'Dark Island, The', 'Dark Island', 2501, '', 0, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (494, '2006-05-07 22:00:00+00', '2012-10-18 13:02:30.398342+00', 'Favourite SCDs Vol. 3 Teacher''s Choice', 'Teacher''s Choice', 3678, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (493, '2006-04-27 22:00:00+00', '2012-12-26 11:28:40.860377+00', 'Celtic Fire in the Music', 'Celtic Fire', 3067, 'LH', 1, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (724, '1998-12-03 23:00:00+00', '2012-01-20 12:57:57.389615+00', 'Dance Date No 1', 'Dance Date 1', 3065, 'EN', 1, 52, 0, 1, '');
INSERT INTO 'album' VALUES (725, '2002-04-08 22:00:00+00', '2012-01-20 12:57:57.395901+00', 'Dance Date No 2', 'Dance Date 2', 3065, 'BL', 1, 53, 0, 1, '');
INSERT INTO 'album' VALUES (727, '1998-11-03 23:00:00+00', '2012-01-20 12:57:57.40215+00', 'Dance with the London Highland Club', 'London HC2', 2414, 'NH', 1, 337, 1974, 1, '');
INSERT INTO 'album' VALUES (728, '1999-04-22 22:00:00+00', '2012-01-20 12:57:57.408365+00', 'Dances Frae the North, Vols 1, 2 & 3', 'North 1, 2 & 3', 3016, 'AS', 1, 416, 1997, 1, '');
INSERT INTO 'album' VALUES (729, '1998-07-22 22:00:00+00', '2012-01-20 12:57:57.414555+00', 'Dances of Scotland Volume 3', 'Dances /Scot 3', 3024, 'CG', 1, 319, 1973, 1, '');
INSERT INTO 'album' VALUES (730, '1998-10-13 22:00:00+00', '2012-01-20 12:57:57.420733+00', 'Dances of Scotland', 'Dances / Scot', 1094, 'EC', 1, 286, 0, 1, '');
INSERT INTO 'album' VALUES (732, '1998-11-19 23:00:00+00', '2012-01-20 12:57:57.426933+00', 'Dancing with the Shands', 'Dancing Shands', 3061, 'AS', 1, 357, 1994, 1, '');
INSERT INTO 'album' VALUES (734, '1999-03-23 23:00:00+00', '2012-01-20 12:57:57.43598+00', 'Donside Records presents', 'Donside', 3057, 'BC', 1, 143, 1987, 1, '');
INSERT INTO 'album' VALUES (735, '1998-11-15 23:00:00+00', '2012-01-20 12:57:57.442179+00', 'Ed Brydie and his Scottish Ramblers', 'Ramblers', 2182, 'BL', 1, 46, 0, 1, '');
INSERT INTO 'album' VALUES (737, '1998-12-19 23:00:00+00', '2012-01-20 12:57:57.448441+00', 'English Folk Dances', 'English FD', 3010, 'PB', 1, 365, 1973, 1, '');
INSERT INTO 'album' VALUES (740, '1998-10-11 22:00:00+00', '2012-01-20 12:57:57.454642+00', 'Fiddle Me Jig', 'Fiddle Me Jig', 3016, 'JW', 1, 420, 0, 1, '');
INSERT INTO 'album' VALUES (741, '1998-10-11 22:00:00+00', '2012-01-20 12:57:57.460836+00', 'Fitchet''s Fancy', 'Fitchet''s', 2301, 'JW', 1, 134, 1981, 1, '');
INSERT INTO 'album' VALUES (743, '1998-10-18 22:00:00+00', '2012-01-20 12:57:57.467047+00', 'For Old Tymes Sake', 'For Old Tymes', 3067, 'EE', 1, 37, 1996, 1, '');
INSERT INTO 'album' VALUES (745, '1998-12-29 23:00:00+00', '2012-01-20 12:57:57.476326+00', 'Gay Gordons, Vol 1', 'Gay Gordons 1', 3026, 'JW', 1, 162, 0, 1, '');
INSERT INTO 'album' VALUES (746, '1998-10-11 22:00:00+00', '2012-01-20 12:57:57.48529+00', 'Gay Gordons, Vol 2', 'Gay Gordons 2', 3026, 'JW', 1, 163, 0, 1, '');
INSERT INTO 'album' VALUES (747, '1998-10-27 23:00:00+00', '2012-01-20 12:57:57.494268+00', 'Golden Hour of Scottish Dancing', 'Golden Hour', 3009, 'HO', 1, 271, 0, 1, '');
INSERT INTO 'album' VALUES (748, '1998-10-13 22:00:00+00', '2012-01-20 12:57:57.500442+00', 'Great Scottish Dance Bands Vol 2', 'Great SDB 2', 3056, 'EN', 1, 120, 1976, 1, '');
INSERT INTO 'album' VALUES (749, '2001-06-13 22:00:00+00', '2012-01-20 12:57:57.509436+00', 'Great Scottish Dance Bands Vol 1', 'Great SDB 1', 3069, 'JW', 1, 345, 1976, 1, '');
INSERT INTO 'album' VALUES (750, '1998-11-11 23:00:00+00', '2012-01-20 12:57:57.515654+00', 'See You Jimmy!', 'See You', 2183, 'NI', 1, 304, 1995, 1, '');
INSERT INTO 'album' VALUES (751, '1998-10-18 22:00:00+00', '2012-01-20 12:57:57.521851+00', 'Happy We''ve Been A'' Thegither', 'Happy', 2344, 'EN', 1, 335, 1988, 1, '');
INSERT INTO 'album' VALUES (514, '2007-09-03 22:00:00+00', '2021-08-20 08:28:04.514604+00', 'Dance, Sing and Rejoice', 'Dance, Sing, Rejoice', 3030, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (753, '1998-10-18 22:00:00+00', '2012-01-20 12:57:57.53997+00', 'Highland Style', 'Highland Style', 3059, 'EN', 1, 56, 0, 1, '');
INSERT INTO 'album' VALUES (754, '1998-10-18 22:00:00+00', '2012-01-20 12:57:57.543369+00', 'I Love Scotland', 'I Love Scotland', 3026, 'EC', 1, 164, 1965, 1, '');
INSERT INTO 'album' VALUES (755, '1998-10-25 23:00:00+00', '2012-01-20 12:57:57.549554+00', 'Ian Powrie Band Show', 'Band Show', 2062, 'EC', 1, 325, 0, 1, '');
INSERT INTO 'album' VALUES (756, '1998-07-22 22:00:00+00', '2012-01-20 12:57:57.555775+00', 'Island Games', 'Island Games', 2029, 'IS', 1, 288, 1991, 1, '');
INSERT INTO 'album' VALUES (758, '1998-10-12 22:00:00+00', '2012-01-20 12:57:57.561951+00', 'Dance Date No 3', 'Dance Date 3', 3065, 'EN', 1, 54, 0, 1, '');
INSERT INTO 'album' VALUES (771, '1998-10-14 22:00:00+00', '2012-01-20 12:57:57.574574+00', 'More Capital Reels', 'More Capital', 2090, 'AS', 1, 10, 1997, 1, '');
INSERT INTO 'album' VALUES (774, '1999-01-22 23:00:00+00', '2012-01-20 12:57:57.583564+00', 'Music for Collins Pocket Reference. Vol 1', 'Collins Ref 1', 3046, 'RS', 1, 105, 1998, 1, '');
INSERT INTO 'album' VALUES (775, '1998-09-08 22:00:00+00', '2012-01-20 12:57:57.589767+00', 'Music for Collins Pocket Reference. Vol 2', 'Collins Ref 2', 3046, 'AP', 1, 106, 1998, 1, '');
INSERT INTO 'album' VALUES (711, '1998-11-24 23:00:00+00', '2022-08-27 10:26:55.147788+00', 'Back in Step', 'Back in Step', 2088, 'CS', 1, 315, 1996, 1, '');
INSERT INTO 'album' VALUES (777, '1998-10-13 22:00:00+00', '2012-01-20 12:57:57.596008+00', 'Scottish Collection: Music of the Glens', 'Scottish: Glens', 3016, 'AS', 1, 433, 1996, 1, '');
INSERT INTO 'album' VALUES (780, '1999-06-30 22:00:00+00', '2012-01-20 12:57:57.602185+00', 'Bobby MacLeod and his Band', 'MacLeod & Band', 2328, 'EN', 1, 260, 0, 1, '');
INSERT INTO 'album' VALUES (781, '1998-07-17 22:00:00+00', '2012-01-20 12:57:57.608352+00', 'Border Country Dance Band', 'Border DB', 2093, 'EC', 1, 33, 1977, 1, '');
INSERT INTO 'album' VALUES (785, '1998-10-13 22:00:00+00', '2012-01-20 12:57:57.614538+00', 'One More Couple Please', 'One More Couple', 2184, 'EN', 1, 351, 1975, 1, '');
INSERT INTO 'album' VALUES (786, '1999-08-06 22:00:00+00', '2012-01-20 12:57:57.620865+00', 'Pet O'' The Pipers', 'Pet Pipers', 2185, 'MB', 1, 313, 0, 1, '');
INSERT INTO 'album' VALUES (790, '1998-12-30 23:00:00+00', '2012-01-20 12:57:57.63353+00', 'Rob''s Music Box', 'Rob''s Music Box', 3026, 'JW', 1, 168, 0, 1, '');
INSERT INTO 'album' VALUES (803, '1998-10-18 22:00:00+00', '2012-01-20 12:57:57.646011+00', 'Scotland''s Favourite', 'Scotland''s Fav', 1811, 'EE', 1, 322, 1979, 1, '');
INSERT INTO 'album' VALUES (805, '1998-10-15 22:00:00+00', '2012-01-20 12:57:57.652219+00', 'Scottish Accordion Hits Vol. 2', 'S Accordion 2', 1605, 'JW', 1, 259, 1977, 1, '');
INSERT INTO 'album' VALUES (811, '1999-05-25 22:00:00+00', '2012-01-20 12:57:57.658417+00', 'Scottish Country Dances', 'SCD Duncan', 2317, 'JW', 1, 118, 0, 1, '');
INSERT INTO 'album' VALUES (822, '1999-06-24 22:00:00+00', '2012-01-20 12:57:57.664587+00', 'Scottish Country Dances in Strict Tempo', 'Strict Tempo', 3010, 'BL', 1, 379, 1957, 1, '');
INSERT INTO 'album' VALUES (824, '1998-07-22 22:00:00+00', '2012-01-20 12:57:57.670799+00', 'Scottish Dance Masters, The Vol 5', 'SD Masters 5', 2231, 'IS', 1, 151, 1991, 1, '');
INSERT INTO 'album' VALUES (826, '1998-07-16 22:00:00+00', '2012-01-20 12:57:57.677046+00', 'Jimmy Blair''s Scottish Dance Party', 'JB''s SD Party', 2038, 'EE', 1, 26, 1961, 1, '');
INSERT INTO 'album' VALUES (829, '1998-10-25 23:00:00+00', '2012-01-20 12:57:57.689459+00', 'Scottish Dance Masters, The Vol 2', 'SD Masters 2', 2379, 'MK', 1, 152, 1984, 1, '');
INSERT INTO 'album' VALUES (832, '1998-10-15 22:00:00+00', '2012-01-20 12:57:57.695994+00', 'Scottish Pipes for Dancing', 'Pipes/Dancing', 1515, 'CG', 1, 344, 1958, 1, '');
INSERT INTO 'album' VALUES (836, '1998-11-11 23:00:00+00', '2012-01-20 12:57:57.708368+00', 'Scottish Sound of Ron Gonnella Playing a Stradivarius', 'Gonella / Strad', 1615, 'BC', 1, 148, 1984, 1, '');
INSERT INTO 'album' VALUES (841, '1998-10-14 22:00:00+00', '2012-01-20 12:57:57.720921+00', 'Skip Change with Scotch Measure', 'Skip Change', 2339, 'AS', 1, 349, 1997, 1, '');
INSERT INTO 'album' VALUES (847, '1998-07-16 22:00:00+00', '2012-01-20 12:57:57.727237+00', 'Happy Meeting, The', 'Happy Meeting', 3057, 'BC', 1, 144, 1988, 1, '');
INSERT INTO 'album' VALUES (849, '1998-07-16 22:00:00+00', '2012-01-20 12:57:57.733491+00', 'Kirrie Lads, The', 'Kirrie Lads', 2188, 'CS', 1, 92, 1998, 1, '');
INSERT INTO 'album' VALUES (852, '1998-07-17 22:00:00+00', '2012-01-20 12:57:57.742476+00', 'Tartan Track, The', 'Tartan Track', 1701, 'EE', 1, 206, 0, 1, '');
INSERT INTO 'album' VALUES (853, '1998-11-24 23:00:00+00', '2012-01-20 12:57:57.748674+00', 'This Lasting Pride', 'Lasting Pride', 3018, 'BC', 1, 91, 1989, 1, '');
INSERT INTO 'album' VALUES (854, '1998-11-20 23:00:00+00', '2012-01-20 12:57:57.754871+00', 'Top Scotch', 'Top Scotch', 3025, 'AS', 1, 245, 1994, 1, '');
INSERT INTO 'album' VALUES (856, '1999-05-25 22:00:00+00', '2012-01-20 12:57:57.76107+00', 'Two More Couples Please', '2 More Couples', 2184, 'JW', 1, 352, 1976, 1, '');
INSERT INTO 'album' VALUES (864, '1998-10-27 23:00:00+00', '2012-01-20 12:57:57.767277+00', 'Welcome to Tayside', 'WelcomeTayside', 2397, 'EC', 1, 293, 0, 1, '');
INSERT INTO 'album' VALUES (869, '1999-05-25 22:00:00+00', '2012-01-20 12:57:57.782954+00', 'Book 23. Twelve Modern Scottish Country Dances', 'RSCDS 23', 3050, 'AP', 1, 354, 1998, 1, '');
INSERT INTO 'album' VALUES (870, '1999-05-25 22:00:00+00', '2012-01-20 12:57:57.79197+00', 'Book 24, Twelve Scottish Country Dances', 'RSCDS 24', 3002, 'AP', 1, 228, 1998, 1, '');
INSERT INTO 'album' VALUES (871, '1998-08-13 22:00:00+00', '2012-01-20 12:57:57.800992+00', 'Dancing Live', 'Dancing Live', 2236, 'AP', 1, 226, 1998, 1, '');
INSERT INTO 'album' VALUES (872, '1998-09-10 22:00:00+00', '2012-01-20 12:57:57.807204+00', 'Come More Scottish Country Dancing', 'Come More SCD', 3032, 'AP', 1, 2, 1998, 1, '');
INSERT INTO 'album' VALUES (875, '2002-05-05 22:00:00+00', '2012-01-20 12:57:57.816147+00', 'Special Requests Volume 3', 'Sp.Requests 3', 3046, 'AP', 1, 108, 1998, 1, '');
INSERT INTO 'album' VALUES (876, '1998-08-13 22:00:00+00', '2012-01-20 12:57:57.825223+00', 'Haste Ye Back', 'Haste Ye', 3002, 'AP', 1, 236, 1998, 1, '');
INSERT INTO 'album' VALUES (878, '1998-10-13 22:00:00+00', '2012-01-20 12:57:57.831507+00', 'Fifteen Dances, Part Two', '15 Dances - 2', 3016, 'AP', 1, 422, 1991, 1, '');
INSERT INTO 'album' VALUES (879, '2009-08-02 22:00:00+00', '2012-01-20 12:57:57.837756+00', 'Dance for Joy!', 'Dance for Joy!', 10000, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (880, '2009-08-02 22:00:00+00', '2012-01-20 12:57:57.84396+00', 'Music for Scottish Country Dancing', 'Music for SCD', 10008, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (881, '2009-08-02 22:00:00+00', '2012-01-20 12:57:57.850136+00', 'Silver Tassie and other Favourite Dances', 'Silver Tassie', 2586, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (882, '2009-08-02 22:00:00+00', '2012-01-20 12:57:57.856338+00', 'Todlen Hame and other Favourite Dances', 'Todlen Hame', 2586, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (868, '1999-04-21 22:00:00+00', '2012-04-27 17:11:26.461708+00', 'RSCDS 75th Anniversary Dances', 'RSCDS 75th Anniv', 3071, 'AP', 1, 296, 1998, 1, '');
INSERT INTO 'album' VALUES (827, '1998-10-12 22:00:00+00', '2013-01-03 11:29:40.224437+00', 'Scottish Dances', 'S Dances (AD)', 2246, 'JW', 1, 117, 1962, 1, '');
INSERT INTO 'album' VALUES (883, '2009-10-17 22:00:00+00', '2012-01-20 12:57:57.862549+00', 'Book 11. Music for 12 Scottish Country Dances', 'Book 11', 3049, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (884, '2009-10-18 22:00:00+00', '2012-01-20 12:57:57.86881+00', 'Angus Welcome, An', 'Angus Welcome', 3032, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (885, '2009-10-18 22:00:00+00', '2012-01-20 12:57:57.87499+00', 'Book 34. Music for 11 Scottish Country Dances (Book 34 plus 3 Dances 2006)', 'Book 34 plus 3', 10018, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (886, '2009-10-18 22:00:00+00', '2012-01-20 12:57:57.881195+00', 'That Pinewoods Sound!', 'Pinewoods Sound', 10019, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (888, '2009-11-02 23:00:00+00', '2012-01-20 12:57:57.893535+00', 'Special Requests Volume 7', 'Sp Requests 7', 3023, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (889, '2009-11-03 23:00:00+00', '2012-01-20 12:57:57.899761+00', 'Take Your Partners For Vol 2', 'Take Your Partners 2', 10034, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (890, '2009-11-04 23:00:00+00', '2012-01-20 12:57:57.906028+00', 'Book 35. Music for Eight Scottish Country Dances', 'Book 35', 3137, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (892, '2009-11-04 23:00:00+00', '2012-01-20 12:57:57.918843+00', 'Take Your Partners For Vol 1', 'Take Your Partners 1', 10034, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (894, '2009-11-05 23:00:00+00', '2012-01-20 12:57:57.931256+00', '2008 Pittsburgh Ball', '2008 Pittsburgh Ball', 3030, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (895, '2009-11-05 23:00:00+00', '2012-01-20 12:57:57.93743+00', 'To Be A Wind', 'To Be A Wind', 1836, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (896, '2009-11-05 23:00:00+00', '2012-01-20 12:57:57.943749+00', 'Live at Opotiki, Music for a Whale of a Time', 'Live at Opotiki', 3420, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (897, '2009-11-05 23:00:00+00', '2012-01-20 12:57:57.949974+00', 'Book 30. Music for Book 30 plus 3 Dances by Hugh Foss', 'Book 30', 3006, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (898, '2009-11-05 23:00:00+00', '2012-01-20 12:57:57.956311+00', 'Book 27. Music for Twelve Scottish Country Dances', 'Book 27', 2944, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (899, '2009-11-06 23:00:00+00', '2012-01-20 12:57:57.962525+00', 'Book 20. Music for Twelve Scottish Country Dances', 'Book 20', 3045, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (902, '2009-11-08 23:00:00+00', '2012-01-20 12:57:57.981591+00', 'TAC 50th Anniversary Collection', 'TAC 50th Anniversary', 3067, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (903, '2009-11-08 23:00:00+00', '2012-01-20 12:57:57.987782+00', 'To the Laird', 'To the Laird', 2681, '', 0, 0, 2009, 0, '2CD''s');
INSERT INTO 'album' VALUES (904, '2009-11-10 23:00:00+00', '2012-01-20 12:57:57.99408+00', 'Vallin Suite 2, The', 'Vallin 2', 3006, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (905, '2009-11-10 23:00:00+00', '2012-01-20 12:57:58.0003+00', 'Vallin Suite 3, The', 'Vallin 3', 10018, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (906, '2009-11-10 23:00:00+00', '2012-01-20 12:57:58.006501+00', 'Vallin Suite 4, The', 'Vallin 4', 3023, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (907, '2009-11-15 23:00:00+00', '2012-01-20 12:57:58.012695+00', 'Ruthven Collection Vol 2, The', 'Ruthven 2', 3023, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (909, '2009-11-17 23:00:00+00', '2012-01-20 12:57:58.025106+00', 'Heather Hills', 'Heather Hills', 10070, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (910, '2009-11-17 23:00:00+00', '2012-01-20 12:57:58.031785+00', 'Music for 12 Perth Dances', '12 Perth Dances', 10037, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (911, '2009-11-17 23:00:00+00', '2012-01-20 12:57:58.038118+00', 'Reel On - Roy Goldring''s Graded and Social Dances 3', 'Reel On', 10076, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (913, '2009-11-21 23:00:00+00', '2012-01-20 12:57:58.051279+00', 'Diamond Jubilee Dances - Belfast Branch', 'Belfast Diamond Jubilee', 3217, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (914, '2009-11-21 23:00:00+00', '2012-01-20 12:57:58.057572+00', 'Aye Afloat', 'Aye Afloat', 2586, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (891, '2009-11-04 23:00:00+00', '2012-12-26 11:41:49.512984+00', 'Book 14. Music for Twelve Scottish Country Dances', 'Book 14', 10037, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (893, '2009-11-05 23:00:00+00', '2012-12-26 11:45:30.525461+00', 'Book 13. Music for 12 Scottish Country Dances', 'Book 13', 3011, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (915, '2009-11-22 23:00:00+00', '2012-01-20 12:57:58.063789+00', 'Very Best of Stan Hamilton, The', 'Best of Hamilton', 3016, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (916, '2009-11-22 23:00:00+00', '2012-01-20 12:57:58.070061+00', 'Dance Goes On, The', 'Dance Goes On', 2029, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (800, '1998-10-27 23:00:00+00', '2022-12-22 22:22:09.618343+00', 'Scotland Swings Again with the Great Jim MacLeod', 'Scotland Swings', 3009, 'EE', 1, 274, 1969, 1, 'Album cover shows no playing time for tracks.');
INSERT INTO 'album' VALUES (922, '2009-11-23 23:00:00+00', '2012-01-20 12:57:58.09485+00', 'Tribute to Derek Haynes, A', 'Tribute to Derek', 3045, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (923, '2009-11-26 23:00:00+00', '2012-01-20 12:57:58.101031+00', 'Original Lindsay Ross, The', 'Lindsay Ross', 3069, '', 0, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (924, '2009-11-28 23:00:00+00', '2012-01-20 12:57:58.107228+00', 'Let''s Celebrate', 'Let''s Celebrate', 10104, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (925, '2009-11-29 23:00:00+00', '2012-01-20 12:57:58.113402+00', 'Transatlantic Ties', 'Transatlantic', 1836, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (926, '2009-11-29 23:00:00+00', '2012-01-20 12:57:58.119585+00', 'Favourite SCDs Vol 1', 'Favourite SCDs 1', 3678, '', 0, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (927, '2009-11-30 23:00:00+00', '2012-01-20 12:57:58.126037+00', 'Favourite SCDs Vol 2', 'Favourite SCDs 2', 3678, '', 0, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (928, '2009-11-30 23:00:00+00', '2012-01-20 12:57:58.132274+00', 'Dance o da Shetland Puffins', 'Shetland Puffins', 10108, '', 0, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (929, '2009-12-01 23:00:00+00', '2012-01-20 12:57:58.13847+00', 'Crossing Borders', 'Crossing Borders', 10114, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (930, '2009-12-01 23:00:00+00', '2012-01-20 12:57:58.144768+00', 'Ruthven Collection, The', 'Ruthven', 3023, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (931, '2009-12-02 23:00:00+00', '2012-01-20 12:57:58.151105+00', 'Second Sheaf Collection, The', 'Sheaf Coll 2', 10117, '', 0, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (932, '2009-12-02 23:00:00+00', '2012-01-20 12:57:58.157679+00', 'Dusk Till Dawn', 'Dusk Till Dawn', 2585, '', 0, 0, 1996, 0, '');
INSERT INTO 'album' VALUES (933, '2009-12-02 23:00:00+00', '2012-01-20 12:57:58.164034+00', 'Thank You For Coming', 'Thank You', 10117, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (934, '2009-12-03 23:00:00+00', '2012-01-20 12:57:58.170257+00', 'Faculty of Actuaries, The', 'Faculty of Actuaries', 10128, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (935, '2009-12-06 23:00:00+00', '2012-01-20 12:57:58.176463+00', 'Bluebonnet Ball 2004', 'Bluebonnet2004', 10129, '', 0, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (936, '2009-12-09 23:00:00+00', '2012-01-20 12:57:58.182727+00', 'Take Your Seats', 'Take Your Seats', 3014, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (937, '2009-12-16 23:00:00+00', '2012-01-20 12:57:58.188915+00', 'Jim Cameron''s Scottish Dance Band Vol 1', 'Jim Cameron 1', 3065, '', 0, 0, 2001, 0, '');
INSERT INTO 'album' VALUES (938, '2009-12-16 23:00:00+00', '2012-01-20 12:57:58.195144+00', 'Jim Cameron''s Scottish Dance Band Vol 2', 'Jim Cameron 2', 3065, '', 0, 0, 2001, 0, '');
INSERT INTO 'album' VALUES (939, '2009-12-16 23:00:00+00', '2012-01-20 12:57:58.201334+00', 'Jim Cameron''s Scottish Dance Band Vol 3', 'Jim Cameron 3', 3065, '', 0, 0, 2002, 0, '');
INSERT INTO 'album' VALUES (940, '2009-12-16 23:00:00+00', '2012-01-20 12:57:58.20753+00', 'Nice to See You Again', 'See You Again', 2188, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (941, '2009-12-16 23:00:00+00', '2012-01-20 12:57:58.213727+00', 'Tim Wright and his Scottish Dance Band', 'Tim Wright', 10141, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (942, '2009-12-22 23:00:00+00', '2012-01-20 12:57:58.219907+00', 'Strathearn - Early Days', 'Strathearn', 10142, '', 0, 0, 1967, 0, '');
INSERT INTO 'album' VALUES (943, '2009-12-22 23:00:00+00', '2012-01-20 12:57:58.226076+00', 'Old Scottish Dance Bands Vol 1, The', 'Old Bands 1', 3016, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (944, '2009-12-22 23:00:00+00', '2012-01-20 12:57:58.232306+00', 'Old Scottish Dance Bands Vol 2, The', 'Old Bands 2', 3016, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (945, '2009-12-27 23:00:00+00', '2012-01-20 12:57:58.238583+00', 'Robert Burns Dances', 'Burns Dances', 3217, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (946, '2010-01-19 23:00:00+00', '2012-01-20 12:57:58.244817+00', '12 Scottish Country Dances by Mervyn Short', '12 Mervyn Short', 2696, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (947, '2010-01-25 23:00:00+00', '2012-01-20 12:57:58.251064+00', 'Silver Spire, The', 'Silver Spire', 3012, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (948, '2010-02-13 23:00:00+00', '2012-01-20 12:57:58.25727+00', 'Schottische Tänze', 'Schottische Tänze', 10157, '', 0, 0, 1999, 0, '');
INSERT INTO 'album' VALUES (949, '2010-04-14 22:00:00+00', '2012-01-20 12:57:58.263461+00', 'Ayr Branch 75th Anniversary Dances', 'Ayr Branch 75', 2566, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (901, '2009-11-07 23:00:00+00', '2013-04-10 08:10:42.059176+00', 'Book 9. Music for 18 Scottish Country Dances (Book 9 plus 4 Dances 2008 and 2 dances for Eileen Watt)', 'Book 9 plus 6', 3016, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (950, '2010-05-29 22:00:00+00', '2012-01-20 12:57:58.269622+00', 'Celtic Steps', 'Celtic Steps', 10046, '', 0, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (951, '2010-05-30 22:00:00+00', '2012-01-20 12:57:58.275816+00', 'Vintage 78''s Vol 2', 'Vintage 78 2', 2328, '', 0, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (952, '2010-05-30 22:00:00+00', '2012-01-20 12:57:58.281996+00', '25th Anniversary Dances, RSCDS Tokyo Branch', '25 Years Tokyo Branch', 10176, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (953, '2010-05-31 22:00:00+00', '2012-01-20 12:57:58.288189+00', 'Let''s Go Scottish Country Dancing Vol 1', 'Let''s Go SCD 1', 3026, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (954, '2010-06-01 22:00:00+00', '2012-01-20 12:57:58.294513+00', 'Old Tyme Favourites Vol 1', 'Old Tyme Fav 1', 10177, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (955, '2010-06-07 22:00:00+00', '2012-01-20 12:57:58.300728+00', 'Fraser McGlynn and his Scottish Dance Band', 'Fraser McGlynn', 10183, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (956, '2010-08-07 22:00:00+00', '2012-01-20 12:57:58.306909+00', 'Book 6. Music for Twelve Traditional Dances', 'Book 6', 3011, '', 0, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (957, '2010-08-07 22:00:00+00', '2012-01-20 12:57:58.313172+00', 'Book 7 plus 2 Dances for 2009', 'Book VII', 3006, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (959, '2010-08-08 22:00:00+00', '2012-01-20 12:57:58.325612+00', 'Book 46', 'Book XLVI', 3019, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (961, '2010-08-31 22:00:00+00', '2012-01-20 12:57:58.338042+00', 'Early Days - John Crawford', 'John Crawford', 10186, '', 0, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (964, '2010-09-02 22:00:00+00', '2012-01-20 12:57:58.356649+00', 'Corryvrechan Live in Concert', 'Corryvrechan Live', 3479, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (965, '2010-09-03 22:00:00+00', '2012-01-20 12:57:58.36298+00', 'Between the Bridges', 'Perth Bridges', 10200, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (918, '2009-11-23 23:00:00+00', '2018-10-25 09:28:28.715308+00', 'Double Take', 'Double Take', 10095, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (908, '2009-11-16 23:00:00+00', '2017-12-01 22:27:35.277891+00', 'Diamond Jubilee Collection - Inverness & District Branch, The', 'Diamond Jubilee - Inverness', 3023, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (967, '2010-09-15 22:00:00+00', '2012-01-20 12:57:58.375482+00', 'Are ye askin''? - The Reel Party', 'Are ye askin''?', 10209, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (969, '2010-09-16 22:00:00+00', '2012-01-20 12:57:58.387861+00', 'Are ye dancin''? - The Ceilidh', 'Are ye dancin''?', 10209, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (970, '2010-09-20 22:00:00+00', '2012-01-20 12:57:58.394043+00', 'Purely Traditional', 'Purely Trad', 10233, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (972, '2010-10-07 22:00:00+00', '2012-01-20 12:57:58.406497+00', 'Highlander Music Scottish Dances Vol 14', 'Highlander SD 14', 10247, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (1069, '2014-03-26 14:26:24.850006+00', '2018-10-25 21:46:38.522216+00', 'Jim Mackay Scottish Dance Band, The', 'Jim Mackay', 10936, '', 0, 0, 2013, 0, '');
INSERT INTO 'album' VALUES (974, '2010-10-13 22:00:00+00', '2012-01-20 12:57:58.418957+00', 'Special Requests Volume 8', 'Sp Requests 8', 3023, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (975, '2010-10-15 22:00:00+00', '2012-01-20 12:57:58.425151+00', 'Old Tyme Favourites Vol 2', 'Old Tyme Fav 2', 10177, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (976, '2010-10-16 22:00:00+00', '2012-01-20 12:57:58.43133+00', 'William Hannah and his Band', 'William Hannah', 10267, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (977, '2010-10-17 22:00:00+00', '2012-01-20 12:57:58.437627+00', 'Kirrie Selection', 'Kirrie Selection', 3065, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (978, '2010-10-18 22:00:00+00', '2012-01-20 12:57:58.443858+00', 'All Set Volume One', 'All Set 1', 10268, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (979, '2010-10-18 22:00:00+00', '2012-01-20 12:57:58.450048+00', 'On the Rocks', 'On the Rocks', 10037, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (980, '2010-10-19 22:00:00+00', '2012-01-20 12:57:58.456284+00', 'Essential Scottish Dance Bands Collection, The', 'Essential SDBs', 3016, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (981, '2010-10-20 22:00:00+00', '2012-01-20 12:57:58.462506+00', '20 Scottish Favourites', '20 Favourites', 3026, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (982, '2010-10-26 22:00:00+00', '2012-01-20 12:57:58.468726+00', 'Scottish Sound of the Bill Hendry Dance Band, The', 'Bill Hendry', 10277, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (983, '2010-10-27 22:00:00+00', '2012-01-20 12:57:58.474909+00', 'Fisherman''s Reel, The', 'Fisherman', 3217, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (984, '2010-10-27 22:00:00+00', '2012-01-20 12:57:58.481138+00', 'Dashing White Sergeant, The', 'White Sergeant', 10104, '', 0, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (985, '2011-01-20 23:00:00+00', '2012-01-20 12:57:58.487346+00', 'Let''s Go Scottish Country Dancing Vol 2', 'Let''s Go SCD 2', 10296, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (960, '2010-08-29 22:00:00+00', '2012-12-26 11:24:31.884261+00', 'King of the Button Box', 'Shand Button Box', 3010, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (962, '2010-08-31 22:00:00+00', '2012-12-26 11:26:10.350461+00', 'King of the Button Box Vol 2', 'Shand Button Box 2', 3010, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (986, '2011-02-17 23:00:00+00', '2012-12-26 11:46:41.643105+00', 'Black Watch Ball, The', 'Black Watch Ball', 10659, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (987, '2011-04-25 22:00:00+00', '2012-01-20 12:57:58.499762+00', 'Ruthven Collection ''Black Watch Edition'', The', 'Ruthven Black Watch', 3023, '', 0, 0, 2011, 0, '');
INSERT INTO 'album' VALUES (988, '2011-06-13 22:00:00+00', '2012-01-20 12:57:58.506014+00', 'Three Hands Across', '', 10330, '', 0, 0, 2011, 0, '');
INSERT INTO 'album' VALUES (989, '2011-08-18 22:00:00+00', '2012-01-20 12:57:58.512218+00', 'Scottish Country Dances', '', 10381, '', 0, 0, 1962, 0, '');
INSERT INTO 'album' VALUES (990, '2011-09-14 22:00:00+00', '2012-01-20 12:57:58.518494+00', 'Scottish Country Dancing Volume 3 (Music for Collins Pocket Reference. Vol 3)', 'Collins Vol3', 3023, '', 0, 0, 2011, 0, '');
INSERT INTO 'album' VALUES (996, '2011-11-04 23:00:00+00', '2012-01-20 12:57:58.537303+00', 'Saint Andrews Collection of Step Dances, The', 'St Andrews Coll', 2586, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (999, '2011-11-17 23:00:00+00', '2012-01-20 12:57:58.555967+00', 'Saint Bernard''s Waltz', 'St Bernard''s Waltz', 3217, '', 0, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (1000, '2011-11-25 23:00:00+00', '2012-01-20 12:57:58.56222+00', 'Reflecting on Rankine', 'Reflecting on Rankine', 10525, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (1003, '2011-11-26 23:00:00+00', '2012-01-20 12:57:58.580954+00', 'Strikes Again', 'Strikes Again', 10108, '', 0, 0, 1998, 0, '');
INSERT INTO 'album' VALUES (1004, '2011-11-26 23:00:00+00', '2012-01-20 12:57:58.588648+00', 'Advance & Retire', 'Advance & Retire', 10541, '', 0, 0, 2005, 0, '');
INSERT INTO 'album' VALUES (1005, '2011-11-28 23:00:00+00', '2012-01-20 12:57:58.594887+00', 'Twenty Scottish Dance Bands Vol 1', '20 SCD Bands Vol 1', 3016, '', 0, 0, 2000, 0, '');
INSERT INTO 'album' VALUES (1006, '2011-11-28 23:00:00+00', '2012-01-20 12:57:58.601117+00', 'Twenty Scottish Dance Bands Vol 2', '20 SCD Bands Vol 2', 3016, '', 0, 0, 2000, 0, '');
INSERT INTO 'album' VALUES (991, '2011-09-21 22:00:00+00', '2012-09-16 15:47:54.495546+00', 'Reel of the Puffins', 'Puffins', 10659, '', 0, 0, 2011, 0, '');
INSERT INTO 'album' VALUES (997, '2011-11-07 23:00:00+00', '2012-12-26 11:18:45.032818+00', 'Live From C Sharp', 'Pinewoods 2010', 10503, '', 0, 0, 2011, 0, 'Album consists of 2 disks



Pinewoods 2010 Ensemble:



fiddles:  Paul Anderson, Hanneke Cassel, Calum Pasqua, Susan Worland

piano:   Susie Petrow, Tom Pixton

bass:    Barbara Pixton

pipes:   Mike MacNintch

with David Knight, fiddle

       Rosalind Buda, bassoon

');
INSERT INTO 'album' VALUES (1001, '2011-11-25 23:00:00+00', '2013-01-05 14:42:32.561976+00', 'Foaming Sea, The', 'Foaming Sea', 10108, '', 0, 0, 1997, 0, '');
INSERT INTO 'album' VALUES (1002, '2011-11-25 23:00:00+00', '2013-01-05 15:16:46.903466+00', 'Shetland Dance, A', 'A Shetland Dance', 10108, '', 0, 0, 2001, 0, '');
INSERT INTO 'album' VALUES (1007, '2011-11-29 23:00:00+00', '2012-01-20 12:57:58.607321+00', 'Vancouver - 20th Anniversary', 'Vancouver 20th', 10551, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (1008, '2011-11-29 23:00:00+00', '2012-01-20 12:57:58.613695+00', 'Salute Alasdair Heron', 'Salute Alasdair', 2503, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (1009, '2011-12-01 23:00:00+00', '2012-01-20 12:57:58.61992+00', 'Reel Tradition, The', 'Reel Tradition', 10553, '', 0, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (1010, '2011-12-02 23:00:00+00', '2012-01-20 12:57:58.6264+00', 'Peter Davidson and his Inverness Country Dance Band', 'Peter Davidson Band', 10148, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (1011, '2011-12-05 23:00:00+00', '2012-01-20 12:57:58.632862+00', 'Best of Donny & Diane''s Highland Ceilidh Band, The', 'Best of Donny & Diane', 10555, '', 0, 0, 2011, 0, '');
INSERT INTO 'album' VALUES (1012, '2011-12-05 23:00:00+00', '2012-01-20 12:57:58.639153+00', 'Highland Accordion Maestro', 'Accordion Maestro', 2328, '', 0, 0, 2011, 0, '');
INSERT INTO 'album' VALUES (1013, '2011-12-06 23:00:00+00', '2012-01-20 12:57:58.647915+00', 'Whistling Rufus', 'Whistling Rufus', 3010, '', 0, 0, 2011, 0, '');
INSERT INTO 'album' VALUES (1014, '2011-12-07 23:00:00+00', '2012-01-20 12:57:58.6544+00', 'Six For Sixty', 'Six For Sixty', 10569, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (1016, '2012-01-06 23:00:00+00', '2012-01-20 12:57:58.667263+00', 'Geordie Diamond, The', 'Geordie Diamond', 3039, '', 0, 0, 2011, 0, '');
INSERT INTO 'album' VALUES (231, '1999-01-30 23:00:00+00', '2013-03-09 10:59:14.173791+00', 'Sounds Scottish', 'Sounds Scottish', 3051, 'PM', 1, 189, 0, 1, '');
INSERT INTO 'album' VALUES (966, '2010-09-05 22:00:00+00', '2014-05-10 22:39:15.260936+00', 'Eight Bars of Magic', 'Eight Bars', 10204, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (971, '2010-09-20 22:00:00+00', '2014-11-11 16:05:02.055168+00', 'Music for 16 dances from the Ribble Valley Book', 'Ribble Valley', 10237, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (1064, '2014-03-13 18:19:19.325535+00', '2014-03-14 16:08:32.852221+00', 'Take Your Partners For Vol 4', 'Take Your Partners 4', 10034, '', 0, 0, 2014, 0, '');
INSERT INTO 'album' VALUES (412, '2002-06-16 22:00:00+00', '2014-03-14 16:40:34.98726+00', 'Reels and Wheels', 'Reels/Wheels', 3050, 'BB', 1, 0, 2001, 2, 'The booklet has full cribs for all the 17 dances.');
INSERT INTO 'album' VALUES (1059, '2014-02-06 18:00:10.043956+00', '2014-02-06 19:07:31.965188+00', 'Moments in Time', 'Moments', 10915, '', 0, 0, 2013, 0, '');
INSERT INTO 'album' VALUES (1058, '2014-02-06 15:19:46.03167+00', '2014-02-06 19:30:50.649741+00', 'Another Scottish Ramble', 'Another Scottish Ramble', 2681, '', 0, 0, 2013, 0, '');
INSERT INTO 'album' VALUES (481, '2005-08-08 22:00:00+00', '2013-04-10 06:20:58.483688+00', 'Book 2. Music for Eleven Traditional Dances +1', '', 3016, '', 0, 0, 2003, 0, '');
INSERT INTO 'album' VALUES (79, '1999-05-25 22:00:00+00', '2013-04-10 06:21:41.603439+00', 'Book 3. Music for Twelve Traditional Dances', 'RSCDS 3', 3018, 'AP', 1, 79, 1986, 1, '');
INSERT INTO 'album' VALUES (104, '1998-11-20 23:00:00+00', '2013-04-10 06:27:54.203198+00', 'Book 6. Music for Twelve Traditional Dances', 'RSCDS 6', 3011, 'PM', 1, 13, 1986, 1, '');
INSERT INTO 'album' VALUES (900, '2009-11-07 23:00:00+00', '2013-04-10 06:29:15.240099+00', 'Book 8. Music for 12 Scottish Country Dances', 'Book 8', 10659, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (12, '2000-04-04 22:00:00+00', '2013-04-10 09:57:42.954413+00', 'Highlander Music Scottish Dances Vol 3', 'Highlander SD 3', 3006, 'AP', 1, 99, 1996, 1, '');
INSERT INTO 'album' VALUES (317, '2000-04-04 22:00:00+00', '2013-04-10 09:58:33.099165+00', 'Highlander Music Scottish Dances Vol 6', 'Highlander SD 6', 2570, 'AP', 1, 65, 1999, 1, '');
INSERT INTO 'album' VALUES (322, '2000-04-04 22:00:00+00', '2013-04-10 09:59:00.952508+00', 'Highlander Music Scottish Dances Vol 8', 'Highlander SD 8', 2584, 'AP', 1, 5, 1999, 1, '');
INSERT INTO 'album' VALUES (1076, '2014-08-11 22:03:52.665967+00', '2014-08-11 22:40:16.625205+00', 'Music for A Third Book of Graded Scottish Country Dances', '3rd Graded Book', 10981, '', 0, 0, 2014, 0, '');
INSERT INTO 'album' VALUES (1060, '2014-02-07 08:48:17.862722+00', '2014-02-07 09:46:58.077862+00', 'Prairie Gold', 'Prairie Gold', 2339, '', 0, 0, 2013, 0, '');
INSERT INTO 'album' VALUES (968, '2010-09-15 22:00:00+00', '2017-07-27 15:18:33.381798+00', 'Ah''m askin'' - Scottish Country Dances', 'Ah''m askin''', 10209, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (1073, '2014-04-29 16:55:32.683061+00', '2014-04-29 17:45:11.393986+00', 'Sound of Scotland, The', 'Sound Scotland (CD)', 3009, '', 0, 0, 2013, 0, 'As LP "Sound of Scotland" NPL-30080 + 3 extras

- Scottish Waltz

- Argyll''s Fancy 6x32J

- Gay Gordons');
INSERT INTO 'album' VALUES (1074, '2014-05-10 00:29:06.098968+00', '2014-05-10 00:29:06.098968+00', 'Coast to Coast with Scotch Mist', 'Coast to Coast', 10955, '', 0, 0, 2014, 0, '');
INSERT INTO 'album' VALUES (1070, '2014-03-27 13:02:29.547773+00', '2014-03-27 14:18:06.273429+00', 'Highland Accordion Medley', 'Accordion Medley', 2328, '', 0, 0, 2013, 0, '');
INSERT INTO 'album' VALUES (1061, '2014-02-09 17:21:30.031306+00', '2014-02-09 18:07:06.991231+00', 'RSCDS Glasgow 90th Anniversary', 'Glasgow 90', 2566, '', 0, 0, 2013, 0, '');
INSERT INTO 'album' VALUES (1053, '2013-08-06 13:49:35.555293+00', '2013-08-06 14:33:14.382817+00', 'Opus Dance', 'Opus', 10823, '', 0, 1, 2013, 1, '');
INSERT INTO 'album' VALUES (1054, '2013-09-11 19:26:21.433599+00', '2013-09-11 22:12:39.072887+00', 'Book 47. 12 Dances to celebrate the 90th Anniversary', 'RSCDS 47', 3050, '', 0, 0, 2013, 0, '');
INSERT INTO 'album' VALUES (788, '1998-07-16 22:00:00+00', '2014-05-13 09:36:32.817626+00', 'Puirt-a-Beul', 'Puirt-a-Beul', 2186, 'EE', 1, 50, 1966, 1, '');
INSERT INTO 'album' VALUES (34, '2002-05-11 22:00:00+00', '2014-06-19 12:12:01.139096+00', 'Book 1. Music for Twelve Traditional Dances', 'RSCDS 1', 3018, 'AP', 1, 77, 2000, 1, '');
INSERT INTO 'album' VALUES (1055, '2013-10-28 23:31:50.375407+00', '2013-11-07 12:29:04.465115+00', 'Sunday Class Dance Book 1, The', 'Sunday Class 1', 3217, '', 0, 0, 2013, 0, '');
INSERT INTO 'album' VALUES (1051, '2013-03-19 09:20:14.485694+00', '2021-08-20 21:52:29.686355+00', 'Oxford Connections', '', 3014, '', 0, 0, 2012, 0, 'Not all tracks have been added. For more details see <<http://www.craigellachie-band.co.uk/oxford_connections.html>>.');
INSERT INTO 'album' VALUES (59, '1999-05-25 22:00:00+00', '2013-12-07 09:34:00.3245+00', 'Book 14/15. Music for Scottish Country Dances (1)', 'RSCDS 14/15 (1)', 3021, 'AP', 1, 128, 1991, 1, 'The full title of the MC is 

MUSIC FOR SCOTTISH COUNTRY DANCES 

From Books 14 and 15. 

CASSETTE 1 - EIGHT DANCES



FIDDLERS THREE PLUS TWO

');
INSERT INTO 'album' VALUES (214, '1998-11-19 23:00:00+00', '2014-08-05 15:10:07.166506+00', 'Scottish Country Dance Favourites Volume I', 'SCD Favs  I', 3042, 'MK', 1, 332, 1971, 1, '');
INSERT INTO 'album' VALUES (995, '2011-11-03 23:00:00+00', '2014-03-05 10:15:53.639488+00', 'Shining Lights', 'Shining Lights', 2066, '', 0, 0, 2011, 0, 'This album is available as a very reasonably priced MP3 download from Amazon.');
INSERT INTO 'album' VALUES (1078, '2014-09-17 16:17:12.051835+00', '2014-09-18 16:43:19.982967+00', 'Music for the Commonwealth Ceilidh', 'Commonwealth Ceilidh 2014', 3016, '', 0, 0, 2014, 0, 'No information (like tunes) given on the CD by the RSCDS.');
INSERT INTO 'album' VALUES (1057, '2014-02-06 14:11:44.196253+00', '2014-02-06 15:01:16.292497+00', 'Bordering on Scottish', 'Bordering', 3217, '', 0, 0, 1999, 0, '');
INSERT INTO 'album' VALUES (1079, '2014-10-02 01:43:08.527029+00', '2014-10-02 01:43:08.527029+00', '90 - Twelve anniversary dances celebrating ninety years of RSCDS Edinburgh Branch', 'Edinburgh 90', 11017, '', 0, 0, 2014, 0, '');
INSERT INTO 'album' VALUES (1052, '2013-05-11 16:36:43.346286+00', '2014-03-10 00:53:52.463276+00', 'Thistle Hall: Dancing to the Kiwi Band', 'Thistle Hall', 3420, '', 0, 0, 2006, 0, 'Entered 2013-05-10



Disc length: 4589 seconds');
INSERT INTO 'album' VALUES (1067, '2014-03-16 15:03:54.26313+00', '2014-03-16 16:14:05.260224+00', 'From Scotland to Saitama', 'Saitama', 3008, '', 0, 0, 2013, 0, '');
INSERT INTO 'album' VALUES (1066, '2014-03-16 11:47:56.320645+00', '2023-01-01 21:55:42.192812+00', 'sailing by', 'Sailing By', 10920, '', 0, 0, 2012, 0, '');
INSERT INTO 'album' VALUES (1065, '2014-03-16 10:18:35.205104+00', '2023-01-01 21:55:18.092807+00', 'Honky-tonk Chateau', 'Honky-tonk', 10920, '', 0, 0, 1999, 0, '');
INSERT INTO 'album' VALUES (1015, '2011-12-14 23:00:00+00', '2023-01-10 22:49:32.989792+00', 'Let''s Go Scottish Country Dancing Vol 3', 'Let''s Go SCD Vol 3', 10580, '', 0, 0, 2011, 0, '');
INSERT INTO 'album' VALUES (1071, '2014-04-25 10:15:07.673522+00', '2014-04-29 14:42:17.596996+00', 'Scottish Dance Band Greats Vol 1', 'SDB Greats 1', 3016, '', 0, 0, 2013, 0, '');
INSERT INTO 'album' VALUES (1063, '2014-03-13 15:57:41.651611+00', '2014-03-13 18:11:21.201445+00', 'Beyond the Borders', 'Beyond', 10114, '', 0, 0, 2014, 0, '');
INSERT INTO 'album' VALUES (1072, '2014-04-29 15:07:10.452756+00', '2014-04-29 16:01:20.95165+00', 'Scottish Country Dance Time Vol 1', 'SCD Time 1', 2038, '', 0, 0, 2013, 0, '');
INSERT INTO 'album' VALUES (1080, '2014-11-13 21:07:11.341192+00', '2014-11-14 10:31:45.433277+00', 'Leeds Golden Collection, The', 'Leeds Golden', 3011, '', 0, 0, 2014, 0, 'Recorded by Stuart Hamilton at Castlesound Studio

Manufactured for Birnam CD Ltd');
INSERT INTO 'album' VALUES (1077, '2014-08-19 07:13:34.400475+00', '2014-08-19 09:14:25.451178+00', 'Dances to Song Tunes', 'Song Tunes', 10982, '', 0, 0, 2014, 0, '');
INSERT INTO 'album' VALUES (394, '2002-05-07 22:00:00+00', '2015-01-11 14:52:47.955078+00', 'Scottish Dance Country', 'Music SCD 2 (BB)', 3067, 'IM', 1, 507, 0, 2, '');
INSERT INTO 'album' VALUES (1081, '2015-05-14 11:56:21.91444+00', '2015-05-14 11:56:21.91444+00', 'Carriages at Midnight', '', 11136, '', 0, 0, 2014, 0, '');
INSERT INTO 'album' VALUES (1068, '2014-03-19 09:36:27.78803+00', '2016-03-14 12:15:26.695873+00', 'Scottish Jigs and Reels', 'Jigs and Reels', 3016, '', 0, 0, 2010, 0, 'Virginia Reel played 8x32R');
INSERT INTO 'album' VALUES (439, '2003-07-27 22:00:00+00', '2016-03-16 09:48:46.668773+00', 'Leicester Branch 1977-2002 The Silver Collection', 'Leicester silver', 3006, 'LA', 1, 0, 2003, 0, 'This <<http://my.strathspey.org/dd/publication/1297/|booklet>> of this CD contains the description of five dances that are not contained in the actual book <<http://my.strathspey.org/dd/publication/83/|The Silver Collection>>. Those dances are Jaunty Jack, The Jovial Gentleman, Daunder in the Glen, The Heather Bank Jig, Bonnie Buchanhaven.');
INSERT INTO 'album' VALUES (1093, '2016-10-08 23:51:17.66737+00', '2016-10-09 02:29:32.356633+00', 'Sunday Class Dance Book 2, The', 'Sunday Class 2', 3217, '', 0, 0, 2016, 0, '');
INSERT INTO 'album' VALUES (1092, '2016-10-03 23:21:44.115632+00', '2016-10-04 00:14:17.558569+00', 'Excited States', '', 11376, '', 0, 0, 2016, 0, 'Due to an error in mastering the CD, in the list of tracks in the CD booklet tracks 9 and 10 have been swapped. The order given here corresponds to the actual order of tracks on the CD/in the download.');
INSERT INTO 'album' VALUES (315, '1999-03-23 23:00:00+00', '2015-06-13 16:02:06.151773+00', 'Night Owls', 'Night Owls', 2137, 'M', 1, 75, 0, 1, 'Times and track numbering here might be different from what is on the cassette, for they are from a digitized version.');
INSERT INTO 'album' VALUES (1083, '2015-06-19 10:38:16.570017+00', '2015-06-19 12:00:45.389809+00', 'Gotta Dance! … to Reel of Seven', 'Gotta Dance!', 10000, '', 0, 1, 2015, 1, '');
INSERT INTO 'album' VALUES (1090, '2016-09-12 22:51:34.579517+00', '2016-09-12 23:50:51.262183+00', 'Book 50 – “Spring Fling” Music for 13 Scottish Country Dances', 'Book 50', 11351, '', 0, 0, 2016, 0, '');
INSERT INTO 'album' VALUES (1089, '2016-07-04 22:38:25.354944+00', '2016-07-04 23:20:09.979016+00', 'Burning of Paddy''s Breeches and other dances', 'Burning of Paddy''s Breeches', 2328, '', 0, 0, 1954, 0, 'Record contains recordings by "Bobby MacLeod''s Highland Dance Band" and "Bobby MacLeod and his Band".');
INSERT INTO 'album' VALUES (1085, '2015-08-31 12:01:56.195632+00', '2015-08-31 12:01:56.195632+00', 'Happy Tartan', '', 11190, '', 0, 0, 2014, 1, '');
INSERT INTO 'album' VALUES (1075, '2014-08-11 14:56:34.908364+00', '2015-09-05 22:03:03.096032+00', 'Book 48 - Music for 15 Scottish Country Dances', 'Book 48', 10979, '', 0, 0, 2014, 0, '');
INSERT INTO 'album' VALUES (245, '1998-11-03 23:00:00+00', '2015-10-06 11:09:22.548999+00', 'Welcome to the London Highland Club', 'Welcome/London', 2414, 'CG', 1, 340, 1977, 1, '');
INSERT INTO 'album' VALUES (371, '2000-09-02 22:00:00+00', '2018-11-09 18:41:16.229543+00', 'Teachers Choice 1', 'Teachers Choice 1', 11743, 'OO', 1, 533, 1965, 2, 'Artist set to Pasadena Recorders (was originally Various Artists). See http://my.strathspey.org/dd/issue/1503/');
INSERT INTO 'album' VALUES (1091, '2016-09-24 10:00:59.259238+00', '2016-09-24 12:03:28.788327+00', 'Dances from Miss Milligan''s Miscellany Part 5', 'Miscellany 5', 10034, '', 0, 0, 2016, 0, '');
INSERT INTO 'album' VALUES (1094, '2016-10-30 22:08:13.761217+00', '2016-10-30 23:50:44.08091+00', 'Tullich Collection, The', '', 3013, '', 0, 0, 2015, 0, '');
INSERT INTO 'album' VALUES (1086, '2015-12-08 10:07:57.666194+00', '2017-11-26 14:34:47.338827+00', 'Third Sheaf Collection of Scottish Country Dances, The', '3rd Sheaf Collection', 3011, '', 0, 0, 2015, 0, 'THIS CD AND RECORDINGS ARE IN THE PROCESS OF BEING ADDED - PLEASE BE PATIENT!');
INSERT INTO 'album' VALUES (1056, '2013-12-19 16:09:48.740321+00', '2018-10-14 00:07:25.295614+00', 'Other Kangaroo Paw, The', 'Other Kangaroo Paw', 3217, '', 0, 0, 2013, 0, '');
INSERT INTO 'album' VALUES (93, '1998-09-02 22:00:00+00', '2017-01-25 01:20:36.077726+00', 'Biggar and Better Sound of Alex MacArthur, The', 'Biggar Better', 3001, '', 0, 289, 0, 1, 'Biggar is the name of a village where Alex had a hotel; it''s also a pun.');
INSERT INTO 'album' VALUES (1088, '2016-07-04 08:49:33.911384+00', '2017-02-03 16:20:53.653406+00', 'Take Your Partners', '', 3057, '', 0, 0, 0, 0, 'This LP has been reissued under the name Early Days in 2005 by Legacy Records.

It is available to buy on itunes, Amazon, Apple Music, etc.

and to listen to on Spotify.');
INSERT INTO 'album' VALUES (1087, '2016-03-13 00:56:44.468602+00', '2018-10-25 21:51:50.610583+00', '9 for 90 RSCDS Aberdeen Branch 90th Anniversary', '9 for 90', 2944, '', 0, 0, 2015, 0, '');
INSERT INTO 'album' VALUES (1097, '2017-02-12 12:10:29.868639+00', '2017-02-12 13:54:07.062866+00', 'Take Your Partners For … Vol. 5', 'Take Your Partners 5', 10034, '', 0, 0, 2015, 0, '');
INSERT INTO 'album' VALUES (1095, '2016-12-14 22:08:06.998512+00', '2017-07-27 16:12:50.74372+00', 'Sunday Class Christmas CD, The', 'Sunday Class Xmas', 10209, '', 0, 0, 2016, 0, '');
INSERT INTO 'album' VALUES (1096, '2016-12-18 01:14:57.066624+00', '2017-03-02 00:55:38.106449+00', 'Magic of Summer School, The', '', 10000, '', 0, 1, 2016, 1, '');
INSERT INTO 'album' VALUES (1101, '2017-08-26 22:27:31.868487+00', '2017-09-30 10:51:22.053534+00', 'Book 51 – Music for 12 Scottish Country Dances and Band Leader''s Choices', 'Book 51', 10018, '', 0, 0, 2017, 0, '');
INSERT INTO 'album' VALUES (1098, '2017-02-13 10:54:29.271333+00', '2017-02-13 17:03:51.619415+00', 'Platinum 70th Anniversary Dances - Belfast Branch', 'Belfast Platinum Dances', 3217, '', 0, 0, 2016, 0, 'The CD states "70th Anniversary Dances" as title on the side, but  "Platinum Anniversary Dances" and "1946 - 70 - 2016" on the front.');
INSERT INTO 'album' VALUES (919, '2009-11-23 23:00:00+00', '2017-03-13 15:29:26.996788+00', 'Cambusdoon', 'Cambusdoon', 3019, '', 0, 0, 2009, 0, '');
INSERT INTO 'album' VALUES (973, '2010-10-08 22:00:00+00', '2017-04-11 07:46:48.105818+00', 'Music for A Second Book of Graded Scottish Country Dances', 'Graded Book 2', 10249, '', 0, 0, 2010, 0, '');
INSERT INTO 'album' VALUES (1102, '2017-11-06 18:23:24.037651+00', '2017-11-08 15:10:08.826632+00', 'Stirling at 90', '', 10209, '', 0, 0, 2017, 0, '');
INSERT INTO 'album' VALUES (175, '1999-10-01 22:00:00+00', '2017-11-08 15:19:04.215146+00', 'Gie us Tullochgorum', 'Gie us', 2066, 'RS', 1, 408, 1986, 1, '');
INSERT INTO 'album' VALUES (118, '2002-05-11 22:00:00+00', '2019-09-11 21:23:39.279214+00', 'Book 33. Music for Eight Scottish Country Dances', 'RSCDS 33', 3019, 'EC', 1, 405, 2001, 1, 'The entry is for the CD which has an extra track compared to the original LP/MC (album ID 1121).');
INSERT INTO 'album' VALUES (1099, '2017-05-19 08:53:45.768291+00', '2017-05-19 18:12:09.299249+00', 'Thistle House Live!', '', 11484, '', 0, 0, 2013, 2, 'Live recording of medleys suitable for Scottish country dancing with original music by David Knight (Fiddle) , Dave Wiesler (Piano) and Dan Emery (pipes and wooden flute) all featured. Recorded at the New Haven Branch Highland Ball 2007');
INSERT INTO 'album' VALUES (440, '2003-09-14 22:00:00+00', '2017-06-10 01:43:12.579801+00', 'Scottish in Salem', 'Salem', 3372, 'AP', 1, 0, 2003, 0, 'The complete lineup for the CD was Lissa Schneckenburger (fiddle), Tom Pixton (piano/accordion), Howard Lasnick and Paul Henle (percussion), and Barbara Pixton (bass).');
INSERT INTO 'album' VALUES (1035, '2013-01-04 12:23:14.374687+00', '2017-06-14 01:14:26.437627+00', 'Are You Ready? .... Well Here We Go!', 'Are You Ready', 3067, '', 0, 0, 2012, 0, 'A very special album, produced from recordings made during Bobby Brown''s last two live band appearances: The 2011 Edmonton Caledonian Ball and The 2011 Toronto Tartan Ball.



The lineup was: Bobby Brown (lead accordion), Laird Brown (2nd accordion), Kathy Fraser-Collins (piano), Don Wood (bass guitar), and Fred Collins (drums).

');
INSERT INTO 'album' VALUES (1103, '2017-11-10 16:19:37.003158+00', '2017-11-10 20:43:48.702406+00', 'Around the World with Scotch Mist', 'Around the World', 10955, '', 0, 0, 2017, 0, '');
INSERT INTO 'album' VALUES (1104, '2017-11-17 09:09:38.499315+00', '2017-11-17 14:34:14.487892+00', 'Elma McCausland MBE', 'Elma McCausland MBE', 3217, '', 0, 0, 2017, 0, 'This is the CD included in the RSCDS Belfast publication "Dances to Honour Elma McCausland MBE".');
INSERT INTO 'album' VALUES (760, '1998-10-12 22:00:00+00', '2021-08-20 22:00:08.380236+00', 'Jimmy Lindsay and his Scottish Dance Band', 'Lindsay & SDB', 3025, 'EN', 1, 244, 1975, 1, 'Only selected tracks have been entered. An image of the back cover is available via <<https://www.amazon.com/Jimmy-Lindsay-Scottish-Dance-Band/dp/B00DVN36D6>>.');
INSERT INTO 'album' VALUES (1116, '2019-02-26 18:19:42.366445+00', '2022-08-27 07:59:36.453208+00', 'Dancing Bear, The', 'Dancing Bear', 11791, '', 0, 0, 0, 0, 'Double CD album');
INSERT INTO 'album' VALUES (1082, '2015-05-31 09:41:23.136553+00', '2022-12-10 19:36:13.044972+00', 'Joy of Sets, The', 'Joy of Sets', 10037, '', 0, 0, 2015, 0, 'The data results from the download version on itunes

 - no tunes yet

 - the times have to be checked');
INSERT INTO 'album' VALUES (1112, '2018-06-23 14:16:42.103466+00', '2018-08-17 17:06:56.497651+00', 'DuK''s Miss Milligan''s Miscellany', 'CD MMM Part 4', 11651, '', 0, 0, 2015, 0, 'The DuK CD has a few oddities:



- The track for "The Monifieth Star" has been recorded as eight repetitions of a 32-bar reel - but the dance in fact is a 48-bar reel.



- The track for "Newington Assembly" has been recorded as eight repetitions of a 48-bar reel but the dance is in fact a 32-bar reel. (The original tune is called "Newington Assembly").



There are re-recordings available, if you login at the <<http://www.rscds.org|RSCDS Homepage>>:  

RSCDS Homepage login / Media / Audio, Video / DuK MMM remastert tracks for "The Monifieth Star" and  "Newington Assembly"');
INSERT INTO 'album' VALUES (1100, '2017-06-28 12:33:29.220775+00', '2017-06-28 14:47:29.935703+00', 'Spark O'' Water', 'Spark O'' Water', 2586, '', 0, 0, 2017, 0, '');
INSERT INTO 'album' VALUES (447, '2004-01-19 23:00:00+00', '2017-08-23 21:14:11.64856+00', 'Peter Macfarlane (fiddle) & Lilian Linden (piano)', 'Peter Macfarlane & Lilian Linden', 3418, '', 0, 0, 2003, 0, 'The CD actually does not show a title besides "Peter Macfarlane (fiddle) & Lilian Linden (piano)". Thus, this is the title of the CD as Peter Macfarlane pointed out by email.



Nevertheless, this CD is sometimes offered as "Invercauld" or "Invercauld001" which related to the catalog number of the CD.');
INSERT INTO 'album' VALUES (1113, '2018-09-15 09:31:17.515487+00', '2018-11-06 21:50:18.526658+00', 'Book 52 – Music for 12 Scottish Country Dances plus 5 Bonus Tracks', 'Book 52', 10659, '', 0, 0, 2018, 0, '');
INSERT INTO 'album' VALUES (1114, '2019-01-08 15:52:22.966775+00', '2019-01-08 16:38:18.926273+00', 'Musicians'' Wedding, The', 'Musicians'' Wedding, The', 3217, '', 0, 0, 2018, 0, '');
INSERT INTO 'album' VALUES (455, '2004-09-29 22:00:00+00', '2019-01-14 16:27:50.071158+00', 'Campbell''s Birl', 'Campbell''s Birl', 2586, 'LH', 1, 0, 2004, 0, 'Dances from Glasgow Assembly and Farewell, My Fancy.');
INSERT INTO 'album' VALUES (1107, '2017-12-27 14:36:16.25479+00', '2017-12-27 17:17:32.534248+00', 'Music for The Carlingwark Collection, Volume Two', 'Carlingwark Collection, Vol. 2', 11351, '', 0, 0, 2017, 0, '');
INSERT INTO 'album' VALUES (1106, '2017-12-16 16:06:41.387136+00', '2017-12-27 17:18:41.25018+00', 'Music for The Carlingwark Collection, Volume One', 'Carlingwark Collection, Vol. 1', 10037, '', 0, 0, 2017, 0, '');
INSERT INTO 'album' VALUES (1108, '2017-12-27 17:14:11.095929+00', '2017-12-27 17:19:33.002192+00', 'Music for The Carlingwark Collection, Volume Three', 'Carlingwark Collection, Vol. 3', 10018, '', 0, 0, 2017, 0, '');
INSERT INTO 'album' VALUES (499, '2006-06-20 22:00:00+00', '2018-01-22 13:28:55.358665+00', 'Catch the Wind', 'Catch the Wind', 3030, 'AP', 1, 0, 2006, 0, '');
INSERT INTO 'album' VALUES (1105, '2017-11-24 16:03:00.175293+00', '2017-12-09 09:00:27.331827+00', 'Full Circle', '', 11568, '', 0, 0, 2017, 0, '');
INSERT INTO 'album' VALUES (833, '1998-10-12 22:00:00+00', '2018-02-15 09:16:38.445068+00', 'Scottish Ramble', 'Ramble', 3010, 'JW', 1, 383, 1963, 1, '');
INSERT INTO 'album' VALUES (1119, '2019-06-14 14:42:56.136199+00', '2019-06-14 18:28:15.186592+00', 'Sunday Class Recorded Highlights Volume 1, The', 'TSC Recorded Hghlights 1', 10659, '', 0, 0, 2019, 0, 'Official release date: 1st July 2019');
INSERT INTO 'album' VALUES (77, '1998-07-23 22:00:00+00', '2017-12-17 22:13:45.978624+00', 'All Set', 'All Set', 3006, 'AP', 1, 96, 1995, 1, 'Please note, the CD indeed contains two recordings for "Saint Andrews of Brampton", a primary and an alternative set with different tunes.');
INSERT INTO 'album' VALUES (1115, '2019-02-26 18:18:42.178699+00', '2019-02-26 18:49:41.727594+00', 'Black Bear, The', '', 11791, '', 0, 0, 0, 0, 'This is a listening CD with mixed scottish tunes but not suitable for dancing.');
INSERT INTO 'album' VALUES (1117, '2019-02-26 18:20:42.181972+00', '2019-02-26 18:50:16.681334+00', 'Ursa Major', 'Ursa Major', 11791, '', 0, 0, 0, 0, 'This is a listening CD with mixed scottish tunes but not suitable for dancing.');
INSERT INTO 'album' VALUES (1121, '2019-09-11 21:04:39.166886+00', '2019-09-11 21:23:49.22428+00', 'Book 33. Music for Eight Scottish Country Dances', 'RSCDS 33', 3019, 'EC', 1, 405, 2001, 1, 'This entry is for the original LP/MC. The CD entry (album ID 118) has an extra track.');
INSERT INTO 'album' VALUES (1120, '2019-08-23 16:02:54.07517+00', '2019-08-23 16:18:16.928308+00', 'Second Chances', '', 11862, '', 0, 1, 2019, 1, '');
INSERT INTO 'album' VALUES (1118, '2019-03-14 00:12:47.537231+00', '2019-03-14 12:14:41.644694+00', 'Dancer''s Best Friend, A', 'Dancer''s Best Friend', 3017, '', 0, 0, 2018, 0, 'For this album the two original members of Terpsichore were joined by Ralph Gordon (https://my.strathspey.org/dd/person/11799/)');
INSERT INTO 'album' VALUES (438, '2003-07-04 22:00:00+00', '2019-11-16 17:42:54.930461+00', 'More Memories of Scottish Weekend', 'More Weekend', 2162, '', 0, 0, 2003, 2, '');
INSERT INTO 'album' VALUES (1084, '2015-08-19 14:29:07.429656+00', '2019-11-26 01:02:01.385378+00', 'Book 49 - Music for 15 Scottish Country Dances', 'Book 49', 10659, '', 0, 0, 2015, 0, '');
INSERT INTO 'album' VALUES (1122, '2019-12-09 22:03:54.591618+00', '2019-12-09 22:36:03.933496+00', 'Robertson: A Musical Heritage', '', 11568, '', 0, 0, 2019, 0, '');
INSERT INTO 'album' VALUES (186, '2001-11-19 23:00:00+00', '2020-02-01 17:17:10.266399+00', 'Note ''N'' Away', 'Note ''N'' Away', 3045, '', 0, 302, 1998, 1, 'Tune details still to be added for some tracks. A list is available at <<https://www.thedancinghaggis.com/note-away-p-68863.html>>.');
INSERT INTO 'album' VALUES (366, '1999-04-22 22:00:00+00', '2020-06-17 22:42:31.967748+00', 'Live', 'Live', 2065, 'AS', 1, 398, 1995, 1, 'Recorded live at the 20th Anniversary Ball of the San Diego branch of the RSCDS in 1995.');
INSERT INTO 'album' VALUES (1126, '2020-06-11 19:02:01.121591+00', '2020-06-11 20:11:26.799191+00', 'Scottish Dance Tour Japan 1997', 'Japan Tour', 3016, '', 0, 0, 1997, 0, 'CD of recordings made specially for a particular tour and not widely available (details supplied by Martina Mueller-Franz).');
INSERT INTO 'album' VALUES (1124, '2020-05-21 08:49:30.54046+00', '2020-05-21 10:26:33.143436+00', 'Grove Collection of SCDs Volume 1', 'Grove Collection 1', 11858, '', 0, 0, 2020, 0, '');
INSERT INTO 'album' VALUES (1125, '2020-05-29 10:20:37.164952+00', '2021-09-01 20:13:40.25169+00', 'Emigrant Scot, The', 'Emigrant Scot', 11953, '', 0, 1, 2020, 1, '');
INSERT INTO 'album' VALUES (1127, '2020-07-04 15:21:29.178579+00', '2020-07-04 15:22:51.471074+00', 'Bruce Fordyce Memorial Collection, The', '', 1042, '', 0, 0, 0, 0, '');
INSERT INTO 'album' VALUES (1123, '2020-04-30 16:48:42.108331+00', '2020-05-08 08:39:58.529211+00', 'Short & Sweet', '', 10114, '', 0, 0, 2020, 0, '');
INSERT INTO 'album' VALUES (208, '1998-05-04 22:00:00+00', '2021-08-20 20:03:19.853201+00', 'Testing the Water', 'Testing Water', 2089, '', 0, 73, 0, 1, 'Some information about this CD found at <<https://www.thedancinghaggis.com/testing-the-water-p-70192.html>>. Used for assigning track numbers (the album was originally entered with all track numbers set to 0). Not all the 13 tracks claimed to be on the CD have been entered in the database.');
INSERT INTO 'album' VALUES (281, '1999-01-23 23:00:00+00', '2021-04-16 11:52:44.537501+00', 'Let''s All Go Scottish Country Dancing', 'Let''s All Go', 2058, 'JW', 1, 295, 1971, 1, 'In <<https://www.discogs.com/McBains-Scottish-Country-Dance-Band-Lets-All-Go-Scottish-Country-Dancing/release/3603144>> track 7 is described as "Airie Brenan". This is perhaps a mistake for Airie Bennan - though the lead tune listed here is not the recommended one for that dance. Similarly track 4 is described as "Earlstoun Loch" but also does not include the recommended tune for that dance.');
INSERT INTO 'album' VALUES (1128, '2020-07-31 16:00:31.832574+00', '2020-07-31 17:01:13.665131+00', 'Encore une Fois', '', 11972, '', 0, 0, 2018, 0, 'Arrangements by Laura Risk and Nicholas Williams.



Recorded by Nicholas Williams and Laura Risk at Tsuga studios in Waterville, QC, April 2018. Mixed and mastered by Nicholas Williams.



Laura and Nicholas would like to thank the Montréal Branch for their encouragement and support of our music. Thanks also to the many musicians with whom we''ve had the pleasure of collaborating over the years, in particular Éric Breton, and to Susie Petrov and Mara Shea for introducing us to some of our favourite dance tunes.');
INSERT INTO 'album' VALUES (958, '2010-08-07 22:00:00+00', '2021-04-30 10:05:56.068917+00', 'Book 17 plus 3 Dances for 2009', 'Book XVII', 3016, '', 0, 0, 2010, 0, 'The RSCDS as uploaded this album to youtube as a playlist <<https://www.youtube.com/playlist?list=OLAK5uy_l4GSZ84YFy5Un22hyNLbSXOziMKmKUYFQ>>. However as reported in <<https://my.strathspey.org/dd/issue/2447/|issue 2447>> the "video" for Bob Sanders was uploaded incorrectly.');
INSERT INTO 'album' VALUES (1129, '2020-12-07 22:45:17.370004+00', '2020-12-07 23:30:35.670053+00', 'Well Tuned Piano, The', 'Well Tuned Piano', 709, '', 0, 0, 2020, 0, 'Subtitle: Piano Music for Scottish Country Dancing.



Sheet music of the tunes is available on request to don.bartlett@veritrack.ca.');
INSERT INTO 'album' VALUES (1132, '2021-05-22 07:59:41.58831+00', '2021-05-22 19:08:55.645134+00', 'Welcome to the Dance', '', 3037, '', 0, 0, 1970, 0, 'This is a stub entry with minimal data from <<https://www.discogs.com/Jim-Johnstone-And-His-Band-Welcome-To-The-Dance/release/6753923>>.');
INSERT INTO 'album' VALUES (1133, '2021-05-23 12:08:43.59459+00', '2021-05-23 12:08:43.59459+00', 'Lassie Come and Dance With Me', 'Lassie Come & Dance', 3009, '', 0, 0, 1966, 0, 'This is a stub entry added to link the recording specifically mentioned in the instructions for <<ddd:Johnny Lad#8430>>. The information was taken from <<https://www.discogs.com/Jim-MacLeod-And-His-Band-Lassie-Come-And-Dance-With-Me/release/10766308>>.');
INSERT INTO 'album' VALUES (1130, '2021-03-18 22:00:37.868864+00', '2021-03-18 22:34:09.796158+00', 'Jimmy Blue''s Welcome to Scotland', 'Blue''s Welcome', 2039, '', 0, 0, 1969, 0, 'Stub entry. Not all recordings on this album are entered.



Those, generic tracks or for dances unknown to the database, include:  

A2: The Ladies from Hell  

A3: Unknown Polka  

A4: Drum Salute  

A5: Scottish Waltz  

A6: Medley  

B2: Fiddle Solo  

B3: Bremner''s March  

B4: Hornpipes  

B5: Accordion Duet  

B7: Moladh Beinn Dobhrain  



Information from https://www.discogs.com/Jimmy-Blue-And-His-Scottish-Band-Jimmy-Blues-Welcome-To-Scotland/release/6491702 (and a google search shows a low resolution photo of the cover which matches the discogs record). Album originally notified via issue 2407 (https://my.strathspey.org/dd/issue/2407/).');
INSERT INTO 'album' VALUES (838, '1998-07-17 22:00:00+00', '2021-03-19 22:37:27.352837+00', 'Scottish Sounds of Jimmy Blue, The', 'Scottish Sounds', 2039, 'EC', 1, 32, 1972, 1, 'This album has several additional tracks which are not for dances and so are not currently listed here.  

A4: Fiddle solo  

A5: Accordion duet  

B3: Accordion Solo  

');
INSERT INTO 'album' VALUES (1134, '2021-06-30 12:02:47.737547+00', '2021-06-30 12:07:13.188907+00', 'Thirty Popular Dances - Volume Two Part one', '', 10037, '', 0, 0, 2019, 0, '');
INSERT INTO 'album' VALUES (1131, '2021-04-03 15:27:57.703586+00', '2021-04-03 15:41:41.051846+00', 'Ian Powrie on Stage', 'Powrie on Stage', 2062, '', 0, 0, 1966, 0, 'Stub entry. The recording for only one dance is identified. The list of tunes used can be found at <<http://www.nigelgatherer.com/perf/fiddlers/ian_powrie.html>>.');
INSERT INTO 'album' VALUES (1135, '2021-08-13 21:15:51.248361+00', '2021-08-13 21:29:14.958169+00', 'Bill Ewan''s Lockdown Sessions', 'Lockdown Sessions', 12028, '', 0, 0, 2021, 0, 'Recordings of live music played by Bill Ewan in online sessions during the 2020 lockdown. Most are "listening" tracks but there are four for dances. The CD was issued in a limited set with all proceeds going to charity.');
INSERT INTO 'album' VALUES (375, '2000-09-06 22:00:00+00', '2021-08-17 08:18:28.240442+00', 'Dance to the Pipes', 'Dance to Pipes', 1556, 'AP', 1, 508, 2000, 2, 'The dance instructions are in the booklet with this note: "Tracks 4, 5, and 7 were previously allocated to the dances in brackets on the cassette ''Broadswords'' SRCM153. These three tracks and track 6 have piano accompaniment by Nancy Dickson. *(Information from <<https://my.strathspey.org/dd/issue/2611/|issue 2611>>).*



So track 4 "Aileen''s Reel" is also for "Bonnie Geordie''s Wig";  

track 5 "East of Yeadon" is also for "Kiss Under the Stairs";  

and track 7 "The Piper''s Glen" is also for "Lady Charlotte Bruce".  ');
INSERT INTO 'album' VALUES (1136, '2021-08-19 12:24:50.89556+00', '2021-08-20 15:20:34.130805+00', 'Friday Fun Night at the Stagger Inn', 'Stagger Inn', 11858, '', 0, 0, 2021, 0, '');
INSERT INTO 'album' VALUES (1137, '2021-09-30 19:17:09.701937+00', '2021-09-30 21:55:31.777313+00', 'A'' the best again fae Banffshire - 90 years of Scottish Country Dancing', 'Banffshire 90th', 12069, '', 0, 0, 2021, 0, '');
INSERT INTO 'album' VALUES (172, '1998-10-18 22:00:00+00', '2021-10-05 11:52:15.4746+00', 'Favourite Scottish Dances', 'Favourite SD', 10748, 'EE', 1, 395, 0, 1, 'See <<https://my.strathspey.org/dd/issue/2629/|issue 2629>> for comments. Previously this was entered with title "Favourite Scottish Dances #5" but the "#5" is now removed.');
INSERT INTO 'album' VALUES (490, '2006-02-21 23:00:00+00', '2021-11-25 22:06:01.856397+00', 'Medal Tests for Young Dancers (2006)', 'Medal Tests 2006', 3658, '', 0, 0, 2006, 0, 'This album is presumably the one accompanying the original edition of the medal tests. Those were later revised and a new CD issued.');
INSERT INTO 'album' VALUES (261, '1998-10-10 22:00:00+00', '2022-07-30 16:07:45.260393+00', 'Reelin'' ''n'' Ramblin''', 'Reelin''', 3057, 'EN', 1, 145, 1976, 1, 'There is no evidence The Gordon Waltz is actually on this album. Maybe a mistake for a Roy Hendri album such as Scottish Dance Party vol 2?');
INSERT INTO 'album' VALUES (1139, '2022-01-13 13:50:26.621791+00', '2022-01-13 19:58:28.525812+00', 'RSCDS Dunfermline Branch 90th Anniversary Dances', 'Dunfermline 90th', 2944, '', 0, 1, 2019, 0, '');
INSERT INTO 'album' VALUES (963, '2010-09-02 22:00:00+00', '2022-01-24 09:57:07.334266+00', 'Music of Corryvrechan, The', 'Corryvrechan Music', 3479, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (1143, '2022-07-21 09:58:12.879285+00', '2022-07-21 10:05:43.832519+00', 'Cherry Blossom Time Volume 1', 'Cherry Blossom 1', 3050, '', 0, 0, 2008, 0, 'This CD appears to be the last 13 tracks (2nd CD) from a double CD set <<dda:Cherry Blossom Time#912>>. It is assumed the recordings are identical (though possibly there was an error in the tune order of the last recording). See <<https://my.strathspey.org/dd/issue/2837/|issue 2837>> for more details.');
INSERT INTO 'album' VALUES (1141, '2022-05-03 21:48:37.910423+00', '2022-05-03 22:13:14.38641+00', 'Ship Ahoy!', '', 11858, '', 0, 1, 2020, 1, 'Produced by Ewan Galloway to raise funds for the Edinburgh Trinity Sea Cadets.');
INSERT INTO 'album' VALUES (1140, '2022-04-29 20:33:41.028937+00', '2022-05-27 16:04:30.443856+00', 'Argentine Collection 2020, The', 'Argentine Coll', 12122, '', 0, 1, 2020, 1, '');
INSERT INTO 'album' VALUES (1144, '2022-08-06 14:32:22.266736+00', '2022-08-06 16:05:45.618932+00', 'Simmerdim Danelaw Dance Band Favourites Vol. 1', 'Simmerdim', 3039, '', 0, 0, 2021, 0, 'This is named "Simmerdim" on the front and "Danelaw Dance Band Favourites Vol. 1" on the back. Note that only subset of the tracks have opening and closing chords.');
INSERT INTO 'album' VALUES (293, '1998-10-11 22:00:00+00', '2022-07-23 14:55:02.386365+00', 'O''er the Border', 'O''er the Border', 3010, 'EN', 1, 376, 1958, 1, '');
INSERT INTO 'album' VALUES (164, '1998-10-10 22:00:00+00', '2022-08-20 15:57:12.715687+00', 'Dancing with Jim Johnstone', 'Dancing w JJ', 3037, 'EN', 1, 208, 1967, 1, '');
INSERT INTO 'album' VALUES (359, '2000-03-12 23:00:00+00', '2022-07-24 18:27:54.177966+00', 'Band Boys'' Choice', 'Band Boys', 3049, '', 0, 530, 1999, 2, '');
INSERT INTO 'album' VALUES (1145, '2022-08-22 23:48:00.183061+00', '2022-08-22 23:48:00.183061+00', 'Highland Pretty', '', 12196, '', 0, 0, 2000, 0, '');
INSERT INTO 'album' VALUES (752, '1998-11-19 23:00:00+00', '2022-08-20 14:37:57.859638+00', 'Heather Medley Scottish Country Dancing', 'Heather Medley', 3037, 'EN', 1, 210, 1969, 1, 'The timings given here refer to the CD version, which was obviously not produced in 1969 (but doesn''t give the actual date). It says “This is a very limited edition CD produced to assist in raising funds for Scottish Cancer Charities.”');
INSERT INTO 'album' VALUES (85, '1998-09-02 22:00:00+00', '2022-08-23 00:01:55.849755+00', 'Scottish Country Dancing', 'SCD (C Wilson)', 3055, 'AP', 1, 460, 1997, 1, '');
INSERT INTO 'album' VALUES (167, '1998-11-14 23:00:00+00', '2022-08-23 21:57:39.61088+00', 'Edinburgh Castle Reel, The and other SCD', 'Edin Cas Reel', 2047, 'DS', 1, 136, 1986, 1, '');
INSERT INTO 'album' VALUES (998, '2011-11-11 23:00:00+00', '2022-08-26 22:52:39.416248+00', 'Live at the Beach Ballroom', 'Beach Ballroom', 3034, '', 0, 0, 2008, 0, '');
INSERT INTO 'album' VALUES (1062, '2014-02-14 14:58:55.918677+00', '2022-08-27 11:35:22.355211+00', 'Netherwood Collection, The', 'Netherwood', 1575, '', 0, 0, 2011, 0, 'The second CD has a recording for <<ddd:Nottingham Lace>> as track 2 that does not appear in the liner notes at all. Everything from “Ederline” is really one track later than it seems.');
INSERT INTO 'album' VALUES (443, '2003-11-17 23:00:00+00', '2022-08-29 00:01:53.830137+00', 'Basingstoke Ball Live 1971', 'Basingstoke', 2058, '', 0, 0, 2003, 0, 'This album was formerly entered in SCDDB with the name "Play Basingstoke Ball". However the CD is actually titled "Basingstoke Ball Live 1971". For more information see <<http://my.strathspey.org/dd/issue/1859/|issue 1859>>.

');
INSERT INTO 'album' VALUES (449, '2004-04-27 22:00:00+00', '2022-08-29 10:27:49.100907+00', 'Vintage Goldring', 'Vintage Goldring', 2586, '', 1, 0, 2004, 0, '');
INSERT INTO 'album' VALUES (1142, '2022-06-25 17:46:55.246972+00', '2023-01-30 18:09:20.097492+00', 'Newcastle 70th Anniversary', 'Newcastle 70th Anniversary', 12157, '', 0, 0, 2022, 0, 'Music performed by Marian Anderson''s and Iain MacPhail''s Dance Bands. Book of same name with dances devised by Sheila Trafford.');
INSERT INTO 'album' VALUES (1138, '2021-11-25 22:20:28.755469+00', '2022-08-29 21:23:23.376356+00', 'Medal Tests for Young Dancers (2014)', 'Medal Tests 2014', 3658, '', 0, 0, 2014, 0, 'This is the CD accompanying the revised medal tests. Some recordings are assumed to be copies of those on the original medal tests CD (<<dda:#490>>) while others are new for the updated version. The insert says this is published and copyright in 2013, 2014.



The CDDB ID data for this album is `1c0c4227 39 150 3707 8230 11716 17728 21194 27213 33087 39133 42388 48384 54430 60375 66363 72322 78359 84377 90319 96233 102270 108272 114324 120229 126151 132151 139368 145396 151436 157479 163491 169333 175550 185538 191335 197294 207552 213523 219676 229657 3140`.

We''re including it here for the time being because the CDDB ID field in the database is limited to 256 characters, and we need to extend that first in order to store this.');
INSERT INTO 'album' VALUES (57, '1999-05-25 22:00:00+00', '2022-09-04 19:49:06.986102+00', 'Book 32. Music for Eight Scottish Country Dances', 'RSCDS 32', 3022, 'AP', 1, 462, 1985, 1, 'For some reason tracks are numbered 2-9 in SCDDB. Otherwise the order corresponds to <<https://www.discogs.com/release/11179821-Alastair-Wood-And-His-Scottish-Dance-Band-Music-For-Eight-Scottish-Country-Dances-Book-32>> or <<https://archive.rscds.org/index.php/music-for-eight-scottish-country-dances-32;isad?sf_culture=en_GB>>.');
INSERT INTO 'album' VALUES (1160, '2022-12-26 13:26:53.731386+00', '2022-12-26 13:30:33.930525+00', 'Dancing Memories Volume Three', 'DancingMemories03', 3016, '', 0, 0, 0, 0, '');
INSERT INTO 'album' VALUES (1146, '2022-12-07 22:00:34.864591+00', '2022-12-07 22:39:57.849396+00', 'Grove Collection of SCDs Volume 2', '', 11858, '', 0, 1, 2022, 1, '');
INSERT INTO 'album' VALUES (1147, '2022-12-11 20:51:28.375079+00', '2022-12-11 21:34:04.594716+00', 'Music for Old Time Dancing, Vol. 6', '', 1580, '', 0, 0, 2013, 0, '');
INSERT INTO 'album' VALUES (887, '2009-10-24 22:00:00+00', '2022-12-13 17:21:05.43387+00', 'Music for Scottish Dances Collected by Mary Isdal MacNab', 'MacNab Dances', 3016, '', 0, 0, 2007, 0, '');
INSERT INTO 'album' VALUES (1148, '2022-12-16 09:45:50.981777+00', '2022-12-16 09:45:50.981777+00', 'Scottish Country Dances', '', 2058, '', 0, 0, 2012, 0, '');
INSERT INTO 'album' VALUES (198, '1998-10-06 22:00:00+00', '2022-12-16 17:15:21.819692+00', 'Memory Lane', 'Memory Lane', 3016, 'EC', 1, 425, 1991, 1, 'TAC005CD has no track 22 as the TAC005C, Meinhard');
INSERT INTO 'album' VALUES (1149, '2022-12-20 23:14:08.447629+00', '2022-12-20 23:14:08.447629+00', 'Landslide', 'Landslide', 11376, '', 0, 0, 2019, 0, 'The titles and album information are as can be seen on Spotify.');
INSERT INTO 'album' VALUES (1150, '2022-12-20 23:19:38.040912+00', '2022-12-20 23:38:48.350477+00', 'Spindriftin''', 'Spindriftin''', 11376, '', 0, 0, 2017, 0, '');
INSERT INTO 'album' VALUES (1151, '2022-12-22 22:44:06.253914+00', '2022-12-26 19:31:18.19832+00', 'Scotland Swings With The Great Jim MacLeod Band', 'Scotland Swings Again', 3009, '', 0, 0, 1968, 0, 'The LP back states: "(...) in fact, four members of the band have all written a tune specifically for this album." Sadly though it is not credited who wrote which tune. 

Produced by Ray Horricks.');
INSERT INTO 'album' VALUES (1162, '2023-02-25 18:09:16.306931+00', '2023-02-26 23:24:53.924778+00', 'RSCDS Tokai 25th Anniversary', 'Tokai 25th', 11953, '', 0, 0, 2023, 0, 'CD to accompany <<ddpub:RSCDS Tokai 25th Anniversary Book#1639>>.');
INSERT INTO 'album' VALUES (912, '2009-11-20 23:00:00+00', '2023-01-16 14:02:37.322017+00', 'Cherry Blossom Time', 'Cherry Blossom Time', 3050, '', 0, 0, 2007, 0, 'The last half of the tracks here (from Breeze Bay onwards) seem to have been reissued under the name "Cherry Blossom Time Volume 1". See <<dda:Cherry Blossom Time Volume 1#1143>> and <<https://my.strathspey.org/dd/issue/2837/|issue 2837>>.');
INSERT INTO 'album' VALUES (1153, '2022-12-23 11:57:58.886506+00', '2022-12-23 12:45:55.754411+00', 'Simply the Best Scottish Country Dance Album', 'Best MacLeod', 3009, '', 0, 0, 2005, 0, 'This is the Audio-CD entry. A DVD with a different track list under the same name is available too. ');
INSERT INTO 'album' VALUES (1152, '2022-12-22 23:21:10.941243+00', '2022-12-23 13:10:49.736885+00', 'Scottish Dance World Of Jim MacLeod And His Band, The', 'SD World MacLeod', 3009, '', 0, 0, 1971, 0, 'This album seems to be a "remix" of the previous Albums "Scotland Swings" and "Scotland Swings Again", published by Label "Ace of Clubs". The editor of this entry only connected previous recordings to that album; no new recordings entry were made, not knowing if new tracks were recorded at all. ');
INSERT INTO 'album' VALUES (1154, '2022-12-26 13:10:41.991702+00', '2022-12-26 13:10:41.991702+00', 'Saturday Dance Volume One', 'SatDance01', 3016, '', 0, 0, 0, 0, '');
INSERT INTO 'album' VALUES (1155, '2022-12-26 13:14:49.181341+00', '2022-12-26 13:15:37.06393+00', 'Saturday Dance Volume Two', 'SatDance02', 3016, '', 0, 0, 0, 0, '');
INSERT INTO 'album' VALUES (1156, '2022-12-26 13:17:12.204258+00', '2022-12-26 13:18:31.038438+00', 'Saturday Dance Volume Three', 'SatDance03', 3016, '', 0, 0, 0, 0, '');
INSERT INTO 'album' VALUES (1157, '2022-12-26 13:19:12.913327+00', '2022-12-26 13:20:13.02718+00', 'Saturday Dance Volume Four', 'SatDance04', 3016, '', 0, 0, 0, 0, '');
INSERT INTO 'album' VALUES (1158, '2022-12-26 13:23:27.880353+00', '2022-12-26 13:24:33.143428+00', 'Dancing Memories Volume One', 'DancingMemories01', 3016, '', 0, 0, 0, 0, '');
INSERT INTO 'album' VALUES (1159, '2022-12-26 13:25:19.711243+00', '2022-12-26 13:25:58.704572+00', 'Dancing Memories Volume Two', 'DancingMemories02', 3016, '', 0, 0, 0, 0, '');
INSERT INTO 'album' VALUES (1161, '2022-12-26 13:29:05.018989+00', '2022-12-26 13:29:50.67249+00', 'Dancing Memories Volume Four', 'DancingMemories04', 3016, '', 0, 0, 0, 0, '');


--
INSERT INTO 'albumsrecordingsmap' VALUES (1, 1, 50, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2, 1, 59, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (3, 1, 72, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4, 1, 88, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5, 1, 90, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6, 1, 106, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7, 1, 117, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8, 1, 149, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9, 1, 157, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10, 1, 200, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11, 1, 290, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (12, 1, 337, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (13, 1, 345, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (14, 1, 350, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (15, 2, 272, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (16, 2, 309, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (17, 2, 341, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (18, 3, 21, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (19, 3, 46, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (20, 3, 97, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (21, 3, 150, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (22, 3, 154, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (23, 3, 155, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (24, 3, 161, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (25, 3, 214, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (26, 3, 230, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (27, 3, 362, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (28, 4, 8, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (29, 4, 14, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (30, 4, 34, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (31, 4, 45, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (32, 4, 91, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (33, 4, 116, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (34, 4, 128, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (35, 4, 147, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (36, 4, 286, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (37, 4, 366, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (38, 5, 15, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (39, 5, 119, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (40, 5, 144, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (41, 5, 160, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (42, 5, 183, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (43, 5, 195, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (44, 5, 197, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (45, 5, 210, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (46, 5, 284, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (47, 5, 314, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (48, 7, 3, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (49, 7, 86, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (50, 7, 198, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (51, 7, 295, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (52, 7, 297, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (53, 7, 299, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (54, 7, 300, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (55, 7, 303, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (56, 7, 304, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (57, 7, 307, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (58, 7, 308, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (59, 7, 310, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (60, 7, 348, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (61, 8, 42, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (62, 8, 124, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (63, 8, 129, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (64, 8, 134, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (65, 8, 163, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (66, 8, 164, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (67, 8, 298, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (68, 8, 305, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (69, 8, 343, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (70, 9, 11, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (71, 9, 31, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (72, 9, 67, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (73, 9, 73, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (74, 9, 87, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (75, 9, 143, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (76, 9, 156, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (77, 9, 162, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (78, 9, 276, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (79, 10, 13, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (80, 10, 22, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (81, 10, 48, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (82, 10, 54, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (83, 10, 96, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (84, 10, 127, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (85, 10, 247, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (86, 10, 248, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (87, 10, 342, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (88, 10, 364, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (89, 11, 6, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (90, 11, 20, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (91, 11, 25, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (92, 11, 36, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9319, 1017, 8847, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9320, 1017, 8848, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9321, 1017, 8849, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9324, 1018, 1734, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9325, 1018, 4154, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9326, 1018, 1735, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9339, 1019, 8852, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9340, 1019, 8853, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9341, 1019, 8854, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9342, 1019, 8855, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9343, 1019, 8856, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9344, 1019, 8857, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9345, 1019, 8858, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9346, 1019, 8859, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9347, 1019, 8860, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9348, 1019, 8861, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9349, 1019, 8862, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9350, 1019, 8863, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9351, 1019, 8864, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9352, 1019, 8865, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9353, 1019, 8866, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9358, 1020, 8871, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9359, 1020, 8872, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9360, 1020, 8873, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9371, 1021, 8884, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9372, 1021, 8885, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9373, 1021, 8886, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9380, 1021, 8893, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9381, 1021, 8894, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9382, 1021, 8895, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9383, 1021, 8896, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9384, 1021, 8897, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9385, 1021, 8898, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9387, 1022, 8900, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9388, 1022, 8901, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9389, 1022, 8902, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9393, 1022, 8906, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9394, 1022, 8907, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9395, 1022, 8908, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9397, 1022, 8911, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9398, 1022, 8912, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9399, 1022, 8913, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9400, 1022, 8914, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9401, 1022, 8915, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9402, 1022, 8916, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9403, 1022, 8917, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9404, 1023, 8918, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9416, 1023, 8930, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9417, 1023, 8931, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9426, 1025, 6591, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9436, 1025, 7785, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9437, 1025, 7786, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9438, 1025, 7799, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9424, 1025, 6874, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9425, 1025, 6875, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9443, 494, 8932, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9453, 1026, 8942, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9454, 1026, 8943, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9455, 1026, 8944, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9459, 1026, 8848, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9460, 1026, 8945, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9461, 1026, 8946, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9462, 1026, 8850, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9463, 1026, 8947, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9464, 1026, 8948, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9466, 1027, 8950, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9467, 1027, 8951, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9468, 1027, 8952, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9469, 1027, 8953, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9470, 1027, 8954, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9471, 1027, 8955, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9472, 1027, 8956, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9473, 1027, 8957, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9478, 1028, 8961, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9479, 1028, 8962, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9480, 1028, 8963, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9481, 1028, 8964, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9482, 1028, 8965, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (93, 11, 58, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (94, 11, 69, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (95, 11, 132, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (96, 11, 208, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (97, 11, 222, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (98, 11, 241, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (99, 11, 260, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (100, 11, 287, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (101, 12, 4, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (102, 12, 5, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9444, 490, 8933, 29);
INSERT INTO 'albumsrecordingsmap' VALUES (9445, 490, 8934, 30);
INSERT INTO 'albumsrecordingsmap' VALUES (103, 12, 7, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (104, 12, 16, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (105, 12, 178, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (106, 12, 226, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (107, 12, 238, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (108, 12, 255, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (109, 12, 261, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (110, 12, 283, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (111, 13, 1, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (112, 13, 40, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (113, 13, 43, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (114, 13, 55, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (115, 13, 109, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (116, 13, 137, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (117, 13, 199, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (118, 13, 229, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (119, 13, 271, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (120, 13, 317, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (121, 13, 324, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (122, 13, 344, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (123, 13, 368, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (124, 14, 108, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (125, 14, 130, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (126, 14, 175, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (127, 14, 187, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (128, 14, 203, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (129, 14, 221, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (130, 14, 254, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (131, 14, 256, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (132, 14, 354, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (133, 14, 363, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (134, 15, 29, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (135, 15, 44, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (136, 15, 80, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (137, 15, 111, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (138, 15, 118, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (139, 15, 125, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (140, 15, 135, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (141, 15, 174, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (142, 15, 205, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (143, 15, 245, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (144, 15, 262, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (145, 15, 296, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (146, 15, 325, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (147, 15, 356, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (148, 16, 28, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (149, 16, 39, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (150, 16, 61, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (151, 16, 136, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (152, 16, 152, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (153, 16, 177, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (154, 16, 181, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (155, 16, 202, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (156, 16, 224, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (157, 16, 267, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (158, 16, 353, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (159, 17, 9, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (160, 17, 52, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (161, 17, 53, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (162, 17, 57, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (163, 17, 64, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (164, 17, 85, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (165, 17, 104, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (166, 17, 112, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (167, 17, 114, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (168, 17, 148, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (169, 17, 193, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (170, 17, 234, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (171, 17, 257, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (172, 17, 278, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (173, 17, 355, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (174, 18, 105, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (175, 18, 110, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (176, 18, 139, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (177, 18, 184, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (178, 18, 188, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (179, 18, 207, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (180, 18, 228, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (181, 18, 333, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (182, 19, 17, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (183, 19, 82, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (184, 19, 83, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (185, 19, 166, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9322, 1017, 8850, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9323, 1017, 8851, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9327, 1018, 4148, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9328, 1018, 1732, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9329, 1018, 4155, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9354, 1019, 8867, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9355, 1019, 8868, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9356, 1019, 8869, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9361, 1020, 8874, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9362, 1020, 8875, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9363, 1020, 8876, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9374, 1021, 8887, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9375, 1021, 8888, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9376, 1021, 8889, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9386, 1021, 8899, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9390, 1022, 8903, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9391, 1022, 8904, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9405, 1023, 8919, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9427, 1025, 6592, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9428, 1025, 6593, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9429, 1025, 6780, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9439, 1025, 7800, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9440, 1025, 7801, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9456, 1026, 2355, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9457, 1026, 8847, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9458, 1026, 8849, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9465, 1026, 8949, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9474, 1027, 8958, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9475, 1027, 8959, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9476, 1027, 8851, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9484, 1028, 8967, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (186, 19, 172, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (187, 19, 268, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (188, 19, 293, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (189, 19, 311, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (190, 19, 318, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (191, 19, 322, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (192, 20, 62, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (193, 20, 77, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (194, 20, 211, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (195, 20, 265, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (196, 20, 285, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (197, 20, 319, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (198, 21, 37, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (199, 21, 56, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (200, 21, 79, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (201, 21, 151, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (202, 21, 180, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (203, 21, 251, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (204, 21, 258, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (205, 21, 273, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (206, 21, 281, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (207, 21, 361, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (208, 22, 32, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (209, 22, 38, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (210, 22, 49, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (211, 22, 140, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (212, 22, 206, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (213, 22, 217, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (214, 22, 289, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (215, 22, 312, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (216, 22, 315, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (217, 22, 323, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (218, 22, 326, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (219, 22, 336, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (220, 23, 27, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (221, 23, 47, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (222, 23, 51, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (223, 23, 65, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (224, 23, 75, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (225, 23, 145, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (226, 23, 173, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (227, 23, 190, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (228, 23, 191, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (229, 23, 201, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (230, 23, 204, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (231, 23, 239, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (232, 23, 246, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (233, 23, 291, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (234, 23, 301, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (235, 23, 357, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (236, 24, 2, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (237, 24, 19, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (238, 24, 23, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (239, 24, 92, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (240, 24, 93, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (241, 24, 98, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (242, 24, 121, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (243, 24, 126, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (244, 24, 131, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (245, 24, 159, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (246, 24, 168, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (247, 24, 192, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (248, 24, 225, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (249, 24, 231, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (250, 24, 280, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (251, 24, 334, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (252, 24, 340, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (253, 24, 349, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (254, 25, 41, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (255, 25, 81, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (256, 25, 103, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (257, 25, 113, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (258, 25, 186, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (259, 25, 215, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (260, 25, 250, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (261, 25, 266, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (262, 25, 339, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (263, 26, 10, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (264, 26, 70, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (265, 26, 213, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (266, 26, 216, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (267, 26, 218, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (268, 26, 227, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (269, 26, 233, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (270, 26, 236, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (271, 26, 328, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (272, 26, 331, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (273, 26, 346, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (274, 26, 347, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (275, 26, 358, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (276, 19, 369, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (277, 19, 370, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9330, 1018, 4157, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9331, 1018, 1739, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9332, 1018, 4147, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9357, 1019, 8870, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (9364, 1020, 8877, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9365, 1020, 8878, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9366, 1020, 8879, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9377, 1021, 8890, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9378, 1021, 8891, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9379, 1021, 8892, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9392, 1022, 8905, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9406, 1023, 8920, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9430, 1025, 6781, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9431, 1025, 6782, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9432, 1025, 6865, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9477, 1027, 8960, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9483, 1028, 8966, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9485, 1028, 8968, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9486, 1028, 8969, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9487, 1028, 8970, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9488, 1028, 8971, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9489, 1028, 8972, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9490, 1028, 8973, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9491, 1029, 8974, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9492, 1029, 8975, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9493, 1029, 8976, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9494, 1029, 8977, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9495, 1029, 8978, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9496, 1029, 8979, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9497, 1029, 8980, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9498, 1029, 8981, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9499, 1029, 8982, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9500, 1029, 8983, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9501, 1029, 8984, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9502, 1029, 8985, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9508, 1030, 8991, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9509, 1030, 8992, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9510, 1030, 8993, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9511, 1030, 8994, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9512, 1030, 8995, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9513, 1030, 8996, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9514, 1030, 8997, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9515, 1030, 8998, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9516, 1030, 8999, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9517, 1030, 9000, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9518, 1030, 9001, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9519, 1030, 9002, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9523, 1030, 9006, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9524, 1030, 9007, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9525, 1031, 9008, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9526, 1031, 9009, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9527, 1031, 9010, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9528, 1031, 9011, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9529, 1031, 9012, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9530, 1031, 9013, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9531, 1031, 9014, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9532, 1031, 9015, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9533, 1031, 9016, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9534, 1032, 9020, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9535, 1032, 9021, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9536, 1032, 9022, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9537, 1032, 9023, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9538, 1032, 9024, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9539, 1032, 9025, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9540, 1032, 9026, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9541, 1032, 9027, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9542, 1032, 9028, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9543, 1032, 9029, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9544, 1032, 9030, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9545, 1031, 9031, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9546, 1031, 9032, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9547, 1031, 9033, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9548, 1031, 9034, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9549, 1031, 9035, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9550, 1031, 9036, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9560, 1031, 9046, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (9561, 1031, 9047, 26);
INSERT INTO 'albumsrecordingsmap' VALUES (9562, 1031, 9048, 27);
INSERT INTO 'albumsrecordingsmap' VALUES (9569, 1033, 9055, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9570, 1033, 9056, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9571, 1033, 9057, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9572, 1033, 9058, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (278, 7, 371, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (279, 5, 30, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (280, 6, 35, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (281, 6, 133, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (282, 6, 158, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (283, 6, 165, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (284, 6, 171, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (285, 6, 182, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (286, 6, 196, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (287, 6, 223, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (288, 6, 26, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (289, 6, 244, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (290, 6, 275, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (291, 6, 279, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (292, 6, 277, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (293, 6, 282, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (294, 26, 194, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (295, 23, 373, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (296, 15, 374, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (297, 1, 169, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (298, 1, 167, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (299, 2, 264, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (300, 2, 138, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (301, 2, 269, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (302, 2, 176, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (303, 2, 68, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (304, 2, 288, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (305, 2, 99, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (306, 2, 185, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (307, 2, 189, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (308, 2, 302, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (309, 2, 306, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (310, 3, 84, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (311, 5, 76, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (312, 5, 179, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (313, 8, 66, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (314, 8, 100, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (315, 8, 94, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (316, 8, 153, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (317, 8, 122, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (318, 9, 219, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (319, 9, 292, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (320, 9, 365, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (321, 9, 313, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (322, 9, 115, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (323, 10, 332, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (324, 10, 232, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (325, 10, 63, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (326, 10, 270, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (327, 11, 237, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (328, 11, 359, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (329, 12, 316, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (330, 12, 253, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (331, 12, 212, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (332, 12, 78, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (333, 14, 33, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (334, 14, 320, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (335, 14, 141, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (336, 14, 327, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (337, 15, 101, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (338, 16, 18, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (339, 17, 294, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (340, 19, 360, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (341, 21, 335, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (342, 23, 102, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (343, 6, 378, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (344, 23, 338, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (345, 23, 329, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (346, 15, 330, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (347, 15, 60, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (348, 15, 351, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (349, 15, 379, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (350, 28, 381, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (351, 28, 382, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (352, 28, 383, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (353, 28, 384, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (354, 28, 385, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (355, 28, 386, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (356, 28, 387, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (357, 28, 388, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (358, 28, 389, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (359, 28, 390, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (360, 28, 391, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (361, 30, 392, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (362, 30, 393, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (363, 30, 394, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (364, 30, 395, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (365, 30, 396, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (366, 30, 397, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (367, 30, 398, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (368, 30, 399, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (369, 30, 400, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (370, 30, 401, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9333, 1018, 1738, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9334, 1018, 4152, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9335, 1018, 1731, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9367, 1020, 8880, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9368, 1020, 8881, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9369, 1020, 8882, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9407, 1023, 8921, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9408, 1023, 8922, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9409, 1023, 8923, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9433, 1025, 6866, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9434, 1025, 6867, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9435, 1025, 6876, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9503, 1029, 8986, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9504, 1029, 8987, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9505, 1029, 8988, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9520, 1030, 9003, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9521, 1030, 9004, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9522, 1030, 9005, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9551, 1031, 9037, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9552, 1031, 9038, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9553, 1031, 9039, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9563, 1031, 9049, 28);
INSERT INTO 'albumsrecordingsmap' VALUES (9564, 1031, 9050, 29);
INSERT INTO 'albumsrecordingsmap' VALUES (9565, 1031, 9051, 30);
INSERT INTO 'albumsrecordingsmap' VALUES (9573, 1033, 9059, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9574, 1033, 9060, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (371, 30, 402, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (372, 30, 403, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (373, 30, 404, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (374, 30, 405, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (375, 30, 406, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (376, 30, 407, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (377, 30, 408, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (378, 27, 220, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (379, 27, 321, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (380, 27, 375, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (381, 27, 376, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (382, 27, 377, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (383, 27, 409, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (384, 27, 410, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (385, 27, 411, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (386, 27, 412, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (387, 27, 413, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (388, 27, 414, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (389, 27, 415, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (390, 27, 416, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (391, 27, 417, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (392, 27, 419, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (393, 27, 420, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (394, 27, 421, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (395, 27, 422, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (396, 27, 423, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (397, 27, 424, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (398, 27, 425, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (399, 27, 426, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (400, 27, 427, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (401, 27, 428, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (402, 27, 429, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (403, 29, 430, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (404, 29, 431, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (405, 29, 432, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (406, 29, 433, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (407, 29, 434, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (408, 29, 435, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (409, 29, 436, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (410, 29, 437, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (411, 29, 438, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (412, 29, 439, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (413, 29, 440, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (414, 29, 441, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (415, 29, 442, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (416, 29, 443, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (417, 29, 444, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (418, 34, 455, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (426, 35, 467, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (427, 35, 468, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (428, 35, 469, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (429, 35, 470, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (430, 35, 471, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (431, 35, 472, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (432, 35, 473, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (433, 35, 474, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (434, 35, 475, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (435, 35, 476, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (436, 35, 477, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (437, 35, 478, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (438, 37, 496, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (439, 37, 497, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (440, 37, 498, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (441, 37, 499, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (442, 37, 500, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (443, 37, 501, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (444, 37, 502, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (445, 37, 503, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (446, 37, 504, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (447, 37, 505, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (448, 37, 506, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (449, 37, 507, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (450, 37, 508, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (451, 37, 509, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (452, 13, 510, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (453, 31, 418, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (454, 31, 511, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (455, 31, 512, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (456, 31, 513, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (457, 31, 514, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (458, 31, 515, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (459, 31, 516, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (460, 31, 517, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (461, 31, 518, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (462, 31, 519, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9336, 1018, 4150, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9337, 1018, 4149, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9338, 1018, 1736, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9370, 1020, 8883, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9410, 1023, 8924, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9411, 1023, 8925, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9412, 1023, 8926, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9506, 1029, 8989, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9507, 1029, 8990, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9554, 1031, 9040, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (9555, 1031, 9041, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (9556, 1031, 9042, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (9566, 1031, 9052, 31);
INSERT INTO 'albumsrecordingsmap' VALUES (9567, 1031, 9053, 32);
INSERT INTO 'albumsrecordingsmap' VALUES (9568, 1031, 9054, 33);
INSERT INTO 'albumsrecordingsmap' VALUES (9575, 1033, 9061, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9576, 1033, 9062, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9577, 1033, 9063, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9578, 1033, 9064, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9579, 1033, 9065, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9580, 1033, 9066, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9581, 1033, 9067, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9582, 1033, 9068, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9583, 1033, 9069, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9585, 1034, 9071, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9586, 1034, 9072, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9587, 1034, 9073, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9588, 1034, 9074, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9589, 1034, 9075, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9590, 1034, 9076, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9591, 1034, 9077, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9592, 1034, 9078, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9593, 1034, 9079, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9594, 1034, 9080, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9595, 1034, 9081, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9596, 1034, 9082, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9597, 1034, 9083, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9598, 1034, 9084, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9599, 1034, 9085, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9600, 1034, 9086, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9601, 1034, 9087, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9602, 1034, 9088, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9616, 1036, 9102, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9617, 1036, 9103, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9618, 1036, 9104, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9619, 1036, 9105, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9620, 1036, 9106, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9621, 1036, 9107, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9622, 1036, 9108, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9623, 1036, 9109, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9624, 1036, 9110, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10753, 1110, 10159, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9625, 1036, 9111, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9626, 1036, 9112, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9627, 1036, 9113, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9629, 1037, 9115, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9630, 1037, 9116, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9631, 1037, 9117, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9632, 1037, 9118, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9633, 1037, 9119, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9634, 1037, 9120, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9635, 1037, 9121, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9636, 1037, 9122, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9637, 1037, 9123, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9638, 1037, 9124, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9639, 1037, 9125, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9640, 1037, 9126, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9641, 1037, 9127, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9642, 1037, 9128, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9643, 1037, 9129, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9644, 1037, 9130, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9645, 1037, 9131, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9646, 1037, 9132, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9649, 1038, 536, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9650, 1038, 2512, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9651, 1038, 9135, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9652, 1038, 9136, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9653, 1038, 9137, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9654, 1038, 9138, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9658, 1038, 9142, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (463, 31, 520, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (464, 31, 521, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (465, 31, 522, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (466, 31, 523, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (467, 33, 524, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (468, 33, 525, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (469, 33, 526, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (470, 33, 527, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (471, 33, 528, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (472, 33, 529, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (473, 33, 531, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (474, 33, 533, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (475, 33, 534, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (476, 33, 537, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (477, 38, 538, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (478, 38, 539, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (479, 38, 540, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (480, 38, 541, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (481, 38, 542, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (482, 38, 543, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (483, 38, 544, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (484, 38, 545, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (485, 38, 546, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (486, 38, 547, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (487, 38, 548, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (488, 38, 549, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (489, 38, 550, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (490, 38, 551, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (491, 39, 552, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (492, 39, 553, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (493, 39, 554, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (494, 39, 555, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (495, 39, 556, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (496, 39, 557, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (497, 39, 558, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (498, 39, 559, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (499, 39, 560, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (500, 39, 561, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (501, 39, 562, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (502, 39, 563, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (503, 39, 564, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (504, 39, 565, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (505, 39, 566, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (506, 39, 567, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (507, 39, 568, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (508, 39, 569, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (509, 39, 570, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (510, 39, 571, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (511, 40, 572, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (512, 40, 573, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (513, 40, 574, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (514, 40, 575, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (515, 40, 576, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (516, 40, 577, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (517, 40, 578, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (518, 40, 579, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (519, 40, 580, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (520, 40, 581, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (521, 40, 582, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (522, 40, 583, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (523, 40, 584, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (524, 41, 34, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (525, 41, 214, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (526, 41, 8, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (527, 41, 585, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (528, 41, 586, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (529, 41, 587, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (530, 41, 588, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (531, 41, 589, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (532, 41, 128, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (533, 42, 590, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (534, 42, 591, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (535, 42, 592, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (536, 42, 593, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (537, 42, 594, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (538, 42, 595, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (539, 42, 596, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (540, 42, 597, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (541, 42, 598, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (542, 42, 599, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (543, 42, 600, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (544, 42, 601, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (545, 42, 194, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (546, 43, 602, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (547, 43, 603, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (548, 43, 104, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (549, 43, 604, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (550, 43, 605, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (551, 43, 177, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (552, 43, 607, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (553, 43, 608, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (554, 43, 609, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (555, 43, 610, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (556, 43, 611, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (557, 43, 612, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (558, 44, 267, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (559, 44, 614, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (560, 44, 152, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (561, 44, 615, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (562, 44, 616, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (563, 44, 617, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (564, 44, 618, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (565, 44, 619, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (566, 45, 620, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (567, 45, 621, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (568, 45, 622, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (569, 45, 623, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (570, 45, 624, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (571, 45, 625, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (572, 45, 626, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9413, 1023, 8927, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9414, 1023, 8928, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9415, 1023, 8929, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9557, 1031, 9043, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (9558, 1031, 9044, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (9559, 1031, 9045, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (9584, 1033, 9070, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10758, 1110, 10164, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10827, 1114, 10233, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9628, 1036, 9114, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9647, 1037, 9133, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (9648, 1037, 9134, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (9655, 1038, 9139, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9656, 1038, 9140, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9657, 1038, 9141, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9659, 1038, 9143, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9660, 1038, 9144, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (573, 45, 627, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (574, 45, 628, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (575, 45, 629, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (576, 45, 630, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (577, 46, 97, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (578, 46, 91, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (579, 46, 21, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (580, 46, 631, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (581, 46, 155, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (582, 46, 286, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (583, 46, 362, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (584, 46, 161, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (585, 46, 116, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (586, 47, 84, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (587, 47, 14, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (588, 47, 46, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (589, 47, 45, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (590, 47, 366, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (591, 47, 632, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (592, 47, 633, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (593, 47, 634, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (594, 47, 635, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (595, 48, 636, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (596, 48, 637, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (597, 48, 638, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (598, 48, 639, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (599, 48, 640, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (600, 48, 641, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (601, 48, 642, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10828, 1114, 10234, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (602, 48, 643, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (603, 48, 644, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (604, 48, 645, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (605, 48, 646, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (606, 49, 18, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (607, 49, 70, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (608, 49, 39, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (609, 49, 224, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (610, 49, 647, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (611, 49, 648, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (612, 49, 649, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (613, 49, 650, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (614, 49, 651, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (615, 49, 652, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (616, 49, 653, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (617, 49, 654, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (618, 50, 655, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (619, 50, 656, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (620, 50, 657, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (621, 50, 658, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (622, 50, 659, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (623, 50, 660, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (624, 50, 661, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (625, 50, 662, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (626, 51, 663, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (627, 51, 664, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (628, 51, 665, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (629, 51, 666, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (630, 51, 667, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (631, 51, 668, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (632, 51, 669, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (633, 51, 670, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (634, 51, 671, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (635, 51, 672, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (636, 51, 673, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (637, 51, 674, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (638, 51, 675, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (639, 51, 676, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (640, 51, 677, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (641, 52, 678, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (642, 52, 679, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (643, 52, 680, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (644, 52, 681, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (645, 52, 682, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (646, 52, 683, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (647, 52, 684, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (648, 52, 685, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (649, 52, 686, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (650, 52, 687, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (651, 53, 688, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (652, 53, 689, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (653, 53, 690, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (654, 53, 691, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (655, 53, 692, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (656, 53, 693, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (657, 53, 694, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (658, 53, 695, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (659, 53, 696, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (660, 53, 697, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (661, 53, 698, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (662, 53, 699, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (663, 53, 700, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (664, 54, 147, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9661, 1038, 9145, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9662, 1038, 9146, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9663, 1038, 9147, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9710, 1040, 9194, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9711, 1040, 9195, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9712, 1040, 9196, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9716, 1040, 9200, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9717, 1040, 9201, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9718, 1040, 9202, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9725, 1040, 9209, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9726, 1040, 9210, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9727, 1040, 9211, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9728, 1040, 9212, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (9729, 1040, 9213, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (9730, 1040, 9214, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (9733, 1041, 9217, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9734, 1041, 9218, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9735, 1041, 9219, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9736, 1041, 9220, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9737, 1041, 9221, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9738, 1041, 9222, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9739, 1041, 9223, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9740, 1041, 9224, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9741, 1041, 9225, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9745, 1041, 9229, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9746, 1041, 9230, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9747, 1041, 9231, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9748, 1041, 9232, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9749, 1041, 9233, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9750, 1042, 9234, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9751, 1042, 9235, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9752, 1042, 9236, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9753, 1042, 9237, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9754, 1042, 9238, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9758, 1042, 9242, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9759, 1042, 9243, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9760, 1042, 9244, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9761, 1042, 9245, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9762, 1042, 9246, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9763, 1042, 9247, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9767, 1043, 9251, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9768, 1043, 9252, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9769, 1043, 9253, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9770, 1043, 9254, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9771, 1043, 9255, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9772, 1043, 8663, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9773, 1043, 9256, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9774, 1043, 9257, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9775, 1043, 9258, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9778, 1044, 2589, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9779, 1044, 2593, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9780, 1044, 2594, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9790, 1045, 2261, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9791, 1045, 2407, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9792, 1045, 2259, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9805, 1046, 2684, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9806, 1046, 1730, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9807, 1046, 3057, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9820, 1047, 9261, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9821, 1047, 9262, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9822, 1047, 9263, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (665, 54, 154, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (666, 54, 702, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (667, 54, 150, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (668, 54, 703, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (669, 54, 704, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (670, 54, 705, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (671, 54, 706, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (672, 54, 707, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (673, 55, 708, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (674, 55, 709, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (675, 55, 710, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (676, 55, 711, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (677, 55, 712, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (678, 55, 713, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (679, 55, 714, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (680, 55, 715, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (681, 56, 228, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (682, 56, 188, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (683, 56, 105, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (684, 56, 333, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (685, 56, 717, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (686, 56, 718, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (687, 56, 719, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (688, 56, 720, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (696, 58, 729, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (697, 58, 730, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (698, 58, 731, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (699, 58, 732, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (700, 58, 733, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (701, 58, 734, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (702, 59, 606, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (703, 59, 721, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (704, 59, 353, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (705, 59, 202, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (706, 59, 136, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (707, 59, 735, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (708, 59, 736, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (709, 60, 737, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (710, 60, 738, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (711, 60, 739, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (712, 60, 740, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (713, 60, 741, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (714, 60, 742, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (715, 60, 743, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (716, 60, 744, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (717, 61, 745, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (718, 61, 746, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (719, 61, 747, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (720, 61, 748, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (721, 61, 749, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (722, 61, 750, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (723, 61, 751, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (724, 61, 752, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (725, 61, 753, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (726, 61, 754, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (727, 62, 755, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (728, 62, 756, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (729, 62, 757, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (730, 62, 758, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (731, 62, 759, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (732, 62, 760, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (733, 62, 761, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (734, 62, 762, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (735, 62, 763, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (736, 62, 764, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (737, 62, 765, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (738, 62, 766, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (739, 62, 767, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (740, 63, 768, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (741, 63, 770, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (742, 63, 771, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (743, 63, 772, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (744, 63, 773, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (745, 63, 774, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (746, 63, 775, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (747, 63, 41, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (748, 63, 186, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (749, 63, 777, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (750, 63, 778, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (751, 64, 613, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (752, 64, 716, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (753, 64, 728, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (754, 64, 785, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (755, 65, 786, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (756, 65, 787, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (757, 65, 788, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9664, 1038, 9148, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9665, 1038, 9149, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9666, 1038, 9150, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9713, 1040, 9197, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9714, 1040, 9198, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9715, 1040, 9199, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9719, 1040, 9203, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9720, 1040, 9204, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9721, 1040, 9205, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9731, 1040, 9215, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (9732, 1040, 9216, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (9742, 1041, 9226, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9743, 1041, 9227, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9744, 1041, 9228, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9755, 1042, 9239, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9756, 1042, 9240, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9757, 1042, 9241, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9764, 1042, 9248, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9765, 1042, 9249, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9766, 1042, 9250, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9776, 1043, 9259, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9777, 1043, 9260, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9781, 1044, 2597, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9782, 1044, 2586, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9783, 1044, 2595, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9793, 1045, 2590, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9794, 1045, 2411, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9795, 1045, 2588, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9808, 1046, 3792, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9809, 1046, 3063, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9810, 1046, 3790, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9823, 1047, 9264, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9824, 1047, 9265, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9825, 1047, 9266, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (758, 65, 789, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (759, 65, 790, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (760, 65, 791, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (761, 66, 113, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (762, 66, 795, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (763, 66, 769, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (764, 66, 152, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (765, 66, 72, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (766, 66, 796, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (767, 66, 278, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (768, 66, 181, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (769, 66, 88, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (770, 66, 331, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (771, 66, 169, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (772, 66, 218, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (773, 66, 797, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (774, 66, 798, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (779, 67, 445, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (780, 67, 446, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (781, 67, 447, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (782, 67, 448, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (783, 67, 449, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (784, 67, 450, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (785, 67, 451, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (786, 67, 452, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (787, 68, 799, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (788, 68, 800, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (789, 68, 801, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (790, 68, 802, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (791, 68, 803, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (792, 68, 804, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (793, 68, 805, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (794, 68, 806, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (795, 69, 807, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (796, 69, 337, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (797, 69, 169, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (798, 69, 157, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (799, 69, 808, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (800, 69, 809, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (801, 69, 810, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (802, 69, 811, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (803, 69, 812, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (804, 69, 813, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (805, 69, 814, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (806, 69, 815, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (807, 20, 792, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (808, 20, 661, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (809, 20, 658, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (810, 20, 449, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (811, 20, 447, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (812, 20, 445, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (813, 20, 793, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (814, 20, 455, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (815, 70, 816, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (816, 70, 817, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (817, 70, 818, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (818, 70, 819, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (819, 70, 820, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (820, 70, 821, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (821, 70, 822, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (822, 70, 823, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (823, 70, 824, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (824, 70, 825, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (825, 70, 826, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (826, 70, 827, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (827, 70, 828, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (828, 70, 829, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (829, 70, 830, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (775, 34, 50, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (776, 34, 88, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (777, 34, 72, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (778, 34, 345, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (830, 71, 832, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (831, 71, 833, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (832, 71, 834, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (833, 71, 835, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (834, 71, 836, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (835, 71, 837, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (836, 71, 838, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (837, 71, 839, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (838, 71, 840, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (839, 71, 841, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (840, 71, 842, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (841, 71, 843, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (842, 71, 844, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (843, 72, 845, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (844, 72, 846, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (845, 72, 847, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (846, 72, 848, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (847, 72, 849, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (848, 72, 850, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (849, 72, 851, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9722, 1040, 9206, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9723, 1040, 9207, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9724, 1040, 9208, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9784, 1044, 2590, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9785, 1044, 2592, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9786, 1044, 2596, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9796, 1045, 2408, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9797, 1045, 2263, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9798, 1045, 2410, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9811, 1046, 149, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9812, 1046, 3781, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9813, 1046, 3059, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9826, 1047, 9269, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9827, 1047, 9270, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9828, 1047, 9271, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9832, 1047, 9275, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9833, 1047, 9276, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9834, 1047, 9277, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9835, 1047, 9278, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9836, 1047, 9279, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9837, 1047, 9280, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9838, 1047, 9281, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (9839, 1047, 9282, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (9840, 1047, 9283, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (9841, 1047, 9284, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (9842, 1047, 9285, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (9843, 1048, 9286, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9844, 1048, 9287, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9845, 1048, 9288, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9847, 1048, 9290, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9848, 1048, 9291, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9849, 1048, 9292, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9850, 1048, 9293, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9851, 1048, 9294, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9852, 1048, 9295, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9853, 1048, 9296, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9854, 1048, 9297, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9855, 1048, 8830, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9856, 1048, 9299, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9857, 1048, 9300, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9858, 1048, 9301, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9859, 1049, 4054, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9860, 1049, 4056, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9861, 1049, 4057, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10829, 1114, 10235, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (850, 72, 852, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (851, 72, 853, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (852, 72, 854, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (853, 72, 855, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (854, 72, 856, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (855, 73, 857, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (856, 73, 858, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (857, 73, 859, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (858, 73, 860, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (859, 73, 861, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (860, 73, 862, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (861, 73, 863, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (862, 73, 864, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (863, 73, 865, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (864, 73, 866, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (865, 73, 867, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (866, 73, 868, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (867, 73, 869, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (868, 73, 870, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (869, 74, 12, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (870, 74, 71, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (871, 74, 89, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (872, 74, 242, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (873, 74, 249, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (874, 74, 252, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (875, 74, 274, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (876, 74, 352, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (877, 74, 367, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (878, 74, 372, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (879, 74, 456, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (880, 75, 459, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (881, 75, 461, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (882, 75, 466, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (883, 75, 871, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (884, 75, 872, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (885, 75, 873, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (886, 75, 874, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (887, 75, 875, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (888, 75, 876, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (889, 75, 877, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (890, 75, 878, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (891, 75, 879, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (892, 76, 880, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (893, 76, 881, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (894, 76, 882, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (895, 76, 883, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (896, 76, 884, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (897, 76, 885, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (898, 76, 886, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (899, 76, 887, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (900, 76, 888, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (901, 76, 889, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (902, 76, 890, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (903, 76, 891, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (904, 76, 892, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10830, 1114, 10236, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10759, 1110, 10165, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10760, 1110, 10166, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10831, 1114, 10237, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (933, 79, 290, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (934, 79, 923, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (938, 80, 200, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (939, 80, 350, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (940, 80, 117, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (941, 80, 167, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (942, 80, 795, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9787, 1044, 2591, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9788, 1044, 3415, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9789, 1044, 2588, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9799, 1045, 2596, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9800, 1045, 2409, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9801, 1045, 2257, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9814, 1046, 4153, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9815, 1046, 3780, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9816, 1046, 3062, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9829, 1047, 9272, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9830, 1047, 9273, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9831, 1047, 9274, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9697, 1039, 9181, 31);
INSERT INTO 'albumsrecordingsmap' VALUES (9698, 1039, 9182, 32);
INSERT INTO 'albumsrecordingsmap' VALUES (9699, 1039, 9183, 33);
INSERT INTO 'albumsrecordingsmap' VALUES (9700, 1039, 9184, 34);
INSERT INTO 'albumsrecordingsmap' VALUES (9701, 1039, 9185, 35);
INSERT INTO 'albumsrecordingsmap' VALUES (9702, 1039, 9186, 36);
INSERT INTO 'albumsrecordingsmap' VALUES (9709, 1039, 9193, 43);
INSERT INTO 'albumsrecordingsmap' VALUES (9846, 1048, 9289, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9862, 1049, 4055, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9863, 1049, 4058, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9864, 1049, 4059, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10903, 1121, 1361, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10904, 1121, 1362, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10905, 1121, 207, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (943, 80, 927, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (944, 80, 928, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (945, 80, 929, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (946, 80, 930, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (947, 80, 931, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (948, 80, 932, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (949, 80, 933, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (950, 81, 934, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (951, 81, 935, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (952, 81, 936, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (953, 81, 937, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (954, 81, 938, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (955, 81, 939, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (956, 81, 940, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (957, 81, 941, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (958, 81, 942, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (959, 81, 943, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (960, 81, 944, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (961, 81, 945, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (962, 81, 946, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (963, 81, 903, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (964, 81, 905, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (965, 32, 914, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (966, 32, 919, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (967, 32, 921, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (968, 32, 947, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (969, 32, 948, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (970, 32, 949, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (971, 32, 950, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (972, 32, 951, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (973, 32, 952, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (974, 32, 953, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (975, 32, 954, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (976, 53, 174, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (977, 36, 487, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (978, 36, 701, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (979, 36, 955, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (980, 36, 956, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (981, 36, 957, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (982, 36, 958, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (983, 36, 959, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (984, 36, 960, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (985, 36, 961, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9872, 1050, 9302, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9873, 1050, 9303, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9874, 1050, 9304, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9875, 1050, 9305, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9876, 1050, 9306, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9877, 1050, 9307, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9878, 1050, 9308, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9879, 1050, 9309, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9880, 1050, 9310, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (905, 77, 831, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (906, 77, 893, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (907, 77, 894, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (908, 77, 895, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (909, 77, 896, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (910, 77, 897, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (911, 77, 898, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (912, 77, 899, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (913, 77, 900, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (914, 77, 901, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (915, 77, 902, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (986, 36, 962, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (987, 36, 963, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (988, 82, 380, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (989, 82, 964, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (990, 82, 965, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (991, 82, 966, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (992, 82, 967, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (993, 82, 968, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (994, 82, 969, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (995, 82, 970, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (996, 82, 971, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (997, 82, 972, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (998, 82, 973, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (999, 82, 974, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1000, 82, 975, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1001, 82, 976, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1002, 83, 977, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1003, 83, 978, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1004, 83, 979, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1005, 83, 980, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1006, 83, 981, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1007, 83, 982, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1008, 83, 983, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1009, 83, 984, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1010, 83, 985, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1011, 83, 986, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1012, 83, 987, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1013, 83, 988, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1014, 83, 989, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1015, 83, 990, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1016, 83, 991, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (1017, 84, 454, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1018, 84, 992, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1019, 84, 993, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1020, 84, 994, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1021, 84, 995, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1022, 84, 996, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1023, 84, 997, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1024, 84, 998, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1025, 84, 999, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1026, 84, 1000, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1027, 84, 1001, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1028, 84, 1002, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1029, 84, 1003, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1030, 23, 1004, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1048, 86, 1022, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1049, 86, 1023, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1050, 86, 1024, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1051, 86, 1025, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1052, 86, 1026, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1053, 86, 1027, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1054, 86, 1028, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1055, 86, 1029, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1056, 86, 1030, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1057, 86, 1031, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1058, 87, 1035, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1059, 87, 1036, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1060, 87, 1037, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1061, 87, 1038, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9802, 1045, 2405, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9803, 1045, 2591, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9804, 1045, 2260, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9817, 1046, 3789, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9818, 1046, 4154, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9819, 1046, 3061, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9865, 1049, 4047, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9866, 1049, 4048, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9867, 1049, 4049, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1062, 87, 1039, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1063, 87, 1040, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1064, 87, 1041, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1065, 88, 1042, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1066, 88, 1043, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1067, 88, 1044, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1068, 88, 1045, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1069, 88, 1046, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1070, 88, 1047, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1071, 88, 1048, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1072, 88, 1049, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1073, 88, 1050, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1074, 88, 1051, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1075, 88, 1052, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1076, 88, 1053, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1077, 88, 1054, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1078, 88, 1055, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1079, 88, 1056, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (1080, 88, 1057, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (1081, 88, 1058, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (1082, 88, 1059, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (1083, 88, 1060, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (1084, 88, 1061, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (1085, 88, 1062, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (1086, 89, 1063, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1087, 89, 1064, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1088, 89, 1065, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1089, 89, 1066, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1090, 89, 1068, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1091, 89, 1071, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1092, 89, 1072, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1093, 89, 1073, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1094, 89, 1075, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1095, 89, 1076, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (1096, 89, 1077, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (1097, 90, 1078, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1098, 90, 1079, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1099, 90, 1080, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1100, 90, 1081, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1101, 90, 1082, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1102, 90, 1083, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1103, 90, 1084, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1104, 90, 1085, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1105, 90, 1086, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1106, 90, 1087, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1107, 90, 1088, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1108, 90, 1089, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1109, 90, 1090, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1110, 90, 1091, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1111, 90, 1092, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (1112, 92, 1093, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1113, 92, 1094, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1114, 92, 1095, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1115, 92, 1096, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1116, 92, 1097, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1117, 92, 1098, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1118, 92, 1099, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1119, 92, 1100, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1120, 92, 1101, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1121, 92, 1102, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1122, 92, 1103, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1123, 92, 1104, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10754, 1110, 10160, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10755, 1110, 10161, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10756, 1110, 10162, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10757, 1110, 10163, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1140, 94, 1121, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1141, 94, 1122, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1142, 94, 1123, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1143, 94, 1124, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1144, 94, 1125, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1145, 94, 1126, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1146, 94, 1127, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1147, 94, 1128, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1148, 94, 1129, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1149, 96, 1138, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1150, 96, 1139, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1151, 96, 1140, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1152, 96, 1141, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1153, 96, 1142, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9868, 1049, 4050, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9869, 1049, 4051, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9870, 1049, 4052, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1154, 96, 1143, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1155, 96, 1144, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1156, 96, 1145, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9887, 1050, 9317, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9888, 1050, 9318, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10761, 1110, 10167, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10762, 1110, 10168, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1157, 97, 1146, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1158, 97, 1147, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1159, 97, 1148, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1160, 97, 1149, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1161, 97, 1150, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1162, 97, 1151, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1163, 97, 1152, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1164, 97, 1153, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1165, 97, 1154, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1166, 97, 1155, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1167, 97, 1156, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1168, 97, 1157, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1169, 99, 1169, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1170, 99, 1170, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1171, 99, 1171, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1172, 99, 1172, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1173, 99, 1173, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1174, 99, 1174, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1175, 99, 1175, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1176, 99, 1176, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1177, 99, 1177, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1178, 100, 1178, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1179, 100, 1179, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1180, 100, 1180, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1181, 100, 1181, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1182, 100, 1182, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1183, 100, 1183, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1184, 100, 1184, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1185, 100, 1185, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1186, 100, 1186, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1187, 100, 1187, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1188, 100, 1188, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1189, 100, 1189, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1190, 100, 1190, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1191, 100, 1191, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1192, 100, 1192, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (1193, 100, 1193, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (1194, 100, 1194, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (1195, 100, 1195, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (1196, 101, 1196, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1197, 101, 1197, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1198, 101, 1198, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1199, 101, 1199, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1200, 101, 1200, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1201, 101, 1201, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1202, 101, 1202, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1203, 101, 1203, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1204, 101, 1204, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1205, 101, 1205, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1206, 101, 1206, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1207, 101, 1207, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1208, 101, 1208, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1209, 101, 1209, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1210, 101, 1210, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (1211, 101, 1211, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (1212, 102, 1213, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1213, 102, 1214, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1214, 102, 1215, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1215, 102, 1216, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1216, 102, 1217, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1217, 102, 1218, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1218, 102, 1219, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1219, 102, 1221, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1220, 102, 1222, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1221, 102, 1224, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1222, 102, 1225, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (1223, 103, 1226, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1224, 103, 1227, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1225, 103, 1228, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1226, 103, 1229, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1227, 103, 1230, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1228, 103, 1231, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1229, 103, 1232, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1230, 103, 1233, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1231, 103, 1234, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1232, 103, 1235, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1233, 103, 1236, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1234, 104, 1237, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1235, 104, 1238, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1236, 104, 1239, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1237, 104, 1240, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1238, 104, 1241, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1239, 104, 1242, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1240, 104, 1243, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1241, 104, 1244, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1242, 104, 1245, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1243, 104, 1246, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1244, 104, 1247, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1245, 104, 1248, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1246, 105, 1249, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9871, 1049, 4053, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1247, 105, 1251, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1248, 105, 1252, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1249, 105, 1253, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1250, 105, 1254, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1251, 105, 1256, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1252, 105, 1257, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1253, 105, 1258, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1254, 105, 1259, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1255, 105, 1260, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1256, 106, 1261, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1257, 106, 1262, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1258, 106, 1263, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1259, 106, 1264, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1260, 106, 1265, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1261, 106, 1266, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1262, 106, 1267, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1263, 106, 1269, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1264, 106, 1270, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1265, 106, 1271, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1266, 106, 1272, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1267, 105, 113, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1268, 105, 266, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1269, 106, 250, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1270, 107, 1273, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1271, 107, 1274, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1272, 107, 1275, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1273, 107, 1276, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1274, 107, 1277, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1275, 107, 1278, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1276, 107, 1279, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1277, 107, 1280, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1278, 107, 1281, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1279, 108, 1282, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1280, 108, 1283, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1281, 108, 1284, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1282, 108, 1285, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1283, 108, 1286, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1284, 108, 797, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1285, 108, 1287, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1286, 108, 1288, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1287, 108, 1289, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1288, 108, 1290, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1289, 108, 1291, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1290, 108, 1292, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1291, 109, 1293, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1292, 109, 181, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1293, 109, 1294, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1294, 109, 1295, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1295, 109, 1296, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1296, 109, 1297, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1297, 109, 1298, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1298, 109, 1299, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1299, 109, 1300, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1300, 109, 1301, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1301, 109, 1302, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1302, 109, 1303, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1303, 110, 61, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1304, 110, 796, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1305, 110, 28, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1306, 110, 1304, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1307, 110, 1305, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1308, 110, 1306, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1309, 111, 236, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1310, 111, 62, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1311, 111, 233, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1312, 111, 346, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1313, 111, 347, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1314, 111, 1307, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1315, 111, 1308, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1316, 111, 1309, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1317, 111, 1310, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1318, 111, 1311, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1319, 111, 1312, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1320, 111, 1313, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1321, 112, 1314, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1322, 112, 1315, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1323, 112, 1316, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1324, 112, 1317, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1325, 112, 1318, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1326, 112, 1319, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1327, 112, 1320, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1328, 112, 1321, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1329, 112, 1322, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1330, 112, 1323, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1331, 112, 1324, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1332, 112, 1325, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1333, 113, 278, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1334, 113, 294, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1335, 113, 1326, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1336, 113, 1327, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1337, 113, 1328, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1338, 113, 1329, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1339, 113, 148, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1340, 113, 1330, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1341, 113, 1331, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1342, 113, 1332, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1343, 113, 1333, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1344, 113, 1334, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1345, 114, 1335, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1346, 114, 1336, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1347, 114, 1337, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1348, 114, 1338, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1349, 114, 234, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1350, 114, 1339, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1351, 114, 1340, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1352, 114, 57, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1353, 114, 1341, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1354, 114, 1342, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1355, 114, 1343, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1356, 114, 1344, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1357, 115, 453, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1358, 115, 1250, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1359, 115, 355, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1360, 115, 85, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1361, 115, 1255, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1362, 115, 1268, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1363, 115, 1345, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1364, 115, 1346, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1365, 115, 114, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1366, 115, 1347, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1367, 116, 1348, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1368, 116, 1349, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1369, 116, 1350, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1370, 116, 1351, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1371, 116, 1352, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1372, 116, 1353, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1373, 116, 112, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1374, 116, 1354, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1375, 116, 1355, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1376, 117, 64, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1377, 117, 53, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1378, 117, 193, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1379, 117, 257, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1380, 117, 9, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1381, 117, 1356, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1382, 117, 1357, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1383, 117, 1358, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1392, 119, 1363, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1393, 119, 1364, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1394, 119, 1365, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1395, 119, 1366, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1396, 119, 1367, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1397, 119, 1368, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1398, 119, 1369, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1399, 119, 1370, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1400, 119, 1371, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1401, 119, 1372, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1402, 119, 1373, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1403, 119, 1374, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1404, 120, 1375, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1405, 120, 1376, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1406, 120, 1377, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1407, 120, 1378, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1408, 120, 1380, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1409, 120, 1381, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1410, 120, 1382, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1411, 121, 1384, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1412, 121, 1385, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1413, 121, 1388, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1414, 121, 1389, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1415, 121, 1390, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1416, 122, 1392, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1417, 122, 1393, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1418, 122, 1395, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1419, 122, 1396, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1420, 122, 1397, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1421, 122, 1398, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1422, 122, 1399, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1423, 123, 1400, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1424, 123, 1401, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1425, 123, 1403, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1426, 123, 1404, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1427, 123, 1409, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1428, 120, 798, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1429, 121, 319, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1430, 121, 285, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1431, 121, 227, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1432, 122, 211, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1433, 122, 77, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1434, 123, 103, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1435, 123, 331, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1436, 123, 213, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1437, 123, 216, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1438, 23, 23, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1439, 18, 801, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1440, 23, 168, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1441, 18, 802, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1442, 24, 239, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1443, 125, 24, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1444, 125, 107, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1445, 125, 123, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1446, 125, 170, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1447, 125, 235, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1448, 125, 240, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1449, 125, 922, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1450, 125, 1383, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1451, 125, 1386, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1452, 125, 1387, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1453, 125, 1391, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1454, 125, 1394, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1455, 125, 1405, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1456, 125, 1406, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (1457, 125, 1407, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (1458, 95, 1136, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1459, 95, 1130, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1460, 95, 1137, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1461, 95, 1134, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1462, 95, 1132, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1463, 95, 1133, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1464, 95, 1131, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1465, 95, 1135, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1466, 206, 1410, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1467, 206, 1411, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1468, 206, 1412, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1469, 206, 1413, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1470, 206, 1414, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1471, 206, 1415, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1472, 206, 1416, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1473, 206, 1417, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1474, 206, 1418, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1475, 125, 1379, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1476, 155, 1419, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1477, 155, 1420, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1478, 155, 1421, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1479, 155, 1422, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1480, 155, 1423, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1481, 155, 1424, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1482, 155, 1425, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1483, 155, 1426, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1484, 166, 1427, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1485, 166, 1428, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1486, 166, 1429, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1487, 166, 1430, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1488, 166, 1431, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1489, 166, 1432, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1490, 166, 1433, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1491, 166, 1434, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1492, 166, 1435, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1493, 156, 1436, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1494, 156, 1437, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1495, 156, 1438, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1496, 156, 1439, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1497, 156, 1440, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1498, 156, 1441, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1499, 156, 1442, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1500, 156, 1443, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1501, 156, 1444, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1502, 204, 1445, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1503, 204, 1446, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1504, 204, 1447, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1505, 204, 1448, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1506, 204, 1449, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1507, 204, 1450, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1508, 204, 1452, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1509, 160, 1453, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1510, 160, 1454, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1511, 160, 1455, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1512, 160, 1456, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1513, 160, 1457, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1514, 160, 1458, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1515, 160, 1459, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1516, 160, 1460, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1517, 160, 1461, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1518, 160, 1462, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1519, 160, 1463, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1520, 160, 1464, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1521, 59, 1465, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1522, 165, 1466, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1523, 165, 1467, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1524, 165, 1469, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1525, 165, 1470, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1526, 165, 1471, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1527, 165, 1472, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1528, 165, 1473, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1529, 165, 1474, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1530, 165, 1475, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1531, 165, 1476, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1532, 165, 1477, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1533, 126, 1489, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1534, 126, 1490, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1535, 126, 1491, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1536, 126, 1492, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1537, 126, 1493, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1538, 126, 1494, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1539, 126, 1495, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1540, 240, 1496, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1541, 240, 1497, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1542, 240, 1498, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1543, 240, 1499, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1544, 240, 1500, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1545, 240, 1501, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1546, 240, 1502, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1547, 240, 1503, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1548, 240, 1504, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1549, 240, 1505, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1550, 240, 1506, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1551, 240, 1507, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1552, 240, 1508, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1553, 240, 1509, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1554, 176, 1510, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1555, 176, 1511, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1556, 176, 1512, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1557, 176, 1513, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1558, 176, 1514, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1559, 176, 1515, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1560, 176, 1516, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1561, 176, 1517, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1562, 176, 1518, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1563, 176, 1519, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1564, 176, 1520, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1565, 176, 1521, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1566, 176, 1522, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1567, 176, 1523, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1568, 194, 1524, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1569, 194, 1525, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1570, 194, 1526, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1571, 194, 1527, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1572, 194, 1528, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1573, 194, 1529, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1574, 194, 1530, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1575, 194, 1531, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1576, 185, 1532, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1577, 185, 1533, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1578, 185, 1534, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1579, 185, 1535, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1580, 185, 1536, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1581, 185, 1537, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1582, 185, 1538, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1583, 185, 1539, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1584, 185, 1540, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1585, 185, 1541, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1586, 141, 1542, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1587, 141, 1543, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1588, 141, 1544, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1589, 141, 1545, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1590, 141, 1546, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1591, 141, 1547, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1592, 141, 1548, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1593, 141, 1549, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1594, 141, 1550, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1595, 141, 1551, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1596, 148, 1552, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1597, 148, 1553, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1598, 148, 1554, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1599, 148, 1555, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1600, 148, 1556, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1601, 148, 1557, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1602, 148, 1558, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1603, 148, 1559, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1604, 148, 1560, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1605, 148, 1561, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1606, 148, 1562, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1607, 148, 1563, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1608, 148, 1564, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1609, 246, 1565, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1610, 246, 1566, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1611, 246, 1567, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1612, 246, 1568, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1613, 246, 1569, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1614, 246, 1570, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1615, 246, 1571, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1616, 246, 1572, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1617, 246, 1573, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1618, 246, 1574, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1619, 246, 1575, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1620, 246, 1576, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1621, 246, 1577, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1629, 247, 1594, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1630, 247, 1595, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1631, 247, 1596, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1632, 247, 1598, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1633, 247, 1599, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1634, 247, 1600, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1635, 247, 1601, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1636, 247, 1602, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1637, 174, 1603, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1638, 202, 1488, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1639, 202, 1579, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1640, 202, 1580, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1641, 202, 1581, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1642, 202, 1582, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1643, 202, 1583, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1644, 202, 1584, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1645, 202, 1586, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1646, 179, 1604, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1647, 179, 1605, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1648, 179, 1606, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1649, 179, 1607, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1650, 179, 1608, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1651, 179, 1609, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1652, 179, 1610, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1653, 179, 1611, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1665, 136, 1623, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1666, 136, 1624, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1667, 136, 1625, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1668, 136, 1626, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1669, 136, 1627, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1670, 136, 1628, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1671, 136, 1629, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1672, 136, 1630, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1673, 136, 1631, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1674, 136, 1632, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1675, 136, 1633, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1676, 136, 1634, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1677, 136, 1635, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1678, 242, 1636, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1679, 242, 1637, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1680, 242, 1638, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1681, 242, 1639, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1682, 242, 1640, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1683, 242, 1641, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1684, 242, 1642, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1685, 242, 1643, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1686, 242, 1644, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1687, 242, 1645, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1688, 232, 1646, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1689, 232, 1647, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1690, 232, 1648, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1691, 232, 1649, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1692, 232, 1650, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1693, 232, 1651, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1694, 232, 1652, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1695, 200, 1653, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1696, 200, 1654, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1697, 200, 1655, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1698, 200, 1656, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1699, 200, 1657, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1700, 200, 1658, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1701, 200, 1659, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1702, 200, 1660, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1703, 200, 1661, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1704, 200, 1662, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1705, 200, 1663, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1706, 200, 1664, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1707, 200, 1665, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1708, 200, 1666, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1709, 200, 1667, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (1710, 203, 1669, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1718, 171, 1677, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1719, 171, 1678, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1720, 171, 1679, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1721, 171, 1668, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1722, 171, 1680, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1723, 171, 1681, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1724, 171, 1682, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1725, 171, 1683, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1726, 171, 1684, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1727, 171, 1685, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1728, 171, 1686, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1729, 171, 1687, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1730, 182, 1688, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1731, 182, 1689, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1732, 182, 1690, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1733, 182, 1691, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1734, 182, 1692, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1735, 182, 1693, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1736, 182, 1694, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1737, 182, 1695, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1738, 236, 1696, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1739, 236, 1697, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1740, 236, 1698, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1741, 236, 1699, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1742, 236, 1700, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1743, 236, 1701, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1744, 236, 1702, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1745, 236, 1703, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1746, 236, 1704, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1747, 236, 1705, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1748, 170, 1717, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1749, 170, 1718, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1750, 170, 1719, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1751, 170, 1720, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1752, 170, 1721, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1753, 170, 1722, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1754, 170, 1723, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1755, 170, 1724, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1756, 170, 1725, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1757, 170, 1726, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1758, 170, 1727, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1759, 150, 1728, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1760, 150, 1729, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1761, 150, 1730, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1762, 150, 1731, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1763, 150, 1732, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1764, 150, 1733, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1765, 150, 1734, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1766, 150, 1735, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1767, 150, 1736, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1768, 150, 1737, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1769, 150, 1738, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1770, 150, 1739, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1771, 150, 1740, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1772, 150, 1741, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1773, 196, 1742, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1774, 196, 1743, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1775, 196, 1744, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1776, 196, 1745, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1777, 196, 1746, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1778, 196, 1747, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1779, 196, 1748, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1780, 196, 1749, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1781, 226, 1750, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1782, 226, 1751, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1783, 226, 1752, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1784, 226, 1753, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1785, 226, 1754, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1786, 226, 1755, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1787, 226, 1756, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1788, 226, 1757, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1789, 226, 1758, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1790, 226, 1759, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1791, 226, 1760, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1792, 226, 1761, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1793, 216, 1762, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1794, 216, 1763, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1795, 216, 1764, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1796, 216, 1765, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1797, 216, 1766, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1798, 216, 1767, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1799, 216, 1768, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1800, 216, 1769, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1801, 191, 1770, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1802, 191, 1771, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1803, 191, 1772, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1804, 191, 1773, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1805, 191, 1774, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1806, 191, 1775, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1807, 191, 1776, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1808, 191, 1777, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1809, 137, 1778, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1810, 137, 1779, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1811, 137, 1780, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1812, 137, 1781, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1813, 137, 1782, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1814, 137, 1783, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1815, 137, 1784, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1816, 137, 1785, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1817, 137, 1786, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1818, 137, 1787, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1819, 138, 1788, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1820, 138, 1789, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1821, 138, 1790, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1822, 138, 1791, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1823, 138, 1792, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1824, 138, 1793, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1825, 138, 1794, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1826, 138, 1795, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1827, 238, 1796, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1828, 238, 1797, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1829, 238, 1798, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1830, 238, 1799, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1831, 238, 1800, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1832, 238, 1801, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1833, 238, 1802, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1834, 238, 1803, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1835, 238, 1804, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1844, 230, 1813, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1845, 230, 1814, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1846, 230, 1815, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1847, 230, 1816, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1848, 230, 1817, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1849, 230, 1818, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1850, 230, 1819, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1851, 230, 1820, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1852, 230, 1821, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1853, 230, 1822, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1854, 192, 1823, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1855, 192, 1824, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1856, 192, 1825, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1857, 192, 1826, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1858, 192, 1827, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1859, 192, 1828, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1860, 192, 1829, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1861, 192, 1830, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1862, 192, 1831, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1863, 192, 1832, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1864, 192, 1833, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1865, 192, 1834, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1866, 192, 1835, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1867, 192, 1836, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1868, 192, 1837, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (1869, 181, 1838, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1870, 181, 1839, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1871, 181, 1840, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1872, 181, 1841, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1873, 181, 1842, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1874, 181, 1843, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1875, 181, 1844, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1876, 181, 1845, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1877, 181, 1846, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1878, 181, 1847, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1879, 181, 1848, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1880, 181, 1849, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1890, 218, 1859, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1891, 218, 1860, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1892, 218, 1861, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1893, 218, 1862, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1894, 218, 1863, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1895, 218, 1864, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1896, 218, 1865, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1897, 218, 1866, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1898, 139, 1867, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1899, 139, 1868, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1900, 139, 1869, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1901, 139, 1870, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1902, 139, 1871, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1903, 139, 1872, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1904, 139, 1873, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1905, 139, 1874, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1906, 139, 1875, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1907, 139, 1876, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1908, 138, 1877, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1909, 220, 1878, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1910, 220, 1879, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1911, 220, 1880, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1912, 220, 1881, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1913, 220, 1882, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1914, 220, 1883, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1915, 220, 1884, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1916, 220, 1885, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1917, 220, 1886, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1918, 223, 1887, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1919, 223, 1888, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1920, 223, 1889, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1921, 223, 1890, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1922, 223, 1891, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1923, 223, 1892, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1924, 223, 1893, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1925, 223, 1894, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1926, 205, 1895, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1927, 205, 1896, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1928, 205, 1897, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1929, 205, 1898, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1930, 205, 1899, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1931, 205, 1900, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1932, 205, 1901, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1933, 205, 1902, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1934, 205, 1903, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1935, 205, 1904, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1936, 205, 1905, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1937, 205, 1906, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1938, 205, 1907, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1939, 205, 1908, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1940, 128, 1909, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1941, 128, 1910, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1942, 128, 1911, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1943, 128, 1912, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1944, 128, 1913, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1945, 128, 1914, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1946, 128, 1915, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1947, 128, 1916, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1948, 128, 1917, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1949, 128, 1918, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1950, 128, 1919, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1951, 128, 1920, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1952, 128, 1921, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1953, 197, 1922, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1954, 197, 1923, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1955, 197, 1924, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1956, 197, 1925, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1957, 197, 1926, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1958, 197, 1927, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1959, 197, 1928, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1960, 197, 1929, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1961, 197, 1930, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1962, 197, 1931, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1963, 197, 1933, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1964, 197, 1934, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1881, 167, 1850, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1882, 167, 1851, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1883, 167, 1852, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1884, 167, 1853, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1885, 167, 1854, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1886, 167, 1855, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1887, 167, 1856, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1965, 197, 1935, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1966, 129, 1936, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1967, 129, 1937, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1968, 129, 1938, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1969, 129, 1939, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1970, 129, 1940, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1971, 129, 1941, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1972, 129, 1942, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1973, 129, 1943, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1974, 129, 1944, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1975, 129, 1945, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1976, 129, 1946, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1977, 129, 1947, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1978, 158, 1948, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1979, 158, 1949, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1980, 158, 1950, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1981, 158, 1951, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1982, 158, 1952, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1983, 158, 1953, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1984, 225, 1954, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (1985, 225, 1955, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1986, 225, 1957, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1987, 225, 1959, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1988, 225, 1960, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1989, 225, 1962, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1990, 225, 1963, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1991, 225, 1965, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1992, 225, 1966, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1993, 132, 1969, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1994, 132, 1970, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1995, 132, 1971, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1996, 132, 1972, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1997, 132, 1973, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1998, 132, 1974, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1999, 132, 1975, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2000, 132, 1976, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2001, 132, 1977, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2002, 132, 1978, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2003, 132, 1979, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2004, 132, 1980, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2005, 132, 1981, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2006, 132, 1982, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2007, 127, 1983, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2008, 127, 1984, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2009, 127, 1985, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2010, 127, 1986, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2011, 127, 1987, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2012, 127, 1988, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2013, 127, 1989, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2014, 127, 1990, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2015, 127, 1991, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2016, 127, 1992, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2017, 127, 1993, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2018, 153, 1994, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2019, 153, 1995, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2020, 153, 1996, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2021, 153, 1997, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2022, 153, 1998, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2023, 153, 1999, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2024, 153, 2000, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2025, 153, 2001, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2026, 153, 2002, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2027, 153, 2003, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2028, 212, 2004, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2029, 212, 2005, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2030, 212, 2006, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2031, 212, 2007, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2032, 212, 2008, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2033, 212, 2009, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2034, 212, 2010, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2035, 212, 2011, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2036, 212, 2012, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2037, 212, 2013, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2038, 212, 2014, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2039, 212, 2015, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2040, 183, 2016, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2041, 183, 2017, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2042, 183, 2018, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2043, 183, 2019, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2044, 183, 2020, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2045, 183, 2021, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2046, 183, 2022, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2047, 183, 2023, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2048, 183, 2024, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2049, 183, 2025, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2050, 183, 2026, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2051, 183, 2027, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2052, 183, 2028, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2053, 193, 2030, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2054, 193, 2031, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2055, 193, 2032, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2056, 193, 2033, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2057, 193, 2035, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2058, 193, 2036, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2059, 193, 2039, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2060, 193, 2040, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2061, 193, 2042, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2062, 143, 2043, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2063, 143, 2044, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2064, 143, 2045, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2065, 143, 2046, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2066, 143, 2047, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2067, 143, 2048, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2068, 143, 2049, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2069, 143, 2050, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2070, 143, 2051, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2071, 143, 2052, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2072, 87, 2053, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2073, 87, 2054, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2074, 87, 2055, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2075, 189, 2056, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2076, 189, 2057, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2077, 189, 2058, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2078, 189, 2059, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2079, 189, 2060, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2080, 189, 2061, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2081, 189, 2062, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2082, 189, 2063, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2083, 189, 2064, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2084, 189, 2065, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2085, 189, 2066, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2086, 189, 2067, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2087, 189, 2068, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2088, 189, 2069, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (2089, 189, 2070, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (2090, 189, 2071, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (2091, 189, 2072, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (2092, 210, 2073, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2093, 210, 2074, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2094, 210, 2075, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2095, 210, 2076, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2096, 210, 2077, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2097, 210, 2078, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2098, 210, 2079, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2099, 210, 2080, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2100, 210, 2081, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2101, 210, 2082, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2102, 210, 2083, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2103, 221, 2084, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2104, 221, 2085, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2105, 221, 2086, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2106, 221, 2087, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2107, 221, 2088, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2108, 221, 2089, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2109, 221, 2090, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2110, 221, 2091, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2111, 239, 2092, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2112, 239, 2093, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2113, 239, 2094, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2114, 239, 2095, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2115, 239, 2096, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2116, 239, 2097, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2117, 239, 2098, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2118, 239, 2099, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2119, 239, 2100, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2120, 239, 2101, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2121, 239, 2102, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2122, 239, 2103, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2123, 239, 2104, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2124, 239, 2105, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2125, 239, 2106, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (2126, 243, 2107, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2127, 243, 2108, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2128, 243, 2109, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2129, 243, 2110, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2130, 243, 2111, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2131, 243, 2112, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2132, 243, 2113, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2133, 243, 2114, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2134, 243, 2115, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2135, 243, 2116, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2136, 243, 2117, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2137, 243, 2118, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2138, 243, 2119, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2139, 243, 2120, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2140, 190, 2121, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2141, 190, 2122, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2142, 190, 2123, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2143, 190, 2124, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2144, 190, 2125, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2145, 190, 2126, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2146, 190, 2127, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2147, 190, 2128, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2148, 190, 2129, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2149, 190, 2130, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2150, 190, 2131, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2151, 190, 2132, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2152, 190, 2133, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2153, 190, 2134, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2154, 228, 2135, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2155, 228, 2136, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2156, 228, 2137, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2157, 228, 2138, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2158, 228, 2139, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2159, 228, 2140, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2160, 228, 2141, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2161, 228, 2142, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2162, 228, 2143, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2163, 228, 2144, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2164, 228, 2145, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2165, 228, 2146, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2166, 228, 2147, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2167, 228, 2148, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2168, 201, 73, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2169, 201, 100, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2170, 201, 153, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2171, 201, 163, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2172, 201, 343, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2173, 201, 94, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2174, 201, 129, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2175, 201, 134, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2176, 201, 1117, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2177, 130, 2151, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2178, 130, 2152, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2179, 130, 2153, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2180, 130, 2154, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2181, 130, 2155, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2182, 130, 2156, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2183, 130, 2157, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2184, 130, 2158, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2185, 130, 2159, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2186, 130, 2160, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2187, 130, 2161, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2188, 152, 2162, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2189, 152, 2163, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2190, 152, 2164, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2191, 152, 2165, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2192, 152, 2166, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2193, 152, 2167, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2194, 152, 2169, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2195, 152, 2170, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2196, 152, 2171, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2197, 173, 2172, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2198, 173, 2173, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2199, 173, 2174, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2200, 173, 2175, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2201, 173, 2176, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2202, 173, 2177, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2203, 173, 2178, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2204, 173, 2179, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2205, 173, 2180, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2206, 173, 2181, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2207, 173, 2182, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2208, 173, 2183, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2209, 173, 2184, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2210, 173, 2185, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2211, 173, 2186, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (2212, 829, 2187, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2213, 829, 2188, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2214, 829, 2189, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2215, 829, 2190, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2216, 829, 2191, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2217, 829, 2192, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2218, 829, 2193, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2219, 829, 2194, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2220, 829, 2195, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2221, 219, 2196, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2222, 219, 2197, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2223, 219, 2198, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2224, 219, 2199, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2225, 219, 2200, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2226, 219, 2201, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2227, 219, 2202, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2228, 219, 2203, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2229, 219, 2204, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2230, 219, 2205, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2231, 219, 2206, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2232, 222, 2207, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2233, 222, 2208, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2234, 222, 2209, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2235, 222, 2210, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2236, 222, 2211, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2237, 222, 2212, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2238, 222, 2213, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2239, 222, 2214, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2240, 224, 2215, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2241, 224, 2216, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2242, 224, 2217, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2243, 224, 2218, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2244, 224, 2219, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2245, 224, 2220, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2246, 224, 2221, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2247, 224, 2222, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2248, 227, 2223, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2249, 227, 2224, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2250, 227, 2225, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2251, 227, 2226, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2252, 227, 2227, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2253, 227, 2228, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2254, 227, 2229, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2255, 227, 2230, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2256, 227, 2231, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2257, 227, 2232, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2258, 227, 2233, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2259, 227, 2234, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2261, 207, 2236, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2262, 207, 2237, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2263, 207, 2238, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2264, 207, 2239, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2265, 207, 2240, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2266, 207, 2241, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2267, 207, 2242, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2268, 207, 2243, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2269, 207, 2244, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2270, 207, 2245, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2271, 178, 2246, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2272, 178, 2247, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2273, 178, 2248, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2274, 178, 2249, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2275, 178, 2250, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2276, 178, 2251, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2277, 178, 2252, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2278, 178, 2253, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2279, 178, 2254, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2280, 231, 2255, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2281, 231, 2256, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2282, 231, 2257, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2283, 231, 2258, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2284, 231, 2259, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2285, 231, 2260, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2286, 231, 2261, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2287, 231, 2262, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2288, 231, 2263, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2289, 231, 2264, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2290, 231, 2265, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2300, 169, 2288, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2301, 169, 2289, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2302, 169, 2290, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2303, 169, 2291, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2304, 169, 2292, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2305, 169, 2293, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2306, 169, 2294, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2307, 169, 2295, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2308, 169, 2296, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2309, 169, 2297, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2310, 169, 2298, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2311, 169, 2299, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2312, 169, 2300, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2313, 162, 1032, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2314, 162, 1033, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2315, 162, 1034, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2316, 162, 1478, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2317, 162, 1479, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2318, 162, 1480, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2319, 162, 1481, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2320, 162, 1482, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2321, 162, 1483, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2322, 162, 1484, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2323, 162, 1485, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2324, 162, 1486, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2325, 162, 1487, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2326, 162, 1585, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2327, 162, 2266, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (2328, 162, 2301, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (2329, 729, 2302, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2330, 729, 2303, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2331, 729, 2304, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2332, 729, 2305, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2333, 729, 2306, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2334, 729, 2307, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2335, 729, 2308, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2336, 729, 2309, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2337, 729, 2310, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2338, 214, 2311, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2339, 214, 2312, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2340, 214, 2313, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2341, 214, 2314, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2343, 214, 2316, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2344, 214, 2317, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2345, 214, 2318, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2346, 149, 2319, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2347, 149, 2320, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2348, 149, 2321, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2349, 149, 2322, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2350, 149, 2323, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2351, 149, 2324, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2352, 149, 2325, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2353, 149, 2326, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2354, 149, 2327, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2355, 149, 2328, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2356, 149, 2329, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2357, 149, 2330, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2358, 215, 2343, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2359, 215, 2344, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2360, 215, 2345, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2361, 215, 2346, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2362, 215, 2347, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2363, 215, 2348, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2364, 215, 2349, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2365, 215, 2350, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2366, 215, 2351, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2367, 215, 2352, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2368, 209, 2353, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2369, 209, 2354, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2370, 209, 2355, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2371, 209, 2356, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2372, 209, 2357, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2373, 209, 2358, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2374, 209, 2359, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2375, 209, 2360, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2376, 209, 2361, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2377, 209, 2362, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2378, 209, 2363, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2379, 209, 2364, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2380, 209, 2365, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2381, 174, 2367, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2382, 174, 2368, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2383, 174, 2369, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2384, 174, 2370, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2385, 174, 2371, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2386, 174, 2372, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2387, 174, 2373, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2388, 174, 2374, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2389, 163, 2375, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2390, 163, 2376, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2391, 163, 2377, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2392, 163, 2378, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2393, 163, 2379, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2394, 163, 2380, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2395, 163, 2381, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2396, 163, 2382, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2397, 163, 2383, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2398, 163, 2384, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2399, 161, 2385, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2400, 161, 2386, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2401, 161, 2387, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2402, 161, 2388, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2403, 161, 2389, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2404, 161, 2390, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2405, 161, 2391, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2406, 161, 2392, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2407, 161, 2393, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2408, 161, 2394, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2409, 161, 2395, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2410, 721, 2396, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2411, 721, 2397, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2412, 721, 2398, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2413, 721, 2399, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2414, 721, 2400, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2415, 721, 2401, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2416, 721, 2402, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2417, 721, 2403, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2418, 721, 2404, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2419, 154, 2405, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2420, 154, 2406, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2421, 154, 2407, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2422, 154, 2408, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2423, 154, 2409, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2424, 154, 2410, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2425, 154, 2411, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2426, 154, 2412, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2427, 159, 2413, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2428, 159, 2414, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2429, 159, 2415, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2430, 159, 2416, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2431, 159, 2417, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2432, 159, 2418, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2433, 159, 2419, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2434, 159, 2420, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2435, 134, 2421, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2436, 134, 2422, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2437, 134, 2425, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2438, 134, 2427, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2439, 134, 2428, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2440, 134, 2429, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2441, 134, 2431, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2442, 229, 2433, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2443, 229, 2434, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2444, 229, 2435, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2445, 229, 2436, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2446, 229, 2437, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2447, 229, 2438, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2448, 229, 2439, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2449, 229, 2440, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2450, 229, 2441, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2451, 229, 2442, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2452, 229, 2443, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2453, 131, 2444, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2454, 131, 2445, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2455, 131, 2446, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2456, 131, 2447, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2457, 131, 2448, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2458, 131, 2449, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2459, 131, 2450, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2460, 131, 2451, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2461, 131, 2452, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2462, 131, 2453, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2463, 131, 2454, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2464, 195, 2455, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2465, 195, 2456, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2466, 195, 2457, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2467, 195, 2458, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2468, 195, 2459, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2469, 195, 2460, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2470, 195, 2461, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2471, 195, 2462, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2472, 195, 2463, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10766, 1110, 10172, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6236, 455, 5748, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6237, 455, 5749, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6238, 455, 5750, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6239, 455, 5751, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6240, 455, 5752, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6241, 455, 5753, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6242, 455, 5754, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6243, 455, 5755, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6244, 455, 5756, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2484, 234, 2477, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2485, 234, 2478, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2486, 234, 2479, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2487, 234, 2480, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2488, 234, 2481, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2489, 234, 2482, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2490, 234, 2483, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2491, 234, 2484, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2492, 234, 2485, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2493, 234, 2486, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2494, 234, 2488, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2495, 237, 2489, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2496, 237, 2490, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2497, 237, 2491, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2498, 237, 2492, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2499, 237, 2493, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2500, 237, 2494, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2501, 237, 2495, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2502, 237, 2496, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2503, 237, 2497, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2504, 237, 2498, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2505, 237, 2499, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2506, 237, 2500, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2523, 144, 2532, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2524, 144, 2533, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2525, 144, 2534, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2526, 144, 2535, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2527, 144, 2536, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2528, 144, 2537, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2529, 144, 2538, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2530, 144, 2539, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2531, 144, 2540, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2532, 144, 2541, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2533, 144, 2542, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2534, 147, 2544, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2535, 147, 2545, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2536, 147, 2546, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2537, 147, 2548, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2538, 147, 2549, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2539, 147, 2550, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2540, 147, 2551, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2541, 147, 2552, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2542, 147, 2553, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2543, 147, 2554, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2544, 180, 2555, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2545, 180, 2556, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2546, 180, 2557, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2547, 180, 2558, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2548, 180, 2559, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2549, 180, 2560, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2550, 180, 2561, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2551, 180, 2562, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2552, 135, 2563, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2553, 135, 2564, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2554, 135, 2565, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2555, 135, 2566, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2556, 135, 2567, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2557, 135, 2569, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2558, 135, 2570, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2559, 727, 2571, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2560, 727, 2572, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2561, 727, 2573, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2562, 727, 2574, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2563, 727, 2575, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (2564, 727, 2576, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2565, 727, 2577, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2566, 727, 2578, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2567, 727, 2579, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2568, 727, 2580, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2569, 727, 2581, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2570, 727, 2582, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2571, 727, 2583, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2572, 727, 2584, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2573, 727, 2585, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2574, 184, 2586, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2575, 184, 2587, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2576, 184, 2588, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2577, 184, 2589, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2578, 184, 2590, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2579, 184, 2591, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2580, 184, 2592, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2581, 184, 2593, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2582, 184, 2594, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2583, 184, 2595, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2584, 184, 2596, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2585, 184, 2597, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2586, 241, 2598, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2587, 241, 2599, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2588, 241, 2600, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2589, 241, 2601, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2590, 241, 2602, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2591, 241, 2603, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2592, 241, 2604, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2593, 241, 2605, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2594, 241, 2606, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2595, 241, 2607, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2601, 140, 2613, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2604, 235, 2616, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2605, 235, 2617, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2606, 235, 2618, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2607, 235, 2619, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2608, 235, 2620, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2609, 235, 2621, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2610, 235, 2622, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2611, 235, 2623, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2612, 235, 2624, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2613, 235, 2625, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2614, 235, 2626, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2615, 235, 2627, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2616, 133, 1158, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2617, 133, 1160, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2618, 133, 1162, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2619, 133, 1163, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2620, 133, 1164, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2621, 133, 1165, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2622, 133, 1167, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2623, 133, 2332, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2624, 133, 2339, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2625, 133, 2628, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2626, 133, 2629, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2627, 145, 2630, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2628, 145, 2631, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2629, 145, 2632, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2630, 145, 2633, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2631, 145, 2634, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2632, 145, 2635, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2633, 145, 2636, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2634, 145, 2637, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2635, 145, 2638, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2636, 146, 2639, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2637, 146, 2640, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2638, 146, 2641, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2639, 146, 2642, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2640, 146, 2643, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2641, 146, 2644, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2642, 146, 2645, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2596, 140, 2608, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2516, 175, 2523, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2517, 175, 2524, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2518, 175, 2525, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2519, 175, 2526, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2520, 175, 2527, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2521, 175, 2529, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2522, 175, 2530, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2597, 140, 2609, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2598, 140, 2610, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2599, 140, 2611, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2600, 140, 2612, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2602, 140, 2614, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2603, 140, 2615, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2643, 146, 2646, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2644, 146, 2647, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2645, 146, 2648, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2646, 146, 2649, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2647, 146, 2650, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2648, 146, 2651, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2649, 168, 2652, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2650, 168, 2653, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2651, 168, 2654, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2652, 168, 2655, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2653, 168, 2656, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2654, 168, 2657, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2655, 168, 2658, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2656, 168, 2659, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2657, 168, 2660, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2658, 168, 2661, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2659, 168, 2662, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2660, 168, 2663, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10767, 1109, 10173, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10768, 1109, 10174, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10769, 1109, 10175, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10770, 1109, 10176, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10771, 1109, 10177, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10772, 1109, 10178, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10773, 1109, 10179, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10774, 1109, 10180, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10775, 1109, 10181, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10776, 1109, 10182, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10777, 1109, 10183, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10778, 1109, 10184, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10779, 1109, 10185, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2678, 187, 2681, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2679, 187, 2682, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2680, 187, 2683, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2681, 188, 2684, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (2682, 188, 2685, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2683, 188, 2686, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2684, 188, 2687, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2685, 188, 2688, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2686, 188, 2689, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2687, 188, 2690, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2688, 188, 2691, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (2689, 188, 2692, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (2704, 211, 2707, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2705, 211, 2708, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (2706, 211, 2709, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (2707, 211, 2710, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2708, 211, 2711, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2709, 213, 2712, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2710, 213, 2713, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2711, 213, 2714, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2712, 213, 2715, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2713, 213, 2716, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2714, 213, 2717, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2715, 213, 2718, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2716, 213, 2719, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2717, 213, 2720, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2718, 213, 2721, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2719, 213, 2722, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (2720, 213, 2724, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (2721, 213, 2725, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2722, 213, 2726, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2723, 248, 2727, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2724, 248, 2728, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2725, 248, 2729, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2726, 248, 2730, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2727, 249, 2501, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2728, 249, 2502, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2729, 249, 2503, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2730, 249, 2504, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2731, 249, 2505, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2732, 249, 2506, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2733, 249, 2507, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2734, 249, 2508, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2735, 249, 2509, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2736, 249, 2510, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2737, 249, 2511, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2738, 249, 2512, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2739, 250, 2513, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2740, 250, 2731, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2741, 250, 2732, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2742, 250, 2733, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2743, 250, 2734, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2744, 250, 2735, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2745, 250, 2736, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2746, 250, 2737, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2747, 250, 2738, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2748, 251, 2739, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2749, 251, 2740, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2750, 251, 2741, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2751, 251, 2742, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2752, 251, 2743, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2753, 251, 2744, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2754, 251, 2745, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2755, 251, 2746, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2756, 251, 2747, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2757, 251, 2748, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2758, 251, 2749, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2759, 251, 2750, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2760, 781, 2751, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2761, 781, 2752, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2762, 781, 2753, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2763, 781, 2754, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2764, 781, 2755, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2765, 781, 2756, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2766, 781, 2757, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2767, 255, 2766, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2768, 255, 2767, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2769, 255, 2768, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2770, 255, 2769, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2771, 255, 2770, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2772, 255, 2771, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2773, 255, 2772, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2774, 255, 2773, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2775, 255, 2774, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2776, 255, 2775, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2777, 255, 2776, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2778, 255, 2777, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2779, 256, 2779, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2780, 256, 2780, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2781, 256, 2781, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2782, 256, 2782, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2783, 256, 2783, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2784, 256, 2784, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2785, 256, 2785, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2786, 256, 2786, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2787, 256, 2787, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2788, 256, 2788, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2789, 256, 2789, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2790, 256, 2790, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2791, 256, 2791, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2792, 257, 2792, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2793, 257, 2793, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2794, 257, 2794, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2795, 257, 2795, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2796, 257, 2796, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2797, 257, 2797, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (2798, 257, 2798, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2799, 257, 2799, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2800, 257, 2800, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2801, 257, 2801, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2802, 257, 2802, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2803, 257, 2803, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2804, 257, 2804, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2805, 257, 2805, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2806, 258, 2806, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2807, 258, 2807, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2808, 258, 2808, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2809, 258, 2809, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2810, 258, 2810, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2811, 258, 2811, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2812, 258, 2812, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2813, 258, 2813, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2814, 258, 2814, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2815, 258, 2815, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2816, 258, 2816, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2817, 259, 2817, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2818, 259, 2818, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2819, 259, 2819, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (2820, 259, 2820, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (2821, 259, 2821, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2822, 260, 2822, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2823, 260, 2823, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2824, 260, 2824, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2825, 204, 2825, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2837, 262, 2836, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2838, 262, 2837, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2839, 262, 2838, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2840, 263, 2839, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2841, 263, 2840, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2842, 263, 2841, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2843, 263, 2842, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2844, 263, 2843, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2845, 263, 2844, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2846, 263, 2845, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2847, 263, 2846, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2848, 263, 2847, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2849, 263, 2848, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2850, 264, 2849, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2851, 264, 2850, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2852, 264, 2851, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2853, 264, 2852, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2854, 264, 2853, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2855, 264, 2854, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2856, 264, 2855, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2857, 264, 2856, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2858, 264, 2857, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2859, 264, 2858, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2860, 264, 2859, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2861, 266, 2867, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2862, 266, 2864, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2863, 266, 2865, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2864, 266, 2866, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2865, 266, 2868, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2866, 267, 2869, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2867, 267, 2870, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2868, 267, 2871, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2869, 267, 2872, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2870, 267, 2873, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2871, 267, 2874, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2872, 267, 2875, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2873, 267, 2876, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2874, 267, 2877, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2875, 267, 2878, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2876, 91, 1451, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2877, 91, 2758, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2878, 91, 2759, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2879, 91, 2760, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2696, 208, 2699, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2697, 208, 2700, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2698, 208, 2701, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2699, 208, 2702, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2700, 208, 2703, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2701, 208, 2704, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2702, 208, 2705, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2703, 208, 2706, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2880, 91, 2761, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2881, 91, 2879, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2882, 91, 2880, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2883, 91, 2881, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2884, 91, 2882, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2885, 91, 2883, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2886, 253, 2884, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2887, 253, 2885, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2888, 253, 2886, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2889, 253, 2887, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2890, 253, 2888, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2891, 253, 2889, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2892, 253, 2890, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2893, 253, 2891, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2894, 253, 2892, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2913, 270, 2912, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2914, 270, 2913, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2915, 270, 2914, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2916, 270, 2915, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2917, 270, 2916, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2918, 270, 2917, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2919, 270, 2918, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2920, 270, 2919, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2921, 270, 2920, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2922, 270, 2921, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2923, 270, 2922, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2924, 270, 2923, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2925, 271, 2924, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2926, 271, 2925, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2927, 271, 2926, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2928, 271, 2927, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2929, 271, 2928, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2930, 271, 2929, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2931, 271, 2930, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2932, 271, 2931, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2933, 271, 2932, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2934, 271, 2933, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2935, 271, 2934, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2936, 271, 2935, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2937, 271, 2936, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2938, 272, 2937, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2939, 272, 2938, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2940, 272, 2939, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2941, 272, 2940, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2942, 272, 2941, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2943, 272, 2942, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2944, 272, 2943, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2945, 272, 2944, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2946, 272, 2945, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2947, 272, 2946, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2948, 272, 2947, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2949, 272, 2948, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2950, 273, 2949, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2951, 273, 2950, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2952, 273, 2951, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2907, 269, 9689, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2953, 273, 2952, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2954, 273, 2953, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2955, 273, 2954, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2956, 273, 2955, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2957, 273, 2956, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2958, 274, 2957, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2959, 274, 2958, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2960, 274, 2959, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2961, 274, 2960, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2962, 274, 2961, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2963, 274, 2962, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2964, 274, 2963, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2965, 274, 2964, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2966, 274, 2965, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2967, 274, 2966, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2968, 275, 2967, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2969, 275, 2968, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2970, 275, 2969, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2971, 275, 2970, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2972, 275, 2971, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2973, 275, 2972, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2974, 275, 2973, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2975, 276, 2974, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2976, 276, 2975, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2977, 276, 2976, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2978, 276, 2977, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2979, 276, 2978, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2980, 276, 2979, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2981, 276, 2980, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2982, 277, 2981, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2983, 277, 2982, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2984, 277, 2983, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2985, 277, 2984, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2986, 277, 2985, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2987, 277, 2986, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2988, 277, 2987, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2989, 277, 2988, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2990, 277, 2989, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2991, 277, 2990, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2992, 277, 2991, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2993, 278, 2992, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2994, 278, 2993, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2995, 278, 2994, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2996, 278, 2995, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2997, 278, 2996, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2998, 278, 2997, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2999, 278, 2998, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3000, 278, 2999, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3001, 279, 3000, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3002, 279, 3001, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3003, 279, 3002, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3004, 279, 3003, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3005, 279, 3004, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3006, 279, 3005, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3007, 279, 3006, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3008, 279, 3007, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3009, 279, 3008, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3010, 279, 3009, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3011, 279, 3010, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3012, 280, 3011, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3013, 280, 3012, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3014, 280, 3013, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3015, 280, 3014, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3016, 280, 3015, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3017, 280, 3016, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3018, 280, 3017, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3019, 280, 3018, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3029, 283, 3040, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3030, 283, 3041, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3031, 283, 3042, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3032, 283, 3043, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3033, 283, 3044, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3034, 283, 3045, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3035, 284, 3046, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3036, 284, 3047, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3037, 284, 3048, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3038, 284, 3049, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3039, 284, 3050, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3040, 284, 3051, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3041, 284, 3052, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3042, 284, 3053, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3043, 284, 3054, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3044, 284, 3055, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3045, 285, 3056, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3046, 285, 3057, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3047, 285, 3058, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3048, 285, 3059, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3049, 285, 3060, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3050, 285, 3061, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3051, 285, 3062, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3052, 285, 3063, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3053, 285, 3064, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3054, 285, 3065, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3055, 286, 3066, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3056, 286, 3067, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3057, 286, 3068, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3058, 286, 3069, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3059, 286, 3070, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3060, 286, 3071, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3061, 286, 3072, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3062, 286, 3073, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3063, 286, 3074, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3064, 286, 3075, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3065, 286, 3076, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3066, 286, 3077, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3068, 287, 3079, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3069, 287, 3080, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3070, 287, 3081, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3077, 289, 3090, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3078, 289, 3091, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3079, 289, 3092, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3080, 289, 3093, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3081, 289, 3094, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3082, 289, 3095, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3083, 289, 3096, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3084, 289, 3097, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3085, 289, 3098, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3086, 289, 3099, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3087, 289, 3100, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3088, 282, 2366, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3089, 282, 2474, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3090, 282, 3029, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3091, 282, 3030, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3092, 282, 3031, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3093, 282, 3034, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3094, 282, 3035, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3095, 290, 3037, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3096, 290, 3038, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3097, 290, 3039, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3098, 290, 3101, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3099, 290, 3102, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3100, 290, 3103, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3101, 290, 3104, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3102, 290, 3106, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3103, 290, 3107, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3104, 290, 3108, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3105, 291, 3109, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3106, 291, 3110, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3107, 291, 3111, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3108, 291, 525, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3109, 291, 531, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3110, 291, 528, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3111, 291, 3031, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3112, 291, 3114, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3113, 292, 3116, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3114, 292, 3117, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3115, 292, 3118, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3116, 292, 3119, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3117, 292, 3120, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3118, 292, 3121, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3119, 292, 3122, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3120, 292, 3123, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3121, 292, 3124, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3122, 292, 3125, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3123, 292, 3126, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3133, 294, 3136, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3134, 294, 3137, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3135, 294, 3138, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3136, 294, 3139, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3137, 294, 3140, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3138, 294, 3141, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3139, 294, 3142, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3140, 295, 3143, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3141, 295, 3144, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3142, 295, 3145, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3143, 295, 3146, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3144, 295, 3147, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3145, 295, 3148, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3146, 295, 3149, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3147, 295, 3150, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3148, 144, 3151, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3149, 296, 3152, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3150, 296, 3153, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3151, 296, 3154, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3152, 296, 3155, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3153, 296, 3156, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3154, 296, 3157, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3155, 297, 2372, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3156, 297, 3094, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3157, 297, 3093, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3158, 297, 3099, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3159, 297, 3095, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3160, 297, 2368, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3161, 297, 3090, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3162, 297, 1595, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3163, 297, 1600, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3164, 297, 3056, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3165, 297, 3064, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3166, 297, 1596, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3167, 290, 19, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3168, 33, 93, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3169, 33, 126, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3170, 282, 168, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3171, 24, 2366, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3172, 282, 225, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3173, 298, 209, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3174, 298, 530, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3175, 298, 532, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3176, 298, 3028, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3177, 265, 1779, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3178, 134, 31, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3179, 8, 2427, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3180, 300, 3159, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3181, 300, 3160, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3182, 300, 3161, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3183, 300, 3162, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3184, 300, 3163, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3185, 300, 3164, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3186, 300, 3165, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3187, 301, 3166, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3188, 301, 3167, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3189, 301, 3168, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3190, 302, 3169, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3191, 302, 3170, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3192, 302, 3171, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3193, 302, 3172, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3194, 302, 1159, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3195, 302, 1161, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3196, 302, 1168, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3071, 833, 3082, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3197, 302, 2430, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3198, 302, 2476, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3199, 299, 2861, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3200, 299, 3174, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3201, 299, 3036, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3202, 299, 3158, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3203, 299, 3173, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3204, 299, 3175, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3205, 299, 3176, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3206, 299, 3177, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3207, 299, 3178, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3208, 303, 3179, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3209, 303, 3180, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3210, 303, 3181, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3211, 303, 3182, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3212, 303, 3183, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3213, 303, 3184, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3214, 303, 3185, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3215, 303, 3186, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3216, 303, 3187, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3217, 303, 3188, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3218, 304, 1962, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3219, 304, 3189, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3220, 304, 3190, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3221, 304, 3191, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3222, 304, 3192, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3223, 282, 159, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3224, 305, 3193, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3225, 305, 3194, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3226, 305, 3195, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3227, 305, 3196, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3228, 305, 3197, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3229, 305, 3198, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3230, 305, 3199, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3232, 306, 3201, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3233, 306, 3202, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3234, 306, 3203, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3235, 306, 3204, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3236, 306, 3205, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3237, 306, 3206, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3238, 306, 3207, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3239, 306, 3208, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3240, 306, 3209, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3241, 306, 3210, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3242, 306, 3211, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3243, 309, 3217, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3244, 309, 3212, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3245, 309, 3213, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3246, 309, 3214, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3247, 309, 3215, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3248, 309, 3216, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3249, 309, 3218, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3250, 309, 3219, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3251, 309, 3220, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3252, 309, 3221, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (3253, 309, 3222, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (3254, 824, 3228, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3255, 824, 3229, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3256, 824, 3230, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3257, 824, 3231, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3258, 824, 3232, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3259, 824, 3233, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3260, 824, 3234, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3261, 824, 3235, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3262, 824, 3236, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3263, 824, 3237, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3264, 314, 3238, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3265, 314, 3239, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3266, 314, 3240, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3267, 314, 3241, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3268, 314, 3242, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6245, 455, 5757, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10790, 1111, 10196, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6246, 455, 5758, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6247, 455, 5759, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3274, 316, 3248, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3275, 316, 3249, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3276, 316, 3250, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3277, 316, 3251, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3278, 316, 3252, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3279, 316, 3253, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3280, 316, 3254, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3281, 316, 3255, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3282, 316, 3256, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3283, 316, 3257, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3284, 307, 3223, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3285, 307, 3224, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3286, 307, 3225, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3287, 307, 3226, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3288, 307, 3227, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3289, 307, 3032, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3290, 307, 3258, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3291, 307, 3259, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3292, 307, 3260, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3293, 307, 3261, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3294, 307, 3262, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3295, 25, 3263, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3296, 123, 1402, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3297, 9, 2429, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3298, 9, 2428, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3299, 134, 162, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3300, 134, 219, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3313, 383, 120, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3314, 383, 146, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3315, 383, 2423, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3316, 383, 2426, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3317, 383, 3264, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3318, 383, 3265, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3319, 383, 3266, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3320, 383, 3267, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3321, 383, 3268, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3322, 383, 3269, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3323, 383, 3270, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3324, 847, 3271, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3325, 847, 3272, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3326, 847, 3273, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3327, 847, 3274, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3328, 847, 3275, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3329, 847, 3276, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3330, 847, 3277, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3331, 847, 3278, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3332, 847, 3279, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3333, 847, 3280, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3334, 847, 3281, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3335, 847, 3282, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3336, 756, 3283, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3337, 756, 3284, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3338, 756, 3285, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3339, 756, 3286, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3340, 756, 3287, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3341, 756, 3288, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3342, 705, 3289, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3343, 705, 3290, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3344, 705, 3291, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3345, 705, 3292, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3346, 705, 3293, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3347, 705, 3294, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3348, 705, 3295, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3349, 705, 3296, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3350, 705, 3297, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3351, 705, 3298, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3352, 705, 3299, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3353, 705, 3300, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3354, 705, 3301, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3355, 705, 3302, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3356, 705, 3303, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3357, 385, 3304, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3358, 385, 3305, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3359, 385, 3306, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3360, 385, 3307, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3361, 385, 3308, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3362, 385, 3309, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3363, 385, 3310, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3364, 385, 3311, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3365, 385, 3312, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3366, 385, 3313, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3367, 385, 3314, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3368, 385, 3315, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3369, 385, 3316, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3370, 385, 3317, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3371, 385, 3318, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (3231, 175, 3200, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10907, 118, 10304, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3385, 66, 3332, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3386, 63, 3333, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3387, 849, 3334, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3388, 849, 3335, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3389, 849, 3336, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3390, 849, 3337, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3391, 849, 3338, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3392, 849, 3339, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3393, 849, 3340, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3394, 849, 3341, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3395, 849, 3342, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3396, 849, 3343, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3397, 849, 3344, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3398, 849, 3345, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3399, 849, 3346, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3400, 849, 3347, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3401, 849, 3348, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3413, 788, 3360, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3414, 788, 3361, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3415, 788, 3362, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3416, 788, 3363, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3417, 826, 3364, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3418, 826, 3365, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3419, 826, 3366, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3420, 826, 3367, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3421, 826, 3368, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3422, 826, 3369, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3423, 826, 3370, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3424, 826, 3371, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3425, 826, 3372, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3426, 826, 3373, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3427, 826, 3374, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3428, 826, 3375, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3429, 826, 3376, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3430, 852, 3377, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3431, 852, 3378, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3432, 852, 3379, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3433, 852, 3380, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3434, 852, 3381, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3443, 781, 3390, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3444, 781, 3391, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3445, 875, 3392, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3446, 875, 3393, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3447, 875, 3394, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3448, 875, 3395, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3449, 875, 3396, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3450, 875, 3397, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3451, 875, 3398, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3452, 875, 3399, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3453, 875, 3400, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3454, 875, 3401, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3455, 875, 3402, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3456, 875, 3403, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3457, 97, 3404, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3435, 838, 3382, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3436, 838, 3383, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3437, 838, 3384, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3438, 838, 3385, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3439, 838, 3386, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3440, 838, 3387, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3441, 838, 3388, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3442, 838, 3389, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3458, 388, 3405, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3459, 388, 3406, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3460, 388, 3407, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3461, 388, 3408, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3462, 388, 3409, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3463, 388, 3410, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3464, 388, 3411, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3465, 388, 3412, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3466, 388, 3413, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3467, 388, 3414, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3468, 388, 3415, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3469, 388, 3416, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3470, 388, 3417, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3471, 388, 3418, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3472, 388, 3419, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3473, 388, 3420, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (3474, 388, 3421, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (3475, 64, 2044, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3476, 876, 783, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3477, 876, 2528, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3478, 876, 3422, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3479, 876, 3423, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3480, 876, 3424, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3481, 876, 3425, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3482, 876, 3426, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3483, 876, 3427, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3484, 876, 3428, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3485, 876, 3429, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3486, 876, 3430, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3487, 876, 3431, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3488, 876, 3432, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3489, 876, 3433, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3490, 876, 3434, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3491, 876, 3435, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (3492, 871, 3436, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3493, 871, 3437, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3494, 871, 3438, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3495, 871, 3439, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3496, 871, 3440, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3497, 871, 3441, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3498, 871, 3442, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3499, 871, 3443, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3500, 871, 3444, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3501, 871, 3445, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3502, 871, 3446, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3503, 871, 3447, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3504, 871, 3448, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3505, 871, 3449, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3506, 871, 3450, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3507, 869, 3451, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3508, 869, 3452, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3509, 869, 3453, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3510, 869, 3454, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3511, 869, 3455, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3512, 869, 3456, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3513, 869, 3457, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3514, 869, 3458, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3515, 869, 3459, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3516, 869, 3460, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3517, 869, 3461, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3518, 869, 3462, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3519, 870, 3463, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3520, 870, 3464, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3521, 870, 3465, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3522, 870, 3466, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3523, 870, 3467, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3524, 870, 3468, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3525, 870, 3469, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3526, 870, 3470, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3527, 870, 3471, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3528, 870, 3472, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3529, 870, 3473, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3530, 870, 3474, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3531, 868, 3475, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3532, 868, 3476, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3533, 868, 3477, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3534, 868, 3478, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3535, 868, 3479, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3536, 868, 3480, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3537, 868, 3481, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3538, 868, 3482, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3539, 868, 3483, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3540, 868, 3484, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3541, 868, 3485, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3542, 868, 3486, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3543, 868, 3487, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3544, 868, 3488, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3545, 324, 3489, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3546, 324, 3490, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3547, 324, 3491, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3548, 324, 3492, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3549, 324, 3493, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3550, 324, 3494, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3551, 324, 3495, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3552, 324, 3496, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3553, 324, 3497, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3554, 324, 3498, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3555, 324, 3499, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3556, 324, 3500, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3557, 324, 3501, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3558, 324, 3502, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3559, 324, 3503, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3560, 324, 3504, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (3561, 774, 3505, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3562, 774, 3506, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3563, 774, 3507, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3564, 774, 3508, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3565, 774, 3509, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3566, 774, 3510, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3567, 774, 3511, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3568, 774, 3512, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3569, 774, 3513, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3570, 774, 3514, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3571, 774, 3515, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3572, 774, 3516, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3573, 774, 3517, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3574, 774, 3518, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3575, 774, 3519, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3576, 774, 3520, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (3577, 774, 3521, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (3578, 774, 3522, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (3579, 774, 3523, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (3580, 774, 3524, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (3581, 774, 3525, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (3582, 774, 3526, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (3583, 774, 3527, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (3584, 774, 3528, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (3585, 774, 3529, 26);
INSERT INTO 'albumsrecordingsmap' VALUES (3586, 774, 3530, 27);
INSERT INTO 'albumsrecordingsmap' VALUES (3587, 774, 3531, 28);
INSERT INTO 'albumsrecordingsmap' VALUES (3588, 775, 3532, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3589, 775, 3533, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3590, 775, 3534, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3591, 775, 3535, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3592, 775, 3536, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3593, 775, 3537, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3594, 775, 3538, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3595, 775, 3539, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3596, 775, 3540, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3597, 775, 3541, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3598, 775, 3542, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3599, 775, 3543, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3600, 775, 3544, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3601, 775, 3545, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3602, 775, 3546, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3603, 775, 3547, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (3604, 872, 3548, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3605, 872, 3549, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3606, 872, 3550, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3607, 872, 3551, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3608, 872, 3552, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3609, 872, 3553, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3610, 872, 3554, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3611, 872, 3555, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3612, 872, 3556, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3613, 872, 3557, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3614, 872, 3558, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3615, 872, 3559, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3616, 872, 3560, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3617, 872, 3561, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3618, 785, 3562, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3619, 785, 3563, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3620, 785, 3564, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3621, 785, 3565, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3622, 785, 3566, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3623, 785, 3567, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3624, 785, 3568, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3625, 785, 3569, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3626, 785, 3570, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3627, 785, 3571, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3628, 785, 3572, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3629, 856, 3573, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3630, 856, 3574, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3631, 856, 3575, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3632, 856, 3576, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3633, 856, 3577, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3634, 856, 3578, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3635, 856, 3579, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3636, 856, 3580, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3637, 856, 3581, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3638, 856, 3582, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3639, 856, 3583, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3640, 856, 3584, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3641, 856, 3585, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3642, 856, 3586, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3643, 398, 3587, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3644, 398, 3588, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3645, 398, 3589, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3646, 398, 3590, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3647, 398, 3591, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3648, 398, 3592, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3649, 398, 3593, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3650, 398, 3594, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3651, 398, 3595, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3652, 398, 3596, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3653, 309, 3597, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3654, 309, 3598, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3655, 309, 3599, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3656, 309, 3600, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3657, 309, 3601, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3658, 309, 3602, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3659, 309, 3603, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (3660, 283, 3604, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3661, 283, 3605, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3662, 283, 3606, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3663, 283, 3607, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3664, 283, 3608, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3665, 283, 3609, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3666, 210, 3610, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3667, 340, 3611, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3668, 340, 3612, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3669, 340, 3613, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3670, 340, 3614, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3671, 340, 3615, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3672, 340, 3616, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3673, 340, 3617, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3674, 340, 3620, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3675, 340, 3621, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3677, 127, 1578, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3678, 127, 2778, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3679, 250, 3623, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3680, 239, 3624, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (3681, 275, 3625, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3682, 735, 3626, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3683, 735, 3627, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3684, 735, 3628, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3685, 735, 3629, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3686, 735, 3630, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3687, 735, 3631, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3688, 735, 3632, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3689, 735, 3633, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3690, 735, 3634, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3691, 735, 3635, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3692, 735, 3636, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3693, 735, 3637, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3694, 712, 3638, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3695, 712, 3639, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3696, 712, 3640, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3697, 712, 3641, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3698, 712, 3642, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3699, 712, 3643, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3700, 712, 3644, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3701, 712, 3645, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3702, 712, 3646, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3703, 712, 3647, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3704, 712, 3648, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3705, 717, 3650, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3706, 717, 3651, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3707, 717, 3652, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3708, 717, 3653, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3709, 717, 3654, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3710, 717, 3655, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3711, 717, 3656, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3712, 718, 3657, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3713, 718, 3658, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3714, 718, 3659, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3715, 718, 3660, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3716, 718, 3661, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3717, 718, 3662, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3718, 718, 3663, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3719, 718, 3664, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3720, 718, 3665, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3721, 718, 3667, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3722, 717, 3668, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3723, 717, 3669, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3724, 717, 3670, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3725, 717, 3671, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3726, 717, 3672, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3727, 717, 3673, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3728, 372, 3674, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3729, 372, 3675, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3730, 372, 3676, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3731, 372, 3677, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3732, 372, 3678, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3733, 372, 3679, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3734, 372, 3680, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3735, 372, 3681, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3736, 372, 3682, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3737, 372, 3683, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3738, 372, 3684, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3739, 372, 3685, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3740, 745, 3686, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3741, 745, 3687, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3742, 745, 3689, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3743, 745, 3690, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3744, 745, 3691, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3745, 745, 3692, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3746, 745, 3693, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3747, 745, 3694, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3748, 745, 3695, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3749, 746, 3696, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3750, 746, 3697, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3751, 746, 3698, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3752, 746, 3699, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3753, 746, 3700, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3754, 746, 3701, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3755, 746, 3702, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3756, 746, 3703, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3757, 746, 1932, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3758, 746, 2287, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3759, 746, 2827, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3760, 749, 2331, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3761, 749, 2340, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3762, 749, 2333, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3763, 749, 2334, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3764, 749, 2335, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3765, 749, 2336, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3766, 749, 2337, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3767, 749, 2338, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3768, 749, 1166, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3769, 749, 2341, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3770, 749, 2342, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3771, 304, 3705, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3772, 304, 3706, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3773, 740, 3708, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3774, 740, 3709, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3775, 740, 3710, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3776, 740, 3711, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3777, 740, 3712, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3778, 740, 3713, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3779, 740, 3714, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3780, 740, 3715, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3781, 740, 3716, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3782, 740, 3717, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3783, 740, 3718, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3784, 740, 3719, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3785, 741, 3720, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3786, 741, 3721, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3787, 741, 3722, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3788, 741, 3723, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3789, 741, 3724, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3790, 741, 3725, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3791, 741, 3726, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3792, 741, 3727, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3793, 741, 3728, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3794, 741, 3729, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3795, 741, 3730, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3796, 741, 3731, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3797, 741, 3732, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3798, 741, 3733, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3799, 790, 3734, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3800, 790, 3735, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3801, 790, 3737, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3802, 790, 3738, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3803, 790, 3739, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3804, 790, 3740, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3805, 790, 3741, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3806, 790, 3742, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3807, 790, 3743, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3808, 790, 3744, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3809, 790, 3745, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3810, 790, 3746, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3811, 790, 3747, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3812, 189, 3748, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3813, 706, 3749, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3814, 706, 3750, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3815, 706, 3751, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3816, 706, 3752, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3817, 706, 3753, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3818, 706, 3754, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3819, 706, 3755, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3820, 811, 3756, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3821, 811, 3757, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3822, 811, 3758, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3823, 811, 3759, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3824, 811, 3760, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3825, 811, 3761, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3826, 811, 3762, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3841, 379, 2366, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3842, 379, 340, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3843, 379, 225, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3844, 379, 349, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3845, 379, 3778, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3846, 379, 126, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3847, 379, 159, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3848, 379, 3779, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3849, 379, 231, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3850, 379, 121, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3851, 379, 2, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3852, 379, 93, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3853, 827, 3780, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3854, 827, 3781, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3855, 827, 3782, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3856, 827, 3783, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3857, 827, 3784, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3858, 827, 3785, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3859, 827, 3786, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3860, 827, 3787, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3861, 827, 3788, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3862, 827, 3789, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3863, 827, 3790, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3864, 827, 3791, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3865, 827, 3792, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3868, 719, 3799, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3869, 719, 3800, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3870, 719, 3801, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3871, 719, 3802, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3872, 719, 3803, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3873, 719, 3804, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3874, 719, 3805, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3875, 719, 3806, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3876, 719, 3807, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3877, 719, 3808, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3878, 719, 3809, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3879, 719, 3810, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3880, 719, 3811, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3881, 719, 3812, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3882, 719, 3813, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3883, 753, 101, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3884, 753, 3814, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3885, 753, 3815, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3886, 753, 3816, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3887, 724, 3817, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3888, 724, 3818, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3889, 724, 3819, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3890, 724, 3820, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3891, 758, 3821, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3892, 758, 3822, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3893, 758, 3823, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3894, 758, 3824, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3901, 878, 455, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3902, 878, 1373, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3903, 878, 1247, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3904, 878, 1283, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3905, 878, 267, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3906, 878, 290, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3907, 878, 61, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3908, 878, 3831, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3909, 878, 3832, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3910, 878, 3833, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3911, 878, 3834, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3912, 878, 3835, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3913, 878, 3836, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3914, 878, 3837, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3915, 878, 3838, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3916, 282, 231, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3917, 748, 3839, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3918, 748, 3840, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3919, 748, 3841, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3920, 748, 3842, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3921, 748, 3843, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3922, 748, 3844, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3923, 780, 3845, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3924, 780, 3846, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3925, 780, 3847, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3926, 780, 3848, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3927, 780, 3849, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3928, 780, 3850, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3929, 780, 3851, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3930, 780, 3852, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3931, 780, 3853, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3932, 730, 3854, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3933, 730, 3855, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3934, 730, 3856, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3935, 730, 3857, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3936, 406, 3859, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3937, 406, 3861, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3938, 406, 3862, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3939, 406, 3863, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3940, 406, 3865, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3941, 406, 3867, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3942, 406, 3868, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3943, 406, 3869, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3944, 406, 124, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3945, 134, 3862, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3946, 406, 2427, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3947, 406, 11, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3948, 406, 313, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3949, 343, 3870, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3950, 343, 3871, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3951, 343, 3872, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3952, 343, 3873, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3953, 343, 3874, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3954, 343, 3875, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3955, 343, 3876, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3956, 343, 3877, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3957, 343, 3878, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3958, 343, 3879, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3959, 343, 3880, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3960, 343, 3881, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3961, 728, 2162, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3962, 728, 2163, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3963, 728, 2164, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3964, 728, 2165, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3965, 728, 2166, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3966, 728, 2167, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3967, 728, 2169, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3968, 728, 2170, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3969, 728, 2171, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3970, 728, 3882, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3971, 728, 3884, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3972, 728, 3885, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3973, 728, 3886, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3974, 728, 3887, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3975, 777, 3888, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3976, 777, 3889, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3977, 777, 3890, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3978, 777, 3891, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3979, 777, 3892, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3980, 777, 3893, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3981, 777, 3894, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3982, 777, 3895, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3983, 777, 3896, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3984, 777, 3897, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3985, 777, 3898, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3986, 777, 3899, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3987, 408, 3901, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3988, 408, 3900, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3989, 408, 3902, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3990, 408, 3903, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3991, 408, 3904, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3992, 408, 3905, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3993, 408, 3906, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3994, 408, 3907, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3995, 408, 3908, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3996, 408, 2432, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3997, 408, 2547, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3998, 408, 2568, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3999, 408, 3033, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4000, 408, 3084, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4001, 771, 3087, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4002, 771, 3793, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4003, 771, 3794, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4004, 771, 3796, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4005, 771, 3797, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4006, 771, 3858, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4007, 771, 3860, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4008, 771, 3864, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4009, 771, 3866, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4010, 771, 3883, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4011, 771, 3909, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4012, 771, 3910, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4013, 771, 3911, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4014, 771, 3912, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4015, 771, 3913, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4016, 771, 3914, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4017, 771, 2723, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (4018, 841, 3916, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4019, 841, 3917, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4020, 841, 3918, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4021, 841, 3919, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4022, 841, 3920, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4023, 841, 3921, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4024, 841, 3922, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4025, 841, 3923, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4026, 841, 3924, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4027, 841, 3925, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4028, 841, 3926, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4029, 751, 3927, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4030, 751, 3928, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4031, 751, 3929, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4032, 751, 3930, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4033, 751, 3931, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4034, 301, 3932, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4035, 301, 3933, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4036, 301, 3934, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (4037, 399, 3082, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4038, 399, 3083, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4039, 399, 3795, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4040, 399, 3085, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4041, 399, 3086, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4042, 399, 3798, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4043, 399, 3088, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4044, 399, 3089, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4045, 715, 3649, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4046, 715, 3935, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4047, 715, 3936, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4048, 715, 3937, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4049, 715, 3938, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4050, 715, 3939, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4051, 715, 3940, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4052, 715, 3941, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4053, 715, 3942, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4054, 715, 3943, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4055, 715, 3944, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4056, 715, 3945, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4057, 832, 3946, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4058, 832, 3947, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4059, 832, 3948, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4060, 832, 3949, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4061, 832, 3950, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4062, 832, 3951, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4063, 832, 3952, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4064, 832, 3953, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4065, 832, 3954, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4066, 832, 3955, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4067, 832, 3956, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4068, 832, 3957, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4069, 832, 3958, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4070, 832, 3959, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4071, 832, 3960, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4072, 832, 3961, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4073, 805, 3962, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4074, 805, 3963, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4075, 805, 3964, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4076, 805, 3965, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4077, 805, 3966, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4078, 805, 3967, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4079, 805, 3968, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4080, 805, 3969, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4081, 805, 3970, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4082, 805, 3971, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4083, 805, 3972, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4084, 805, 3973, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4085, 703, 3974, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4086, 703, 3975, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4087, 703, 3976, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4088, 703, 3977, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4089, 703, 3978, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4090, 703, 3979, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4091, 703, 3980, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4092, 703, 3981, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4093, 803, 3982, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4094, 803, 3983, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4095, 803, 3984, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4096, 803, 3985, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4097, 803, 3986, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4098, 803, 3987, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4099, 803, 3988, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4100, 803, 3989, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4101, 803, 3990, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4102, 803, 3991, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4103, 803, 3992, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4104, 803, 3993, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4105, 803, 3994, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4106, 743, 3995, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4107, 743, 3996, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4108, 743, 3997, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4109, 743, 3998, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4110, 743, 3999, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4111, 743, 4000, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4112, 743, 4001, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4113, 743, 4002, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4114, 743, 4003, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4115, 743, 4004, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4116, 743, 4005, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4117, 743, 4006, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4118, 743, 4007, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4119, 743, 4008, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4120, 743, 4009, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4121, 743, 4010, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4122, 743, 4011, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (4123, 743, 4012, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (4124, 743, 4013, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (4125, 743, 4014, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (4126, 743, 4015, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (4127, 743, 4016, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (4128, 743, 4017, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (4131, 755, 4021, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4132, 755, 4022, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4133, 755, 4024, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4134, 755, 4025, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4135, 755, 4026, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4136, 755, 4027, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4137, 755, 4029, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4138, 755, 4030, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4139, 755, 4031, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4140, 755, 4032, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4141, 755, 4033, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4142, 755, 4034, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4143, 754, 4035, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4144, 754, 4036, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4145, 754, 4037, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4146, 754, 4038, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4147, 754, 4039, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4148, 754, 4040, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4149, 754, 4041, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4150, 754, 4042, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4151, 754, 4043, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4152, 200, 4044, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (4153, 414, 4046, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4154, 368, 4047, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4155, 368, 4048, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4156, 368, 4049, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4157, 368, 4050, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4158, 368, 4051, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4159, 368, 4052, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4160, 368, 4053, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4161, 368, 4054, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4162, 368, 4055, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4163, 368, 4056, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4164, 368, 4057, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4165, 368, 4058, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4166, 368, 4059, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4167, 417, 4060, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4168, 417, 4061, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4169, 417, 4062, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4170, 417, 4063, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4171, 417, 4064, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4172, 417, 4065, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4173, 417, 4066, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4174, 417, 4067, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4175, 417, 4068, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4176, 417, 4069, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4177, 417, 4070, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4178, 417, 4071, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4179, 418, 2378, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4180, 418, 4072, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4181, 247, 23, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4182, 418, 23, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4183, 419, 4080, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4184, 419, 4081, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4185, 419, 4082, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4186, 419, 4083, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4187, 419, 4084, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4188, 419, 4085, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4189, 419, 4086, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4190, 419, 4087, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4191, 419, 4088, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4192, 419, 4089, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4193, 419, 4090, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4194, 419, 4091, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4195, 419, 4092, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4196, 419, 4093, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4197, 419, 4094, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4198, 755, 2030, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4199, 755, 2032, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4200, 193, 4029, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4201, 193, 2016, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4202, 183, 2040, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4203, 193, 4022, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4204, 420, 4095, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4205, 420, 4096, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4206, 420, 4097, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4207, 420, 4098, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4208, 420, 4099, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4209, 420, 4100, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4210, 420, 4101, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4211, 420, 4102, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4212, 421, 4103, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4213, 421, 4104, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4214, 421, 4105, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4215, 421, 4106, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4216, 421, 4107, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4217, 421, 4108, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4218, 421, 4109, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4219, 421, 4110, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4220, 421, 1597, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4221, 421, 2029, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4222, 421, 2034, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4223, 421, 2038, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4224, 107, 2041, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4225, 107, 4023, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4226, 107, 4028, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4227, 124, 4111, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4228, 124, 4112, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4229, 124, 4113, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4230, 124, 4115, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4231, 124, 4116, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4232, 124, 4117, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4233, 124, 4118, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4234, 124, 4119, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4235, 124, 4120, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4236, 124, 4121, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4237, 124, 4122, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4238, 370, 4123, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4239, 370, 4125, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4240, 370, 1955, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4241, 370, 4127, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4242, 370, 4128, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4243, 370, 4129, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4244, 370, 4130, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4245, 213, 4131, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4246, 213, 4132, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4247, 213, 4133, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4248, 213, 4134, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (4249, 864, 4135, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4250, 864, 4136, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4251, 864, 4137, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4252, 864, 4138, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4253, 864, 4139, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4254, 864, 4140, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4255, 864, 4141, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4256, 864, 4142, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4257, 864, 4143, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4258, 864, 4144, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4259, 864, 4145, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4260, 864, 4146, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4261, 723, 4147, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4262, 723, 4148, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4263, 723, 4149, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4264, 723, 4150, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4265, 723, 4151, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4266, 723, 4152, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4267, 723, 4153, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4268, 723, 4154, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4269, 723, 4155, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4270, 723, 4156, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4271, 723, 4157, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4272, 723, 4158, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4273, 747, 1954, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4274, 747, 1965, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4275, 747, 1959, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4276, 225, 4127, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4277, 747, 4127, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4278, 747, 3105, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4279, 225, 3105, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4280, 225, 4130, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4281, 747, 4130, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4282, 747, 1957, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4283, 747, 3192, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4284, 225, 3192, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4285, 747, 1966, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4287, 747, 1960, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4288, 370, 1963, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4289, 747, 1963, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4290, 225, 4170, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4291, 747, 1955, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4292, 225, 4172, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4293, 747, 4172, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4294, 304, 4172, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4295, 747, 1962, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4296, 747, 4170, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4297, 33, 3056, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4298, 33, 3064, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4300, 326, 536, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4301, 326, 1956, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4302, 326, 1958, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4303, 326, 1961, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4304, 326, 1964, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4305, 326, 1967, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4306, 326, 1968, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4307, 326, 3112, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4308, 326, 3707, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4309, 326, 4019, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4310, 326, 4126, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4311, 374, 4159, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4312, 374, 4160, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4313, 374, 4161, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4314, 374, 4162, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4315, 374, 4163, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4316, 374, 4164, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4317, 374, 4165, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4318, 374, 4166, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4319, 374, 4167, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4320, 302, 74, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4321, 340, 613, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4322, 340, 716, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4299, 326, 7529, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10782, 1111, 10188, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10783, 1111, 10189, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10784, 1111, 10190, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10785, 1111, 10191, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10786, 1111, 10192, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4339, 836, 4173, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4340, 836, 4174, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4341, 836, 4176, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4342, 836, 4175, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4343, 836, 4177, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4344, 836, 4178, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4345, 836, 4179, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4346, 836, 4180, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4347, 836, 4181, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4348, 836, 4182, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4349, 836, 4183, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4350, 836, 4184, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4351, 836, 4185, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4352, 836, 4186, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4353, 734, 4187, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4354, 734, 4188, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4355, 734, 4189, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4356, 734, 4190, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4357, 734, 4191, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4358, 734, 4192, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4359, 734, 4193, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4360, 734, 4194, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4361, 750, 4195, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4362, 750, 4196, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4363, 750, 4197, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4364, 750, 4198, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4365, 750, 4199, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4366, 750, 4200, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4367, 750, 4201, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4368, 750, 4202, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4369, 750, 4203, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4370, 750, 4204, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4371, 750, 4205, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4372, 750, 4206, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4373, 750, 4207, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4374, 750, 4208, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4375, 750, 4209, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4376, 750, 4210, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4377, 750, 4211, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (4378, 750, 4212, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (4379, 376, 4213, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4380, 376, 4214, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4381, 376, 4215, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4382, 376, 4216, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4383, 376, 4217, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4384, 376, 4218, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4385, 376, 4219, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4386, 376, 4220, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4387, 376, 4221, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4388, 376, 4222, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4389, 376, 4223, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4390, 376, 4224, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4391, 305, 4225, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4392, 305, 4226, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4393, 305, 4227, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4394, 305, 4228, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4395, 305, 4229, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4396, 381, 168, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4397, 381, 192, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4398, 381, 92, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4399, 381, 98, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4400, 381, 23, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4401, 381, 131, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4402, 381, 280, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4403, 381, 121, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4404, 381, 334, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4405, 381, 239, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4406, 381, 19, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4407, 709, 4230, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4408, 709, 4231, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4409, 709, 4232, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4410, 709, 4233, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4411, 709, 4234, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4412, 709, 4235, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4413, 709, 4236, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4414, 709, 4237, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4415, 709, 4238, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4416, 709, 4239, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4417, 709, 4240, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4418, 709, 4241, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4419, 415, 4242, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4420, 415, 1408, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4421, 415, 4243, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4422, 415, 4244, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4423, 415, 4245, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4424, 415, 4246, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4425, 415, 4247, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4426, 415, 4248, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4427, 415, 4249, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4428, 415, 4250, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4429, 415, 4251, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4430, 415, 4252, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4431, 269, 4253, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4435, 702, 4257, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4436, 702, 4258, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4437, 702, 4259, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4438, 702, 4260, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4439, 702, 4261, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4440, 702, 4262, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4441, 702, 4263, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4442, 702, 4264, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4443, 702, 4265, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4444, 702, 4266, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4445, 702, 4267, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4446, 702, 4268, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4447, 702, 4269, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4448, 702, 4270, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4449, 702, 4271, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4451, 89, 338, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4452, 89, 3767, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4453, 89, 3777, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4454, 89, 2905, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4455, 89, 2927, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4456, 732, 4273, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4457, 732, 4274, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4458, 732, 4275, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4459, 732, 4276, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4460, 732, 4277, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4461, 732, 4278, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4462, 732, 4279, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4463, 732, 4280, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4286, 800, 1960, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4464, 732, 4281, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4465, 732, 4282, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4466, 732, 4283, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4467, 732, 4284, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4468, 732, 4285, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4469, 732, 4286, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4470, 732, 4287, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4471, 732, 4288, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4472, 732, 4289, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (4473, 732, 4290, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (4474, 854, 1067, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4475, 854, 1069, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4476, 854, 1070, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4477, 854, 1074, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4478, 854, 3769, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4479, 854, 4291, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4480, 854, 4292, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4481, 854, 4293, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4482, 854, 3863, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4483, 854, 4294, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4484, 854, 4295, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4485, 854, 4296, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4486, 854, 4297, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4487, 716, 4025, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4488, 716, 4298, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4489, 716, 4299, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4490, 716, 4300, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4491, 716, 4301, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4492, 716, 4302, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4493, 716, 4303, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4494, 98, 4304, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4495, 98, 4305, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4496, 98, 4306, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4497, 98, 4307, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4498, 98, 4308, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4499, 98, 4309, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4500, 98, 4310, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4501, 98, 4311, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4502, 98, 4312, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4503, 98, 4313, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4504, 98, 4314, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4505, 98, 4315, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4506, 314, 4316, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4507, 314, 4317, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4508, 853, 4318, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4509, 853, 4319, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4510, 853, 4320, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4511, 853, 4321, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4512, 853, 4322, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4513, 853, 4323, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4514, 853, 4324, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4515, 853, 4325, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4516, 853, 4326, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4517, 853, 4327, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4518, 853, 4328, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4519, 853, 4329, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4520, 853, 4330, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4521, 853, 4331, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4522, 853, 1390, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4523, 853, 4332, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4524, 853, 4333, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (4525, 853, 4334, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (4526, 853, 4335, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (4527, 853, 4336, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (4529, 64, 2046, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4530, 321, 1210, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4531, 321, 780, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4532, 321, 4170, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4533, 321, 1966, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4534, 321, 1954, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4535, 321, 4338, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4536, 321, 4339, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4537, 321, 3105, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4538, 321, 1211, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4539, 327, 313, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4540, 327, 11, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4541, 327, 67, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4542, 327, 115, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4543, 327, 87, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4544, 327, 156, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4545, 327, 4340, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4546, 327, 276, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4547, 327, 4341, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4548, 327, 4342, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4549, 329, 4343, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4550, 329, 4344, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4551, 329, 4345, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4552, 329, 4346, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4553, 329, 4347, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4554, 329, 4348, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4555, 329, 4349, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4556, 329, 4350, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4557, 329, 4351, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4558, 329, 4352, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4559, 329, 4353, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4560, 329, 4354, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4561, 329, 4355, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4562, 329, 4356, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4563, 329, 4357, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4564, 329, 4358, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4565, 329, 4359, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (4566, 329, 4360, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (4567, 329, 4361, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (4568, 333, 4362, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4569, 333, 2169, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4570, 333, 2170, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4571, 333, 2171, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4572, 152, 4362, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4573, 728, 4362, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4574, 334, 4363, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4575, 334, 4364, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4576, 334, 4365, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4577, 334, 4366, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4578, 334, 4367, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4579, 334, 4368, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4580, 822, 2378, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4581, 822, 4072, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4582, 822, 23, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4583, 822, 4073, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4584, 822, 4074, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4585, 822, 3135, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4586, 822, 4075, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4587, 822, 4076, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4588, 822, 4077, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4589, 822, 4078, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4590, 822, 4079, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4591, 822, 4369, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4592, 418, 4073, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4593, 418, 4075, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4594, 418, 4074, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4595, 418, 4076, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4596, 418, 4077, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4597, 418, 4078, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4598, 418, 4079, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4599, 170, 4370, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4600, 345, 4371, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4601, 345, 4372, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4602, 724, 4373, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4603, 142, 4374, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4604, 142, 4375, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4605, 142, 4376, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4606, 142, 4377, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4607, 142, 4378, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4608, 142, 4379, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4609, 725, 4380, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4610, 725, 4381, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4611, 725, 4382, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4612, 725, 4383, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4613, 725, 4385, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4614, 725, 4386, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4615, 725, 4389, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4616, 724, 4390, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4617, 724, 4391, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4618, 724, 4392, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4619, 151, 4393, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4620, 151, 4394, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4621, 151, 4395, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4622, 151, 4396, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4623, 151, 4397, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4624, 151, 4398, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4625, 151, 4399, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4626, 151, 4400, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4627, 151, 4401, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4628, 151, 4402, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4629, 151, 4403, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4630, 151, 4404, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4631, 151, 4405, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4632, 151, 4406, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4633, 151, 4407, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4634, 151, 4408, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (4635, 102, 2984, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4636, 102, 2316, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4637, 102, 2991, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4638, 257, 4409, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4639, 257, 4410, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4640, 157, 4411, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4641, 157, 4412, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4642, 157, 4413, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4643, 157, 4414, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4644, 157, 4415, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4528, 711, 4337, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4645, 157, 4416, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4646, 157, 4417, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4647, 157, 4418, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4648, 157, 4419, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4649, 157, 4420, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4650, 157, 4421, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4651, 157, 4422, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4652, 157, 4423, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4653, 157, 4424, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4654, 157, 4425, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4655, 157, 4426, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4656, 737, 1212, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4657, 737, 1220, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4658, 737, 1223, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4659, 737, 2168, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4660, 737, 3109, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4661, 737, 4427, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4662, 291, 1212, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4663, 737, 4428, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4664, 737, 4430, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4665, 737, 4431, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4666, 737, 4432, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4667, 737, 4433, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4668, 737, 4434, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4669, 199, 4435, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4670, 199, 4436, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4671, 199, 4437, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4672, 199, 4438, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4673, 199, 4439, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4674, 199, 4440, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4675, 199, 4441, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4676, 199, 4442, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4677, 199, 4443, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4678, 199, 4444, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4679, 199, 4445, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4680, 199, 4446, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4681, 199, 4447, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4682, 199, 4448, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4683, 199, 4449, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4684, 199, 4450, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4685, 199, 4451, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (4686, 199, 4452, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (4687, 199, 4453, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (4688, 199, 4454, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (4689, 199, 4455, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (4690, 199, 4456, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (4691, 217, 4457, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4692, 217, 4458, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4693, 217, 4459, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4694, 217, 4460, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4695, 217, 4461, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4696, 217, 4462, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4697, 217, 4463, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4698, 217, 4464, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4699, 217, 4465, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4700, 217, 4466, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4701, 217, 4467, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4702, 217, 4468, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4703, 244, 4469, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4704, 244, 4470, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4705, 244, 4471, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4706, 244, 4472, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4707, 244, 4473, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4708, 244, 4474, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4709, 244, 4475, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4710, 244, 4476, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4711, 244, 4477, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4712, 244, 4478, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4713, 244, 4479, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4714, 244, 4480, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4715, 244, 4481, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4716, 244, 4482, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4717, 244, 4483, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4718, 244, 4484, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4719, 244, 4485, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (4720, 244, 4486, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (4721, 252, 4487, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4722, 252, 4488, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4723, 252, 4489, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4724, 252, 4490, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4725, 252, 4491, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4726, 252, 4492, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4727, 252, 4493, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4728, 252, 4494, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4729, 252, 4495, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4730, 252, 4496, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4731, 252, 4497, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4732, 252, 4498, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4733, 252, 4499, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4734, 252, 4500, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4735, 288, 1424, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4736, 288, 1426, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4737, 288, 1423, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4738, 288, 1421, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4739, 288, 1425, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4740, 288, 1419, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4741, 288, 1420, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4742, 288, 1422, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4743, 308, 4501, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4744, 308, 4502, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4745, 308, 3730, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4746, 308, 3723, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4747, 308, 3661, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4748, 718, 2009, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4749, 308, 3663, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4750, 308, 4503, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4751, 308, 4504, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4752, 265, 3693, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4753, 745, 1779, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4754, 265, 3690, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4755, 265, 3695, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4756, 308, 4506, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4757, 308, 4507, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4758, 308, 4508, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4759, 308, 4509, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4760, 790, 2839, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4761, 310, 4510, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4762, 310, 4511, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4763, 310, 4512, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4764, 310, 4513, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4765, 310, 4514, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4766, 310, 4515, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4767, 310, 4516, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4768, 310, 4517, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4769, 310, 4518, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4770, 310, 4519, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4771, 310, 4520, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4772, 310, 4521, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4773, 311, 4522, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4774, 311, 4523, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4775, 311, 4524, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4776, 311, 4525, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4777, 311, 4526, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4778, 311, 4527, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4779, 311, 4528, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4780, 311, 4529, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4781, 311, 4530, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4782, 311, 4531, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4783, 311, 4532, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4784, 311, 4533, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4785, 311, 4534, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4786, 311, 4535, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4787, 311, 4536, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4788, 419, 2860, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (4789, 774, 2862, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (4790, 151, 2863, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4791, 231, 3113, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4792, 201, 3666, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4793, 201, 298, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4794, 201, 305, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4795, 385, 3688, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4796, 313, 4552, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4797, 313, 4553, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4798, 313, 4554, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4799, 313, 4555, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4800, 313, 4556, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4801, 313, 4557, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4802, 313, 4558, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4803, 313, 4559, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4804, 313, 4560, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4805, 313, 4561, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4806, 313, 4562, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4807, 313, 4563, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4808, 313, 4564, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4809, 313, 4565, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4810, 312, 3736, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4811, 312, 4542, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4812, 312, 4550, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4813, 312, 4547, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4814, 312, 4544, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4815, 312, 4537, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4816, 312, 4540, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4817, 312, 4548, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4818, 312, 4543, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4819, 312, 4545, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4820, 312, 4551, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4821, 312, 4539, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4822, 312, 4546, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4823, 312, 4538, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4824, 312, 4541, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4825, 312, 4549, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4826, 317, 4566, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4827, 317, 4567, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4828, 317, 4568, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4829, 317, 4570, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4830, 317, 4571, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4831, 317, 4572, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4832, 317, 4573, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4833, 317, 4574, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4834, 317, 4575, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4835, 317, 4576, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4836, 317, 4577, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4837, 317, 4578, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4838, 317, 4579, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4839, 318, 4580, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4840, 318, 4581, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4841, 318, 4582, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4842, 318, 4583, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4843, 318, 4584, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4844, 318, 4585, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4845, 318, 4586, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4846, 318, 4587, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4847, 318, 4588, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4848, 318, 4589, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4849, 318, 4590, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4850, 318, 4591, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4851, 318, 4592, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4852, 318, 4593, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4853, 319, 1468, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4854, 319, 2149, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4855, 319, 2150, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4856, 319, 2762, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4857, 319, 2763, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4858, 319, 2764, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4859, 319, 2765, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4860, 319, 4594, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4861, 319, 4595, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4862, 319, 4596, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4863, 319, 4597, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4864, 319, 4598, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4865, 317, 4624, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4866, 254, 4569, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4867, 254, 4613, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4868, 254, 4614, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4869, 254, 4615, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4870, 254, 4616, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4871, 254, 4617, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4872, 254, 4618, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4873, 254, 4619, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4874, 254, 4620, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4875, 254, 4621, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4876, 254, 4622, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4877, 254, 4623, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4878, 254, 4625, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4879, 320, 4626, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4880, 320, 4627, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4881, 320, 4628, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4882, 320, 4629, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4883, 320, 4630, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4884, 320, 4631, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4885, 320, 4632, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4886, 320, 4633, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4887, 320, 4634, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4888, 320, 4635, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4889, 320, 4636, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4890, 320, 4637, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4891, 320, 4638, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4892, 320, 4639, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4893, 320, 4640, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4894, 320, 4641, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4895, 322, 4642, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4896, 322, 4643, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4897, 322, 4644, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4898, 322, 4645, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4899, 322, 4646, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4900, 322, 4647, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4901, 322, 4648, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4902, 322, 4649, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4903, 322, 4650, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4904, 322, 4651, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4905, 322, 4652, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4906, 322, 4653, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4907, 322, 4654, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4908, 322, 4655, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4909, 323, 4656, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4910, 323, 4657, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4911, 323, 4658, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4912, 323, 4659, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4913, 323, 4660, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4914, 323, 4661, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4915, 323, 4662, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4916, 323, 4663, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4917, 323, 4664, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4918, 323, 4665, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4919, 323, 4666, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4920, 323, 4667, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4921, 323, 4668, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4922, 323, 4669, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4923, 325, 4670, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4924, 325, 4671, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4925, 325, 4672, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4926, 325, 4673, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4927, 325, 4674, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4928, 325, 4675, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4929, 325, 4676, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4930, 325, 4677, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4931, 325, 4678, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4932, 325, 4679, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4933, 325, 4680, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4934, 325, 4681, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4935, 325, 4682, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4936, 325, 4683, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4937, 328, 4684, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4938, 328, 4685, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4939, 328, 4686, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4940, 328, 4687, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4941, 328, 4688, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4942, 328, 4689, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4943, 328, 4690, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4944, 328, 4691, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4945, 328, 4692, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4946, 328, 4693, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4947, 328, 4694, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4948, 328, 4695, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4949, 328, 4696, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4964, 331, 4711, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4965, 331, 4712, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4966, 331, 4713, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4967, 331, 4714, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4968, 331, 4715, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4969, 331, 4716, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4970, 331, 4717, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4971, 331, 4718, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4972, 259, 4719, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4973, 332, 4721, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4974, 332, 4720, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4975, 332, 4722, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4976, 332, 4723, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4977, 332, 4724, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4978, 332, 4725, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4979, 332, 4726, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4980, 332, 4727, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4981, 332, 4728, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4982, 332, 4729, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4983, 332, 4730, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4984, 297, 4731, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4985, 335, 4732, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4986, 335, 4733, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4987, 335, 4734, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4988, 335, 4735, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4989, 335, 4736, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4990, 335, 4737, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4991, 335, 4738, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4992, 335, 4739, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4993, 335, 4740, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4994, 335, 4741, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4995, 336, 3704, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4996, 336, 4742, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4997, 336, 4743, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4998, 336, 4744, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4999, 336, 4745, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5000, 336, 4746, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5001, 336, 4747, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5002, 336, 4748, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5003, 336, 4749, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5004, 336, 4750, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5005, 722, 4599, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5006, 722, 4600, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5007, 722, 4601, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5008, 722, 4602, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5009, 722, 4603, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5010, 722, 4604, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5011, 722, 4606, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5012, 722, 4607, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5013, 722, 4608, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5014, 722, 4609, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5015, 337, 4610, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5016, 337, 4611, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5017, 337, 4751, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5018, 337, 4752, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5019, 337, 4753, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5020, 337, 4754, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5021, 337, 4755, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5022, 337, 4756, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5023, 338, 4760, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5024, 338, 4757, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5025, 338, 4758, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5026, 338, 4759, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5027, 338, 4761, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5028, 338, 4762, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5029, 338, 4763, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5030, 338, 4764, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5031, 338, 4765, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5032, 338, 4766, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5033, 339, 4767, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5034, 339, 4768, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5035, 339, 4769, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5036, 339, 4770, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5037, 339, 4771, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5038, 339, 4772, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5039, 341, 4773, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5040, 341, 4774, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5041, 341, 4775, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5042, 341, 4776, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5043, 341, 4777, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5044, 341, 4778, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5045, 341, 4779, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5046, 341, 4780, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5047, 341, 4781, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5048, 342, 4782, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5049, 342, 4783, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5050, 342, 4784, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5051, 342, 4785, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5052, 342, 4786, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5053, 342, 4787, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5054, 342, 4788, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5055, 342, 4789, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5056, 342, 4790, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5057, 342, 4791, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5058, 342, 4792, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5059, 344, 4793, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5060, 344, 4794, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5061, 344, 4795, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5062, 786, 4796, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5063, 786, 4797, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5064, 786, 4798, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5065, 786, 4799, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5066, 786, 4800, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5067, 786, 4801, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5068, 786, 4802, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5069, 786, 4803, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5070, 786, 4804, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5071, 786, 4805, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5072, 786, 4806, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5073, 786, 4807, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5074, 786, 4808, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5075, 346, 4809, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5076, 346, 4810, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5077, 346, 4811, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5078, 346, 4812, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5079, 346, 4813, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5080, 346, 4814, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5081, 346, 4815, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5082, 346, 4816, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5083, 346, 4817, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5084, 346, 4818, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5085, 346, 4819, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5086, 346, 4820, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5087, 414, 4821, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5088, 414, 4822, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5089, 414, 4823, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5090, 414, 4824, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5101, 349, 4835, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5102, 349, 4836, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5103, 349, 4837, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5104, 349, 4838, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5105, 349, 4839, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5106, 349, 4840, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5107, 349, 4841, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5108, 349, 4842, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5109, 349, 4843, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5110, 349, 4844, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5111, 349, 4845, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5112, 349, 4846, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5113, 350, 4847, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5114, 350, 4848, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5115, 350, 4849, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5116, 350, 4850, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5117, 350, 4851, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5118, 350, 4852, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5119, 350, 4853, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5120, 350, 4854, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5121, 350, 4855, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5122, 350, 4856, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5123, 350, 4857, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5124, 350, 4858, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5125, 350, 4859, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5126, 351, 4860, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5127, 351, 4861, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5128, 351, 4862, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5129, 351, 4863, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5130, 351, 4864, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5131, 351, 4865, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5132, 351, 4866, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5133, 351, 4867, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10780, 1111, 10186, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10781, 1111, 10187, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10787, 1111, 10193, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10788, 1111, 10194, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10789, 1111, 10195, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10791, 1111, 10197, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10792, 1111, 10198, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10793, 1111, 10199, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10794, 1111, 10200, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10795, 1111, 10201, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10796, 1111, 10202, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10763, 1110, 10169, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10764, 1110, 10170, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10765, 1110, 10171, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5148, 353, 4882, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5149, 353, 4883, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5150, 353, 4884, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5151, 353, 4885, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5152, 353, 4886, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5153, 353, 4887, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5154, 353, 4888, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5155, 353, 4889, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5156, 353, 4890, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5157, 353, 4891, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5158, 353, 4892, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5159, 353, 4893, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5160, 353, 4894, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5161, 353, 4895, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5162, 353, 4896, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5163, 353, 4897, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5164, 353, 4898, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5165, 353, 4899, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (5166, 347, 4900, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5167, 347, 4901, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5168, 347, 4902, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5169, 347, 4903, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5170, 347, 4904, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5171, 347, 4905, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5172, 347, 4906, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5173, 347, 4907, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5174, 347, 4908, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5175, 347, 4909, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5176, 347, 4910, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5177, 347, 4911, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5178, 354, 4912, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5179, 354, 4913, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5180, 354, 4914, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5181, 354, 4915, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5182, 354, 4916, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5183, 354, 4917, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5184, 354, 4918, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5185, 354, 4919, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5186, 354, 4920, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5187, 354, 4921, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5188, 354, 4922, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5189, 354, 4923, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5190, 354, 4924, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5191, 354, 4925, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5192, 354, 4926, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5193, 354, 4927, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5194, 354, 4928, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5195, 354, 4929, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (5196, 354, 4930, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (5197, 354, 4931, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (5198, 714, 2958, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5199, 714, 2959, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5200, 714, 4932, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5201, 714, 2957, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5202, 714, 2960, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5203, 714, 2961, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5204, 714, 2963, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5205, 714, 2964, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5206, 714, 4933, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5207, 714, 2962, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5208, 355, 4045, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5209, 355, 4934, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5210, 355, 4935, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5211, 355, 4936, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5212, 355, 4937, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5213, 355, 4938, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5214, 355, 4939, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5215, 355, 4940, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5216, 355, 4941, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5217, 355, 4942, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5218, 355, 4943, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5219, 355, 4944, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5220, 355, 4945, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5221, 356, 4946, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5222, 356, 4947, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5223, 356, 4948, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5224, 356, 4949, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5225, 356, 4950, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5226, 356, 4951, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5227, 356, 4952, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5228, 356, 4953, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5229, 356, 4954, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5230, 356, 4955, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5231, 356, 4956, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5232, 356, 4957, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5233, 356, 4958, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5234, 356, 4959, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5235, 357, 4960, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5236, 357, 4961, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5237, 357, 4962, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5238, 357, 4963, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5239, 357, 4964, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5240, 357, 4965, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5241, 357, 4966, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5242, 357, 4967, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5243, 357, 4968, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5244, 357, 4969, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5245, 357, 4970, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5246, 357, 4971, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5247, 357, 4972, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5248, 357, 4973, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5249, 357, 4974, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5250, 357, 4975, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5251, 358, 4976, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5252, 358, 4977, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5253, 358, 4978, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5254, 358, 4979, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5255, 358, 4980, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5256, 358, 4981, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5257, 358, 4982, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5258, 358, 4983, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5259, 358, 4984, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5260, 358, 4985, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5261, 358, 4986, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5262, 358, 4987, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5288, 361, 5012, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5289, 361, 5013, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5290, 361, 5014, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5291, 361, 5015, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5292, 361, 5016, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5293, 361, 5017, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5294, 361, 5018, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5295, 361, 5019, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5296, 361, 5020, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5297, 361, 5021, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5298, 361, 5022, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5299, 361, 5023, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5300, 361, 5024, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5301, 361, 5025, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5302, 362, 5026, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5303, 362, 5027, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5304, 362, 5028, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5305, 362, 5029, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5306, 362, 5030, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5307, 362, 5031, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5308, 362, 5032, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5309, 362, 5033, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5310, 362, 5034, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5311, 362, 5035, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5312, 362, 5036, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5313, 362, 5037, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5314, 362, 5038, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5315, 362, 5039, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5316, 362, 5040, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5317, 362, 5041, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5318, 363, 5042, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5319, 363, 5043, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5320, 363, 5044, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5321, 363, 5045, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5322, 363, 5046, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5323, 363, 5047, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5324, 363, 5048, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5325, 363, 5049, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5326, 363, 5050, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5327, 363, 5051, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5328, 363, 5052, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5329, 363, 5053, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5330, 363, 5054, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5331, 364, 5055, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5332, 364, 5056, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5333, 364, 5057, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5334, 364, 5058, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5335, 364, 5059, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5336, 364, 5060, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5337, 364, 5061, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5338, 364, 5062, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5339, 364, 5063, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5340, 364, 5064, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5341, 364, 5065, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5342, 364, 5066, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5343, 367, 1121, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5344, 367, 1122, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5345, 367, 1123, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5346, 367, 1124, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5347, 367, 1125, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5348, 367, 1126, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5349, 367, 1127, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5350, 367, 1128, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5351, 367, 1129, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5352, 367, 1130, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5353, 367, 1131, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5354, 367, 1132, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5355, 367, 1133, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5356, 367, 1134, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5357, 367, 1135, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5358, 367, 1136, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5359, 367, 1137, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5360, 367, 1138, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (5361, 367, 1139, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (5362, 367, 1140, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (5363, 367, 1141, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (5364, 367, 1142, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (5365, 367, 1143, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (5366, 367, 1144, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (5367, 367, 1145, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (5381, 373, 5080, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5382, 373, 5081, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5383, 373, 5082, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5384, 373, 5083, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5385, 373, 5084, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5386, 373, 5085, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5387, 373, 5086, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5388, 373, 5087, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5389, 373, 5088, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5390, 373, 5089, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5391, 373, 5090, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5392, 373, 5091, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5393, 373, 5092, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5394, 373, 5093, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5395, 373, 5094, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5396, 373, 5095, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5397, 373, 5096, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5272, 360, 4997, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5273, 360, 4998, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5274, 360, 4999, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5275, 360, 5000, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5276, 360, 5001, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5277, 360, 5002, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5278, 360, 5003, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5279, 360, 5004, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5411, 377, 5099, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5412, 377, 5100, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5413, 377, 5101, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5414, 377, 5102, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5415, 377, 5103, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5416, 377, 5104, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5417, 377, 5105, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5418, 377, 5106, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5419, 377, 5107, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5420, 377, 5108, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5421, 377, 5109, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5422, 377, 5110, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5423, 377, 5111, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5424, 377, 5112, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5425, 377, 5113, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5426, 377, 5114, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5427, 377, 5115, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5428, 369, 5116, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5429, 369, 5117, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5430, 369, 5118, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5431, 369, 5119, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5432, 369, 5120, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5433, 369, 5121, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5434, 369, 5122, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5435, 369, 5123, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5436, 369, 5124, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5437, 369, 5125, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5438, 725, 1036, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5439, 725, 1040, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5440, 234, 2626, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5441, 378, 2487, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5442, 378, 2531, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5443, 378, 4384, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5444, 380, 4388, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5445, 380, 5097, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5446, 380, 5126, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5447, 380, 5127, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5448, 380, 5128, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5449, 380, 5129, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5450, 380, 5130, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5451, 382, 5131, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5452, 382, 5132, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5453, 382, 5133, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5454, 382, 5134, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5455, 382, 5135, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5456, 382, 5136, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5457, 382, 5137, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5458, 382, 5138, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5459, 382, 5139, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5460, 382, 5140, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5461, 382, 5141, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5462, 382, 5142, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5463, 382, 5143, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5464, 384, 5144, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5465, 384, 5145, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5466, 384, 5146, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5467, 384, 5147, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5468, 384, 5148, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5469, 384, 5149, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5470, 384, 5150, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5471, 384, 5151, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5472, 384, 5152, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5473, 384, 5153, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5474, 384, 5154, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5475, 384, 5155, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5476, 384, 5156, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5477, 384, 5157, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5478, 384, 5158, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5479, 386, 5159, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5480, 386, 5160, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5481, 386, 5161, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5482, 386, 5162, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5483, 386, 5163, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5484, 386, 5164, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5485, 386, 5165, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5486, 386, 5166, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5487, 386, 5167, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5488, 386, 5168, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5489, 386, 5169, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (5490, 387, 1453, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5491, 387, 1454, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5492, 387, 1455, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5493, 387, 1456, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5494, 387, 1457, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5495, 387, 1458, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5496, 387, 1459, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5497, 387, 1460, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5498, 387, 1461, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5499, 387, 1462, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5500, 387, 1463, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5501, 387, 1464, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5502, 387, 1989, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5503, 387, 1987, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5504, 389, 5170, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5505, 389, 5171, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5506, 389, 5172, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5507, 389, 5173, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5508, 389, 5174, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5509, 389, 5175, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5510, 389, 5176, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5511, 389, 5177, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5512, 389, 5178, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5513, 389, 5179, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5514, 389, 5180, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5515, 389, 5181, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5516, 389, 5182, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5517, 387, 1992, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5518, 387, 1983, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5519, 387, 2778, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5520, 390, 5183, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5521, 390, 5184, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5522, 390, 5185, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5523, 390, 5186, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5524, 390, 5187, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5525, 390, 5188, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5526, 390, 5189, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5527, 390, 5190, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5528, 390, 5191, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5529, 390, 5192, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5530, 390, 5193, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5531, 390, 5194, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5532, 391, 5195, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5533, 391, 5196, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5534, 391, 5197, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5535, 391, 5198, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5536, 391, 5199, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5537, 391, 5200, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5538, 391, 5201, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5539, 391, 5202, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5540, 391, 5203, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5541, 391, 5204, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5542, 391, 5205, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5543, 391, 5206, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5544, 391, 5207, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5545, 749, 5208, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5546, 392, 2245, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5547, 392, 2238, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5548, 392, 2242, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5549, 392, 2236, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5550, 392, 5209, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5551, 392, 5210, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5552, 392, 5211, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5553, 392, 5212, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5554, 392, 2240, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5555, 392, 2244, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5556, 392, 2237, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5557, 392, 2243, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5558, 392, 2239, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5559, 392, 2241, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5560, 393, 5213, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5561, 393, 5214, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5562, 393, 5215, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5563, 393, 5216, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5564, 393, 5217, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5565, 393, 5218, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5566, 393, 5219, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5567, 393, 5220, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5568, 393, 5221, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5569, 393, 5222, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5570, 393, 5223, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5571, 393, 5224, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5587, 395, 5240, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5588, 395, 5241, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5589, 395, 5242, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5590, 395, 5243, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5591, 395, 5244, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5592, 395, 5245, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5593, 395, 5246, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5594, 395, 5247, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5595, 395, 5248, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5596, 395, 5249, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5597, 395, 5250, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5598, 395, 5251, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5599, 395, 5252, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5600, 395, 5253, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5601, 395, 5254, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5602, 395, 5255, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5603, 395, 5256, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5604, 395, 5257, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (10797, 1112, 10203, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10798, 1112, 10204, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10799, 1112, 10205, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10898, 1121, 1359, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10899, 1121, 1360, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10900, 1121, 184, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10901, 1121, 110, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10902, 1121, 139, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5605, 395, 5258, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (5606, 395, 5259, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (5607, 395, 5260, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (5608, 395, 5261, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (5609, 395, 5262, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (5610, 395, 5263, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (5611, 396, 1400, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5612, 396, 1404, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5613, 396, 1401, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5614, 396, 1403, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5615, 396, 1381, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5616, 396, 798, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5617, 396, 1376, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5618, 396, 1377, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5619, 396, 1375, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5620, 396, 227, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5621, 396, 1388, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5622, 396, 216, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5623, 397, 5264, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5624, 397, 5265, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5625, 397, 5266, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5626, 397, 5267, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5627, 397, 5268, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5628, 397, 5269, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5629, 397, 5270, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5630, 397, 5271, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5631, 397, 5272, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5632, 397, 5273, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5633, 397, 5274, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5634, 397, 5275, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5635, 397, 5276, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5636, 400, 5277, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5637, 400, 5278, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5638, 400, 5279, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5639, 400, 5280, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5640, 400, 5281, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5641, 400, 5282, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5642, 400, 5283, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5643, 400, 5284, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5644, 400, 5285, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5645, 400, 5286, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5646, 400, 5287, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5647, 400, 5288, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5648, 400, 5289, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5649, 400, 5290, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5650, 400, 5291, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5651, 401, 5292, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5652, 401, 5293, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5653, 401, 5294, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5654, 401, 5295, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5655, 401, 5296, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5656, 401, 5297, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5657, 401, 5298, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5658, 401, 5299, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5659, 401, 5300, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5660, 401, 5301, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5661, 401, 5302, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5662, 402, 5303, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5663, 402, 5304, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5664, 402, 5305, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5665, 402, 5306, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5666, 402, 5307, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5667, 402, 5308, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5668, 402, 5309, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5669, 402, 5310, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5670, 402, 5311, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5671, 402, 5312, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5672, 402, 5313, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5673, 402, 5314, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5674, 402, 5315, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5675, 402, 5316, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5676, 402, 5317, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5689, 404, 5318, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5690, 404, 5319, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5691, 404, 5320, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5692, 404, 5321, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5693, 404, 5322, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5694, 404, 5323, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5695, 404, 5324, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5696, 404, 5325, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5697, 404, 5326, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5698, 404, 5327, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5699, 404, 5328, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5700, 404, 5329, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5701, 404, 5330, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5702, 404, 5331, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5703, 404, 5332, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5704, 404, 5333, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5705, 404, 5334, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5706, 405, 5335, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5707, 405, 5336, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5708, 405, 5337, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5709, 405, 5338, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5710, 405, 5339, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5711, 405, 5340, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5712, 405, 5341, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5713, 405, 5342, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5714, 405, 5343, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5715, 405, 5344, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5716, 405, 5345, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5717, 405, 5346, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5718, 407, 1389, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5719, 407, 1384, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5720, 407, 1385, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5721, 407, 1390, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5722, 407, 319, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5723, 407, 285, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5724, 407, 1395, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5725, 407, 1398, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5726, 407, 1397, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5727, 407, 1382, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5728, 409, 5347, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5729, 409, 5348, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5730, 409, 5349, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5731, 64, 2552, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5732, 410, 784, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5733, 410, 4605, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5734, 410, 4612, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5735, 410, 5350, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5736, 410, 5351, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5737, 410, 5352, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5738, 410, 5353, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5739, 410, 5354, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5740, 410, 5355, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5741, 410, 5356, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5742, 410, 5357, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5743, 410, 5358, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5744, 410, 5359, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5745, 410, 5360, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5746, 410, 5361, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5747, 410, 5362, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5748, 411, 977, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5749, 411, 978, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5750, 411, 979, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5751, 411, 980, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5752, 411, 981, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5753, 411, 985, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5754, 411, 986, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5755, 411, 987, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5756, 411, 5363, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5757, 411, 5364, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5758, 411, 5365, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5759, 411, 5366, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5760, 411, 5367, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5761, 411, 5368, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5762, 411, 5369, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5763, 411, 5370, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5764, 412, 5371, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5765, 412, 5372, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5766, 412, 5373, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5767, 412, 5374, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5768, 412, 5375, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5769, 412, 5376, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5770, 412, 5377, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5771, 412, 5378, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5772, 412, 5379, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5773, 412, 5380, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5774, 412, 5381, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5775, 412, 5382, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5776, 412, 5383, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5777, 412, 5384, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5778, 412, 5385, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5779, 412, 5386, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5780, 412, 5387, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5781, 409, 5388, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5782, 409, 5389, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5783, 409, 5390, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5784, 409, 5391, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5785, 409, 5392, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5786, 409, 5393, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5787, 409, 5394, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5788, 413, 1169, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5789, 413, 1172, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10800, 1112, 10206, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10801, 1112, 10207, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10802, 1112, 10208, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5790, 413, 554, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5791, 413, 555, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5792, 413, 1174, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5793, 413, 557, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5794, 413, 558, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5795, 413, 559, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5796, 413, 560, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5797, 413, 561, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5798, 413, 1170, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5799, 413, 563, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5800, 413, 564, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5801, 413, 1176, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5802, 413, 566, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5803, 413, 567, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5804, 413, 568, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5805, 413, 569, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (5806, 413, 570, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (5807, 413, 1177, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (5808, 416, 5395, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5809, 416, 5396, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5810, 416, 5397, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5811, 416, 5398, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5812, 416, 5399, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5813, 416, 5400, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5814, 416, 5401, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5815, 416, 5402, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5816, 416, 5403, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5817, 416, 5404, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5818, 416, 5405, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5819, 416, 5406, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5820, 416, 5407, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5821, 416, 5408, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5822, 422, 5409, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5823, 422, 5410, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5824, 422, 5411, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5825, 422, 5412, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5826, 422, 5413, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5827, 422, 5414, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5828, 422, 5415, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5829, 422, 5416, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5830, 422, 5417, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5831, 422, 5418, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5832, 422, 5419, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5833, 422, 5420, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5834, 422, 5421, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5835, 422, 5422, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5836, 422, 5423, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5837, 422, 5424, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5838, 422, 5425, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5839, 422, 5426, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (5840, 422, 5427, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (5841, 422, 5428, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (5842, 423, 5429, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5843, 423, 5430, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5844, 423, 5431, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5845, 423, 5432, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5846, 423, 5433, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5847, 423, 5434, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5848, 423, 5435, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5849, 423, 5436, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5850, 423, 5437, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5851, 423, 5438, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5852, 423, 5439, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5853, 423, 5440, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5854, 424, 5441, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5855, 424, 5443, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5856, 424, 5445, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5857, 424, 5446, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5858, 424, 5447, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5859, 424, 5448, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5860, 424, 5449, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5861, 424, 5450, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5862, 424, 5451, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5863, 424, 5452, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5864, 425, 5453, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5865, 425, 5454, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5866, 425, 5455, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5867, 425, 5456, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5868, 425, 5457, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5869, 425, 5458, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5870, 425, 5459, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5871, 425, 5460, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5872, 425, 5461, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5873, 425, 5462, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5874, 425, 5463, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5875, 425, 5464, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5876, 424, 5442, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5877, 424, 5444, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5878, 426, 479, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5879, 426, 480, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5880, 426, 481, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5881, 426, 482, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5882, 426, 483, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5883, 426, 484, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5884, 427, 485, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5885, 427, 486, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5886, 427, 488, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5887, 427, 489, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5888, 427, 490, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5889, 427, 491, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5890, 427, 492, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5891, 427, 493, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5892, 427, 494, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5893, 427, 495, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5894, 428, 1714, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5895, 428, 2037, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5896, 428, 2908, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5897, 428, 3915, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5898, 428, 4124, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5899, 428, 5465, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5900, 428, 5466, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5901, 428, 5467, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5902, 428, 5468, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5903, 428, 5469, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5904, 428, 5470, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5905, 428, 5471, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5906, 428, 5472, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5907, 428, 5473, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5908, 428, 5474, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5909, 429, 5475, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5910, 429, 5476, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5911, 429, 5477, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5912, 429, 5478, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5913, 429, 5479, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5914, 429, 5480, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5915, 429, 5481, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5916, 429, 5482, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5917, 429, 5483, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5918, 429, 5484, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5919, 429, 5485, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5920, 429, 5486, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5921, 429, 5487, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5922, 429, 5488, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5923, 429, 5489, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5924, 429, 5490, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5925, 134, 164, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5926, 430, 5491, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5927, 430, 5492, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5928, 430, 5493, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5929, 430, 5494, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5930, 430, 5495, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5931, 430, 5496, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5932, 430, 5497, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5933, 430, 5498, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5934, 430, 5499, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5935, 430, 5500, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5936, 430, 5501, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5937, 430, 5502, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5938, 430, 5503, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5939, 431, 5504, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5940, 431, 5505, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5941, 431, 5506, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5942, 431, 5507, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5943, 431, 5508, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5944, 431, 5509, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5945, 431, 5510, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5946, 431, 5511, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5947, 432, 5512, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5948, 432, 5513, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5949, 432, 5514, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5950, 432, 5515, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5951, 432, 5516, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5952, 432, 5517, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5953, 432, 5518, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5954, 432, 5519, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5965, 434, 5530, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5966, 434, 5531, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5967, 434, 5532, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5968, 434, 5533, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5969, 434, 5534, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5970, 434, 5535, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5971, 434, 5536, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5972, 434, 5537, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5973, 434, 5538, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5974, 434, 5539, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5975, 434, 5540, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5976, 434, 5541, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5977, 434, 5542, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5978, 434, 5543, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5979, 124, 3845, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5980, 435, 3845, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5981, 435, 2961, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5982, 435, 4113, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5983, 435, 3849, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5984, 435, 5544, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5985, 435, 5545, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5986, 435, 5546, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5987, 435, 5547, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5988, 435, 5548, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5989, 435, 5549, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5990, 435, 5550, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5991, 435, 3850, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5992, 435, 5552, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5993, 435, 5553, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5994, 435, 5551, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5995, 435, 4117, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5996, 435, 4932, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5997, 435, 5555, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (5998, 435, 5556, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (5999, 435, 5554, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (6012, 437, 168, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6013, 437, 145, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6014, 437, 190, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6015, 437, 173, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6016, 437, 338, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6017, 437, 357, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6018, 437, 51, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6019, 437, 75, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6020, 437, 246, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6021, 437, 65, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6022, 437, 102, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6023, 437, 329, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2898, 268, 2896, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2899, 268, 2897, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2900, 268, 2898, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6066, 308, 420, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6067, 442, 5609, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6068, 442, 5610, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6069, 442, 5611, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6070, 442, 5612, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6071, 442, 5613, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6072, 442, 5614, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6073, 442, 5615, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6074, 442, 5616, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6075, 442, 5617, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6076, 442, 5618, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6077, 442, 5619, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6078, 442, 5620, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6079, 442, 5621, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6080, 442, 5622, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6081, 441, 5623, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6082, 441, 5624, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6083, 441, 5625, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6084, 441, 5626, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6085, 441, 5627, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6086, 441, 5628, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6087, 441, 5629, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6088, 441, 5630, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6089, 441, 5631, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6090, 441, 5632, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6091, 441, 5633, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6092, 441, 5634, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6093, 441, 5635, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6094, 441, 5636, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6095, 441, 5637, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6111, 444, 5653, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6112, 444, 5654, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6113, 444, 5655, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6114, 444, 5656, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6115, 444, 5657, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6116, 444, 5658, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6117, 444, 5659, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6118, 444, 5660, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6119, 444, 5661, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6120, 444, 5662, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6121, 444, 5663, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6122, 444, 5664, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6123, 444, 5665, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6124, 64, 2045, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6125, 64, 2050, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6126, 64, 2048, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6127, 64, 2051, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6128, 445, 776, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6129, 445, 779, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6130, 445, 781, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6131, 445, 782, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6132, 445, 4505, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6133, 445, 5666, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6134, 445, 5667, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6135, 445, 5668, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6136, 445, 5669, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6137, 445, 5670, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6138, 445, 5671, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6139, 445, 5672, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6140, 446, 5673, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6141, 446, 5674, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6142, 446, 5675, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6143, 446, 5676, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6144, 446, 5677, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6145, 446, 5678, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6146, 446, 5679, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6147, 446, 5680, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6148, 446, 5681, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6149, 446, 5682, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6150, 446, 5683, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6151, 446, 5684, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6152, 446, 5685, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6153, 446, 5686, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6155, 447, 5687, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6053, 440, 5596, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6054, 440, 5597, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6055, 440, 5598, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6056, 440, 5599, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6057, 440, 5600, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6058, 440, 5601, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6059, 440, 5602, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6060, 440, 5603, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6061, 440, 5604, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6062, 440, 5605, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6063, 440, 5606, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6064, 440, 5607, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6065, 440, 5608, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6156, 447, 5688, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6157, 447, 5689, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6158, 447, 5690, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6159, 447, 5691, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6000, 436, 2424, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6001, 436, 4114, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6002, 436, 5557, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6003, 436, 5558, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6004, 436, 5559, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6005, 436, 5560, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2895, 268, 2893, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2896, 268, 2894, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2897, 268, 2895, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2901, 268, 2899, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2902, 268, 2900, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2903, 268, 2901, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2904, 268, 2902, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2905, 268, 2903, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2906, 268, 2904, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6235, 455, 5747, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6170, 448, 445, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6171, 448, 447, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6172, 448, 448, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6173, 448, 5702, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6174, 448, 5703, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6175, 448, 5704, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6176, 448, 5705, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6177, 448, 5706, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6096, 443, 5638, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6097, 443, 5639, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6178, 449, 5707, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6179, 449, 5708, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6180, 449, 5709, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6181, 449, 5710, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6182, 449, 5711, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6183, 449, 5712, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6184, 449, 5713, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6185, 449, 5714, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6186, 449, 5715, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6187, 449, 5716, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6188, 449, 5717, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6189, 449, 5718, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6196, 450, 5725, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6197, 450, 5726, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6198, 450, 5727, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6199, 450, 5728, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6200, 450, 5729, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6201, 450, 5730, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6202, 450, 5731, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6203, 450, 5732, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6204, 450, 5733, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6205, 450, 5734, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6206, 450, 5735, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6207, 450, 5736, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6208, 451, 585, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6209, 451, 706, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6210, 451, 631, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6211, 451, 703, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6212, 451, 704, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6213, 451, 633, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6214, 451, 707, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6215, 451, 586, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6216, 451, 705, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6217, 451, 588, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6218, 452, 5737, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6219, 452, 5738, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6220, 452, 5739, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6221, 452, 5740, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6222, 452, 5741, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6223, 452, 5742, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6224, 452, 5743, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6225, 452, 5744, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6226, 452, 5745, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6227, 452, 5746, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6228, 18, 711, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6229, 18, 710, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6230, 18, 708, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6231, 18, 806, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6248, 453, 5760, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6249, 453, 5761, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6250, 453, 5762, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6251, 453, 5763, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6252, 453, 5764, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6253, 453, 5765, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6254, 453, 5766, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6255, 453, 5767, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6256, 453, 5768, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6257, 453, 5769, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6258, 453, 5770, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6259, 453, 5771, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6260, 453, 5772, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6261, 453, 5773, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6262, 453, 5774, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6263, 453, 5775, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6264, 453, 5776, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (6265, 456, 5777, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6266, 456, 5778, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6267, 456, 5779, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6268, 456, 5780, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6269, 456, 5781, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6270, 456, 5782, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6271, 456, 5783, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6272, 456, 5784, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6273, 456, 5785, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6274, 456, 5786, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6275, 456, 722, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6276, 456, 726, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6277, 456, 5787, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6279, 456, 5788, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6280, 456, 725, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6281, 456, 5789, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6282, 456, 724, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (6283, 456, 723, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (6284, 456, 52, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (6285, 457, 5790, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6286, 457, 5791, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6287, 457, 5792, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6288, 457, 5793, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6289, 457, 5794, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6290, 457, 5795, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6291, 457, 5796, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6292, 457, 5797, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6293, 457, 5798, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6294, 457, 5799, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6295, 457, 5800, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6296, 457, 5801, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6297, 458, 5802, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6298, 458, 5803, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6299, 458, 5804, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6300, 458, 5805, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6301, 458, 5806, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6302, 458, 5807, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6303, 458, 5808, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6304, 458, 5809, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6305, 458, 5810, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6306, 458, 5811, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6307, 458, 5812, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6308, 458, 5813, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6309, 458, 5814, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6310, 458, 5815, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6311, 458, 5816, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6312, 459, 5817, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6313, 459, 5818, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6314, 459, 5819, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6315, 459, 5820, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6316, 459, 5821, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6317, 459, 5822, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6318, 459, 5823, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6319, 459, 5824, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6320, 459, 5825, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6321, 459, 5826, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6322, 459, 5827, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6323, 459, 5828, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6324, 459, 5829, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6325, 460, 5830, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6326, 460, 5831, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6327, 460, 5832, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6328, 460, 5833, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6329, 460, 5834, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6330, 460, 5835, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6331, 460, 5836, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6332, 460, 5837, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6333, 460, 5838, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6334, 460, 5839, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6335, 460, 5840, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6336, 460, 5841, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6337, 460, 5842, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6338, 460, 5843, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6339, 460, 5844, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6340, 461, 1363, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6341, 461, 1364, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6342, 461, 1365, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6343, 461, 1366, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6344, 461, 1367, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6345, 461, 1368, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6346, 461, 1369, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6347, 461, 1370, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6348, 461, 1371, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6349, 461, 1372, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6350, 461, 1373, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6351, 461, 1374, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6352, 461, 5845, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6353, 461, 5846, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6354, 461, 5847, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6355, 461, 5848, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6356, 461, 5849, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (6357, 461, 5850, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (6358, 461, 5851, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (6359, 461, 5852, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (6360, 461, 5853, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (6361, 461, 5854, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (6362, 461, 5855, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (6363, 461, 5856, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (6365, 725, 4387, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6366, 292, 4610, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9960, 1056, 9387, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10803, 1112, 10209, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10804, 1112, 10210, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10805, 1112, 10211, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6382, 463, 5872, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6383, 463, 5873, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6384, 463, 5874, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6385, 463, 5875, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6386, 463, 5876, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6387, 463, 5877, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6388, 463, 5878, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6389, 463, 5879, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6390, 463, 5880, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6391, 463, 5881, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6392, 463, 5882, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1654, 177, 1612, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1655, 177, 1613, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1656, 177, 1614, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10852, 1116, 10258, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10853, 1116, 10259, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10854, 1116, 10260, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10855, 1116, 10261, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6195, 449, 5724, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (6278, 57, 5787, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6393, 463, 5883, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6394, 463, 5884, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6395, 463, 5885, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6396, 463, 5886, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6397, 463, 5887, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6398, 463, 5888, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (6399, 465, 5889, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6400, 465, 5890, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6401, 465, 5891, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6402, 465, 5892, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6403, 465, 5893, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6404, 465, 5894, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6405, 465, 5895, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6406, 465, 5896, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6407, 465, 5897, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6408, 465, 5898, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6409, 465, 5899, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6410, 465, 5900, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6411, 465, 5901, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6412, 465, 5902, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6413, 465, 5903, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6414, 465, 5904, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6415, 466, 5905, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6416, 466, 5906, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6417, 466, 5907, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6418, 466, 5908, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6419, 466, 5909, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6420, 466, 5910, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6421, 466, 5911, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6422, 466, 5912, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6423, 466, 5913, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6424, 466, 5914, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6425, 466, 5915, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6426, 466, 5916, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6427, 466, 5917, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6428, 467, 5918, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6429, 467, 5919, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6430, 467, 5920, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6431, 467, 5921, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6432, 467, 5922, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6433, 467, 5923, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6434, 467, 5924, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6435, 467, 5925, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6436, 467, 5926, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6437, 467, 5927, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6438, 467, 5928, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6439, 467, 5929, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6440, 467, 5930, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6441, 467, 5931, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6442, 467, 5932, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6443, 467, 5933, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6444, 467, 5934, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (6445, 468, 5935, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6446, 468, 5936, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6447, 468, 5937, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6448, 468, 5938, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6449, 468, 5939, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6450, 468, 5940, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6451, 468, 5941, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6452, 468, 5942, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6453, 468, 5943, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6454, 468, 5944, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6455, 468, 5945, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6456, 468, 5946, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6457, 468, 5947, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6458, 468, 5948, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6459, 469, 142, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6460, 469, 243, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6461, 469, 3115, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6462, 469, 4272, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6463, 469, 5949, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6464, 469, 5950, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6465, 469, 5951, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6466, 469, 5952, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6467, 469, 5953, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6468, 469, 5954, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6469, 469, 5955, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6470, 469, 5956, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6471, 469, 5957, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6472, 469, 5958, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6473, 469, 5959, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6474, 470, 5960, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6475, 470, 5961, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6476, 470, 5962, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6477, 470, 5963, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6478, 471, 5964, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6479, 471, 5965, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6480, 471, 5966, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6481, 471, 5967, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6482, 472, 5968, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6483, 472, 5969, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6484, 472, 5970, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6485, 472, 5971, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6486, 472, 5972, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6487, 472, 5973, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6488, 472, 5974, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6489, 472, 5975, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6490, 472, 5976, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6491, 472, 5977, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6492, 472, 5978, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6493, 472, 5979, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6494, 472, 5980, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6495, 472, 5981, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6496, 472, 5982, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6497, 472, 5983, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6498, 473, 5984, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6499, 473, 5985, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6500, 473, 5986, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6501, 473, 5987, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6502, 473, 5988, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6503, 473, 5989, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6504, 473, 5990, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6505, 473, 5991, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6506, 473, 5992, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6507, 473, 5993, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6508, 473, 5994, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6509, 473, 5995, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6510, 473, 5996, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6511, 473, 5997, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6512, 474, 5998, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6513, 474, 5999, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6514, 474, 6000, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6515, 474, 6001, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6516, 474, 6002, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6517, 474, 6003, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6518, 474, 6004, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6519, 474, 6005, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6520, 474, 6006, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6521, 474, 6007, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6522, 475, 6008, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6523, 475, 6009, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6524, 475, 6010, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6525, 475, 6011, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6526, 475, 6012, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6527, 476, 524, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6528, 476, 525, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6529, 476, 526, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10806, 1112, 10212, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6367, 462, 5857, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10807, 1112, 10213, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10808, 1112, 10214, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9961, 1056, 9388, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9962, 1056, 9389, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6530, 476, 527, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6531, 476, 528, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6532, 476, 529, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6533, 476, 126, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6534, 476, 93, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6535, 476, 531, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6553, 478, 6013, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6554, 478, 6014, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6555, 478, 6015, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6556, 478, 6016, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6557, 478, 6017, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6558, 478, 6018, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6559, 478, 526, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6560, 737, 6017, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6564, 479, 6020, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6565, 479, 6021, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6566, 479, 6022, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6567, 479, 6023, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6568, 479, 6024, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6569, 479, 6025, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6570, 479, 6026, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6571, 479, 6027, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6572, 479, 6028, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6573, 479, 6029, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6574, 479, 6030, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6575, 479, 6031, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6576, 479, 6032, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6577, 479, 6033, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6578, 479, 6034, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6579, 479, 6035, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6580, 479, 6036, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (6581, 479, 6037, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (6582, 480, 4429, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6583, 480, 6019, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6584, 480, 6038, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6585, 480, 6039, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6586, 480, 6040, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6587, 480, 6041, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6588, 480, 6042, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6589, 480, 6043, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6590, 480, 6044, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6591, 480, 6045, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6592, 480, 6046, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6593, 480, 6047, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6594, 480, 6048, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6595, 481, 149, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6596, 481, 912, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6597, 481, 106, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6598, 481, 910, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6599, 481, 6049, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6600, 481, 906, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6601, 481, 908, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6602, 481, 909, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6603, 481, 6050, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6604, 481, 6051, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6605, 481, 904, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6606, 481, 3533, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6607, 482, 927, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6608, 482, 200, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6609, 482, 929, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6610, 482, 930, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6611, 482, 167, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6612, 482, 6052, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6613, 482, 928, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6614, 482, 350, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6615, 482, 931, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6616, 482, 117, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6617, 482, 933, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6618, 482, 795, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6619, 483, 6053, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6620, 483, 6054, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6621, 483, 6055, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6622, 483, 6056, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6623, 483, 6057, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6624, 483, 6058, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6625, 483, 6059, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6626, 483, 6060, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6627, 483, 6061, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6628, 483, 6062, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6629, 483, 6063, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6630, 483, 6064, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6631, 483, 6065, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6632, 483, 6066, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6633, 483, 6067, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6634, 483, 6068, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6635, 485, 6069, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6636, 485, 6070, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6637, 485, 6071, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6638, 485, 6072, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6639, 485, 6073, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6640, 485, 6074, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6641, 485, 6075, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6642, 485, 6076, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6643, 485, 6077, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6644, 485, 6078, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6645, 485, 6079, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6646, 485, 6080, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6647, 485, 6081, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6648, 485, 6082, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6649, 485, 6083, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6650, 487, 6084, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6651, 487, 6085, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6652, 487, 6086, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6653, 487, 6087, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6654, 487, 6088, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6655, 487, 6089, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6656, 487, 6090, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6657, 487, 6091, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6658, 487, 6092, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6659, 487, 6093, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6660, 487, 6094, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6661, 487, 6095, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6662, 487, 6096, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6663, 487, 6097, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6664, 488, 6098, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6665, 488, 6099, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6666, 488, 6100, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6667, 488, 6101, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6668, 488, 6102, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6669, 488, 6103, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6670, 488, 6104, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6671, 488, 6105, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6672, 488, 6106, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6673, 488, 6107, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6674, 488, 6108, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6675, 488, 6109, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6676, 488, 6110, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6677, 488, 6111, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6678, 488, 6112, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6679, 486, 6113, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6680, 486, 6114, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6681, 486, 6115, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6682, 486, 6116, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6683, 486, 6117, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6684, 486, 6118, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6685, 486, 6119, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6686, 486, 6120, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6687, 486, 6121, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6688, 486, 6122, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6689, 486, 6123, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6690, 486, 6124, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6691, 486, 6125, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6692, 486, 6126, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6693, 486, 6127, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6694, 486, 6128, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6695, 489, 6129, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6696, 489, 6130, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6697, 489, 6131, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6698, 489, 6132, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6699, 489, 6133, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6700, 489, 6134, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6701, 489, 6135, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6702, 489, 6136, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6703, 489, 6137, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6704, 489, 6138, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6705, 489, 6139, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6706, 489, 6140, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6735, 491, 6169, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6736, 491, 6170, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6737, 491, 6171, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6738, 491, 6172, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6739, 491, 6173, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6740, 491, 6174, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6741, 491, 6175, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6742, 491, 6176, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6743, 491, 6177, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6744, 491, 6178, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6745, 491, 6179, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6746, 491, 6180, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6747, 491, 6181, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6748, 491, 6182, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6749, 491, 6183, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6750, 491, 6184, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6751, 491, 6185, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (6752, 492, 6186, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6753, 492, 6187, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6754, 492, 6188, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6755, 492, 6189, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6756, 492, 6190, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6757, 492, 6191, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6758, 492, 6192, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6759, 492, 6193, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6760, 492, 6194, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6761, 492, 6195, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6762, 492, 6196, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6763, 492, 6197, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6764, 492, 6198, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6765, 492, 6199, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6766, 492, 6200, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6767, 493, 6201, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6768, 493, 6202, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6769, 493, 6203, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6770, 493, 6204, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6771, 493, 6205, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6772, 493, 6206, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6773, 493, 6207, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6774, 493, 6208, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6775, 493, 6209, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6776, 493, 6210, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6777, 493, 6211, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6778, 493, 6212, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6779, 493, 6213, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6780, 493, 6214, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6781, 493, 6215, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6782, 493, 6216, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6783, 493, 6217, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (6784, 493, 6218, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (6785, 493, 6219, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (6786, 493, 6220, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (6787, 493, 6221, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (6788, 493, 6222, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (6789, 493, 6223, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (6790, 493, 6224, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (6791, 493, 6225, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (6792, 493, 6226, 26);
INSERT INTO 'albumsrecordingsmap' VALUES (6793, 493, 6227, 27);
INSERT INTO 'albumsrecordingsmap' VALUES (6794, 494, 6228, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6795, 494, 6229, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6796, 494, 6230, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6797, 494, 6231, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6798, 494, 6232, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6799, 494, 6233, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6800, 494, 6234, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6801, 494, 6235, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6802, 494, 6236, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6803, 494, 6237, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6804, 494, 6238, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6805, 494, 6239, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6806, 494, 6240, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6809, 495, 6243, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6810, 495, 6244, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6811, 495, 6245, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6812, 495, 6246, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6813, 495, 6247, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6814, 495, 6248, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6815, 495, 6249, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6816, 495, 6250, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6817, 495, 6251, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6818, 495, 6252, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6819, 495, 6253, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6820, 495, 6254, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6821, 495, 6255, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6822, 496, 6256, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6823, 496, 6257, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6824, 496, 6258, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6825, 496, 6259, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6807, 494, 6241, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6808, 494, 6242, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6826, 496, 6260, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6827, 496, 6261, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6828, 496, 6262, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6829, 496, 6263, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6830, 496, 6264, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6831, 496, 6265, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6832, 496, 6266, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6833, 497, 6267, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6834, 497, 6268, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6835, 497, 6269, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6836, 497, 6270, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6837, 497, 6271, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6838, 497, 6272, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6839, 497, 6273, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6840, 497, 6274, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6841, 497, 6275, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6842, 497, 6276, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6843, 498, 6277, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6844, 498, 6278, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6845, 498, 6279, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6846, 498, 6280, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6847, 65, 791, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6848, 65, 792, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6849, 65, 793, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6850, 65, 793, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6851, 65, 794, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6852, 500, 6282, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6853, 500, 6283, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6854, 500, 6284, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6855, 500, 6285, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6856, 500, 6286, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6857, 500, 6287, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6858, 500, 6289, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6859, 500, 6288, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6860, 500, 6290, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6861, 500, 6291, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6862, 500, 6292, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6863, 500, 6293, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6864, 500, 6294, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6865, 500, 6295, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6866, 500, 6296, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6867, 500, 6297, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6868, 500, 6298, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (6869, 501, 6299, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6870, 501, 6300, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6871, 501, 6301, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6872, 501, 6302, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6873, 501, 6303, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6874, 501, 6304, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6875, 501, 6305, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6876, 501, 6306, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6877, 501, 6307, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6878, 501, 6308, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6879, 501, 6309, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6880, 501, 6310, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6881, 502, 6311, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6882, 502, 6312, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6883, 502, 6313, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6884, 502, 6314, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6885, 502, 6315, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6886, 502, 6316, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6887, 502, 6317, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6888, 502, 6318, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6889, 502, 6319, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6890, 502, 6320, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6891, 502, 6321, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6892, 502, 6322, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6893, 502, 6323, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6894, 502, 6324, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6895, 502, 6325, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6896, 503, 6326, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6897, 503, 6327, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6898, 503, 6328, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6899, 503, 6329, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6900, 503, 6330, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6901, 503, 6331, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6902, 503, 6332, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6903, 503, 6333, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6904, 503, 6334, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6905, 503, 6335, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6906, 503, 6337, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6907, 503, 6336, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6908, 503, 6338, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6909, 504, 6339, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6910, 504, 6340, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6911, 504, 6341, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6912, 504, 6342, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6913, 504, 6343, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6914, 504, 6344, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6915, 504, 6345, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6916, 504, 6346, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6917, 504, 6347, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6918, 504, 6348, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6919, 504, 6349, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6920, 504, 6350, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6921, 504, 6351, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6922, 504, 6352, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6923, 507, 6353, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6924, 507, 6354, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6925, 507, 6355, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6926, 507, 6356, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6927, 507, 6357, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6928, 507, 6358, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6929, 507, 6359, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6930, 507, 6360, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6931, 507, 6361, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6932, 507, 6362, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6933, 507, 6363, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6934, 507, 6364, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6935, 507, 6365, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6939, 505, 6375, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6940, 505, 6376, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6941, 505, 6377, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6942, 505, 6378, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6943, 505, 6379, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6944, 505, 6380, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6945, 505, 6381, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6946, 505, 6382, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6947, 505, 6383, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6948, 505, 6384, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6949, 505, 6385, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6950, 505, 6386, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6951, 505, 6387, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6952, 505, 6388, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6953, 508, 6389, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6954, 508, 6390, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6955, 508, 6391, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6956, 508, 6392, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6957, 508, 6393, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6958, 508, 6394, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6959, 508, 6395, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6960, 508, 6396, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6961, 508, 6397, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6962, 508, 6398, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6963, 508, 6399, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6964, 508, 6400, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6965, 508, 6401, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6966, 508, 6402, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6967, 508, 6403, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6968, 509, 6404, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6969, 509, 6405, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6970, 509, 6406, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6971, 509, 6407, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6972, 509, 6408, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6973, 509, 6409, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6974, 509, 6410, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6975, 509, 6411, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6976, 509, 6412, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6977, 509, 6413, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6978, 509, 6414, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6979, 509, 6415, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6980, 509, 6416, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6981, 509, 6417, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6982, 509, 6418, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9963, 1056, 9390, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6994, 510, 6424, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6995, 510, 6425, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6996, 510, 6426, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6997, 510, 6427, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6998, 510, 6428, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6999, 510, 6429, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7000, 510, 6430, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7001, 510, 6431, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7002, 510, 6432, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7003, 510, 6433, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7004, 510, 6434, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7005, 510, 6435, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7006, 510, 6436, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7007, 510, 6437, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7008, 510, 6438, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7009, 510, 6439, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7010, 511, 6440, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7011, 511, 6441, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7012, 511, 6442, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7013, 511, 6443, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7014, 511, 6444, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7015, 511, 6445, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7016, 511, 6446, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7017, 511, 6447, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7018, 511, 6448, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7019, 511, 6449, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7020, 511, 6450, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7021, 511, 6451, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7022, 511, 6452, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7023, 513, 6453, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7024, 513, 6454, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7025, 513, 6455, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7026, 513, 6456, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7027, 513, 6457, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7028, 513, 6458, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7029, 513, 6459, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7030, 513, 6460, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7031, 513, 6461, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7032, 513, 6462, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7033, 513, 6463, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7034, 513, 6464, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7035, 513, 6465, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7036, 513, 6466, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7037, 144, 6106, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7038, 512, 2543, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7039, 512, 6467, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7040, 512, 6468, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7041, 512, 6469, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7042, 512, 6470, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7044, 512, 1647, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7045, 512, 1648, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7046, 512, 1649, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7047, 512, 1650, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7048, 512, 1651, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7043, 512, 1646, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7049, 512, 1652, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7065, 38, 6487, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7066, 38, 6488, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7067, 38, 6489, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (7075, 516, 6494, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7076, 516, 6495, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7077, 516, 6496, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7078, 516, 6497, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7079, 516, 6498, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7080, 516, 6499, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7081, 516, 6500, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7082, 516, 6501, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7083, 516, 6502, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7084, 516, 6503, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7085, 516, 6504, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7086, 516, 6505, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7087, 516, 6506, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7088, 516, 6507, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7089, 17, 5787, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7090, 879, 6508, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7091, 879, 6509, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9964, 1056, 9391, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9965, 1056, 9392, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9966, 1056, 9393, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9967, 1056, 9394, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9968, 1056, 9395, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9969, 1056, 9396, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7092, 879, 6510, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7093, 879, 6511, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7094, 879, 6512, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7095, 879, 6513, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7096, 879, 6514, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7097, 879, 6515, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7098, 879, 6516, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7099, 879, 6517, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7100, 879, 6518, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7101, 879, 6519, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7102, 879, 6520, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7103, 880, 6521, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7104, 880, 6522, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7105, 880, 6523, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7106, 880, 6524, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7107, 880, 6525, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7108, 880, 6526, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7109, 880, 6527, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7110, 880, 6528, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7111, 880, 6529, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7112, 880, 6530, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7113, 880, 6531, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7114, 881, 6532, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7115, 881, 6533, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7116, 881, 6534, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7117, 881, 6535, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7118, 881, 6536, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7119, 881, 6537, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7120, 881, 6538, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7121, 881, 6539, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7122, 881, 6540, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7123, 881, 6541, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7124, 881, 6542, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7125, 881, 6543, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7126, 882, 6544, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7127, 882, 6545, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7128, 882, 6546, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7129, 882, 6547, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7130, 882, 6548, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7131, 882, 6549, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7132, 882, 6550, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7133, 882, 6551, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7134, 882, 6552, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7135, 882, 6553, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7136, 882, 6554, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7137, 882, 6555, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7138, 883, 6556, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7139, 883, 6557, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7140, 883, 6558, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7141, 883, 6559, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7142, 883, 6560, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7143, 883, 6561, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7144, 883, 6562, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7145, 883, 6563, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7146, 883, 6564, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7147, 883, 6565, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7148, 883, 6566, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7149, 883, 6567, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7150, 884, 6568, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7151, 884, 6569, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7152, 884, 6570, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7153, 884, 6571, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7154, 884, 6572, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7155, 884, 6573, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7156, 884, 6574, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7157, 884, 6575, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7158, 884, 6576, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7159, 884, 6577, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7160, 884, 6578, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7161, 884, 6579, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7162, 884, 6580, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7163, 884, 6581, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7164, 885, 6582, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7165, 885, 6583, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7166, 885, 6584, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7167, 885, 6585, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7168, 885, 6586, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7169, 885, 6587, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7170, 885, 6588, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7171, 885, 6589, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7172, 885, 6590, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7173, 885, 6591, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7174, 885, 6592, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7175, 885, 6593, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7176, 886, 6594, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7177, 886, 6595, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7178, 886, 6596, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7179, 886, 6597, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7180, 886, 6598, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7181, 886, 6599, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7182, 886, 6600, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7183, 886, 6601, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7184, 886, 6602, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7185, 886, 6603, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7186, 886, 6604, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7187, 886, 6605, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7188, 886, 6606, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7189, 886, 6607, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7190, 886, 6608, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7221, 888, 6639, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7222, 888, 6640, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7223, 888, 6641, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7224, 888, 6642, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7225, 888, 6643, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7226, 888, 6644, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7227, 888, 6645, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7228, 888, 6646, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7229, 888, 6647, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7230, 888, 6648, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7231, 888, 6649, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7232, 888, 6650, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7233, 888, 6651, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7234, 888, 6652, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7235, 888, 6653, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7236, 888, 6654, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7237, 888, 6655, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (7238, 888, 6656, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (7239, 889, 6657, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7240, 889, 6658, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7241, 889, 6659, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7242, 889, 6660, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7243, 889, 6661, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7244, 889, 6662, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7245, 889, 6663, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7246, 889, 6664, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7247, 889, 6665, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7248, 889, 6666, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7249, 889, 6667, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7250, 889, 6668, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7251, 889, 6669, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7252, 889, 6670, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7253, 889, 6671, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7254, 889, 6672, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7255, 890, 6673, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7256, 890, 6674, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7257, 890, 6675, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7258, 890, 6676, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7259, 890, 6677, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7260, 890, 6678, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7261, 890, 6679, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7262, 890, 6680, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7263, 890, 6681, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7264, 891, 6682, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7265, 891, 6683, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7266, 891, 6684, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7267, 891, 6685, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7268, 891, 6686, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7269, 891, 6687, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7270, 891, 6688, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7271, 891, 6689, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7272, 891, 6690, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7273, 891, 6691, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7274, 891, 6692, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7275, 891, 6693, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7276, 892, 6694, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7277, 892, 6695, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7278, 892, 6696, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7279, 892, 6697, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7280, 892, 6698, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7281, 892, 6699, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7282, 892, 6700, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7283, 892, 6701, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7284, 892, 6702, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7285, 892, 6703, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7286, 892, 6704, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7287, 892, 6705, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7288, 892, 6706, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7289, 892, 6707, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7290, 892, 6708, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7291, 892, 6709, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7292, 893, 6710, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7293, 893, 6711, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7294, 893, 6712, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7295, 893, 6713, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7296, 893, 6714, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7297, 893, 6715, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7298, 893, 6716, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7299, 893, 6717, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7300, 893, 6718, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7301, 893, 6719, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7302, 893, 6720, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7303, 893, 6721, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7304, 894, 6722, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7305, 894, 6723, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7306, 894, 6724, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7307, 894, 6725, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7308, 894, 6726, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7309, 894, 6727, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7310, 894, 6728, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7311, 894, 6729, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7312, 894, 6730, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7313, 894, 6731, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7314, 894, 6732, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7315, 894, 6733, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7316, 894, 6734, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7317, 894, 6735, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7318, 894, 6736, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7319, 894, 6737, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7320, 894, 6738, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (7321, 894, 6739, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (7322, 894, 6740, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (7323, 895, 6741, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7324, 895, 6742, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7325, 895, 6743, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7326, 895, 6744, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7327, 895, 6745, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7328, 895, 6746, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7329, 895, 6747, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7330, 895, 6748, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7331, 895, 6749, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7332, 895, 6750, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7333, 895, 6751, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7334, 895, 6752, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7335, 895, 6753, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7336, 895, 6754, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7337, 895, 6755, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7338, 896, 6756, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7339, 896, 6757, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7340, 896, 6758, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7341, 896, 6759, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7342, 896, 6760, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7343, 896, 6761, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7344, 896, 6762, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7345, 896, 6763, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7346, 896, 6764, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7347, 896, 6765, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7348, 896, 6766, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7349, 896, 6767, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7350, 896, 6768, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7351, 896, 6769, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7352, 896, 6770, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7353, 896, 6771, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7354, 897, 6772, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7355, 897, 6773, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7356, 897, 6774, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7357, 897, 6775, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7358, 897, 6776, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7359, 897, 6777, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7360, 897, 6778, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7361, 897, 6779, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7362, 897, 6780, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7363, 897, 6781, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7364, 897, 6782, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7365, 898, 6783, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7366, 898, 6784, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7367, 898, 6785, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7368, 898, 6786, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7369, 898, 6787, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7370, 898, 6788, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7371, 898, 6789, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7372, 898, 6790, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7373, 898, 6791, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7374, 898, 6792, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7375, 898, 6793, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7376, 898, 6794, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7377, 898, 6795, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7378, 898, 6796, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7379, 899, 6809, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7380, 899, 6810, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7381, 899, 6811, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7382, 899, 6812, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7383, 899, 6813, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7384, 899, 6814, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7385, 899, 6815, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7386, 899, 6816, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7387, 899, 6817, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7388, 899, 6818, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7389, 899, 6819, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7390, 899, 6820, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7391, 900, 6821, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7392, 900, 6822, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7393, 900, 6823, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7394, 900, 6824, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7395, 900, 6825, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7396, 900, 6826, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7397, 900, 6827, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7398, 900, 6828, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7399, 900, 6829, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7400, 900, 6830, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7401, 900, 6831, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7402, 900, 6832, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7403, 901, 6859, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7404, 901, 6860, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7405, 901, 6861, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7406, 901, 6862, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7407, 901, 6863, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7408, 901, 6864, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7409, 901, 6865, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7410, 901, 6866, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7411, 901, 6867, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7412, 901, 6868, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7413, 901, 6869, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7414, 901, 6870, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7415, 901, 6871, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7416, 901, 6872, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7417, 901, 6873, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7418, 901, 6874, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7419, 901, 6875, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (7420, 901, 6876, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (7421, 902, 6891, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7422, 902, 6892, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7423, 902, 6893, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7424, 902, 6894, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7425, 902, 6895, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7426, 902, 6896, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7427, 902, 6897, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7428, 902, 6898, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7429, 902, 6899, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7430, 902, 6900, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7431, 902, 6901, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7432, 902, 6902, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7433, 902, 6903, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7434, 902, 6904, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7435, 903, 6905, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7436, 903, 6906, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7437, 903, 6907, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7438, 903, 6908, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7439, 903, 6909, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7440, 903, 6910, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7441, 903, 6911, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7442, 903, 6912, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7443, 903, 6913, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7444, 903, 6914, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7445, 903, 6915, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7446, 903, 6916, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7447, 903, 6917, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7448, 903, 6918, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7449, 903, 6919, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7450, 903, 6920, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7451, 903, 6921, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (7452, 903, 6922, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (7453, 903, 6923, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (7454, 903, 6924, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (7455, 904, 6925, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7456, 904, 6926, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7457, 904, 6927, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7458, 904, 6928, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7459, 904, 6929, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7460, 904, 6930, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7461, 904, 6931, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7462, 904, 6932, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7463, 904, 6933, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7464, 904, 6934, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7465, 904, 6935, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7466, 904, 6936, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7467, 904, 6937, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7468, 904, 6938, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7469, 904, 6939, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7470, 904, 6940, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7471, 905, 6941, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7472, 905, 6942, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7473, 905, 6943, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7474, 905, 6944, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7475, 905, 6945, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7476, 905, 6946, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7477, 905, 6947, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7478, 905, 6948, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7479, 905, 6949, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7480, 905, 6950, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7481, 905, 6951, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7482, 905, 6952, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7483, 905, 6953, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7484, 905, 6954, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7485, 905, 6955, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7486, 906, 6956, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7487, 906, 6957, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7488, 906, 6958, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7489, 906, 6959, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7490, 906, 6960, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7491, 906, 6961, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7492, 906, 6962, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7493, 906, 6963, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7494, 906, 6964, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7495, 906, 6965, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7496, 906, 6966, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7497, 906, 6967, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7498, 906, 6968, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7499, 906, 6969, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7500, 906, 6970, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7501, 907, 6971, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7502, 907, 6972, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7503, 907, 6973, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7504, 907, 6974, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7505, 907, 6975, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7506, 907, 6976, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7507, 907, 6977, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7508, 907, 6978, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7509, 907, 6979, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7510, 907, 6980, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7511, 907, 6981, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7512, 907, 6982, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7513, 907, 6983, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7514, 907, 6984, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7515, 907, 6985, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7516, 907, 6986, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7517, 907, 6987, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9970, 1056, 9397, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9971, 1056, 9398, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9972, 1056, 9399, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9973, 1056, 9400, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9974, 1056, 9401, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10818, 1113, 10224, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10819, 1113, 10225, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10820, 1113, 10226, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7533, 909, 7003, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7534, 909, 7004, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7535, 909, 7005, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7536, 909, 7006, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7537, 909, 7007, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7538, 909, 7008, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7539, 909, 7009, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7540, 909, 7010, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7541, 909, 7011, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7542, 909, 7012, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7543, 909, 7013, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7544, 909, 7014, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7545, 909, 7015, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7546, 909, 7016, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7547, 910, 7017, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7548, 910, 7018, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7549, 910, 7019, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7550, 910, 7020, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7551, 910, 7021, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7552, 910, 7022, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7553, 910, 7023, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7554, 910, 7024, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7555, 910, 7025, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7556, 910, 7026, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7557, 910, 7027, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7558, 910, 7028, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7559, 911, 7029, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7560, 911, 7030, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7561, 911, 7031, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7562, 911, 7032, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7563, 911, 7033, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7564, 911, 7034, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7565, 911, 7035, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7566, 911, 7036, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7567, 911, 7037, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7568, 911, 7038, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7569, 911, 7039, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7570, 911, 7040, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7571, 911, 7041, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7572, 911, 7042, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7573, 911, 7043, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7574, 911, 7044, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7602, 913, 7072, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7603, 913, 7073, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7604, 913, 7074, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7605, 913, 7075, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7606, 913, 7076, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7607, 913, 7077, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7608, 913, 7078, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7609, 913, 7079, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7610, 913, 7080, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7611, 913, 7081, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7612, 914, 7082, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7613, 914, 7083, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7614, 914, 7084, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7615, 914, 7085, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7616, 914, 7086, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7617, 914, 7087, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7618, 914, 7088, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7619, 914, 7089, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7620, 914, 7090, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7621, 914, 7091, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7622, 914, 7092, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7623, 914, 7093, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7624, 915, 7094, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7625, 915, 7095, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7626, 915, 7096, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7627, 915, 7097, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7628, 915, 7098, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7629, 915, 7099, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7630, 915, 7100, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7631, 915, 7101, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7632, 915, 7102, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7633, 915, 7103, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7634, 915, 7104, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7635, 915, 7105, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7636, 915, 7106, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7637, 915, 7107, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7638, 916, 7108, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7639, 916, 7109, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7640, 916, 7110, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7641, 916, 7111, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7642, 916, 7112, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7643, 916, 7113, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7644, 916, 7114, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7645, 916, 7115, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7646, 916, 7116, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10859, 1118, 10265, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10860, 1118, 10266, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10861, 1118, 10267, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7647, 916, 7117, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7648, 916, 7118, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7649, 916, 7119, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7650, 916, 7120, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7651, 916, 7121, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7652, 916, 7122, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7653, 916, 7123, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7654, 916, 7124, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (7655, 916, 7125, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (7656, 916, 7126, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (7657, 916, 7127, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (7658, 916, 7128, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (7659, 917, 7129, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7660, 917, 7130, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7661, 917, 7131, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7662, 917, 7132, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7663, 917, 7133, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7664, 917, 7134, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7665, 917, 7135, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7666, 917, 7136, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7667, 917, 7137, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7668, 917, 7138, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7669, 917, 7139, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7670, 917, 7140, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7671, 917, 7141, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7672, 917, 7142, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7673, 918, 7143, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7674, 918, 7144, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7675, 918, 7145, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7676, 918, 7146, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7677, 918, 7147, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7678, 918, 7148, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7679, 918, 7149, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7680, 918, 7150, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7731, 922, 7201, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7732, 922, 7202, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7733, 922, 7203, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7734, 922, 7204, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7735, 922, 7205, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7736, 922, 7206, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7737, 922, 7207, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7738, 922, 7208, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7739, 922, 7209, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7740, 922, 7210, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7741, 922, 7211, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7742, 922, 7212, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7743, 922, 7213, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7744, 922, 7214, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7745, 922, 7215, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7746, 922, 7216, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7747, 922, 7217, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (7748, 923, 7218, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7749, 923, 7219, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7750, 923, 7220, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7751, 923, 7221, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7752, 923, 7222, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7753, 923, 7223, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7754, 923, 7224, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7755, 923, 7225, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7756, 923, 7226, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7757, 923, 7227, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7758, 923, 7228, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7759, 923, 7229, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7760, 923, 7230, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7761, 923, 7231, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7762, 923, 7232, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7763, 923, 7233, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7764, 923, 7234, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (7765, 923, 7235, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (7766, 924, 7236, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7767, 924, 7237, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7768, 924, 7238, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7769, 924, 7239, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7770, 924, 7240, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7771, 924, 7241, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7772, 924, 7242, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7773, 924, 7243, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7774, 924, 7244, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7775, 924, 7245, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7776, 924, 7246, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7777, 924, 7247, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7778, 924, 7248, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7779, 924, 7249, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7780, 924, 7250, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7781, 924, 7251, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7782, 924, 7252, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (7783, 924, 7253, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (7784, 924, 7254, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (7785, 924, 7255, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (7786, 925, 7256, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7787, 925, 7257, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7788, 925, 7258, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7789, 925, 7259, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7790, 925, 7260, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7791, 925, 7261, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7792, 925, 7262, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7793, 925, 7263, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7794, 925, 7264, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7795, 925, 7265, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7796, 925, 7266, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7797, 925, 7267, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7798, 925, 7268, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7799, 926, 7269, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7800, 926, 7270, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7801, 926, 7271, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7802, 926, 7272, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7803, 926, 7273, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7804, 926, 7274, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7805, 926, 7275, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7806, 926, 7276, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7807, 926, 7277, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7808, 926, 7278, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7809, 926, 7279, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7810, 927, 7280, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7811, 927, 7281, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7812, 927, 7282, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7813, 927, 7283, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7814, 927, 7284, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7815, 927, 7285, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7816, 927, 7286, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7817, 927, 7287, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7818, 927, 7288, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7819, 927, 7289, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7820, 927, 7290, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7821, 927, 7291, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7822, 927, 7292, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7823, 927, 7293, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7824, 928, 7294, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7825, 928, 7295, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7826, 928, 7296, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7827, 928, 7297, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7828, 928, 7298, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7829, 928, 7299, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7830, 928, 7300, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7831, 928, 7301, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7832, 928, 7302, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7833, 928, 7303, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7834, 928, 7304, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7835, 928, 7305, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7836, 928, 7306, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7837, 928, 7307, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7838, 928, 7308, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7839, 928, 7309, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7840, 929, 7310, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7841, 929, 7311, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7842, 929, 7312, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7843, 929, 7313, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7844, 929, 7314, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7845, 929, 7315, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7846, 929, 7316, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7847, 929, 7317, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7848, 929, 7318, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7849, 929, 7319, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7850, 929, 7320, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7851, 929, 7321, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7852, 929, 7322, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7853, 929, 7323, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7854, 930, 7324, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7855, 930, 7325, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7856, 930, 7326, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7857, 930, 7327, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7858, 930, 7328, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7859, 930, 7329, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7681, 918, 7151, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7682, 918, 7152, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7683, 918, 7153, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10821, 1113, 10227, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10822, 1113, 10228, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10823, 1113, 10229, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7860, 930, 7330, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7861, 930, 7331, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7862, 930, 7332, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7863, 930, 7333, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7864, 930, 7334, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7865, 930, 7335, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7866, 930, 7336, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7867, 930, 7337, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7868, 930, 7338, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7869, 930, 7339, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7870, 931, 7340, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7871, 931, 7341, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7872, 931, 7342, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7873, 931, 7343, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7874, 931, 7344, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7875, 931, 7345, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7876, 931, 7346, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7877, 931, 7347, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7878, 931, 7348, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7879, 931, 7349, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7880, 931, 7350, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7881, 931, 7351, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7882, 931, 7352, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7883, 931, 7353, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7884, 931, 7354, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7885, 931, 7355, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7886, 932, 7356, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7887, 932, 7357, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7888, 932, 7358, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7889, 932, 7359, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7890, 932, 7360, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7891, 932, 7361, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7892, 932, 7362, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7893, 932, 7363, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7894, 932, 7364, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7895, 932, 7365, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7896, 932, 7366, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7897, 932, 7367, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7898, 932, 7368, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7899, 932, 7369, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7900, 932, 7370, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7901, 932, 7371, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7902, 932, 7372, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (7903, 933, 7373, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7904, 933, 7374, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7905, 933, 7375, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7906, 933, 7376, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7907, 933, 7377, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7908, 933, 7378, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7909, 933, 7379, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7910, 933, 7380, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7911, 933, 7381, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7912, 933, 7382, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7913, 933, 7383, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7914, 933, 7384, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7915, 933, 7385, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7916, 934, 7386, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7917, 934, 7387, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7918, 934, 7388, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7919, 934, 7389, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7920, 934, 7390, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7921, 935, 7391, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7922, 935, 7392, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7923, 935, 7393, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7924, 935, 7394, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7925, 935, 7395, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7926, 935, 7396, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7927, 935, 7397, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7928, 935, 7398, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7929, 935, 7399, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7930, 935, 7400, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7931, 935, 7401, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7932, 935, 7402, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7933, 935, 7403, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7934, 935, 7404, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7935, 935, 7405, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7936, 935, 7406, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7937, 936, 7407, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7938, 936, 7408, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7939, 936, 7409, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7940, 936, 7410, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7941, 936, 7411, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7942, 936, 7412, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7943, 936, 7413, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7944, 936, 7414, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7945, 936, 7415, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7946, 936, 7416, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7947, 936, 7417, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7948, 936, 7418, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7949, 936, 7419, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7950, 936, 7420, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7951, 936, 7421, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7952, 936, 7422, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7953, 937, 7423, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7954, 937, 7424, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7955, 937, 7425, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7956, 937, 7426, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7957, 937, 7427, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7958, 937, 7428, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7959, 937, 7429, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7960, 937, 7430, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7961, 937, 7431, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7962, 937, 7432, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7963, 937, 7433, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7964, 937, 7434, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7965, 937, 7435, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7966, 937, 7436, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7967, 937, 7437, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7968, 937, 7438, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7969, 937, 7439, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (7970, 937, 7440, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (7971, 937, 7441, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (7972, 937, 7442, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (7973, 938, 7443, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7974, 938, 7444, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7975, 938, 7445, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7976, 938, 7446, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7977, 938, 7447, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7978, 938, 7448, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7979, 938, 7449, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7980, 938, 7450, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7981, 938, 7451, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7982, 938, 7452, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7983, 938, 7453, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7984, 938, 7454, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7985, 938, 7455, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7986, 938, 7456, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7987, 938, 7457, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7988, 938, 7458, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7989, 939, 7459, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7990, 939, 7460, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7991, 939, 7461, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7992, 939, 7462, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7993, 939, 7463, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7994, 939, 7464, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7995, 939, 7465, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7996, 939, 7466, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7997, 939, 7467, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7998, 939, 7468, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7999, 939, 7469, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8000, 939, 7470, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8001, 939, 7471, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8002, 939, 7472, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8003, 939, 7473, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8004, 939, 7474, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8005, 939, 7475, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8006, 939, 7476, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8007, 939, 7477, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8008, 939, 7478, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (8009, 940, 7479, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8010, 940, 7480, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8011, 940, 7481, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8012, 940, 7482, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8013, 940, 7483, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8014, 940, 7484, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8015, 940, 7485, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8016, 940, 7486, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8017, 940, 7487, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8018, 940, 7488, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8019, 940, 7489, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8020, 940, 7490, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8021, 940, 7491, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8022, 940, 7492, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8023, 940, 7493, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8024, 940, 7494, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8025, 941, 7495, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8026, 941, 7496, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8027, 941, 7497, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8028, 941, 7498, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8029, 941, 7499, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8030, 941, 7500, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8031, 941, 7501, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8032, 941, 7502, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8033, 941, 7503, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8034, 941, 7504, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8035, 941, 7505, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8036, 941, 7506, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8037, 941, 7507, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8038, 941, 7508, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8039, 941, 7509, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8040, 941, 7510, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8041, 942, 7511, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8042, 942, 7512, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8043, 942, 7513, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8044, 942, 7514, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8045, 942, 7515, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8046, 942, 7516, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8047, 942, 7517, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8048, 942, 7518, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8049, 942, 7519, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8050, 942, 7520, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8051, 942, 7521, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8052, 942, 7522, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8053, 943, 7523, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8054, 943, 7524, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8055, 943, 7525, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8056, 943, 7526, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8057, 943, 7527, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8058, 943, 7528, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8059, 943, 7529, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8060, 943, 7530, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8061, 943, 7531, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8062, 943, 7532, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8063, 943, 7533, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8064, 943, 7534, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8065, 943, 7535, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8066, 943, 7536, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8067, 943, 7537, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8068, 943, 7538, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8069, 943, 7539, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8070, 944, 7540, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8071, 944, 7541, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8072, 944, 7542, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8073, 944, 7543, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8074, 944, 7544, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8075, 944, 7545, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8076, 944, 7546, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8077, 944, 7547, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8078, 944, 7548, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8079, 944, 7549, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8080, 944, 7550, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8081, 944, 7551, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8082, 944, 7552, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8083, 944, 7553, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8084, 944, 7554, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8085, 944, 7555, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8086, 944, 7556, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8087, 945, 7557, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8088, 945, 7558, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8089, 945, 7559, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8090, 945, 7560, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8091, 945, 7561, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8092, 945, 7562, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8093, 945, 7563, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8094, 945, 7564, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8095, 945, 7565, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8096, 945, 7566, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8097, 945, 7567, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8098, 945, 7568, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8099, 945, 7569, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8100, 945, 7570, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8101, 946, 7571, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8102, 946, 7572, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8103, 946, 7573, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8104, 946, 7574, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8105, 946, 7575, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8106, 946, 7576, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8107, 946, 7577, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8108, 946, 7578, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8109, 946, 7579, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8110, 946, 7580, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8111, 946, 7581, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8112, 946, 7582, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8113, 947, 7583, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8114, 947, 7584, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8115, 947, 7585, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8116, 947, 7586, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8117, 947, 7587, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8118, 947, 7588, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8119, 947, 7589, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8120, 947, 7590, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8121, 947, 7591, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8122, 947, 7592, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8123, 947, 7593, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8124, 947, 7594, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8125, 947, 7595, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8126, 947, 7596, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8127, 947, 7597, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8128, 947, 7598, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8129, 947, 7599, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8130, 947, 7600, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8131, 947, 7601, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8132, 947, 7602, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (8133, 947, 7603, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (8134, 947, 7604, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (8135, 947, 7605, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (8136, 211, 7606, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8137, 211, 7607, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8138, 211, 7608, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8139, 211, 7610, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8140, 211, 7611, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8141, 211, 7612, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8142, 211, 7613, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8143, 211, 7614, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8144, 211, 7615, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8145, 211, 7616, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8146, 211, 7617, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8147, 211, 7618, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8148, 211, 7619, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8149, 948, 7620, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8150, 948, 7621, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8151, 948, 7622, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8152, 948, 7623, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8153, 948, 7624, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8154, 948, 7625, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8155, 948, 7626, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8156, 948, 7627, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8157, 948, 7628, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8158, 948, 7629, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8159, 948, 7630, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8160, 948, 7631, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8161, 949, 7632, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8162, 949, 7633, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8163, 949, 7634, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8164, 949, 7635, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8165, 949, 7636, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8166, 949, 7637, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8167, 949, 7638, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8168, 949, 7639, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8169, 949, 7640, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8170, 950, 7641, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8171, 950, 7642, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8172, 950, 7643, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8173, 950, 7644, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8174, 950, 7645, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8175, 950, 7646, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8176, 950, 7647, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8177, 950, 7648, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8178, 950, 7649, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8179, 950, 7650, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8180, 950, 7651, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8181, 950, 7652, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8182, 950, 7653, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8183, 950, 7654, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8184, 950, 7655, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8185, 950, 7656, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8186, 950, 7657, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8187, 950, 7658, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8188, 950, 7659, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8189, 950, 7660, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (8190, 951, 7661, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8191, 951, 7662, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8192, 951, 7663, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8193, 951, 7664, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8194, 951, 7665, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8195, 951, 7666, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8196, 951, 7667, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8197, 951, 7668, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8198, 951, 7669, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8199, 951, 7670, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8200, 951, 7671, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8201, 951, 7672, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8202, 951, 7673, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8203, 951, 7674, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8204, 951, 7675, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8205, 951, 7676, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8206, 951, 7677, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8207, 951, 7678, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8208, 951, 7679, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8209, 951, 7680, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (8210, 952, 7681, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8211, 952, 7682, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8212, 952, 7683, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8213, 952, 7684, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8214, 952, 7685, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8215, 952, 7686, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8216, 952, 7687, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8217, 953, 7688, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8218, 953, 7689, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8219, 953, 7690, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8220, 953, 7691, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8221, 953, 7692, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8222, 953, 7693, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8223, 953, 7694, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8224, 953, 7695, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8225, 953, 7696, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8226, 953, 7697, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8227, 953, 7698, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8228, 953, 7699, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8229, 953, 7700, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8230, 953, 7701, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8231, 953, 7702, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8232, 954, 7721, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8233, 954, 7722, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8234, 954, 7723, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8235, 954, 7724, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8236, 954, 7725, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8237, 954, 7726, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8238, 954, 7727, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8239, 954, 7728, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8240, 954, 7729, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8241, 954, 7730, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8242, 954, 7731, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8243, 954, 7732, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8244, 954, 7733, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8245, 954, 7734, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8246, 954, 7735, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8247, 954, 7736, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8248, 954, 7737, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8249, 954, 7738, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8250, 955, 7739, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8251, 955, 7740, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8252, 955, 7741, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8253, 955, 7742, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8254, 955, 7743, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8255, 955, 7744, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8256, 955, 7745, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8257, 955, 7746, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8258, 955, 7747, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8259, 955, 7748, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8260, 955, 7749, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8261, 955, 7750, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8262, 955, 7751, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8263, 955, 7752, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8264, 955, 7753, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8265, 955, 7754, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8266, 955, 7755, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8267, 955, 7756, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8268, 955, 7757, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8269, 955, 7758, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (8270, 955, 7759, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (8271, 955, 7760, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (8272, 956, 7761, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8273, 956, 7762, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8274, 956, 7763, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8275, 956, 7764, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8276, 956, 7765, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8277, 956, 7766, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8278, 956, 7767, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8279, 956, 7768, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8280, 956, 7769, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8281, 956, 7770, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8282, 956, 7771, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8283, 956, 7772, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8284, 957, 7773, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8285, 957, 7774, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8286, 957, 7775, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8287, 957, 7776, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8288, 957, 7777, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8289, 957, 7778, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8290, 957, 7779, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8291, 957, 7780, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8292, 957, 7781, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8293, 957, 7782, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8294, 957, 7783, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8295, 957, 7784, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8296, 957, 7785, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8297, 957, 7786, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8313, 959, 7802, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8314, 959, 7803, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8315, 959, 7804, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8316, 959, 7805, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8317, 959, 7806, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8318, 959, 7807, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8319, 959, 7808, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8320, 959, 7809, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8321, 959, 7810, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8322, 959, 7811, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8323, 959, 7812, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8324, 959, 7813, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8325, 959, 7814, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8326, 960, 7815, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8327, 960, 7816, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8328, 960, 7817, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8329, 960, 7818, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8330, 960, 7819, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8331, 960, 7820, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8332, 960, 7821, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8333, 960, 7822, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8334, 960, 7823, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8335, 960, 7824, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8336, 960, 7825, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8337, 960, 7826, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8338, 960, 7827, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8339, 960, 7828, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8340, 960, 7829, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8341, 960, 7830, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8342, 960, 7831, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8343, 960, 7832, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8344, 960, 7833, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8345, 960, 7834, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (8346, 960, 7835, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (8347, 960, 7836, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (8348, 960, 7837, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (8349, 960, 7838, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (8350, 960, 7839, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (8351, 960, 7840, 26);
INSERT INTO 'albumsrecordingsmap' VALUES (8352, 960, 7841, 27);
INSERT INTO 'albumsrecordingsmap' VALUES (8353, 960, 7842, 28);
INSERT INTO 'albumsrecordingsmap' VALUES (8354, 960, 7843, 29);
INSERT INTO 'albumsrecordingsmap' VALUES (8355, 960, 7844, 30);
INSERT INTO 'albumsrecordingsmap' VALUES (8356, 960, 7845, 31);
INSERT INTO 'albumsrecordingsmap' VALUES (8357, 960, 7846, 32);
INSERT INTO 'albumsrecordingsmap' VALUES (8358, 960, 7847, 33);
INSERT INTO 'albumsrecordingsmap' VALUES (8359, 960, 7848, 34);
INSERT INTO 'albumsrecordingsmap' VALUES (8360, 960, 7849, 35);
INSERT INTO 'albumsrecordingsmap' VALUES (8361, 960, 7850, 36);
INSERT INTO 'albumsrecordingsmap' VALUES (8362, 961, 7851, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8363, 961, 7852, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8364, 961, 7853, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8365, 961, 7854, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8366, 961, 7855, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8367, 961, 7856, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8368, 961, 7857, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8369, 961, 7858, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8370, 961, 7859, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8371, 961, 7860, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8372, 961, 7861, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8373, 961, 7862, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8374, 961, 7863, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8375, 961, 7864, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8376, 962, 7865, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8377, 962, 7866, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8378, 962, 7867, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8379, 962, 7868, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8380, 962, 7869, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8381, 962, 7870, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8382, 962, 7871, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8383, 962, 7872, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8384, 962, 7873, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8385, 962, 7874, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8386, 962, 7875, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8387, 962, 7876, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8388, 962, 7877, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8389, 962, 7878, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8390, 962, 7879, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8391, 962, 7880, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8392, 962, 7881, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8393, 962, 7882, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8394, 962, 7883, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8395, 962, 7884, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (8396, 962, 7885, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (8397, 962, 7886, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (8398, 962, 7887, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (8399, 962, 7888, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (8400, 962, 7889, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (8401, 962, 7890, 26);
INSERT INTO 'albumsrecordingsmap' VALUES (8402, 962, 7891, 27);
INSERT INTO 'albumsrecordingsmap' VALUES (8403, 962, 7892, 28);
INSERT INTO 'albumsrecordingsmap' VALUES (8404, 962, 7893, 29);
INSERT INTO 'albumsrecordingsmap' VALUES (8405, 962, 7894, 30);
INSERT INTO 'albumsrecordingsmap' VALUES (8406, 962, 7895, 31);
INSERT INTO 'albumsrecordingsmap' VALUES (8407, 962, 7896, 32);
INSERT INTO 'albumsrecordingsmap' VALUES (8408, 962, 7897, 33);
INSERT INTO 'albumsrecordingsmap' VALUES (8409, 962, 7898, 34);
INSERT INTO 'albumsrecordingsmap' VALUES (8410, 962, 7899, 35);
INSERT INTO 'albumsrecordingsmap' VALUES (8411, 962, 7900, 36);
INSERT INTO 'albumsrecordingsmap' VALUES (8432, 964, 7921, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8433, 964, 7922, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8434, 964, 7923, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8435, 964, 7924, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8436, 964, 7925, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8437, 964, 7926, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8438, 964, 7927, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8439, 964, 7928, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8440, 964, 7929, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8441, 964, 7930, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8442, 964, 7931, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8443, 964, 7932, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8444, 964, 7933, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8445, 964, 7934, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8446, 964, 7935, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8447, 964, 7936, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8448, 964, 7937, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8449, 964, 7938, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8450, 965, 7939, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8451, 965, 7940, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8452, 965, 7941, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8453, 965, 7942, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8454, 965, 7943, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8455, 965, 7944, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8456, 965, 7945, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8457, 965, 7946, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8458, 965, 7947, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8459, 965, 7948, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8460, 965, 7949, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8461, 965, 7950, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8462, 965, 7951, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8463, 965, 7952, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8464, 965, 7953, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8465, 965, 7954, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8466, 965, 7955, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8467, 965, 7956, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8468, 966, 7957, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8469, 966, 7958, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8470, 966, 7959, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8471, 966, 7960, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8472, 966, 7961, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8473, 966, 7962, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8474, 966, 7963, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8475, 966, 7964, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8476, 966, 7965, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8477, 966, 7966, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8478, 967, 7967, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8479, 967, 7968, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8480, 967, 7969, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8481, 967, 7970, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8482, 967, 7971, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8483, 967, 7972, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8484, 967, 7973, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8485, 967, 7974, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8486, 967, 7975, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8487, 967, 7976, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8488, 967, 7977, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8489, 967, 7978, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8490, 967, 7979, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8491, 967, 7980, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8492, 967, 7981, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8509, 969, 7998, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8510, 969, 7999, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8511, 969, 8000, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8512, 969, 8001, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8513, 969, 8002, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8514, 969, 8003, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8515, 969, 8004, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8516, 969, 8005, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8517, 969, 8006, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8518, 969, 8007, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8519, 969, 8008, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8520, 969, 8009, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8521, 969, 8010, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8522, 969, 8011, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8523, 969, 8012, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8524, 969, 8013, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8525, 969, 8014, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8526, 970, 8015, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8527, 970, 8016, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8528, 970, 8017, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8529, 970, 8018, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8530, 970, 8019, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8531, 970, 8020, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8532, 970, 8021, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8533, 970, 8022, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8534, 970, 8023, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8535, 970, 8024, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8536, 970, 8025, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8537, 970, 8026, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8538, 970, 8027, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8539, 970, 8028, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8540, 970, 8029, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8541, 970, 8030, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8542, 971, 8031, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8543, 971, 8032, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8544, 971, 8033, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8545, 971, 8034, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8546, 971, 8035, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8547, 971, 8036, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8548, 971, 8037, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8549, 971, 8038, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8550, 971, 8039, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8551, 971, 8040, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8552, 971, 8041, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8553, 971, 8042, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8554, 971, 8043, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8555, 971, 8044, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8556, 971, 8045, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8557, 971, 8046, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8558, 972, 8047, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8559, 972, 8048, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8560, 972, 8049, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8561, 972, 8050, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8562, 972, 8051, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8563, 972, 8052, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8564, 972, 8053, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8565, 972, 8054, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8566, 972, 8055, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8567, 972, 8056, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8568, 972, 8057, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8569, 972, 8058, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8570, 972, 8059, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8571, 972, 8060, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8572, 972, 8061, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8573, 972, 8062, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7684, 918, 7154, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7685, 918, 7155, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7686, 918, 7156, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7687, 918, 7157, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7688, 918, 7158, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10863, 1118, 10269, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10864, 1118, 10270, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8598, 974, 8087, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8599, 974, 8088, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8493, 968, 7982, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8494, 968, 7983, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8495, 968, 7984, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8496, 968, 7985, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8497, 968, 7986, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8498, 968, 7987, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8499, 968, 7988, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8500, 968, 7989, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8501, 968, 7990, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8502, 968, 7991, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8503, 968, 7992, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8504, 968, 7993, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8505, 968, 7994, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8506, 968, 7995, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8507, 968, 7996, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8508, 968, 7997, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8600, 974, 8089, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8601, 974, 8090, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8602, 974, 8091, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8603, 974, 8092, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8604, 974, 8093, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8605, 974, 8094, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8606, 974, 8095, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8607, 974, 8096, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8608, 974, 8097, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8609, 974, 8098, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8610, 974, 8099, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8611, 974, 8100, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8612, 974, 8101, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8613, 974, 8102, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8614, 974, 8103, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8615, 975, 8104, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8616, 975, 8105, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8617, 975, 8106, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8618, 975, 8107, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8619, 975, 8108, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8620, 975, 8109, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8621, 975, 8110, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8622, 975, 8111, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8623, 975, 8112, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8624, 975, 8113, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8625, 975, 8114, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8626, 975, 8115, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8627, 975, 8116, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8628, 975, 8117, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8629, 975, 8118, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8630, 975, 8119, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8631, 975, 8120, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8632, 975, 8121, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8633, 976, 8122, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8634, 976, 8123, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8635, 976, 8124, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8636, 976, 8125, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8637, 976, 8126, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8638, 976, 8127, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8639, 976, 8128, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8640, 976, 8129, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8641, 976, 8130, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8642, 976, 8131, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8643, 976, 8132, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8644, 976, 8133, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8645, 976, 8134, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8646, 976, 8135, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8647, 976, 8136, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8648, 976, 8137, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8649, 976, 8138, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8650, 976, 8139, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8651, 976, 8140, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8652, 977, 8141, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8653, 977, 8142, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8654, 977, 8143, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8655, 977, 8144, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8656, 977, 8145, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8657, 977, 8146, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8658, 977, 8147, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8659, 977, 8148, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8660, 977, 8149, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8661, 977, 8150, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8662, 977, 8151, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8663, 977, 8152, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8664, 977, 8153, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8665, 977, 8154, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8666, 977, 8155, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8667, 978, 8156, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8668, 978, 8157, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8669, 978, 8158, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8670, 978, 8159, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8671, 978, 8160, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8672, 978, 8161, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8673, 978, 8162, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8674, 978, 8163, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8675, 978, 8164, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8676, 978, 8165, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8677, 978, 8166, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8678, 978, 8167, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8679, 978, 8168, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8680, 978, 8169, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8681, 978, 8170, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8682, 978, 8171, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8683, 978, 8172, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8684, 978, 8173, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8685, 978, 8174, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8686, 978, 8175, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (8687, 978, 8176, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (8688, 979, 8177, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8689, 979, 8178, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8690, 979, 8179, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8691, 979, 8180, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8692, 979, 8181, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8693, 979, 8182, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8694, 979, 8183, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8695, 979, 8184, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8696, 979, 8185, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8697, 979, 8186, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8698, 979, 8187, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8699, 979, 8188, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8700, 979, 8189, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8701, 979, 8190, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8702, 979, 8191, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8703, 979, 8192, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8704, 979, 8193, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8705, 979, 8194, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8706, 979, 8195, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8707, 980, 8196, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8708, 980, 8197, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8709, 980, 8198, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8710, 980, 8199, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8711, 980, 8200, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8712, 980, 8201, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8713, 980, 8202, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8714, 980, 8203, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8715, 980, 8204, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8716, 980, 8205, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8717, 980, 8206, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8718, 980, 8207, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8719, 980, 8208, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8720, 980, 8209, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8721, 980, 8210, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8722, 980, 8211, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8723, 980, 8212, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8724, 980, 8213, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8725, 980, 8214, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8726, 980, 8215, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (8727, 981, 8216, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8728, 981, 8217, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8729, 981, 8218, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8730, 981, 8219, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8731, 981, 8220, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8732, 981, 8221, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8733, 981, 8222, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8734, 981, 8223, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8735, 981, 8224, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8736, 981, 8225, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8737, 981, 8226, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8738, 981, 8227, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8739, 981, 8228, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8740, 981, 8229, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8741, 981, 8230, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8742, 981, 8231, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8743, 981, 8232, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8744, 981, 8233, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8745, 981, 8234, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8746, 981, 8235, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (8747, 982, 8236, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8748, 982, 8237, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8749, 982, 8238, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8750, 982, 8239, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8751, 982, 8240, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8752, 982, 8241, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8753, 982, 8242, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8754, 982, 8243, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8755, 982, 8244, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8756, 982, 8245, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8757, 982, 8246, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8758, 982, 8247, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8759, 982, 8248, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8760, 982, 8249, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8761, 982, 8250, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8762, 982, 8251, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8763, 983, 8252, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8764, 983, 8253, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8765, 983, 8254, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8766, 983, 8255, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8767, 983, 8256, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8768, 983, 8257, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8769, 983, 8258, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8770, 983, 8259, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8771, 983, 8260, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8772, 983, 8261, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8773, 983, 8262, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8774, 983, 8263, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8775, 983, 8264, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8776, 983, 8265, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8777, 983, 8266, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8778, 984, 8267, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8779, 984, 8268, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8780, 984, 8269, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8781, 984, 8270, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8782, 984, 8271, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8783, 984, 8272, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8784, 984, 8273, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8785, 984, 8274, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8786, 984, 8275, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8787, 984, 8276, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8788, 984, 8277, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8789, 984, 8278, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8790, 984, 8279, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8791, 984, 8280, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8792, 984, 8281, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8793, 984, 8282, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8794, 984, 8283, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8795, 984, 8284, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8796, 984, 8285, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8797, 985, 8286, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8798, 985, 8287, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8799, 985, 8288, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8800, 985, 8289, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8801, 985, 8290, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8802, 985, 8291, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8803, 985, 8292, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8804, 985, 8293, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8805, 985, 8294, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8806, 985, 8295, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8807, 985, 8296, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8808, 985, 8297, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8809, 985, 8298, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8810, 985, 8299, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8811, 985, 8300, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8812, 986, 8301, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8813, 986, 8302, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8814, 986, 8303, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8815, 986, 8304, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8816, 986, 8305, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8817, 986, 8306, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8818, 986, 8307, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8819, 986, 8308, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8820, 986, 8309, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8821, 986, 8310, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8822, 986, 8311, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8823, 986, 8312, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8824, 986, 8313, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8825, 986, 8314, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8826, 986, 8315, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8827, 986, 8316, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8828, 987, 8317, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8829, 987, 8318, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8830, 987, 8319, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8831, 987, 8320, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8832, 987, 8321, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8833, 987, 8322, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8834, 988, 8323, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8835, 988, 8324, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8836, 988, 8325, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8837, 988, 8326, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8838, 988, 8327, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8839, 988, 8328, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8840, 988, 8329, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8841, 988, 8330, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8842, 988, 8331, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8843, 988, 8332, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8844, 988, 8333, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8845, 988, 8334, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8846, 988, 8335, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8847, 988, 8336, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8848, 989, 8337, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8849, 989, 8338, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8850, 989, 8339, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8851, 989, 8340, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8852, 989, 8341, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8853, 989, 8342, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8854, 989, 8343, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8855, 989, 8344, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8856, 989, 8345, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8857, 989, 8346, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8858, 990, 8347, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8859, 990, 8348, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8860, 990, 8349, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8861, 990, 8350, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8862, 990, 8351, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8863, 990, 8352, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8864, 990, 8353, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8865, 990, 8354, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8866, 990, 8355, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8867, 990, 8356, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8868, 990, 8357, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8869, 990, 8358, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8870, 990, 8359, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8871, 990, 8360, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8872, 990, 8361, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8873, 990, 8362, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8874, 990, 8363, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8875, 990, 8364, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8876, 990, 8365, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8877, 991, 8366, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8878, 991, 8367, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8879, 991, 8368, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8880, 991, 8369, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8881, 991, 8370, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8882, 991, 8371, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8883, 991, 8372, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8884, 991, 8373, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8885, 991, 8374, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8886, 991, 8375, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8887, 991, 8376, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8888, 991, 8377, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8889, 991, 8378, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8890, 991, 8379, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8917, 995, 8406, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8918, 995, 8407, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8919, 995, 8408, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8920, 995, 8409, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8921, 995, 8410, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8922, 995, 8411, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8923, 995, 8412, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8924, 995, 8413, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8925, 995, 8414, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8926, 995, 8415, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8927, 995, 8416, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8928, 995, 8417, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8929, 995, 8418, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8930, 995, 8419, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8931, 995, 8420, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8932, 996, 8421, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8933, 996, 8422, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8934, 996, 8423, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8935, 996, 8424, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8936, 996, 8425, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8937, 996, 8426, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8938, 996, 8427, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8939, 996, 8428, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8940, 996, 8429, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8941, 996, 8430, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8942, 996, 8431, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8943, 996, 8432, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8944, 996, 8433, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8945, 996, 8434, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8946, 996, 8435, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8947, 996, 8436, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8948, 996, 8437, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8949, 996, 8438, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8950, 996, 8439, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8951, 996, 8440, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (8952, 996, 8441, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (8953, 996, 8442, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (8954, 996, 8443, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (8955, 996, 8444, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (8956, 996, 8445, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (8957, 996, 8446, 26);
INSERT INTO 'albumsrecordingsmap' VALUES (8958, 996, 8447, 27);
INSERT INTO 'albumsrecordingsmap' VALUES (8959, 996, 8448, 28);
INSERT INTO 'albumsrecordingsmap' VALUES (8960, 996, 8449, 29);
INSERT INTO 'albumsrecordingsmap' VALUES (8961, 996, 8450, 30);
INSERT INTO 'albumsrecordingsmap' VALUES (8962, 996, 8451, 31);
INSERT INTO 'albumsrecordingsmap' VALUES (8963, 996, 8452, 32);
INSERT INTO 'albumsrecordingsmap' VALUES (8964, 996, 8453, 33);
INSERT INTO 'albumsrecordingsmap' VALUES (8965, 996, 8454, 34);
INSERT INTO 'albumsrecordingsmap' VALUES (8966, 996, 8455, 35);
INSERT INTO 'albumsrecordingsmap' VALUES (8967, 997, 8456, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8968, 997, 8457, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8969, 997, 8458, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8970, 997, 8459, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8971, 997, 8460, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8972, 997, 8461, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8973, 997, 8462, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8974, 997, 8463, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8975, 997, 8464, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8976, 997, 8465, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8977, 997, 8466, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8978, 997, 8467, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8979, 997, 8468, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9013, 999, 8502, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9014, 999, 8503, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9015, 999, 8504, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9016, 999, 8505, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9017, 999, 8506, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9018, 999, 8507, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9019, 999, 8508, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9020, 999, 8509, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9021, 999, 8510, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9022, 999, 8511, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9023, 999, 8512, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9024, 999, 8513, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9025, 999, 8514, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9026, 999, 8515, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9027, 999, 8516, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9028, 999, 8517, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9029, 1000, 8518, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9030, 1000, 8519, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9031, 1000, 8520, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9032, 1000, 8521, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9033, 1000, 8522, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9034, 1000, 8523, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9035, 1000, 8524, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9036, 1000, 8525, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9037, 1000, 8526, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9038, 1000, 8527, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9039, 1000, 8528, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9040, 1000, 8529, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9041, 1000, 8530, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9042, 1000, 8531, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9043, 1000, 8532, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9044, 1000, 8533, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9045, 1000, 8534, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9046, 1000, 8535, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9047, 1000, 8536, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (9048, 1000, 8537, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (9049, 1001, 8556, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9050, 1001, 8557, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9051, 1001, 8558, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9052, 1001, 8559, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9053, 1001, 8560, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9054, 1001, 8561, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9055, 1001, 8562, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9056, 1001, 8563, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9057, 1001, 8564, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9058, 1001, 8565, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9059, 1001, 8566, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9060, 1001, 8567, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9061, 1001, 8568, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9062, 1001, 8569, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9063, 1001, 8570, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9064, 1001, 8571, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9065, 1001, 8572, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9066, 1001, 8573, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9067, 1002, 8574, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9068, 1002, 8575, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9069, 1002, 8576, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9070, 1002, 8577, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9071, 1002, 8578, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9072, 1002, 8579, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9073, 1002, 8580, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9074, 1002, 8581, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9075, 1002, 8582, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9076, 1002, 8583, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9077, 1002, 8584, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9078, 1002, 8585, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9079, 1002, 8586, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9080, 1002, 8587, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9081, 1002, 8588, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9082, 1002, 8589, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9083, 1002, 8590, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9084, 1002, 8591, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9085, 1002, 8592, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (9086, 1002, 8593, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (9087, 1002, 8594, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (9088, 1003, 8595, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9089, 1003, 8596, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9090, 1003, 8597, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9091, 1003, 8598, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9092, 1003, 8599, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9093, 1003, 8600, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9094, 1003, 8601, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9095, 1003, 8602, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9096, 1003, 8603, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9097, 1003, 8604, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9098, 1003, 8605, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9099, 1003, 8606, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9100, 1003, 8607, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9101, 1003, 8608, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9102, 1003, 8609, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9103, 1003, 8610, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9104, 1004, 8611, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9105, 1004, 8612, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9106, 1004, 8613, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9107, 1004, 8614, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9108, 1004, 8615, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9109, 1004, 8616, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8980, 997, 8469, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8981, 997, 8470, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8982, 997, 8471, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8983, 997, 8472, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8984, 997, 8473, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8985, 997, 8474, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8986, 997, 8475, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (8987, 997, 8476, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (8988, 997, 8477, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (8989, 997, 8478, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (8990, 997, 8479, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (8991, 997, 8480, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (8992, 997, 8481, 26);
INSERT INTO 'albumsrecordingsmap' VALUES (9110, 1004, 8617, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9111, 1004, 8618, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9112, 1004, 8619, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9113, 1004, 8620, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9114, 1004, 8621, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9115, 1004, 8622, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9116, 1004, 8623, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9117, 1004, 8624, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9118, 1004, 8625, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9119, 1004, 8626, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9120, 1004, 8627, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9121, 1004, 8628, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9122, 1004, 8629, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (9123, 1005, 8650, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9124, 1005, 8651, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9125, 1005, 8652, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9126, 1005, 8653, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9127, 1005, 8654, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9128, 1005, 8655, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9129, 1005, 8656, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9130, 1005, 8657, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9131, 1005, 8658, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9132, 1005, 8659, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9133, 1005, 8660, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9134, 1005, 8661, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9135, 1005, 8662, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9136, 1005, 8663, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9137, 1005, 8664, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9138, 1005, 8665, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9139, 1005, 8666, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9140, 1005, 8667, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9141, 1005, 8668, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (9142, 1005, 8669, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (9143, 1006, 8670, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9144, 1006, 8671, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9145, 1006, 8672, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9146, 1006, 8673, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9147, 1006, 8674, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9148, 1006, 8675, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9149, 1006, 8676, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9150, 1006, 8677, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9151, 1006, 8678, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9152, 1006, 8679, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9153, 1006, 8680, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9154, 1006, 8681, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9155, 1006, 8682, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9156, 1006, 8683, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9157, 1006, 8684, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9158, 1006, 8685, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9159, 1006, 8686, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9160, 1006, 8687, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9161, 1006, 8688, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (9162, 1006, 8689, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (9163, 1007, 8690, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9164, 1007, 8691, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9165, 1007, 8692, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9166, 1007, 8693, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9167, 1007, 8694, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9168, 1007, 8695, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9169, 1007, 8696, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9170, 1007, 8697, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9171, 1007, 8698, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9172, 1007, 8699, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9173, 1007, 8700, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9174, 1007, 8701, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9175, 1007, 8702, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9176, 1008, 8703, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9177, 1008, 8704, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9178, 1008, 8705, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9179, 1008, 8706, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9180, 1008, 8707, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9181, 1008, 8708, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9182, 1008, 8709, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9183, 1008, 8710, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9184, 1008, 8711, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9185, 1008, 8712, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9186, 1008, 8713, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9187, 1008, 8714, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9188, 1008, 8715, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9189, 1008, 8716, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9190, 1008, 8717, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9191, 1009, 8718, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9192, 1009, 8719, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9193, 1009, 8720, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9194, 1009, 8721, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9195, 1009, 8722, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9196, 1009, 8723, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9197, 1009, 8724, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9198, 1009, 8725, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9199, 1009, 8726, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9200, 1009, 8727, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9201, 1009, 8728, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9202, 1009, 8729, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9203, 1009, 8730, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9204, 1009, 8731, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9205, 1009, 8732, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9206, 1009, 8733, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9207, 1009, 8734, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9208, 1009, 8735, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9209, 1010, 8736, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9210, 1010, 8737, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9211, 1010, 8738, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9212, 1010, 8739, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9213, 1010, 8740, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9214, 1010, 8741, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9215, 1010, 8742, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9216, 1010, 8743, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9217, 1010, 8744, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9218, 1010, 8745, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9219, 1010, 8746, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9220, 1010, 8747, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9221, 1011, 8748, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9222, 1011, 8749, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9223, 1011, 8750, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9224, 1011, 8751, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9225, 1011, 8752, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9226, 1011, 8753, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9227, 1011, 8754, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9228, 1011, 8755, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9229, 1011, 8756, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9230, 1011, 8757, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9231, 1011, 8758, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9232, 1011, 8759, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9233, 1011, 8760, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9234, 1011, 8761, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9235, 1011, 8762, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9236, 1011, 8763, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9237, 1011, 8764, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9238, 1011, 8765, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9239, 1011, 8766, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (9240, 1011, 8767, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (9241, 1011, 8768, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (9242, 1011, 8769, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (9243, 1011, 8770, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (9244, 1011, 8771, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (9245, 1012, 8772, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9246, 1012, 8773, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9247, 1012, 8774, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9248, 1012, 8775, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9249, 1012, 8776, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9250, 1012, 8777, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9251, 1012, 8778, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9252, 1012, 8779, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9253, 1012, 8780, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9254, 1012, 8781, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9255, 1012, 8782, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9256, 1012, 8783, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9257, 1012, 8784, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9258, 1012, 8785, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9259, 1012, 8786, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9260, 1012, 8787, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9261, 1012, 8788, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9262, 1012, 8789, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9263, 1013, 8790, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9264, 1013, 8791, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9265, 1013, 8792, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9266, 1013, 8793, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9267, 1013, 8794, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9268, 1013, 8795, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9269, 1013, 8796, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9270, 1013, 8797, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9271, 1013, 8798, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9272, 1013, 8799, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9273, 1013, 8800, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9274, 1013, 8801, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9275, 1013, 8802, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9276, 1013, 8803, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9277, 1013, 8804, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9278, 1013, 8805, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9279, 1013, 8806, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9280, 1013, 8807, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9281, 1013, 8808, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (9282, 1013, 8809, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (9283, 1013, 8810, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (9284, 1014, 8811, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9285, 1014, 8812, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9286, 1014, 8813, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9287, 1014, 8814, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9288, 1014, 8815, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9289, 1014, 8816, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9304, 1016, 8831, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9305, 1016, 8832, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9306, 1016, 8833, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9307, 1016, 8834, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9308, 1016, 8835, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9309, 1016, 8836, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9310, 1016, 8837, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9311, 1016, 8838, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9312, 1016, 8839, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9313, 1016, 8840, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9314, 1016, 8841, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9315, 1016, 8842, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9316, 1016, 8843, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9317, 1016, 8844, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9318, 1016, 8845, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (925, 79, 915, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (926, 79, 916, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (927, 79, 917, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (928, 79, 918, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (929, 79, 920, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (930, 79, 59, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (931, 79, 90, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (935, 79, 924, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (936, 79, 925, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (937, 79, 926, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9901, 79, 9328, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9902, 1052, 9329, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9903, 1052, 9330, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9904, 1052, 9331, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9905, 1052, 9332, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9906, 1052, 9333, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9907, 1052, 9334, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9908, 1052, 9335, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9909, 1052, 9336, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9910, 1052, 9337, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9911, 1052, 9338, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9912, 1052, 9339, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9913, 1052, 9340, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9914, 1052, 9341, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9915, 1052, 9342, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9916, 1052, 9343, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9917, 1052, 9344, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9667, 1039, 9151, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9668, 1039, 9152, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9669, 1039, 9153, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9670, 1039, 9154, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9671, 1039, 9155, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9672, 1039, 9156, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9673, 1039, 9157, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9674, 1039, 9158, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9675, 1039, 9159, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9676, 1039, 9160, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9677, 1039, 9161, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9678, 1039, 9162, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9679, 1039, 9163, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9680, 1039, 9164, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9681, 1039, 9165, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9682, 1039, 9166, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9683, 1039, 9167, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9684, 1039, 9168, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9685, 1039, 9169, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (9686, 1039, 9170, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (9687, 1039, 9171, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (9688, 1039, 9172, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (9689, 1039, 9173, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (9690, 1039, 9174, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (9691, 1039, 9175, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (9692, 1039, 9176, 26);
INSERT INTO 'albumsrecordingsmap' VALUES (9693, 1039, 9177, 27);
INSERT INTO 'albumsrecordingsmap' VALUES (9694, 1039, 9178, 28);
INSERT INTO 'albumsrecordingsmap' VALUES (9695, 1039, 9179, 29);
INSERT INTO 'albumsrecordingsmap' VALUES (9696, 1039, 9180, 30);
INSERT INTO 'albumsrecordingsmap' VALUES (9703, 1039, 9187, 37);
INSERT INTO 'albumsrecordingsmap' VALUES (9704, 1039, 9188, 38);
INSERT INTO 'albumsrecordingsmap' VALUES (9705, 1039, 9189, 39);
INSERT INTO 'albumsrecordingsmap' VALUES (9706, 1039, 9190, 40);
INSERT INTO 'albumsrecordingsmap' VALUES (9707, 1039, 9191, 41);
INSERT INTO 'albumsrecordingsmap' VALUES (9708, 1039, 9192, 42);
INSERT INTO 'albumsrecordingsmap' VALUES (9918, 1053, 9345, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9919, 1053, 9346, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9920, 1053, 9347, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9921, 1053, 9348, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9922, 1053, 9349, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9923, 1053, 9350, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9924, 1053, 9351, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9925, 1053, 9352, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9926, 1053, 9353, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9927, 1053, 9354, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9928, 1053, 9355, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9929, 1053, 9356, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9930, 1053, 9357, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9931, 1054, 9358, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9932, 1054, 9359, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9933, 1054, 9360, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9934, 1054, 9361, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9935, 1054, 9363, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9936, 1054, 9362, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9937, 1054, 9364, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9938, 1054, 9365, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9939, 1054, 9366, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9940, 1054, 9367, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9941, 1054, 9368, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9942, 1054, 9369, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9943, 1055, 9370, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9944, 1055, 9371, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9945, 1055, 9372, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9946, 1055, 9373, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9947, 1055, 9374, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9948, 1055, 9375, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9949, 1055, 9376, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9950, 1055, 9377, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9951, 1055, 9378, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9952, 1055, 9379, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9953, 1055, 9380, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9954, 1055, 9381, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9955, 1055, 9382, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9956, 1055, 9383, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9957, 1055, 9384, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9958, 1055, 9385, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9959, 1055, 9386, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9975, 1057, 9402, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9976, 1057, 9403, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9977, 1057, 9404, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9978, 1057, 9405, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9979, 1057, 9406, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9980, 1057, 9407, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9981, 1057, 9408, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9982, 1057, 9409, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9983, 1057, 9410, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9984, 1057, 9411, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9985, 1057, 9412, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9986, 1057, 9413, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9987, 1057, 9414, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9988, 1057, 9415, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9989, 1057, 9416, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9990, 1058, 9417, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9991, 1058, 9418, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9992, 1058, 9419, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9993, 1058, 9420, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9994, 1058, 9421, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9995, 1058, 9422, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9996, 1058, 9423, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9997, 1058, 9424, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9998, 1058, 9425, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9999, 1058, 9426, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10000, 1058, 9427, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10001, 1058, 9428, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10002, 1059, 9429, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10003, 1059, 9430, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10004, 1059, 9431, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10005, 1059, 9432, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10006, 1059, 9433, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10007, 1059, 9434, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10008, 1059, 9435, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10009, 1059, 9436, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10010, 1059, 9437, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10011, 1059, 9438, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10012, 1059, 9439, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10013, 1059, 9440, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10014, 1059, 9441, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10015, 1059, 9442, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10016, 1058, 9443, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10017, 1060, 9444, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10018, 1060, 3925, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10019, 1060, 9446, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10020, 1060, 9447, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10021, 1060, 9448, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10022, 1060, 9449, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10023, 1060, 9450, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10024, 1060, 9451, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10025, 1060, 9452, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10026, 1060, 9453, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10027, 1060, 9454, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10028, 1060, 9455, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10029, 1060, 9456, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10030, 1060, 9457, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10031, 1060, 9458, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10032, 1061, 9459, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10033, 1061, 9460, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10034, 1061, 9461, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10035, 1061, 9462, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10036, 1061, 9463, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10037, 1061, 9464, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10038, 1061, 9465, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10039, 1061, 9466, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10040, 1061, 9467, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10041, 1061, 9468, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10042, 1061, 9469, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10043, 1061, 9470, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10073, 1063, 9500, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10074, 1063, 9501, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10075, 1063, 9502, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10076, 1063, 9503, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10077, 1063, 9504, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10078, 1063, 9505, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10079, 1063, 9506, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10080, 1063, 9507, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10081, 1063, 9508, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10082, 1063, 9509, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10083, 1063, 9510, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10084, 1063, 9511, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10085, 1063, 9512, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10086, 1063, 9513, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10087, 1064, 9514, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10088, 1064, 9515, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10089, 1064, 9516, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10090, 1064, 9517, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10091, 1064, 9518, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10092, 1064, 9519, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10093, 1064, 9520, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10094, 1064, 9521, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10095, 1064, 9522, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10096, 1064, 9523, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10097, 1064, 9524, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10098, 1064, 9525, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10099, 1064, 9526, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10100, 1064, 9527, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10101, 1064, 9528, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10102, 1064, 9529, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10137, 1067, 9564, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10138, 1067, 9565, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10139, 1067, 9566, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10140, 1067, 9567, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10141, 1067, 9568, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10142, 1067, 9569, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10143, 1067, 9570, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10144, 1067, 9571, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10145, 1067, 9572, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10146, 1067, 9573, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10147, 1067, 9574, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10148, 1067, 9575, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10149, 1067, 9576, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10168, 1069, 9595, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10169, 1069, 9596, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10170, 1069, 9597, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10171, 1069, 9598, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10172, 1069, 9599, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10173, 1069, 9600, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10174, 1069, 9601, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10175, 1069, 9602, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10176, 1069, 9603, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10177, 1069, 9604, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10178, 1069, 9605, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10179, 1069, 9606, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10180, 1069, 9607, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10181, 1069, 9608, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10182, 1069, 9609, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10183, 1069, 9610, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10184, 1069, 9611, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10185, 1069, 9612, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (10187, 1070, 2952, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10188, 1070, 9615, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10189, 1070, 9616, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10190, 1070, 9617, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10191, 1070, 9618, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10192, 1070, 9619, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10193, 1070, 9620, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10194, 1070, 9621, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10195, 1070, 9622, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10196, 1070, 9623, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10197, 1070, 9624, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10198, 1070, 7662, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10199, 1070, 9626, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10200, 1070, 9627, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10201, 1070, 9628, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10202, 1070, 9629, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10203, 1070, 9630, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (10204, 1070, 9631, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10205, 1071, 8782, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10206, 1071, 9633, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10207, 1071, 9634, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10208, 1071, 9635, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10209, 1071, 9636, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10210, 1071, 9637, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10211, 1071, 9638, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10212, 1071, 9639, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10213, 1071, 9640, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10214, 1071, 9641, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10215, 1071, 9642, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10216, 1071, 9643, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10217, 1071, 9644, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10219, 1071, 9646, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10220, 1071, 9647, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10221, 1071, 9648, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10222, 1071, 9649, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10223, 1071, 9650, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (10224, 1071, 3369, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (10225, 1071, 9651, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (10226, 1072, 9652, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10227, 1072, 9653, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10228, 1072, 9654, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10229, 1072, 9655, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10230, 1072, 9656, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10231, 1072, 9657, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10232, 1072, 9658, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10233, 1072, 9659, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10234, 1072, 9660, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10235, 1072, 9661, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10236, 1072, 9662, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10237, 1072, 9663, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10238, 1073, 3705, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10249, 1073, 1962, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10251, 1073, 3192, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10241, 1073, 9664, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10242, 1073, 9665, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10244, 1073, 3189, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10246, 1073, 3190, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10247, 1073, 3191, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10252, 1073, 9667, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10253, 1073, 9668, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10254, 1073, 9669, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10255, 1074, 9670, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10256, 1074, 9671, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10257, 1074, 9672, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10258, 1074, 9673, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10259, 1074, 9674, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10260, 1074, 9675, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10261, 1074, 9676, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10262, 1074, 9677, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10263, 1074, 9678, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10264, 1074, 9679, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10265, 1074, 9680, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10125, 1066, 9552, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10126, 1066, 9553, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10127, 1066, 9554, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10128, 1066, 9555, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10129, 1066, 9556, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10130, 1066, 9557, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10131, 1066, 9558, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10132, 1066, 9559, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10133, 1066, 9560, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10134, 1066, 9561, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10135, 1066, 9562, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10136, 1066, 9563, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10103, 1065, 9530, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10104, 1065, 9553, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10105, 1065, 9532, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10106, 1065, 9533, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10107, 1065, 9534, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10108, 1065, 9535, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10109, 1065, 9536, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10110, 1065, 9537, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10111, 1065, 9538, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10112, 1065, 9539, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10113, 1065, 9540, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10114, 1065, 9541, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10115, 1065, 9542, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10116, 1065, 9543, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10117, 1065, 9544, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10118, 1065, 9545, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10119, 1065, 9546, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10266, 1074, 9681, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10267, 1074, 9682, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10268, 1074, 9683, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10269, 1074, 9684, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (419, 34, 457, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (420, 34, 458, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (421, 34, 460, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (422, 34, 462, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (423, 34, 463, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (424, 34, 464, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (425, 34, 465, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2908, 269, 2906, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2909, 269, 2907, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2910, 269, 2909, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2911, 269, 2910, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2912, 269, 2911, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4432, 269, 4254, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4433, 269, 4255, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4434, 269, 4256, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10270, 269, 9685, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10271, 269, 9686, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10272, 214, 2315, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10273, 269, 9688, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10186, 1069, 9613, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (10289, 1076, 9705, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10290, 1076, 9706, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10291, 1076, 9707, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10292, 1076, 9708, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10293, 1076, 9709, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10294, 1076, 9710, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10295, 1076, 9711, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10296, 1076, 9712, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10297, 1076, 9713, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10298, 1076, 9714, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10299, 1076, 9715, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10300, 1076, 9716, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10301, 1076, 9717, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10302, 1076, 9718, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10303, 1077, 9719, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10304, 1077, 9720, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10305, 1077, 9721, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10306, 1077, 9722, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10307, 1077, 9723, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10308, 1077, 9724, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10309, 1077, 9725, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10310, 1077, 9726, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10311, 1077, 9727, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10312, 1077, 9728, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10313, 1077, 9729, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10314, 1077, 9730, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10315, 1077, 9731, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10316, 1077, 9732, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10317, 1077, 9733, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10318, 1022, 9734, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10319, 1078, 9735, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10320, 1078, 9736, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10321, 1078, 9737, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10322, 1078, 9738, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10323, 1078, 9739, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10324, 1078, 9740, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10325, 1078, 9741, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10326, 1078, 9742, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10327, 1078, 9743, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10328, 1078, 9744, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10329, 1078, 9745, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10330, 1078, 9746, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10331, 1078, 9747, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10332, 1078, 9748, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10333, 1078, 9749, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10334, 1078, 9750, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10335, 1079, 9751, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10336, 1079, 9752, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10337, 1079, 9753, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10338, 1079, 9754, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10339, 1079, 9755, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10340, 1079, 9757, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10341, 1079, 9756, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10342, 1079, 9758, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10343, 1079, 9759, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10344, 1079, 9760, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10345, 1079, 9761, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10346, 1079, 9762, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10347, 1079, 9763, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10348, 1080, 9764, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10349, 1080, 9765, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10350, 1080, 9766, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10351, 1080, 9767, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10353, 1080, 9769, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10352, 1080, 9768, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10354, 1080, 9770, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10355, 1080, 9771, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10356, 1080, 9772, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10357, 1080, 9773, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10358, 1080, 9774, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10359, 1080, 9775, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10360, 1080, 9776, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5572, 394, 5225, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5573, 394, 5226, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5574, 394, 5227, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5575, 394, 5228, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5576, 394, 5229, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5577, 394, 5230, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5578, 394, 5231, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5579, 394, 5232, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5580, 394, 5233, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5581, 394, 5234, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5582, 394, 5235, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5583, 394, 5236, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5584, 394, 5237, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5585, 394, 5238, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5586, 394, 5239, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10361, 1081, 9777, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10362, 1081, 9778, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10363, 1081, 9779, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10364, 1081, 9780, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10365, 1081, 9782, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10366, 1081, 9781, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10367, 1081, 9783, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10368, 1081, 9784, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10369, 1081, 9785, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10370, 1081, 9787, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10371, 1081, 9788, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10372, 1081, 9786, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3269, 315, 3243, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3270, 315, 3244, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3271, 315, 3245, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3272, 315, 3246, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3273, 315, 3247, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10392, 315, 9808, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10393, 315, 9809, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10394, 315, 9810, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10274, 1075, 9690, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10275, 1075, 9691, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10276, 1075, 9692, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10277, 1075, 9693, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10278, 1075, 9694, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10279, 1075, 9695, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10280, 1075, 9696, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10281, 1075, 9697, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10282, 1075, 9698, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10283, 1075, 9699, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10284, 1075, 9700, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10395, 315, 9811, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10396, 315, 9812, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10397, 315, 9813, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10398, 315, 9814, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10399, 315, 9815, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10285, 1075, 9701, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10286, 1075, 9702, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10287, 1075, 9703, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10862, 1118, 10268, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10865, 1118, 10271, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10866, 1118, 10272, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10867, 1118, 10273, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10868, 1118, 10274, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10400, 315, 9816, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10401, 1083, 9817, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10402, 1083, 9818, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10403, 1083, 9819, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10404, 1083, 9820, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10405, 1083, 9821, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10406, 1083, 9822, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10407, 1083, 9823, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10408, 1083, 9824, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10409, 1083, 9825, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10410, 1083, 9826, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10411, 1083, 9827, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10412, 1083, 9828, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10413, 1083, 9829, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5134, 352, 4868, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5135, 352, 4869, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5136, 352, 4870, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5137, 352, 4871, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5138, 352, 4872, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5139, 352, 4873, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5140, 352, 4874, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5141, 352, 4875, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5142, 352, 4876, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5143, 352, 4877, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5144, 352, 4878, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5145, 352, 4879, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5146, 352, 4880, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5147, 352, 4881, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10431, 1085, 9847, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10432, 1085, 9848, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10433, 1085, 9849, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10434, 1085, 9850, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10435, 1085, 9851, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10436, 1085, 9852, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10437, 1085, 9853, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10438, 1085, 9854, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10439, 1085, 9855, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10440, 1085, 9856, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10288, 1075, 9704, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10443, 1087, 9860, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2473, 245, 2464, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2474, 245, 2465, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2475, 245, 2466, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2476, 245, 2467, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2477, 245, 2468, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2478, 245, 2469, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2479, 245, 2470, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2480, 245, 2471, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2481, 245, 2472, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2482, 245, 2473, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2483, 245, 2475, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3067, 245, 3078, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10441, 245, 9857, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10444, 1087, 9861, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10465, 1089, 4933, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10466, 1089, 2962, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10809, 1113, 10215, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10810, 1113, 10216, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10811, 1113, 10217, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10812, 1113, 10218, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10813, 1113, 10219, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10814, 1113, 10220, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10815, 1113, 10221, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10816, 1113, 10222, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10817, 1113, 10223, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10824, 1113, 10230, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10150, 1068, 9577, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10151, 1068, 9578, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10152, 1068, 9579, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4323, 365, 9858, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4324, 365, 1706, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4325, 365, 1707, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4326, 365, 1708, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4327, 365, 1709, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4328, 365, 1710, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4329, 365, 1711, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4330, 365, 1712, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4331, 365, 1713, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4332, 365, 1715, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4333, 365, 1716, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4334, 365, 3618, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4335, 365, 3619, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (4336, 365, 4168, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4337, 365, 4169, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (4338, 365, 4171, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10442, 365, 9859, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10467, 1089, 7662, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10468, 1089, 2964, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10445, 1087, 9862, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10446, 1087, 9863, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10447, 1087, 9864, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10448, 1087, 9865, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10449, 1087, 9866, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10153, 1068, 9580, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10154, 1068, 9581, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10155, 1068, 9582, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10156, 1068, 9583, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10157, 1068, 9584, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10158, 1068, 9585, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10159, 1068, 9586, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10160, 1068, 9587, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10161, 1068, 9588, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10162, 1068, 9589, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10163, 1068, 9590, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10164, 1068, 9591, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10165, 1068, 9592, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10166, 1068, 9593, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10167, 1068, 9594, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (6038, 439, 5581, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6039, 439, 5582, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6040, 439, 5583, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6041, 439, 5584, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6042, 439, 5585, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6043, 439, 5586, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6044, 439, 5587, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6045, 439, 5588, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6046, 439, 5589, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6047, 439, 5590, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6048, 439, 5591, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6049, 439, 5592, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6050, 439, 5593, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6051, 439, 5594, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6052, 439, 5595, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10450, 1087, 9867, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10451, 1087, 9868, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10469, 1090, 9888, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10470, 1090, 9889, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10485, 1091, 9875, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10452, 1087, 9869, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10486, 1091, 9876, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10825, 1113, 10231, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5368, 371, 5067, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10453, 1088, 4060, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10454, 1088, 8680, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10455, 1088, 8660, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10456, 1088, 2829, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10471, 1090, 9890, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10472, 1090, 9891, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10487, 1091, 9877, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10488, 1091, 9878, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10489, 1091, 9879, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10473, 1090, 9892, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10474, 1090, 9893, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10475, 1090, 9894, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10476, 1090, 9895, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10477, 1090, 9896, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10478, 1090, 9897, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10479, 1090, 9898, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10480, 1090, 9899, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10481, 1090, 9900, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10482, 1090, 9901, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10483, 1090, 9902, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10484, 1090, 9903, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10490, 1091, 9880, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10491, 1091, 9881, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10492, 1091, 9882, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10493, 1091, 9883, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10494, 1091, 9884, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10495, 1091, 9885, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10496, 1091, 9886, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10497, 1091, 9887, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5369, 371, 5068, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5370, 371, 5069, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5371, 371, 5070, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5372, 371, 5071, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5373, 371, 5072, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5374, 371, 5073, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10498, 1092, 9904, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10499, 1092, 9905, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10500, 1092, 9906, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10501, 1092, 9907, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10502, 1092, 9908, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10503, 1092, 9909, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10504, 1092, 9910, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10505, 1092, 9911, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10506, 1092, 9912, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10507, 1092, 9913, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10508, 1092, 9914, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10509, 1092, 9915, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10510, 1092, 9916, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10511, 1092, 9917, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5375, 371, 5074, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5376, 371, 5075, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5377, 371, 5076, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10512, 1093, 9918, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10513, 1093, 9919, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10514, 1093, 9920, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10515, 1093, 9921, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10516, 1093, 9922, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10517, 1093, 9923, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10518, 1093, 9924, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10519, 1093, 9925, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10520, 1093, 9926, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10521, 1093, 9927, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10522, 1093, 9928, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10523, 1093, 9929, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10524, 1093, 9930, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10525, 1093, 9931, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10526, 1093, 9932, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10527, 1093, 9933, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10528, 1093, 9934, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10529, 1093, 9935, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (5378, 371, 5077, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5379, 371, 5078, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1124, 93, 1105, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1125, 93, 1106, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1126, 93, 1107, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1127, 93, 1108, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1128, 93, 1109, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1129, 93, 1110, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1130, 93, 1111, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1131, 93, 1112, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1132, 93, 1113, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1133, 93, 1114, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1134, 93, 1115, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1135, 93, 1116, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1136, 93, 1117, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1137, 93, 1118, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1138, 93, 1119, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (1139, 93, 1120, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10530, 1094, 9936, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10531, 1094, 9937, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10532, 1094, 9938, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10533, 1094, 9939, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10534, 1094, 9940, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10535, 1094, 9941, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10536, 1094, 9942, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10537, 1094, 9943, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10538, 1094, 9944, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10539, 1094, 9945, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10540, 1094, 9946, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10541, 1094, 9947, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10542, 1094, 9948, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10543, 1094, 9949, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10544, 1094, 9950, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5380, 371, 5079, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1711, 203, 1670, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10871, 1118, 10277, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1712, 203, 1671, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1713, 203, 1672, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10592, 1096, 9999, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10593, 1096, 10000, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1714, 203, 1673, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1715, 203, 1674, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1716, 203, 1675, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10594, 1096, 10001, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10560, 1097, 9967, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10561, 1097, 9968, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10562, 1097, 9972, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10563, 1097, 9970, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1717, 203, 1676, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10564, 1097, 9971, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10565, 1097, 9969, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10566, 1097, 9973, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10457, 1088, 3271, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10458, 1088, 9870, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10459, 1088, 4069, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10460, 1088, 9871, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10461, 1088, 8198, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10462, 1088, 9872, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10463, 1088, 9873, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10464, 1088, 9874, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10567, 1097, 9974, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10568, 1097, 9975, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10569, 1097, 9976, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10570, 1097, 9977, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10571, 1097, 9978, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10572, 1097, 9979, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10573, 1097, 9980, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10574, 1097, 9981, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10595, 1096, 10002, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10596, 1096, 10003, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10597, 1096, 10004, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10598, 1096, 10005, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10600, 1096, 10008, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10601, 1096, 10009, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10575, 1097, 9982, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10576, 1098, 9983, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10577, 1098, 9984, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10578, 1098, 9985, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10579, 1098, 9986, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10580, 1098, 9987, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10581, 1098, 9988, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10582, 1098, 9989, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10583, 1098, 9990, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10584, 1098, 9991, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10585, 1098, 9992, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10586, 1098, 9993, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10587, 1098, 9994, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10588, 1098, 9995, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10589, 1098, 9996, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10590, 1098, 9997, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (916, 78, 904, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (917, 78, 906, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (918, 78, 907, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (919, 78, 908, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (920, 78, 909, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (921, 78, 910, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (922, 78, 911, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (923, 78, 912, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (924, 78, 913, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (932, 78, 149, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6364, 78, 106, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7689, 919, 7159, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7690, 919, 7160, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7691, 919, 7161, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7692, 919, 7162, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7693, 919, 7163, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7694, 919, 7164, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7695, 919, 7165, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7696, 919, 7166, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10602, 1096, 10007, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10603, 1096, 10011, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7697, 919, 7167, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7698, 919, 7168, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7699, 919, 7169, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7700, 919, 7170, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7701, 919, 7171, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10591, 1096, 9998, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10604, 1096, 10012, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10605, 1096, 10013, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10606, 1096, 10014, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7702, 919, 7172, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8574, 973, 8063, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8575, 973, 8064, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8576, 973, 8065, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8577, 973, 8066, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8578, 973, 8067, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8579, 973, 8068, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8580, 973, 8069, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8581, 973, 8070, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8582, 973, 8071, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8583, 973, 8072, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8584, 973, 8073, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8585, 973, 8074, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8586, 973, 8075, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8587, 973, 8076, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8588, 973, 8077, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8589, 973, 8078, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8590, 973, 8079, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8591, 973, 8080, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8592, 973, 8081, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8593, 973, 8082, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (8594, 973, 8083, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (8595, 973, 8084, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (8596, 973, 8085, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (8597, 973, 8086, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (6160, 447, 5692, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6161, 447, 5693, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6162, 447, 5694, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6163, 447, 5695, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6164, 447, 5696, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6165, 447, 5697, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6166, 447, 5698, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6167, 447, 5699, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6168, 447, 5700, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6169, 447, 5701, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10641, 1101, 10049, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10642, 1101, 10050, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10643, 1101, 10051, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10644, 1101, 10052, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10645, 1101, 10053, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10646, 1101, 10054, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10647, 1101, 10055, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10648, 1101, 10056, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10649, 1101, 10057, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10650, 1101, 10058, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10651, 1101, 10059, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10652, 1101, 10060, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10653, 1101, 10061, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10665, 1102, 10073, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10666, 1102, 10074, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10667, 1102, 10075, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10607, 1099, 10016, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10608, 1099, 10015, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10609, 1099, 10017, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10610, 1099, 10018, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10611, 1099, 10019, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10612, 1099, 10020, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10613, 1099, 10021, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10614, 1099, 10027, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10615, 1099, 10022, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10616, 1099, 10023, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10617, 1099, 10025, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10618, 1099, 10026, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10619, 1099, 10028, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10620, 1099, 10024, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9603, 1035, 9089, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9604, 1035, 9090, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9605, 1035, 9091, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9606, 1035, 9092, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9607, 1035, 9093, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9608, 1035, 9094, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9609, 1035, 9095, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9610, 1035, 9096, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9611, 1035, 9097, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9612, 1035, 9098, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9613, 1035, 9099, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9614, 1035, 9100, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9615, 1035, 9101, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10685, 1104, 10093, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10621, 1100, 10029, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10622, 1100, 10030, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10623, 1100, 10031, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10624, 1100, 10032, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10625, 1100, 10033, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10626, 1100, 10034, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10627, 1100, 10035, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10628, 1100, 10036, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10629, 1100, 10037, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10630, 1100, 10038, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10631, 1100, 10039, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10632, 1100, 10040, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10633, 1100, 10041, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10634, 1100, 10042, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10635, 1100, 10043, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10636, 1100, 10044, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10637, 1100, 10045, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10638, 1100, 10046, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9881, 1050, 9311, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9882, 1050, 9312, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9883, 1050, 9313, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9884, 1050, 9314, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9885, 1050, 9315, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9886, 1050, 9316, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10545, 1095, 9951, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10546, 1095, 9952, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10547, 1095, 9953, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10548, 1095, 9954, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10549, 1095, 9955, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10550, 1095, 9956, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10551, 1095, 9957, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10552, 1095, 9958, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10553, 1095, 9959, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10554, 1095, 9960, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10555, 1095, 9961, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10556, 1095, 9962, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10557, 1095, 9963, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10558, 1095, 9964, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10559, 1095, 9965, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10668, 1102, 10076, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10669, 1102, 10077, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10670, 1103, 10078, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10671, 1103, 10079, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10672, 1103, 10080, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10639, 1101, 10047, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10640, 1101, 10048, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10654, 1102, 10062, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10655, 1102, 10063, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10656, 1102, 10064, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10657, 1102, 10065, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10658, 1102, 10066, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10659, 1102, 10067, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10660, 1102, 10068, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10661, 1102, 10069, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10662, 1102, 10070, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10663, 1102, 10071, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10664, 1102, 10072, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10673, 1103, 10081, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10674, 1103, 10082, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10675, 1103, 10083, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10676, 1103, 10084, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10677, 1103, 10085, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10678, 1103, 10086, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10679, 1103, 10087, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10680, 1103, 10088, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10681, 1103, 10089, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10682, 1103, 10090, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10683, 1103, 10091, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10684, 1103, 10092, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6368, 462, 5858, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6369, 462, 5859, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6370, 462, 5860, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6371, 462, 5861, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6372, 462, 5862, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6373, 462, 5863, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6374, 462, 5864, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6375, 462, 5865, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6376, 462, 5866, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6377, 462, 5867, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6378, 462, 5868, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6379, 462, 5869, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6380, 462, 5870, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6381, 462, 5871, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10686, 1105, 10094, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10687, 1105, 10095, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10688, 1105, 10096, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10826, 1114, 10232, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10689, 1105, 10097, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10690, 1105, 10098, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10691, 1105, 10099, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10832, 1114, 10238, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10741, 1108, 10147, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10742, 1108, 10149, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10743, 1108, 10148, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10833, 1114, 10239, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10744, 1108, 10150, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10745, 1108, 10151, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10746, 1108, 10152, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10747, 1108, 10153, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10834, 1114, 10240, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10748, 1108, 10154, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10749, 1108, 10155, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10750, 1108, 10156, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10751, 1108, 10157, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10752, 1108, 10158, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6936, 499, 6366, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10835, 1114, 10241, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10836, 1114, 10242, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10837, 1114, 10243, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10838, 1114, 10244, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10839, 1114, 10245, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10840, 1114, 10246, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10872, 1119, 10278, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10873, 1119, 10279, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10874, 1119, 10280, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10875, 1119, 10281, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10729, 1107, 10135, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10730, 1107, 10136, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10731, 1107, 10137, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10732, 1107, 10138, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10733, 1107, 10139, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10734, 1107, 10140, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10735, 1107, 10141, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10736, 1107, 10142, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10737, 1107, 10143, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10738, 1107, 10144, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10739, 1107, 10145, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10702, 1086, 10110, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10703, 1086, 10111, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10704, 1086, 10112, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10705, 1086, 10113, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10706, 1086, 10114, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10707, 1086, 10115, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10708, 1086, 10116, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10709, 1086, 10117, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10710, 1086, 10118, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10711, 1086, 10119, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10712, 1086, 10120, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10713, 1086, 10121, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7518, 908, 6988, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7519, 908, 6989, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7520, 908, 6990, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7521, 908, 6991, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7522, 908, 6992, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7523, 908, 6993, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7524, 908, 6994, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7525, 908, 6995, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7526, 908, 6996, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7527, 908, 6997, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7528, 908, 6998, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7529, 908, 6999, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7530, 908, 7000, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7531, 908, 7001, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7532, 908, 7002, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10692, 1105, 10100, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10693, 1105, 10101, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10694, 1105, 10102, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10695, 1105, 10103, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10696, 1105, 10104, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10697, 1105, 10105, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10698, 1105, 10106, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10699, 1105, 10107, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10700, 1105, 10108, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10701, 1105, 10109, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (5677, 403, 236, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5678, 403, 1307, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5679, 403, 62, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5680, 403, 1308, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5681, 403, 1309, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5682, 403, 1310, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5683, 403, 1311, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5684, 403, 233, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5685, 403, 1313, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5686, 403, 346, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5687, 403, 1312, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5688, 403, 347, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10740, 1107, 10146, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6937, 499, 6367, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6938, 499, 6368, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6983, 499, 6420, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6984, 499, 6421, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10869, 1118, 10275, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10870, 1118, 10276, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6985, 499, 6422, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6986, 499, 6423, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6987, 499, 6419, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6988, 499, 6369, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6989, 499, 6370, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6990, 499, 6371, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6991, 499, 6372, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6992, 499, 6373, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6993, 499, 6374, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3072, 833, 3083, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3073, 833, 3085, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3074, 833, 3086, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3075, 833, 3088, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3076, 833, 3089, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3866, 833, 3798, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3867, 833, 3795, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6006, 436, 5561, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6007, 436, 5562, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6008, 436, 5563, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6009, 436, 5564, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6010, 436, 5565, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6011, 436, 5566, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10876, 1119, 10282, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10877, 1119, 10283, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10714, 1106, 10122, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10715, 1106, 10123, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10716, 1106, 10124, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10717, 1106, 10125, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10718, 1106, 10134, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10720, 1106, 10126, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10721, 1106, 10127, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10722, 1106, 10128, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10723, 1106, 10129, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10724, 1106, 10130, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10725, 1106, 10131, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10726, 1106, 10132, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10727, 1106, 10133, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10887, 1120, 10293, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10878, 1119, 10284, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10879, 1119, 10285, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10880, 1119, 10286, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10881, 1119, 10287, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10882, 1119, 10288, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10883, 1119, 10289, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10884, 1119, 10290, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10885, 1119, 10291, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10886, 1119, 10292, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10888, 1120, 10294, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10889, 1120, 10295, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10890, 1120, 10296, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10891, 1120, 10297, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10892, 1120, 10298, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10893, 1120, 10299, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10894, 1120, 10300, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10895, 1120, 10301, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10896, 1120, 10302, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10897, 1120, 10303, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1384, 118, 1359, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1385, 118, 1360, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1386, 118, 184, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1387, 118, 110, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1388, 118, 139, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1389, 118, 1361, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1390, 118, 1362, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1391, 118, 207, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6024, 438, 5567, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6025, 438, 5568, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6026, 438, 5569, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6027, 438, 5570, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6028, 438, 5571, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6029, 438, 5572, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6030, 438, 5573, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6031, 438, 5574, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6032, 438, 5575, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6033, 438, 5576, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6034, 438, 5577, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6035, 438, 5578, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6036, 438, 5579, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6037, 438, 5580, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10414, 1084, 9830, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10415, 1084, 9831, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10416, 1084, 9832, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10417, 1084, 9833, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10418, 1084, 9834, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10419, 1084, 9835, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10420, 1084, 9836, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10421, 1084, 9837, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10422, 1084, 9838, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10423, 1084, 9839, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10424, 1084, 9840, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10425, 1084, 9841, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10426, 1084, 9842, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10427, 1084, 9843, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10428, 1084, 9844, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10429, 1084, 9845, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10430, 1084, 9846, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10908, 1122, 10311, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10909, 1122, 10312, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10910, 1122, 10313, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10911, 1122, 10314, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10912, 1122, 10315, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10913, 1122, 10327, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10914, 1122, 10317, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10915, 1122, 10318, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10916, 1122, 10319, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10917, 1122, 10320, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10918, 1122, 10321, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10919, 1122, 10328, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10920, 1122, 10323, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10921, 1122, 10324, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10922, 1122, 10325, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10923, 1122, 10326, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10924, 1122, 10316, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10925, 1122, 10322, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (2661, 186, 2664, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2662, 186, 2665, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2663, 186, 2666, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2664, 186, 2667, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2665, 186, 2668, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2666, 186, 2669, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2667, 186, 2670, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2668, 186, 2671, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2669, 186, 2672, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2670, 186, 2673, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2671, 186, 2674, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2672, 186, 2675, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (2673, 186, 2676, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2674, 186, 2677, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2675, 186, 2678, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (2676, 186, 2679, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (2677, 186, 2680, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10926, 1123, 10329, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10927, 1123, 10330, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10928, 1123, 10331, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10929, 1123, 10332, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10930, 1123, 10333, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10931, 1123, 10334, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10932, 1123, 10335, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10933, 1123, 10337, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10934, 1123, 10338, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11022, 1129, 10425, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11023, 1129, 10426, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11024, 1129, 10427, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11025, 1129, 10428, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11026, 1129, 10429, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11027, 1129, 10430, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10935, 1123, 10336, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10936, 1123, 10339, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10937, 1123, 10340, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10938, 1123, 10342, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10939, 1123, 10343, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10940, 1123, 10344, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10941, 1123, 10345, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10942, 1123, 10346, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (10943, 1123, 10347, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (10944, 1123, 10348, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (10945, 1123, 10349, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (10946, 1123, 10341, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11028, 1129, 10431, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (11003, 1128, 10406, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11004, 1128, 10407, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11005, 1128, 10408, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11006, 1128, 10409, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11007, 1128, 10410, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11008, 1128, 10411, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11009, 1128, 10412, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11010, 1128, 10413, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10947, 1124, 10350, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10948, 1124, 10351, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10949, 1124, 10352, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10950, 1124, 10353, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10951, 1124, 10354, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10952, 1124, 10355, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10953, 1124, 10356, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10954, 1124, 10357, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10955, 1124, 10358, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10956, 1124, 10359, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10957, 1124, 10360, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10958, 1124, 10362, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10959, 1124, 10363, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10960, 1124, 10364, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10961, 1124, 10365, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10962, 1124, 10366, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10963, 1124, 10361, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10981, 1126, 10384, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10982, 1126, 10385, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10983, 1126, 10386, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10984, 1126, 10387, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10985, 1126, 10388, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10986, 1126, 10389, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10987, 1126, 10390, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10988, 1126, 10391, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10989, 1126, 10392, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10990, 1126, 10393, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10991, 1126, 10394, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10992, 1126, 10395, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10993, 1126, 10396, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10994, 1126, 10397, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (2507, 233, 2514, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2508, 233, 2515, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2509, 233, 2516, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2510, 233, 2517, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2511, 233, 2518, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2512, 233, 2519, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2513, 233, 2520, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2514, 233, 2521, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11011, 1128, 10414, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11012, 1128, 10415, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11013, 1128, 10416, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2515, 233, 2522, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3676, 233, 3622, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3372, 366, 3319, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3373, 366, 3320, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3374, 366, 3321, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3375, 366, 3322, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3376, 366, 3323, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3377, 366, 3324, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3378, 366, 3325, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3379, 366, 3326, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3380, 366, 3327, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3381, 366, 3328, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3382, 366, 3329, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3383, 366, 3330, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3384, 366, 3331, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11029, 1130, 10432, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11030, 1130, 10433, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11031, 1130, 10434, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10995, 1127, 10398, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10996, 1127, 10399, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10997, 1127, 10400, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10998, 1127, 10401, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10999, 1127, 10402, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11000, 1127, 10403, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11001, 1127, 10404, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11002, 1127, 10405, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11032, 1130, 10435, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3020, 281, 3019, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3021, 281, 3020, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3022, 281, 3021, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3023, 281, 3022, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3024, 281, 3023, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3025, 281, 3024, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3026, 281, 3025, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3027, 281, 3026, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11014, 1129, 10417, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11015, 1129, 10418, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11016, 1129, 10419, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11017, 1129, 10420, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11018, 1129, 10421, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11019, 1129, 10422, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11020, 1129, 10423, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11021, 1129, 10424, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3028, 281, 3027, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11033, 1131, 10436, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11042, 1133, 10445, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11043, 1134, 10446, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11034, 1132, 10437, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8298, 958, 7787, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8299, 958, 7788, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8300, 958, 7789, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8301, 958, 7790, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8302, 958, 7791, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8303, 958, 7792, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8304, 958, 7793, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8305, 958, 7794, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8306, 958, 7795, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8307, 958, 7796, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8308, 958, 7797, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8309, 958, 7798, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8310, 958, 7799, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8311, 958, 7800, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8312, 958, 7801, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (11035, 1132, 10438, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11036, 1132, 10439, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11037, 1132, 10440, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11038, 1132, 10441, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11039, 1132, 10442, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11040, 1132, 10443, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11041, 1132, 10444, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11044, 1135, 10448, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11045, 1135, 10449, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11046, 1135, 10450, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (11047, 1135, 10451, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (5398, 375, 3199, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5399, 375, 3198, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5400, 375, 3193, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5401, 375, 3195, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5402, 375, 3197, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5403, 375, 3196, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5404, 375, 1691, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5405, 375, 1692, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5406, 375, 1688, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5407, 375, 1695, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5408, 375, 1693, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5409, 375, 1689, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (5410, 375, 1690, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6154, 375, 3194, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7050, 514, 6472, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7051, 514, 6473, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7052, 514, 6474, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7053, 514, 6475, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7054, 514, 6476, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7055, 514, 6477, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7056, 514, 6478, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7057, 514, 6479, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7058, 514, 6480, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7059, 514, 6481, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7060, 514, 6482, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7061, 514, 6483, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7062, 514, 6484, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7063, 514, 6485, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7064, 514, 6486, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9441, 514, 6476, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9442, 514, 6472, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (11048, 1136, 10452, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11049, 1136, 10453, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11050, 1136, 10454, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11051, 1136, 10455, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11052, 1136, 10456, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11053, 1136, 10457, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11054, 1136, 10458, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11055, 1136, 10459, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11056, 1136, 10460, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11057, 1136, 10461, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11058, 1136, 10462, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11059, 1136, 10463, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9889, 1051, 9319, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9890, 1051, 9320, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9891, 1051, 9321, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9892, 1051, 2443, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9893, 1051, 9322, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9894, 1051, 9323, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9895, 1051, 9324, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9896, 1051, 2433, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9897, 1051, 9325, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9898, 1051, 9326, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9899, 1051, 306, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9900, 1051, 9327, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3895, 760, 3825, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3896, 760, 3826, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3897, 760, 3827, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3898, 760, 3828, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3899, 760, 3829, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3900, 760, 3830, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10964, 1125, 10367, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10965, 1125, 10368, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10966, 1125, 10369, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10967, 1125, 10370, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10968, 1125, 10371, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10969, 1125, 10372, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10970, 1125, 10373, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10971, 1125, 10374, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10972, 1125, 10375, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10973, 1125, 10376, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10974, 1125, 10377, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10975, 1125, 10378, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10976, 1125, 10379, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10977, 1125, 10380, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10978, 1125, 10381, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10979, 1125, 10382, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10980, 1125, 10383, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (11060, 1137, 10464, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11061, 1137, 10465, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11062, 1137, 10466, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11063, 1137, 10467, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11064, 1137, 10468, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11065, 1137, 10469, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11066, 1137, 10470, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11067, 1137, 10471, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11068, 1137, 10472, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11069, 1137, 10473, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11070, 1137, 10474, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11071, 1137, 10475, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11072, 1137, 10476, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1622, 172, 1587, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1623, 172, 1588, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1624, 172, 1589, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1625, 172, 1590, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1626, 172, 1591, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1627, 172, 1592, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1628, 172, 1593, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6707, 490, 6141, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6708, 490, 6142, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6709, 490, 6143, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6710, 490, 6144, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6711, 490, 6145, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6712, 490, 6146, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6713, 490, 6147, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6714, 490, 6148, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6715, 490, 6149, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6716, 490, 6150, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6717, 490, 6151, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6718, 490, 6152, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6719, 490, 6153, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6720, 490, 6154, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6721, 490, 6155, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6722, 490, 6156, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6723, 490, 6157, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (6724, 490, 6158, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (6725, 490, 6159, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (6726, 490, 6160, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (6727, 490, 6161, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (6728, 490, 6162, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (6729, 490, 6163, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (6730, 490, 6164, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (6731, 490, 6165, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (6732, 490, 6166, 26);
INSERT INTO 'albumsrecordingsmap' VALUES (6733, 490, 6167, 27);
INSERT INTO 'albumsrecordingsmap' VALUES (6734, 490, 6168, 28);
INSERT INTO 'albumsrecordingsmap' VALUES (9446, 490, 8935, 31);
INSERT INTO 'albumsrecordingsmap' VALUES (9447, 490, 8936, 32);
INSERT INTO 'albumsrecordingsmap' VALUES (9448, 490, 8937, 33);
INSERT INTO 'albumsrecordingsmap' VALUES (9449, 490, 8938, 34);
INSERT INTO 'albumsrecordingsmap' VALUES (9450, 490, 8939, 35);
INSERT INTO 'albumsrecordingsmap' VALUES (9451, 490, 8940, 36);
INSERT INTO 'albumsrecordingsmap' VALUES (9452, 490, 8941, 37);
INSERT INTO 'albumsrecordingsmap' VALUES (11112, 1139, 10491, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11113, 1139, 10492, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11114, 1139, 10493, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11115, 1139, 10494, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11116, 1139, 10495, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11117, 1139, 10496, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11118, 1139, 10497, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11119, 1139, 10498, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11120, 1139, 10499, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11121, 1139, 10500, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11122, 1139, 10501, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11123, 1139, 10502, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11124, 1139, 10503, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11125, 1139, 10504, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (11126, 1139, 10505, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (11127, 1139, 10506, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8412, 963, 7901, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8413, 963, 7902, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8414, 963, 7903, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8415, 963, 7904, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8416, 963, 7905, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8417, 963, 7906, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8418, 963, 7907, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (8419, 963, 7908, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (8420, 963, 7909, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (8421, 963, 7910, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (8422, 963, 7911, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (8423, 963, 7912, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (8424, 963, 7913, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (8425, 963, 7914, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (8426, 963, 7915, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (8427, 963, 7916, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8428, 963, 7917, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (8429, 963, 7918, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (8430, 963, 7919, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (8431, 963, 7920, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (11142, 1141, 10521, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11143, 1141, 10522, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11144, 1141, 10523, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11145, 1141, 10524, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11146, 1141, 10525, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11128, 1140, 10507, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11129, 1140, 10508, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11130, 1140, 10509, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11131, 1140, 10510, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11132, 1140, 10511, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11133, 1140, 10512, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11134, 1140, 10513, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11135, 1140, 10514, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11136, 1140, 10515, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11137, 1140, 10516, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11138, 1140, 10517, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11139, 1140, 10518, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11140, 1140, 10519, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11073, 1138, 6141, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11074, 1138, 10477, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11075, 1138, 6142, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11076, 1138, 10478, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11077, 1138, 6144, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11078, 1138, 6146, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11079, 1138, 6147, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11080, 1138, 6149, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11081, 1138, 10479, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11082, 1138, 6150, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11083, 1138, 6151, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11084, 1138, 10480, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11085, 1138, 6154, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (11141, 1140, 10520, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3827, 752, 3763, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3828, 752, 3764, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3829, 752, 3765, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3830, 752, 3766, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3831, 752, 3767, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3832, 752, 3768, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3833, 752, 3770, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3834, 752, 3771, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3835, 752, 3772, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3836, 752, 3773, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3837, 752, 3774, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3838, 752, 3775, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3839, 752, 3776, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3840, 752, 3777, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (4450, 752, 1064, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1836, 164, 1805, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1837, 164, 1806, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1838, 164, 1807, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (1839, 164, 1808, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11163, 1143, 7059, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11164, 1143, 7060, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11165, 1143, 7061, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11166, 1143, 7062, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11167, 1143, 7063, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11168, 1143, 7064, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11169, 1143, 7065, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11170, 1143, 7066, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11171, 1143, 7067, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11172, 1143, 7068, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11173, 1143, 7069, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11174, 1143, 7070, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11175, 1143, 7071, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3124, 293, 3127, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3125, 293, 3128, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3126, 293, 3129, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (3127, 293, 3130, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3128, 293, 3131, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3129, 293, 3132, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (3130, 293, 3133, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (3131, 293, 3134, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3132, 293, 3135, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1840, 164, 1809, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1841, 164, 1810, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1842, 164, 1811, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1843, 164, 1812, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11197, 1145, 10563, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11198, 1145, 10564, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11199, 1145, 10565, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11200, 1145, 10566, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11201, 1145, 10567, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11202, 1145, 10568, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11203, 1145, 10569, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11204, 1145, 10570, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11205, 1145, 10571, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11206, 1145, 10572, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11207, 1145, 10573, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1031, 85, 1005, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (1032, 85, 1006, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (1033, 85, 1007, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5263, 359, 4988, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5264, 359, 4989, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5265, 359, 4990, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5266, 359, 4991, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5267, 359, 4992, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5268, 359, 4993, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5269, 359, 4994, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5270, 359, 4995, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (5271, 359, 4996, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (6232, 359, 95, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6233, 359, 259, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (6234, 359, 263, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (11176, 359, 10542, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2826, 261, 125, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2827, 261, 2826, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2828, 261, 2827, 0);
INSERT INTO 'albumsrecordingsmap' VALUES (2829, 261, 2828, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2830, 261, 2829, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2831, 261, 2830, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2832, 261, 2831, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2833, 261, 2832, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2834, 261, 2833, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2835, 261, 2834, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2836, 261, 2835, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1034, 85, 1008, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1035, 85, 1009, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1036, 85, 1010, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1037, 85, 1011, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1038, 85, 1012, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1039, 85, 1013, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1040, 85, 1014, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1041, 85, 1015, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (1042, 85, 1016, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (1043, 85, 1017, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (1044, 85, 1018, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (1045, 85, 1019, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (1046, 85, 1020, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (1047, 85, 1021, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (1888, 167, 1857, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1889, 167, 1858, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1657, 177, 1615, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (1658, 177, 1616, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (1659, 177, 1617, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (1660, 177, 1618, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (1661, 177, 1619, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (1662, 177, 1620, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (1663, 177, 1621, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (1664, 177, 1622, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5280, 360, 5005, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5281, 360, 5006, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (5282, 360, 5007, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (5283, 360, 5008, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (5284, 360, 5009, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11177, 1144, 10543, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11178, 1144, 10544, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11179, 1144, 10545, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11180, 1144, 10546, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11181, 1144, 10547, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11182, 1144, 10548, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11183, 1144, 10550, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11184, 1144, 10551, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11185, 1144, 10552, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11186, 1144, 10553, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11187, 1144, 10554, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11188, 1144, 10549, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11189, 1144, 10555, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11190, 1144, 10556, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (11191, 1144, 10557, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (11192, 1144, 10558, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (11193, 1144, 10559, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (11194, 1144, 10560, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (11195, 1144, 10561, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (11196, 1144, 10562, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (5285, 360, 5010, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (5286, 360, 5011, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (5287, 360, 3341, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (8993, 998, 8482, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (8994, 998, 8483, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (8995, 998, 8484, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (8996, 998, 8485, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (8997, 998, 8486, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (8998, 998, 8487, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (8999, 998, 8488, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9000, 998, 8489, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11147, 1142, 10526, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11148, 1142, 10534, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11149, 1142, 10535, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11150, 1142, 10527, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11151, 1142, 10528, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11152, 1142, 10529, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11153, 1142, 10536, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11154, 1142, 10530, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11155, 1142, 10537, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11156, 1142, 10538, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11157, 1142, 10531, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11158, 1142, 10532, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11159, 1142, 10539, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11160, 1142, 10540, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (11161, 1142, 10533, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (11162, 1142, 10541, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9001, 998, 8490, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9002, 998, 8491, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9003, 998, 8492, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9004, 998, 8493, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9005, 998, 8494, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9006, 998, 8495, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (9007, 998, 8496, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (9008, 998, 8497, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (9009, 998, 8498, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (9010, 998, 8499, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (9011, 998, 8500, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (9012, 998, 8501, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (10841, 1116, 10247, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10842, 1116, 10248, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10843, 1116, 10249, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10844, 1116, 10250, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10845, 1116, 10251, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10846, 1116, 10252, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10847, 1116, 10253, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10848, 1116, 10254, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10849, 1116, 10255, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10850, 1116, 10256, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10851, 1116, 10257, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10856, 1116, 10262, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10857, 1116, 10263, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10858, 1116, 10264, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (2690, 711, 2693, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2691, 711, 2694, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (2692, 711, 2695, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (2693, 711, 2696, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2694, 711, 2697, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (2695, 711, 2698, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (3402, 711, 3349, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (3403, 711, 3350, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (3404, 711, 3351, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (3405, 711, 3352, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (3406, 711, 3353, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (3407, 711, 3356, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3408, 711, 3355, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3409, 711, 3354, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (3410, 711, 3358, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3411, 711, 3357, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3412, 711, 3359, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10044, 1062, 9471, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10045, 1062, 9472, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10046, 1062, 9473, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10047, 1062, 9474, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10048, 1062, 9475, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10049, 1062, 9476, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10050, 1062, 9477, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10051, 1062, 9478, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10052, 1062, 9479, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10053, 1062, 9480, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10054, 1062, 9481, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10055, 1062, 9482, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10056, 1062, 9483, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10057, 1062, 9484, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10058, 1062, 9485, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10059, 1062, 9486, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10060, 1062, 9487, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10061, 1062, 9488, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (10062, 1062, 9489, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (10063, 1062, 9490, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (10064, 1062, 9491, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (10065, 1062, 9492, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (10066, 1062, 9493, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (10067, 1062, 9494, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (10068, 1062, 9495, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (10069, 1062, 9496, 26);
INSERT INTO 'albumsrecordingsmap' VALUES (10070, 1062, 9497, 27);
INSERT INTO 'albumsrecordingsmap' VALUES (10071, 1062, 9498, 28);
INSERT INTO 'albumsrecordingsmap' VALUES (10072, 1062, 9499, 29);
INSERT INTO 'albumsrecordingsmap' VALUES (6098, 443, 5640, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6099, 443, 5641, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6100, 443, 5642, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6101, 443, 5643, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6102, 443, 5644, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6103, 443, 5645, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6104, 443, 5646, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6105, 443, 5647, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6106, 443, 5648, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (6107, 443, 5649, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (6108, 443, 5650, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6109, 443, 5651, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6110, 443, 5652, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6190, 449, 5719, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (6191, 449, 5720, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (6192, 449, 5721, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (6193, 449, 5722, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (6194, 449, 5723, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (11086, 1138, 6155, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (11087, 1138, 10482, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (11088, 1138, 10483, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (11089, 1138, 6158, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (11090, 1138, 6161, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (11091, 1138, 6160, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (11092, 1138, 10481, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (11093, 1138, 6162, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (11094, 1138, 6159, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (11095, 1138, 6163, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (11096, 1138, 6165, 26);
INSERT INTO 'albumsrecordingsmap' VALUES (11097, 1138, 6164, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (11098, 1138, 10484, 27);
INSERT INTO 'albumsrecordingsmap' VALUES (11099, 1138, 6167, 28);
INSERT INTO 'albumsrecordingsmap' VALUES (11100, 1138, 8934, 31);
INSERT INTO 'albumsrecordingsmap' VALUES (11101, 1138, 8937, 34);
INSERT INTO 'albumsrecordingsmap' VALUES (11102, 1138, 8938, 35);
INSERT INTO 'albumsrecordingsmap' VALUES (11103, 1138, 8939, 36);
INSERT INTO 'albumsrecordingsmap' VALUES (11104, 1138, 8940, 37);
INSERT INTO 'albumsrecordingsmap' VALUES (11105, 1138, 8941, 38);
INSERT INTO 'albumsrecordingsmap' VALUES (11106, 1138, 6145, 39);
INSERT INTO 'albumsrecordingsmap' VALUES (11107, 1138, 10485, 30);
INSERT INTO 'albumsrecordingsmap' VALUES (11108, 1138, 10486, 32);
INSERT INTO 'albumsrecordingsmap' VALUES (11109, 1138, 10487, 33);
INSERT INTO 'albumsrecordingsmap' VALUES (11110, 1138, 10488, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11111, 1138, 10489, 29);
INSERT INTO 'albumsrecordingsmap' VALUES (689, 57, 52, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (690, 57, 722, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (691, 57, 723, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (692, 57, 724, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (693, 57, 725, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (694, 57, 726, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (695, 57, 727, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11208, 1146, 10574, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11209, 1146, 10575, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11210, 1146, 10576, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11211, 1146, 10577, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11212, 1146, 10578, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11213, 1146, 10579, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11214, 1146, 10580, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11215, 1146, 10581, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11216, 1146, 10582, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11217, 1146, 10583, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11218, 1146, 10584, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11219, 1146, 10585, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11220, 1146, 10586, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11221, 1146, 10587, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (11222, 1146, 10588, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (11223, 1146, 10589, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (11224, 1146, 10524, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (11225, 1146, 10591, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (4950, 330, 4697, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4951, 330, 4698, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (4952, 330, 4699, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4953, 330, 4700, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (4954, 330, 4701, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (4955, 330, 4702, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (4956, 330, 4703, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (4957, 330, 4704, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (4958, 330, 4705, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (4959, 330, 4706, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (4960, 330, 4707, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (4961, 330, 4708, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (4962, 330, 4709, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (4963, 330, 4710, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10373, 1082, 9789, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (10374, 1082, 9790, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (10375, 1082, 9791, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (10376, 1082, 9792, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (10377, 1082, 9793, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (10378, 1082, 9794, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (10379, 1082, 9795, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (10380, 1082, 9796, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (10381, 1082, 9797, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (10382, 1082, 9798, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (10383, 1082, 9799, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (10384, 1082, 9800, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10385, 1082, 9801, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (10386, 1082, 9802, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (10387, 1082, 9803, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (10388, 1082, 9804, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (10389, 1082, 9805, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (10390, 1082, 9806, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (10391, 1082, 9807, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (5955, 433, 5520, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5956, 433, 5521, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5957, 433, 5522, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5958, 433, 5523, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5959, 433, 5524, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5960, 433, 5525, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5961, 433, 5526, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5962, 433, 5527, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5963, 433, 5528, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5964, 433, 5529, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11226, 1147, 10592, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11227, 1147, 10593, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11228, 1147, 10594, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11229, 1147, 10595, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11230, 1147, 10596, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11231, 1147, 10597, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11232, 1147, 10598, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11233, 1147, 10599, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11234, 1147, 10600, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11235, 1147, 10601, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11236, 1147, 10602, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11237, 1147, 10603, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11238, 1147, 10604, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11239, 1147, 10605, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (11240, 1147, 10606, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (11241, 1147, 10607, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (11242, 1147, 10608, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (11243, 1147, 10609, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (11244, 1147, 10610, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (11245, 1147, 10611, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (11246, 1147, 10612, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (11247, 1147, 10613, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (11248, 1147, 10614, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (11249, 1147, 10615, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (7191, 887, 6609, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7192, 887, 6610, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7193, 887, 6611, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7194, 887, 6612, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7195, 887, 6613, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7196, 887, 6614, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7197, 887, 6615, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7198, 887, 6616, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7199, 887, 6617, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7200, 887, 6618, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7201, 887, 6619, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7202, 887, 6620, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7203, 887, 6621, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7204, 887, 6622, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (7205, 887, 6623, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7206, 887, 6624, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7207, 887, 6625, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (7208, 887, 6626, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (7209, 887, 6627, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (7210, 887, 6628, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (7211, 887, 6629, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (7212, 887, 6630, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (7213, 887, 6631, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (7214, 887, 6632, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (7215, 887, 6633, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (7216, 887, 6634, 26);
INSERT INTO 'albumsrecordingsmap' VALUES (7217, 887, 6635, 27);
INSERT INTO 'albumsrecordingsmap' VALUES (7218, 887, 6636, 28);
INSERT INTO 'albumsrecordingsmap' VALUES (7219, 887, 282, 29);
INSERT INTO 'albumsrecordingsmap' VALUES (7220, 887, 6638, 30);
INSERT INTO 'albumsrecordingsmap' VALUES (11250, 1148, 5641, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11251, 1148, 10616, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11252, 1148, 10617, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11253, 1148, 10618, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11254, 1148, 10619, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11255, 1148, 2155, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11256, 1148, 2151, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11257, 1148, 10620, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11258, 1148, 10621, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11259, 1148, 10622, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11260, 1148, 2156, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11261, 1148, 10623, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11262, 1148, 10624, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11263, 1148, 2157, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (11264, 1148, 2152, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (11265, 1148, 2159, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (11266, 1148, 2158, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (11267, 1148, 2160, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (11268, 1148, 2154, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (11269, 1148, 2161, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (11270, 1148, 2153, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (6536, 477, 2157, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (6537, 477, 2152, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (6538, 477, 2155, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (6539, 477, 2159, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (6540, 477, 2158, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (6541, 477, 2151, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (6542, 477, 2160, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (6543, 477, 2154, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (6544, 477, 2153, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (6545, 477, 2161, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (6546, 477, 2156, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (2260, 198, 2235, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (2291, 198, 2267, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (2292, 198, 2268, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (2293, 198, 2269, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (2294, 198, 2270, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (2295, 198, 2271, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (2296, 198, 2272, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (2297, 198, 2273, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (2298, 198, 2274, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (2299, 198, 2275, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (3301, 198, 2276, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (3302, 198, 2277, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (3303, 198, 2278, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (3304, 198, 2279, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (3305, 198, 2280, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (3306, 198, 2281, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (3307, 198, 2282, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (3308, 198, 2283, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (3309, 198, 2284, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (3310, 198, 2285, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (3311, 198, 2286, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (11271, 1149, 10625, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11272, 1149, 10626, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11273, 1149, 10627, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11274, 1149, 10628, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11275, 1149, 10629, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11276, 1149, 10630, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11277, 1149, 10631, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11278, 1149, 10632, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11279, 1149, 10633, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11280, 1149, 10634, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11281, 1149, 10635, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11282, 1149, 10636, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11283, 1149, 10637, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11284, 1150, 10638, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11285, 1150, 10639, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11286, 1150, 10640, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11287, 1150, 10641, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11288, 1150, 10642, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11289, 1150, 10643, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11290, 1150, 10644, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11291, 1150, 10645, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11292, 1150, 10646, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11293, 1150, 10647, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11294, 1150, 10648, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7575, 912, 7045, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5091, 348, 4825, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (5092, 348, 4826, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (5093, 348, 4827, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (5094, 348, 4828, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (5095, 348, 4829, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (5096, 348, 4830, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (5097, 348, 4831, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (5098, 348, 4832, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (5099, 348, 4833, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (5100, 348, 4834, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11349, 1156, 3707, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (4129, 800, 4018, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (4130, 800, 4020, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11295, 800, 10649, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11296, 800, 10650, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11297, 800, 10651, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11298, 800, 10652, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11299, 800, 10653, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11300, 800, 10654, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11301, 800, 10655, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11302, 800, 10656, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11303, 800, 10657, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11350, 1157, 4170, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11351, 1158, 8743, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11352, 1159, 1683, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7594, 912, 7064, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (11354, 1161, 8810, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11353, 1160, 8797, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11304, 1151, 10658, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11305, 1151, 10659, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11306, 1151, 10660, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11307, 1151, 10661, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11308, 1151, 10662, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7595, 912, 7065, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (7596, 912, 7066, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (7597, 912, 7067, 23);
INSERT INTO 'albumsrecordingsmap' VALUES (7598, 912, 7068, 24);
INSERT INTO 'albumsrecordingsmap' VALUES (7599, 912, 7069, 25);
INSERT INTO 'albumsrecordingsmap' VALUES (7600, 912, 7070, 26);
INSERT INTO 'albumsrecordingsmap' VALUES (7601, 912, 7071, 27);
INSERT INTO 'albumsrecordingsmap' VALUES (11363, 1162, 10697, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11309, 1151, 10663, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11310, 1151, 10664, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11311, 1151, 10665, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11312, 1151, 10666, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11313, 1151, 10667, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11314, 1151, 10668, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11315, 1151, 10669, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (10120, 1065, 9547, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (10121, 1065, 9548, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (10122, 1065, 9549, 20);
INSERT INTO 'albumsrecordingsmap' VALUES (10123, 1065, 9550, 21);
INSERT INTO 'albumsrecordingsmap' VALUES (10124, 1065, 9551, 22);
INSERT INTO 'albumsrecordingsmap' VALUES (9290, 1015, 8817, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (9291, 1015, 8818, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (9292, 1015, 8819, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (9293, 1015, 8820, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (9294, 1015, 8821, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (9295, 1015, 8822, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (9296, 1015, 8823, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (9297, 1015, 8824, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (9298, 1015, 8825, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (9299, 1015, 8826, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (9300, 1015, 8827, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (9301, 1015, 8828, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (9302, 1015, 2609, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (9303, 1015, 8830, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (11328, 1153, 10670, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11329, 1153, 10671, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11330, 1153, 10672, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7576, 912, 7046, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (7577, 912, 7047, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (7578, 912, 7048, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (7579, 912, 7049, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (7580, 912, 7050, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (7581, 912, 7051, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (7582, 912, 7052, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (7583, 912, 7053, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (7584, 912, 7054, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (7585, 912, 7055, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (7586, 912, 7056, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (7587, 912, 7057, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (7588, 912, 7058, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (11331, 1153, 10673, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11332, 1153, 10674, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11333, 1153, 10675, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11334, 1153, 10676, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11335, 1153, 10677, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11336, 1153, 10658, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11337, 1153, 10679, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11338, 1153, 10669, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11339, 1153, 10667, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11340, 1153, 10682, 13);
INSERT INTO 'albumsrecordingsmap' VALUES (11341, 1153, 10683, 14);
INSERT INTO 'albumsrecordingsmap' VALUES (11342, 1153, 10684, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (11343, 1153, 10685, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (11344, 1153, 10686, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (11345, 1153, 10687, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (11346, 1153, 10688, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (11316, 1152, 10649, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11317, 1152, 10650, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11318, 1152, 4018, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11319, 1152, 10657, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11320, 1152, 10652, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11321, 1152, 10653, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11322, 1152, 10664, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11323, 1152, 10663, 8);
INSERT INTO 'albumsrecordingsmap' VALUES (11324, 1152, 10665, 9);
INSERT INTO 'albumsrecordingsmap' VALUES (11325, 1152, 10666, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11326, 1152, 10667, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11327, 1152, 10669, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11347, 1154, 7222, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11348, 1155, 3135, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (7589, 912, 7059, 15);
INSERT INTO 'albumsrecordingsmap' VALUES (7590, 912, 7060, 16);
INSERT INTO 'albumsrecordingsmap' VALUES (7591, 912, 7061, 17);
INSERT INTO 'albumsrecordingsmap' VALUES (7592, 912, 7062, 18);
INSERT INTO 'albumsrecordingsmap' VALUES (7593, 912, 7063, 19);
INSERT INTO 'albumsrecordingsmap' VALUES (11364, 1162, 10698, 10);
INSERT INTO 'albumsrecordingsmap' VALUES (11365, 1162, 10699, 11);
INSERT INTO 'albumsrecordingsmap' VALUES (11366, 1162, 10700, 12);
INSERT INTO 'albumsrecordingsmap' VALUES (11355, 1162, 10689, 1);
INSERT INTO 'albumsrecordingsmap' VALUES (11356, 1162, 10690, 2);
INSERT INTO 'albumsrecordingsmap' VALUES (11357, 1162, 10691, 3);
INSERT INTO 'albumsrecordingsmap' VALUES (11358, 1162, 10692, 4);
INSERT INTO 'albumsrecordingsmap' VALUES (11359, 1162, 10693, 5);
INSERT INTO 'albumsrecordingsmap' VALUES (11360, 1162, 10694, 6);
INSERT INTO 'albumsrecordingsmap' VALUES (11361, 1162, 10695, 7);
INSERT INTO 'albumsrecordingsmap' VALUES (11362, 1162, 10696, 8);


--
INSERT INTO 'couples' VALUES (105, '6 couples (4x,5x,6x)');
INSERT INTO 'couples' VALUES (108, '16 couples');
INSERT INTO 'couples' VALUES (109, '2 couples (1x)');
INSERT INTO 'couples' VALUES (110, '3 couples (1x)');
INSERT INTO 'couples' VALUES (111, '9 persons');
INSERT INTO 'couples' VALUES (112, '7 persons');
INSERT INTO 'couples' VALUES (101, '4w+2m');
INSERT INTO 'couples' VALUES (1, '1 couple');
INSERT INTO 'couples' VALUES (2, '2 couples');
INSERT INTO 'couples' VALUES (3, '3 couples');
INSERT INTO 'couples' VALUES (4, '4 couples');
INSERT INTO 'couples' VALUES (5, '5 couples');
INSERT INTO 'couples' VALUES (6, '6 couples');
INSERT INTO 'couples' VALUES (7, '7 couples');
INSERT INTO 'couples' VALUES (8, '8 couples');
INSERT INTO 'couples' VALUES (51, '1 person');
INSERT INTO 'couples' VALUES (53, '3 persons');
INSERT INTO 'couples' VALUES (54, '4 persons');
INSERT INTO 'couples' VALUES (55, '5 persons');
INSERT INTO 'couples' VALUES (56, '2 trios');
INSERT INTO 'couples' VALUES (99, 'unknown');
INSERT INTO 'couples' VALUES (100, '4 couples (3x,4x)');
INSERT INTO 'couples' VALUES (102, '4 couples (2x,4x)');
INSERT INTO 'couples' VALUES (104, '3 couples (2x)');
INSERT INTO 'couples' VALUES (114, '4 couples (1x,3x)');
INSERT INTO 'couples' VALUES (115, '12 persons');
INSERT INTO 'couples' VALUES (116, '4 couples (1x,2x)');
INSERT INTO 'couples' VALUES (106, '2 couples (Glasgow Highl)');
INSERT INTO 'couples' VALUES (107, '4 couples (Glasgow Highl)');
INSERT INTO 'couples' VALUES (117, '6 persons');
INSERT INTO 'couples' VALUES (118, '3 trios');
INSERT INTO 'couples' VALUES (130, '4 couples (1x,4x)');
INSERT INTO 'couples' VALUES (113, 'any');
INSERT INTO 'couples' VALUES (119, '4 trios');
INSERT INTO 'couples' VALUES (120, '3 couples (3x)');
INSERT INTO 'couples' VALUES (121, '3 couples (1x,2x)');
INSERT INTO 'couples' VALUES (122, '8 persons');
INSERT INTO 'couples' VALUES (98, 'other');
INSERT INTO 'couples' VALUES (124, '>8 couples');
INSERT INTO 'couples' VALUES (125, '2 couples (2x)');
INSERT INTO 'couples' VALUES (126, '>9 persons');
INSERT INTO 'couples' VALUES (127, '4 couples (4x)');
INSERT INTO 'couples' VALUES (128, '4 couples (2x,3x)');
INSERT INTO 'couples' VALUES (129, '5 couples (2x,4x)');
INSERT INTO 'couples' VALUES (132, '3 couples (1x,3x)');
INSERT INTO 'couples' VALUES (133, '6 couples (2x,4x,6x)');
INSERT INTO 'couples' VALUES (134, '3 couples (2x,3x)');
INSERT INTO 'couples' VALUES (135, '2 persons');


--
INSERT INTO 'couplesshape' VALUES (43, 54, 4, '4P/SQ');
INSERT INTO 'couplesshape' VALUES (44, 54, 5, '4P/RR');
INSERT INTO 'couplesshape' VALUES (1, 1, 1, '1C/4');
INSERT INTO 'couplesshape' VALUES (45, 54, 6, '4P/tri');
INSERT INTO 'couplesshape' VALUES (2, 1, 5, 'RR');
INSERT INTO 'couplesshape' VALUES (46, 54, 8, '4P/6');
INSERT INTO 'couplesshape' VALUES (47, 55, 1, '5P/4');
INSERT INTO 'couplesshape' VALUES (3, 1, 7, '1C/Circle');
INSERT INTO 'couplesshape' VALUES (48, 55, 4, '5P/SQ');
INSERT INTO 'couplesshape' VALUES (4, 1, 11, '1C');
INSERT INTO 'couplesshape' VALUES (49, 55, 5, '5P/RR');
INSERT INTO 'couplesshape' VALUES (50, 55, 11, '5P');
INSERT INTO 'couplesshape' VALUES (5, 2, 1, '2C/4');
INSERT INTO 'couplesshape' VALUES (51, 56, 5, '3P-3/RR');
INSERT INTO 'couplesshape' VALUES (6, 2, 2, '2C/3');
INSERT INTO 'couplesshape' VALUES (52, 56, 7, '3P-3/circl');
INSERT INTO 'couplesshape' VALUES (53, 56, 11, '3P-3');
INSERT INTO 'couplesshape' VALUES (7, 2, 4, '2C/square');
INSERT INTO 'couplesshape' VALUES (54, 99, 1, '?');
INSERT INTO 'couplesshape' VALUES (55, 99, 4, '?');
INSERT INTO 'couplesshape' VALUES (56, 99, 6, '?');
INSERT INTO 'couplesshape' VALUES (57, 99, 7, '?');
INSERT INTO 'couplesshape' VALUES (58, 99, 11, '?');
INSERT INTO 'couplesshape' VALUES (8, 2, 5, '2C/RR');
INSERT INTO 'couplesshape' VALUES (9, 2, 7, '2C/Circle');
INSERT INTO 'couplesshape' VALUES (10, 2, 11, '2C');
INSERT INTO 'couplesshape' VALUES (11, 3, 1, '3C/4');
INSERT INTO 'couplesshape' VALUES (12, 3, 2, '3C/3');
INSERT INTO 'couplesshape' VALUES (13, 3, 3, '3C/5');
INSERT INTO 'couplesshape' VALUES (14, 3, 4, '3C/square');
INSERT INTO 'couplesshape' VALUES (15, 3, 5, '3C/RR');
INSERT INTO 'couplesshape' VALUES (16, 3, 6, 'Triang.');
INSERT INTO 'couplesshape' VALUES (17, 3, 9, '3C/7');
INSERT INTO 'couplesshape' VALUES (18, 3, 11, '3C');
INSERT INTO 'couplesshape' VALUES (19, 4, 1, '4C/4');
INSERT INTO 'couplesshape' VALUES (20, 4, 3, '4C/5');
INSERT INTO 'couplesshape' VALUES (21, 4, 4, 'SQ');
INSERT INTO 'couplesshape' VALUES (22, 4, 5, '4C/RR');
INSERT INTO 'couplesshape' VALUES (23, 4, 6, '4C/Tri');
INSERT INTO 'couplesshape' VALUES (24, 4, 11, '4C');
INSERT INTO 'couplesshape' VALUES (25, 5, 3, '5C/5');
INSERT INTO 'couplesshape' VALUES (26, 5, 4, '5C/SQ');
INSERT INTO 'couplesshape' VALUES (27, 5, 5, '5C/RR');
INSERT INTO 'couplesshape' VALUES (28, 5, 7, '5C/circle');
INSERT INTO 'couplesshape' VALUES (29, 5, 11, '5C');
INSERT INTO 'couplesshape' VALUES (30, 6, 4, '6C/SQ');
INSERT INTO 'couplesshape' VALUES (31, 6, 7, '6C/circle');
INSERT INTO 'couplesshape' VALUES (32, 6, 8, '6C/6');
INSERT INTO 'couplesshape' VALUES (33, 6, 11, '6C');
INSERT INTO 'couplesshape' VALUES (34, 7, 9, '7C/7');
INSERT INTO 'couplesshape' VALUES (35, 8, 4, '8C/SQ');
INSERT INTO 'couplesshape' VALUES (36, 8, 11, '8C');
INSERT INTO 'couplesshape' VALUES (37, 51, 1, '1P/4');
INSERT INTO 'couplesshape' VALUES (38, 53, 1, '3P/4');
INSERT INTO 'couplesshape' VALUES (39, 53, 5, '3P/RR');
INSERT INTO 'couplesshape' VALUES (40, 53, 6, '3P/tri');
INSERT INTO 'couplesshape' VALUES (41, 53, 11, '3P');
INSERT INTO 'couplesshape' VALUES (42, 54, 1, '4P/4');


--
INSERT INTO 'dance' VALUES (2, '1999-05-10 22:00:00+00', '2018-04-29 21:40:31.79983+00', 'Lot To Answer For, A', 'LOT TO ANSWER FOR', 2, 32, 9999, 1, 3, 42, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18396, '2018-07-13 09:52:29.547919+00', '2018-07-13 09:52:29.547919+00', 'Metamorphosis', 'METAMORPHOSIS', 2, 40, NULL, 1, 4, NULL, 11659, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4, '1997-08-28 22:00:00+00', '2012-01-20 12:55:59.955314+00', 'A'' Dol Suiridhe', 'A DOL SUIRIDHE', 3, 32, 9999, 1, 4, NULL, 607, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5, '1997-04-03 22:00:00+00', '2012-01-20 12:55:59.962458+00', 'A'' the Marquis''s', 'A THE MARQUISS', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (38, '1997-08-28 22:00:00+00', '2019-09-13 19:16:25.254153+00', 'Adelaide Grand Prix', 'ADELAIDE GRAND PRIX', 1, 32, 9999, 1, 4, 1, 605, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11, '1997-08-28 22:00:00+00', '2012-01-20 12:56:00.016337+00', 'Aberbrothock', 'ABERBROTHOCK', 4, 64, 9999, 4, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12, '2003-01-26 23:00:00+00', '2012-01-20 12:56:00.025897+00', 'Aberdeen to Zorra', 'ABERDEEN TO ZORRA', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17, '1998-04-20 22:00:00+00', '2012-01-20 12:56:00.072818+00', 'Academy, The', 'ACADEMY', 4, 32, 40, 1, 2, NULL, 44, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19, '1997-04-03 22:00:00+00', '2012-01-20 12:56:00.090382+00', 'Accounting For Time', 'ACCOUNTING FOR TIME', 3, 32, 9999, 1, 4, NULL, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3755, '1997-08-26 22:00:00+00', '2019-03-15 10:00:01.428299+00', 'Lawson''s Lady', 'LAWSONS LADY', 3, 32, 9999, 2, 3, 17, 553, '1995-01-01', '', 71, '880/855/855/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2611, '1997-04-03 22:00:00+00', '2019-03-16 16:28:07.456831+00', 'Gordon Chase, The', 'GORDON CHASE', 3, 80, 9999, 4, 4, 3, 108, '1988-01-01', '', 100, '8888/8888/8888/8888/8888/8888/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (25, '1997-08-28 22:00:00+00', '2012-01-20 12:56:00.143018+00', 'Achnamara', 'ACHNAMARA', 3, 32, 9999, 1, 4, NULL, 602, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (26, '1997-08-28 22:00:00+00', '2012-01-20 12:56:00.151706+00', 'Achnasheen', 'ACHNASHEEN', 3, 48, 9999, 4, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (27, '1997-08-28 22:00:00+00', '2012-01-20 12:56:00.160394+00', 'Ackergill Agreement', 'ACKERGILL AGREEMENT', 1, 32, 9999, 1, 4, NULL, 603, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18398, '2018-07-13 10:05:21.12156+00', '2019-05-01 08:30:01.084364+00', 'Memento, The', 'MEMENTO', 2, 32, NULL, 1, 3, 42, 11662, NULL, '', 34, '802/806/800/822', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2612, '1998-04-12 22:00:00+00', '2012-01-20 12:56:20.879056+00', 'Gordon Highlanders', 'GORDON HIGHLANDERS', 2, 40, 9999, 1, 4, NULL, 313, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2614, '1997-09-03 22:00:00+00', '2012-01-20 12:56:20.896634+00', 'Heather in a Mist', 'HEATHER IN A MIST', 1, 32, 9999, 4, 4, NULL, 729, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2615, '1997-04-03 22:00:00+00', '2012-01-20 12:56:20.90594+00', 'Gosford House Jig', 'GOSFORD HOUSE JIG', 2, 32, 9999, 1, 4, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3754, '1997-09-07 22:00:00+00', '2012-01-20 12:56:30.515966+00', 'Lawrence Centenary Medley', 'LAWRENCE CENTENARY MEDLEY', 4, 128, 9999, 4, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3758, '1999-04-21 22:00:00+00', '2012-01-20 12:56:30.543617+00', 'Grand Jour, Le', 'GRAND JOUR', 3, 32, 9999, 2, 3, NULL, 23, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3760, '1997-09-07 22:00:00+00', '2012-01-20 12:56:30.557295+00', 'Leading Lady', 'LEADING LADY', 2, 48, 9999, 1, 4, NULL, 1067, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7, '1997-04-03 22:00:00+00', '2018-04-03 00:07:29.38674+00', 'Abbess, The', 'ABBESS', 1, 32, 9999, 1, 3, 42, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (33, '2002-02-21 23:00:00+00', '2012-01-20 12:56:00.213743+00', 'Across the Tay Bridge', 'ACROSS THE TAY BRIDGE', 3, 32, 9999, 1, 4, NULL, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (35, '1997-08-28 22:00:00+00', '2012-01-20 12:56:00.231087+00', 'Adam Buchan O!', 'ADAM BUCHAN O', 1, 32, 9999, 2, 3, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8, '1997-08-28 22:00:00+00', '2018-04-03 00:07:29.450245+00', 'Abbey Craig', 'ABBEY CRAIG', 3, 32, 9999, 1, 3, 42, 346, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (23, '1997-04-03 22:00:00+00', '2018-04-03 00:07:29.531539+00', 'Achnacloich', 'ACHNACLOICH', 3, 32, 9999, 1, 3, 42, 3, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (24, '1997-04-03 22:00:00+00', '2018-04-03 00:07:29.539945+00', 'Achnahennich', 'ACHNAHENNICH', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21, '2002-03-02 23:00:00+00', '2018-04-03 00:07:29.548307+00', 'Achtilbuie', 'ACHTILBUIE', 2, 40, 9999, 1, 3, 42, 26, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (31, '2002-02-21 23:00:00+00', '2018-04-03 00:07:29.581805+00', 'Across the High C''s', 'ACROSS THE HIGH CS', 1, 32, 9999, 1, 3, 42, 23, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (34, '2002-02-21 23:00:00+00', '2018-04-03 00:07:29.632073+00', 'Across the Tweed', 'ACROSS THE TWEED', 1, 40, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (36, '2003-01-28 23:00:00+00', '2018-04-03 00:07:29.656798+00', 'Adam Fergusson''s Reel', 'ADAM FERGUSSONS REEL', 1, 32, 9999, 1, 3, 42, 35, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (37, '1998-09-04 22:00:00+00', '2018-04-03 00:07:29.665099+00', 'Adam Forrester of Knocksheen''s Night Out', 'ADAM FORRESTER OF KNOCKSHEENS NIGHT OUT', 2, 32, 9999, 1, 3, 42, 210, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3, '1997-08-28 22:00:00+00', '2018-04-03 00:07:29.673488+00', 'A'' Dannsadh An Aghaidh an t-Struith', 'A DANNSADH AN AGHAIDH AN TSTRUITH', 3, 32, 9999, 1, 3, 42, 264, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3757, '1997-09-01 22:00:00+00', '2018-04-03 00:07:41.633397+00', 'Debauche, Le', 'DEBAUCHE', 1, 48, 9999, 1, 3, 42, 198, '1757-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2609, '1997-04-03 22:00:00+00', '2018-04-03 00:07:49.40753+00', 'Gopher''s Reel, The', 'GOPHERS REEL', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3756, '1997-07-16 22:00:00+00', '2018-04-03 00:07:59.187668+00', 'Lazy Jean', 'LAZY JEAN', 3, 32, 9999, 1, 3, 42, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3761, '1997-09-07 22:00:00+00', '2018-04-03 00:07:59.223142+00', 'Leamington Lassies And Lads', 'LEAMINGTON LASSIES AND LADS', 2, 32, 9999, 1, 3, 42, 1068, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10323, '2002-01-08 23:00:00+00', '2018-04-03 00:08:05.143974+00', 'Monday Evening', 'MONDAY EVENING', 3, 40, 9999, 1, 3, 42, 1038, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (39, '1998-04-04 22:00:00+00', '2012-01-20 12:56:00.265983+00', 'Adelaide''s Welcome to John Drewry', 'ADELAIDES WELCOME TO JOHN DREWRY', 2, 48, 9999, 1, 4, NULL, 711, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (42, '1998-01-05 23:00:00+00', '2012-01-20 12:56:00.292159+00', 'Admiral Jervis', 'ADMIRAL JERVIS', 1, 32, 9999, 3, 5, NULL, 606, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (72, '1997-04-03 22:00:00+00', '2019-02-24 10:31:55.7359+00', 'Aldwark Reel, The', 'ALDWARK REEL', 1, 32, 9999, 1, 3, 42, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9, '1997-08-28 22:00:00+00', '2020-09-07 14:00:42.980451+00', 'Abbotswell Jig, The', 'ABBOTSWELL JIG', 2, 32, 9999, 1, 3, 42, 601, NULL, '', 44, '800/880/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (32, '2002-02-21 23:00:00+00', '2020-09-07 14:06:07.186051+00', 'Across the Tay', 'ACROSS THE TAY', 2, 48, 9999, 1, 4, 1, 176, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10325, '2005-12-21 23:00:00+00', '2020-11-08 12:24:25.171944+00', 'George''s Strathspey', 'GEORGES STRATHSPEY', 3, 40, 9999, 1, 100, 11, 3412, NULL, '', 90, '8448/8888/8888/8888/4884', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10324, '2002-01-08 23:00:00+00', '2021-02-10 10:13:09.484229+00', 'Muirton Bank', 'MUIRTON BANK', 3, 32, 9999, 2, 3, 17, 205, NULL, '', 50, '440/880/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2639, '1997-04-03 22:00:00+00', '2021-04-05 08:18:39.483807+00', 'Grand Tour, The', 'GRAND TOUR', 1, 40, 9999, 1, 3, 42, 352, '1991-10-26', '', 69, '880/844/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10322, '2002-01-08 23:00:00+00', '2021-06-08 09:50:02.270782+00', 'Millennium Reel', 'MILLENNIUM REEL', 1, 32, 9999, 1, 3, 42, 851, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (53, '1997-08-28 22:00:00+00', '2012-01-20 12:56:00.392358+00', 'Ainsty Strathspey, The', 'AINSTY STRATHSPEY', 3, 40, 9999, 1, 4, 1, 611, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (78, '1998-01-05 23:00:00+00', '2018-04-29 21:15:54.290612+00', 'Alexander Hamilton''s Reel', 'ALEXANDER HAMILTONS REEL', 1, 40, 9999, 1, 3, 42, 608, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2618, '1997-09-03 22:00:00+00', '2012-01-20 12:56:20.932707+00', 'Govandale Reel', 'GOVANDALE REEL', 2, 48, 9999, 1, 4, NULL, 967, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2619, '1998-07-08 22:00:00+00', '2012-01-20 12:56:20.942576+00', 'Gowans', 'GOWANS', 3, 32, 9999, 1, 4, 2, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14389, '2012-01-03 23:00:00+00', '2022-08-14 08:48:57.914191+00', 'Abbey Jig', 'ABBEY JIG', 2, 32, NULL, 5, 2, 76, 10870, NULL, '', 100, '88  88  88  88', 1, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (2613, '1997-04-03 22:00:00+00', '2023-01-27 11:06:29.834598+00', 'Gordon Young''s Reel', 'GORDON YOUNGS REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 69, '888/888/808/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2610, '1997-11-20 23:00:00+00', '2023-01-27 11:12:58.862234+00', 'Gordon Castle', 'GORDON CASTLE', 3, 32, 9999, 1, 2, 76, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2621, '1997-04-03 22:00:00+00', '2012-01-20 12:56:20.959995+00', 'Gowden Reel, The', 'GOWDEN REEL', 1, 32, 9999, 1, 4, NULL, 108, '1978-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2622, '1997-09-03 22:00:00+00', '2012-01-20 12:56:20.968781+00', 'Goyt Valley Reel, The', 'GOYT VALLEY REEL', 2, 48, 9999, 1, 4, NULL, 968, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (67, '1998-11-02 23:00:00+00', '2019-03-20 00:16:18.912397+00', 'Alberta Rose, The', 'ALBERTA ROSE', 3, 80, 9999, 4, 4, 3, 612, '1982-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (45, '1997-08-25 22:00:00+00', '2019-02-27 23:46:39.821154+00', 'Afore Ye Go', 'AFORE YE GO', 2, 40, 9999, 1, 4, 1, 549, '1977-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2625, '2002-05-11 22:00:00+00', '2012-01-20 12:56:20.994791+00', 'Fourteenth of February', 'FOURTEENTH OF FEBRUARY', 2, 32, 9999, 3, 5, NULL, 1146, '1979-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10326, '2002-02-09 23:00:00+00', '2012-01-20 12:57:20.335841+00', 'North Muir Jig', 'NORTH MUIR JIG', 2, 32, 9999, 1, 4, 2, 9998, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18399, '2018-07-13 10:05:59.999864+00', '2019-10-26 18:38:30.144452+00', 'Telesita''s Fancy', 'TELESITAS FANCY', 3, 32, NULL, 1, 3, NULL, 11662, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (61, '1997-04-03 22:00:00+00', '2012-01-20 12:56:00.465449+00', 'Alamein', 'ALAMEIN', 1, 32, 9999, 1, 4, NULL, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (70, '1997-12-29 23:00:00+00', '2012-01-20 12:56:00.543832+00', 'Aldivalloch', 'ALDIVALLOCH', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (58, '1997-04-03 22:00:00+00', '2018-04-03 00:07:29.790936+00', 'Airth Castle', 'AIRTH CASTLE', 3, 32, 9999, 1, 3, 42, 34, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (75, '1997-04-03 22:00:00+00', '2012-01-20 12:56:00.588276+00', 'Alec''s Favourite', 'ALECS FAVOURITE', 3, 32, 9999, 1, 4, NULL, 173, '1990-07-26', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (79, '1998-07-08 22:00:00+00', '2012-01-20 12:56:00.624078+00', 'Alexander Reel, The', 'ALEXANDER REEL', 1, 32, 9999, 1, 4, 2, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (80, '2002-04-28 22:00:00+00', '2012-01-20 12:56:00.633625+00', 'Alexander''s 40th Reel', 'ALEXANDERS 40TH REEL', 1, 40, 9999, 1, 4, 2, 614, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (84, '1997-08-28 22:00:00+00', '2012-01-20 12:56:00.669224+00', 'Alfred McDonald Strathspey', 'ALFRED MACDONALD STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 615, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (85, '1997-05-17 22:00:00+00', '2012-01-20 12:56:00.677958+00', 'Alice', 'ALICE', 3, 32, 9999, 2, 3, NULL, 108, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2634, '1997-04-03 22:00:00+00', '2012-01-20 12:56:21.073776+00', 'Grand Affair, A', 'GRAND AFFAIR', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2638, '1997-09-03 22:00:00+00', '2015-09-21 06:42:57.161515+00', 'Grand Slam', 'GRAND SLAM', 2, 32, 9999, 3, 5, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (48, '1997-04-03 22:00:00+00', '2015-09-21 06:47:53.609816+00', 'Agnes Evans', 'AGNES EVANS', 2, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (44, '1998-07-08 22:00:00+00', '2016-09-04 19:59:03.284732+00', 'Ae Fond Kiss', 'AE FOND KISS', 1, 48, 9999, 8, 6, NULL, 608, NULL, '(bottom 3 couples do not start improper)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (49, '1997-04-03 22:00:00+00', '2018-04-03 00:07:29.816043+00', 'Ai Strathspey', 'AI STRATHSPEY', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (62, '1997-04-03 22:00:00+00', '2018-04-03 00:07:29.866292+00', 'Alan Malone''s Reel', 'ALAN MALONES REEL', 1, 32, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (63, '1997-04-03 22:00:00+00', '2018-04-03 00:07:29.874732+00', 'Alan Maxwell''s Farewell', 'ALAN MAXWELLS FAREWELL', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (65, '1997-04-03 22:00:00+00', '2018-04-03 00:07:29.89978+00', 'Albany House', 'ALBANY HOUSE', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (69, '1997-08-28 22:00:00+00', '2018-04-03 00:07:29.94757+00', 'Alderley Medley', 'ALDERLEY MEDLEY', 4, 32, 9999, 1, 3, 42, 314, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (71, '1998-04-29 22:00:00+00', '2018-04-03 00:07:29.95822+00', 'Aldridge''s Hornpipe', 'ALDRIDGES HORNPIPE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (86, '1999-07-25 22:00:00+00', '2018-04-03 00:07:30.025064+00', 'Alice Mann''s Strathspey', 'ALICE MANNS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1982-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2620, '1997-09-03 22:00:00+00', '2018-04-03 00:07:49.465948+00', 'Gowden Laverock, The', 'GOWDEN LAVEROCK', 3, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2624, '1997-04-03 22:00:00+00', '2018-04-03 00:07:49.491028+00', 'Graceful Strathspey, The', 'GRACEFUL STRATHSPEY', 3, 32, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2623, '2002-11-29 23:00:00+00', '2018-04-03 00:07:49.499245+00', 'Grace Of Alvertoune, The', 'GRACE OF ALVERTOUNE', 3, 32, 9999, 1, 3, 42, 2614, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2626, '2002-04-19 22:00:00+00', '2018-04-03 00:07:49.507556+00', 'Graduation Jig, The', 'GRADUATION JIG', 2, 32, 9999, 1, 3, 42, 969, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2627, '2002-01-06 23:00:00+00', '2018-04-03 00:07:49.515946+00', 'Graelynda Strathspey, The', 'GRAELYNDA STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2633, '1997-04-03 22:00:00+00', '2018-04-03 00:07:49.532595+00', 'Grampian Tartan, The', 'GRAMPIAN TARTAN', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2637, '1998-04-24 22:00:00+00', '2018-04-03 00:07:49.565876+00', 'Grand Promenade, The', 'GRAND PROMENADE', 3, 32, 9999, 1, 3, 42, 108, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10330, '2002-02-09 23:00:00+00', '2018-04-03 00:08:10.481652+00', 'Petherum Brig', 'PETHERUM BRIG', 1, 32, 9999, 1, 3, 42, 1272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10331, '2002-02-09 23:00:00+00', '2018-04-03 00:08:11.682655+00', 'Queen Mother''s Century, The', 'QUEEN MOTHERS CENTURY', 1, 32, 9999, 1, 3, 42, 2987, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2657, '1998-04-12 22:00:00+00', '2018-12-13 02:26:03.858061+00', 'Great Thunder Falls, The', 'GREAT THUNDER FALLS', 2, 32, 9999, 1, 3, 42, 44, '1986-01-01', 'Presented to the Teachers'' Association (Canada) to celebrate the 1986 TAC Summer School.', 53, '888/800/804/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10360, '2002-02-26 23:00:00+00', '2012-01-20 12:57:20.653145+00', 'Larkhall Ladies', 'LARKHALL LADIES', 3, 32, 9999, 3, 5, 16, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10362, '2002-03-03 23:00:00+00', '2012-01-20 12:57:20.671402+00', 'Key to the Fylde', 'KEY TO THE FYLDE', 3, 128, 9999, 4, 4, NULL, 9998, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (47, '1997-04-03 22:00:00+00', '2020-06-30 18:58:20.905056+00', 'After the Battle', 'AFTER THE BATTLE', 1, 32, 9999, 5, 2, NULL, 270, NULL, '', 94, '88/77/88/77', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (46, '1997-08-28 22:00:00+00', '2020-08-24 22:48:53.95524+00', 'After the Ball', 'AFTER THE BALL', 3, 48, 9999, 4, 4, 3, 609, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10329, '2002-02-09 23:00:00+00', '2021-02-10 10:09:37.829808+00', 'Pauline''s Wedding', 'PAULINES WEDDING', 3, 40, 9999, 4, 4, 14, 103, '2000-01-01', '', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (59, '1997-04-03 22:00:00+00', '2021-05-13 07:34:19.021003+00', 'Airy Fairy', 'AIRY FAIRY', 1, 32, 9999, 1, 2, 76, 352, '1993-01-22', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2656, '1998-04-12 22:00:00+00', '2021-06-02 11:27:57.456321+00', 'Great Spirit''s Voice, The', 'GREAT SPIRITS VOICE', 3, 32, 9999, 1, 2, 76, 401, '1983-01-01', '', 60, '84/88/84/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10328, '2002-02-09 23:00:00+00', '2021-06-08 09:49:13.858675+00', 'Pat Petrie''s Jig', 'PAT PETRIES JIG', 2, 40, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (81, '1997-04-03 22:00:00+00', '2021-06-22 20:17:20.786351+00', 'Alexander''s Jig', 'ALEXANDERS JIG', 2, 32, 9999, 1, 3, 42, 259, NULL, '', 53, '800/888/822/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2629, '1998-01-05 23:00:00+00', '2021-07-11 15:53:00.371303+00', 'Graham Park', 'GRAHAM PARK', 1, 32, 9999, 1, 3, 42, 970, NULL, '', 64, '864/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2630, '1997-04-03 22:00:00+00', '2021-07-17 18:41:20.620077+00', 'Graham''s Fancy', 'GRAHAMS FANCY', 2, 32, 9999, 1, 4, 1, 377, NULL, 'According to the dance notes, the tune Graham Warren Hamilton was composed by Brian Hamilton for his son Graham for whom this dance was devised.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10363, '2002-03-03 23:00:00+00', '2012-01-20 12:57:20.680941+00', 'Millennium Bug, The', 'MILLENNIUM BUG', 1, 32, 9999, 1, 4, 2, 123, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18400, '2018-07-13 10:08:02.705115+00', '2019-10-26 18:38:02.875259+00', 'Five Reasons for Drinking, The', 'FIVE REASONS FOR DRINKING', 1, 40, NULL, 1, 3, NULL, 11663, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (94, '1997-04-03 22:00:00+00', '2012-01-20 12:56:00.761808+00', 'All Friends Around Wrekin', 'ALL FRIENDS AROUND WREKIN', 3, 64, 9999, 4, 4, NULL, 329, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (97, '1997-04-03 22:00:00+00', '2018-04-02 10:27:25.782689+00', 'All That Glisters', 'ALL THAT GLISTERS', 2, 32, 9999, 1, 3, 42, 352, '1993-05-20', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (96, '1997-04-03 22:00:00+00', '2012-01-20 12:56:00.779124+00', 'All Slobbered And Sost', 'ALL SLOBBERED AND SOST', 2, 32, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2654, '1997-04-03 22:00:00+00', '2018-04-02 23:56:35.026267+00', 'Great Obsession, The', 'GREAT OBSESSION', 3, 24, 9999, 1, 3, 42, 352, '1994-01-13', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2628, '1997-04-03 22:00:00+00', '2022-11-07 22:05:24.625705+00', 'Graham Hamilton of Glenwood', 'GRAHAM HAMILTON OF GLENWOOD', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (99, '1997-08-31 22:00:00+00', '2012-01-20 12:56:00.805468+00', 'All Together, One After Another', 'ALL TOGETHER ONE AFTER ANOTHER', 2, 32, 9999, 1, 2, NULL, 446, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (102, '1997-08-28 22:00:00+00', '2012-01-20 12:56:00.838695+00', 'Allerton Lassies', 'ALLERTON LASSIES', 1, 32, 9999, 1, 4, NULL, 620, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (87, '1997-04-03 22:00:00+00', '2018-04-03 00:07:30.050187+00', 'Alison and Sandy Grant', 'ALISON AND SANDY GRANT', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (106, '1997-08-28 22:00:00+00', '2012-01-20 12:56:00.88332+00', 'Alloway Rant, The', 'ALLOWAY RANT', 1, 32, 9999, 1, 4, NULL, 622, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (110, '1997-08-28 22:00:00+00', '2012-01-20 12:56:00.922265+00', 'Alpin Fancy', 'ALPIN FANCY', 2, 48, 9999, 1, 4, NULL, 311, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (111, '1997-04-03 22:00:00+00', '2012-01-20 12:56:00.930946+00', 'Altnabreac', 'ALTNABREAC', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (112, '2002-11-29 23:00:00+00', '2012-01-20 12:56:00.939721+00', 'Alverton Strathspey', 'ALVERTON STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 3249, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (113, '1998-01-04 23:00:00+00', '2012-01-20 12:56:00.948597+00', 'Always Welcome', 'ALWAYS WELCOME', 1, 32, 9999, 1, 2, NULL, 44, '1968-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (115, '1997-09-21 22:00:00+00', '2012-01-20 12:56:00.966291+00', 'Always Welcome', 'ALWAYS WELCOME', 1, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2646, '1998-07-08 22:00:00+00', '2012-01-20 12:56:21.190909+00', 'Grant''s Strathspey', 'GRANTS STRATHSPEY', 3, 40, 9999, 1, 4, 2, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2647, '1997-09-03 22:00:00+00', '2012-01-20 12:56:21.20621+00', 'Granton Lassie, The', 'GRANTON LASSIE', 3, 32, 9999, 1, 4, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2648, '1997-09-03 22:00:00+00', '2012-01-20 12:56:21.214889+00', 'Granville Reel, The', 'GRANVILLE REEL', 1, 40, 9999, 4, 4, NULL, 929, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2650, '1997-04-03 22:00:00+00', '2012-01-20 12:56:21.232199+00', 'Great Aunt Henderson', 'GREAT AUNT HENDERSON', 2, 40, 9999, 1, 4, NULL, 393, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2652, '1997-04-03 22:00:00+00', '2012-01-20 12:56:21.24956+00', 'Great MacMillan Of Knap', 'GREAT MACMILLAN OF KNAP', 3, 40, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (90, '1997-04-03 22:00:00+00', '2018-04-03 00:07:30.066952+00', 'Alistair''s Favourite Pickle', 'ALISTAIRS FAVOURITE PICKLE', 2, 32, 9999, 1, 3, 42, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10369, '2002-03-07 23:00:00+00', '2012-01-20 12:57:20.735731+00', 'Celtic Curve, The', 'CELTIC CURVE', 3, 64, 9999, 4, 4, 14, 2994, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (119, '1997-08-28 22:00:00+00', '2012-01-20 12:56:01.001358+00', 'Amang The Heather', 'AMANG THE HEATHER', 2, 40, 9999, 1, 4, NULL, 78, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (121, '1997-04-03 22:00:00+00', '2012-01-20 12:56:01.018896+00', 'Amerada Hess Jig', 'AMERADA HESS JIG', 2, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (122, '1997-04-03 22:00:00+00', '2012-01-20 12:56:01.027536+00', 'Amerada Hess Reel', 'AMERADA HESS REEL', 1, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2643, '1997-12-27 23:00:00+00', '2018-02-19 00:43:39.871869+00', 'Grant Park', 'GRANT PARK', 3, 24, 9999, 1, 2, 76, 361, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10358, '2002-02-26 23:00:00+00', '2017-05-31 13:03:28.347795+00', 'schoener Wunsch, Ein', 'SCHOENER WUNSCH EIN', 1, 32, 9999, 2, 3, 17, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (101, '1997-09-17 22:00:00+00', '2018-04-03 00:07:30.108657+00', 'Allan''s Rant, The', 'ALLANS RANT', 1, 32, 9999, 1, 3, 42, 346, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (108, '1997-11-27 23:00:00+00', '2018-04-03 00:07:30.250669+00', 'Alltreoch', 'ALLTREOCH', 4, 32, 1, 1, 3, 42, 176, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (120, '1998-04-04 22:00:00+00', '2018-04-03 00:07:30.309311+00', 'Amazing Glace', 'AMAZING GLACE', 3, 32, 9999, 1, 3, 42, 108, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2653, '1997-04-03 22:00:00+00', '2018-04-03 00:07:49.716105+00', 'Great North Road', 'GREAT NORTH ROAD', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2655, '1997-04-03 22:00:00+00', '2018-04-03 00:07:49.724448+00', 'Great October Blow, The', 'GREAT OCTOBER BLOW', 2, 48, 9999, 1, 3, 42, 145, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10359, '2002-02-26 23:00:00+00', '2018-04-03 00:07:53.718988+00', 'Inveruglas House', 'INVERUGLAS HOUSE', 99, 0, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2641, '2000-11-17 23:00:00+00', '2018-04-03 00:07:55.320012+00', 'Jess Nichol''s Fancy', 'JESS NICHOLS FANCY', 3, 32, 9999, 1, 3, 42, 2825, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (124, '1998-07-08 22:00:00+00', '2012-01-20 12:56:01.089584+00', 'Among the Wicklow Hills', 'AMONG THE WICKLOW HILLS', 3, 40, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (125, '1997-04-03 22:00:00+00', '2012-01-20 12:56:01.10555+00', 'Ample Plaid, The', 'AMPLE PLAID', 3, 32, 9999, 1, 4, 11, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10335, '2002-02-11 23:00:00+00', '2018-04-03 00:07:30.11691+00', 'All at Once Well Met', 'ALL AT ONCE WELL MET', 2, 40, 9999, 1, 3, 42, 2408, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (131, '1997-09-11 22:00:00+00', '2012-01-20 12:56:01.182104+00', 'Poussie, Poussie, Bawdrons', 'POUSSIE POUSSIE BAWDRONS', 3, 12, 9999, 1, 4, NULL, 3, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (299, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.537638+00', 'Auld Kirk, The', 'AULD KIRK', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (114, '1997-09-30 22:00:00+00', '2020-08-14 20:53:36.411143+00', 'Always Welcome', 'ALWAYS WELCOME', 1, 32, 9999, 1, 4, 1, 21, NULL, '', 56, '8008/8008/8000/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (83, '1998-10-31 23:00:00+00', '2020-09-07 14:12:41.89724+00', 'Alexandria Reel, The', 'ALEXANDRIA REEL', 2, 48, 9999, 1, 100, 2, 108, '1976-01-01', '', 81, '6886/8008/8888/8888/8008/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (92, '1997-09-30 22:00:00+00', '2020-09-07 14:21:09.100733+00', 'All Feathers and Fluff', 'ALL FEATHERS AND FLUFF', 2, 32, 9999, 1, 3, 42, 21, NULL, '', 53, '840/888/880/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (88, '1997-08-28 22:00:00+00', '2020-12-27 12:57:32.273249+00', 'Alison Jane''s Jig', 'ALISON JANES JIG', 2, 40, 9999, 1, 3, 42, 617, NULL, '', 49, '860/866/844/800/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10357, '2002-04-11 22:00:00+00', '2021-02-09 12:37:57.686277+00', 'Anchors Aweigh', 'ANCHORS AWEIGH', 1, 48, 9999, 1, 3, 42, 2863, NULL, '', 65, '844/888/888/822/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10364, '2002-07-23 22:00:00+00', '2021-02-09 12:31:30.566718+00', 'Mr MacAskill''s Problem', 'MR MACASKILLS PROBLEM', 3, 32, 9999, 1, 4, 1, 1, '1997-01-01', '', 81, '8888/8888/8440/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10368, '2002-03-06 23:00:00+00', '2021-04-18 19:02:51.612649+00', 'Nut Loaf, The', 'NUT LOAF', 2, 40, 9999, 1, 3, 42, 44, '2000-03-25', '', 60, '844/866/844/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2666, '1998-01-05 23:00:00+00', '2021-05-13 14:04:36.533502+00', 'Green Moss', 'GREEN MOSS', 1, 24, 9999, 1, 3, 42, 352, '1993-01-12', '', 42, '800/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (103, '1998-11-02 23:00:00+00', '2021-06-22 20:06:03.941833+00', 'Allison''s Invention', 'ALLISONS INVENTION', 1, 32, 9999, 1, 3, 42, 621, '1986-01-01', 'Devised as a teaching dance for Kingston''s 1986 Spring Workshop.', 50, '800/888/844/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18401, '2018-07-13 10:09:09.559026+00', '2018-07-13 10:09:09.559026+00', 'All-Around Poussette', 'ALLAROUND POUSSETTE', 2, 40, NULL, 4, 4, NULL, 11661, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (136, '1997-08-28 22:00:00+00', '2012-01-20 12:56:01.225682+00', 'And One for Judy', 'AND ONE FOR JUDY', 2, 32, 9999, 2, 3, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (146, '1997-08-28 22:00:00+00', '2018-08-20 10:33:41.69255+00', 'Andrew''s Welcome', 'ANDREWS WELCOME', 1, 32, 9999, 1, 4, 1, 377, NULL, 'Written for Andrew, son of David and Janet Berg.', 56, '4000/4000/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18880, '2018-10-08 18:09:58.224869+00', '2018-10-08 18:09:58.224869+00', 'Simple Simon', 'SIMPLE SIMON', 1, 32, NULL, 1, 3, NULL, 2766, '2009-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (143, '1998-07-08 22:00:00+00', '2012-01-20 12:56:01.287832+00', 'Andrew Rankine''s Reel', 'ANDREW RANKINES REEL', 1, 32, 9999, 1, 4, 11, 627, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (163, '1997-04-03 22:00:00+00', '2019-02-07 17:48:35.230782+00', 'Annandale', 'ANNANDALE', 2, 32, 9999, 3, 5, 16, 13, NULL, '', 65, '88288/80808/86888/80000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2659, '1997-09-03 22:00:00+00', '2012-01-20 12:56:21.310757+00', 'Green Boughs of the North', 'GREEN BOUGHS OF THE NORTH', 4, 64, 9999, 4, 4, NULL, 973, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (160, '1997-08-28 22:00:00+00', '2019-03-20 00:02:42.250783+00', 'Anna''s Reel', 'ANNAS REEL', 1, 32, 9999, 1, 4, 2, 634, NULL, '', 81, '8888/8448/8888/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2665, '1997-04-03 22:00:00+00', '2012-01-20 12:56:21.366565+00', 'Green Meadow, The', 'GREEN MEADOW', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (126, '1997-08-31 22:00:00+00', '2022-12-18 21:58:48.66917+00', 'Fair Quaker of Deal, The', 'FAIR QUAKER OF DEAL', 2, 32, 9999, 1, 2, NULL, 397, '1712-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (169, '2000-08-01 22:00:00+00', '2018-02-27 09:45:41.735131+00', 'Anne Grant''s Reel', 'ANNE GRANTS REEL', 1, 32, 9999, 1, 3, 42, 827, '1993-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10332, '2002-02-09 23:00:00+00', '2012-01-20 12:57:20.393585+00', 'RNLI - 175th Anniversary', 'RNLI  175TH ANNIVERSARY', 1, 32, 9999, 1, 4, 1, 1836, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10336, '2002-02-11 23:00:00+00', '2012-01-20 12:57:20.430327+00', 'Matinee, The', 'MATINEE', 3, 32, 9999, 4, 4, NULL, 2988, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10337, '2002-02-12 23:00:00+00', '2012-01-20 12:57:20.439832+00', 'Scottish Fare', 'SCOTTISH FARE', 1, 32, 9999, 1, 4, 2, 205, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (148, '1997-08-28 22:00:00+00', '2012-01-20 12:56:01.331593+00', 'Ane Reel For Fionnghuala', 'ANE REEL FOR FIONNGHUALA', 1, 40, 9999, 1, 2, NULL, 264, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (133, '1997-04-03 22:00:00+00', '2018-04-03 00:07:30.401864+00', 'Ancient Glasgow''s Glory', 'ANCIENT GLASGOWS GLORY', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (151, '1997-08-28 22:00:00+00', '2012-01-20 12:56:01.359342+00', 'Angus And Fiona', 'ANGUS AND FIONA', 3, 96, 9999, 4, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (134, '1997-08-28 22:00:00+00', '2018-04-03 00:07:30.418554+00', 'Ancient Yew, The', 'ANCIENT YEW', 3, 32, 9999, 1, 3, 42, 108, '1987-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (172, '1997-04-03 22:00:00+00', '2012-01-20 12:56:01.548151+00', 'Anne Simpson of Perth', 'ANNE SIMPSON OF PERTH', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10334, '2002-02-11 23:00:00+00', '2015-03-03 22:28:56.121944+00', 'Ron Ramsay Reel, The', 'RON RAMSAY REEL', 1, 40, 9999, 1, 4, 1, 2913, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (138, '1997-04-03 22:00:00+00', '2018-04-03 00:07:30.443662+00', 'Andenne Jig, The', 'ANDENNE JIG', 2, 40, 9999, 1, 3, 42, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (142, '1998-01-05 23:00:00+00', '2018-04-03 00:07:30.485291+00', 'Andrew Arrived', 'ANDREW ARRIVED', 1, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (145, '1997-09-14 22:00:00+00', '2018-04-03 00:07:30.510337+00', 'Andrew''s Fancy', 'ANDREWS FANCY', 3, 32, 9999, 1, 3, 42, 629, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (147, '1997-04-03 22:00:00+00', '2018-04-03 00:07:30.526983+00', 'Andy Stewart''s Reel', 'ANDY STEWARTS REEL', 1, 40, 9999, 1, 3, 42, 39, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (149, '1997-08-31 22:00:00+00', '2018-04-03 00:07:30.568976+00', 'Angela''s Delight', 'ANGELAS DELIGHT', 2, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (165, '1997-04-03 22:00:00+00', '2018-04-03 00:07:30.702606+00', 'Anne', 'ANNE', 3, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (166, '1997-04-03 22:00:00+00', '2018-04-03 00:07:30.719289+00', 'Anne Elizabeth''s Fancy', 'ANNE ELIZABETHS FANCY', 2, 32, 9999, 1, 3, 42, 271, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (167, '1997-04-03 22:00:00+00', '2018-04-03 00:07:30.727655+00', 'Anne Eltham''s Fancy', 'ANNE ELTHAMS FANCY', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (156, '1997-08-28 22:00:00+00', '2018-04-03 00:07:30.869497+00', 'Ann Of Little Rock', 'ANN OF LITTLE ROCK', 3, 32, 9999, 1, 3, 42, 642, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (158, '1997-04-03 22:00:00+00', '2018-04-03 00:07:30.877795+00', 'Ann''s Joy', 'ANNS JOY', 3, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2658, '1998-01-05 23:00:00+00', '2018-04-03 00:07:49.749452+00', 'Green And White, The', 'GREEN AND WHITE', 1, 32, 9999, 1, 3, 42, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2662, '1997-04-03 22:00:00+00', '2018-04-03 00:07:49.950838+00', 'Green Jersey, The', 'GREEN JERSEY', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2663, '1997-04-03 22:00:00+00', '2018-04-03 00:07:49.974678+00', 'Green Lady Of Skipness Castle', 'GREEN LADY OF SKIPNESS CASTLE', 3, 32, 9999, 1, 3, 42, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10338, '2002-02-12 23:00:00+00', '2018-04-03 00:08:16.15242+00', 'Sheila''s Jig', 'SHEILAS JIG', 2, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2697, '1998-10-19 22:00:00+00', '2018-03-18 21:48:36.756075+00', 'Guid Tae See Ye', 'GUID TAE SEE YE', 1, 32, 9999, 1, 3, 42, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (176, '1997-04-03 22:00:00+00', '2018-04-03 00:07:30.777623+00', 'Anne''s Quest', 'ANNES QUEST', 3, 40, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2676, '1997-09-03 22:00:00+00', '2012-01-20 12:56:21.46502+00', 'Greenwich Park', 'GREENWICH PARK', 1, 32, 9999, 1, 2, NULL, 446, '1709-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2677, '1997-04-03 22:00:00+00', '2012-01-20 12:56:21.473854+00', 'Greenwood Reel, The', 'GREENWOOD REEL', 1, 32, 9999, 1, 4, NULL, 199, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18403, '2018-07-13 10:11:25.248412+00', '2018-07-13 10:11:25.248412+00', 'Pas-De-Basco', 'PASDEBASCO', 2, 32, NULL, 2, 3, NULL, 11664, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (192, '1997-04-03 22:00:00+00', '2018-12-16 16:42:28.427554+00', 'Another Piece of Silver', 'ANOTHER PIECE OF SILVER', 1, 32, 9999, 1, 3, 42, 146, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (168, '1997-09-02 22:00:00+00', '2020-07-01 03:33:23.498027+00', 'Anne Fraser McKenzie', 'ANNE FRASER MACKENZIE', 2, 40, 9999, 1, 3, 42, 270, NULL, '', 55, '480/880/848/884/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2668, '2003-03-21 23:00:00+00', '2021-01-18 23:25:18.107348+00', 'Kathy''s Jig', 'KATHYS JIG', 2, 40, 9999, 1, 3, 42, 2626, '2002-01-01', 'Dance devised for Kathy Stewart''s 60th Birthday.', 50, '804/840/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (177, '1997-04-03 22:00:00+00', '2020-08-29 11:47:40.033837+00', 'Annie Elizabeth Bruce', 'ANNIE ELIZABETH BRUCE', 1, 32, 9999, 1, 3, 42, 371, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2670, '1997-09-03 22:00:00+00', '2020-10-07 21:36:57.396236+00', 'Green Sleeves and Yellow Lace', 'GREEN SLEEVES AND YELLOW LACE', 2, 64, 9999, 1, 3, 42, 976, '1721-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10333, '2002-02-11 23:00:00+00', '2021-02-09 18:28:44.504261+00', 'Reel of the A68, The', 'REEL OF THE A68', 1, 40, 9999, 1, 4, 1, 1175, '1993-01-01', '', 57, '0008/8000/0880/8888/4888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (128, '1997-08-31 22:00:00+00', '2020-12-27 18:47:24.658265+00', 'An Cailin Dhu', 'CAILIN DHU', 3, 32, 9999, 4, 4, 13, 411, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (155, '1997-04-03 22:00:00+00', '2020-12-27 19:03:47.741467+00', 'Ann Nisbet''s Strathspey', 'ANN NISBETS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 62, NULL, '', 53, '888/800/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (141, '1997-04-03 22:00:00+00', '2021-03-03 16:13:13.708608+00', 'Andersons'' Awa''', 'ANDERSONS AWA', 3, 32, 9999, 2, 3, 17, 3586, NULL, '', 63, '822/880/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (137, '2002-03-03 23:00:00+00', '2021-07-04 11:29:38.246644+00', 'And They Lived Happily Ever After', 'AND THEY LIVED HAPPILY EVER AFTER', 3, 40, 9999, 1, 4, 1, 630, NULL, 'Devised "in honour of the 30th Wedding Anniversary of Alec and Margaret Macwaters, Ottawa Branch."', 46, '8000/8110/8404/8000/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (173, '1998-01-11 23:00:00+00', '2019-03-19 23:58:05.262601+00', 'Anne Smyth', 'ANNE SMYTH', 2, 40, 9999, 1, 4, 1, 149, NULL, '', 60, '8008/8888/6666/8008/8000', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2684, '1997-04-03 22:00:00+00', '2012-01-20 12:56:21.535129+00', 'Grey Buck, The', 'GREY BUCK', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2685, '1997-04-03 22:00:00+00', '2012-01-20 12:56:21.543805+00', 'Grey Cairns, The', 'GREY CAIRNS', 3, 32, 9999, 3, 5, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10371, '2002-03-07 23:00:00+00', '2012-01-20 12:57:20.754762+00', 'Dragon Dance, The', 'DRAGON DANCE', 3, 32, 9999, 1, 4, 1, 2994, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10372, '2002-03-07 23:00:00+00', '2012-01-20 12:57:20.764355+00', 'Finding Heather Fold', 'FINDING HEATHER FOLD', 2, 32, 9999, 1, 4, 1, 2995, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2690, '1997-09-03 22:00:00+00', '2019-09-15 19:14:08.227464+00', 'Grinder''s Hornpipe, The', 'GRINDERS HORNPIPE', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10374, '2002-03-07 23:00:00+00', '2012-01-20 12:57:20.782662+00', 'Highlandology', 'HIGHLANDOLOGY', 3, 40, 9999, 3, 5, 16, 2997, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10375, '2002-03-07 23:00:00+00', '2012-01-20 12:57:20.79225+00', 'Left-Handed Reel or Jig', 'LEFTHANDED REEL OR JIG', 1, 32, 9999, 2, 3, 17, 1133, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10377, '2002-03-07 23:00:00+00', '2012-01-20 12:57:20.810518+00', 'Milk River Jig, The', 'MILK RIVER JIG', 2, 64, 9999, 1, 4, 2, 2998, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (179, '1997-04-03 22:00:00+00', '2012-01-20 12:56:01.609051+00', 'Annie''s Well', 'ANNIES WELL', 2, 32, 9999, 1, 2, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (180, '2002-03-12 23:00:00+00', '2012-01-20 12:56:01.6177+00', 'Anniesland Cross', 'ANNIESLAND CROSS', 4, 80, 4, 1, 4, NULL, 111, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (181, '1998-01-05 23:00:00+00', '2012-01-20 12:56:01.626347+00', 'Bothy Night at Frimley Green', 'BOTHY NIGHT AT FRIMLEY GREEN', 1, 40, 9999, 1, 4, NULL, 329, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (182, '1997-08-28 22:00:00+00', '2012-01-20 12:56:01.635016+00', 'Anniversary Jig', 'ANNIVERSARY JIG', 2, 32, 9999, 1, 4, NULL, 638, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (187, '1997-09-12 22:00:00+00', '2012-01-20 12:56:01.678446+00', 'Anniversary Strathspey, The', 'ANNIVERSARY STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (191, '1997-08-31 22:00:00+00', '2012-01-20 12:56:01.713481+00', 'Another Kind Love', 'ANOTHER KIND LOVE', 2, 32, 9999, 1, 2, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (193, '1999-05-09 22:00:00+00', '2012-01-20 12:56:01.731597+00', 'Another SCD Wedding', 'ANOTHER SCD WEDDING', 3, 32, 9999, 1, 4, 2, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (194, '1998-01-05 23:00:00+00', '2012-01-20 12:56:01.740264+00', 'Anthony McLaren', 'ANTHONY MACLAREN', 1, 32, 9999, 1, 2, NULL, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (196, '1997-08-31 22:00:00+00', '2012-01-20 12:56:01.757563+00', 'Apley House', 'APLEY HOUSE', 1, 24, 9999, 1, 2, NULL, 446, '1702-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (199, '1997-09-22 22:00:00+00', '2012-01-20 12:56:01.784598+00', 'Appleringie', 'APPLERINGIE', 4, 128, 9999, 1, 4, NULL, 81, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (201, '1997-08-28 22:00:00+00', '2018-04-03 00:07:31.011574+00', 'Arascain Reel', 'ARASCAIN REEL', 1, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2691, '1997-10-21 22:00:00+00', '2012-01-20 12:56:21.596971+00', 'Grosvenor House Strathspey', 'GROSVENOR HOUSE STRATHSPEY', 3, 96, 9999, 4, 4, NULL, 1759, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2692, '1997-04-03 22:00:00+00', '2012-01-20 12:56:21.605643+00', 'Growling Old Woman, The', 'GROWLING OLD WOMAN', 2, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2694, '1997-09-03 22:00:00+00', '2012-01-20 12:56:21.623075+00', 'Guethary Reel, The', 'GUETHARY REEL', 1, 96, 9999, 4, 4, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10378, '2002-03-07 23:00:00+00', '2012-01-20 12:57:20.819337+00', 'Morning After, The', 'MORNING AFTER', 3, 32, 9999, 1, 4, NULL, 428, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2683, '1997-04-03 22:00:00+00', '2016-10-04 21:33:56.88549+00', 'Gretna Green Jig, The', 'GRETNA GREEN JIG', 2, 32, 9999, 1, 2, NULL, 212, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (200, '1998-01-04 23:00:00+00', '2016-11-10 23:11:35.818756+00', 'April In October', 'APRIL IN OCTOBER', 1, 32, 9999, 1, 3, 42, 90, '1979-10-25', 'This dance is for Carla and Daniel Clarke of Nashwaaksis, N.B. to celebrate the birth of their

daughter, April Phyllis, on October 25, 1979', 75, '888/888/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10373, '2002-03-07 23:00:00+00', '2018-04-03 00:07:48.256087+00', 'Gillespie Jig, The', 'GILLESPIE JIG', 2, 32, 9999, 1, 3, 42, 2996, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2672, '1997-04-03 22:00:00+00', '2018-04-03 00:07:50.016205+00', 'Green''s Hotel, The', 'GREENS HOTEL', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2678, '1997-04-03 22:00:00+00', '2018-04-03 00:07:50.049633+00', 'Greenwoodside', 'GREENWOODSIDE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2679, '1997-04-03 22:00:00+00', '2018-04-03 00:07:50.057966+00', 'Greeting Greta', 'GREETING GRETA', 3, 32, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2680, '2003-01-28 23:00:00+00', '2018-04-03 00:07:50.074578+00', 'Greeting, The', 'GREETING', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2689, '2003-01-25 23:00:00+00', '2018-04-03 00:07:50.141318+00', 'Grigarach Reel', 'GRIGARACH REEL', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2693, '2003-01-28 23:00:00+00', '2018-04-03 00:07:50.183023+00', 'Guess This''ll Do', 'GUESS THISLL DO', 2, 32, 9999, 1, 3, 42, 35, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2699, '1997-09-03 22:00:00+00', '2018-04-03 00:07:50.191344+00', 'Guide Patrol, The', 'GUIDE PATROL', 1, 32, 9999, 1, 3, 42, 109, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2696, '2002-02-28 23:00:00+00', '2018-04-03 00:07:50.249711+00', 'Guid Luck Go Wi'' Ye', 'GUID LUCK GO WI YE', 3, 32, 9999, 1, 3, 42, 406, '1975-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18404, '2018-07-13 10:12:10.953535+00', '2018-07-13 10:12:10.953535+00', 'Last Year''s Snow Was Falling', 'LAST YEARS SNOW WAS FALLING', 3, 32, NULL, 1, 3, NULL, 11664, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10386, '2002-03-11 23:00:00+00', '2018-11-08 14:32:09.559053+00', 'Rigmarole', 'RIGMAROLE', 3, 48, 9999, 4, 4, 1, 2605, '2002-01-01', 'There are instructions for this dance in strathspey message <<sspey:29886>>.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10387, '2002-04-24 22:00:00+00', '2018-11-08 18:25:58.404682+00', 'What''s Up?', 'WHATS UP', 3, 32, 9999, 1, 4, 1, 3035, '2002-01-01', '', 86, '8888/8888/8888/8000', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (207, '1997-04-03 22:00:00+00', '2012-01-20 12:56:01.854378+00', 'Archie Menzies', 'ARCHIE MENZIES', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19185, '2019-02-14 09:19:09.175613+00', '2019-02-22 23:16:54.130903+00', 'Bass Rock Strathspey, The', 'BASS ROCK STRATHSPEY', 3, 32, NULL, 2, 3, 17, 10902, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2883, '1999-04-14 22:00:00+00', '2019-03-16 12:36:14.099952+00', 'Herself', 'HERSELF', 3, 32, 9999, 4, 55, 30, 23, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (216, '1997-04-03 22:00:00+00', '2012-01-20 12:56:01.933895+00', 'Argyll Broadswords', 'ARGYLL BROADSWORDS', 7, 64, 9999, 1, 98, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (198, '1997-09-17 22:00:00+00', '2019-12-31 12:16:53.468329+00', 'Apple Tree, The', 'APPLE TREE', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', 76, '4888/4888/8660/8660/8888/0864', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (175, '1997-04-03 22:00:00+00', '2020-04-29 10:40:31.335349+00', 'Anne''s Dancing Duster', 'ANNES DANCING DUSTER', 1, 32, 9999, 1, 4, 1, 99, '1986-04-01', '', 81, '8888/8008/8888/4668', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18621, '2018-09-17 18:24:34.430206+00', '2020-11-19 19:14:52.920509+00', 'Lossie Lass', 'LOSSIE LASS', 1, 40, NULL, 1, 100, 2, 11708, '2007-10-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (174, '1997-08-28 22:00:00+00', '2020-12-27 19:16:32.733711+00', 'Anne Tufts'' Strathspey', 'ANNE TUFTS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 636, NULL, 'To Anne and Duncan on their Wedding Day', 84, '8888/8888/8048/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (197, '2002-02-26 23:00:00+00', '2020-12-27 19:20:21.367717+00', 'Apple Tree, The', 'APPLE TREE', 1, 32, 9999, 1, 100, 11, 108, '1988-01-01', '', 88, '8008/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2686, '1997-09-18 22:00:00+00', '2021-05-07 22:17:34.217087+00', 'Grey Daylight', 'GREY DAYLIGHT', 3, 32, 9999, 1, 2, 76, 392, '1962-01-01', '"Grey Daylight" is an alternative name for Stirling Castle (which is the tune for the dance).', 52, '84/84/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (217, '1997-09-12 22:00:00+00', '2012-01-20 12:56:01.942534+00', 'Argyll Gathering', 'ARGYLL GATHERING', 4, 64, 9999, 3, 5, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (225, '1998-10-08 22:00:00+00', '2012-01-20 12:56:02.012589+00', 'Ariel Eightsome, The', 'ARIEL EIGHTSOME', 4, 64, 9999, 4, 4, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (226, '1998-07-08 22:00:00+00', '2012-01-20 12:56:02.022949+00', 'Aries In Conjunction', 'ARIES IN CONJUNCTION', 1, 32, 9999, 1, 4, 5, 425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2703, '1998-07-08 22:00:00+00', '2012-01-20 12:56:21.705161+00', 'Gulf Of Coirebhreachain, The', 'GULF OF COIREBHREACHAIN', 1, 32, 9999, 1, 4, 2, 1, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (232, '1997-04-03 22:00:00+00', '2019-04-17 13:56:52.396156+00', 'Arniston Glen', 'ARNISTON GLEN', 3, 32, 9999, 1, 3, 42, 101, NULL, 'Dedicated to Ruth abd Archie Scott', -1, '660/888/660/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2710, '1997-04-03 22:00:00+00', '2012-01-20 12:56:21.769355+00', 'Gyrating Wheel', 'GYRATING WHEEL', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (210, '1997-04-03 22:00:00+00', '2019-10-17 22:35:40.945613+00', 'Ardbeg', 'ARDBEG', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', 56, '66/88/88/44', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10391, '2002-11-13 23:00:00+00', '2012-01-20 12:57:20.937925+00', 'Jigsaw', 'JIGSAW', 3, 32, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (204, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.019974+00', 'Archbishop Sharp''s Jig', 'ARCHBISHOP SHARPS JIG', 2, 48, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (236, '1998-01-12 23:00:00+00', '2012-01-20 12:56:02.10997+00', 'Aroon the Clachan of Dalry', 'AROON THE CLACHAN OF DALRY', 2, 32, 9999, 5, 2, NULL, 210, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (238, '1998-01-04 23:00:00+00', '2012-01-20 12:56:02.127608+00', 'Arrabri Reel', 'ARRABRI REEL', 1, 32, 9999, 1, 4, NULL, 653, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (239, '1997-08-28 22:00:00+00', '2012-01-20 12:56:02.136266+00', 'Arrabri Scramble', 'ARRABRI SCRAMBLE', 1, 32, 9999, 1, 4, NULL, 43, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (242, '1997-04-03 22:00:00+00', '2012-01-20 12:56:02.166128+00', 'Arran View', 'ARRAN VIEW', 3, 40, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (247, '1997-04-03 22:00:00+00', '2012-01-20 12:56:02.2129+00', 'As Time Will Serve Her', 'AS TIME WILL SERVE HER', 2, 64, 9999, 4, 4, NULL, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (209, '1997-04-03 22:00:00+00', '2022-07-17 09:54:55.392269+00', 'Ardailly Mill', 'ARDAILLY MILL', 1, 32, 9999, 5, 53, 4, 370, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2695, '1997-09-03 22:00:00+00', '2023-01-20 19:32:06.089508+00', 'Guid Freens', 'GUID FREENS', 1, 32, 9999, 1, 3, 42, 787, NULL, 'The notes say this is "Dedicated to Avril and David Quarrie, the Chicago Branch''s teachers, mentors, and friends."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2673, '1997-09-03 22:00:00+00', '2023-01-20 19:36:38.506559+00', 'Greenan Mill, The', 'GREENAN MILL', 1, 48, 9999, 1, 4, 1, 477, '1974-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (248, '1997-04-03 22:00:00+00', '2012-01-20 12:56:02.221609+00', 'Ascot Lady, The', 'ASCOT LADY', 3, 80, 9999, 4, 4, NULL, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (251, '1998-07-08 22:00:00+00', '2012-01-20 12:56:02.248556+00', 'Ashcroft', 'ASHCROFT', 2, 32, 9999, 1, 4, 2, 372, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10382, '2002-03-07 23:00:00+00', '2016-11-22 03:06:24.044093+00', 'Seann Truibhas for Four', 'SEANN TRUIBHAS FOR FOUR', 3, 32, 9999, 1, 4, 1, 3000, NULL, 'The correct Gaelic spelling is Triubhas.  For details see "Extra Info" for the dance Seann Triubhas Wikkichan".', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (206, '2001-11-18 23:00:00+00', '2018-04-03 00:07:31.061575+00', 'Archibald Minto', 'ARCHIBALD MINTO', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (208, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.070022+00', 'Archie Patterson', 'ARCHIE PATTERSON', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (211, '1998-01-05 23:00:00+00', '2018-04-03 00:07:31.078236+00', 'Ardbrae Reel, The', 'ARDBRAE REEL', 1, 48, 9999, 1, 3, 42, 649, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (227, '1998-01-05 23:00:00+00', '2018-04-03 00:07:31.145284+00', 'Arisaig Tushker, The', 'ARISAIG TUSHKER', 1, 32, 9999, 1, 3, 42, 176, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (234, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.187079+00', 'Arniston House', 'ARNISTON HOUSE', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (233, '2001-03-13 23:00:00+00', '2018-04-03 00:07:31.195334+00', 'Arniston House', 'ARNISTON HOUSE', 2, 32, 9999, 1, 3, 42, 401, '1989-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (244, '1997-09-17 22:00:00+00', '2018-04-03 00:07:31.253763+00', 'Arthur''s Fancy', 'ARTHURS FANCY', 2, 32, 9999, 1, 3, 42, 35, '1971-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2712, '1997-04-03 22:00:00+00', '2018-04-03 00:07:52.36782+00', 'H.M.S. Invincible', 'HMS INVINCIBLE', 1, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10379, '2002-03-07 23:00:00+00', '2018-04-03 00:08:07.79628+00', 'Nice an'' Aisy', 'NICE AN AISY', 2, 32, 9999, 1, 3, 42, 2999, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10383, '2002-03-07 23:00:00+00', '2018-04-03 00:08:19.004461+00', 'Summer Dancing in Ottawa', 'SUMMER DANCING IN OTTAWA', 3, 32, 9999, 1, 3, 42, 3005, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10385, '2002-03-07 23:00:00+00', '2018-04-03 00:08:25.341896+00', 'Whiskey-Jack, The', 'WHISKEYJACK', 1, 32, 9999, 1, 3, 42, 2999, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (252, '1998-10-19 22:00:00+00', '2012-01-20 12:56:02.257222+00', 'Ashhurst Gathering, The', 'ASHHURST GATHERING', 3, 32, 9999, 4, 4, NULL, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (253, '1997-04-03 22:00:00+00', '2012-01-20 12:56:02.266741+00', 'Ashley Terrace', 'ASHLEY TERRACE', 3, 40, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (254, '1997-08-28 22:00:00+00', '2012-01-20 12:56:02.275396+00', 'Ashra Autad', 'ASHRA AUTAD', 1, 88, 9999, 6, 98, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (256, '1997-10-27 23:00:00+00', '2012-01-20 12:56:02.292829+00', 'Aspen Bank', 'ASPEN BANK', 3, 32, 9999, 1, 4, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (259, '1997-04-03 22:00:00+00', '2012-01-20 12:56:02.318949+00', 'Aston Reel', 'ASTON REEL', 1, 32, 9999, 1, 4, NULL, 102, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18406, '2018-07-13 10:16:23.389472+00', '2018-07-13 10:16:23.389472+00', 'Finding the Way', 'FINDING THE WAY', 3, 48, NULL, 1, 4, NULL, 11487, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2721, '1997-11-24 23:00:00+00', '2012-01-20 12:56:21.864642+00', 'Hagg''s Castle', 'HAGGS CASTLE', 4, 48, 11, 4, 4, NULL, 270, NULL, '<<scddb:not-identical:2720>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2724, '1997-09-03 22:00:00+00', '2012-01-20 12:56:21.890844+00', 'Hague Silver Jubilee', 'HAGUE SILVER JUBILEE', 3, 32, 9999, 1, 4, NULL, 980, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2726, '1997-09-03 22:00:00+00', '2012-01-20 12:56:21.908613+00', 'Half A Loaf', 'HALF A LOAF', 3, 40, 9999, 1, 4, NULL, 981, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (286, '1997-04-03 22:00:00+00', '2018-04-02 23:56:32.87832+00', 'August Frost', 'AUGUST FROST', 3, 32, 9999, 1, 3, 42, 352, '1993-04-11', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10393, '2002-03-12 23:00:00+00', '2012-01-20 12:57:20.956852+00', 'Happier Meeting, The', 'HAPPIER MEETING', 1, 32, 9999, 5, 2, NULL, 49, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10394, '2005-04-27 22:00:00+00', '2012-01-20 12:57:20.967105+00', 'Nae Luck aboot the Hoose', 'NAE LUCK ABOOT THE HOOSE', 3, 32, 9999, NULL, NULL, NULL, 3578, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10396, '2002-03-13 23:00:00+00', '2012-01-20 12:57:20.988325+00', 'Palindrome, The', 'PALINDROME', 4, 128, 2, 4, 4, NULL, 550, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10384, '2002-03-07 23:00:00+00', '2020-02-01 22:09:27.678317+00', 'Taffy Strathspey, The', 'TAFFY STRATHSPEY', 3, 32, 9999, 1, 4, 1, 3033, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (276, '1998-01-05 23:00:00+00', '2020-08-02 11:47:13.363536+00', 'Auchencairn', 'AUCHENCAIRN', 1, 32, 9999, 1, 2, 76, 129, '1966-01-01', '', 56, '84/66/88/85', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2706, '1997-04-03 22:00:00+00', '2021-04-12 21:45:53.07677+00', 'Gunn''s Rant, The', 'GUNNS RANT', 1, 32, 9999, 1, 3, 42, 418, NULL, '', 34, '800/844/800/822', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (237, '1997-04-03 22:00:00+00', '2021-05-13 09:29:05.024257+00', 'Around The Corner', 'AROUND THE CORNER', 1, 32, 9999, 1, 3, 42, 352, '1993-01-23', '', 38, '800/844/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (235, '1998-04-04 22:00:00+00', '2021-07-04 10:45:57.765415+00', 'Arnold House Medley', 'ARNOLD HOUSE MEDLEY', 4, 32, 1, 1, 3, 42, 270, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (228, '2002-02-26 23:00:00+00', '2021-07-04 10:54:21.163172+00', 'Arkaig Jig', 'ARKAIG JIG', 2, 32, 9999, 1, 3, 42, 500, NULL, '', 63, '888/888/822/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (243, '1997-12-03 23:00:00+00', '2021-08-09 16:04:46.519528+00', 'Sixth of September', 'SIXTH OF SEPTEMBER', 2, 32, 9999, 1, 2, NULL, 1382, NULL, 'This dance is good for the first night of dancing. (T)', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2739, '1997-04-03 22:00:00+00', '2018-10-30 10:12:52.040147+00', 'Halloween', 'HALLOWEEN', 2, 40, 9999, 1, 3, 42, 270, NULL, '', 48, '800/833/833/888/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (258, '1997-08-28 22:00:00+00', '2018-04-03 00:07:31.30395+00', 'Aster, The', 'ASTER', 1, 32, 9999, 1, 3, 42, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (266, '1997-09-22 22:00:00+00', '2012-01-20 12:56:02.380017+00', 'Atherny Lodge', 'ATHERNY LODGE', 1, 64, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2718, '1997-04-03 22:00:00+00', '2019-02-04 18:33:43.004397+00', 'Hadrian''s Reel', 'HADRIANS REEL', 1, 32, 9999, 1, 4, 2, 212, NULL, '', 66, '6006/8888/8448/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (269, '1997-08-24 22:00:00+00', '2012-01-20 12:56:02.407867+00', 'Atholl Highlanders, The', 'ATHOLL HIGHLANDERS', 1, 32, 9999, 1, 4, 1, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (260, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.329003+00', 'At Buckie', 'AT BUCKIE', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (267, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.345759+00', 'Atholl Brose', 'ATHOLL BROSE', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18407, '2018-07-13 10:17:15.214824+00', '2019-04-25 08:15:36.16268+00', 'Club Harmony, The', 'CLUB HARMONY', 1, 48, NULL, 2, 3, 18, 11663, NULL, '', 83, '844/844/888/880/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2732, '1997-04-03 22:00:00+00', '2019-03-16 16:00:59.96403+00', 'Haliburton Welcome', 'HALIBURTON WELCOME', 2, 32, 9999, 1, 4, 1, 67, NULL, '', 56, '8000/8888/8220/8446', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (278, '2001-05-21 22:00:00+00', '2019-03-21 00:09:52.699815+00', 'Auchentoshen', 'AUCHENTOSHEN', 1, 40, 9999, 1, 4, 1, 539, '1977-01-01', '', 65, '8448/4884/8888/4444/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (272, '1997-08-28 22:00:00+00', '2018-04-03 00:07:31.354019+00', 'Atlanta Fair', 'ATLANTA FAIR', 2, 32, 9999, 1, 3, 42, 656, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2728, '1997-09-03 22:00:00+00', '2012-01-20 12:56:21.928642+00', 'Half O'' This And That', 'HALF O THIS AND THAT', 3, 32, 9999, 1, 4, NULL, 696, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2735, '1997-08-27 22:00:00+00', '2012-01-20 12:56:21.991968+00', 'Halley''s Comet', 'HALLEYS COMET', 1, 32, 9999, 4, 4, NULL, 584, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (319, '1997-04-03 22:00:00+00', '2016-07-15 13:19:04.922202+00', 'Avonda-Le', 'AVONDALE', 3, 24, 9999, 1, 4, 1, 352, '1993-07-22', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2737, '1997-09-03 22:00:00+00', '2016-11-02 23:45:20.162386+00', 'Hallowe''en Jig', 'HALLOWEEN JIG', 2, 32, 9999, 1, 3, 42, 983, NULL, '', 53, '844/844/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (263, '1997-09-03 22:00:00+00', '2018-04-03 00:07:31.395728+00', 'At The Fair', 'AT THE FAIR', 2, 32, 9999, 1, 3, 42, 2028, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2704, '1997-04-03 22:00:00+00', '2022-12-08 11:14:04.297181+00', 'Gumboot Rant, The', 'GUMBOOT RANT', 1, 32, 9999, 1, 3, 42, 35, NULL, '', 59, '822/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (270, '1997-04-03 22:00:00+00', '2022-12-18 22:36:12.157834+00', 'Atholl House', 'ATHOLL HOUSE', 3, 32, 9999, 1, 2, 76, 270, NULL, '', 52, '44/44/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2714, '1997-09-03 22:00:00+00', '2023-01-20 12:28:47.138265+00', 'Haar On The Hill, The', 'HAAR ON THE HILL', 2, 32, 9999, 1, 3, 42, 979, NULL, '', 73, '822/666/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2722, '1998-04-12 22:00:00+00', '2023-01-24 11:00:55.179392+00', 'Haggis Hunters, The', 'HAGGIS HUNTERS', 4, 128, 2, 4, 4, 3, 104, '1986-01-01', '', 88, '8888/8888/8080/0808/8888/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (277, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.412367+00', 'Auchendean', 'AUCHENDEAN', 3, 32, 9999, 1, 3, 42, 108, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (279, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.420774+00', 'Auchenvennel', 'AUCHENVENNEL', 2, 32, 9999, 1, 3, 42, 199, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (283, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.437507+00', 'Auckland Assembly', 'AUCKLAND ASSEMBLY', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (284, '1997-08-21 22:00:00+00', '2018-04-03 00:07:31.445887+00', 'Auckland Ladies'' Reel', 'AUCKLAND LADIES REEL', 3, 32, 9999, 1, 3, 42, 108, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (285, '1997-08-28 22:00:00+00', '2018-04-03 00:07:31.454346+00', 'Audrey Hinchcliffe''s Strathspey', 'AUDREY HINCHCLIFFES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (288, '1997-12-22 23:00:00+00', '2018-04-03 00:07:31.50431+00', 'Auld Alliance, The', 'AULD ALLIANCE', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10397, '2002-03-14 23:00:00+00', '2018-04-03 00:07:47.930707+00', 'Geneva Makes Three', 'GENEVA MAKES THREE', 3, 32, 9999, 1, 3, 42, 50, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2720, '1997-04-03 22:00:00+00', '2018-04-03 00:07:50.383173+00', 'Hagg''s Castle', 'HAGGS CASTLE', 3, 32, 9999, 1, 3, 42, 270, NULL, '<<scddb:not-identical:2721>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2729, '2003-01-26 23:00:00+00', '2018-04-03 00:07:50.433216+00', 'Half Turn', 'HALF TURN', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2731, '1997-04-03 22:00:00+00', '2018-04-03 00:07:50.449891+00', 'Haliburton Heatwave', 'HALIBURTON HEATWAVE', 3, 32, 9999, 1, 3, 42, 67, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2733, '2000-01-30 23:00:00+00', '2018-04-03 00:07:50.45825+00', 'Hall Of Memories', 'HALL OF MEMORIES', 3, 40, 9999, 1, 3, 42, 59, '1961-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2738, '1997-09-03 22:00:00+00', '2018-04-03 00:07:50.47497+00', 'Hallowed Halls of Saint Andrews, The', 'HALLOWED HALLS OF SAINT ANDREWS', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2740, '1997-09-03 22:00:00+00', '2018-04-03 00:07:50.499937+00', 'Halsway Manor', 'HALSWAY MANOR', 1, 32, 9999, 1, 3, 42, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10400, '2002-03-14 23:00:00+00', '2018-04-29 06:24:49.169757+00', 'Buchan Tensome Reel', 'BUCHAN TENSOME REEL', 1, 160, 9999, 102, 5, NULL, 50, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2741, '1997-09-03 22:00:00+00', '2019-09-13 22:38:25.631571+00', 'Hambleton''s Round', 'HAMBLETONS ROUND', 1, 32, 9999, 1, 3, 42, 446, '1710-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (265, '1998-01-07 23:00:00+00', '2012-02-22 23:49:05.27727+00', 'Athelstaneford Medley', 'ATHELSTANEFORD MEDLEY', 4, 32, 1, 1, 4, 2, 2027, '1988-01-01', 'The Saltire Flag flies all the year round in Athelstaneford, and I have tried to depict the shape of the flag in this dance.



Dance inscribed to Richard Ross who retired as Session Clerk from Athelstaneford Church after 40 years service in 1988.



', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (290, '1997-08-28 22:00:00+00', '2012-01-20 12:56:02.595273+00', 'Auld Claes And Parritch', 'AULD CLAES AND PARRITCH', 2, 40, 9999, 1, 4, NULL, 658, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (297, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.529378+00', 'Auld Inn, The', 'AULD INN', 2, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (293, '2002-03-12 23:00:00+00', '2012-01-20 12:56:02.622525+00', 'Auld Glesga Subway, The', 'AULD GLESGA SUBWAY', 1, 32, 9999, 1, 4, 1, 111, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (316, '1997-04-03 22:00:00+00', '2018-09-07 06:50:42.560296+00', 'Autumn Leaves', 'AUTUMN LEAVES', 3, 32, 9999, 1, 3, 42, 173, '1991-05-17', '', 63, '888/844/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (296, '2002-11-26 23:00:00+00', '2012-01-20 12:56:02.648559+00', 'Auld Hoose, The', 'AULD HOOSE', 2, 48, 9999, 2, 3, NULL, 108, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2743, '1997-11-27 23:00:00+00', '2019-03-16 15:57:53.819116+00', 'Hame O'' Mine', 'HAME O MINE', 4, 64, 5, 1, 4, 22, 2028, NULL, '', 75, '8484/4848/8888/8888/4848/4848/8080/8080', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (298, '1997-04-03 22:00:00+00', '2012-01-20 12:56:02.666034+00', 'Auld Jock', 'AULD JOCK', 3, 40, 9999, 1, 4, NULL, 222, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2730, '1997-04-03 22:00:00+00', '2020-08-06 14:53:35.20293+00', 'Halfway There', 'HALFWAY THERE', 1, 32, 9999, 1, 2, NULL, 151, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (295, '2000-10-13 22:00:00+00', '2020-09-23 09:10:27.881595+00', 'Auld Grey Cat, The', 'AULD GREY CAT', 1, 32, 9999, 1, 3, 42, 44, NULL, '', 44, '800/888/800/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10405, '2002-08-06 22:00:00+00', '2021-01-08 20:13:01.831152+00', 'Rio(tous) Reel', 'RIOTOUS REEL', 1, 32, 9999, 1, 4, 1, 534, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2736, '1997-04-03 22:00:00+00', '2021-06-01 11:04:19.401696+00', 'Hallowe''en', 'HALLOWEEN', 2, 32, 9999, 1, 2, 76, 28, NULL, '', 60, '88/88/80/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2734, '1997-09-03 22:00:00+00', '2021-06-01 11:20:15.087531+00', 'Hall Of The South', 'HALL OF THE SOUTH', 2, 32, 9999, 1, 2, 76, 697, NULL, '', 64, '57/88/88/88', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (281, '1997-04-03 22:00:00+00', '2021-06-19 20:54:57.204252+00', 'Auckland 1990', 'AUCKLAND 1990', 1, 40, 9999, 1, 4, 1, 352, '1990-07-08', '', 40, '8000/8440/8000/8404/4822', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (273, '1998-11-02 23:00:00+00', '2021-06-22 19:56:34.766717+00', 'Atlantic Crossing', 'ATLANTIC CROSSING', 2, 32, 9999, 3, 5, 20, 118, '1984-01-01', '', 65, '80808/80408/82428/84888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (287, '1997-04-03 22:00:00+00', '2014-03-30 20:53:42.107168+00', 'Auld Acquaintance', 'AULD ACQUAINTANCE', 3, 32, 9999, 1, 102, 11, 313, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2751, '1997-09-03 22:00:00+00', '2019-09-13 22:42:34.692796+00', 'Lady Amelia Murray''s Choice', 'LADY AMELIA MURRAYS CHOICE', 1, 48, 9999, 1, 3, 42, 984, '1785-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (305, '1997-09-23 22:00:00+00', '2012-01-20 12:56:02.727737+00', 'Auld Mistress Mackintosh', 'AULD MISTRESS MACKINTOSH', 2, 48, 9999, 5, 1, NULL, 108, '1983-01-01', '12 bar phrases', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (310, '1997-08-28 22:00:00+00', '2012-01-20 12:56:02.775046+00', 'Australia II', 'AUSTRALIA II', 1, 64, 9999, 1, 4, NULL, 660, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (311, '1997-08-28 22:00:00+00', '2012-01-20 12:56:02.783732+00', 'Australia: The Great South Land', 'AUSTRALIA THE GREAT SOUTH LAND', 3, 32, 9999, 1, 4, NULL, 661, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (317, '1997-08-28 22:00:00+00', '2012-01-20 12:56:02.842153+00', 'Autumn Wedding', 'AUTUMN WEDDING', 3, 40, 9999, 1, 4, NULL, 662, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2748, '1997-04-03 22:00:00+00', '2012-01-20 12:56:22.10537+00', 'Hamilton''s Reel', 'HAMILTONS REEL', 1, 32, 9999, 1, 2, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2750, '1997-09-03 22:00:00+00', '2012-01-20 12:56:22.123804+00', 'Hamilton''s Strathspey, The', 'HAMILTONS STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 389, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2754, '1997-12-03 23:00:00+00', '2012-01-20 12:56:22.16189+00', 'Heather''s Jig', 'HEATHERS JIG', 2, 32, 9999, 1, 4, NULL, 989, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2755, '1997-04-03 22:00:00+00', '2012-01-20 12:56:22.170602+00', 'Hamish''s Fancy', 'HAMISHS FANCY', 3, 32, 9999, 3, 5, NULL, 109, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (320, '1997-04-03 22:00:00+00', '2012-01-20 12:56:02.868224+00', 'Avondale Medley', 'AVONDALE MEDLEY', 4, 32, 9999, 1, 4, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (291, '1998-01-12 23:00:00+00', '2016-05-11 14:33:59.921434+00', 'Auld Davie McClemmet''s Fiddle', 'AULD DAVIE MACCLEMMETS FIDDLE', 2, 40, 9999, 103, 2, NULL, 210, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (318, '1997-04-03 22:00:00+00', '2016-10-04 21:28:22.77188+00', 'Aviemore Strathspey', 'AVIEMORE STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 212, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10402, '2002-08-06 22:00:00+00', '2017-05-16 21:04:33.593075+00', 'Arnside Knott', 'ARNSIDE KNOTT', 3, 32, 9999, 3, 5, 4, 534, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (302, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.562743+00', 'Auld Luckie', 'AULD LUCKIE', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (315, '1997-08-28 22:00:00+00', '2018-04-03 00:07:31.688094+00', 'Autumn in Lakeland', 'AUTUMN IN LAKELAND', 2, 32, 9999, 1, 3, 42, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (321, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.744068+00', 'Awa Tae Kinross', 'AWA TAE KINROSS', 3, 32, 9999, 1, 3, 42, 101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (325, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.754899+00', 'Awatiro Jig, The', 'AWATIRO JIG', 2, 32, 9999, 1, 3, 42, 411, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10399, '2002-03-14 23:00:00+00', '2018-04-03 00:07:41.483257+00', 'David''s Seven - O', 'DAVIDS SEVEN  O', 1, 32, 9999, 1, 3, 42, 50, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (262, '1998-04-04 22:00:00+00', '2022-07-30 16:43:42.569887+00', 'At the End of the Day', 'AT THE END OF THE DAY', 3, 32, 9999, 1, 3, 42, 44, '1992-01-01', '', 50, '800/888/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (307, '1997-10-27 23:00:00+00', '2022-11-06 10:59:56.385008+00', 'Auld Toon of Ayr, The', 'AULD TOON OF AYR', 3, 32, 9999, 1, 3, 42, 270, '1983-01-01', '', 50, '802/820/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (304, '1997-11-24 23:00:00+00', '2022-12-18 22:32:17.178263+00', 'Auld Luckie Scaup', 'AULD LUCKIE SCAUP', 4, 32, 1, 1, 4, 1, 270, NULL, '', 66, '8888/8000/8888/8500', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10401, '2002-03-14 23:00:00+00', '2023-01-05 22:24:42.678117+00', 'De''il Amang the Sailors', 'DEIL AMANG THE SAILORS', 4, 96, 56, 2, 3, NULL, 50, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10403, '2002-08-06 22:00:00+00', '2018-04-03 00:08:08.696971+00', 'Olwyn''s Reel', 'OLWYNS REEL', 1, 32, 9999, 1, 3, 42, 534, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2767, '1999-05-10 22:00:00+00', '2018-04-29 21:39:48.949649+00', 'Happy 40, Gail Cordy', 'HAPPY 40 GAIL CORDY', 2, 40, 9999, 1, 3, 42, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (331, '1997-04-03 22:00:00+00', '2012-01-20 12:56:02.970544+00', 'Aysgarth Place', 'AYSGARTH PLACE', 1, 32, 9999, 4, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (332, '1997-08-28 22:00:00+00', '2012-01-20 12:56:02.979191+00', 'Babbling Brook, The', 'BABBLING BROOK', 2, 32, 9999, 1, 2, NULL, 664, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (309, '1998-07-08 22:00:00+00', '2014-03-30 20:54:31.681725+00', 'Aurora Australis', 'AURORA AUSTRALIS', 2, 32, 9999, 1, 100, 2, 108, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (355, '1998-10-31 23:00:00+00', '2019-02-04 17:47:52.567911+00', 'Baldovan Strathspey', 'BALDOVAN STRATHSPEY', 3, 32, 9999, 1, 4, 1, 176, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (346, '1997-08-28 22:00:00+00', '2012-01-20 12:56:03.101933+00', 'Bairns, The', 'BAIRNS', 2, 24, 9999, 1, 4, NULL, 666, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (347, '1997-09-14 22:00:00+00', '2012-01-20 12:56:03.110615+00', 'Bal Na Luath', 'BAL NA LUATH', 1, 32, 9999, 4, 4, NULL, 670, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (336, '1997-04-03 22:00:00+00', '2019-08-23 23:31:10.405285+00', 'Back of Catterthin, The', 'BACK OF CATTERTHIN', 3, 32, 9999, 1, 4, 2, 270, NULL, '', 78, '8080/8888/8888/8228', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2766, '1998-07-08 22:00:00+00', '2012-01-20 12:56:22.270036+00', 'Hansel, The', 'HANSEL', 3, 32, 9999, 1, 4, 2, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (330, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.805062+00', 'Ayrshire Lass, An', 'AYRSHIRE LASS', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10411, '2002-03-24 23:00:00+00', '2020-12-07 12:43:02.962082+00', 'Destination Unknown', 'DESTINATION UNKNOWN', 10, 40, 9999, 99, 99, NULL, 3075, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (323, '1998-11-17 23:00:00+00', '2020-08-02 07:07:10.249067+00', 'Awa'' Tae The Fair', 'AWA TAE THE FAIR', 2, 128, 9999, 1, 4, NULL, 82, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (324, '1997-04-03 22:00:00+00', '2020-08-02 07:08:27.0809+00', 'Awa'', Whigs, Awa''', 'AWA WHIGS AWA', 1, 32, 9999, 1, 3, 42, 129, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2757, '1998-01-11 23:00:00+00', '2020-08-06 14:51:51.402559+00', 'Hand in Hand', 'HAND IN HAND', 4, 32, 1, 1, 4, NULL, 82, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (352, '1998-10-31 23:00:00+00', '2020-08-18 10:34:13.839055+00', 'Baldovan Jig', 'BALDOVAN JIG', 2, 32, 9999, 1, 4, 1, 176, NULL, '', 64, '8444 8880 8088 8222', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (294, '1997-09-17 22:00:00+00', '2020-08-24 22:58:12.015531+00', 'Auld Grey Cat, The', 'AULD GREY CAT', 1, 32, 9999, 1, 4, 1, 270, NULL, '', 83, '8008/8888/8888/4886', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10409, '2002-03-24 23:00:00+00', '2020-12-07 12:58:28.135349+00', 'Beaten Path, The', 'BEATEN PATH', 3, 32, 9999, 1, 2, 76, 1268, NULL, 'Published in 1995 by the RSCDS Twin Cities Branch in 20 Years 20 Dances.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2753, '1997-04-03 22:00:00+00', '2021-05-31 10:27:38.187683+00', 'Hamish Smith''s Reel', 'HAMISH SMITHS REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 63, '880/888/880/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10413, '2002-03-25 23:00:00+00', '2020-12-07 12:42:10.585214+00', 'Flowers of Shakopee, The', 'FLOWERS OF SHAKOPEE', 2, 32, 9999, 5, 2, NULL, 693, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10410, '2002-03-24 23:00:00+00', '2020-12-07 12:58:00.68198+00', 'Dance Thirty', 'DANCE THIRTY', 3, 32, 9999, 1, 3, 42, 3074, NULL, 'Published in 1995 by the RSCDS Twin Cities Branch in 20 Years 20 Dances.', 63, '888/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10417, '2002-03-25 23:00:00+00', '2020-12-07 13:01:16.662441+00', 'Midnight Cats, The', 'MIDNIGHT CATS', 1, 40, 9999, 1, 3, 42, 3077, '1995-01-01', '', 43, '800/822/888/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10414, '2002-03-25 23:00:00+00', '2020-12-07 13:02:20.309452+00', 'Garland, The', 'GARLAND', 2, 32, 9999, 1, 2, NULL, 693, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10408, '2002-03-24 23:00:00+00', '2020-12-07 13:04:02.5009+00', 'Baban, The', 'BABAN', 1, 32, 9999, 1, 3, 42, 2428, '1995-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10404, '2002-08-06 22:00:00+00', '2021-02-09 09:48:43.418156+00', 'Wee Jessie Cooper', 'WEE JESSIE COOPER', 2, 40, 9999, 1, 3, 42, 534, NULL, '10 bar phrases', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2742, '2002-04-19 22:00:00+00', '2021-06-01 11:02:30.730865+00', 'Hame came our Gudeman', 'HAME CAME OUR GUDEMAN', 3, 32, 9999, 1, 3, 42, 432, '1816-01-01', '', 56, '880/880/888/808', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (326, '1997-04-03 22:00:00+00', '2021-07-04 09:28:41.524455+00', 'Away to the Coast', 'AWAY TO THE COAST', 2, 32, 9999, 1, 3, 42, 48, NULL, 'Inscribed "for Maysie and Maurice Carnell on the occasion of their ruby wedding".', 56, '844/888/848/840', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (351, '1997-08-28 22:00:00+00', '2012-01-20 12:56:03.145356+00', 'Baldovan Fivesome, The', 'BALDOVAN FIVESOME', 1, 32, 9999, 3, 5, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (362, '1997-09-11 22:00:00+00', '2012-01-20 12:56:03.241118+00', 'Ballachulish Ferry, The', 'BALLACHULISH FERRY', 3, 32, 9999, 1, 4, NULL, 668, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (363, '1997-04-03 22:00:00+00', '2012-01-20 12:56:03.249803+00', 'Ballad Of Corrievreckan', 'BALLAD OF CORRIEVRECKAN', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (368, '1997-04-03 22:00:00+00', '2012-01-20 12:56:03.294281+00', 'Ballycopeland Windmill', 'BALLYCOPELAND WINDMILL', 1, 24, 9999, 4, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (369, '1998-07-08 22:00:00+00', '2012-01-20 12:56:03.303914+00', 'Ballynaree', 'BALLYNAREE', 3, 32, 9999, 3, 5, 16, 108, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (370, '2003-01-25 23:00:00+00', '2012-01-20 12:56:03.313534+00', 'Balmacara Strathspey', 'BALMACARA STRATHSPEY', 3, 48, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (361, '1997-04-03 22:00:00+00', '2016-05-19 23:08:52.791288+00', 'Balkan Hills', 'BALKAN HILLS', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2768, '1997-09-03 22:00:00+00', '2016-12-21 08:51:04.626292+00', 'Happy Christmas', 'HAPPY CHRISTMAS', 2, 32, 9999, 1, 3, 42, 620, NULL, '', 69, '888/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (341, '1997-08-24 22:00:00+00', '2018-04-03 00:07:31.896892+00', 'Bag of Wind, The', 'BAG OF WIND', 1, 32, 9999, 1, 3, 42, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (343, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.922011+00', 'Bailey''s Irish Cream', 'BAILEYS IRISH CREAM', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (344, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.930267+00', 'Bailie''s Jig', 'BAILIES JIG', 2, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (348, '2003-01-28 23:00:00+00', '2018-04-03 00:07:31.963629+00', 'Balboa Park', 'BALBOA PARK', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (349, '1997-09-23 22:00:00+00', '2018-04-03 00:07:31.972118+00', 'Balcomie House', 'BALCOMIE HOUSE', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (350, '1997-08-28 22:00:00+00', '2018-04-03 00:07:31.980372+00', 'Baldooser, The', 'BALDOOSER', 2, 32, 9999, 1, 3, 42, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (356, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.997135+00', 'Balevulin', 'BALEVULIN', 1, 40, 9999, 1, 3, 42, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2765, '1997-12-03 23:00:00+00', '2018-04-03 00:07:46.354552+00', 'Flying High', 'FLYING HIGH', 2, 40, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10415, '2002-03-25 23:00:00+00', '2018-04-03 00:07:50.600066+00', 'Hampden Park', 'HAMPDEN PARK', 2, 32, 9999, 1, 3, 42, 1268, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2756, '1997-09-03 22:00:00+00', '2018-04-03 00:07:50.616693+00', 'Hanchurch Hills', 'HANCHURCH HILLS', 1, 40, 9999, 1, 3, 42, 606, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2761, '1997-11-23 23:00:00+00', '2018-04-03 00:07:50.641795+00', 'Hands Across The Ocean', 'HANDS ACROSS THE OCEAN', 3, 40, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2763, '1998-04-12 22:00:00+00', '2018-04-03 00:07:50.650131+00', 'Hands Across The Sea', 'HANDS ACROSS THE SEA', 1, 32, 9999, 1, 3, 42, 352, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2759, '1997-10-19 22:00:00+00', '2018-04-03 00:07:50.675123+00', 'Hands Of Friendship, The', 'HANDS OF FRIENDSHIP', 3, 32, 9999, 1, 3, 42, 985, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (337, '2002-04-24 22:00:00+00', '2022-11-05 11:19:01.248039+00', 'Back O''The Change House', 'BACK OTHE CHANGE HOUSE', 3, 48, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (333, '1997-09-23 22:00:00+00', '2022-11-06 21:43:31.89808+00', 'Babes in the Wood', 'BABES IN THE WOOD', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (345, '1997-09-21 22:00:00+00', '2022-11-07 17:35:03.082006+00', 'Baillie of Canna', 'BAILLIE OF CANNA', 2, 32, 9999, 2, 3, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2749, '1998-07-08 22:00:00+00', '2023-01-20 12:21:06.327306+00', 'Hamilton''s Strathspey', 'HAMILTONS STRATHSPEY', 3, 32, 9999, 1, 100, 2, 108, '1976-01-01', 'John Drewry wrote in the original description that the dance was for Bill Hamilton of Slough.', 81, '8888/8008/8888/8448', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2764, '1997-04-03 22:00:00+00', '2018-04-03 00:07:50.683494+00', 'Hangleton Strathspey', 'HANGLETON STRATHSPEY', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10416, '2002-03-25 23:00:00+00', '2018-04-03 00:07:53.568786+00', 'In the Good Old Days', 'IN THE GOOD OLD DAYS', 1, 32, 9999, 1, 3, 42, 3076, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10418, '2002-03-25 23:00:00+00', '2018-04-03 00:08:07.393202+00', 'Ne''er the Twain Shall Meet', 'NEER THE TWAIN SHALL MEET', 3, 32, 9999, 1, 3, 42, 3076, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (357, '1997-12-28 23:00:00+00', '2018-04-03 00:08:24.391294+00', 'Wedding, The', 'WEDDING', 4, 32, 1, 1, 3, 42, 737, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (367, '1997-04-03 22:00:00+00', '2018-07-17 11:11:23.361462+00', 'Ballochmyle House', 'BALLOCHMYLE HOUSE', 2, 32, 9999, 1, 3, 42, 129, NULL, '', 49, '888/800/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (396, '1997-04-03 22:00:00+00', '2019-03-27 18:36:53.434129+00', 'Banks of the Devon, The', 'BANKS OF THE DEVON', 2, 32, 9999, 1, 3, 42, 129, NULL, '', 62, '800/880/888/822', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (398, '1997-04-03 22:00:00+00', '2019-03-19 22:42:48.647061+00', 'Bannetstane, The', 'BANNETSTANE', 2, 32, 9999, 1, 4, 1, 150, NULL, '', 91, '8888/8888/8840/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (376, '1997-04-03 22:00:00+00', '2012-01-20 12:56:03.370919+00', 'Balmullo House', 'BALMULLO HOUSE', 1, 48, 9999, 3, 5, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2771, '1997-09-03 22:00:00+00', '2012-01-20 12:56:22.313621+00', 'Happy Dancing', 'HAPPY DANCING', 1, 32, 9999, 5, 2, NULL, 70, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2772, '1997-09-03 22:00:00+00', '2012-01-20 12:56:22.322301+00', 'Happy Fiddler', 'HAPPY FIDDLER', 3, 32, 9999, 1, 2, NULL, 209, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2773, '1997-04-03 22:00:00+00', '2012-01-20 12:56:22.330947+00', 'Happy Go Lucky', 'HAPPY GO LUCKY', 2, 32, 9999, 3, 5, NULL, 329, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (385, '1997-04-03 22:00:00+00', '2019-03-19 22:55:24.324174+00', 'Bank Street Reel', 'BANK STREET REEL', 1, 32, 9999, 1, 4, 1, 353, NULL, '', 81, '8484/8888/8888/8080', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2776, '1997-09-03 22:00:00+00', '2012-01-20 12:56:22.356929+00', 'Happy Marriage, The', 'HAPPY MARRIAGE', 2, 32, 9999, 1, 2, NULL, 446, '1696-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (380, '2001-12-16 23:00:00+00', '2019-03-19 22:58:28.609962+00', 'Ban Righ Strathspey, The', 'BAN RIGH STRATHSPEY', 3, 40, 9999, 4, 4, 13, 394, '1985-01-01', '', 100, '8/8/8/8/8', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2779, '1997-09-03 22:00:00+00', '2012-01-20 12:56:22.383053+00', 'Happy Miller, The', 'HAPPY MILLER', 1, 40, 9999, 1, 4, NULL, 986, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2783, '1997-10-19 22:00:00+00', '2012-01-20 12:56:22.417826+00', 'Happy Valley', 'HAPPY VALLEY', 1, 32, 9999, 4, 4, NULL, 810, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (354, '1998-01-11 23:00:00+00', '2019-03-19 23:05:24.325759+00', 'Baldovan Square', 'BALDOVAN SQUARE', 3, 96, 9999, 4, 4, 3, 108, '1977-02-02', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2793, '1998-07-08 22:00:00+00', '2019-07-17 22:09:02.55243+00', 'Hares On The Mountain', 'HARES ON THE MOUNTAIN', 2, 32, 9999, 1, 100, 2, 13, NULL, '', 75, '8008/8888/8888/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (381, '1997-11-27 23:00:00+00', '2012-01-20 12:56:03.415392+00', 'Band of Gold', 'BAND OF GOLD', 4, 64, 5, 4, 4, NULL, 615, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (384, '1997-09-23 22:00:00+00', '2012-01-20 12:56:03.441447+00', 'Bangor Regatta', 'BANGOR REGATTA', 2, 48, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (388, '1997-04-03 22:00:00+00', '2012-01-20 12:56:03.477084+00', 'Bankhead', 'BANKHEAD', 1, 32, 9999, 1, 4, NULL, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (393, '1998-01-05 23:00:00+00', '2012-01-20 12:56:03.523409+00', 'Banks of Garry', 'BANKS OF GARRY', 1, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (372, '1997-08-28 22:00:00+00', '2018-04-03 00:07:32.030462+00', 'Balmoral Jig', 'BALMORAL JIG', 2, 48, 9999, 1, 3, 42, 669, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (404, '1997-04-03 22:00:00+00', '2012-01-20 12:56:03.62573+00', 'Banton Mill', 'BANTON MILL', 2, 32, 9999, 1, 98, NULL, 19, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (394, '1998-04-04 22:00:00+00', '2020-08-02 23:14:12.063744+00', 'Banks of Spey, The', 'BANKS OF SPEY', 3, 32, 9999, 1, 4, 1, 62, '1968-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (399, '1997-08-28 22:00:00+00', '2020-08-02 23:15:09.38604+00', 'Bannockburn Reel, The', 'BANNOCKBURN REEL', 1, 32, 9999, 1, 4, 1, 101, '1968-01-01', '', 68, '8888/8008/8044/8088', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (366, '1997-04-03 22:00:00+00', '2020-08-29 11:58:55.231327+00', 'Ballindalloch', 'BALLINDALLOCH', 3, 32, 9999, 1, 3, 42, 108, '1988-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14072, '2011-08-25 22:00:00+00', '2020-09-27 08:05:07.043018+00', 'St Chad''s Jig', 'SAINT CHADS JIG', 2, 32, NULL, 1, 4, 1, 2804, NULL, '', 75, '8888/8484/8800/4848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10341, '2002-02-12 23:00:00+00', '2021-02-09 18:19:28.303456+00', 'Sultan''s Signature, The', 'SULTANS SIGNATURE', 2, 48, 9999, 1, 4, 2, 108, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (359, '2002-04-24 22:00:00+00', '2021-07-03 14:12:32.582764+00', 'Roller Coaster, The', 'ROLLER COASTER', 2, 32, 9999, 1, 3, 42, 663, NULL, '', 63, '844/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (339, '1998-01-05 23:00:00+00', '2021-04-04 13:17:43.462422+00', 'Back to Basics', 'BACK TO BASICS', 1, 32, 9999, 1, 3, 42, 352, '1993-04-17', '', 56, '880/800/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (374, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.038903+00', 'Balmoral Tartan, The', 'BALMORAL TARTAN', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2788, '1997-09-03 22:00:00+00', '2012-01-20 12:56:22.462155+00', 'Harbour Cities Jig', 'HARBOUR CITIES JIG', 2, 32, 9999, 1, 4, NULL, 209, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2790, '1997-04-03 22:00:00+00', '2012-01-20 12:56:22.480349+00', 'Hardy Annual Jig, The', 'HARDY ANNUAL JIG', 2, 48, 9999, 1, 4, NULL, 329, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (405, '1997-04-03 22:00:00+00', '2016-05-19 23:09:52.273099+00', 'Bantry Lassies', 'BANTRY LASSIES', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (375, '1998-11-02 23:00:00+00', '2018-04-03 00:07:32.047173+00', 'Balmoral Terrace', 'BALMORAL TERRACE', 3, 32, 9999, 1, 3, 42, 394, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (379, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.063941+00', 'Bambooselum', 'BAMBOOSELUM', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (383, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.103214+00', 'Bangers and Beans', 'BANGERS AND BEANS', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (391, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.164122+00', 'Banks of Bogie, The', 'BANKS OF BOGIE', 1, 32, 9999, 1, 3, 42, 108, '1977-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (402, '1997-09-29 22:00:00+00', '2018-04-03 00:07:32.214189+00', 'Banshee, The', 'BANSHEE', 1, 48, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (403, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.222459+00', 'Bantam Rooster, The', 'BANTAM ROOSTER', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2774, '1997-04-03 22:00:00+00', '2018-04-03 00:07:50.77524+00', 'Happy Hostess, The', 'HAPPY HOSTESS', 1, 32, 9999, 1, 3, 42, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2778, '1997-04-03 22:00:00+00', '2018-04-03 00:07:50.791872+00', 'Happy Meetings', 'HAPPY MEETINGS', 3, 32, 9999, 1, 3, 42, 300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2784, '1997-04-03 22:00:00+00', '2018-04-03 00:07:50.833493+00', 'Happy Wanderers, The', 'HAPPY WANDERERS', 2, 32, 9999, 1, 3, 42, 204, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2785, '1997-04-03 22:00:00+00', '2018-04-03 00:07:50.850301+00', 'Happy We''ll Be', 'HAPPY WELL BE', 2, 32, 9999, 1, 3, 42, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2792, '1997-09-03 22:00:00+00', '2018-04-03 00:07:50.883634+00', 'Hare''s Maggot, The', 'HARES MAGGOT', 1, 36, 9999, 1, 3, 42, 446, '1709-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2795, '1997-09-03 22:00:00+00', '2018-04-03 00:07:50.900245+00', 'Harlequin Tartan', 'HARLEQUIN TARTAN', 1, 40, 9999, 1, 3, 42, 300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2796, '1997-04-03 22:00:00+00', '2018-04-03 00:07:50.908643+00', 'Harmonica, The', 'HARMONICA', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10342, '2002-02-13 23:00:00+00', '2018-04-03 00:08:13.975761+00', 'Roy of Olicana', 'ROY OF OLICANA', 3, 32, 9999, 1, 3, 42, 223, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10340, '2002-02-12 23:00:00+00', '2018-04-03 00:08:18.754458+00', 'Strathspey for Jane, A', 'STRATHSPEY FOR JANE', 3, 32, 9999, 1, 3, 42, 619, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2798, '1997-10-19 22:00:00+00', '2012-01-20 12:56:22.551032+00', 'Harpenden Ladies', 'HARPENDEN LADIES', 4, 128, 9999, 4, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10346, '2002-02-16 23:00:00+00', '2012-01-20 12:57:20.522968+00', '2-4-6-8', '2468', 1, 40, 9999, 1, 4, 2, 108, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10347, '2002-02-21 23:00:00+00', '2012-01-20 12:57:20.532677+00', 'Trip to Crieff', 'TRIP TO CRIEFF', 3, 32, 9999, 2, 3, 18, 2913, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (423, '1997-04-03 22:00:00+00', '2018-04-26 22:14:07.499087+00', 'Battle of the Shirts, The', 'BATTLE OF THE SHIRTS', 1, 32, 9999, 3, 5, 7, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2787, '1997-09-03 22:00:00+00', '2022-11-06 21:45:20.923138+00', 'Happy we''ve been a'' the gither', 'HAPPY WEVE BEEN A THE GITHER', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2791, '1997-04-03 22:00:00+00', '2022-11-07 16:41:25.128605+00', 'Hare Amang the Corn, The', 'HARE AMANG THE CORN', 2, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2802, '1997-04-03 22:00:00+00', '2018-04-29 10:47:46.28471+00', 'Hartz Reel, The', 'HARTZ REEL', 2, 32, 9999, 1, 3, 42, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (412, '1997-09-24 22:00:00+00', '2012-01-20 12:56:03.695269+00', 'Barmaid, The', 'BARMAID', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (419, '1997-08-28 22:00:00+00', '2012-01-20 12:56:03.756116+00', 'Bartlett Pair, The', 'BARTLETT PAIR', 4, 64, 9999, 4, 4, NULL, 675, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (447, '1997-08-28 22:00:00+00', '2019-03-19 22:32:25.42007+00', 'Beginner''s Luck', 'BEGINNERS LUCK', 2, 40, 9999, 1, 4, 1, 683, NULL, '', 40, '8000/4400/8080/4040/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (422, '1997-04-03 22:00:00+00', '2012-01-20 12:56:03.782276+00', 'Battle of the Boyne', 'BATTLE OF THE BOYNE', 1, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (425, '1997-09-11 22:00:00+00', '2012-01-20 12:56:03.810029+00', 'Battle Road', 'BATTLE ROAD', 1, 32, 9999, 1, 4, NULL, 679, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (429, '1997-08-28 22:00:00+00', '2012-01-20 12:56:03.844696+00', 'Bawdekyn', 'BAWDEKYN', 1, 32, 9999, 1, 4, NULL, 90, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1426, '1997-08-25 22:00:00+00', '2019-10-03 22:48:26.564434+00', 'Crom Allt', 'CROM ALLT', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 53, '888/840/844/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2800, '1997-04-03 22:00:00+00', '2012-01-20 12:56:22.568323+00', 'Harrow Park', 'HARROW PARK', 1, 48, 9999, 1, 4, NULL, 102, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2808, '1998-01-04 23:00:00+00', '2012-01-20 12:56:22.640465+00', 'Haste Ye Back', 'HASTE YE BACK', 1, 40, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2810, '1997-09-13 22:00:00+00', '2012-01-20 12:56:22.657765+00', 'Roundabouts', 'ROUNDABOUTS', 1, 32, 9999, 1, 4, NULL, 1083, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10354, '2002-02-21 23:00:00+00', '2012-05-01 21:42:16.304063+00', 'Strathspey for Cis Wood, A', 'STRATHSPEY FOR CIS WOOD', 3, 32, 9999, 4, 4, 1, 1359, '2000-05-01', 'Devised for the members of the Bathgate class', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10420, '2002-03-25 23:00:00+00', '2012-01-20 12:57:21.21537+00', 'Renaissance Fair', 'RENAISSANCE FAIR', 2, 32, 9999, 2, 3, NULL, 3078, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (437, '1997-09-14 22:00:00+00', '2012-01-20 12:56:03.916367+00', 'Beatles'' Reel', 'BEATLES REEL', 1, 32, 9999, 1, 4, NULL, 480, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (432, '1998-07-06 22:00:00+00', '2020-03-09 11:02:58.745367+00', 'Be Traist', 'BE TRAIST', 3, 48, 9999, 1, 4, 2, 270, NULL, '', 83, '8888/8888/8008/8888/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2775, '1997-04-03 22:00:00+00', '2020-12-24 09:11:36.31564+00', 'Happy House Martins, The', 'HAPPY HOUSE MARTINS', 2, 32, 9999, 1, 3, 42, 99, NULL, '', 69, '880/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (431, '1997-04-03 22:00:00+00', '2020-08-02 23:17:29.396677+00', 'Be Seeing You', 'BE SEEING YOU', 2, 32, 9999, 5, 2, 76, 151, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13560, '2010-01-19 23:00:00+00', '2020-09-19 11:29:46.805343+00', 'Fahyda', 'FAHYDA', 1, 32, NULL, 1, 3, 42, 347, NULL, '', 63, '888/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10345, '2002-10-20 22:00:00+00', '2021-02-09 17:26:53.046042+00', 'Go with the Rhythm', 'GO WITH THE RHYTHM', 2, 32, 9999, 1, 4, 2, 108, '2001-01-01', '', 84, '8888/8888/8228/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (411, '1997-04-03 22:00:00+00', '2021-02-17 23:22:58.188687+00', 'Barley Riggs', 'BARLEY RIGGS', 1, 32, 9999, 1, 2, NULL, 392, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10344, '2002-10-20 22:00:00+00', '2021-02-09 17:30:28.758915+00', 'Etta Gibson''s Strathspey', 'ETTA GIBSONS STRATHSPEY', 3, 40, 9999, 1, 3, 42, 108, '2001-01-01', '', 42, '880/800/822/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (414, '1998-01-04 23:00:00+00', '2021-04-17 11:14:49.99615+00', 'Barn Close', 'BARN CLOSE', 1, 48, 9999, 1, 4, 1, 673, '1987-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (400, '1999-08-06 22:00:00+00', '2021-07-03 12:18:11.193912+00', 'Bannocks and Brose', 'BANNOCKS AND BROSE', 2, 32, 9999, 1, 3, 42, 181, NULL, '', 56, '840/848/808/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (397, '1997-09-23 22:00:00+00', '2021-07-03 12:27:48.528809+00', 'Banner Bearer, The', 'BANNER BEARER', 1, 32, 9999, 1, 3, 42, 352, '1991-08-01', '"Dedicated to Eddy West, who carried the Scottish banner at the 1990 Commonwealth Games Opening Ceremony in Auckland."', 61, '860/888/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10350, '2002-02-21 23:00:00+00', '2014-05-10 16:38:19.882028+00', 'Tribute to Aberlemno, A', 'TRIBUTE TO ABERLEMNO', 2, 40, 9999, 2, 3, 18, 619, '1998-01-01', 'Inscribed to the Aberlemno Dance Class October 1998', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (406, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.230768+00', 'Barbara Bradley''s Jig', 'BARBARA BRADLEYS JIG', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (446, '1997-04-03 22:00:00+00', '2012-01-20 12:56:03.998625+00', 'Beginner''s Luck', 'BEGINNERS LUCK', 2, 32, 9999, 1, 2, NULL, 204, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (448, '1997-08-28 22:00:00+00', '2012-01-20 12:56:04.016136+00', 'Beginner''s Luck', 'BEGINNERS LUCK', 1, 48, 9999, 1, 2, NULL, 684, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (450, '1997-04-03 22:00:00+00', '2012-01-20 12:56:04.033609+00', 'Beinn Alligin', 'BEINN ALLIGIN', 1, 24, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2803, '1997-09-03 22:00:00+00', '2017-07-15 01:01:01.739973+00', 'Harvard Square, The', 'HARVARD SQUARE', 2, 160, 9999, 4, 4, NULL, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (408, '1997-08-28 22:00:00+00', '2018-04-03 00:07:32.247532+00', 'Barbara Rae', 'BARBARA RAE', 1, 28, 9999, 1, 3, 42, 672, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (409, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.347687+00', 'Bards of Old, The', 'BARDS OF OLD', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (415, '1997-08-28 22:00:00+00', '2018-04-03 00:07:32.381036+00', 'Barney Duffy''s Jig', 'BARNEY DUFFYS JIG', 2, 32, 9999, 1, 3, 42, 674, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (417, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.542107+00', 'Baron''s 8th Wife, The', 'BARONS 8TH WIFE', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (421, '1997-08-31 22:00:00+00', '2018-04-03 00:07:32.647873+00', 'Bath Carnival', 'BATH CARNIVAL', 2, 32, 9999, 1, 3, 42, 466, '1777-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (426, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.656228+00', 'Battle-Axe, The', 'BATTLEAXE', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (434, '1997-08-28 22:00:00+00', '2018-04-03 00:07:32.714481+00', 'Beadbonny Ash, The', 'BEADBONNY ASH', 2, 32, 9999, 1, 3, 42, 681, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (435, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.723018+00', 'Bear and the Bay Tree, The', 'BEAR AND THE BAY TREE', 1, 32, 9999, 1, 3, 42, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (436, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.73121+00', 'Bearsden Fiddler, The', 'BEARSDEN FIDDLER', 3, 32, 9999, 1, 3, 42, 417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (438, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.756314+00', 'Beau of Oakhill', 'BEAU OF OAKHILL', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (449, '1997-08-28 22:00:00+00', '2018-04-03 00:07:32.806544+00', 'Beginning, The', 'BEGINNING', 3, 32, 9999, 1, 3, 42, 684, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2804, '1997-09-03 22:00:00+00', '2018-04-03 00:07:51.048485+00', 'Harvest Home', 'HARVEST HOME', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2818, '1997-09-03 22:00:00+00', '2018-04-03 00:07:51.108734+00', 'Hawthorn Tree of Cawdor, The', 'HAWTHORN TREE OF CAWDOR', 3, 32, 9999, 1, 3, 42, 108, '1987-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10355, '2002-02-21 23:00:00+00', '2018-04-03 00:08:14.442951+00', 'Saint Andrew Forever', 'SAINT ANDREW FOREVER', 3, 32, 9999, 1, 3, 42, 515, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10349, '2002-02-16 23:00:00+00', '2018-04-03 00:08:24.7082+00', 'Welcome to Burns'' Nicht', 'WELCOME TO BURNS NICHT', 4, 64, 5, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10353, '2002-02-16 23:00:00+00', '2018-04-03 00:08:25.667514+00', 'Wicked Children', 'WICKED CHILDREN', 1, 32, 9999, 1, 3, 42, 2988, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (489, '1998-01-05 23:00:00+00', '2019-08-28 23:47:02.63803+00', 'Beth Wilson''s Delight', 'BETH WILSONS DELIGHT', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 69, '862/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (465, '1997-04-03 22:00:00+00', '2018-04-29 21:34:13.224961+00', 'Belle of the Dee, The', 'BELLE OF THE DEE', 2, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6956, '2002-04-19 22:00:00+00', '2018-08-27 20:42:14.103417+00', 'Wave Tossed Sands, The', 'WAVE TOSSED SANDS', 3, 32, 9999, 1, 3, 42, 44, NULL, '', 50, '880/800/888/844', 0, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (455, '1997-04-03 22:00:00+00', '2012-01-20 12:56:04.083441+00', 'Belfield, The', 'BELFIELD', 50, 32, 9999, 5, 1, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (401, '1998-10-18 22:00:00+00', '2022-08-11 13:38:31.28192+00', 'Bannocks o'' Barley', 'BANNOCKS O BARLEY', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 56, '800/844/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (416, '1998-10-18 22:00:00+00', '2022-11-06 21:44:01.574718+00', 'Barnyards O''Delgaty, The', 'BARNYARDS ODELGATY', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (418, '1997-04-03 22:00:00+00', '2022-11-07 17:35:23.140841+00', 'Barren Rocks of Aden', 'BARREN ROCKS OF ADEN', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (444, '1997-04-03 22:00:00+00', '2018-04-02 23:56:32.945177+00', 'Beehive, The', 'BEEHIVE', 4, 64, 5, 1, 3, 42, 108, '1983-01-01', '»If preferred, the dance may be done just as a Strathspey.« (JD)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (459, '2003-01-27 23:00:00+00', '2012-01-20 12:56:04.118431+00', 'Bell Boy Rant, The', 'BELL BOY RANT', 4, 32, 1, 1, 2, NULL, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2816, '2003-01-25 23:00:00+00', '2012-01-20 12:56:22.712829+00', 'Hawaiian Fling', 'HAWAIIAN FLING', 1, 32, 9999, 3, 5, 7, 35, '1979-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2819, '1997-04-03 22:00:00+00', '2012-01-20 12:56:22.739071+00', 'Hay''s Reel', 'HAYS REEL', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2824, '1997-09-03 22:00:00+00', '2012-01-20 12:56:22.782487+00', 'Hazeldean', 'HAZELDEAN', 3, 32, 9999, 2, 3, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10425, '2002-03-25 23:00:00+00', '2012-01-20 12:57:21.265263+00', 'Waltz and Be Welcome', 'WALTZ AND BE WELCOME', 5, 48, 9999, 5, 2, NULL, 693, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (476, '1997-04-03 22:00:00+00', '2019-08-24 09:18:41.684343+00', 'Benvie House', 'BENVIE HOUSE', 2, 40, 9999, 1, 3, 42, 270, NULL, '', 52, '800/880/851/808/815', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10427, '2002-04-02 22:00:00+00', '2012-01-20 12:57:21.283376+00', 'Alexandra Grace', 'ALEXANDRA GRACE', 3, 32, 9999, 1, 4, 1, 3083, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (482, '1997-04-03 22:00:00+00', '2019-08-25 20:49:39.398449+00', 'Berwickshire Volunteers, The', 'BERWICKSHIRE VOLUNTEERS', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 36, '800/888/800/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (457, '1997-08-22 22:00:00+00', '2019-08-29 20:44:19.372189+00', 'Belgian Folly', 'BELGIAN FOLLY', 2, 40, 9999, 1, 4, 1, 518, '1988-01-01', 'Devised for the wedding of Christine Archibald and Hugo Aerts (of Belgium) in December 1988.', 83, '8888/8888/4848/8888/8040', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (466, '1997-04-03 22:00:00+00', '2012-01-20 12:56:04.184528+00', 'Bells Of Ireland', 'BELLS OF IRELAND', 3, 32, 9999, 1, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (470, '1997-11-27 23:00:00+00', '2012-01-20 12:56:04.219317+00', 'Ben Ledi Medley, The', 'BEN LEDI MEDLEY', 4, 64, 17, 1, 4, NULL, 155, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2806, '1997-04-03 22:00:00+00', '2020-08-06 14:49:53.082772+00', 'Harvest Time', 'HARVEST TIME', 2, 32, 9999, 1, 3, 42, 62, '1962-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (479, '1997-08-28 22:00:00+00', '2020-04-13 08:58:31.443404+00', 'Bert McCroskie', 'BERT MACCROSKIE', 1, 32, 9999, 3, 5, 16, 270, NULL, '', 61, '82228/82428/82028/80888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (456, '1997-10-15 22:00:00+00', '2021-04-10 18:30:38.662065+00', 'Well-Hall', 'WELLHALL', 1, 32, 9999, 1, 2, NULL, 446, '1686-01-01', 'Originally entered in SCDDB with title "Belgia Retriev''d" and alias "Well-Hall" but these are now swapped as the latter is the preferred title.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (483, '1997-08-28 22:00:00+00', '2020-08-29 12:08:05.840393+00', 'Beryl''s Bouquet', 'BERYLS BOUQUET', 3, 64, 9999, 4, 4, 3, 687, NULL, '', 100, '8/8/8/8/8/8/8/8', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10351, '2002-02-16 23:00:00+00', '2021-02-09 12:43:57.323898+00', 'Shortbread Fingers', 'SHORTBREAD FINGERS', 3, 32, 9999, 2, 3, 17, 553, NULL, '', 92, '888/888/888/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10424, '2002-03-25 23:00:00+00', '2021-02-10 10:06:33.055814+00', 'Twin Cities Farewell', 'TWIN CITIES FAREWELL', 3, 32, 9999, 1, 4, 2, 3078, '1988-01-01', '', 72, '8008/8448/8888/8228', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (474, '1997-08-28 22:00:00+00', '2021-07-02 14:00:37.257687+00', 'Benarty Bishop', 'BENARTY BISHOP', 1, 32, 9999, 1, 2, 76, 686, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (440, '1997-09-24 22:00:00+00', '2021-07-03 11:48:40.59193+00', 'Beauty of the North, The', 'BEAUTY OF THE NORTH', 3, 32, 9999, 1, 3, 42, 44, NULL, '', 41, '800/888/800/822', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (439, '1997-08-25 22:00:00+00', '2021-07-03 11:56:02.280745+00', 'Beauty of the North, The', 'BEAUTY OF THE NORTH', 3, 32, 9999, 1, 3, 42, 108, '1981-01-01', '', 59, '606/888/888/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (477, '1997-04-03 22:00:00+00', '2012-01-20 12:56:04.281024+00', 'Berkeley Rant, The', 'BERKELEY RANT', 1, 28, 9999, 1, 4, NULL, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (478, '1997-04-03 22:00:00+00', '2012-01-20 12:56:04.289681+00', 'Berry Picking', 'BERRY PICKING', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (481, '1997-04-03 22:00:00+00', '2012-01-20 12:56:04.315671+00', 'Berwickshire Round Reel', 'BERWICKSHIRE ROUND REEL', 1, 64, 9999, 4, 4, NULL, 146, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (487, '1997-04-03 22:00:00+00', '2012-01-20 12:56:04.367918+00', 'Best Foot Forward', 'BEST FOOT FORWARD', 3, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10423, '2002-03-25 23:00:00+00', '2014-10-07 15:16:51.041581+00', 'Squashed in the Kitchen With Bonny', 'SQUASHED IN THE KITCHEN WITH BONNY', 1, 32, 9999, 1, 2, NULL, 3081, '1993-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (490, '1997-09-12 22:00:00+00', '2012-01-20 12:56:04.394952+00', 'Beth''s Wedding', 'BETHS WEDDING', 3, 40, 9999, 1, 4, NULL, 318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2831, '1997-04-03 22:00:00+00', '2016-05-29 20:38:49.465413+00', 'Heart to Heart', 'HEART TO HEART', 3, 32, 9999, 1, 4, 1, 382, '1993-02-01', '', 94, '8888/8888/8888/0888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (460, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.848177+00', 'Belladrum''s Strathspey', 'BELLADRUMS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (468, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.940043+00', 'Belvoir Castle', 'BELVOIR CASTLE', 3, 32, 9999, 1, 3, 42, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (469, '1997-04-03 22:00:00+00', '2018-04-03 00:07:32.973481+00', 'Ben Bhreagh', 'BEN BHREAGH', 2, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (486, '1997-04-03 22:00:00+00', '2018-04-03 00:07:33.106916+00', 'Best Foot Forward', 'BEST FOOT FORWARD', 2, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2817, '1997-09-03 22:00:00+00', '2018-04-03 00:07:51.100426+00', 'Hawthorn Hill', 'HAWTHORN HILL', 1, 40, 9999, 1, 3, 42, 657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2829, '1997-09-03 22:00:00+00', '2018-04-03 00:07:51.158794+00', 'Heart For All, A', 'HEART FOR ALL', 2, 32, 9999, 1, 3, 42, 990, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10421, '2002-03-25 23:00:00+00', '2018-04-03 00:08:14.384604+00', 'Sailing Bonny Bayfield', 'SAILING BONNY BAYFIELD', 3, 32, 9999, 1, 3, 42, 2707, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10422, '2002-03-25 23:00:00+00', '2018-04-03 00:08:18.120601+00', 'Sprightly Stepping Scots', 'SPRIGHTLY STEPPING SCOTS', 2, 40, 9999, 1, 3, 42, 3079, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10426, '2002-03-25 23:00:00+00', '2018-04-03 00:08:26.67531+00', 'Wisconsin Journey', 'WISCONSIN JOURNEY', 2, 32, 9999, 1, 3, 42, 3080, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (509, '1997-04-03 22:00:00+00', '2018-04-29 21:17:39.44597+00', 'Bill and Evelyn', 'BILL AND EVELYN', 3, 40, 9999, 1, 3, 42, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2838, '2002-03-03 23:00:00+00', '2012-01-20 12:56:22.906797+00', 'Heather Mixture Jig', 'HEATHER MIXTURE JIG', 2, 32, 9999, 5, 2, NULL, 52, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3764, '1997-04-03 22:00:00+00', '2012-01-20 12:56:30.586805+00', 'Leapfrog', 'LEAPFROG', 2, 32, 9999, 5, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10429, '2002-04-02 22:00:00+00', '2012-01-20 12:57:21.301609+00', 'Balthayock House', 'BALTHAYOCK HOUSE', 2, 48, 9999, 3, 5, 7, 3085, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10430, '2002-04-02 22:00:00+00', '2012-01-20 12:57:21.311105+00', 'Belted Plaid, The', 'BELTED PLAID', 3, 32, 9999, 1, 4, 2, 3084, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (492, '1997-04-03 22:00:00+00', '2012-01-20 12:56:04.412495+00', 'Betty Paton', 'BETTY PATON', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (494, '1997-04-03 22:00:00+00', '2012-01-20 12:56:04.429842+00', 'Betty''s Delight', 'BETTYS DELIGHT', 2, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (493, '1997-04-03 22:00:00+00', '2018-04-03 00:07:33.173767+00', 'Betty Richmond''s Fancy', 'BETTY RICHMONDS FANCY', 1, 32, 9999, 1, 3, 42, 247, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18686, '2018-10-02 08:14:39.407661+00', '2018-10-02 08:14:39.407661+00', 'Breakers on the Shore', 'BREAKERS ON THE SHORE', 3, 32, NULL, 1, 3, 42, 2766, '2015-09-01', 'This dance occurred as I tried to envision a 3-couples poussette. It isn’t that, but the figures remind me of waves on the shore.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (473, '1998-07-08 22:00:00+00', '2022-08-18 09:41:00.725908+00', 'Ben Wyvis', 'BEN WYVIS', 3, 32, 9999, 1, 100, 2, 313, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2839, '1997-09-03 22:00:00+00', '2022-11-06 21:45:41.695275+00', 'Heather on the Hill, The', 'HEATHER ON THE HILL', 3, 48, 9999, 3, 5, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2823, '1997-04-03 22:00:00+00', '2023-01-28 13:42:52.315147+00', 'Hazelbank', 'HAZELBANK', 3, 40, 9999, 1, 4, 1, 108, '1967-01-01', '"To Mrs. Allan (Nan Main), of Aberdeen."', 83, '8686/8888/8008/8888/8484', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (461, '1998-07-08 22:00:00+00', '2023-01-17 11:49:49.376749+00', 'Bellanoch Bridge', 'BELLANOCH BRIDGE', 3, 32, 9999, 1, 4, 2, 602, NULL, 'Deviser states: "Suitable recording: Blue Mess Jacket".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (499, '1997-08-28 22:00:00+00', '2012-01-20 12:56:04.474285+00', 'Bicycle Reel, The', 'BICYCLE REEL', 1, 32, 9999, 1, 4, NULL, 688, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (500, '1998-01-05 23:00:00+00', '2012-01-20 12:56:04.483007+00', 'Biddy of the Buller', 'BIDDY OF THE BULLER', 1, 32, 9999, 1, 2, NULL, 108, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (505, '1997-08-26 22:00:00+00', '2012-01-20 12:56:04.579598+00', 'White Lady, The', 'WHITE LADY', 2, 32, 9999, 1, 4, NULL, 108, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (506, '2002-04-19 22:00:00+00', '2012-01-20 12:56:04.588478+00', 'Big Law Burn, The', 'BIG LAW BURN', 3, 32, 9999, 1, 4, NULL, 689, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (511, '1997-08-28 22:00:00+00', '2012-01-20 12:56:04.632279+00', 'Bill King', 'BILL KING', 2, 32, 9999, 1, 2, NULL, 353, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (512, '1997-09-24 22:00:00+00', '2012-01-20 12:56:04.641112+00', 'Bill Pimm', 'BILL PIMM', 2, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (516, '1997-08-28 22:00:00+00', '2012-01-20 12:56:04.676053+00', 'Bird Table, The', 'BIRD TABLE', 3, 32, 9999, 1, 2, NULL, 694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (517, '2002-03-12 23:00:00+00', '2012-01-20 12:56:04.685688+00', 'Birken-Shaw, The', 'BIRKENSHAW', 3, 32, 9999, 1, 4, 1, 111, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (464, '1998-01-05 23:00:00+00', '2019-12-19 20:21:13.993825+00', 'Belle of the Ball, The', 'BELLE OF THE BALL', 1, 32, 9999, 1, 3, 42, 44, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2827, '1997-04-03 22:00:00+00', '2020-05-14 22:50:31.780359+00', 'HE-HO-Hiram', 'HEHOHIRAM', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (443, '2002-04-19 22:00:00+00', '2021-07-02 14:07:16.327483+00', 'Bee''s Wing, The', 'BEES WING', 1, 32, 9999, 1, 3, 42, 682, NULL, '', 50, '822/844/844/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2849, '1997-09-06 22:00:00+00', '2020-08-06 14:48:35.883342+00', 'Heights Of Alma, The', 'HEIGHTS OF ALMA', 1, 32, 9999, 1, 2, 76, 129, '1968-01-01', '', 58, '66/66/77/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (467, '1997-08-28 22:00:00+00', '2020-08-07 22:18:19.820319+00', 'Beltane, The', 'BELTANE', 1, 32, 9999, 1, 3, 42, 94, NULL, '', 63, '822/866/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (484, '1997-04-03 22:00:00+00', '2020-08-14 21:01:21.747262+00', 'Bessie & Laurie Kemp', 'BESSIE AND LAURIE KEMP', 2, 40, 9999, 3, 5, 16, 372, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (452, '1997-12-27 23:00:00+00', '2020-08-29 12:05:43.887177+00', 'Belden Reel, The', 'BELDEN REEL', 1, 32, 9999, 1, 3, 42, 361, NULL, '', 50, '880/800/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (491, '1997-08-28 22:00:00+00', '2021-04-18 20:34:33.452148+00', 'Bett Nairn''s Strathspey', 'BETT NAIRNS STRATHSPEY', 3, 48, 9999, 2, 3, 17, 304, '1986-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3767, '1998-11-15 23:00:00+00', '2021-05-15 18:46:47.523487+00', 'Left Handed Tushker, The', 'LEFT HANDED TUSHKER', 1, 32, 9999, 5, 56, 76, 44, '1983-01-01', 'The notes to the dance explain that a ''tushker'' is the tool used in the Shetlands to cast peat.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2821, '1998-09-29 22:00:00+00', '2021-05-31 10:06:51.025319+00', 'Haymaking', 'HAYMAKING', 1, 40, 9999, 1, 3, 42, 9998, NULL, '', 43, '850/880/800/822/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3768, '1997-04-03 22:00:00+00', '2021-06-16 23:52:10.53855+00', 'Leg of a Duck, The', 'LEG OF A DUCK', 2, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (519, '1997-11-25 23:00:00+00', '2021-07-02 12:08:09.296913+00', 'Birkie Lads, The', 'BIRKIE LADS', 4, 64, 5, 1, 2, 76, 82, NULL, 'The notes say 3rd & 4th couples should start at the same time as 1st & 2nd couples.', 58, '66/66/88/77', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (520, '1997-08-28 22:00:00+00', '2012-01-20 12:56:04.712472+00', 'Birkmyre Park', 'BIRKMYRE PARK', 3, 32, 9999, 1, 2, NULL, 644, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (524, '1997-08-28 22:00:00+00', '2012-01-20 12:56:04.74798+00', 'Birnie Brig, The', 'BIRNIE BRIG', 1, 64, 9999, 4, 4, NULL, 601, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (525, '1997-08-28 22:00:00+00', '2012-01-20 12:56:04.756746+00', 'Birthday Cake', 'BIRTHDAY CAKE', 1, 64, 9999, 4, 4, NULL, 488, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2847, '1997-10-07 22:00:00+00', '2012-01-20 12:56:22.985478+00', 'Hector''s Delight', 'HECTORS DELIGHT', 3, 32, 9999, 1, 98, NULL, 138, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (496, '1997-04-03 22:00:00+00', '2018-04-03 00:07:33.198802+00', 'Betty''s Ramble', 'BETTYS RAMBLE', 1, 32, 9999, 1, 3, 42, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (526, '1997-04-03 22:00:00+00', '2012-01-20 12:56:04.765425+00', 'Birthday Promenade', 'BIRTHDAY PROMENADE', 2, 16, 9999, 5, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (528, '1997-04-03 22:00:00+00', '2012-01-20 12:56:04.78444+00', 'Bit of Fluff, A', 'BIT OF FLUFF', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (507, '1997-08-28 22:00:00+00', '2018-04-03 00:07:33.323902+00', 'Big Man Wi'' The Twinkle In His', 'BIG MAN WI THE TWINKLE IN HIS', 2, 32, 9999, 1, 3, 42, 690, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (514, '1997-04-03 22:00:00+00', '2018-04-03 00:07:33.35749+00', 'Billie''s Bawbee', 'BILLIES BAWBEE', 3, 32, 9999, 1, 3, 42, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (515, '1997-04-03 22:00:00+00', '2018-04-03 00:07:33.40752+00', 'Bird of Paradise Reel', 'BIRD OF PARADISE REEL', 1, 32, 9999, 1, 3, 42, 419, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (527, '1997-08-31 22:00:00+00', '2018-04-03 00:07:33.490994+00', 'Bishop, The', 'BISHOP', 2, 32, 9999, 1, 3, 42, 466, '1778-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10432, '2002-04-04 22:00:00+00', '2018-04-03 00:07:37.604158+00', 'Celebration Reel', 'CELEBRATION REEL', 1, 40, 9999, 1, 3, 42, 3084, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2837, '1998-01-04 23:00:00+00', '2018-04-03 00:07:51.226361+00', 'Heather In Bloom', 'HEATHER IN BLOOM', 1, 32, 9999, 1, 3, 42, 838, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2844, '1997-09-03 22:00:00+00', '2018-04-03 00:07:51.540346+00', 'Heather''s Strathspey', 'HEATHERS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 606, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2841, '1997-04-03 22:00:00+00', '2018-04-03 00:07:51.550626+00', 'Heather Strathspey, The', 'HEATHER STRATHSPEY', 3, 32, 9999, 1, 3, 42, 250, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2843, '1998-03-05 23:00:00+00', '2018-04-03 00:07:51.558973+00', 'Heather Tree, The', 'HEATHER TREE', 2, 32, 9999, 1, 3, 42, 159, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2845, '1997-04-03 22:00:00+00', '2018-04-03 00:07:51.584145+00', 'Hebridean Reel, The', 'HEBRIDEAN REEL', 4, 96, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10436, '2002-03-26 23:00:00+00', '2018-04-03 00:07:57.113069+00', 'Keltic Lodge, The', 'KELTIC LODGE', 2, 32, 9999, 1, 3, 42, 3086, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (531, '1998-01-05 23:00:00+00', '2012-01-20 12:56:04.810887+00', 'Black Baron, The', 'BLACK BARON', 1, 48, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (536, '1997-04-03 22:00:00+00', '2012-01-20 12:56:04.85566+00', 'Black Boy', 'BLACK BOY', 1, 32, 9999, 5, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (537, '2002-03-02 23:00:00+00', '2012-01-20 12:56:04.864337+00', 'Black Cat, The', 'BLACK CAT', 2, 32, 9999, 1, 2, NULL, 108, '1975-02-02', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (539, '1997-08-24 22:00:00+00', '2012-01-20 12:56:04.883132+00', 'Black Coolins of Skye, The', 'BLACK COOLINS OF SKYE', 3, 32, 9999, 1, 4, 2, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (552, '1998-07-08 22:00:00+00', '2012-01-20 12:56:05.004109+00', 'Black Rock, The', 'BLACK ROCK', 1, 32, 9999, 8, 6, 12, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (553, '1997-08-28 22:00:00+00', '2012-01-20 12:56:05.013019+00', 'Black Snuff Mill', 'BLACK SNUFF MILL', 1, 64, 9999, 4, 4, NULL, 699, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2856, '1997-04-03 22:00:00+00', '2012-01-20 12:56:23.068909+00', 'Helen''s Wedding', 'HELENS WEDDING', 3, 40, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2860, '1998-07-08 22:00:00+00', '2012-01-20 12:56:23.105236+00', 'Hen''s March Over the Midden, The', 'HENS MARCH OVER THE MIDDEN', 1, 32, 9999, 1, 4, 2, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2862, '1997-09-03 22:00:00+00', '2012-01-20 12:56:23.123626+00', 'Henderson Strathspey, The', 'HENDERSON STRATHSPEY', 3, 32, 9999, 2, 3, 18, 964, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2864, '1997-12-16 23:00:00+00', '2012-01-20 12:56:23.140992+00', 'Hendersons Of Ardbrae, The', 'HENDERSONS OF ARDBRAE', 3, 112, 9999, 4, 4, NULL, 994, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10437, '2002-10-15 22:00:00+00', '2012-01-20 12:57:21.371939+00', 'Celtic Square', 'CELTIC SQUARE', 4, 128, 2, 4, 4, NULL, 74, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10440, '2002-03-27 23:00:00+00', '2012-01-20 12:57:21.399152+00', 'Rebecca''s Rant', 'REBECCAS RANT', 1, 32, 9999, 1, 4, NULL, 3087, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19206, '2019-03-02 10:19:54.362995+00', '2019-04-15 12:15:18.054909+00', 'Mackintosh Alone', 'MACKINTOSH ALONE', 3, 32, NULL, 2, 3, NULL, 3165, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2858, '1999-05-10 22:00:00+00', '2022-02-25 18:50:53.402405+00', 'Helpful Jig, The', 'HELPFUL JIG', 2, 32, 9999, 1, 2, NULL, 2604, '1993-04-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (508, '1997-08-28 22:00:00+00', '2022-08-18 19:38:30.146596+00', 'Big Orange, The', 'BIG ORANGE', 1, 64, 9999, 1, 4, 5, 691, '1990-01-01', 'The "Big Orange" is a nickname for the greater Los Angeles area.', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (503, '1997-04-03 22:00:00+00', '2023-01-26 19:08:51.712045+00', 'Big Corral, The', 'BIG CORRAL', 1, 48, 9999, 4, 54, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10443, '2002-03-27 23:00:00+00', '2012-01-20 12:57:21.42514+00', 'Saint Augustine''s Strathspey', 'SAINT AUGUSTINES STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 3087, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2857, '1997-04-03 22:00:00+00', '2012-06-30 15:42:40.108123+00', 'Helensville Dominie, The', 'HELENSVILLE DOMINIE', 3, 32, 9999, 1, 3, 42, 411, '1992-01-01', 'For my uncle Peter West, former tutor of the Helensville SCD Club', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (544, '1997-11-27 23:00:00+00', '2019-04-20 23:45:30.412763+00', 'Black Horse Medley', 'BLACK HORSE MEDLEY', 4, 64, 5, 1, 4, 3, 697, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (566, '1997-08-28 22:00:00+00', '2019-05-26 08:59:59.564018+00', 'Blanket Preacher Of Yarrow, The', 'BLANKET PREACHER OF YARROW', 1, 64, 9999, 4, 4, 4, 678, '1983-01-01', '', 70, '8888/8888/8888/8888/4242/5555/1414/8080/0808', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (558, '1997-04-03 22:00:00+00', '2012-01-20 12:56:05.06155+00', 'Blackberry Bush', 'BLACKBERRY BUSH', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (563, '1997-04-03 22:00:00+00', '2012-01-20 12:56:05.111944+00', 'Blairgowrie Brose', 'BLAIRGOWRIE BROSE', 3, 32, 9999, 1, 2, NULL, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (565, '1997-04-03 22:00:00+00', '2012-01-20 12:56:05.131771+00', 'Blairnane''s Rant', 'BLAIRNANES RANT', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (568, '1997-04-03 22:00:00+00', '2012-01-20 12:56:05.158882+00', 'Bleasby Strathspey', 'BLEASBY STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (534, '1997-04-03 22:00:00+00', '2020-02-17 00:30:39.121317+00', 'Black Bear, The', 'BLACK BEAR', 1, 48, 9999, 1, 3, 42, 270, NULL, '', 54, '880/844/844/844/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (557, '1997-11-12 23:00:00+00', '2020-08-02 23:23:55.981521+00', 'Black Walnut, The', 'BLACK WALNUT', 1, 32, 9999, 1, 3, 42, 249, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2851, '1997-09-03 22:00:00+00', '2020-08-06 14:47:26.364775+00', 'Heir Of Errol, The', 'HEIR OF ERROL', 2, 200, 9999, 2, 3, NULL, 249, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (510, '1998-09-27 22:00:00+00', '2020-08-29 12:32:56.536329+00', 'Bill Hendry''s Reel', 'BILL HENDRYS REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10434, '2002-03-26 23:00:00+00', '2020-09-11 08:20:06.396587+00', 'Diamond White', 'DIAMOND WHITE', 2, 32, 9999, 1, 3, 42, 3083, NULL, '', 53, '800/844/877/877', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (513, '1997-08-28 22:00:00+00', '2020-12-07 12:59:56.369963+00', 'Bill''s Reel', 'BILLS REEL', 2, 32, 9999, 1, 3, 42, 693, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2850, '1997-04-03 22:00:00+00', '2021-07-01 18:13:19.949694+00', 'Heights of Inchvannie, The', 'HEIGHTS OF INCHVANNIE', 1, 32, 9999, 1, 3, 42, 13, NULL, 'The Heights of Inchvannie is an area near Strathpeffer.', 63, '888/880/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2848, '1997-04-03 22:00:00+00', '2020-12-27 12:01:16.188041+00', 'Heeliegoleerie', 'HEELIEGOLEERIE', 1, 32, 9999, 1, 100, 102, 13, NULL, '', 81, '8888/8888/8448/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15411, '2014-04-02 22:38:41.125096+00', '2020-12-30 21:40:55.403474+00', 'Friendships', 'FRIENDSHIPS', 3, 32, NULL, 1, 4, 1, 3350, NULL, '', 69, '8484/4848/8440/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10431, '2002-04-02 22:00:00+00', '2021-02-09 09:37:31.85291+00', 'Butterfly, The', 'BUTTERFLY', 2, 32, 9999, 1, 3, 42, 3083, NULL, '', 44, '800/804/840/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (550, '1997-04-03 22:00:00+00', '2021-04-17 18:06:51.828946+00', 'Black Ness', 'BLACK NESS', 3, 32, 9999, 1, 2, 76, 392, NULL, '', 47, '77/77/80/08', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (540, '1998-04-03 22:00:00+00', '2021-07-02 11:31:59.381871+00', 'Black Craig Of Dee', 'BLACK CRAIG OF DEE', 1, 32, 9999, 1, 3, 42, 129, '1964-01-01', '', 53, '800/866/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2836, '1997-04-03 22:00:00+00', '2021-08-05 08:06:04.636247+00', 'Heather Honey', 'HEATHER HONEY', 3, 32, 9999, 1, 3, 42, 13, NULL, '', 56, '880/808/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (569, '1997-08-28 22:00:00+00', '2012-01-20 12:56:05.167729+00', 'Blenheim Butterfly, The', 'BLENHEIM BUTTERFLY', 3, 32, 9999, 6, 3, NULL, 700, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (574, '1998-07-08 22:00:00+00', '2012-01-20 12:56:05.209819+00', 'Blind Piper, The', 'BLIND PIPER', 2, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (580, '1997-04-03 22:00:00+00', '2012-01-20 12:56:05.263347+00', 'Bloody Stockade', 'BLOODY STOCKADE', 3, 48, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (532, '1997-09-11 22:00:00+00', '2018-04-03 00:07:33.532629+00', 'Black Barony', 'BLACK BARONY', 1, 32, 9999, 1, 3, 42, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (538, '1997-04-03 22:00:00+00', '2018-04-03 00:07:33.574346+00', 'Black Colonel, The', 'BLACK COLONEL', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (554, '1997-04-03 22:00:00+00', '2018-04-03 00:07:33.641187+00', 'Black Swan, The', 'BLACK SWAN', 3, 32, 9999, 1, 3, 42, 250, NULL, '<<scddb:not-identical:555>>

<<scddb:not-identical:14094>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (555, '1997-04-03 22:00:00+00', '2018-04-03 00:07:33.649507+00', 'Black Swan, The', 'BLACK SWAN', 3, 32, 9999, 1, 3, 42, 94, NULL, '<<scddb:not-identical:554>>

<<scddb:not-identical:14094>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (561, '1997-08-24 22:00:00+00', '2018-04-03 00:07:33.682829+00', 'Blair Castle', 'BLAIR CASTLE', 2, 32, 9999, 1, 3, 42, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (562, '2003-01-26 23:00:00+00', '2018-04-03 00:07:33.69119+00', 'Blair''s Gamble', 'BLAIRS GAMBLE', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (575, '1997-08-31 22:00:00+00', '2018-04-03 00:07:34.130888+00', 'Blinkbonny', 'BLINKBONNY', 3, 32, 9999, 1, 3, 42, 108, '1985-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (577, '1997-04-03 22:00:00+00', '2018-04-03 00:07:34.224803+00', 'Blithe to See Ye', 'BLITHE TO SEE YE', 2, 32, 9999, 1, 3, 42, 108, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (579, '1997-08-28 22:00:00+00', '2018-04-03 00:07:34.241501+00', 'Blomidon Look Off', 'BLOMIDON LOOK OFF', 1, 32, 9999, 1, 3, 42, 209, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2855, '1997-04-03 22:00:00+00', '2018-04-03 00:07:51.792483+00', 'Helen''s Half Holiday Reel', 'HELENS HALF HOLIDAY REEL', 1, 32, 9999, 1, 3, 42, 310, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2863, '1997-09-03 22:00:00+00', '2018-04-03 00:07:51.850731+00', 'Hendersons'' Rant, The', 'HENDERSONS RANT', 2, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10439, '2002-03-27 23:00:00+00', '2018-04-03 00:07:56.637546+00', 'Julia''s Jig', 'JULIAS JIG', 2, 32, 9999, 1, 3, 42, 3087, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10442, '2002-03-27 23:00:00+00', '2018-04-03 00:08:18.24563+00', 'Squirrel Lady, The', 'SQUIRREL LADY', 1, 32, 9999, 1, 3, 42, 3088, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (581, '1997-04-03 22:00:00+00', '2012-01-20 12:56:05.272131+00', 'Bloom Of The Thistle', 'BLOOM OF THE THISTLE', 3, 40, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10448, '2002-03-27 23:00:00+00', '2018-09-26 12:47:12.598066+00', 'Tabitha''s Jig', 'TABITHAS JIG', 2, 32, 9999, 1, 3, 42, 3085, NULL, '', 44, '800/800/888/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10445, '2002-03-27 23:00:00+00', '2019-02-20 10:14:09.960744+00', 'Silver Branch, The', 'SILVER BRANCH', 2, 32, 9999, 2, 3, 17, 3089, NULL, '', 92, '484/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2869, '1997-04-03 22:00:00+00', '2012-01-20 12:56:23.184617+00', 'Herbie MacLeod', 'HERBIE MACLEOD', 1, 32, 9999, 1, 4, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2870, '1997-04-03 22:00:00+00', '2012-01-20 12:56:23.193266+00', 'Here Be Dragons', 'HERE BE DRAGONS', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2874, '1997-09-04 22:00:00+00', '2012-01-20 12:56:23.228797+00', 'Here''s to the Health', 'HERES TO THE HEALTH', 1, 128, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (590, '2001-04-26 22:00:00+00', '2019-03-19 21:38:48.84908+00', 'Blue Eyed Lassie, The', 'BLUE EYED LASSIE', 1, 32, 9999, 1, 3, 42, 127, NULL, '', 63, '880/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (606, '1997-04-03 22:00:00+00', '2019-08-24 20:11:02.470342+00', 'Bob Johnstone', 'BOB JOHNSTONE', 3, 32, 9999, 2, 3, 17, 270, NULL, '', 85, '864/864/868/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10446, '2002-03-27 23:00:00+00', '2012-01-20 12:57:21.451217+00', 'Silverdale', 'SILVERDALE', 2, 32, 9999, 2, 3, NULL, 3085, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10450, '2002-04-01 22:00:00+00', '2012-01-20 12:57:21.485974+00', 'Knox Nuptials', 'KNOX NUPTIALS', 1, 32, 9999, 1, 4, NULL, 2973, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (593, '2002-04-28 22:00:00+00', '2012-01-20 12:56:05.43648+00', 'Blue Men of the Minch, The', 'BLUE MEN OF THE MINCH', 3, 32, 9999, 1, 4, 2, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (582, '1997-04-03 22:00:00+00', '2018-04-03 00:07:34.249819+00', 'Bloom on the Thistle, The', 'BLOOM ON THE THISTLE', 3, 40, 9999, 1, 3, 42, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (601, '1997-08-31 22:00:00+00', '2012-01-20 12:56:05.494289+00', 'Bo''s Delight', 'BOS DELIGHT', 3, 96, 9999, 4, 4, NULL, 716, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (602, '1997-04-03 22:00:00+00', '2012-01-20 12:56:05.501089+00', 'Boatie Rows, The', 'BOATIE ROWS', 3, 32, 9999, 1, 4, NULL, 108, '1968-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2879, '1997-04-03 22:00:00+00', '2012-01-20 12:56:23.272135+00', 'Hermitage Castle', 'HERMITAGE CASTLE', 2, 48, 9999, 1, 4, NULL, 212, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2885, '1997-09-04 22:00:00+00', '2012-01-20 12:56:23.325216+00', 'Hey To Cupar', 'HEY TO CUPAR', 2, 32, 9999, 4, 4, NULL, 686, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2888, '1997-09-04 22:00:00+00', '2012-01-20 12:56:23.355232+00', 'Hey-boys Up We Go', 'HEYBOYS UP WE GO', 1, 24, 9999, 1, 98, NULL, 446, '1686-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2889, '1997-09-04 22:00:00+00', '2012-01-20 12:56:23.364052+00', 'Heysen Trail, The', 'HEYSEN TRAIL', 3, 32, 9999, 1, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2892, '1997-09-04 22:00:00+00', '2012-01-20 12:56:23.395952+00', 'Hide Park', 'HIDE PARK', 2, 72, 9999, 4, 4, NULL, 446, '1651-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10451, '2002-04-01 22:00:00+00', '2012-01-20 12:57:21.494626+00', 'Key Lime Pie', 'KEY LIME PIE', 2, 32, 9999, 3, 5, NULL, 2973, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10452, '2002-04-01 22:00:00+00', '2012-01-20 12:57:21.503319+00', 'West Side Wedding', 'WEST SIDE WEDDING', 3, 32, 9999, 99, 3, NULL, 2973, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (589, '1997-04-03 22:00:00+00', '2018-04-03 00:07:34.31653+00', 'Blue Bonnets Over The Border', 'BLUE BONNETS OVER THE BORDER', 5, 24, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (586, '2002-06-30 22:00:00+00', '2018-04-03 00:07:34.274845+00', 'Blue Anchor, The', 'BLUE ANCHOR', 2, 32, 9999, 1, 3, 42, 27, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (591, '1997-04-03 22:00:00+00', '2018-04-03 00:07:34.32495+00', 'Blue Falcon, The', 'BLUE FALCON', 2, 32, 9999, 1, 3, 42, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (592, '1997-08-28 22:00:00+00', '2018-04-03 00:07:34.333324+00', 'Blue Hen, The', 'BLUE HEN', 2, 32, 9999, 1, 3, 42, 691, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (585, '1997-04-03 22:00:00+00', '2020-03-24 22:17:53.748434+00', 'Blossom''s Reel', 'BLOSSOMS REEL', 1, 40, 9999, 1, 3, 42, 3412, NULL, '', 55, '844/844/888/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (576, '1997-06-01 22:00:00+00', '2020-08-04 19:08:16.749353+00', 'Blithe and Cheerie', 'BLITHE AND CHEERIE', 2, 32, 9999, 1, 3, 42, 62, NULL, '', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2871, '1998-07-08 22:00:00+00', '2021-05-30 13:07:32.032178+00', 'Here''s a Hand', 'HERES A HAND', 2, 32, 9999, 1, 114, 2, 696, NULL, '', 94, '8888/8448/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2861, '2002-03-11 23:00:00+00', '2021-05-30 19:47:58.878953+00', 'Henderson In Hereford', 'HENDERSON IN HEREFORD', 1, 32, 9999, 1, 3, 42, 108, '1988-01-01', 'The notes say this dance is "for Hereford S.C.D. Club - founded by Douglas Henderson - a dance to mark their 40th anniversary"', 63, '888/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2859, '1998-11-02 23:00:00+00', '2021-05-30 19:52:51.356731+00', 'Hen House, The', 'HEN HOUSE', 1, 32, 9999, 1, 3, 42, 394, NULL, 'Devised for Ken and Margaret Small on their 25th Wedding Anniversary. Their home in Brockville was formerly the Hain''s house, which was corrupted by the Scots to the Hen-house.', 56, '888/888/800/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19191, '2019-02-20 21:44:13.454653+00', '2021-06-11 15:52:03.810858+00', 'Westering Home', 'WESTERING HOME', 5, 80, NULL, 5, 56, NULL, 11784, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (598, '1998-01-11 23:00:00+00', '2021-07-01 22:36:35.508135+00', 'Bluebell Strathspey, The', 'BLUEBELL STRATHSPEY', 3, 32, 9999, 1, 4, 1, 87, NULL, '', 44, '8008/4444/8220/8220', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (543, '1997-08-28 22:00:00+00', '2021-07-02 11:28:16.079745+00', 'Black Douglas, The', 'BLACK DOUGLAS', 2, 40, 9999, 1, 3, 42, 696, NULL, '', 48, '464/464/484/484/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (605, '1999-08-11 22:00:00+00', '2021-10-02 14:29:01.064918+00', 'Bob Gilmour''s Return to Scotland', 'BOB GILMOURS RETURN TO SCOTLAND', 2, 32, 9999, 3, 5, 7, 68, '1974-01-01', '', 80, '80800/86866/88888/86888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (607, '1997-04-03 22:00:00+00', '2018-04-03 00:07:34.51676+00', 'Bob McMath''s Reel', 'BOB MACMATHS REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2865, '1997-04-03 22:00:00+00', '2018-04-03 00:07:51.867388+00', 'Hepburn Gardens', 'HEPBURN GARDENS', 1, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2866, '1997-04-03 22:00:00+00', '2018-04-03 00:07:51.87583+00', 'Her Bonnie Black E''e', 'HER BONNIE BLACK EE', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2876, '1998-04-21 22:00:00+00', '2018-04-03 00:07:51.884158+00', 'Here and There and Everywhere', 'HERE AND THERE AND EVERYWHERE', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2872, '1997-04-03 22:00:00+00', '2018-04-03 00:07:51.917527+00', 'Here''s a Health to Ane I Lo''e Dear', 'HERES A HEALTH TO ANE I LOE DEAR', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2875, '1997-04-03 22:00:00+00', '2018-04-03 00:07:51.942481+00', 'Here''s to the Ladies', 'HERES TO THE LADIES', 1, 32, 9999, 1, 3, 42, 365, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2867, '1997-11-24 23:00:00+00', '2018-04-03 00:07:51.950765+00', 'Her Grace''s Joy', 'HER GRACES JOY', 4, 32, 1, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2881, '1997-04-03 22:00:00+00', '2018-04-03 00:07:51.975813+00', 'Hermitage Of Braid', 'HERMITAGE OF BRAID', 2, 40, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2891, '1997-04-03 22:00:00+00', '2018-04-03 00:07:52.050948+00', 'Hidden Vale, The', 'HIDDEN VALE', 3, 32, 9999, 1, 3, 42, 44, '1982-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3807, '1997-08-24 22:00:00+00', '2018-04-03 00:07:59.540039+00', 'Lila''s Smile', 'LILAS SMILE', 3, 32, 9999, 1, 3, 42, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10444, '2002-03-27 23:00:00+00', '2018-04-03 00:08:15.752167+00', 'Sewing Maid, The', 'SEWING MAID', 3, 32, 9999, 1, 3, 42, 3086, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10447, '2002-03-27 23:00:00+00', '2018-04-03 00:08:16.744493+00', 'Silverhaze', 'SILVERHAZE', 1, 32, 9999, 1, 3, 42, 3090, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10453, '2002-04-01 22:00:00+00', '2012-01-20 12:57:21.511989+00', 'How-Dee-Do', 'HOWDEEDO', 2, 32, 9999, 5, 2, NULL, 2973, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10454, '2002-04-01 22:00:00+00', '2012-01-20 12:57:21.520649+00', 'New York Pillar Dance, The', 'NEW YORK PILLAR DANCE', 1, 32, 9999, 4, 4, NULL, 2973, NULL, 'Square set arranged around a pillar', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14406, '2012-03-08 15:42:21.61474+00', '2012-03-08 15:42:21.614751+00', 'Real Crazy', 'REAL CRAZY', 1, 32, NULL, 1, 4, 1, 10608, '2009-01-01', 'Geschrieben aus Jux ub=nd Dollerei', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (612, '1998-03-16 23:00:00+00', '2012-01-20 12:56:05.571989+00', 'Bob''s Your Uncle', 'BOBS YOUR UNCLE', 2, 32, 9999, 1, 2, NULL, 365, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (614, '1997-12-28 23:00:00+00', '2012-01-20 12:56:05.585726+00', 'Stoneycroft Reel, The', 'STONEYCROFT REEL', 1, 32, 9999, 2, 3, NULL, 623, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (619, '1997-04-03 22:00:00+00', '2012-01-20 12:56:05.620151+00', 'Bobby''s Eightsome, The', 'BOBBYS EIGHTSOME', 1, 192, 9999, 4, 4, NULL, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (620, '2003-01-26 23:00:00+00', '2012-01-20 12:56:05.627822+00', 'Bobier''s Garden Party', 'BOBIERS GARDEN PARTY', 4, 32, 1, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (623, '1997-08-28 22:00:00+00', '2012-01-20 12:56:05.648184+00', 'Boland''s Favourite', 'BOLANDS FAVOURITE', 1, 32, 9999, 5, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (642, '2002-03-03 23:00:00+00', '2019-03-19 21:10:21.857269+00', 'Bonnie Brux', 'BONNIE BRUX', 4, 80, 4, 4, 4, 3, 69, '1959-01-01', '', 93, '8888/4444/8888/8888/8888/8888/8686/6868/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (626, '1997-12-28 23:00:00+00', '2012-01-20 12:56:05.66855+00', 'Stoneycroft Strathspey, The', 'STONEYCROFT STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 623, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (628, '1997-04-03 22:00:00+00', '2012-01-20 12:56:05.682463+00', 'Bon Accord Jig', 'BON ACCORD JIG', 2, 48, 9999, 4, 4, NULL, 160, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10460, '2002-07-21 22:00:00+00', '2019-07-24 11:57:24.907937+00', 'Fox in the Wood', 'FOX IN THE WOOD', 1, 32, 9999, 1, 3, 42, 2961, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (631, '1997-04-03 22:00:00+00', '2012-01-20 12:56:05.703432+00', 'Bonfire at Parliament', 'BONFIRE AT PARLIAMENT', 1, 32, 9999, 7, 1, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (630, '1997-04-03 22:00:00+00', '2019-10-26 11:21:59.334021+00', 'Bonawe Highlanders', 'BONAWE HIGHLANDERS', 2, 32, 9999, 1, 3, 42, 270, NULL, '', 41, '800/822/822/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (634, '1997-08-28 22:00:00+00', '2012-01-20 12:56:05.723989+00', 'Bonnie Bairns Of Morwell, The', 'BONNIE BAIRNS OF MORWELL', 3, 32, 9999, 1, 4, NULL, 701, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (637, '1997-11-27 23:00:00+00', '2012-01-20 12:56:05.745185+00', 'Bonnie Belinda', 'BONNIE BELINDA', 4, 32, 1, 1, 4, NULL, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10455, '2002-04-19 22:00:00+00', '2018-04-02 23:56:38.582701+00', 'Whitney Welcome', 'WHITNEY WELCOME', 3, 32, 9999, 1, 3, 42, 2973, '1999-07-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2895, '1997-09-04 22:00:00+00', '2012-01-20 12:56:23.416926+00', 'Hielan Brochan', 'HIELAN BROCHAN', 1, 32, 9999, 4, 4, NULL, 270, NULL, '<<scddb:not-identical:2894>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2898, '1997-04-03 22:00:00+00', '2012-01-20 12:56:23.443073+00', 'High Jinks', 'HIGH JINKS', 1, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (599, '1999-08-11 22:00:00+00', '2022-07-30 18:37:10.856892+00', 'Bluebells of Scotland', 'BLUEBELLS OF SCOTLAND', 3, 32, 9999, 1, 3, 42, 250, '1963-01-01', '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2854, '1997-04-03 22:00:00+00', '2022-06-28 22:21:59.419368+00', 'Helen''s Fancy', 'HELENS FANCY', 3, 32, 9999, 1, 3, 42, 28, NULL, '', 56, '800/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (647, '1997-04-03 22:00:00+00', '2022-08-11 13:42:42.925273+00', 'Bonnie Doon', 'BONNIE DOON', 2, 32, 9999, 1, 3, 42, 270, NULL, '', 59, '800/888/888/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2897, '2002-03-03 23:00:00+00', '2023-01-20 11:56:39.332534+00', 'High Close Lassies', 'HIGH CLOSE LASSIES', 1, 40, 9999, 1, 4, 11, 127, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2899, '1997-04-03 22:00:00+00', '2012-01-20 12:56:23.449956+00', 'High Level', 'HIGH LEVEL', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2902, '1997-09-04 22:00:00+00', '2013-01-24 13:58:34.274499+00', 'High Peak, The', 'HIGH PEAK', 1, 32, 9999, 1, 100, 2, 108, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2904, '1997-09-04 22:00:00+00', '2012-01-20 12:56:23.485974+00', 'High Road, The', 'HIGH ROAD', 2, 32, 9999, 1, 4, NULL, 981, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (613, '1997-04-03 22:00:00+00', '2018-04-03 00:07:34.464443+00', 'Bobbing Brush', 'BOBBING BRUSH', 2, 32, 9999, 1, 3, 42, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10461, '2005-04-27 22:00:00+00', '2012-01-20 12:57:21.590231+00', '9 /11:Commemoration', '9 /11COMMEMORATION', 3, 32, 9999, 1, 4, NULL, 3350, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10464, '2002-04-11 22:00:00+00', '2012-01-20 12:57:21.616881+00', 'Hamilton Jubilee', 'HAMILTON JUBILEE', 1, 64, 9999, 4, 4, NULL, 2863, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14407, '2012-03-08 15:47:46.660197+00', '2012-03-08 15:47:46.660208+00', 'Eindhoven Delight', 'EINDHOVEN DELIGHT', 4, 64, 2, 4, 4, 3, 10609, '2005-01-01', 'Geschrieben zur Hochzeit von Regina und Jörg Plenkers', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (617, '1997-10-27 23:00:00+00', '2018-04-03 00:07:34.48383+00', 'Bobby Dunlop''s Jig', 'BOBBY DUNLOPS JIG', 2, 48, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2913, '1997-09-04 22:00:00+00', '2016-09-04 20:50:09.751273+00', 'Highland Heather', 'HIGHLAND HEATHER', 2, 32, 9999, 1, 3, 42, 371, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2896, '1998-04-12 22:00:00+00', '2020-08-05 14:26:23.72306+00', 'High Bridge O'' Ken, The', 'HIGH BRIDGE O KEN', 3, 32, 9999, 1, 4, 1, 62, '1973-01-01', '', 78, '8444/4488/8888/8844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2890, '1998-04-12 22:00:00+00', '2020-08-05 14:29:05.639714+00', 'Hi Kiwi!', 'HI KIWI', 3, 32, 9999, 1, 3, 42, 62, '1969-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (625, '1997-09-29 22:00:00+00', '2020-08-14 21:03:46.237479+00', 'Bolt Court', 'BOLT COURT', 1, 48, 9999, 1, 4, 1, 287, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2884, '1997-09-04 22:00:00+00', '2020-10-07 21:37:51.110045+00', 'Hey to Cupar', 'HEY TO CUPAR', 3, 24, 9999, 1, 3, 42, 397, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (603, '1998-01-05 23:00:00+00', '2021-01-09 23:28:34.859352+00', 'Bob and Bev''s Reel', 'BOB AND BEVS REEL', 1, 32, 9999, 1, 3, 42, 361, '1989-07-01', '', 63, '880/880/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2873, '1997-04-03 22:00:00+00', '2020-12-26 22:46:38.898869+00', 'Here''s Tae Us!', 'HERES TAE US', 1, 32, 9999, 1, 3, 42, 13, '1968-01-01', '', 53, '800/888/804/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2877, '1997-09-04 22:00:00+00', '2021-02-28 13:06:24.977937+00', 'Hereford Rant, The', 'HEREFORD RANT', 2, 32, 9999, 1, 3, 42, 176, NULL, '', 50, '880/660/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2905, '1997-09-04 22:00:00+00', '2021-04-07 19:28:13.68089+00', 'Highcliff Jig', 'HIGHCLIFF JIG', 2, 32, 9999, 1, 4, 2, 549, NULL, '', 81, '8008/8448/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2878, '1998-11-14 23:00:00+00', '2021-05-30 13:02:39.194771+00', 'Hereford Silver Jubilee, The', 'HEREFORD SILVER JUBILEE', 1, 32, 9999, 1, 3, 42, 176, NULL, '', 45, '802/888/840/804', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14408, '2012-03-08 16:08:04.56338+00', '2012-03-08 16:08:20.17245+00', 'Elena''s Wedding', 'ELENAS WEDDING', 3, 40, NULL, 1, 4, NULL, 10516, '2009-01-01', 'The progression turns out at 2134, which is impossible (3c stays put).  There must be an error in the original description.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (651, '1998-11-16 23:00:00+00', '2012-01-20 12:56:05.847508+00', 'Bonnie Glenshee', 'BONNIE GLENSHEE', 4, 120, 16, 4, 4, NULL, 87, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (653, '1997-08-28 22:00:00+00', '2012-01-20 12:56:05.861283+00', 'Bonnie Jean', 'BONNIE JEAN', 3, 32, 9999, 1, 4, NULL, 601, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2893, '1997-04-03 22:00:00+00', '2018-04-03 00:07:52.059277+00', 'Hiding Behind The Pillars', 'HIDING BEHIND THE PILLARS', 3, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (618, '1997-10-27 23:00:00+00', '2018-04-03 00:07:34.497793+00', 'Bobby Watson', 'BOBBY WATSON', 1, 40, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (621, '2003-01-26 23:00:00+00', '2018-04-03 00:07:34.550196+00', 'Boggie''s Reel', 'BOGGIES REEL', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (622, '1997-04-03 22:00:00+00', '2018-04-03 00:07:34.566915+00', 'Boky Hound, The', 'BOKY HOUND', 1, 32, 9999, 1, 3, 42, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (632, '1999-01-05 23:00:00+00', '2018-04-03 00:07:34.610477+00', 'Bonnie Agnes Blair', 'BONNIE AGNES BLAIR', 2, 32, 9999, 1, 3, 42, 2524, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (638, '1997-08-28 22:00:00+00', '2018-04-03 00:07:34.641799+00', 'Bonnie Belles Of Altanta, The', 'BONNIE BELLES OF ALTANTA', 1, 32, 9999, 1, 3, 42, 704, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (639, '1998-01-05 23:00:00+00', '2018-04-03 00:07:34.650086+00', 'Bonnie Betty', 'BONNIE BETTY', 1, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (643, '1997-04-03 22:00:00+00', '2018-04-03 00:07:34.675227+00', 'Bonnie Charlie', 'BONNIE CHARLIE', 1, 32, 9999, 1, 3, 42, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (646, '1997-08-28 22:00:00+00', '2018-04-03 00:07:34.68363+00', 'Bonnie Diamond, The', 'BONNIE DIAMOND', 2, 40, 9999, 1, 3, 42, 620, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (648, '1997-08-28 22:00:00+00', '2018-04-03 00:07:34.700276+00', 'Bonnie Dundee', 'BONNIE DUNDEE', 2, 32, 9999, 1, 3, 42, 707, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2908, '1999-01-05 23:00:00+00', '2018-04-29 21:42:16.591917+00', 'Highland Cronies', 'HIGHLAND CRONIES', 2, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18687, '2018-10-02 08:48:32.032182+00', '2018-10-02 08:48:32.032182+00', 'Brecksville Beckons', 'BRECKSVILLE BECKONS', 1, 32, NULL, 4, 4, 13, 2766, '2009-08-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (659, '1997-09-29 22:00:00+00', '2012-01-20 12:56:05.902957+00', 'Bonnie Lassie Strathspey', 'BONNIE LASSIE STRATHSPEY', 3, 32, 9999, 5, 2, NULL, 710, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2930, '1997-04-03 22:00:00+00', '2018-08-14 08:14:27.146456+00', 'Highland Welcome, A', 'HIGHLAND WELCOME', 2, 32, 9999, 1, 3, 42, 101, NULL, 'Dedicated to Barbara Little', 50, '800/844/888/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (663, '1997-04-03 22:00:00+00', '2012-01-20 12:56:05.930967+00', 'Bonnie MacKinnon is 21', 'BONNIE MACKINNON IS 21', 2, 32, 9999, 1, 4, NULL, 197, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (664, '1997-04-03 22:00:00+00', '2012-01-20 12:56:05.938203+00', 'Bonnie Maggie Tate', 'BONNIE MAGGIE TATE', 3, 32, 9999, 1, 4, NULL, 55, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (666, '1998-07-08 22:00:00+00', '2012-01-20 12:56:05.952507+00', 'Bonnie Mary', 'BONNIE MARY', 3, 32, 9999, 1, 4, 2, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2920, '1997-08-25 22:00:00+00', '2019-02-27 00:33:06.985079+00', 'Highland Park', 'HIGHLAND PARK', 2, 32, 9999, 1, 3, 42, 543, '1977-01-01', '', 67, '868/888/444/808/444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19208, '2019-03-02 10:30:47.172989+00', '2019-04-15 11:51:46.343649+00', 'Hay Tor Hey', 'HAY TOR HEY', 1, 32, NULL, 1, 3, NULL, 3165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2909, '1998-07-09 22:00:00+00', '2012-01-20 12:56:23.524176+00', 'Highland Donald', 'HIGHLAND DONALD', 1, 48, 9999, 3, 5, 7, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (691, '1997-08-26 22:00:00+00', '2019-03-19 20:26:38.162945+00', 'Bookworm, The', 'BOOKWORM', 1, 88, 9999, 6, 3, 3, 554, '1995-01-01', '', 95, '888/888/888/664/668/888/888/888/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10465, '2002-04-11 22:00:00+00', '2012-01-20 12:57:21.625525+00', 'Life Goes On at Sixty', 'LIFE GOES ON AT SIXTY', 3, 64, 9999, 99, 4, NULL, 2687, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10466, '2002-04-11 22:00:00+00', '2012-01-20 12:57:21.634186+00', 'Off to Colorado', 'OFF TO COLORADO', 2, 32, 9999, 99, 99, NULL, 2687, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14409, '2012-03-08 16:11:37.301348+00', '2012-03-08 16:11:37.301359+00', 'March Mellow', 'MARCH MELLOW', 2, 48, NULL, 1, 3, 42, 10516, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (657, '1997-04-03 22:00:00+00', '2018-04-03 00:07:34.867231+00', 'Bonnie Lass From Huntley, The', 'BONNIE LASS FROM HUNTLEY', 3, 32, 9999, 1, 3, 42, 204, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (678, '1997-08-28 22:00:00+00', '2012-01-20 12:56:06.037903+00', 'Bonnie Wee Well, The', 'BONNIE WEE WELL', 3, 32, 9999, 4, 4, NULL, 711, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (692, '1997-08-28 22:00:00+00', '2012-01-20 12:56:06.139331+00', 'Bootham Bar', 'BOOTHAM BAR', 3, 32, 9999, 1, 4, 1, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (661, '1997-08-28 22:00:00+00', '2018-04-03 00:07:34.908788+00', 'Bonnie Laurie', 'BONNIE LAURIE', 2, 32, 9999, 1, 3, 42, 710, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2923, '1997-09-28 22:00:00+00', '2012-01-20 12:56:23.627381+00', 'Highland Potlach', 'HIGHLAND POTLACH', 4, 128, 9999, 1, 4, NULL, 591, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (673, '1997-04-03 22:00:00+00', '2016-05-19 23:10:53.015907+00', 'Bonnie Strathmore', 'BONNIE STRATHMORE', 2, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2894, '1997-09-04 22:00:00+00', '2022-08-12 09:06:46.9427+00', 'Hielan Brochan', 'HIELAN BROCHAN', 1, 48, 9999, 1, 3, 42, 270, NULL, '<<scddb:not-identical:2895>>', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2922, '2000-05-20 22:00:00+00', '2023-01-20 11:52:48.762718+00', 'While Rudi''s Away', 'WHILE RUDIS AWAY', 1, 32, 9999, 2, 3, 17, 448, '1996-01-01', '', 58, '800/844/844/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (665, '1997-08-28 22:00:00+00', '2020-08-02 23:28:14.618477+00', 'Bonnie Mally Lee', 'BONNIE MALLY LEE', 1, 32, 9999, 1, 4, 1, 105, '1969-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (686, '1997-04-03 22:00:00+00', '2020-08-02 23:29:25.210595+00', 'Bonspiel, The', 'BONSPIEL', 1, 32, 9999, 1, 4, 1, 249, NULL, '', 56, '8440/8444/8808/8004', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2907, '1997-04-03 22:00:00+00', '2020-10-09 13:27:36.543195+00', 'Highland Castle', 'HIGHLAND CASTLE', 4, 64, 9999, 1, 4, 1, 270, NULL, '', 67, '8888/8888/8888/8800/8660/8000/8440/8044', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2932, '1997-04-05 22:00:00+00', '2020-10-09 21:38:24.067463+00', 'Highland Whisky', 'HIGHLAND WHISKY', 3, 32, 9999, 5, 53, 4, 270, NULL, '', 92, '888/888/484/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2919, '1997-04-03 22:00:00+00', '2020-12-13 22:56:56.385432+00', 'Highland Milkmaid', 'HIGHLAND MILKMAID', 1, 32, 9999, 1, 4, 1, 13, NULL, '', 88, '8888/8888/8888/8080', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10462, '2002-07-23 22:00:00+00', '2021-02-08 15:50:55.803773+00', 'Miss Rhiannon''s Strathspey', 'MISS RHIANNONS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1391, NULL, '', 50, '800/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (656, '2001-04-03 22:00:00+00', '2021-03-02 22:58:57.532795+00', 'Bonnie Lass', 'BONNIE LASS', 1, 32, 9999, 1, 3, 42, 446, '1710-01-01', '', 38, '822/842/440/860', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2906, '1997-04-03 22:00:00+00', '2021-05-28 12:50:06.566993+00', 'Highland Brigade, The', 'HIGHLAND BRIGADE', 2, 32, 9999, 1, 3, 42, 94, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (690, '1997-04-03 22:00:00+00', '2021-06-22 19:24:14.493166+00', 'Book One', 'BOOK ONE', 1, 64, 9999, 1, 4, 1, 109, '1973-08-01', 'The notes say this was "written to celebrate the 50th Anniversary of the Royal Scottish Country Dance Society and draws entirely on elements found in Book 1 of Scottish Country Dances published In 1923.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (687, '1998-07-08 22:00:00+00', '2021-06-29 09:58:06.478637+00', 'Bonxie, The', 'BONXIE', 1, 40, 9999, 1, 4, 2, 567, NULL, '', 64, '8888/8558/4444/6006/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (662, '1998-01-05 23:00:00+00', '2021-06-30 21:28:33.423797+00', 'Bonnie Links, The', 'BONNIE LINKS', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 50, '800/888/822/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (660, '1997-08-28 22:00:00+00', '2021-06-30 21:40:58.146652+00', 'Bonnie Lassie, A', 'BONNIE LASSIE', 2, 32, 9999, 1, 3, 42, 709, NULL, '', 44, '800/844/848/822', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (655, '1998-09-30 22:00:00+00', '2021-06-30 21:50:49.153528+00', 'Bonnie Kitty', 'BONNIE KITTY', 1, 40, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (667, '1997-09-28 22:00:00+00', '2018-04-03 00:07:34.933824+00', 'Bonnie Montrose', 'BONNIE MONTROSE', 2, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (693, '2002-04-19 22:00:00+00', '2017-08-19 22:13:55.010964+00', 'Charter Oak Reel, The', 'CHARTER OAK REEL', 1, 32, 9999, 1, 3, 42, 422, '1986-01-01', '', 47, '800/822/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (668, '1997-04-03 22:00:00+00', '2018-04-03 00:07:34.942254+00', 'Bonnie Nairn', 'BONNIE NAIRN', 1, 32, 9999, 1, 3, 42, 393, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (676, '1997-04-03 22:00:00+00', '2018-04-03 00:07:34.975704+00', 'Bonnie Warm Blankets', 'BONNIE WARM BLANKETS', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (688, '1997-08-28 22:00:00+00', '2018-04-03 00:07:35.042279+00', 'Book of Kells, The', 'BOOK OF KELLS', 3, 32, 9999, 1, 3, 42, 712, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (689, '1997-09-29 22:00:00+00', '2018-04-03 00:07:35.050597+00', 'Book Of Verse, A', 'BOOK OF VERSE', 3, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2912, '1997-11-24 23:00:00+00', '2018-04-03 00:07:52.109389+00', 'Highland Gentleman, The', 'HIGHLAND GENTLEMAN', 4, 32, 1, 1, 3, 42, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2915, '1997-09-04 22:00:00+00', '2018-04-03 00:07:52.134389+00', 'Highland Jigg', 'HIGHLAND JIGG', 2, 32, 9999, 1, 3, 42, 397, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2917, '1997-04-03 22:00:00+00', '2018-04-03 00:07:52.159383+00', 'Highland Lass and Laddie', 'HIGHLAND LASS AND LADDIE', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2921, '1997-04-03 22:00:00+00', '2018-04-03 00:07:52.20105+00', 'Highland Pipers', 'HIGHLAND PIPERS', 1, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2929, '1997-09-04 22:00:00+00', '2018-04-03 00:07:52.21767+00', 'Highland Wedding', 'HIGHLAND WEDDING', 1, 40, 9999, 1, 3, 42, 198, '1750-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2928, '1997-04-03 22:00:00+00', '2018-04-03 00:07:52.226171+00', 'Highland Wedding', 'HIGHLAND WEDDING', 2, 32, 9999, 1, 3, 42, 3578, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10467, '2002-04-12 22:00:00+00', '2018-04-03 00:08:06.887289+00', 'Munich Medley, The', 'MUNICH MEDLEY', 4, 32, 1, 1, 3, 42, 3095, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (669, '1997-09-14 22:00:00+00', '2018-04-03 00:08:16.315814+00', 'Shira Glen Strathspey', 'SHIRA GLEN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 250, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3772, '1997-09-29 22:00:00+00', '2012-01-20 12:56:30.647462+00', 'Leichhardt Reel, The', 'LEICHHARDT REEL', 4, 32, 9999, 3, 5, NULL, 325, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3773, '1997-09-07 22:00:00+00', '2012-01-20 12:56:30.654498+00', 'Leila''s Lilt', 'LEILAS LILT', 2, 40, 9999, 1, 4, NULL, 377, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2927, '1997-04-03 22:00:00+00', '2018-07-20 12:35:11.145466+00', 'Highland Troop, The', 'HIGHLAND TROOP', 2, 32, 9999, 1, 3, 42, 129, NULL, '', 56, '844/866/844/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18810, '2018-10-05 21:40:10.417159+00', '2018-10-05 21:40:10.417159+00', 'Lady Hannah', 'LADY HANNAH', 3, 32, NULL, 1, 3, 42, 2766, '2009-06-01', 'This dance was written to celebrate Hannah Newfield-Plunkett and Josh Bowman’s engagement.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14410, '2012-03-08 16:18:05.442595+00', '2012-03-08 16:18:05.442605+00', 'Till Death Do Us Part', 'TILL DEATH DO US PART', 4, 186, 10025, 1, 4, 3, 10609, '2004-01-01', 'Demo dance, for the marriage of Nadine and Holger Montag', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (703, '1997-08-31 22:00:00+00', '2012-01-20 12:56:06.216904+00', 'Border Reel, The', 'BORDER REEL', 1, 40, 9999, 1, 4, NULL, 714, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (706, '1997-08-31 22:00:00+00', '2012-01-20 12:56:06.34273+00', 'Border Strathspey, The', 'BORDER STRATHSPEY', 3, 40, 9999, 2, 3, NULL, 333, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (709, '1997-04-03 22:00:00+00', '2012-01-20 12:56:06.363597+00', 'Borderer''s Jig, The', 'BORDERERS JIG', 2, 32, 9999, 1, 4, NULL, 145, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14411, '2012-03-08 16:24:52.679848+00', '2012-03-08 16:24:52.679859+00', 'Susanne''s Medley', 'SUSANNES MEDLEY', 4, 64, 5, 1, 100, 13, 3778, NULL, '', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (718, '1998-07-08 22:00:00+00', '2012-01-20 12:56:06.430849+00', 'Bosun''s Locker, The', 'BOSUNS LOCKER', 1, 32, 9999, 1, 4, 11, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (719, '1998-04-05 22:00:00+00', '2012-01-20 12:56:06.437655+00', 'Botany Bay', 'BOTANY BAY', 3, 32, 9999, 1, 2, NULL, 108, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2943, '1997-09-04 22:00:00+00', '2019-03-15 20:52:05.481147+00', 'Hills of Nova Scotia, The', 'HILLS OF NOVA SCOTIA', 3, 32, 9999, 1, 4, 1, 996, NULL, '', 75, '8888/4884/8440/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2939, '1997-04-03 22:00:00+00', '2012-01-20 12:56:23.761398+00', 'Hilary''s Jig', 'HILARYS JIG', 2, 32, 9999, 1, 4, NULL, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2940, '1997-04-03 22:00:00+00', '2012-01-20 12:56:23.770034+00', 'Hill House', 'HILL HOUSE', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (711, '1998-03-22 23:00:00+00', '2013-11-16 08:37:54.892954+00', 'Borders Welcome, A', 'BORDERS WELCOME', 1, 32, 9999, 5, 56, NULL, 715, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (710, '1997-08-22 22:00:00+00', '2019-03-19 11:09:10.292576+00', 'Borders Revisited, The', 'BORDERS REVISITED', 1, 32, 9999, 1, 4, 2, 88, NULL, '', 81, '8008/8448/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2942, '1997-04-03 22:00:00+00', '2012-01-20 12:56:23.787356+00', 'Hills of Lorne', 'HILLS OF LORNE', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (732, '1998-04-01 22:00:00+00', '2019-04-04 20:27:32.70202+00', 'Bracknell Canter, The', 'BRACKNELL CANTER', 4, 128, 2, 1, 4, 1, 721, NULL, '1st & 2nd couples each dance 32 bars strathspey, then 3rd & 4th couples dance 32 bars in reel time.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2948, '1997-10-27 23:00:00+00', '2012-01-20 12:56:23.841179+00', 'Hoist The Flag', 'HOIST THE FLAG', 2, 48, 9999, 1, 4, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (714, '1998-01-07 23:00:00+00', '2012-02-22 21:59:48.769026+00', 'Borrowstoun Lass, The', 'BORROWSTOUN LASS', 3, 32, 9999, 1, 3, 42, 2027, '1983-06-01', 'Presented to Miss Martha Y K Cunningham on her retiral as Chairman of the West Lothian Branch, June 1983



Borrowstouness - Burgh and Seaport of Linlithgowshire, known usually as Bo''ness', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (725, '1997-11-27 23:00:00+00', '2012-01-20 12:56:06.479108+00', 'Boundaries Of Scotland', 'BOUNDARIES OF SCOTLAND', 4, 32, 1, 4, 4, NULL, 718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (728, '1997-08-31 22:00:00+00', '2012-01-20 12:56:06.50014+00', 'Bow Tie, The', 'BOW TIE', 2, 32, 9999, 1, 2, NULL, 720, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (720, '1997-04-03 22:00:00+00', '2018-04-03 00:07:35.200872+00', 'Bothal Barn, The', 'BOTHAL BARN', 1, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (734, '1998-04-05 22:00:00+00', '2012-01-20 12:56:06.541923+00', 'Braes Abune Loch Sween, The', 'BRAES ABUNE LOCH SWEEN', 3, 32, 9999, 1, 2, NULL, 121, '1987-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (736, '1998-10-18 22:00:00+00', '2012-01-20 12:56:06.557053+00', 'Braes o'' Lochaber', 'BRAES O LOCHABER', 3, 32, 9999, 1, 4, 2, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (707, '1997-06-26 22:00:00+00', '2020-06-09 22:07:23.288008+00', 'Border Wizard, The', 'BORDER WIZARD', 1, 32, 9999, 9, 7, 66, 313, NULL, '', 79, '8888888/8080800/8686866/8686866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (704, '1997-08-31 22:00:00+00', '2020-09-11 20:01:05.241947+00', 'Border Reiver''s Bride, The', 'BORDER REIVERS BRIDE', 4, 64, 9999, 4, 4, 3, 116, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (697, '1997-04-03 22:00:00+00', '2020-12-26 18:15:32.009839+00', 'Border Burn, A', 'BORDER BURN', 1, 32, 9999, 1, 2, 76, 13, NULL, '', 60, '80/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10473, '2002-04-15 22:00:00+00', '2021-02-08 15:18:31.513974+00', 'Telford Anniversary Jig', 'TELFORD ANNIVERSARY JIG', 2, 32, 9999, 3, 5, 7, 9998, NULL, '', 65, '80800/88888/80800/80888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18972, '2018-10-15 16:56:13.111104+00', '2021-05-15 11:44:43.946233+00', 'Raleigh Reel, The', 'RALEIGH REEL', 1, 40, NULL, 1, 3, 42, 2948, NULL, 'The use of "inverted" in the instructions is somewhat unclear. MiniCrib provide a danceable interpretation.', 55, '800/844/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2926, '1997-04-03 22:00:00+00', '2021-05-28 12:40:59.552802+00', 'Highland Rose, The', 'HIGHLAND ROSE', 3, 32, 9999, 1, 3, 42, 108, '1982-01-01', '', 59, '833/888/833/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (672, '1997-04-03 22:00:00+00', '2021-06-30 09:19:44.36826+00', 'Bonnie Strathearn', 'BONNIE STRATHEARN', 3, 32, 9999, 1, 3, 42, 417, '1987-01-01', '', 59, '888/888/880/822', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (671, '1997-08-28 22:00:00+00', '2021-06-30 21:24:04.948374+00', 'Bonnie Strathdee', 'BONNIE STRATHDEE', 1, 32, 9999, 1, 3, 42, 249, NULL, '', 59, '844/888/888/660', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (726, '1997-08-31 22:00:00+00', '2021-10-26 07:25:33.137704+00', 'Bovaird Strathspey, The', 'BOVAIRD STRATHSPEY', 3, 32, 9999, 2, 3, 18, 719, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (740, '1999-08-06 22:00:00+00', '2012-01-20 12:56:06.58435+00', 'Braes of Balmoral, The', 'BRAES OF BALMORAL', 3, 40, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (716, '1997-04-03 22:00:00+00', '2016-09-04 21:17:45.520407+00', 'Boston Medley, The', 'BOSTON MEDLEY', 4, 96, 11, 4, 4, 3, 351, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (724, '1997-04-03 22:00:00+00', '2018-04-03 00:07:35.242618+00', 'Boughs of Holly', 'BOUGHS OF HOLLY', 1, 32, 9999, 1, 3, 42, 252, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (741, '1999-08-06 22:00:00+00', '2018-04-03 00:07:35.351064+00', 'Braes of Balquhidder, The', 'BRAES OF BALQUHIDDER', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'See <<ddd:Balquidder Strathspey>> for information about Balquhidder.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (744, '1999-08-06 22:00:00+00', '2018-04-03 00:07:35.359375+00', 'Braes of Broadlands, The', 'BRAES OF BROADLANDS', 3, 40, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (701, '1998-04-21 22:00:00+00', '2018-04-03 00:07:38.079763+00', 'Chase Around The Windmill', 'CHASE AROUND THE WINDMILL', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2937, '1997-04-03 22:00:00+00', '2018-04-03 00:07:52.292885+00', 'Hiker''s Special, The', 'HIKERS SPECIAL', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2946, '1997-04-03 22:00:00+00', '2018-04-03 00:07:52.392964+00', 'Hoddam Castle', 'HODDAM CASTLE', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10472, '2002-04-15 22:00:00+00', '2018-04-03 00:08:19.796842+00', 'Talisman Reel, The', 'TALISMAN REEL', 1, 40, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (746, '1999-08-06 22:00:00+00', '2012-01-20 12:56:06.625433+00', 'Braes of Cammeray, The', 'BRAES OF CAMMERAY', 3, 96, 9999, 1, 4, NULL, 157, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2974, '1997-09-04 22:00:00+00', '2019-03-15 20:23:51.03748+00', 'Honeysuckle and the Bindweed', 'HONEYSUCKLE AND THE BINDWEED', 3, 32, 9999, 1, 100, 1, 48, NULL, '', 56, '8008/0880/8440/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2973, '2002-12-02 23:00:00+00', '2019-03-15 20:26:56.375662+00', 'Honeypot, The', 'HONEYPOT', 3, 32, 9999, 1, 4, 1, 783, NULL, '', 88, '8080/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (768, '1997-08-31 22:00:00+00', '2019-03-19 10:50:31.97553+00', 'Bratach Astrailia', 'BRATACH ASTRAILIA', 3, 32, 9999, 1, 4, 1, 670, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2958, '1997-04-03 22:00:00+00', '2012-01-20 12:56:23.932495+00', 'Hollyburn', 'HOLLYBURN', 4, 64, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (763, '1998-01-04 23:00:00+00', '2019-03-19 10:55:20.075008+00', 'Brandane Reel, The', 'BRANDANE REEL', 1, 48, 9999, 1, 4, 1, 477, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10479, '2002-04-19 22:00:00+00', '2018-04-02 23:56:33.581712+00', 'Connecticut Assemblies, The', 'CONNECTICUT ASSEMBLIES', 3, 32, 9999, 1, 3, 42, 361, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (749, '1997-04-03 22:00:00+00', '2013-09-23 22:37:18.863292+00', 'Braes of Glenorchy', 'BRAES OF GLENORCHY', 3, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14222, '2011-08-26 22:00:00+00', '2014-02-08 14:34:15.016155+00', 'Forty Years On', 'FORTY YEARS ON', 3, 32, NULL, 1, 4, 2, 3561, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (751, '2002-03-03 23:00:00+00', '2019-04-19 22:14:34.17922+00', 'Braes of Lochaber, The', 'BRAES OF LOCHABER', 4, 80, 4, 1, 4, 3, 94, NULL, '', 100, '8 8 8 8 8 8 8 8', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2961, '1997-09-04 22:00:00+00', '2012-01-20 12:56:23.962289+00', 'Holy Rood, The', 'HOLY ROOD', 1, 40, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2963, '1997-09-04 22:00:00+00', '2012-01-20 12:56:23.979724+00', 'Homage', 'HOMAGE', 3, 72, 9999, 4, 4, NULL, 999, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2964, '1998-01-04 23:00:00+00', '2012-01-20 12:56:23.988337+00', 'Homecrest Meeting', 'HOMECREST MEETING', 1, 32, 9999, 2, 3, NULL, 642, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14412, '2012-03-08 16:27:49.000349+00', '2012-03-08 16:27:49.00036+00', 'Superfast IX', 'SUPERFAST IX', 1, 32, NULL, 1, 100, NULL, 2102, '2004-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2951, '1998-01-05 23:00:00+00', '2012-05-18 06:50:32.726477+00', 'Holden Lane', 'HOLDEN LANE', 1, 32, 9999, 1, 3, 42, 181, NULL, 'Anna has been a frequent teacher at Brock summer school.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (756, '1997-04-03 22:00:00+00', '2012-01-20 12:56:06.694539+00', 'Braeside Ramble', 'BRAESIDE RAMBLE', 3, 32, 9999, 1, 2, NULL, 141, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (758, '1997-09-29 22:00:00+00', '2012-01-20 12:56:06.708371+00', 'Braid Bonnet, The', 'BRAID BONNET', 1, 32, 9999, 1, 2, NULL, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10481, '2002-04-19 22:00:00+00', '2018-04-02 23:56:34.784167+00', 'Fun and Flirtation', 'FUN AND FLIRTATION', 3, 32, 9999, 1, 3, 42, 3099, '1998-12-02', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (764, '1997-04-03 22:00:00+00', '2012-01-20 12:56:06.749632+00', 'Brandon Strathspey', 'BRANDON STRATHSPEY', 3, 64, 9999, 1, 4, NULL, 3, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (766, '1997-04-03 22:00:00+00', '2012-01-20 12:56:06.763985+00', 'Brant''s Reel', 'BRANTS REEL', 1, 32, 9999, 1, 4, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (757, '1997-04-03 22:00:00+00', '2018-04-03 00:07:35.342733+00', 'Braeside Strathspey, The', 'BRAESIDE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (770, '1997-04-03 22:00:00+00', '2012-01-20 12:56:06.791507+00', 'Braw Lad From Bonnybridge, The', 'BRAW LAD FROM BONNYBRIDGE', 3, 40, 9999, 1, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (771, '1997-11-24 23:00:00+00', '2012-01-20 12:56:06.79831+00', 'Braw Lads And Lassies', 'BRAW LADS AND LASSIES', 4, 64, 9999, 4, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (772, '1998-04-05 22:00:00+00', '2012-01-20 12:56:06.805115+00', 'Braw Lasses And Lads', 'BRAW LASSES AND LADS', 2, 32, 9999, 1, 2, NULL, 121, '1987-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (775, '1997-04-03 22:00:00+00', '2012-01-20 12:56:06.825654+00', 'Braw, Braw Lads', 'BRAW BRAW LADS', 3, 48, 9999, 4, 4, NULL, 116, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2969, '1997-11-27 23:00:00+00', '2012-01-20 12:56:24.031827+00', 'Honey and the Bee, The', 'HONEY AND THE BEE', 4, 80, 4, 6, 3, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2977, '2002-03-11 23:00:00+00', '2012-01-20 12:56:24.103883+00', 'Honours of Scotland', 'HONOURS OF SCOTLAND', 1, 96, 9999, 1, 98, NULL, 563, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10477, '2002-04-19 22:00:00+00', '2016-04-18 23:09:08.177552+00', 'Chase New Haven', 'CHASE NEW HAVEN', 2, 32, 9999, 1, 2, NULL, 3098, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (788, '1997-10-27 23:00:00+00', '2018-04-03 00:07:35.70162+00', 'Bridal Jig, The', 'BRIDAL JIG', 2, 40, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10480, '2002-04-19 22:00:00+00', '2021-09-17 21:14:45.956426+00', 'Fudge Factor, The', 'FUDGE FACTOR', 1, 32, 9999, 1, 3, 42, 422, '1988-01-01', 'Devised in honour of a fudge brownie recipe given in the original book.', 50, '880/880/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (752, '1997-08-25 22:00:00+00', '2020-12-02 11:30:32.233063+00', 'Braes of Mar, The', 'BRAES OF MAR', 3, 32, 9999, 1, 3, 42, 108, '1981-01-01', '', 41, '800/844/822/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2941, '1997-04-03 22:00:00+00', '2023-01-20 11:39:28.840357+00', 'Hills of Langholm, The', 'HILLS OF LANGHOLM', 2, 32, 9999, 1, 3, 42, 146, NULL, '', 55, '543/877/888/822', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (778, '1998-09-30 22:00:00+00', '2020-10-03 12:33:51.681258+00', 'Brechin Fancy', 'BRECHIN FANCY', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 60, '80/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2953, '1997-09-04 22:00:00+00', '2020-10-07 21:38:17.605645+00', 'Hole in the Wall', 'HOLE IN THE WALL', 1, 16, 9999, 1, 2, NULL, 446, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2945, '1997-04-03 22:00:00+00', '2020-10-21 10:08:01.473995+00', 'Ho Ho My Nut Brown Maiden', 'HO HO MY NUT BROWN MAIDEN', 1, 40, 9999, 1, 3, 42, 270, NULL, '', 60, '484/484/484/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2968, '1997-04-03 22:00:00+00', '2021-01-16 00:23:34.12544+00', 'Honest Men and Bonnie Lassies', 'HONEST MEN AND BONNIE LASSIES', 3, 32, 9999, 6, 56, 18, 3412, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10475, '2002-04-19 22:00:00+00', '2021-02-08 15:14:21.147587+00', 'Cerebral Vortex', 'CEREBRAL VORTEX', 1, 32, 9999, 1, 3, 42, 3097, '1997-01-01', '', 50, '808/888/080/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10474, '2003-01-10 23:00:00+00', '2021-02-08 15:15:51.39653+00', 'Y not 2K', 'Y NOT 2K', 1, 32, 9999, 1, 3, 42, 3309, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (737, '1998-10-18 22:00:00+00', '2021-02-26 19:01:15.768522+00', 'Braes o'' Mar', 'BRAES O MAR', 3, 16, 9999, 5, 2, NULL, 392, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3771, '1997-09-07 22:00:00+00', '2021-06-16 23:51:49.540005+00', 'Leggett''s Reel', 'LEGGETTS REEL', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (765, '1998-11-02 23:00:00+00', '2021-06-28 14:34:59.955465+00', 'Brandysnaps', 'BRANDYSNAPS', 1, 32, 9999, 1, 4, 2, 118, '1990-04-01', '', 75, '8008/8888/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (735, '2002-03-02 23:00:00+00', '2021-06-28 14:47:04.257534+00', 'Braes o'' Loch Broom', 'BRAES O LOCH BROOM', 1, 32, 9999, 1, 3, 42, 21, '1978-01-01', '', 63, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10478, '2002-04-19 22:00:00+00', '2016-05-14 13:14:31.060367+00', 'Colonel Joshua Lawrence Chamberlain', 'COLONEL JOSHUA LAWRENCE CHAMBERLAIN', 2, 32, 9999, 1, 3, 18, 1167, '1995-01-01', 'The dance has been known as "Colonel Joshua Lawrence Chamberlain", but that is not in agreement with the original name in the Nutmeg collection.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2967, '1997-04-03 22:00:00+00', '2018-04-03 00:07:52.576437+00', 'Honest George', 'HONEST GEORGE', 1, 32, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (747, '1999-08-06 22:00:00+00', '2018-04-03 00:07:35.367683+00', 'Braes of Crosskirk, The', 'BRAES OF CROSSKIRK', 1, 24, 9999, 1, 3, 42, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (748, '1999-08-06 22:00:00+00', '2018-04-03 00:07:35.384426+00', 'Braes of Dornoch', 'BRAES OF DORNOCH', 3, 32, 9999, 1, 3, 42, 198, '1757-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (777, '1998-01-05 23:00:00+00', '2018-04-03 00:07:35.543225+00', 'Breathless Piper, The', 'BREATHLESS PIPER', 1, 32, 9999, 1, 3, 42, 250, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (911, '1997-08-31 22:00:00+00', '2018-04-03 00:07:36.377495+00', 'Cadogan Gait', 'CADOGAN GAIT', 1, 40, 9999, 1, 3, 42, 734, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2950, '2002-03-02 23:00:00+00', '2018-04-03 00:07:52.434576+00', 'Hold Fast', 'HOLD FAST', 1, 32, 9999, 1, 3, 42, 44, '1989-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2954, '2003-01-27 23:00:00+00', '2018-04-03 00:07:52.476321+00', 'Holkham Hall', 'HOLKHAM HALL', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2959, '1997-09-04 22:00:00+00', '2018-04-03 00:07:52.484684+00', 'Hollyburn Jig, The', 'HOLLYBURN JIG', 2, 32, 9999, 1, 3, 42, 998, '1976-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2960, '1997-04-03 22:00:00+00', '2018-04-03 00:07:52.509834+00', 'Holy Corner', 'HOLY CORNER', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2971, '1997-09-04 22:00:00+00', '2018-04-03 00:07:52.609849+00', 'Honey Well, The', 'HONEY WELL', 3, 32, 9999, 1, 3, 42, 108, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (810, '2002-11-26 23:00:00+00', '2019-03-19 10:41:28.503664+00', 'Brigs O'' Ayr, The', 'BRIGS O AYR', 3, 32, 9999, 2, 3, 18, 13, NULL, '', 83, '888/808/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (813, '1997-08-31 22:00:00+00', '2019-10-07 23:08:36.266154+00', 'Brinkie Braes', 'BRINKIE BRAES', 3, 48, 9999, 1, 4, NULL, 270, NULL, '', 79, '4884/8888/8888/8008/8008/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (781, '1997-08-31 22:00:00+00', '2012-01-20 12:56:06.866719+00', 'Breith, The', 'BREITH', 2, 40, 9999, 1, 4, NULL, 724, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (804, '1997-08-24 22:00:00+00', '2018-04-02 23:56:33.19677+00', 'Brig O'' Dee', 'BRIG O DEE', 3, 32, 9999, 1, 3, 42, 108, '1971-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (786, '1997-04-03 22:00:00+00', '2012-01-20 12:56:06.902984+00', 'Briar, The', 'BRIAR', 3, 32, 9999, 1, 98, NULL, 108, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (789, '1998-07-08 22:00:00+00', '2012-01-20 12:56:06.924846+00', 'Bride''s Bonn, The', 'BRIDES BONN', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (791, '1997-09-14 22:00:00+00', '2012-01-20 12:56:06.938768+00', 'Tardy Eddie', 'TARDY EDDIE', 3, 32, 9999, 1, 4, NULL, 1281, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (792, '1998-04-05 22:00:00+00', '2012-01-20 12:56:06.945675+00', 'Bridge At Ballachullish, The', 'BRIDGE AT BALLACHULLISH', 3, 32, 9999, 4, 4, NULL, 417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (793, '1997-04-03 22:00:00+00', '2012-01-20 12:56:06.952538+00', 'Bridge of Brechin', 'BRIDGE OF BRECHIN', 3, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10484, '2002-04-19 22:00:00+00', '2018-04-02 23:56:36.988238+00', 'Peter Price''s Compliment to Geoff and Pat Walshe', 'PETER PRICES COMPLIMENT TO GEOFF AND PAT WALSHE', 1, 32, 9999, 1, 3, 42, 1167, '1994-09-02', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (799, '1997-08-31 22:00:00+00', '2012-01-20 12:56:06.994496+00', 'Bridges, The', 'BRIDGES', 4, 128, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (806, '1999-10-24 22:00:00+00', '2012-01-20 12:56:07.047321+00', 'Brig o'' Blair', 'BRIG O BLAIR', 2, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10485, '2002-04-19 22:00:00+00', '2018-04-02 23:56:37.364071+00', 'Robert''s Roundhouse', 'ROBERTS ROUNDHOUSE', 2, 32, 9999, 1, 3, 42, 3101, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2986, '1998-07-08 22:00:00+00', '2012-01-20 12:56:24.186472+00', 'Horseless Carriage, The', 'HORSELESS CARRIAGE', 2, 32, 9999, 1, 4, 2, 108, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10486, '2002-04-19 22:00:00+00', '2018-04-02 23:56:37.956994+00', 'Talcott Mountain Strathspey, The', 'TALCOTT MOUNTAIN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 361, '1999-01-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2989, '1997-12-03 23:00:00+00', '2012-01-20 12:56:24.212869+00', 'Helen''s Hornpipe', 'HELENS HORNPIPE', 2, 32, 9999, 1, 4, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2976, '1997-12-02 23:00:00+00', '2014-07-17 20:33:48.051581+00', 'Honour The Piper', 'HONOUR THE PIPER', 4, 96, 11, 4, 4, NULL, 91, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2991, '1997-09-04 22:00:00+00', '2012-01-20 12:56:24.230309+00', 'Hot Punch', 'HOT PUNCH', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10487, '2002-04-19 22:00:00+00', '2018-04-02 23:56:38.006911+00', 'Third Couple Reel', 'THIRD COUPLE REEL', 1, 32, 9999, 1, 3, 42, 3101, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2988, '1997-09-04 22:00:00+00', '2016-09-04 20:05:32.53189+00', 'Hot And Muggy', 'HOT AND MUGGY', 4, 32, 1, 1, 3, 42, 608, NULL, 'Devised on a day that was not "Cold and Raw"!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10497, '2003-01-14 23:00:00+00', '2016-09-23 21:53:10.693858+00', 'Tweedbridge Court', 'TWEEDBRIDGE COURT', 3, 32, 9999, 1, 3, 42, 3105, '1997-01-01', '', 47, '800/844/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10489, '2002-04-19 22:00:00+00', '2018-04-03 00:08:23.374152+00', 'Unnamed Dance', 'UNNAMED DANCE', 3, 32, 9999, 1, 3, 42, 3102, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2983, '1998-01-05 23:00:00+00', '2017-01-16 00:10:08.338407+00', 'Hopeful Lovers, The', 'HOPEFUL LOVERS', 1, 40, 9999, 1, 3, 42, 44, '1965-01-01', 'Devised to celebrate the engagement of Lorraine Farrand and Poul Nielsen.', 60, '880/800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2984, '1998-01-07 23:00:00+00', '2017-02-13 14:52:37.075465+00', 'Hopetoun House', 'HOPETOUN HOUSE', 2, 32, 9999, 1, 3, 42, 2027, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2982, '1997-04-03 22:00:00+00', '2018-04-03 00:07:52.643159+00', 'Hopeful Lover, The', 'HOPEFUL LOVER', 3, 32, 9999, 1, 3, 42, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (783, '1997-04-03 22:00:00+00', '2018-04-03 00:07:35.660315+00', 'Brendetta Jig, The', 'BRENDETTA JIG', 2, 32, 9999, 1, 3, 42, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (785, '2003-01-25 23:00:00+00', '2018-04-03 00:07:35.676642+00', 'Brian''s Blunder', 'BRIANS BLUNDER', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (787, '1997-08-31 22:00:00+00', '2018-04-03 00:07:35.684838+00', 'Brick Makers, The', 'BRICK MAKERS', 1, 48, 9999, 1, 3, 42, 198, '1750-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (784, '2002-02-28 23:00:00+00', '2020-08-02 23:30:48.313403+00', 'Brian Boru', 'BRIAN BORU', 1, 32, 9999, 1, 3, 42, 406, '1968-01-01', '', 46, '888/800/800/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (800, '1997-04-03 22:00:00+00', '2020-08-02 23:31:49.349915+00', 'Brier, The', 'BRIER', 3, 32, 9999, 1, 4, NULL, 249, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2965, '1997-04-03 22:00:00+00', '2020-08-30 21:04:45.513511+00', 'Homeward Bound', 'HOMEWARD BOUND', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 66, '888/884/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2985, '1997-10-27 23:00:00+00', '2022-11-06 11:00:53.466035+00', 'Hops of Kent', 'HOPS OF KENT', 1, 32, 9999, 1, 2, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (762, '1997-08-25 22:00:00+00', '2023-02-21 19:31:10.406817+00', 'Bramhall', 'BRAMHALL', 3, 32, 9999, 1, 3, 42, 108, '1992-05-01', 'Inscribed "for Mac and Joan Birnie of the Bramhall Branch of the R.S.C.D.S."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10495, '2005-01-19 23:00:00+00', '2021-02-08 14:37:48.221472+00', 'Jig for Corrie, A', 'JIG FOR CORRIE', 2, 32, 9999, 1, 4, 1, 2886, '2003-01-01', '', 62, '8000/8444/8444/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10491, '2002-04-20 22:00:00+00', '2021-02-08 15:06:23.670552+00', 'Ailsa''s Jig', 'AILSAS JIG', 2, 32, 9999, 1, 3, 42, 1849, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2966, '1997-04-03 22:00:00+00', '2021-05-27 21:43:11.624438+00', 'Homeward Bound', 'HOMEWARD BOUND', 1, 32, 9999, 1, 3, 42, 44, NULL, '', 41, '800/844/844/840', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2952, '1998-04-12 22:00:00+00', '2021-05-27 22:15:29.697298+00', 'Hole In The Wa'', The', 'HOLE IN THE WA', 1, 32, 9999, 1, 3, 42, 101, '1993-01-01', '', 53, '800/888/844/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (807, '1999-04-19 22:00:00+00', '2021-06-28 10:26:10.530684+00', 'Bright And Breezy', 'BRIGHT AND BREEZY', 1, 32, 9999, 1, 4, 1, 87, NULL, '', 72, '8668/8888/0808/0088', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10493, '2002-04-23 22:00:00+00', '2021-09-19 12:00:30.900222+00', 'Smokers Corner, The', 'SMOKERS CORNER', 3, 32, 9999, 1, 3, 42, 2764, '1992-01-01', 'on the way home from Bonn 1992', 58, '808/886/444/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (798, '1997-04-03 22:00:00+00', '2018-04-03 00:07:35.743372+00', 'Bridge over Troubled Waters', 'BRIDGE OVER TROUBLED WATERS', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (808, '1997-04-03 22:00:00+00', '2018-04-03 00:07:35.785027+00', 'Brighton Belle, The', 'BRIGHTON BELLE', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2987, '1997-09-04 22:00:00+00', '2018-04-03 00:07:52.676481+00', 'Hot Afternoon', 'HOT AFTERNOON', 3, 32, 9999, 1, 3, 42, 887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2993, '1997-04-03 22:00:00+00', '2018-04-03 00:07:52.716243+00', 'Hotch-Potch', 'HOTCHPOTCH', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10490, '2002-04-19 22:00:00+00', '2018-04-03 00:08:24.540621+00', 'Wee Dram, A', 'WEE DRAM', 1, 32, 9999, 1, 3, 42, 3103, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (814, '1997-04-03 22:00:00+00', '2012-01-20 12:56:07.101883+00', 'Brisbane Medley', 'BRISBANE MEDLEY', 3, 64, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (818, '1997-04-03 22:00:00+00', '2012-01-20 12:56:07.132296+00', 'British Caledonian Band, The', 'BRITISH CALEDONIAN BAND', 1, 32, 9999, 1, 4, 1, 211, '1973-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (821, '1997-12-06 23:00:00+00', '2012-01-20 12:56:07.153036+00', 'Britannia', 'BRITANNIA', 1, 32, 9999, 1, 98, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (825, '1998-04-05 22:00:00+00', '2012-01-20 12:56:07.18034+00', 'Brock Squared', 'BROCK SQUARED', 1, 128, 9999, 4, 4, NULL, 726, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (826, '1998-04-05 22:00:00+00', '2012-01-20 12:56:07.187135+00', 'Brock Village Medley', 'BROCK VILLAGE MEDLEY', 4, 64, 5, 1, 4, NULL, 361, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (831, '1997-04-03 22:00:00+00', '2012-01-20 12:56:07.221854+00', 'Bromley Market', 'BROMLEY MARKET', 1, 40, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18675, '2018-10-01 11:57:29.297288+00', '2018-10-01 12:07:48.807031+00', 'All Together Again', 'ALL TOGETHER AGAIN', 3, 32, NULL, 1, 3, 42, 2766, '2015-12-01', 'Celebrating the holiday season when the family gathers together again.', 66, '888/644/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10498, '2002-04-23 22:00:00+00', '2019-02-04 11:01:05.125348+00', 'Diamond Rose', 'DIAMOND ROSE', 3, 24, 9999, 1, 2, NULL, 558, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (837, '1997-04-03 22:00:00+00', '2012-01-20 12:56:07.2624+00', 'Brougham Hayes', 'BROUGHAM HAYES', 3, 32, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2994, '1997-04-03 22:00:00+00', '2012-01-20 12:56:24.256218+00', 'House By The Streams', 'HOUSE BY THE STREAMS', 1, 32, 9999, 1, 4, NULL, 896, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (829, '1997-08-31 22:00:00+00', '2019-09-24 23:49:19.113651+00', 'Broken Ridge, The', 'BROKEN RIDGE', 3, 32, 9999, 1, 3, 42, 21, NULL, '', 53, '880/888/880/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2996, '1997-04-03 22:00:00+00', '2012-01-20 12:56:24.273647+00', 'House Of Gray', 'HOUSE OF GRAY', 2, 24, 9999, 3, 5, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3004, '1997-09-04 22:00:00+00', '2012-01-20 12:56:24.343217+00', 'Hugh Cusack''s Farewell To Gardenvale', 'HUGH CUSACKS FAREWELL TO GARDENVALE', 1, 32, 9999, 4, 4, NULL, 941, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3007, '1997-09-04 22:00:00+00', '2012-01-20 12:56:25.016379+00', 'Hugh''s Welcome', 'HUGHS WELCOME', 3, 32, 9999, 5, 2, NULL, 1008, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (832, '1997-04-03 22:00:00+00', '2018-04-03 00:07:35.910232+00', 'Brooch of Lorn, The', 'BROOCH OF LORN', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14415, '2012-03-08 16:44:03.213088+00', '2012-03-08 16:44:03.213099+00', 'Washing Machine', 'WASHING MACHINE', 3, 32, NULL, 2, 3, 18, 10517, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (844, '1998-07-08 22:00:00+00', '2012-01-20 12:56:07.31394+00', 'Bruce''s Castle', 'BRUCES CASTLE', 1, 32, 9999, 1, 4, 2, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (847, '1997-08-31 22:00:00+00', '2012-01-20 12:56:07.334369+00', 'Brynich Shieling', 'BRYNICH SHIELING', 3, 32, 9999, 1, 4, NULL, 728, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (851, '1997-08-31 22:00:00+00', '2012-01-20 12:56:07.362363+00', 'Buchanhaven Jig, The', 'BUCHANHAVEN JIG', 2, 40, 9999, 1, 4, NULL, 601, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (835, '1997-04-03 22:00:00+00', '2018-04-03 00:07:35.951966+00', 'Broon''s Bairns', 'BROONS BAIRNS', 3, 32, 9999, 1, 3, 42, 222, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (836, '2002-04-05 22:00:00+00', '2018-04-03 00:07:35.960252+00', 'Brothers Three', 'BROTHERS THREE', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (846, '1997-04-03 22:00:00+00', '2016-07-15 05:13:43.465206+00', 'Bruichladdich', 'BRUICHLADDICH', 3, 32, 9999, 1, 4, 1, 352, '1993-06-13', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (840, '1997-04-03 22:00:00+00', '2018-04-03 00:07:35.976911+00', 'Broun''s Strathspey', 'BROUNS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (843, '1997-04-03 22:00:00+00', '2020-08-02 23:32:25.559236+00', 'Bruce Trail, The', 'BRUCE TRAIL', 3, 32, 9999, 1, 3, 42, 249, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (824, '1997-04-03 22:00:00+00', '2020-05-12 23:04:00.138942+00', 'Brochan Lom', 'BROCHAN LOM', 3, 32, 9999, 1, 3, 42, 243, NULL, '', 69, '888/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3006, '1997-04-03 22:00:00+00', '2020-08-30 21:10:02.730847+00', 'Hugh Morison''s Delight', 'HUGH MORISONS DELIGHT', 2, 32, 9999, 1, 3, 42, 21, NULL, '', 56, '800/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3010, '1997-09-04 22:00:00+00', '2020-09-23 09:12:49.077191+00', 'Humming Bird, The', 'HUMMING BIRD', 2, 32, 9999, 3, 5, 16, 943, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2992, '1997-09-04 22:00:00+00', '2020-10-03 23:00:33.482438+00', 'Hot Toddy, A', 'HOT TODDY', 2, 32, 9999, 1, 3, 42, 1003, NULL, '', 66, '844/888/888/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2978, '1999-08-09 22:00:00+00', '2021-01-06 11:04:46.432862+00', 'Hoop Her and Gird Her', 'HOOP HER AND GIRD HER', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 50, '800/888/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (839, '1997-08-31 22:00:00+00', '2021-01-09 11:59:52.342851+00', 'Broughty Ferry Castle', 'BROUGHTY FERRY CASTLE', 1, 40, 9999, 1, 2, NULL, 499, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2980, '1997-04-03 22:00:00+00', '2021-05-13 09:26:04.520234+00', 'Hop Scotch', 'HOP SCOTCH', 1, 32, 9999, 1, 3, 42, 352, NULL, '', 44, '800/844/844/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3777, '1997-11-18 23:00:00+00', '2021-05-01 22:11:44.631919+00', 'Lerwick Reel, The', 'LERWICK REEL', 3, 128, 9999, 1, 4, 3, 9998, NULL, 'The highland steps include Rocking, Glasgow Highlander’s, Highland Schottische, Huntly.', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2990, '1997-08-20 22:00:00+00', '2021-05-27 21:30:27.819557+00', 'Hot Punch', 'HOT PUNCH', 2, 32, 9999, 1, 3, 42, 108, '1964-01-01', '', 50, '880/840/822/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (855, '2002-05-04 22:00:00+00', '2021-06-12 10:44:44.290867+00', 'Buckshaw Reel', 'BUCKSHAW REEL', 1, 32, 9999, 1, 2, 76, 3125, NULL, 'Devised for young dancers who meet at Buckshaw School', 43, '80/08/80/88', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (853, '1997-08-31 22:00:00+00', '2021-06-28 08:54:42.940689+00', 'Buckie Jig, The', 'BUCKIE JIG', 2, 32, 9999, 1, 2, 76, 394, NULL, 'Suited for Jig as well as Strathspey time (stated explicitly in the description of the dance).', 60, '88/80/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (842, '2001-12-16 23:00:00+00', '2021-06-28 09:24:52.326285+00', 'Bruce and Margaret Urquhart', 'BRUCE AND MARGARET URQUHART', 3, 32, 9999, 1, 3, 42, 21, NULL, '', 63, '880/808/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10500, '2002-11-13 23:00:00+00', '2022-09-13 13:28:29.498691+00', 'Golden Knot, The', 'GOLDEN KNOT', 3, 32, 9999, 6, 3, 17, 1253, NULL, '', 88, '666/666/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10502, '2002-04-29 22:00:00+00', '2022-10-01 19:06:25.137158+00', 'Catherine Wheels', 'CATHERINE WHEELS', 1, 32, 9999, 1, 4, 11, 3109, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2981, '1998-11-25 23:00:00+00', '2023-01-20 11:34:38.129516+00', 'Hopeful Lover, The', 'HOPEFUL LOVER', 1, 32, 9999, 1, 3, 42, 259, NULL, 'Inscribed "For Anthony Moretti".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (815, '1998-07-08 22:00:00+00', '2023-02-21 13:35:31.947147+00', 'Brisk Bob', 'BRISK BOB', 3, 32, 9999, 1, 100, 11, 108, '1975-02-02', 'The notes say "this dance was written at the request of Margaret Walker of Helensburgh to mark the first weekend school of the Dunbartonshire West Branch of the R.S.C.D.S."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (803, '1998-10-18 22:00:00+00', '2021-06-28 10:30:27.965081+00', 'Brig o'' Bogendreep', 'BRIG O BOGENDREEP', 1, 32, 9999, 1, 3, 42, 179, NULL, '', 52, '864/800/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (830, '1998-01-05 23:00:00+00', '2021-10-10 13:49:26.096071+00', 'Broken Spoke, A', 'BROKEN SPOKE', 1, 32, 9999, 1, 3, 42, 352, '1993-04-17', '', 44, '800/840/804/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10492, '2002-04-23 22:00:00+00', '2021-09-13 13:46:00.418084+00', 'Mug of Tea, A', 'MUG OF TEA', 3, 32, 9999, 1, 3, 42, 2764, '1992-01-01', '', 56, '844/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2995, '1997-04-03 22:00:00+00', '2018-04-03 00:07:52.959957+00', 'House of Cluny, The', 'HOUSE OF CLUNY', 3, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2998, '1997-09-04 22:00:00+00', '2018-04-03 00:07:52.968371+00', 'Housewarming, The', 'HOUSEWARMING', 3, 32, 9999, 1, 3, 42, 653, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3000, '1997-04-03 22:00:00+00', '2018-04-03 00:07:52.985047+00', 'Howards'' Jig, The', 'HOWARDS JIG', 2, 40, 9999, 1, 3, 42, 351, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3003, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.026694+00', 'Hubbard''s Cove', 'HUBBARDS COVE', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3005, '2003-01-26 23:00:00+00', '2018-04-03 00:07:53.035104+00', 'Hugh McKee''s Reel', 'HUGH MACKEES REEL', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (856, '1998-07-08 22:00:00+00', '2012-01-20 12:56:07.397003+00', 'Buffs'' And Gurkha''s March to Braemar, The', 'BUFFS AND GURKHAS MARCH TO BRAEMAR', 1, 40, 9999, 1, 4, 11, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (858, '1997-09-17 22:00:00+00', '2012-01-20 12:56:07.410746+00', 'Wee Willie Winkie', 'WEE WILLIE WINKIE', 3, 32, 9999, 1, 2, NULL, 416, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (863, '1997-04-03 22:00:00+00', '2018-06-17 08:41:53.732705+00', 'Bung Your Eye', 'BUNG YOUR EYE', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10508, '2002-04-29 22:00:00+00', '2018-04-02 23:56:33.054023+00', 'Blackpool & Fylde Strathspey', 'BLACKPOOL AND FYLDE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 11600, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (864, '1997-08-31 22:00:00+00', '2012-01-20 12:56:07.451781+00', 'Burdett, The', 'BURDETT', 2, 40, 9999, 1, 4, NULL, 731, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (865, '1997-08-31 22:00:00+00', '2012-01-20 12:56:07.458584+00', 'Burgundy''s Flight', 'BURGUNDYS FLIGHT', 1, 24, 9999, 1, 2, NULL, 446, '1713-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (866, '1997-08-31 22:00:00+00', '2012-01-20 12:56:07.465768+00', 'Burlington Centennial Strathspey', 'BURLINGTON CENTENNIAL STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 732, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3011, '1997-04-03 22:00:00+00', '2012-01-20 12:56:25.053019+00', 'Hummingbird Strathspey, The', 'HUMMINGBIRD STRATHSPEY', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13169, '2006-12-11 23:00:00+00', '2018-10-06 05:03:18.133986+00', 'Laura''s Reel', 'LAURAS REEL', 1, 32, 9999, 1, 4, 2, 2766, '2006-05-01', 'This reel is for Laura Gladstone.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3018, '1997-04-03 22:00:00+00', '2012-01-20 12:56:25.103038+00', 'Hunt''s Favourite, The', 'HUNTS FAVOURITE', 2, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3023, '1997-04-03 22:00:00+00', '2012-01-20 12:56:25.139501+00', 'Hunter''s Reel', 'HUNTERS REEL', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3024, '1997-08-20 22:00:00+00', '2012-01-20 12:56:25.146281+00', 'Hunter''s Reel, The', 'HUNTERS REEL', 3, 40, 9999, 1, 4, NULL, 108, '1964-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10510, '2002-04-30 22:00:00+00', '2019-03-02 23:42:47.361244+00', 'Cowburn Rant, The', 'COWBURN RANT', 1, 32, 9999, 1, 4, 1, 3114, NULL, '', 52, '8002/8008/8000/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (869, '1997-04-03 22:00:00+00', '2012-01-20 12:56:07.48773+00', 'Burn''s Club Rant', 'BURNS CLUB RANT', 1, 32, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (870, '1997-04-03 22:00:00+00', '2012-01-20 12:56:07.494581+00', 'Burn''s Night', 'BURNS NIGHT', 3, 32, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14416, '2012-03-08 16:46:59.560326+00', '2013-08-19 11:45:58.799401+00', 'Leading Ladies, The', 'LEADING LADIES', 2, 32, NULL, 1, 3, 42, 3775, '2008-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (879, '1997-08-31 22:00:00+00', '2012-01-20 12:56:07.556422+00', 'Burnside Strathspey', 'BURNSIDE STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 733, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (882, '1997-04-03 22:00:00+00', '2012-01-20 12:56:07.576768+00', 'Burton Jig', 'BURTON JIG', 2, 24, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (872, '1997-04-03 22:00:00+00', '2018-04-03 00:07:36.143871+00', 'Burnhervie Picnic', 'BURNHERVIE PICNIC', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3028, '1997-09-04 22:00:00+00', '2012-01-20 12:56:25.176099+00', 'Hunting MacLeod, The', 'HUNTING MACLEOD', 3, 32, 9999, 1, 4, NULL, 293, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3034, '1997-10-27 23:00:00+00', '2012-01-20 12:56:25.2178+00', 'Hurdle Race, The', 'HURDLE RACE', 1, 32, 9999, 1, 4, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3035, '1997-04-03 22:00:00+00', '2012-01-20 12:56:25.22466+00', 'Hurlock''s Reel', 'HURLOCKS REEL', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (876, '1997-11-27 23:00:00+00', '2016-05-12 22:32:00.398121+00', 'Burns Night Foursome', 'BURNS NIGHT FOURSOME', 4, 128, 2, 104, 125, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (859, '1998-10-22 22:00:00+00', '2016-04-04 01:18:51.789818+00', 'Bull Stane, The', 'BULL STANE', 1, 40, 9999, 1, 3, 42, 50, '1975-01-01', '', 55, '888/800/12 12 12/444/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (881, '1997-08-31 22:00:00+00', '2016-09-04 20:28:16.034539+00', 'Burst The Fetters', 'BURST THE FETTERS', 2, 32, 9999, 1, 2, 76, 351, NULL, 'Named for the two "chains", both of which are broken off before the end.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10509, '2002-04-29 22:00:00+00', '2016-09-23 22:42:43.639946+00', 'Crystal Reel', 'CRYSTAL REEL', 1, 32, 9999, 1, 4, 1, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (880, '1997-08-31 22:00:00+00', '2018-04-03 00:07:36.152198+00', 'Burnt Potato', 'BURNT POTATO', 2, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (884, '1997-04-03 22:00:00+00', '2018-04-03 00:07:36.208742+00', 'Butcher''s Broom', 'BUTCHERS BROOM', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3026, '1997-04-03 22:00:00+00', '2020-04-29 22:55:38.365166+00', 'Huntie Gowk', 'HUNTIE GOWK', 1, 32, 9999, 5, 4, NULL, 270, NULL, 'The name means "April Fool"', 100, '8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2999, '1997-09-04 22:00:00+00', '2021-05-27 21:25:11.028352+00', 'How Does It Go?', 'HOW DOES IT GO', 2, 32, 9999, 1, 3, 42, 1006, NULL, '', 44, '800/804/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (854, '1997-04-03 22:00:00+00', '2020-05-14 22:47:50.255737+00', 'Bucksburn Reel, The', 'BUCKSBURN REEL', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (857, '1997-04-03 22:00:00+00', '2020-08-29 12:50:03.353586+00', 'Builders Of Wainfleet, The', 'BUILDERS OF WAINFLEET', 3, 32, 9999, 6, 3, 18, 48, NULL, '', 75, '444/888/444/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3012, '1997-04-03 22:00:00+00', '2020-10-21 10:31:32.146388+00', 'Humours of Castle Barnard', 'HUMOURS OF CASTLE BARNARD', 1, 32, 9999, 5, 4, 30, 270, NULL, '', 100, '8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10501, '2002-04-24 22:00:00+00', '2021-02-08 13:43:10.583308+00', 'Trip to Blairgowrie, A', 'TRIP TO BLAIRGOWRIE', 2, 40, 9999, 1, 3, 42, 692, '2001-01-01', '', 63, '833/888/888/833/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2997, '1998-01-05 23:00:00+00', '2021-02-26 12:17:19.791439+00', 'Housewarming, The', 'HOUSEWARMING', 1, 32, 9999, 1, 3, 42, 1005, NULL, '', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3016, '1998-04-23 22:00:00+00', '2021-05-31 23:12:01.286748+00', '100th Monkey', '100TH MONKEY', 1, 32, 9999, 1, 2, 76, 352, '1991-06-04', '', 60, '80/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (861, '1997-04-03 22:00:00+00', '2021-06-13 20:11:21.827563+00', 'Bulrush, The', 'BULRUSH', 1, 48, 9999, 1, 4, 1, 352, '1991-05-19', '', 67, '8440/8484/8080/0808/8448/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (889, '2000-03-30 22:00:00+00', '2021-06-28 00:35:04.21884+00', 'By Dundonald', 'BY DUNDONALD', 3, 32, 9999, 2, 3, 18, 21, NULL, '', 56, '880/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (871, '1997-04-03 22:00:00+00', '2021-06-28 00:42:31.488395+00', 'Burnham Park', 'BURNHAM PARK', 2, 40, 9999, 2, 3, 17, 104, NULL, '', 63, '844/866/822/866/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3014, '1997-08-25 22:00:00+00', '2021-11-08 00:02:31.806226+00', 'Hundred Pipers, A', 'HUNDRED PIPERS', 1, 32, 9999, 1, 4, 1, 544, '1977-01-01', '', 50, '8008/8448/0880/8000', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (892, '1997-04-03 22:00:00+00', '2022-08-18 20:06:07.004865+00', 'By Tyneside Waters', 'BY TYNESIDE WATERS', 3, 40, 9999, 1, 3, 42, 39, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3001, '1997-04-03 22:00:00+00', '2022-01-24 12:45:08.88491+00', 'Howe O'' Fife, The', 'HOWE O FIFE', 3, 32, 9999, 2, 3, 17, 313, NULL, '', 71, '888/822/844/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (862, '1998-11-25 23:00:00+00', '2022-11-30 19:35:37.578975+00', 'Bumpkin, The', 'BUMPKIN', 2, 224, 9999, 4, 111, 3, 397, '1754-02-02', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (885, '1997-11-27 23:00:00+00', '2022-12-24 20:25:44.750296+00', 'Butter the Horse''s Ear', 'BUTTER THE HORSES EAR', 4, 160, 10, 4, 4, 54, 270, NULL, '', 95, '8888/8888/8888/8888/8888/8888/8888/8888/4444/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (850, '1997-04-03 22:00:00+00', '2023-02-21 13:16:58.140973+00', 'Buchan Strathspey, The', 'BUCHAN STRATHSPEY', 3, 24, 9999, 1, 3, 42, 418, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3015, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.060111+00', 'Hundred Thousand Welcomes, A', 'HUNDRED THOUSAND WELCOMES', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3029, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.093407+00', 'Hunting the Pinecones', 'HUNTING THE PINECONES', 1, 40, 9999, 1, 3, 42, 44, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3032, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.101726+00', 'Huntsman''s Chorus', 'HUNTSMANS CHORUS', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10511, '2002-04-30 22:00:00+00', '2012-01-20 12:57:22.016084+00', 'Crossways', 'CROSSWAYS', 1, 32, 9999, 1, 4, 2, 3113, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (901, '1997-04-03 22:00:00+00', '2012-01-20 12:56:07.709834+00', 'Caber, The', 'CABER', 1, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (903, '2002-11-26 23:00:00+00', '2012-01-20 12:56:07.723525+00', 'Cabot Trail, The', 'CABOT TRAIL', 1, 64, 9999, 2, 3, NULL, 425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (906, '2002-11-29 23:00:00+00', '2012-01-20 12:56:07.74462+00', 'Cadenza', 'CADENZA', 2, 40, 9999, 1, 4, NULL, 2617, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14417, '2012-03-08 16:52:55.41868+00', '2013-08-19 11:45:59.659424+00', '"O", The', 'O', 3, 32, NULL, 4, 4, 1, 10610, NULL, 'For Oliver''s 40th birthday', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (912, '1998-07-09 22:00:00+00', '2012-01-20 12:56:07.78636+00', 'Caerketton', 'CAERKETTON', 3, 48, 9999, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (913, '1998-07-09 22:00:00+00', '2012-01-20 12:56:07.793818+00', 'Caerlaverock Castle', 'CAERLAVEROCK CASTLE', 3, 40, 9999, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (914, '1997-08-31 22:00:00+00', '2012-01-20 12:56:07.800714+00', 'Caerleon Ruby, The', 'CAERLEON RUBY', 1, 80, 9999, 4, 4, NULL, 735, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (918, '1997-04-03 22:00:00+00', '2012-01-20 12:56:07.828084+00', 'Cairn, The', 'CAIRN', 3, 32, 9999, 1, 4, NULL, 197, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19209, '2019-03-02 10:35:08.137282+00', '2019-03-02 10:36:13.364337+00', 'Rickety', 'RICKETY', 1, 48, NULL, 1, 4, NULL, 3165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (922, '1997-04-03 22:00:00+00', '2012-01-20 12:56:07.855938+00', 'Cairngorm Brooch, The', 'CAIRNGORM BROOCH', 3, 32, 9999, 5, 2, NULL, 305, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19210, '2019-03-02 10:37:29.505952+00', '2019-03-02 10:37:29.505952+00', 'M.V. St. Ola, The', 'MV ST OLA', 2, 32, NULL, 3, 5, NULL, 3165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3039, '1997-10-27 23:00:00+00', '2012-01-20 12:56:25.252086+00', 'I Daurna Say No', 'I DAURNA SAY NO', 2, 48, 9999, 1, 4, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (940, '1998-01-05 23:00:00+00', '2019-08-29 20:27:33.608595+00', 'Caley Capers', 'CALEY CAPERS', 1, 40, 9999, 1, 3, 42, 516, '1989-01-01', '', 53, '844/833/833/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (926, '1997-04-03 22:00:00+00', '2019-10-27 20:58:48.915136+00', 'Caithness Volunteers', 'CAITHNESS VOLUNTEERS', 1, 32, 9999, 1, 2, 76, 270, NULL, '', 52, '80/80/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3049, '1997-04-03 22:00:00+00', '2012-01-20 12:56:25.322016+00', 'I''m The Saftest O'' The Family', 'IM THE SAFTEST O THE FAMILY', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10517, '2002-04-30 22:00:00+00', '2012-01-20 12:57:22.065952+00', 'Ian Alexander''s Reel', 'IAN ALEXANDERS REEL', 1, 32, 9999, 1, 3, 42, 520, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (933, '1998-01-05 23:00:00+00', '2012-01-20 12:56:07.93593+00', 'Caledonia Reel', 'CALEDONIA REEL', 1, 32, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (943, '1998-01-05 23:00:00+00', '2012-01-20 12:56:08.008056+00', 'Calico and Paisley', 'CALICO AND PAISLEY', 1, 32, 9999, 1, 2, NULL, 348, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3043, '1997-11-27 23:00:00+00', '2016-11-16 00:12:31.911575+00', 'I Shall Return!', 'I SHALL RETURN', 4, 32, 1, 1, 4, 1, 1013, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (938, '1997-08-31 22:00:00+00', '2017-02-25 13:05:27.52548+00', 'Caledonian Roundabout', 'CALEDONIAN ROUNDABOUT', 1, 32, 9999, 5, 2, NULL, 264, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (921, '1997-04-03 22:00:00+00', '2018-04-03 00:07:36.402592+00', 'Cairngorm', 'CAIRNGORM', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (923, '1997-04-03 22:00:00+00', '2018-04-03 00:07:36.410768+00', 'Cairns Of Maryland, The', 'CAIRNS OF MARYLAND', 2, 32, 9999, 1, 3, 42, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (927, '2002-03-12 23:00:00+00', '2018-04-03 00:07:36.419278+00', 'Calabogie Reel, The', 'CALABOGIE REEL', 1, 32, 9999, 1, 3, 42, 111, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (944, '2002-03-02 23:00:00+00', '2018-04-03 00:07:36.51098+00', 'Californian MacLeod', 'CALIFORNIAN MACLEOD', 3, 32, 9999, 1, 3, 42, 35, '1989-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3040, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.243411+00', 'I Ha''e Laid A Herring In Salt', 'I HAE LAID A HERRING IN SALT', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3044, '1997-10-20 22:00:00+00', '2018-04-03 00:07:53.268563+00', 'I''ll Come Tae Ye', 'ILL COME TAE YE', 2, 36, 9999, 1, 3, 42, 270, NULL, 'Phrases: 10,8,10,8', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (886, '1998-07-08 22:00:00+00', '2020-02-08 20:30:08.758382+00', 'Butterfly Bride', 'BUTTERFLY BRIDE', 1, 48, 9999, 1, 100, 2, 127, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10522, '2002-04-30 22:00:00+00', '2021-02-07 12:28:59.214364+00', 'Sirius', 'SIRIUS', 3, 32, 9999, 1, 4, 1, 520, NULL, '', 81, '4444/8888/8888/8088', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (897, '1998-11-05 23:00:00+00', '2020-04-29 21:53:04.088858+00', 'C. M. Beattie', 'C M BEATTIE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 44, '800/866/866/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3048, '1998-07-09 22:00:00+00', '2020-05-14 22:53:09.154695+00', 'I''m Doun for Lak O'' Johnnie', 'IM DOUN FOR LAK O JOHNNIE', 3, 40, 9999, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (915, '1998-10-21 22:00:00+00', '2021-06-26 20:09:18.806437+00', 'Cairdin'' O''t, The', 'CAIRDIN OT', 1, 32, 9999, 1, 2, 76, 44, '1978-01-01', '', 69, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3013, '1998-03-24 23:00:00+00', '2020-09-27 22:18:59.96282+00', 'Humours of Glendart, The', 'HUMOURS OF GLENDART', 2, 32, 9999, 1, 3, 42, 270, NULL, '', 50, '800/800/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10521, '2002-04-30 22:00:00+00', '2021-02-07 18:24:13.167579+00', 'Royal Navy Hornpipe, The', 'ROYAL NAVY HORNPIPE', 1, 32, 9999, 1, 4, 5, 520, '1999-01-01', '', 91, '8888/7777/4488/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10518, '2002-04-30 22:00:00+00', '2021-02-08 10:57:40.045507+00', 'Neil''s Reel', 'NEILS REEL', 3, 40, 9999, 1, 4, 15, 520, NULL, '', 65, '8000/8080/8800/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10516, '2002-04-30 22:00:00+00', '2021-02-08 11:05:52.689916+00', 'Hunterston Brooch, The', 'HUNTERSTON BROOCH', 2, 32, 9999, 1, 4, 22, 520, NULL, '', 94, '8888/8888/8888/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (931, '1997-08-31 22:00:00+00', '2021-09-18 21:31:14.262695+00', 'Cauldron Linn, The', 'CAULDRON LINN', 1, 32, 9999, 1, 3, 18, 352, '1990-11-01', 'The Cauldron Linn is the name for three round holes worn by cataracts on the river Devon.', 63, '844/888/888/808', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (935, '1998-01-05 23:00:00+00', '2021-10-14 17:59:57.344422+00', 'Caledonian Forest, The', 'CALEDONIAN FOREST', 1, 32, 9999, 1, 3, 42, 352, '1991-05-31', '', 47, '800/880/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (932, '1997-04-03 22:00:00+00', '2021-06-26 19:55:13.048354+00', 'Caledon Hills, The', 'CALEDON HILLS', 1, 32, 9999, 1, 3, 42, 249, NULL, '', 50, '844/800/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10512, '2002-04-30 22:00:00+00', '2021-08-02 04:03:10.548892+00', 'Miss Adele''s Delight', 'MISS ADELES DELIGHT', 4, 48, 58, 1, 4, 1, 452, '1985-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10513, '2002-11-19 23:00:00+00', '2021-08-02 04:11:51.234118+00', 'Dance for all the McKays, A', 'DANCE FOR ALL THE MACKAYS', 2, 40, 9999, 1, 4, 1, 452, '1996-01-01', '', 55, '8880/8800/8800/8080/8044', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3050, '1997-09-04 22:00:00+00', '2018-04-03 00:07:54.73617+00', 'I.W. Kirkpatrick', 'IW KIRKPATRICK', 3, 32, 9999, 1, 3, 42, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (945, '1998-01-05 23:00:00+00', '2018-04-29 22:09:35.703553+00', 'Call It What You Will', 'CALL IT WHAT YOU WILL', 1, 40, 9999, 1, 3, 42, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (948, '1997-08-27 22:00:00+00', '2012-01-20 12:56:08.04217+00', 'Callanish Vows', 'CALLANISH VOWS', 3, 64, 9999, 1, 4, NULL, 583, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (907, '1998-04-08 22:00:00+00', '2022-07-30 18:51:32.30509+00', 'Cadger Of Crief, The', 'CADGER OF CRIEF', 3, 32, 9999, 1, 3, 42, 9998, '1740-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3022, '1997-09-04 22:00:00+00', '2022-08-20 18:07:08.205979+00', 'Hunter''s Rant', 'HUNTERS RANT', 3, 40, 9999, 1, 3, 42, 318, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (920, '1997-04-03 22:00:00+00', '2022-12-24 20:53:41.713906+00', 'Cairney Mount', 'CAIRNEY MOUNT', 1, 40, 9999, 1, 3, 42, 270, NULL, '', 48, '800/844/844/844/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (934, '1997-11-18 23:00:00+00', '2023-02-21 13:09:24.411288+00', 'Caledonian Country Dance', 'CALEDONIAN COUNTRY DANCE', 3, 24, 9999, 1, 2, 76, 9998, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (925, '1997-09-29 22:00:00+00', '2023-02-21 13:13:41.940569+00', 'Caithness Heart, The', 'CAITHNESS HEART', 1, 32, 9999, 1, 2, 76, 13, NULL, 'According to the notes "This dance was devised especially for Dillwyn John and his fellow dancers at

Chirping Norton." 



A Caithness Heart is a heart-shaped corn dolly with a bow in the middle.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (952, '1997-04-03 22:00:00+00', '2012-01-20 12:56:08.071548+00', 'Callum Donaldson', 'CALLUM DONALDSON', 1, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (953, '1997-04-03 22:00:00+00', '2012-01-20 12:56:08.078324+00', 'Callum''s Square', 'CALLUMS SQUARE', 4, 64, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19211, '2019-03-02 10:41:42.767108+00', '2019-03-02 10:41:42.767108+00', 'Mor Hafren', 'MOR HAFREN', 3, 32, NULL, 2, 3, NULL, 3165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3060, '1997-08-30 22:00:00+00', '2012-01-20 12:56:25.399675+00', 'Ian Powrie''s Welcome To Canberra', 'IAN POWRIES WELCOME TO CANBERRA', 2, 32, 9999, 1, 4, NULL, 85, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3062, '1997-08-28 22:00:00+00', '2012-01-20 12:56:25.413342+00', 'Ian''s Strathspey', 'IANS STRATHSPEY', 3, 48, 9999, 1, 4, NULL, 592, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10526, '2002-12-05 23:00:00+00', '2012-01-20 12:57:22.18969+00', 'Dancing in 2000', 'DANCING IN 2000', 1, 40, 9999, 1, 4, 1, 3116, NULL, 'Devised to celebrate the year 2000.  Figures represent the digits "2" "0" "00"', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10529, '2002-04-30 22:00:00+00', '2012-01-20 12:57:22.210431+00', 'Friends Old and New', 'FRIENDS OLD AND NEW', 4, 64, 22, 1, 4, NULL, 617, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (930, '1998-01-05 23:00:00+00', '2012-02-22 21:47:38.855408+00', 'Calderwood Reel, The', 'CALDERWOOD REEL', 1, 32, 9999, 1, 3, 42, 736, NULL, 'The full deviser information is "Mrs. Betty Beveridge and the Children of the Brunstane Primary School"', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19533, '2019-08-12 08:47:22.429718+00', '2019-08-12 08:47:22.429718+00', 'Fugal Floozy', 'FUGAL FLOOZY', 1, 32, NULL, 2, 3, 17, 11856, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (947, '1997-08-31 22:00:00+00', '2018-04-03 00:07:36.527459+00', 'Callanish Stones', 'CALLANISH STONES', 2, 32, 9999, 1, 3, 42, 738, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (957, '1997-08-31 22:00:00+00', '2012-01-20 12:56:08.105702+00', 'Calum Of Cleat', 'CALUM OF CLEAT', 2, 96, 9999, 4, 4, NULL, 739, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (960, '1997-04-03 22:00:00+00', '2012-01-20 12:56:08.126332+00', 'Camaraderie', 'CAMARADERIE', 2, 32, 9999, 3, 5, NULL, 385, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (951, '1997-04-03 22:00:00+00', '2018-04-03 00:07:36.560876+00', 'Callum Beag', 'CALLUM BEAG', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (966, '1997-04-03 22:00:00+00', '2012-01-20 12:56:08.169228+00', 'Camel''s Hump', 'CAMELS HUMP', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (967, '1997-08-31 22:00:00+00', '2012-01-20 12:56:08.176189+00', 'Camelot', 'CAMELOT', 4, 64, 9999, 4, 4, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (968, '1997-04-03 22:00:00+00', '2012-01-20 12:56:08.183004+00', 'Cameron Got His Wife Again', 'CAMERON GOT HIS WIFE AGAIN', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (961, '1997-04-03 22:00:00+00', '2018-04-03 00:07:36.619411+00', 'Cambridge Bay Reel, The', 'CAMBRIDGE BAY REEL', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (973, '1997-08-31 22:00:00+00', '2012-01-20 12:56:08.217559+00', 'Camp, The', 'CAMP', 3, 32, 9999, 1, 3, 42, 59, NULL, 'Official Alias: Larnach Castle', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (949, '1997-08-24 22:00:00+00', '2014-04-28 14:24:21.053549+00', 'Callendar House', 'CALLENDAR HOUSE', 2, 48, 9999, 1, 4, 1, 108, '1990-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (983, '1997-11-20 23:00:00+00', '2012-01-20 12:56:08.288212+00', 'Campbell''s Strathspey', 'CAMPBELLS STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3064, '1997-04-03 22:00:00+00', '2012-01-20 12:56:25.426895+00', 'Ikoyi Club, The', 'IKOYI CLUB', 2, 40, 9999, 1, 4, NULL, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3068, '1998-09-17 22:00:00+00', '2012-01-20 12:56:25.454058+00', 'Chain Reaction', 'CHAIN REACTION', 3, 32, 9999, 1, 4, NULL, 2140, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3070, '2000-06-12 22:00:00+00', '2012-01-20 12:56:25.467733+00', 'Imperial Strathspey, The', 'IMPERIAL STRATHSPEY', 3, 48, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (969, '1997-04-03 22:00:00+00', '2018-04-03 00:07:36.694485+00', 'Cameron Lass', 'CAMERON LASS', 1, 32, 9999, 1, 3, 42, 300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (970, '1997-04-03 22:00:00+00', '2016-07-15 05:15:56.239384+00', 'Cameron Toll', 'CAMERON TOLL', 2, 40, 9999, 1, 4, 1, 352, '1993-06-14', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (939, '2002-04-19 22:00:00+00', '2016-09-26 23:41:08.698469+00', 'Caledonian Strathspey, The', 'CALEDONIAN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 332, NULL, '', 55, '886/888/880/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (959, '1997-08-31 22:00:00+00', '2017-12-28 10:10:48.204+00', 'Cam''nethan Priory', 'CAMNETHAN PRIORY', 2, 40, 9999, 1, 4, NULL, 149, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (978, '1997-11-20 23:00:00+00', '2018-04-03 00:07:36.711142+00', 'Campbell''s Fancy', 'CAMPBELLS FANCY', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (979, '1997-08-31 22:00:00+00', '2018-04-03 00:07:36.719472+00', 'Campbell''s Farewell to Redcastle', 'CAMPBELLS FAREWELL TO REDCASTLE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (982, '1997-04-03 22:00:00+00', '2018-04-03 00:07:36.736061+00', 'Campbell''s Knot', 'CAMPBELLS KNOT', 3, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10527, '2002-12-05 23:00:00+00', '2018-04-03 00:07:44.427431+00', 'Elspeth''s Delight', 'ELSPETHS DELIGHT', 1, 48, 9999, 1, 3, 42, 3117, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10528, '2002-04-30 22:00:00+00', '2018-04-03 00:07:45.186526+00', 'Farewell to Alister', 'FAREWELL TO ALISTER', 1, 32, 9999, 1, 3, 42, 3118, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3055, '1997-10-27 23:00:00+00', '2018-04-03 00:07:53.168383+00', 'Ian Duncan', 'IAN DUNCAN', 1, 32, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3056, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.184963+00', 'Ian James Ogilvie', 'IAN JAMES OGILVIE', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3061, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.201669+00', 'Ian''s Reel', 'IANS REEL', 2, 32, 9999, 1, 3, 42, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19512, '2019-08-02 21:07:04.348586+00', '2020-11-26 10:39:54.022713+00', 'My First Ever SCD', 'MY FIRST EVER SCD', 2, 32, NULL, 1, 4, 1, 11035, NULL, '', 59, '8000/8444/8888/8008', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3041, '1997-04-03 22:00:00+00', '2020-10-10 11:45:22.47223+00', 'I Lo''ed Nae Lassie But Ane', 'I LOED NAE LASSIE BUT ANE', 3, 40, 9999, 1, 3, 42, 270, NULL, '', 55, '800/888/888/800/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10525, '2002-04-30 22:00:00+00', '2021-02-07 12:20:50.788891+00', 'Ultramarine', 'ULTRAMARINE', 3, 40, 9999, 1, 4, 1, 520, NULL, '', 57, '8000/8440/8000/4888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10520, '2002-04-30 22:00:00+00', '2021-02-07 18:26:21.036736+00', 'Out and About', 'OUT AND ABOUT', 1, 40, 9999, 1, 3, 42, 520, NULL, '', 55, '880/800/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3053, '1997-09-04 22:00:00+00', '2021-04-07 19:04:02.420802+00', 'Iain MacPhail''s Jig', 'IAIN MACPHAILS JIG', 2, 32, 9999, 1, 4, 1, 21, NULL, '', 86, '8888/8888/8888/8006', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3051, '1997-09-04 22:00:00+00', '2021-04-07 19:10:37.274569+00', 'Iain D. MacPhail', 'IAIN D MACPHAIL', 1, 32, 9999, 3, 5, 7, 21, NULL, '', 65, '88880/80800/88888/80800', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3054, '1997-04-03 22:00:00+00', '2021-05-26 10:10:47.632966+00', 'Iain Nixon''s Reel', 'IAIN NIXONS REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 56, '862/826/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3069, '1997-04-03 22:00:00+00', '2021-06-20 22:22:39.164931+00', 'Immemorial Strathspey', 'IMMEMORIAL STRATHSPEY', 3, 32, 9999, 1, 4, 1, 352, '1991-08-03', 'The dance name was "taken from the label of a bottle of malt whiskey".', 50, '8000/8440/8880/8044', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (974, '1997-08-31 22:00:00+00', '2021-06-25 11:39:30.723364+00', 'Campbell of Cawdor', 'CAMPBELL OF CAWDOR', 3, 32, 9999, 1, 2, 76, 181, NULL, '', 47, '80/88/80/84', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10514, '2002-08-29 22:00:00+00', '2021-08-02 08:52:04.010406+00', 'Three Rivers Reel, The', 'THREE RIVERS REEL', 1, 40, 9999, 1, 3, 42, 452, '1983-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (971, '1999-08-06 22:00:00+00', '2021-06-25 22:39:05.128546+00', 'Cameronian''s Farewell, The', 'CAMERONIANS FAREWELL', 1, 48, 9999, 1, 3, 42, 476, NULL, '', 50, '800/866/866/866/866/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3072, '1997-12-22 23:00:00+00', '2018-04-03 00:07:53.360391+00', 'In Ballad Country', 'IN BALLAD COUNTRY', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3073, '1998-01-05 23:00:00+00', '2012-01-20 12:56:25.48853+00', 'In Between', 'IN BETWEEN', 1, 32, 9999, 3, 5, NULL, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (987, '1998-01-05 23:00:00+00', '2018-04-29 10:13:03.184493+00', 'Canadian Bagpipes, The', 'CANADIAN BAGPIPES', 1, 40, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3075, '2002-06-30 22:00:00+00', '2012-01-20 12:56:25.506517+00', 'In Going E''e, The', 'IN GOING EE', 3, 48, 9999, 1, 4, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3076, '1998-07-08 22:00:00+00', '2012-01-20 12:56:25.516144+00', 'In Paradise', 'IN PARADISE', 3, 32, 9999, 1, 4, 2, 108, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (962, '1998-11-17 23:00:00+00', '2023-02-21 12:50:39.121067+00', 'Cambridge Six', 'CAMBRIDGE SIX', 3, 32, 9999, 2, 3, 17, 2433, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3078, '1997-04-03 22:00:00+00', '2012-01-20 12:56:25.534792+00', 'In Quietness and Dignity', 'IN QUIETNESS AND DIGNITY', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10531, '2002-10-15 22:00:00+00', '2018-06-27 05:40:37.357044+00', 'Gold in Sydney', 'GOLD IN SYDNEY', 1, 40, 9999, 1, 3, 42, 74, NULL, 'Devised by Brian Charlton to celebrate the 50th Anniversary of the formation of the R.S.C.D.S.

Sydney Branch.', 50, '880/800/844/844/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18674, '2018-10-01 11:37:56.645868+00', '2018-10-01 11:53:14.247712+00', 'Alberta Arts', 'ALBERTA ARTS', 2, 32, NULL, 1, 3, 42, 2766, '2015-01-01', 'This dance is named for a colorway of yarn given to me this past Christmas. Also, my grandfather was born in Alberta, Canada.', 59, '888/888/822/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1007, '1997-08-31 22:00:00+00', '2019-03-19 00:19:49.322746+00', 'Captain Bain''s Tribute', 'CAPTAIN BAINS TRIBUTE', 2, 40, 9999, 1, 4, 2, 743, NULL, '', 65, '8008/8888/8008/8008/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (995, '1997-08-31 22:00:00+00', '2019-10-27 22:29:13.727212+00', 'Cantie Auld Man', 'CANTIE AULD MAN', 2, 32, 9999, 5, 56, NULL, 270, NULL, '', 64, '888/484/688/686', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3088, '2002-02-27 23:00:00+00', '2019-08-28 21:09:46.636163+00', 'Indian Peter''s Reel', 'INDIAN PETERS REEL', 1, 32, 9999, 1, 3, 42, 101, '1993-01-01', '', 53, '844/888/800/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (993, '1998-07-08 22:00:00+00', '2012-01-20 12:56:08.353063+00', 'Canny Bargain, A', 'CANNY BARGAIN', 1, 32, 9999, 1, 4, 2, 740, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10536, '2002-12-05 23:00:00+00', '2018-04-03 00:07:31.295551+00', 'As Light as a Feather', 'AS LIGHT AS A FEATHER', 3, 32, 9999, 1, 3, 42, 3117, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1005, '1998-01-05 23:00:00+00', '2012-01-20 12:56:08.490999+00', 'Captain and Mrs. Raeburn', 'CAPTAIN AND MRS RAEBURN', 1, 32, 9999, 1, 2, NULL, 211, '1974-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1006, '1997-04-03 22:00:00+00', '2012-01-20 12:56:08.497933+00', 'Captain Arthur Phillip', 'CAPTAIN ARTHUR PHILLIP', 3, 40, 9999, 1, 4, NULL, 20, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1010, '1997-08-31 22:00:00+00', '2012-01-20 12:56:08.525178+00', 'Captain Francis Wemys', 'CAPTAIN FRANCIS WEMYS', 3, 48, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1011, '1997-08-31 22:00:00+00', '2012-01-20 12:56:08.531972+00', 'Captain George', 'CAPTAIN GEORGE', 1, 32, 9999, 4, 4, NULL, 745, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1014, '1997-08-31 22:00:00+00', '2012-01-20 12:56:08.562376+00', 'Captain Horne', 'CAPTAIN HORNE', 3, 40, 9999, 2, 3, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (990, '1997-04-03 22:00:00+00', '2018-04-03 00:07:36.752865+00', 'Canberra''s Shores', 'CANBERRAS SHORES', 3, 32, 9999, 1, 3, 42, 293, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1016, '1997-04-03 22:00:00+00', '2012-01-20 12:56:08.57787+00', 'Captain Keeler''s Reel', 'CAPTAIN KEELERS REEL', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3079, '1997-04-03 22:00:00+00', '2012-01-20 12:56:25.543606+00', 'In Sterner Times', 'IN STERNER TIMES', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3081, '1998-07-08 22:00:00+00', '2012-01-20 12:56:25.565386+00', 'In The Ottawa Valley', 'IN THE OTTAWA VALLEY', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3086, '2003-01-30 23:00:00+00', '2012-01-20 12:56:25.609668+00', 'Inclement Wragge', 'INCLEMENT WRAGGE', 1, 32, 9999, 2, 3, 17, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10538, '2002-05-01 22:00:00+00', '2012-01-20 12:57:22.275013+00', 'Fairy''s Jig', 'FAIRYS JIG', 2, 32, 9999, 1, 4, 1, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (996, '2002-03-12 23:00:00+00', '2018-04-03 00:07:36.844673+00', 'Cantie Wee Barmaid, The', 'CANTIE WEE BARMAID', 1, 32, 9999, 1, 3, 42, 111, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1023, '1998-01-05 23:00:00+00', '2012-01-20 12:56:08.627167+00', 'Captain Stirling''s Reel', 'CAPTAIN STIRLINGS REEL', 1, 48, 9999, 1, 4, NULL, 747, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1031, '2002-04-19 22:00:00+00', '2012-01-20 12:56:08.68361+00', 'Cariboo Country Dance', 'CARIBOO COUNTRY DANCE', 3, 32, 9999, 1, 2, NULL, 392, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (997, '1997-04-03 22:00:00+00', '2018-04-03 00:07:36.853045+00', 'Canty Couple, The', 'CANTY COUPLE', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1021, '1997-04-03 22:00:00+00', '2018-04-03 00:07:36.953066+00', 'Captain Pringle of Yair', 'CAPTAIN PRINGLE OF YAIR', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1026, '1997-11-24 23:00:00+00', '2018-04-03 00:07:36.969665+00', 'Captain''s Balls, The', 'CAPTAINS BALLS', 4, 32, 1, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1028, '1997-04-03 22:00:00+00', '2018-04-03 00:07:36.994673+00', 'Caretaker''s Jig', 'CARETAKERS JIG', 2, 32, 9999, 1, 3, 42, 123, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10530, '2002-04-30 22:00:00+00', '2018-04-03 00:07:47.438652+00', 'Fylde Cross, The', 'FYLDE CROSS', 1, 40, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3087, '2003-01-29 23:00:00+00', '2018-04-03 00:07:53.393833+00', 'Independence Reel', 'INDEPENDENCE REEL', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3077, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.477134+00', 'In Peace Or War', 'IN PEACE OR WAR', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3082, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.618902+00', 'In the South', 'IN THE SOUTH', 3, 32, 9999, 1, 3, 42, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3074, '1997-09-05 22:00:00+00', '2018-04-03 00:07:55.711826+00', 'Jimmy Shankland''s Reel', 'JIMMY SHANKLANDS REEL', 1, 32, 9999, 1, 3, 42, 1027, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10541, '2002-05-02 22:00:00+00', '2020-05-15 22:21:53.203579+00', '1915 Penny, The', '1915 PENNY', 3, 32, 9999, 6, 3, 17, 3122, NULL, '', 88, '666/666/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1032, '1997-08-20 22:00:00+00', '2020-08-29 15:39:32.249754+00', 'Caribou Gathering, The', 'CARIBOU GATHERING', 1, 40, 9999, 1, 3, 42, 101, '1991-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1004, '1997-08-31 22:00:00+00', '2021-07-08 08:27:39.875509+00', 'Capstan, The', 'CAPSTAN', 1, 48, 9999, 1, 4, 14, 742, NULL, 'Dedicated to Captain Henderson. The dance is repeated once.', 96, '4884/8888/8888/8888/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1027, '1997-08-31 22:00:00+00', '2020-08-03 06:54:18.48026+00', 'Captain''s Round', 'CAPTAINS ROUND', 2, 24, 9999, 5, 2, NULL, 109, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (999, '1997-04-03 22:00:00+00', '2020-08-29 12:57:17.169635+00', 'Cape Breton Island', 'CAPE BRETON ISLAND', 1, 32, 9999, 1, 100, 2, 108, '1988-07-01', 'DEVISED:1988-07', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10539, '2002-05-02 22:00:00+00', '2021-02-07 12:12:56.978235+00', 'Half Crown Jig', 'HALF CROWN JIG', 2, 32, 9999, 107, 122, NULL, 1649, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10524, '2002-04-30 22:00:00+00', '2021-02-07 12:23:29.128203+00', 'Trek to Kyrgyzstan', 'TREK TO KYRGYZSTAN', 1, 32, 9999, 1, 3, 42, 520, '1999-01-01', '', 59, '880/888/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10523, '2002-04-30 22:00:00+00', '2021-02-07 12:26:12.113601+00', 'Skagit Strathspey, The', 'SKAGIT STRATHSPEY', 3, 32, 9999, 1, 3, 42, 520, NULL, '', 53, '800/844/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1029, '1997-08-31 22:00:00+00', '2021-06-23 12:11:09.368725+00', 'Caretaker, The', 'CARETAKER', 1, 32, 9999, 1, 2, 76, 727, NULL, '', 52, '66/66/44/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (992, '1998-04-05 22:00:00+00', '2021-06-25 08:21:14.816171+00', 'Cannon Hill Assembly', 'CANNON HILL ASSEMBLY', 3, 32, 9999, 4, 4, 13, 181, NULL, '', 91, '5555/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1035, '1997-08-31 22:00:00+00', '2012-01-20 12:56:08.711413+00', 'China Wedding, The', 'CHINA WEDDING', 1, 32, 9999, 1, 4, NULL, 774, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1040, '1997-04-03 22:00:00+00', '2018-04-29 10:49:44.142064+00', 'Carlyle House', 'CARLYLE HOUSE', 3, 40, 9999, 1, 3, 42, 108, '1976-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3092, '1998-01-05 23:00:00+00', '2018-04-29 21:24:26.997322+00', 'Ingrid''s Frolic', 'INGRIDS FROLIC', 1, 32, 9999, 1, 3, 42, 361, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18814, '2018-10-06 05:34:09.116612+00', '2018-10-06 05:34:09.116612+00', 'Light and Shade', 'LIGHT AND SHADE', 2, 32, NULL, 1, 3, 42, 2766, '2009-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1058, '2002-03-03 23:00:00+00', '2019-03-19 00:03:37.694564+00', 'Caryl''s Jig, The', 'CARYLS JIG', 2, 64, 9999, 1, 4, 14, 755, NULL, '', 91, '8008/8448/8888/8888/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1045, '1997-08-31 22:00:00+00', '2019-03-19 00:12:51.823765+00', 'Carolside Jig, The', 'CAROLSIDE JIG', 2, 40, 9999, 1, 4, 1, 751, NULL, '', 63, '8008/0880/8888/2882/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1043, '1997-08-31 22:00:00+00', '2012-01-20 12:56:08.766072+00', 'Carnival, The', 'CARNIVAL', 1, 32, 9999, 1, 4, NULL, 653, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1000, '1997-11-24 23:00:00+00', '2022-11-04 18:27:55.460525+00', 'Cape Wrath Light', 'CAPE WRATH LIGHT', 4, 96, 6, 1, 4, 1, 270, NULL, '', 82, '8080/8888/8888/8888/8484/0808/8888/8888/8888/0884/0088/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1003, '1997-04-03 22:00:00+00', '2022-12-24 23:53:38.862682+00', 'Capon Tree, The', 'CAPON TREE', 2, 48, 9999, 1, 4, 1, 270, NULL, '', 100, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1012, '1997-08-31 22:00:00+00', '2023-01-26 19:09:47.793042+00', 'Capt. H. Munro', 'CAPT H MUNRO', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1044, '1998-11-17 23:00:00+00', '2012-01-20 12:56:08.773559+00', 'Carnoustie Caper', 'CARNOUSTIE CAPER', 1, 40, 9999, 1, 4, 1, 2432, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1047, '1997-08-31 22:00:00+00', '2012-01-20 12:56:08.794676+00', 'Carousel', 'CAROUSEL', 3, 80, 9999, 4, 4, NULL, 752, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1048, '1997-04-03 22:00:00+00', '2012-01-20 12:56:08.801436+00', 'Carousel, The', 'CAROUSEL', 4, 64, 9999, 1, 4, NULL, 137, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1049, '1997-04-03 22:00:00+00', '2012-01-20 12:56:08.808185+00', 'Carra Beag', 'CARRA BEAG', 3, 32, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3089, '1997-09-04 22:00:00+00', '2012-01-20 12:56:25.630894+00', 'Indian Queen', 'INDIAN QUEEN', 1, 32, 9999, 1, 2, NULL, 446, '1701-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1065, '1997-04-03 22:00:00+00', '2019-07-31 13:55:19.041131+00', 'Castle Campbell', 'CASTLE CAMPBELL', 3, 32, 9999, 1, 3, 42, 392, NULL, '', 59, '800/888/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3095, '1997-04-03 22:00:00+00', '2012-01-20 12:56:25.674266+00', 'Innes Grant', 'INNES GRANT', 2, 32, 9999, 1, 2, NULL, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3097, '1997-09-04 22:00:00+00', '2012-01-20 12:56:25.688062+00', 'Innes Russell Of Perth', 'INNES RUSSELL OF PERTH', 3, 32, 9999, 1, 4, NULL, 420, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1052, '1997-08-31 22:00:00+00', '2012-01-20 12:56:08.828697+00', 'Carrick Realm, The', 'CARRICK REALM', 2, 32, 9999, 1, 4, NULL, 687, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1053, '1998-04-14 22:00:00+00', '2012-01-20 12:56:08.835531+00', 'Carrongrange Lodge', 'CARRONGRANGE LODGE', 3, 32, 9999, 3, 5, NULL, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1054, '1997-08-31 22:00:00+00', '2012-01-20 12:56:08.842324+00', 'Carse of Lecropt, The', 'CARSE OF LECROPT', 3, 32, 9999, 1, 4, NULL, 754, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1055, '1997-08-31 22:00:00+00', '2012-01-20 12:56:08.849278+00', 'Carswella Strathspey', 'CARSWELLA STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1061, '1997-11-27 23:00:00+00', '2012-01-20 12:56:08.889895+00', 'Casnewydd Medley', 'CASNEWYDD MEDLEY', 4, 64, 5, 1, 4, NULL, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1063, '1997-08-31 22:00:00+00', '2012-01-20 12:56:08.903681+00', 'Castel Froma', 'CASTEL FROMA', 2, 32, 9999, 1, 98, NULL, 756, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1070, '1997-04-03 22:00:00+00', '2012-01-20 12:56:08.952496+00', 'Castle In The Sea', 'CASTLE IN THE SEA', 3, 32, 9999, 1, 4, NULL, 385, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1076, '1997-04-03 22:00:00+00', '2012-01-20 12:56:08.993625+00', 'Castlelaw Reel', 'CASTLELAW REEL', 2, 16, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1078, '1997-09-05 22:00:00+00', '2012-01-20 12:56:09.009306+00', 'Castles In The Air', 'CASTLES IN THE AIR', 3, 48, 9999, 1, 4, NULL, 81, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1079, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.016113+00', 'Castles Of Mar', 'CASTLES OF MAR', 3, 32, 9999, 1, 98, NULL, 650, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1036, '1997-08-31 22:00:00+00', '2018-04-03 00:07:37.061859+00', 'Carl''s Retreat To Oregon', 'CARLS RETREAT TO OREGON', 1, 32, 9999, 1, 3, 42, 749, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1062, '1997-04-03 22:00:00+00', '2016-09-27 13:33:41.87714+00', 'Cast Iron Pot, The', 'CAST IRON POT', 1, 24, 9999, 1, 2, 76, 352, '1993-06-30', '', 52, '80/88/84', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1025, '1997-04-03 22:00:00+00', '2017-09-18 20:20:00.39837+00', 'Captain Whiteside', 'CAPTAIN WHITESIDE', 2, 32, 9999, 1, 3, 42, 129, NULL, '', 53, '822/888/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1041, '1997-10-27 23:00:00+00', '2018-04-03 00:07:37.070191+00', 'Carm Oliver''s Jig', 'CARM OLIVERS JIG', 2, 32, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1057, '1998-01-05 23:00:00+00', '2018-04-03 00:07:37.13693+00', 'Carter Bar', 'CARTER BAR', 1, 40, 9999, 1, 3, 42, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1067, '1997-09-17 22:00:00+00', '2018-04-03 00:07:37.203753+00', 'Castle Espie', 'CASTLE ESPIE', 3, 32, 9999, 1, 3, 42, 359, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3090, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.418733+00', 'Inebriated Gentleman, The', 'INEBRIATED GENTLEMAN', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3098, '1997-09-04 22:00:00+00', '2018-04-03 00:07:53.493778+00', 'Installation, The', 'INSTALLATION', 2, 64, 9999, 1, 3, 42, 466, '1772-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3099, '1997-09-04 22:00:00+00', '2018-04-03 00:07:53.627166+00', 'Intrigue, The', 'INTRIGUE', 1, 38, 9999, 1, 3, 42, 397, '1711-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3100, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.635599+00', 'Inukshuk Shuffle', 'INUKSHUK SHUFFLE', 3, 32, 9999, 1, 3, 42, 67, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3103, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.643837+00', 'Inverane Rant', 'INVERANE RANT', 1, 32, 9999, 1, 3, 42, 332, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1033, '1997-04-03 22:00:00+00', '2020-08-06 22:31:00.855013+00', 'Carisbrooke Castle', 'CARISBROOKE CASTLE', 3, 72, 9999, 104, 2, 3, 281, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3096, '1997-09-04 22:00:00+00', '2020-10-21 10:36:32.615552+00', 'Innes'' Jig', 'INNES JIG', 2, 32, 9999, 1, 3, 42, 270, NULL, '', 44, '800/822/822/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1071, '1997-04-03 22:00:00+00', '2020-11-30 11:35:30.824312+00', 'Castle of the Comyns, The', 'CASTLE OF THE COMYNS', 1, 32, 9999, 1, 4, 2, 13, NULL, '', 88, '8448/8888/8888/8448', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10547, '2002-08-05 22:00:00+00', '2021-02-07 10:44:20.699433+00', 'Mrs Helen Baillie', 'MRS HELEN BAILLIE', 3, 32, 9999, 1, 3, 42, 3128, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1074, '2001-12-17 23:00:00+00', '2021-06-23 11:34:17.554931+00', 'Castle Varrich', 'CASTLE VARRICH', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 63, '800/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10542, '2002-12-05 23:00:00+00', '2021-02-07 11:03:16.155321+00', 'Dainty Duncan', 'DAINTY DUNCAN', 2, 32, 9999, 1, 3, 42, 21, NULL, '', 59, '800/888/888/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10540, '2002-05-02 22:00:00+00', '2021-02-07 11:05:42.796677+00', 'Welcome Spring', 'WELCOME SPRING', 1, 32, 9999, 1, 3, 42, 3121, '1989-01-01', '', 47, '800/833/833/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10533, '2002-05-01 22:00:00+00', '2021-02-07 12:17:22.103028+00', 'Turning the Key', 'TURNING THE KEY', 1, 32, 9999, 1, 3, 42, 74, NULL, '', 69, '880/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10544, '2002-08-05 22:00:00+00', '2021-04-08 12:13:22.417578+00', 'Somerled Square', 'SOMERLED SQUARE', 2, 64, 9999, 4, 4, 13, 3127, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1072, '1998-09-28 22:00:00+00', '2021-06-23 11:38:15.710728+00', 'Castle Park Jig, The', 'CASTLE PARK JIG', 2, 32, 9999, 1, 3, 42, 21, NULL, '', 63, '808/888/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1068, '1998-04-05 22:00:00+00', '2021-06-23 11:44:57.519009+00', 'Castle Grant', 'CASTLE GRANT', 3, 32, 9999, 1, 3, 42, 9998, '1740-01-01', '', 41, '800/840/866/840', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1073, '1998-04-05 22:00:00+00', '2021-06-23 11:55:00.022645+00', 'Castle Stuart', 'CASTLE STUART', 3, 32, 9999, 1, 3, 42, 9998, '1740-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1046, '1999-04-19 22:00:00+00', '2021-06-24 09:26:00.320684+00', 'Carousel', 'CAROUSEL', 2, 32, 9999, 1, 4, 1, 87, NULL, 'Progression involves change-of-side.', 75, '8888/8448/8088/4048', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3107, '1997-09-04 22:00:00+00', '2012-01-20 12:56:25.75989+00', 'Inverewe', 'INVEREWE', 2, 32, 9999, 1, 98, NULL, 650, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10553, '2002-05-08 22:00:00+00', '2018-07-28 16:30:06.693531+00', 'Ring Dance, The', 'RING DANCE', 1, 32, 9999, 4, 4, NULL, 2686, '2001-01-01', '', 100, '8888/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3116, '1997-09-04 22:00:00+00', '2012-01-20 12:56:25.821954+00', 'Invicta', 'INVICTA', 3, 80, 9999, 4, 4, NULL, 222, NULL, 'Official Alias: Scots of Kent', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10550, '2002-05-06 22:00:00+00', '2012-01-20 12:57:22.359676+00', 'Provost''s Lady''s Jig, The', 'PROVOSTS LADYS JIG', 2, 32, 9999, NULL, NULL, NULL, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10551, '2002-05-06 22:00:00+00', '2012-01-20 12:57:22.36521+00', 'Maryland''s Silver Reel', 'MARYLANDS SILVER REEL', 1, 32, 9999, NULL, NULL, NULL, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10552, '2002-05-06 22:00:00+00', '2012-01-20 12:57:22.370591+00', 'Vicar of Bray, The', 'VICAR OF BRAY', 1, 32, 9999, NULL, NULL, NULL, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10557, '2002-05-11 22:00:00+00', '2019-03-02 23:29:43.934715+00', 'Glen Orrin Mixer, The', 'GLEN ORRIN MIXER', 2, 48, 9999, 4, 4, 4, 2677, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3113, '1997-08-21 22:00:00+00', '2023-01-20 11:19:17.117831+00', 'Inverugie Castle', 'INVERUGIE CASTLE', 3, 32, 9999, 1, 100, 2, 108, '1991-01-01', 'The notes say this was devised "for a S.C.D. Weekend at the Waterside Inn, Inverugie, Peterhead".', 84, '8668/8448/8888/8448', 1, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (3101, '1997-09-04 22:00:00+00', '2023-01-20 11:20:35.317844+00', 'Inver Inn', 'INVER INN', 1, 32, 9999, 1, 2, 76, 129, '1966-01-01', '', 47, '84/48/44/66', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3091, '1998-04-12 22:00:00+00', '2023-01-20 11:23:45.116335+00', 'Infare, The', 'INFARE', 3, 16, 9999, 1, 3, 42, 339, '1749-01-01', 'The book explains that the "Infare is the feast given for the home-coming of a bride."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1059, '1997-08-31 22:00:00+00', '2023-02-17 18:49:46.336157+00', 'Casbah, The', 'CASBAH', 2, 32, 9999, 1, 3, 42, 676, '1988-11-01', '"Devised for the fourth Robin Ellis Scottish Dancing Week at the Hotel Sahara Beach, Monastlr, 1st November 1988."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1037, '1997-08-31 22:00:00+00', '2023-02-17 18:54:50.345943+00', 'Carleton County', 'CARLETON COUNTY', 3, 32, 9999, 1, 3, 42, 748, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1082, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.036705+00', 'Cat Wheel, A', 'CAT WHEEL', 2, 32, 9999, 4, 4, NULL, 760, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1083, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.043515+00', 'Cat''s Cradle', 'CATS CRADLE', 3, 32, 9999, 1, 4, NULL, 759, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1095, '1997-04-03 22:00:00+00', '2012-01-20 12:56:09.128598+00', 'Cathkin Braes', 'CATHKIN BRAES', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1101, '1998-01-05 23:00:00+00', '2012-01-20 12:56:09.171545+00', 'Caurie Shells', 'CAURIE SHELLS', 1, 32, 9999, 5, 2, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1105, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.199481+00', 'Cawnpore To Lucknow', 'CAWNPORE TO LUCKNOW', 3, 32, 9999, 1, 98, NULL, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1106, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.206252+00', 'Cead Mile Failte', 'CEAD MILE FAILTE', 3, 32, 9999, 1, 4, NULL, 222, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1107, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.213112+00', 'Cearcan Frangach', 'CEARCAN FRANGACH', 1, 48, 9999, 2, 3, NULL, 264, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3118, '1997-09-04 22:00:00+00', '2012-01-20 12:56:25.835786+00', 'Iona Black Strathspey, The', 'IONA BLACK STRATHSPEY', 3, 32, 9999, 2, 3, NULL, 993, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3121, '1997-09-04 22:00:00+00', '2012-01-20 12:56:25.8564+00', 'Iona Of Bras D''Or', 'IONA OF BRAS DOR', 3, 32, 9999, 1, 4, NULL, 209, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1090, '1997-04-03 22:00:00+00', '2018-04-03 00:07:37.312228+00', 'Cath And Ricky''s Reel', 'CATH AND RICKYS REEL', 1, 40, 9999, 1, 3, 42, 247, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3124, '1997-11-27 23:00:00+00', '2012-01-20 12:56:25.877097+00', 'Irene Bryson Medley', 'IRENE BRYSON MEDLEY', 4, 128, 2, 4, 4, NULL, 247, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3126, '1997-09-04 22:00:00+00', '2012-01-20 12:56:25.890746+00', 'Irene''s Rant', 'IRENES RANT', 3, 32, 9999, 1, 4, NULL, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3130, '2001-05-21 22:00:00+00', '2012-01-20 12:56:25.921478+00', 'Iron Bridge, The', 'IRON BRIDGE', 3, 32, 9999, 1, 4, 1, 228, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1092, '1997-04-03 22:00:00+00', '2018-04-03 00:07:37.370605+00', 'Catherine McIsaac''s Wedding Day', 'CATHERINE MACISAACS WEDDING DAY', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1094, '1997-04-03 22:00:00+00', '2018-04-03 00:07:37.404+00', 'Cathie''s Reel', 'CATHIES REEL', 1, 32, 9999, 1, 3, 42, 108, '1968-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1081, '1997-11-27 23:00:00+00', '2018-04-03 00:07:37.428952+00', 'Cat On The Prowl', 'CAT ON THE PROWL', 4, 32, 1, 1, 3, 42, 109, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1098, '1997-04-03 22:00:00+00', '2018-04-03 00:07:37.479067+00', 'Cats in the Kitchen, The', 'CATS IN THE KITCHEN', 2, 32, 9999, 1, 3, 42, 44, '1973-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1102, '1997-04-03 22:00:00+00', '2018-04-03 00:07:37.537478+00', 'Cavehill', 'CAVEHILL', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1104, '1997-04-03 22:00:00+00', '2018-04-03 00:07:37.554124+00', 'Cawdor Castle', 'CAWDOR CASTLE', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10558, '2002-05-11 22:00:00+00', '2018-04-03 00:07:49.374117+00', 'Good Company, The', 'GOOD COMPANY', 3, 32, 9999, 1, 3, 42, 227, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3112, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.702339+00', 'Inverquharity Castle', 'INVERQUHARITY CASTLE', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3117, '1997-09-04 22:00:00+00', '2018-04-03 00:07:53.752224+00', 'Iolair', 'IOLAIR', 3, 32, 9999, 1, 3, 42, 965, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3120, '2003-01-27 23:00:00+00', '2018-04-03 00:07:53.760702+00', 'Iona Hall', 'IONA HALL', 1, 32, 9999, 1, 3, 42, 35, '1979-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3125, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.78568+00', 'Irene Harper''s Delight', 'IRENE HARPERS DELIGHT', 1, 32, 9999, 1, 3, 42, 247, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10561, '2002-05-11 22:00:00+00', '2018-04-03 00:07:55.470113+00', 'Jig for January, A', 'JIG FOR JANUARY', 2, 32, 9999, 1, 3, 42, 3113, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14223, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.835822+00', 'Ikema''s Fancy', 'IKEMAS FANCY', 2, 32, NULL, 1, 4, 2, 827, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10554, '2002-05-11 22:00:00+00', '2020-01-26 09:04:11.916924+00', 'Encore, The', 'ENCORE', 4, 64, 22, 4, 4, 28, 2677, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1088, '1997-12-03 23:00:00+00', '2020-02-28 17:42:58.593189+00', 'Sla''ine''s Fancy', 'SLAINES FANCY', 2, 32, 9999, 1, 3, 42, 1392, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1086, '1997-04-03 22:00:00+00', '2020-08-03 07:18:16.144411+00', 'Catch Me If You Can', 'CATCH ME IF YOU CAN', 2, 32, 9999, 1, 4, 1, 151, NULL, '', 50, '8008/8000/8888/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10562, '2002-05-12 22:00:00+00', '2021-02-06 15:47:48.075723+00', 'Kiss in Time, A', 'KISS IN TIME', 1, 32, 9999, 1, 3, 42, 3130, NULL, '', 47, '800/822/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10560, '2002-05-11 22:00:00+00', '2021-02-06 15:52:33.640089+00', 'Jack''s Teddy-Bears', 'JACKS TEDDYBEARS', 2, 32, 9999, 1, 100, 2, 9998, NULL, '', 75, '8888/8008/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10556, '2002-05-14 22:00:00+00', '2021-02-07 10:34:33.652581+00', 'Garden Party, The', 'GARDEN PARTY', 1, 32, 9999, 5, 56, NULL, 3136, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10549, '2002-08-05 22:00:00+00', '2021-02-07 10:41:27.831839+00', 'Eilean Ban', 'EILEAN BAN', 3, 32, 9999, 1, 4, 1, 2985, NULL, '', 50, '8000/8044/8800/8466', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3109, '1997-04-03 22:00:00+00', '2021-02-26 19:08:04.158964+00', 'Inverness Gathering', 'INVERNESS GATHERING', 1, 48, 9999, 1, 4, NULL, 392, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1099, '1997-04-03 22:00:00+00', '2021-05-17 07:41:51.201389+00', 'Caught Napping', 'CAUGHT NAPPING', 1, 32, 9999, 1, 3, 42, 352, '1993-01-24', '', 38, '800/800/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1096, '1997-08-31 22:00:00+00', '2021-06-23 11:10:50.169565+00', 'Caton Caprice', 'CATON CAPRICE', 1, 32, 9999, 1, 4, 1, 118, '1979-01-01', 'Devised whilst on sabbatical leave with Lancaster University, and living in the village of Caton. ', 50, '880/880/888/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3094, '1998-07-08 22:00:00+00', '2021-11-18 16:22:10.193738+00', 'Finnan Haddies', 'FINNAN HADDIES', 3, 32, 9999, 1, 100, 11, 108, '1994-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14224, '2011-08-26 22:00:00+00', '2018-07-17 10:16:13.86528+00', 'Let''s Dance Together', 'LETS DANCE TOGETHER', 2, 32, NULL, 1, 3, 42, 3561, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14225, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.848972+00', 'Merry Circle', 'MERRY CIRCLE', 3, 32, NULL, 2, 3, 17, 10471, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1109, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.22669+00', 'Ceilidh Special, The', 'CEILIDH SPECIAL', 1, 48, 9999, 3, 5, NULL, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1110, '1997-11-20 23:00:00+00', '2012-01-20 12:56:09.233549+00', 'Ceilidh, The', 'CEILIDH', 3, 16, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1111, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.240361+00', 'Ceilidh, The', 'CEILIDH', 1, 32, 9999, 1, 4, NULL, 761, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1112, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.247167+00', 'Celebrate The Children', 'CELEBRATE THE CHILDREN', 2, 40, 9999, 1, 4, NULL, 724, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1115, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.268484+00', 'Celebration Reel', 'CELEBRATION REEL', 1, 32, 9999, 1, 2, NULL, 765, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1116, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.275527+00', 'Celebration Reel', 'CELEBRATION REEL', 1, 32, 9999, 1, 4, NULL, 764, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1117, '2003-01-25 23:00:00+00', '2012-01-20 12:56:09.282445+00', 'Celebration Reel', 'CELEBRATION REEL', 1, 96, 9999, 4, 4, NULL, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1118, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.289257+00', 'Celebration Reel, The', 'CELEBRATION REEL', 1, 32, 9999, 1, 4, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1120, '1997-04-03 22:00:00+00', '2012-01-20 12:56:09.307697+00', 'Celebration Strathspey, The', 'CELEBRATION STRATHSPEY', 3, 32, 9999, 4, 4, NULL, 719, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1122, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.32593+00', 'Celie''s Fancy', 'CELIES FANCY', 4, 64, 9999, 4, 4, NULL, 225, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1080, '1997-04-03 22:00:00+00', '2022-08-11 15:12:05.63621+00', 'Cat Among The Pigeons, The', 'CAT AMONG THE PIGEONS', 1, 32, 9999, 1, 3, 42, 99, '1986-11-01', 'Inscribed "For Kate and Dermot Murphy".', 59, '686/888/565/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1091, '1997-04-03 22:00:00+00', '2022-08-14 22:22:30.21001+00', 'Catherine Hayes'' Delight', 'CATHERINE HAYES DELIGHT', 2, 32, 9999, 1, 3, 42, 108, '1995-01-01', '', 56, '808/888/880/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3122, '1997-09-04 22:00:00+00', '2022-08-20 18:15:13.083446+00', 'Iona Reel, The', 'IONA REEL', 1, 32, 9999, 1, 3, 42, 1011, NULL, 'Devised for the lona Scottish Country Dance Club, Christchurch.', 50, '844/800/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1097, '2002-03-02 23:00:00+00', '2023-02-17 18:37:16.997542+00', 'Catriona''s Wee Audacity', 'CATRIONAS WEE AUDACITY', 3, 32, 9999, 1, 3, 42, 686, '1980-01-01', '"Dedicated to Roy and Katherine Robinson, Wymington, Beds."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1085, '1997-09-17 22:00:00+00', '2023-02-17 18:40:01.278022+00', 'Catch As Catch Can', 'CATCH AS CATCH CAN', 1, 32, 9999, 1, 4, 1, 758, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1123, '1997-09-17 22:00:00+00', '2012-01-20 12:56:09.334675+00', 'Welcome to Summer Dancing', 'WELCOME TO SUMMER DANCING', 3, 32, 9999, 5, 2, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1126, '1998-04-08 22:00:00+00', '2012-01-20 12:56:09.357046+00', 'Celtic Cross', 'CELTIC CROSS', 4, 160, 9999, 4, 6, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1129, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.377578+00', 'Celtic Design', 'CELTIC DESIGN', 4, 80, 9999, 4, 4, NULL, 70, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1132, '1997-04-03 22:00:00+00', '2012-01-20 12:56:09.398078+00', 'Celtic Knot, The', 'CELTIC KNOT', 1, 32, 9999, 3, 5, NULL, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1135, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.418857+00', 'Centenary Jig, The', 'CENTENARY JIG', 2, 64, 9999, 1, 4, NULL, 78, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1121, '1997-04-03 22:00:00+00', '2018-04-03 00:07:37.645946+00', 'Celia''s Choice', 'CELIAS CHOICE', 2, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3131, '1998-07-08 22:00:00+00', '2014-07-17 10:02:54.029096+00', 'Iron Horse, The', 'IRON HORSE', 1, 32, 9999, 1, 4, 2, 313, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1137, '1997-04-03 22:00:00+00', '2012-01-20 12:56:09.444818+00', 'Centenary at Port Adelaide', 'CENTENARY AT PORT ADELAIDE', 3, 48, 9999, 1, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3132, '1997-09-17 22:00:00+00', '2012-01-20 12:56:25.936174+00', 'Iron Man', 'IRON MAN', 3, 96, 9999, 1, 4, NULL, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1147, '2001-05-21 22:00:00+00', '2019-03-18 23:52:17.569414+00', 'Challoner Chase', 'CHALLONER CHASE', 3, 32, 9999, 1, 4, 2, 770, NULL, '', 100, '8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1124, '2002-04-29 22:00:00+00', '2019-03-18 23:56:26.468987+00', 'Cellardyke', 'CELLARDYKE', 2, 144, 9999, 1, 4, 3, 50, '1968-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3144, '1997-08-25 22:00:00+00', '2012-12-01 11:17:43.85817+00', 'Islay Mist', 'ISLAY MIST', 2, 32, 9999, 1, 4, 1, 545, '1977-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10568, '2003-01-09 23:00:00+00', '2012-01-20 12:57:22.480712+00', 'Culzean Castle', 'CULZEAN CASTLE', 1, 0, 9999, 4, 4, NULL, 3117, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1138, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.453567+00', 'Centennial Reel', 'CENTENNIAL REEL', 1, 32, 9999, 2, 3, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1139, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.462475+00', 'Centennial Reel', 'CENTENNIAL REEL', 1, 32, 9999, 1, 4, NULL, 768, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1144, '1998-07-08 22:00:00+00', '2012-01-20 12:56:09.512222+00', 'Cessford Wedding', 'CESSFORD WEDDING', 3, 32, 9999, 1, 4, 2, 299, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1146, '1998-01-05 23:00:00+00', '2012-01-20 12:56:09.529677+00', 'Challenge Eightsome, The', 'CHALLENGE EIGHTSOME', 1, 40, 9999, 1, 4, NULL, 351, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1130, '1998-01-05 23:00:00+00', '2018-04-03 00:07:37.721129+00', 'Celtic King, The', 'CELTIC KING', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1134, '1997-08-31 22:00:00+00', '2018-04-03 00:07:37.779455+00', 'Celtic Rose, The', 'CELTIC ROSE', 2, 32, 9999, 1, 3, 42, 767, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1136, '1997-04-03 22:00:00+00', '2018-04-03 00:07:37.787807+00', 'Centenary Strathspey, The', 'CENTENARY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 368, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1140, '1997-04-03 22:00:00+00', '2018-04-03 00:07:37.804465+00', 'Centre In The Square, The', 'CENTRE IN THE SQUARE', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1149, '2003-01-25 23:00:00+00', '2018-04-03 00:07:37.946242+00', 'Chandos Reel', 'CHANDOS REEL', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3138, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.868977+00', 'Isabel Fuller Reel, The', 'ISABEL FULLER REEL', 2, 32, 9999, 1, 3, 42, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3141, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.885756+00', 'Island Cottage', 'ISLAND COTTAGE', 1, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3143, '1997-09-04 22:00:00+00', '2018-04-03 00:07:53.910806+00', 'Islay Hoose', 'ISLAY HOOSE', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19044, '2018-10-29 10:18:36.554272+00', '2018-10-29 11:58:50.589093+00', 'Raphaëlle and Emma', 'RAPHAELLE AND EMMA', 1, 64, NULL, 4, 4, 1, 11741, '2009-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1156, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.61618+00', 'Charing Cross', 'CHARING CROSS', 3, 96, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1157, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.623114+00', 'Charing Eight Strathspey', 'CHARING EIGHT STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 222, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1159, '1998-07-06 22:00:00+00', '2012-01-20 12:56:09.6396+00', 'Charlie Hunter', 'CHARLIE HUNTER', 2, 48, 9999, 8, 6, 9, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1142, '1997-08-31 22:00:00+00', '2019-12-03 21:48:48.562184+00', 'Ceol Na Mara', 'CEOL NA MARA', 3, 32, 9999, 1, 4, 1, 80, NULL, 'Ceol na Mara (Music of the Sea)', 81, '8282/8888/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1151, '1997-04-03 22:00:00+00', '2019-12-31 12:08:43.583878+00', 'Channel Fleet', 'CHANNEL FLEET', 1, 32, 9999, 1, 4, 1, 270, NULL, '', 59, '8884/8884/8000/8220', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3139, '1997-09-04 22:00:00+00', '2020-02-20 13:51:23.64338+00', 'Isca Reel, The', 'ISCA REEL', 1, 128, 9999, 4, 4, 3, 1012, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3136, '1998-01-05 23:00:00+00', '2020-08-06 14:57:21.194426+00', 'Ironbung Creek', 'IRONBUNG CREEK', 1, 40, 9999, 1, 2, NULL, 151, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3146, '1997-04-03 22:00:00+00', '2020-10-10 21:37:11.818017+00', 'Isle O'' Walsay', 'ISLE O WALSAY', 1, 32, 9999, 5, 2, NULL, 270, NULL, '', 100, '88/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10569, '2002-12-05 23:00:00+00', '2021-02-06 15:37:48.825292+00', 'Not Over the Hill', 'NOT OVER THE HILL', 1, 40, 9999, 1, 4, 1, 518, NULL, '', 75, '8888/4444/8888/8440/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10564, '2002-05-12 22:00:00+00', '2021-02-06 15:40:42.864645+00', 'Legacy of Pearl''s, A', 'LEGACY OF PEARLS', 2, 32, 9999, 1, 4, 1, 1727, NULL, '', 81, '8484/8888/8888/8080', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1119, '1997-08-31 22:00:00+00', '2021-04-17 11:04:19.798304+00', 'Celebration Ruby', 'CELEBRATION RUBY', 1, 48, 9999, 1, 3, 42, 766, '1987-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3135, '1997-04-03 22:00:00+00', '2021-06-16 14:07:34.168483+00', 'Iron Sands', 'IRON SANDS', 1, 32, 9999, 1, 3, 42, 352, '1993-05-23', '', 56, '800/844/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1141, '1998-01-05 23:00:00+00', '2021-06-22 18:01:56.403588+00', 'Centre One', 'CENTRE ONE', 1, 40, 9999, 1, 3, 42, 566, NULL, '', 45, '800/888/844/844/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1131, '1998-01-05 23:00:00+00', '2021-06-22 18:12:40.87575+00', 'Celtic Kiwi, The', 'CELTIC KIWI', 1, 32, 9999, 1, 3, 42, 108, '1991-10-01', 'Inscribed "for the dancers of Whangarei, New Zealand".', 69, '888/888/888/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1197, '1998-01-05 23:00:00+00', '2018-12-31 12:10:58.649514+00', 'Christmas Ale', 'CHRISTMAS ALE', 1, 32, 9999, 1, 3, 42, 775, NULL, '', 56, '800/677/866/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1164, '1997-04-03 22:00:00+00', '2012-01-20 12:56:09.685507+00', 'Chase Me Charlie', 'CHASE ME CHARLIE', 1, 32, 9999, 1, 4, NULL, 159, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1166, '2003-01-26 23:00:00+00', '2012-01-20 12:56:09.704122+00', 'Chatham House', 'CHATHAM HOUSE', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3148, '1997-09-04 22:00:00+00', '2012-01-20 12:56:26.052268+00', 'Isle of Canna', 'ISLE OF CANNA', 3, 64, 9999, 4, 4, NULL, 787, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3150, '1997-04-03 22:00:00+00', '2012-01-20 12:56:26.066114+00', 'Isle of May, The', 'ISLE OF MAY', 3, 64, 9999, 4, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3151, '1997-04-03 22:00:00+00', '2012-01-20 12:56:26.072943+00', 'Isle of Mull, The', 'ISLE OF MULL', 3, 32, 9999, 1, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3156, '1998-07-08 22:00:00+00', '2012-01-20 12:56:26.111504+00', 'Isobel''s Fancy', 'ISOBELS FANCY', 2, 48, 9999, 1, 4, 2, 606, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3157, '1998-07-08 22:00:00+00', '2012-01-20 12:56:26.119172+00', 'Isobel''s Strathspey', 'ISOBELS STRATHSPEY', 3, 32, 9999, 1, 4, 2, 606, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3158, '1998-07-08 22:00:00+00', '2012-01-20 12:56:26.128012+00', 'It Was A Graun'' Thoucht', 'IT WAS A GRAUN THOUCHT', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10571, '2002-05-12 22:00:00+00', '2019-02-22 12:46:58.810197+00', 'October''s Party Reel', 'OCTOBERS PARTY REEL', 1, 32, 9999, 1, 4, 1, 3133, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10574, '2002-05-12 22:00:00+00', '2012-01-20 12:57:22.516109+00', 'Scots in France', 'SCOTS IN FRANCE', 1, 40, 9999, 3, 5, NULL, 17, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1168, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.7216+00', 'Cheeper On Friday, A', 'CHEEPER ON FRIDAY', 1, 32, 9999, 5, 2, NULL, 358, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1158, '1997-11-18 23:00:00+00', '2014-07-26 23:12:22.958289+00', 'Charles Stuart', 'CHARLES STUART', 3, 32, 9999, 1, 3, 42, 9998, '1794-01-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1174, '2003-01-30 23:00:00+00', '2012-01-20 12:56:09.763534+00', 'Cherry Blossoms', 'CHERRY BLOSSOMS', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1181, '1997-04-03 22:00:00+00', '2012-01-20 12:56:09.812441+00', 'Cheviot Gate', 'CHEVIOT GATE', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1184, '1997-04-03 22:00:00+00', '2012-01-20 12:56:09.833562+00', 'Chief, The', 'CHIEF', 1, 32, 9999, 1, 4, 1, 211, '1969-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1185, '1997-04-03 22:00:00+00', '2012-01-20 12:56:09.840608+00', 'Chieftain Bill', 'CHIEFTAIN BILL', 2, 32, 9999, 1, 4, NULL, 225, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1188, '1997-04-03 22:00:00+00', '2012-01-20 12:56:09.861215+00', 'Choristers, The', 'CHORISTERS', 2, 40, 9999, 1, 4, NULL, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3163, '1997-08-24 22:00:00+00', '2012-01-20 12:56:26.163933+00', 'It''s a Wee World!', 'ITS A WEE WORLD', 1, 32, 9999, 1, 4, 2, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3149, '1997-04-03 22:00:00+00', '2018-04-03 00:07:53.944453+00', 'Isle of Lindisfarne, The', 'ISLE OF LINDISFARNE', 3, 32, 9999, 1, 3, 42, 44, '1985-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1169, '1997-08-31 22:00:00+00', '2018-04-03 00:07:38.121443+00', 'Chelmsford Assembly', 'CHELMSFORD ASSEMBLY', 2, 32, 9999, 1, 3, 42, 198, '1753-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1175, '1997-04-03 22:00:00+00', '2018-04-03 00:07:38.205151+00', 'Cherry Tree, The', 'CHERRY TREE', 2, 32, 9999, 1, 3, 42, 59, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3153, '1997-09-04 22:00:00+00', '2018-04-03 00:07:54.01063+00', 'Isle of the West', 'ISLE OF THE WEST', 3, 32, 9999, 1, 3, 42, 108, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3161, '1997-04-03 22:00:00+00', '2018-04-03 00:07:54.561155+00', 'It''s A Dying Art', 'ITS A DYING ART', 1, 32, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3162, '1997-09-04 22:00:00+00', '2018-04-03 00:07:54.577766+00', 'It''s A Long Way To The Moon', 'ITS A LONG WAY TO THE MOON', 3, 32, 9999, 1, 3, 42, 1015, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3164, '1997-04-03 22:00:00+00', '2018-04-03 00:07:54.611192+00', 'It''s In The Bag', 'ITS IN THE BAG', 1, 32, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3166, '1997-04-03 22:00:00+00', '2018-04-03 00:07:54.619584+00', 'It''s Morning Time!', 'ITS MORNING TIME', 1, 32, 9999, 1, 3, 42, 204, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3167, '1997-04-03 22:00:00+00', '2018-04-03 00:07:54.636172+00', 'It''s Not My Fault', 'ITS NOT MY FAULT', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3159, '1997-04-03 22:00:00+00', '2018-04-03 00:07:54.652877+00', 'It was A'' Conceit', 'IT WAS A CONCEIT', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10581, '2002-05-14 22:00:00+00', '2012-01-20 12:57:22.571808+00', 'Mr & Mrs Young', 'MR AND MRS YOUNG', 3, 48, 9999, 1, 4, 1, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10582, '2002-05-14 22:00:00+00', '2012-01-20 12:57:22.579294+00', 'O for Ane & Twenty', 'O FOR ANE AND TWENTY', 2, 32, 9999, 2, 3, 17, 9998, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1198, '1997-04-03 22:00:00+00', '2018-09-04 15:20:31.168837+00', 'Christmas Ceilidh, A', 'CHRISTMAS CEILIDH', 1, 40, 9999, 1, 3, 42, 3591, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1199, '1997-04-03 22:00:00+00', '2012-01-20 12:56:09.933379+00', 'Christmas Snow', 'CHRISTMAS SNOW', 3, 48, 9999, 1, 4, NULL, 204, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1160, '1997-08-31 22:00:00+00', '2020-08-29 15:49:31.790137+00', 'Charlotte and Aileen', 'CHARLOTTE AND AILEEN', 3, 32, 9999, 1, 100, 2, 773, NULL, '', 94, '6666/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1183, '1997-12-27 23:00:00+00', '2020-08-29 15:51:10.451564+00', 'Chicago Loop, The', 'CHICAGO LOOP', 1, 32, 9999, 1, 3, 42, 361, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10577, '2002-05-12 22:00:00+00', '2020-09-11 08:25:22.209145+00', 'Strome Ferry', 'STROME FERRY', 1, 32, 9999, 2, 3, 4, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1190, '1997-04-03 22:00:00+00', '2020-11-05 20:40:41.402281+00', 'Chrys Greenyer''s Jig', 'CHRYS GREENYERS JIG', 2, 32, 9999, 1, 3, 42, 99, NULL, '', 41, '404/404/288/828', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3155, '1997-09-04 22:00:00+00', '2020-12-27 18:52:51.855215+00', 'Isles Of The Sea, The', 'ISLES OF THE SEA', 3, 32, 9999, 2, 3, 18, 13, NULL, '', 92, '880/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10572, '2002-05-12 22:00:00+00', '2021-02-06 15:29:45.407941+00', 'Peter Hastings'' Chocolate Mousse', 'PETER HASTINGS CHOCOLATE MOUSSE', 2, 32, 9999, 1, 4, 13, 3651, '1999-01-01', '', 81, '8400/8866/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1162, '1998-01-11 23:00:00+00', '2021-01-14 20:57:35.105488+00', 'Charlotte Square', 'CHARLOTTE SQUARE', 1, 32, 9999, 1, 3, 42, 108, '1982-01-01', '', 56, '800/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1192, '1997-07-03 22:00:00+00', '2021-06-21 10:46:03.322559+00', 'Christie of the Clinthill', 'CHRISTIE OF THE CLINTHILL', 2, 64, 9999, 1, 4, 1, 129, NULL, '', 64, '8000/8800/0880/4488/8888/6886/8488/8004', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1180, '1997-04-03 22:00:00+00', '2021-06-19 22:22:07.390239+00', 'Chevalier Strathspey, The', 'CHEVALIER STRATHSPEY', 3, 32, 9999, 1, 3, 42, 352, '1991-05-05', 'The dance notes state that James Stuart was the Chevalier de St George.', 55, '800/888/646/868', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1171, '2000-09-02 22:00:00+00', '2021-06-21 21:55:47.510502+00', 'Chequered Hall, The', 'CHEQUERED HALL', 3, 32, 9999, 1, 2, 76, 146, NULL, '', 69, '88/88/88/88', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1165, '1998-04-08 22:00:00+00', '2021-06-21 22:00:24.72484+00', 'Chasing a Wish', 'CHASING A WISH', 1, 32, 9999, 1, 3, 42, 301, NULL, '', 44, '800/800/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1194, '1998-11-03 23:00:00+00', '2021-06-21 23:22:35.569512+00', 'Christina Lake Jig', 'CHRISTINA LAKE JIG', 2, 32, 9999, 1, 3, 42, 394, '1979-01-01', '', 34, '800/800/844/822', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1153, '1998-01-05 23:00:00+00', '2021-06-22 17:40:26.592604+00', 'Chapel on the Hill, The', 'CHAPEL ON THE HILL', 1, 32, 9999, 1, 3, 42, 44, '1966-01-01', '"Devised for Kathleen and Harry Farran to celebrate their 25th Wedding Anniversary."', 50, '880/800/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1152, '1997-08-31 22:00:00+00', '2021-06-22 17:59:12.141364+00', 'Chaos In The Kirkway', 'CHAOS IN THE KIRKWAY', 3, 32, 9999, 2, 3, 18, 772, '1993-01-01', '', 83, '888/888/088/808', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1205, '1997-08-31 22:00:00+00', '2012-01-20 12:56:09.974515+00', 'Chuffer, The', 'CHUFFER', 1, 32, 9999, 3, 5, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1206, '1997-04-03 22:00:00+00', '2012-01-20 12:56:09.981369+00', 'Churchill Barracks', 'CHURCHILL BARRACKS', 1, 40, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12169, '2005-04-13 22:00:00+00', '2018-09-13 23:55:50.114041+00', 'Carole''s Welcome', 'CAROLES WELCOME', 1, 32, 9999, 1, 2, 76, 1089, NULL, 'Dedicated to Carole Skinner, a beautiful dancer and partner, in thanks for her very memorable welcome to the 1992 Montreal Weekend in Lennoxvifle', 60, '88/88/80/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1212, '1997-08-31 22:00:00+00', '2012-01-20 12:56:10.023024+00', 'Circle of Friendship', 'CIRCLE OF FRIENDSHIP', 3, 96, 9999, 1, 4, NULL, 780, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1214, '2002-05-06 22:00:00+00', '2012-01-20 12:56:10.036639+00', 'City of Light, The', 'CITY OF LIGHT', 3, 32, 9999, 4, 4, NULL, 70, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1216, '1997-08-31 22:00:00+00', '2012-01-20 12:56:10.051736+00', 'City of Roses Strathspey', 'CITY OF ROSES STRATHSPEY', 3, 96, 9999, 3, 5, NULL, 782, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1219, '1998-07-09 22:00:00+00', '2012-01-20 12:56:10.07299+00', 'Clachna Cudain', 'CLACHNA CUDAIN', 3, 32, 9999, 2, 3, 18, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1220, '1997-04-03 22:00:00+00', '2012-01-20 12:56:10.079791+00', 'Clan Gregor Gathering', 'CLAN GREGOR GATHERING', 4, 64, 9999, 1, 4, NULL, 354, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1187, '1997-04-03 22:00:00+00', '2019-03-18 23:46:23.58299+00', 'Chippy''s Rant', 'CHIPPYS RANT', 2, 32, 9999, 2, 3, 18, 104, NULL, '', 85, '484/888/888/882', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1222, '1997-08-31 22:00:00+00', '2012-01-20 12:56:10.09362+00', 'Clans, The', 'CLANS', 2, 40, 9999, 4, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1224, '1997-08-31 22:00:00+00', '2012-01-20 12:56:10.107841+00', 'Clare Broome Of Leamington Spa', 'CLARE BROOME OF LEAMINGTON SPA', 1, 32, 9999, 1, 98, NULL, 783, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3175, '1997-09-04 22:00:00+00', '2012-01-20 12:56:26.248223+00', 'Jack Lindsay''s Strathspey', 'JACK LINDSAYS STRATHSPEY', 3, 32, 9999, 2, 3, NULL, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3178, '1997-09-04 22:00:00+00', '2012-01-20 12:56:26.268906+00', 'Jack Oozie', 'JACK OOZIE', 4, 128, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3182, '1997-11-24 23:00:00+00', '2012-01-20 12:56:26.299392+00', 'Jack''s Medley', 'JACKS MEDLEY', 4, 192, 3, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1196, '1997-08-31 22:00:00+00', '2022-08-11 23:10:21.506775+00', 'Christine McAskill', 'CHRISTINE MACASKILL', 2, 48, 9999, 5, 2, 76, 270, NULL, '', 100, '88/88/88/88/88/88', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1172, '1997-08-31 22:00:00+00', '2022-12-25 16:37:58.48691+00', 'Cherish the Ladies', 'CHERISH THE LADIES', 2, 32, 9999, 4, 4, 13, 270, NULL, '', 100, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1178, '1997-04-03 22:00:00+00', '2023-01-26 19:10:09.392457+00', 'Chester Hornpipe, The', 'CHESTER HORNPIPE', 1, 32, 9999, 1, 4, 2, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1195, '1997-08-31 22:00:00+00', '2023-02-17 18:24:48.898924+00', 'Christina McLellan', 'CHRISTINA MACLELLAN', 1, 32, 9999, 1, 3, 42, 101, '1968-01-01', '', 40, '800/808/800/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3184, '1997-09-04 22:00:00+00', '2012-01-20 12:56:26.313076+00', 'Jacob Hall''s Jigg', 'JACOB HALLS JIGG', 2, 32, 9999, 1, 2, NULL, 446, '1695-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3185, '1997-04-03 22:00:00+00', '2012-01-20 12:56:26.319974+00', 'Jacobite Jig, The', 'JACOBITE JIG', 2, 32, 9999, 1, 2, NULL, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10584, '2002-05-14 22:00:00+00', '2012-01-20 12:57:22.594106+00', 'Sprots o'' Burniboosie, The', 'SPROTS O BURNIBOOSIE', 2, 32, 9999, 1, 4, 11, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1226, '1997-04-03 22:00:00+00', '2012-01-20 12:56:10.123894+00', 'Clarence House', 'CLARENCE HOUSE', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1230, '1998-04-08 22:00:00+00', '2012-01-20 12:56:10.151269+00', 'Cleekum, The', 'CLEEKUM', 1, 32, 9999, 4, 4, NULL, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1208, '1997-08-31 22:00:00+00', '2018-04-03 00:07:38.455387+00', 'Cincinnati Jubilee, The', 'CINCINNATI JUBILEE', 3, 32, 9999, 1, 3, 42, 777, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3179, '1997-10-27 23:00:00+00', '2018-04-03 00:07:54.769576+00', 'Jack''s Delight', 'JACKS DELIGHT', 1, 32, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1209, '1997-08-31 22:00:00+00', '2018-04-03 00:07:38.463834+00', 'Cincinnati''s Silver Anniversary', 'CINCINNATIS SILVER ANNIVERSARY', 3, 32, 9999, 1, 3, 42, 778, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1213, '1997-08-31 22:00:00+00', '2018-04-03 00:07:38.497169+00', 'City of Glasgow Dancers', 'CITY OF GLASGOW DANCERS', 3, 40, 9999, 1, 3, 42, 240, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1217, '1997-04-03 22:00:00+00', '2018-04-03 00:07:38.555583+00', 'Clachan Bridge', 'CLACHAN BRIDGE', 2, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1221, '1997-04-03 22:00:00+00', '2018-04-03 00:07:38.580558+00', 'Clan''s Gathering', 'CLANS GATHERING', 2, 32, 9999, 1, 3, 42, 300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1225, '1997-04-03 22:00:00+00', '2018-04-03 00:07:38.605518+00', 'Clare''s Welcome', 'CLARES WELCOME', 1, 32, 9999, 1, 3, 42, 411, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1228, '1997-08-31 22:00:00+00', '2018-04-03 00:07:38.630562+00', 'Claverhouse Reel', 'CLAVERHOUSE REEL', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1233, '1997-04-03 22:00:00+00', '2018-04-03 00:07:38.672254+00', 'Click Mill, The', 'CLICK MILL', 1, 32, 9999, 1, 3, 42, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1236, '1997-04-03 22:00:00+00', '2018-04-03 00:07:38.705765+00', 'Clochmaloo', 'CLOCHMALOO', 2, 32, 9999, 1, 3, 42, 108, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3181, '1997-09-04 22:00:00+00', '2018-04-03 00:07:54.777974+00', 'Jack''s Maggot', 'JACKS MAGGOT', 1, 32, 9999, 1, 3, 42, 446, '1702-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3187, '1997-04-03 22:00:00+00', '2018-04-03 00:07:54.794593+00', 'Jacobite Piper, The', 'JACOBITE PIPER', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3171, '1997-04-03 22:00:00+00', '2018-04-03 00:07:55.90365+00', 'J. McInnes Esq.', 'J MACINNES ESQ', 3, 24, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10583, '2002-05-14 22:00:00+00', '2018-04-03 00:08:11.324054+00', 'Prince William of Wales', 'PRINCE WILLIAM OF WALES', 3, 0, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10585, '2002-05-14 22:00:00+00', '2018-04-03 00:08:20.175248+00', 'Tayside Scanner Hornpipe', 'TAYSIDE SCANNER HORNPIPE', 1, 32, 9999, 1, 3, 42, 176, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1267, '1998-01-05 23:00:00+00', '2018-04-29 13:22:42.543343+00', 'Cockle Gatherer, The', 'COCKLE GATHERER', 1, 32, 9999, 1, 3, 42, 401, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1240, '1998-07-08 22:00:00+00', '2012-01-20 12:56:10.225477+00', 'Cloutie Dumpling, The', 'CLOUTIE DUMPLING', 1, 32, 9999, 1, 4, 2, 101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1264, '1997-04-03 22:00:00+00', '2018-04-26 22:40:14.336126+00', 'Cock-a-Leekie', 'COCKALEEKIE', 2, 32, 9999, 1, 3, 42, 143, NULL, '', 69, '888/880/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1251, '1997-04-03 22:00:00+00', '2019-03-18 15:57:41.82098+00', 'Coates Crescent', 'COATES CRESCENT', 3, 40, 9999, 1, 4, 1, 28, NULL, '', 75, '8888/8888/8888/4444/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1234, '1997-04-03 22:00:00+00', '2019-12-03 22:10:48.184552+00', 'Clifton Jig, The', 'CLIFTON JIG', 2, 32, 9999, 1, 4, 1, 418, NULL, '', 85, '8888/8448/4884/5888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1191, '2002-03-02 23:00:00+00', '2020-01-05 21:10:27.138322+00', 'Christie McLeod', 'CHRISTIE MACLEOD', 1, 32, 9999, 5, 2, NULL, 270, '1979-01-01', '', 100, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3813, '1997-04-03 22:00:00+00', '2020-08-06 15:39:03.516433+00', 'Lily Of The Vale, The', 'LILY OF THE VALE', 1, 32, 9999, 1, 3, 42, 129, NULL, '', 40, '840/888/800/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1193, '1997-04-03 22:00:00+00', '2020-08-29 15:54:51.173615+00', 'Christina', 'CHRISTINA', 3, 40, 9999, 1, 100, 11, 3412, NULL, '', 78, '4444/4444/8668/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3183, '1997-04-03 22:00:00+00', '2020-10-10 23:08:18.318873+00', 'Jackson''s Jig', 'JACKSONS JIG', 2, 32, 9999, 1, 3, 42, 270, NULL, '', 53, '800/844/866/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3173, '1997-09-04 22:00:00+00', '2020-10-12 09:32:18.574146+00', 'J. F. Mackenzie Esq. of Carrynahine', 'J F MACKENZIE ESQ OF CARRYNAHINE', 3, 32, 9999, 1, 3, 42, 270, NULL, '', 56, '800/866/866/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3177, '1998-11-14 23:00:00+00', '2021-05-25 18:10:27.97597+00', 'Jack On The Green', 'JACK ON THE GREEN', 3, 32, 9999, 1, 3, 42, 9998, '1740-01-01', '', 47, '800/844/822/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1247, '2002-11-11 23:00:00+00', '2021-06-20 12:23:43.106405+00', 'Clydeview', 'CLYDEVIEW', 3, 32, 9999, 1, 4, 1, 647, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1237, '2002-03-04 23:00:00+00', '2021-06-21 08:29:37.155374+00', 'Cloisters, The', 'CLOISTERS', 3, 32, 9999, 1, 2, 76, 108, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1249, '1997-04-03 22:00:00+00', '2012-01-20 12:56:10.288367+00', 'Coach And Horses, The', 'COACH AND HORSES', 1, 40, 9999, 1, 4, NULL, 416, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1250, '1998-04-08 22:00:00+00', '2019-03-18 15:59:48.181453+00', 'Coanwood Stuarts, The', 'COANWOOD STUARTS', 2, 32, 9999, 1, 4, 1, 146, NULL, '', 53, '4440/8880/4440/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1235, '1998-07-08 22:00:00+00', '2019-10-19 22:43:56.113515+00', 'Clints of Dromore, The', 'CLINTS OF DROMORE', 1, 32, 9999, 1, 100, 2, 13, NULL, '', 75, '8448/8448/8008/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3193, '1997-09-04 22:00:00+00', '2012-01-20 12:56:26.375963+00', 'James Crichton Of Eliock''s Strathspey', 'JAMES CRICHTON OF ELIOCKS STRATHSPEY', 3, 96, 9999, 4, 4, NULL, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3194, '1997-04-03 22:00:00+00', '2012-01-20 12:56:26.382774+00', 'James Stephen', 'JAMES STEPHEN', 2, 32, 9999, 3, 5, NULL, 270, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1239, '1997-04-03 22:00:00+00', '2018-04-03 00:07:38.739071+00', 'Closeborne House', 'CLOSEBORNE HOUSE', 3, 32, 9999, 1, 3, 42, 109, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10588, '2002-06-04 22:00:00+00', '2014-05-07 13:06:17.017489+00', 'Megan''s Favourite', 'MEGANS FAVOURITE', 2, 32, 9999, 1, 3, 42, 316, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3199, '2002-11-29 23:00:00+00', '2012-01-20 12:56:26.419464+00', 'Jan''s Chase', 'JANS CHASE', 2, 48, 9999, 1, 4, NULL, 1582, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1241, '2003-01-26 23:00:00+00', '2018-04-03 00:07:38.755782+00', 'Clove Hitch Hornpipe, The', 'CLOVE HITCH HORNPIPE', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3808, '1997-09-07 22:00:00+00', '2012-01-20 12:56:30.917242+00', 'Lillias', 'LILLIAS', 3, 32, 9999, 7, 2, NULL, 1075, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3809, '1997-09-07 22:00:00+00', '2012-01-20 12:56:30.924059+00', 'Lilli Burlero', 'LILLI BURLERO', 1, 32, 9999, 1, 2, NULL, 446, '1690-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3810, '1997-09-07 22:00:00+00', '2012-01-20 12:56:30.931171+00', 'Lilliput Bay', 'LILLIPUT BAY', 3, 40, 9999, 2, 3, NULL, 734, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3811, '1997-04-03 22:00:00+00', '2012-01-20 12:56:30.937986+00', 'Lilt for Laura, A', 'LILT FOR LAURA', 3, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1243, '1997-04-03 22:00:00+00', '2018-04-03 00:07:38.780773+00', 'Cluny Castle', 'CLUNY CASTLE', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1257, '2000-01-10 23:00:00+00', '2012-01-20 12:56:10.346472+00', 'Cobham Hornpipe', 'COBHAM HORNPIPE', 1, 64, 9999, 1, 4, NULL, 785, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1258, '2000-02-13 23:00:00+00', '2012-01-20 12:56:10.353922+00', 'Cobham Trees', 'COBHAM TREES', 3, 32, 9999, 2, 3, 17, 196, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1265, '1997-08-31 22:00:00+00', '2012-01-20 12:56:10.403076+00', 'Cockleroy', 'COCKLEROY', 4, 64, 9999, 4, 4, NULL, 101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1270, '1997-08-31 22:00:00+00', '2012-01-20 12:56:10.440177+00', 'Cockle Shells', 'COCKLE SHELLS', 1, 32, 9999, 1, 2, NULL, 446, '1701-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1272, '1997-04-03 22:00:00+00', '2012-01-20 12:56:10.457678+00', 'Coffee Leaf, The', 'COFFEE LEAF', 1, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1242, '1997-08-24 22:00:00+00', '2023-02-17 13:06:50.903738+00', 'Clovenside', 'CLOVENSIDE', 3, 32, 9999, 1, 3, 42, 108, '1990-08-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1200, '1998-01-05 23:00:00+00', '2023-02-17 18:02:19.802726+00', 'Christmas Tree, The', 'CHRISTMAS TREE', 1, 32, 9999, 1, 3, 42, 352, '1993-05-23', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1268, '1997-12-03 23:00:00+00', '2018-04-03 00:08:11.332413+00', 'Prince William of Wales', 'PRINCE WILLIAM OF WALES', 2, 32, 9999, 1, 3, 42, 66, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10592, '2002-12-05 23:00:00+00', '2017-03-02 07:42:24.6382+00', 'Scholars'' Strathspey, The', 'SCHOLARS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 154, '1997-08-01', '', 47, '800/840/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1248, '1997-04-03 22:00:00+00', '2018-04-03 00:07:38.858028+00', 'Clyne''s Trek Ower The Muir', 'CLYNES TREK OWER THE MUIR', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1253, '1997-04-03 22:00:00+00', '2018-04-03 00:07:38.922574+00', 'Cobbler''s Awl, The', 'COBBLERS AWL', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1254, '1997-04-03 22:00:00+00', '2018-04-03 00:07:38.939279+00', 'Cobblestone Court', 'COBBLESTONE COURT', 2, 32, 9999, 1, 3, 42, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1266, '1997-08-31 22:00:00+00', '2018-04-03 00:07:38.989311+00', 'Cockle Gatherers, The', 'COCKLE GATHERERS', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1263, '1997-10-27 23:00:00+00', '2018-04-03 00:07:39.022527+00', 'Cock up your Beaver', 'COCK UP YOUR BEAVER', 2, 32, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3190, '1997-04-03 22:00:00+00', '2018-04-03 00:07:54.802978+00', 'Jacobite''s Jig, The', 'JACOBITES JIG', 2, 32, 9999, 1, 3, 42, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3191, '1997-09-04 22:00:00+00', '2018-04-03 00:07:54.844611+00', 'Jakie Stewart''s Reel', 'JAKIE STEWARTS REEL', 1, 48, 9999, 1, 3, 42, 466, '1758-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3192, '1997-04-03 22:00:00+00', '2018-04-03 00:07:54.853059+00', 'James and Gina''s Strathspey', 'JAMES AND GINAS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3195, '1997-04-03 22:00:00+00', '2018-04-03 00:07:54.877889+00', 'Jamie Shearer', 'JAMIE SHEARER', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3220, '1998-01-05 23:00:00+00', '2018-04-29 21:13:35.565484+00', 'Jean''s Whimsy', 'JEANS WHIMSY', 1, 40, 9999, 1, 3, 42, 351, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18638, '2018-09-18 22:04:00.813291+00', '2018-09-18 22:05:09.913532+00', 'Meeting of the Minds', 'MEETING OF THE MINDS', 1, 40, NULL, 2, 3, 18, 11709, '2014-06-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3216, '1997-04-03 22:00:00+00', '2018-08-01 09:58:11.909089+00', 'Jean Sim''s Jig', 'JEAN SIMS JIG', 2, 32, 9999, 1, 2, 76, 108, '1975-02-02', '', 31, '80/88/62/26', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1308, '1997-08-31 22:00:00+00', '2018-04-02 23:56:33.548214+00', 'Comely Lass, The', 'COMELY LASS', 1, 32, 9999, 1, 3, 42, 101, '1992-01-01', 'Devised for the wedding of Susan Comely and Martin Watson, September 1992.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3203, '1997-09-29 22:00:00+00', '2012-01-20 12:56:26.450019+00', 'Janet''s Delight', 'JANETS DELIGHT', 5, 16, 9999, 4, 4, NULL, 420, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3204, '1997-04-03 22:00:00+00', '2012-01-20 12:56:26.456806+00', 'Janet''s Jig', 'JANETS JIG', 2, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3206, '1997-04-03 22:00:00+00', '2012-01-20 12:56:26.470461+00', 'Janette Cunningham''s Strathspey', 'JANETTE CUNNINGHAMS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3196, '2002-02-28 23:00:00+00', '2020-08-06 15:11:19.729967+00', 'Jamie''s Hornpipe', 'JAMIES HORNPIPE', 1, 32, 9999, 1, 2, 76, 406, '1966-01-01', '', 42, '80/80/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1245, '1998-01-05 23:00:00+00', '2020-08-29 22:57:56.121548+00', 'Clybourn Junction', 'CLYBOURN JUNCTION', 1, 32, 9999, 1, 3, 42, 361, NULL, 'May also be danced as a Strathspey', 44, '800/800/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1256, '1997-11-24 23:00:00+00', '2020-09-27 08:57:07.998792+00', 'Cobham Hall', 'COBHAM HALL', 4, 128, 1, 1, 4, 3, 270, NULL, '', 88, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10587, '2002-12-05 23:00:00+00', '2021-02-06 13:52:13.115888+00', 'Ilka Joy', 'ILKA JOY', 1, 32, 9999, 1, 100, 11, 154, '2000-01-01', '', 88, '8008/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1271, '1997-04-03 22:00:00+00', '2020-12-12 22:19:26.834263+00', 'Cocklemill Burn', 'COCKLEMILL BURN', 3, 32, 9999, 2, 3, 18, 13, NULL, '', 63, '800/666/666/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3814, '1997-04-03 22:00:00+00', '2021-05-15 10:55:38.069951+00', 'Lincluden Abbey', 'LINCLUDEN ABBEY', 3, 32, 9999, 1, 3, 42, 200, NULL, '', 72, '888/848/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1262, '1998-07-09 22:00:00+00', '2021-06-16 23:51:33.084986+00', 'Cock O'' The North', 'COCK O THE NORTH', 2, 32, 9999, 3, 5, 7, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3200, '1997-09-04 22:00:00+00', '2021-05-25 12:51:13.568014+00', 'Jane''s a Bonnie Lass', 'JANES A BONNIE LASS', 2, 32, 9999, 1, 3, 42, 377, NULL, 'The version of the instructions from The Ruislip Set says the dance was ''devised for Jane. Will the two ladies of this name who have partnered me, please share this dance. Neither are "plain" and the title suits both of them.''', 44, '804/840/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1252, '1997-08-31 22:00:00+00', '2021-06-20 12:20:44.970651+00', 'Cobbler''s Awl, The', 'COBBLERS AWL', 1, 32, 9999, 1, 3, 42, 57, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1275, '1997-04-03 22:00:00+00', '2021-07-04 15:46:49.38271+00', 'Cold Iron Bridge, The', 'COLD IRON BRIDGE', 3, 32, 9999, 1, 4, NULL, 156, NULL, 'Comments of the author of the dance "The Cold Iron Bridge": I envisage an exchange of spys at a border post somewhere in the forests of eastern Europe. Why, I have no idea! (Source: Southern Stars Book, where the dance is published)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1288, '1998-01-04 23:00:00+00', '2019-04-29 16:33:09.308039+00', 'Colonel Anne Of Moy Hall', 'COLONEL ANNE OF MOY HALL', 1, 32, 9999, 1, 4, 1, 3461, '1984-01-01', '', 75, '6660/8880/6664/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1287, '1997-08-31 22:00:00+00', '2019-09-13 22:24:43.658768+00', 'Duke of Rutland''s Delight, The', 'DUKE OF RUTLANDS DELIGHT', 1, 32, 9999, 1, 2, NULL, 446, '1728-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3209, '1997-04-03 22:00:00+00', '2012-01-20 12:56:26.491707+00', 'Jar of Honey, A', 'JAR OF HONEY', 2, 32, 9999, 1, 2, NULL, 44, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1260, '1998-11-14 23:00:00+00', '2013-09-21 19:50:44.085774+00', 'Cock A Bendie', 'COCK A BENDIE', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3210, '1997-11-25 23:00:00+00', '2012-01-20 12:56:26.498577+00', 'Jean Anderson Strathspey', 'JEAN ANDERSON STRATHSPEY', 3, 128, 9999, 4, 98, NULL, 403, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3213, '1997-04-03 22:00:00+00', '2012-01-20 12:56:26.519502+00', 'Jean Flynn Jig', 'JEAN FLYNN JIG', 2, 32, 9999, 3, 5, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3215, '1998-01-04 23:00:00+00', '2012-01-20 12:56:26.533168+00', 'Jean Reid', 'JEAN REID', 1, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1276, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.047619+00', 'Coldoch Gamekeeper, The', 'COLDOCH GAMEKEEPER', 3, 32, 9999, 1, 3, 42, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10598, '2002-12-05 23:00:00+00', '2012-01-20 12:57:22.702603+00', 'Agitator, The', 'AGITATOR', 2, 32, 9999, 5, 4, NULL, 154, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1284, '1997-11-27 23:00:00+00', '2012-01-20 12:56:10.544106+00', 'Colliding Beams', 'COLLIDING BEAMS', 4, 64, 5, 5, 56, NULL, 787, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1286, '1997-08-31 22:00:00+00', '2012-01-20 12:56:10.562094+00', 'Collie''s Reel', 'COLLIES REEL', 1, 32, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1289, '1997-04-03 22:00:00+00', '2012-01-20 12:56:10.582892+00', 'Colonel Byng', 'COLONEL BYNG', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1292, '1997-04-03 22:00:00+00', '2012-01-20 12:56:10.603835+00', 'Colosseum', 'COLOSSEUM', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1294, '1997-08-31 22:00:00+00', '2012-01-20 12:56:10.619141+00', 'Co-master''s Cotillion, The', 'COMASTERS COTILLION', 3, 32, 9999, 4, 4, NULL, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1279, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.072791+00', 'College Echoes', 'COLLEGE ECHOES', 2, 40, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1301, '1997-04-03 22:00:00+00', '2012-01-20 12:56:10.66765+00', 'Come Rain or Shine', 'COME RAIN OR SHINE', 1, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1303, '1997-08-31 22:00:00+00', '2012-01-20 12:56:10.68136+00', 'Come To The Fair', 'COME TO THE FAIR', 2, 32, 9999, 1, 2, NULL, 761, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1306, '1997-09-29 22:00:00+00', '2012-01-20 12:56:10.704555+00', 'Come Ye Back Again', 'COME YE BACK AGAIN', 1, 48, 9999, 1, 4, NULL, 675, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1281, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.097832+00', 'College On The Hill', 'COLLEGE ON THE HILL', 2, 32, 9999, 1, 3, 42, 3, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1310, '1997-04-03 22:00:00+00', '2012-01-20 12:56:10.732801+00', 'Coming of Age', 'COMING OF AGE', 3, 32, 9999, 1, 4, NULL, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3217, '1997-09-04 22:00:00+00', '2012-01-20 12:56:26.547134+00', 'Jean''s Anniversary Strathspey', 'JEANS ANNIVERSARY STRATHSPEY', 3, 32, 9999, 5, 56, NULL, 964, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1259, '1998-04-08 22:00:00+00', '2022-07-31 09:59:22.173341+00', 'Cochno Burn', 'COCHNO BURN', 3, 32, 9999, 1, 3, 42, 121, '1966-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1307, '1998-01-11 23:00:00+00', '2023-02-17 12:30:53.263703+00', 'Comely Bank', 'COMELY BANK', 3, 32, 9999, 1, 2, 76, 108, '1980-01-01', 'The notes say this was "A dance for the Edinburgh Weekend School held at Cramond in April, 1980".', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1290, '1997-08-31 22:00:00+00', '2018-04-03 00:07:39.16452+00', 'Colonel Ridley', 'COLONEL RIDLEY', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3222, '1997-10-27 23:00:00+00', '2012-01-20 12:56:26.583797+00', 'Jeannie Blue E''en', 'JEANNIE BLUE EEN', 2, 32, 9999, 1, 2, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3223, '1997-09-04 22:00:00+00', '2012-01-20 12:56:26.590944+00', 'Jeannie Campbell of Edinburgh', 'JEANNIE CAMPBELL OF EDINBURGH', 3, 32, 9999, 1, 4, NULL, 311, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3227, '1997-09-04 22:00:00+00', '2012-01-20 12:56:26.618861+00', 'Jeannie''s Jaunt', 'JEANNIES JAUNT', 2, 32, 9999, 1, 2, NULL, 211, '1979-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3228, '1997-04-03 22:00:00+00', '2012-01-20 12:56:26.625864+00', 'Jeannie''s Jig', 'JEANNIES JIG', 2, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3229, '1997-04-03 22:00:00+00', '2012-01-20 12:56:26.634237+00', 'Jedburgh Castle', 'JEDBURGH CASTLE', 3, 32, 9999, 1, 4, NULL, 323, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10596, '2002-06-30 22:00:00+00', '2016-02-20 13:08:02.880547+00', 'Banks of Allan, The', 'BANKS OF ALLAN', 1, 32, 9999, 1, 3, 42, 27, '1999-01-01', '', 62, '888/888/800/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1298, '1997-04-03 22:00:00+00', '2017-08-28 19:27:42.407002+00', 'Come in out of the Rain', 'COME IN OUT OF THE RAIN', 1, 32, 9999, 1, 2, 76, 44, '1966-01-01', 'Devised for Michael Laidlaw', 60, '66/66/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1297, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.206248+00', 'Come Dance with Me', 'COME DANCE WITH ME', 1, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1305, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.247903+00', 'Come Walk With Me', 'COME WALK WITH ME', 3, 32, 9999, 1, 3, 42, 300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1309, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.256299+00', 'Comfrey Medley, The', 'COMFREY MEDLEY', 4, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1312, '1998-01-05 23:00:00+00', '2018-04-03 00:07:39.272982+00', 'Commoner Prince, The', 'COMMONER PRINCE', 1, 28, 9999, 1, 3, 42, 789, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3205, '1997-04-03 22:00:00+00', '2018-04-03 00:07:54.911473+00', 'Janet''s Wedding', 'JANETS WEDDING', 3, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3208, '1997-09-04 22:00:00+00', '2018-04-03 00:07:55.003168+00', 'January Strathspey, The', 'JANUARY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1017, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3211, '1997-09-04 22:00:00+00', '2018-04-03 00:07:55.061486+00', 'Jean Chaplin''s Jig', 'JEAN CHAPLINS JIG', 2, 32, 9999, 1, 3, 42, 176, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3212, '2000-09-02 22:00:00+00', '2018-04-03 00:07:55.069841+00', 'Jean Dyson''s Strathspey', 'JEAN DYSONS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 146, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3226, '1998-04-12 22:00:00+00', '2018-04-03 00:07:55.103099+00', 'Jeannie''s Delight', 'JEANNIES DELIGHT', 3, 32, 9999, 1, 3, 42, 2028, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1302, '1998-04-19 22:00:00+00', '2018-04-03 00:07:55.11982+00', 'Jean''s Dream', 'JEANS DREAM', 3, 32, 9999, 1, 3, 42, 417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10612, '2002-06-30 22:00:00+00', '2018-04-03 00:07:31.629603+00', 'Auld Stobhill, The', 'AULD STOBHILL', 1, 32, 9999, 1, 3, 42, 27, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1324, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.348116+00', 'Conversazione, The', 'CONVERSAZIONE', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1313, '1997-08-31 22:00:00+00', '2012-01-20 12:56:10.753397+00', 'Companion, The', 'COMPANION', 1, 32, 9999, 1, 2, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1316, '1997-08-31 22:00:00+00', '2012-01-20 12:56:10.775363+00', 'Concord Wedding, A', 'CONCORD WEDDING', 3, 64, 9999, 1, 4, NULL, 724, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1317, '1997-08-31 22:00:00+00', '2012-01-20 12:56:10.782167+00', 'Concorde', 'CONCORDE', 1, 32, 9999, 1, 2, NULL, 790, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1321, '1997-08-31 22:00:00+00', '2012-01-20 12:56:10.810143+00', 'Conor''s Fancy', 'CONORS FANCY', 3, 32, 9999, 1, 4, NULL, 794, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1318, '1997-08-31 22:00:00+00', '2019-03-04 18:56:53.10561+00', 'Concorde Strathspey, The', 'CONCORDE STRATHSPEY', 3, 32, 9999, 2, 3, 17, 791, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1325, '1997-11-27 23:00:00+00', '2012-01-20 12:56:10.839995+00', 'Cookery Nook', 'COOKERY NOOK', 4, 128, 2, 4, 4, NULL, 159, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1326, '1997-04-03 22:00:00+00', '2012-01-20 12:56:10.848806+00', 'Cookie Shine', 'COOKIE SHINE', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3224, '1997-04-03 22:00:00+00', '2020-12-27 21:35:51.264604+00', 'Jeanie Dean''s Jig', 'JEANIE DEANS JIG', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 75, '800/888/866/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10597, '2002-06-04 22:00:00+00', '2021-02-06 13:46:11.416965+00', 'Carleton Strathspey, The', 'CARLETON STRATHSPEY', 3, 32, 9999, 1, 3, 42, 316, NULL, '', 56, '800/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3207, '1997-04-03 22:00:00+00', '2021-05-25 12:40:35.671522+00', 'Janette''s Jig', 'JANETTES JIG', 2, 32, 9999, 1, 3, 42, 200, NULL, 'In the original instructions, the last sentence for bars 5-8 looks out of place (perhaps a copy of the end of bars 17-24).', 69, '880/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1328, '1997-04-03 22:00:00+00', '2012-01-20 12:56:10.86484+00', 'Cooper''s Jig, The', 'COOPERS JIG', 2, 32, 9999, 1, 4, NULL, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1319, '1997-08-31 22:00:00+00', '2019-03-18 11:34:55.994604+00', 'Connaught Ladies', 'CONNAUGHT LADIES', 3, 32, 9999, 1, 4, 1, 792, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1332, '1997-04-03 22:00:00+00', '2012-01-20 12:56:10.896186+00', 'Coppins Crossing', 'COPPINS CROSSING', 1, 32, 9999, 1, 4, NULL, 93, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10603, '2002-06-30 22:00:00+00', '2019-05-15 22:53:48.024612+00', 'Cockle Gathers, The', 'COCKLE GATHERS', 1, 32, 9999, 1, 4, NULL, 27, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1336, '1998-04-08 22:00:00+00', '2012-01-20 12:56:10.924388+00', 'Coral Sea Hornpipe, The', 'CORAL SEA HORNPIPE', 1, 32, 9999, 1, 4, NULL, 108, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1337, '1997-08-31 22:00:00+00', '2012-01-20 12:56:10.932664+00', 'Coral Wedding, The', 'CORAL WEDDING', 2, 32, 9999, 1, 2, NULL, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1291, '1997-08-25 22:00:00+00', '2014-05-16 19:59:30.950697+00', 'Colonel''s Bed, The', 'COLONELS BED', 2, 32, 9999, 1, 3, 42, 108, '1981-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3230, '1997-04-03 22:00:00+00', '2012-01-20 12:56:26.641053+00', 'Jeddah Roundabout', 'JEDDAH ROUNDABOUT', 2, 40, 9999, 4, 4, NULL, 3760, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1327, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.356373+00', 'Cooper''s Hornpipe', 'COOPERS HORNPIPE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3239, '1997-09-04 22:00:00+00', '2012-01-20 12:56:26.705821+00', 'Jesse''s Reel', 'JESSES REEL', 1, 32, 9999, 1, 4, NULL, 710, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10606, '2002-06-30 22:00:00+00', '2012-01-20 12:57:22.755461+00', 'Speyside Medley, The', 'SPEYSIDE MEDLEY', 4, 128, 2, 4, 4, NULL, 27, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10607, '2002-06-30 22:00:00+00', '2012-01-20 12:57:22.762402+00', 'Maryhill', 'MARYHILL', 1, 32, 9999, 6, 3, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1334, '2003-01-25 23:00:00+00', '2018-04-03 00:07:39.389741+00', 'Copy Cat', 'COPY CAT', 1, 40, 9999, 1, 3, 42, 35, '1979-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1335, '1997-12-21 23:00:00+00', '2018-04-03 00:07:39.423135+00', 'Coral Capers', 'CORAL CAPERS', 1, 32, 9999, 1, 3, 42, 425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1340, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.431448+00', 'Corbie''s Burn', 'CORBIES BURN', 3, 32, 9999, 1, 3, 42, 393, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1343, '1997-10-05 22:00:00+00', '2012-01-20 12:56:10.977961+00', 'Corinne''s Ceilidh', 'CORINNES CEILIDH', 2, 24, 9999, 1, 2, NULL, 795, NULL, '6 bar phrases', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1357, '2002-11-11 23:00:00+00', '2012-01-20 12:56:11.076211+00', 'Corryvrecken', 'CORRYVRECKEN', 2, 32, 9999, 3, 5, NULL, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1341, '1997-08-31 22:00:00+00', '2018-04-03 00:07:39.456451+00', 'Core Of My Heart', 'CORE OF MY HEART', 1, 32, 9999, 1, 3, 42, 653, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10608, '2002-06-30 22:00:00+00', '2016-02-20 13:41:50.252248+00', 'Baliemore', 'BALIEMORE', 1, 32, 9999, 1, 100, 2, 27, '1999-01-01', '', -1, '0880/8888/6666/4444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1346, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.473116+00', 'Cormorant''s Rock, The', 'CORMORANTS ROCK', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1344, '1997-04-03 22:00:00+00', '2016-05-19 23:15:21.766276+00', 'Cork Hill', 'CORK HILL', 2, 32, 9999, 1, 4, 1, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1347, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.548089+00', 'Corn On The Cob', 'CORN ON THE COB', 1, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3218, '1998-01-15 23:00:00+00', '2023-01-10 20:04:27.551034+00', 'Jean''s Frolic', 'JEANS FROLIC', 1, 32, 9999, 1, 3, 42, 1, '1978-09-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1314, '2001-11-13 23:00:00+00', '2023-02-17 12:27:49.117609+00', 'Company at the Manor', 'COMPANY AT THE MANOR', 2, 32, 9999, 1, 100, 2, 313, '1987-10-01', '"Devised after a Dance Weekend at Halsway Manor, Crowcombe, October 1987."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3242, '1997-04-03 22:00:00+00', '2018-01-15 13:41:43.386824+00', 'Jessie Stuart Of Dufftown', 'JESSIE STUART OF DUFFTOWN', 3, 32, 9999, 2, 3, 17, 89, '1989-06-15', 'Dance devised for Jessie Stuart who always makes everyone welcome to Dufftown.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1351, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.523176+00', 'Corner Link, The', 'CORNER LINK', 3, 32, 9999, 1, 3, 42, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1355, '1997-08-31 22:00:00+00', '2018-04-03 00:07:39.556445+00', 'Corporation, The', 'CORPORATION', 1, 40, 9999, 1, 3, 42, 466, '1777-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1370, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.706682+00', 'Country Weekend', 'COUNTRY WEEKEND', 3, 32, 9999, 1, 3, 42, 92, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1333, '1998-01-04 23:00:00+00', '2018-04-03 00:07:39.798572+00', 'Craigie Flowers Bloom Abroad', 'CRAIGIE FLOWERS BLOOM ABROAD', 3, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10611, '2002-06-30 22:00:00+00', '2018-04-03 00:08:14.418088+00', 'Sailor''s Wife, The', 'SAILORS WIFE', 3, 32, 9999, 1, 3, 42, 27, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1360, '1997-08-31 22:00:00+00', '2012-01-20 12:56:11.101903+00', 'Cotherstone Reel, The', 'COTHERSTONE REEL', 1, 32, 9999, 2, 3, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1362, '1997-04-03 22:00:00+00', '2012-01-20 12:56:11.119099+00', 'Cotyburn', 'COTYBURN', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3260, '2000-11-12 23:00:00+00', '2018-04-29 21:43:10.084668+00', 'Jig for Moira, A', 'JIG FOR MOIRA', 2, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18639, '2018-09-18 22:08:57.371245+00', '2019-01-24 16:31:11.61463+00', 'Monday Night Fancy', 'MONDAY NIGHT FANCY', 2, 32, NULL, 1, 2, 76, 3617, '1998-10-01', '', 60, '88/80/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1399, '1997-08-31 22:00:00+00', '2019-03-18 11:07:07.287671+00', 'Craigievar Reel, The', 'CRAIGIEVAR REEL', 1, 40, 9999, 1, 4, 1, 804, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1393, '1998-01-11 23:00:00+00', '2019-03-18 11:13:21.684373+00', 'Craigendoran', 'CRAIGENDORAN', 3, 32, 9999, 2, 3, 17, 108, '1971-01-01', '', 82, '821/866/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1387, '1997-08-31 22:00:00+00', '2019-08-29 18:52:29.847162+00', 'Craigdarroch''s Whistle', 'CRAIGDARROCHS WHISTLE', 1, 48, 9999, 2, 3, 17, 517, '1971-01-01', '', 82, '888/888/747/484/848/448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10613, '2002-06-30 22:00:00+00', '2012-01-20 12:57:22.801667+00', 'Isle of Mull, The', 'ISLE OF MULL', 4, 128, 2, 4, 4, NULL, 27, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1356, '1997-04-03 22:00:00+00', '2020-08-29 23:08:07.30439+00', 'Corrievrechan', 'CORRIEVRECHAN', 1, 32, 9999, 1, 3, 42, 313, NULL, '', 44, '800/444/444/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1363, '1998-07-08 22:00:00+00', '2020-12-30 12:03:25.072384+00', 'Coulin and Clair', 'COULIN AND CLAIR', 3, 32, 9999, 1, 4, 2, 13, NULL, '', 94, '8888/8888/8888/4884', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3238, '1997-09-04 22:00:00+00', '2021-04-07 18:57:42.035598+00', 'Jess''s Jubilee', 'JESSS JUBILEE', 3, 40, 9999, 107, 3, 18, 200, NULL, '3 couples (3x40) danced in a ‘U’ shape or horseshoe formation.', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1366, '1998-09-29 22:00:00+00', '2021-06-19 20:09:45.381234+00', 'Countess of Crawford''s Reel, The', 'COUNTESS OF CRAWFORDS REEL', 3, 40, 9999, 1, 3, 42, 9998, '1754-01-01', 'The Society’s version of this dance can be traced back to a collection *Caledonian Country Dances* published 1754.', 60, '888/888/880/844/844', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1359, '1997-08-31 22:00:00+00', '2021-06-19 20:18:29.545739+00', 'Corstorphine Park', 'CORSTORPHINE PARK', 3, 32, 9999, 1, 3, 42, 57, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1353, '1997-04-03 22:00:00+00', '2021-06-20 09:47:28.45115+00', 'Cornet''s Lass, The', 'CORNETS LASS', 3, 32, 9999, 1, 3, 42, 200, NULL, '', 47, '862/800/844/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1329, '1998-01-05 23:00:00+00', '2021-06-20 09:58:26.63122+00', 'Cooper''s Wife, The', 'COOPERS WIFE', 1, 32, 9999, 1, 3, 42, 417, '1985-01-01', '', 47, '880/800/822/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1349, '1997-04-03 22:00:00+00', '2021-06-21 23:17:01.723368+00', 'Corner Cupboard, The', 'CORNER CUPBOARD', 1, 40, 9999, 1, 3, 42, 393, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10615, '2002-06-30 22:00:00+00', '2012-01-20 12:57:22.814768+00', 'Belfast Castle', 'BELFAST CASTLE', 1, 40, 9999, NULL, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3240, '1997-08-24 22:00:00+00', '2018-04-02 23:56:35.468694+00', 'Jessie Cruickshank', 'JESSIE CRUICKSHANK', 3, 32, 9999, 1, 3, 42, 108, '1990-05-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1361, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.639985+00', 'Cotton Reel', 'COTTON REEL', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1371, '1997-11-23 23:00:00+00', '2012-01-20 12:56:11.191787+00', 'Country Wife''s Ball, The', 'COUNTRY WIFES BALL', 4, 32, 9999, 1, 2, NULL, 389, '1983-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1373, '1998-04-21 22:00:00+00', '2012-01-20 12:56:11.206157+00', 'Court Jester, The', 'COURT JESTER', 2, 32, 9999, 1, 2, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1374, '1998-01-05 23:00:00+00', '2012-01-20 12:56:11.213012+00', 'Courtship', 'COURTSHIP', 1, 32, 9999, 1, 4, NULL, 348, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1377, '1998-07-08 22:00:00+00', '2012-01-20 12:56:11.234411+00', 'Couthie Lass', 'COUTHIE LASS', 3, 32, 9999, 1, 4, 2, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1379, '1997-09-11 22:00:00+00', '2012-01-20 12:56:11.248104+00', 'Covered Wagon, The', 'COVERED WAGON', 3, 32, 9999, 1, 4, NULL, 114, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1380, '1997-08-31 22:00:00+00', '2012-01-20 12:56:11.25487+00', 'Cowal Games, The', 'COWAL GAMES', 2, 32, 9999, 5, 2, NULL, 799, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1394, '1997-09-28 22:00:00+00', '2012-01-20 12:56:11.357323+00', 'Craigflower Cutie', 'CRAIGFLOWER CUTIE', 1, 32, 9999, 1, 4, NULL, 590, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1395, '1997-08-31 22:00:00+00', '2012-01-20 12:56:11.364231+00', 'Craigie''s Folly', 'CRAIGIES FOLLY', 1, 32, 9999, 1, 4, NULL, 802, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1396, '1997-08-31 22:00:00+00', '2012-01-20 12:56:11.371036+00', 'Craigie''s Reel', 'CRAIGIES REEL', 1, 32, 9999, 1, 4, NULL, 803, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3258, '2000-11-12 23:00:00+00', '2012-01-20 12:56:26.838971+00', 'Jig for Marie, A', 'JIG FOR MARIE', 2, 32, 9999, 1, 4, 2, 247, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3259, '2001-06-12 22:00:00+00', '2012-01-20 12:56:26.846727+00', 'Jig for Midge', 'JIG FOR MIDGE', 2, 40, 9999, 1, 4, 1, 2896, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3262, '2000-11-12 23:00:00+00', '2012-01-20 12:56:26.869301+00', 'Jig for Ron, A', 'JIG FOR RON', 2, 40, 9999, 4, 4, NULL, 1025, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1365, '1997-08-31 22:00:00+00', '2018-04-03 00:07:39.664967+00', 'Counter Trey', 'COUNTER TREY', 2, 32, 9999, 1, 3, 42, 797, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10616, '2002-06-30 22:00:00+00', '2012-01-20 12:57:22.820855+00', 'Hazelwood', 'HAZELWOOD', 3, 32, 9999, 1, 99, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1369, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.698292+00', 'Country Club Hills', 'COUNTRY CLUB HILLS', 2, 32, 9999, 1, 3, 42, 361, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1381, '2003-01-28 23:00:00+00', '2018-04-03 00:07:39.740064+00', 'Crack The Whip', 'CRACK THE WHIP', 2, 32, 9999, 1, 3, 42, 35, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1386, '1997-09-11 22:00:00+00', '2018-04-03 00:07:39.756742+00', 'Craigdarroch Jig, The', 'CRAIGDARROCH JIG', 2, 32, 9999, 1, 3, 42, 800, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1391, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.773382+00', 'Craigellachie Reel, The', 'CRAIGELLACHIE REEL', 2, 32, 9999, 1, 3, 42, 417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1397, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.790091+00', 'Craigieburn Wood', 'CRAIGIEBURN WOOD', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10614, '2002-06-30 22:00:00+00', '2018-04-03 00:07:45.378376+00', 'Favourite, The', 'FAVOURITE', 3, 32, 9999, 1, 3, 42, 27, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3248, '1998-01-04 23:00:00+00', '2018-04-03 00:07:55.259779+00', 'Jessie-in-the-Middle', 'JESSIEINTHEMIDDLE', 1, 40, 9999, 1, 3, 42, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3243, '1997-04-03 22:00:00+00', '2018-04-03 00:07:55.293188+00', 'Jessie''s Fancy', 'JESSIES FANCY', 2, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1372, '1998-11-14 23:00:00+00', '2022-03-31 17:44:39.02182+00', 'Courage Reel, The', 'COURAGE REEL', 1, 48, 9999, 1, 3, 42, 108, '1977-01-01', 'Dedicated to Simon Fraser of "The Courage", Nairn', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1385, '1997-11-25 23:00:00+00', '2022-06-26 22:08:55.139559+00', 'Craigard', 'CRAIGARD', 1, 128, 9999, 4, 4, 3, 755, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3234, '1997-09-04 22:00:00+00', '2022-07-31 10:55:43.891833+00', 'Jennifer''s Strathspey', 'JENNIFERS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 601, '1987-01-01', 'Devised "in 1987 to mark the occasion of the wedding of her elder daughter in Quatercentenary year."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1390, '2002-04-30 22:00:00+00', '2023-02-17 12:12:24.404069+00', 'Craigellachie Lasses', 'CRAIGELLACHIE LASSES', 2, 32, 9999, 1, 2, 76, 108, '1988-06-01', 'The notes say this was a "dance for the week of dancing in Aviemore - June 1988".', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3249, '1997-04-03 22:00:00+00', '2018-04-03 00:07:55.336647+00', 'Jethart''s Here', 'JETHARTS HERE', 1, 32, 9999, 1, 3, 42, 101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3255, '2001-05-20 22:00:00+00', '2018-04-03 00:07:55.503494+00', 'Jig for Joan and John, A', 'JIG FOR JOAN AND JOHN', 2, 32, 9999, 1, 3, 42, 971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1406, '1997-08-25 22:00:00+00', '2019-01-25 17:40:49.777706+00', 'Crannog, The', 'CRANNOG', 3, 32, 9999, 1, 3, 42, 108, '1981-01-01', '', 62, '686/686/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3270, '1998-04-02 22:00:00+00', '2012-01-20 12:56:26.927649+00', 'Jill of Corstorphine', 'JILL OF CORSTORPHINE', 3, 80, 9999, 4, 4, NULL, 617, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3271, '1998-04-16 22:00:00+00', '2012-01-20 12:56:26.935969+00', 'Jill''s Medley', 'JILLS MEDLEY', 4, 48, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5084, '2000-08-01 22:00:00+00', '2018-02-26 07:00:50.367605+00', 'Once A Month', 'ONCE A MONTH', 1, 32, 9999, 1, 3, 42, 843, '1993-01-01', 'Written for the dancers of Higasinakano Scottish Country Dance Circle. Usually they gather and dance on the evening of 3rd or 4 th Saturday, once a month.



_Suggested music_: "For to-night we''ll merry, merry be" (Kerr''s collection)



Played A, A, B, C, where A, B, and C are each 8 bars.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10626, '2002-07-01 22:00:00+00', '2018-04-03 00:07:33.298914+00', 'Big Ball of Yarn, The', 'BIG BALL OF YARN', 3, 32, 9999, 1, 3, 42, 10297, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10625, '2002-07-01 22:00:00+00', '2012-01-20 12:57:22.879142+00', 'Basket of Kittens, A', 'BASKET OF KITTENS', 1, 40, 9999, 1, 4, 2, 2203, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10622, '2002-06-30 22:00:00+00', '2018-10-18 15:09:39.64194+00', 'Turning the Stone', 'TURNING THE STONE', 2, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10621, '2002-06-30 22:00:00+00', '2018-10-18 15:10:45.582729+00', 'Thistle And The Shamrock, The', 'THISTLE AND THE SHAMROCK', 4, 64, 5, 4, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1392, '1997-04-03 22:00:00+00', '2020-01-26 14:26:19.541797+00', 'Craigenarden', 'CRAIGENARDEN', 1, 32, 9999, 1, 3, 42, 13, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3254, '2000-11-12 23:00:00+00', '2021-03-16 12:42:43.737197+00', 'Jig for Jeannie, A', 'JIG FOR JEANNIE', 2, 32, 9999, 1, 3, 42, 2526, NULL, 'For all the Jeannies of Scottish Country Dancing -- especially one!', 47, '800/888/8811/811', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1389, '1997-04-03 22:00:00+00', '2020-08-04 00:29:18.388155+00', 'Craigellachie Brig', 'CRAIGELLACHIE BRIG', 1, 40, 9999, 1, 3, 42, 249, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1413, '1999-07-25 22:00:00+00', '2020-08-04 00:30:33.112729+00', 'Creel, The', 'CREEL', 1, 32, 9999, 1, 4, 11, 175, '1966-01-01', 'A Creel is a fishing basket.  Bars 1-16 show the construction of the sides, 17-24 the top rim, and 25-32 the two handles, one on each side.



First published on a Glendarroch SCD Sheet in 1966.

', 87, '8448/4884/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3266, '1997-09-04 22:00:00+00', '2020-08-06 15:12:30.238268+00', 'Jig for Charlie, A', 'JIG FOR CHARLIE', 2, 32, 9999, 1, 3, 42, 1020, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3285, '1997-04-03 22:00:00+00', '2020-08-06 15:13:49.245184+00', 'Jindalee Jig, The', 'JINDALEE JIG', 2, 32, 9999, 1, 2, NULL, 151, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1352, '1998-07-08 22:00:00+00', '2020-08-29 23:04:15.391961+00', 'Cornet''s Chase, The', 'CORNETS CHASE', 2, 40, 9999, 1, 100, 2, 101, '1991-01-01', '', 72, '8008/8888/8228/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3253, '2000-11-12 23:00:00+00', '2020-08-30 21:19:18.630194+00', 'Jig for Jack, A', 'JIG FOR JACK', 2, 32, 9999, 1, 3, 42, 372, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1364, '1997-04-03 22:00:00+00', '2021-06-19 20:13:25.186527+00', 'Coulter''s Candy', 'COULTERS CANDY', 1, 32, 9999, 1, 3, 42, 352, '1993-01-17', '', 44, '800/800/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3261, '2000-11-12 23:00:00+00', '2021-05-25 12:02:22.993235+00', 'Jig for Robin, A', 'JIG FOR ROBIN', 2, 32, 9999, 2, 2, 76, 1024, '1987-11-01', 'Dedicated to Robin Chubb, a founding teacher of the Kingston Scottish Country Dance Society, which is now Kingston Ontario Branch.



The instructions say this is for a 3 couple set.

', 54, '80/88/84/88', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3263, '1997-09-04 22:00:00+00', '2021-06-06 21:24:41.147419+00', 'Jig of Scurs, The', 'JIG OF SCURS', 2, 32, 9999, 1, 3, 42, 270, NULL, '', 63, '855/833/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1411, '1997-04-03 22:00:00+00', '2012-01-20 12:56:11.474597+00', 'Credit To Colin, A', 'CREDIT TO COLIN', 2, 32, 9999, 1, 2, NULL, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1425, '1997-04-03 22:00:00+00', '2019-05-12 09:37:56.911922+00', 'Crofter''s Rant, The', 'CROFTERS RANT', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 56, '822/888/822/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10627, '2002-07-01 22:00:00+00', '2018-04-03 00:07:36.502645+00', 'Calico Jig, The', 'CALICO JIG', 2, 32, 9999, 1, 3, 42, 10298, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1416, '1997-04-03 22:00:00+00', '2012-01-20 12:56:11.512924+00', 'Crieff Hydro, The', 'CRIEFF HYDRO', 1, 32, 9999, 1, 4, 1, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10628, '2002-07-01 22:00:00+00', '2018-04-03 00:07:37.41237+00', 'Cat in the Argyll Socks, The', 'CAT IN THE ARGYLL SOCKS', 1, 40, 9999, 1, 3, 42, 10297, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1418, '1997-04-03 22:00:00+00', '2012-01-20 12:56:11.526542+00', 'Crimson Heather', 'CRIMSON HEATHER', 3, 32, 9999, 1, 2, NULL, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1419, '1997-08-31 22:00:00+00', '2012-01-20 12:56:11.533386+00', 'Crinan Waters', 'CRINAN WATERS', 3, 32, 9999, 1, 4, NULL, 650, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3284, '1998-09-29 22:00:00+00', '2019-06-11 09:48:21.592191+00', 'Jimp Waist, The', 'JIMP WAIST', 3, 32, 9999, 3, 110, 17, 9998, NULL, '', 40, '88000/88000/80000/88800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1421, '2000-05-17 22:00:00+00', '2012-01-20 12:56:11.546974+00', 'Brandywine Bridge', 'BRANDYWINE BRIDGE', 2, 32, 9999, 7, 56, NULL, 2203, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3272, '1997-10-27 23:00:00+00', '2012-01-20 12:56:26.943097+00', 'Jim Anderson''s Delight', 'JIM ANDERSONS DELIGHT', 2, 48, 9999, 1, 4, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3274, '1997-04-03 22:00:00+00', '2012-01-20 12:56:26.957307+00', 'Jim Bruce', 'JIM BRUCE', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3279, '1997-09-05 22:00:00+00', '2012-01-20 12:56:26.992942+00', 'Jimmy Shand Jig, The', 'JIMMY SHAND JIG', 2, 32, 9999, 1, 4, NULL, 297, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3283, '2002-03-12 23:00:00+00', '2012-01-20 12:56:27.031481+00', 'Jimmy''s Taen Alice Awa''', 'JIMMYS TAEN ALICE AWA', 3, 24, 9999, 1, 4, 1, 111, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10629, '2002-07-01 22:00:00+00', '2012-01-20 12:57:22.907001+00', 'Catnap', 'CATNAP', 3, 32, 9999, 1, 4, 2, 2203, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10630, '2002-07-01 22:00:00+00', '2012-01-20 12:57:22.914089+00', 'Chasing Bugs', 'CHASING BUGS', 1, 32, 9999, 1, 2, NULL, 10299, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1432, '1997-04-03 22:00:00+00', '2012-01-20 12:56:11.622943+00', 'Crook Of Devon', 'CROOK OF DEVON', 1, 32, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10620, '2002-06-30 22:00:00+00', '2016-08-04 21:48:19.866549+00', 'Shepherd of Slemish, The', 'SHEPHERD OF SLEMISH', 3, 32, 9999, 1, 4, 2, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1401, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.840189+00', 'Craigmillar Castle', 'CRAIGMILLAR CASTLE', 3, 24, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1408, '1997-04-03 22:00:00+00', '2018-04-03 00:07:39.873498+00', 'Crathes', 'CRATHES', 3, 32, 9999, 1, 3, 42, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1412, '1997-09-03 22:00:00+00', '2018-04-03 00:07:39.998638+00', 'Creel, The', 'CREEL', 1, 32, 9999, 1, 3, 42, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1422, '1997-04-03 22:00:00+00', '2018-04-03 00:07:40.03203+00', 'Croaghpatrick', 'CROAGHPATRICK', 2, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1423, '1997-09-29 22:00:00+00', '2018-04-03 00:07:40.040342+00', 'Crock Of Gold, The', 'CROCK OF GOLD', 2, 32, 9999, 1, 3, 42, 325, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10631, '2002-07-01 22:00:00+00', '2018-04-03 00:07:41.408164+00', 'Daphne the Scamp', 'DAPHNE THE SCAMP', 2, 32, 9999, 1, 3, 42, 10299, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3273, '1997-04-03 22:00:00+00', '2018-04-03 00:07:55.653518+00', 'Jim Barrie', 'JIM BARRIE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3275, '1997-04-03 22:00:00+00', '2018-04-03 00:07:55.661856+00', 'Jim Douglas', 'JIM DOUGLAS', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3276, '1997-04-03 22:00:00+00', '2018-04-03 00:07:55.670189+00', 'Jim Kennedy''s Jig', 'JIM KENNEDYS JIG', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3278, '1997-09-05 22:00:00+00', '2018-04-03 00:07:55.678587+00', 'Jim McKenzie''s Rant', 'JIM MACKENZIES RANT', 3, 32, 9999, 1, 3, 42, 109, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3277, '2002-11-18 23:00:00+00', '2023-01-10 19:49:06.853812+00', 'Jim MacLellan''s Strathspey', 'JIM MACLELLANS STRATHSPEY', 3, 32, 9999, 1, 4, 2, 108, '1988-01-01', 'Inscribed "for Jim MacLellan of Cape Breton Island, Nova Scotia".', 56, '4444/4444/4884/8008', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1433, '1997-04-03 22:00:00+00', '2012-01-20 12:56:11.629834+00', 'Crook Of Devon, The', 'CROOK OF DEVON', 1, 32, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1434, '1997-04-03 22:00:00+00', '2012-01-20 12:56:11.636702+00', 'Crook Of The Lade', 'CROOK OF THE LADE', 3, 40, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1436, '1997-04-03 22:00:00+00', '2012-01-20 12:56:11.650278+00', 'Crooked Glen, The', 'CROOKED GLEN', 2, 32, 9999, 3, 5, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1439, '1997-04-03 22:00:00+00', '2012-01-20 12:56:11.67079+00', 'Crosrien', 'CROSRIEN', 1, 32, 9999, 1, 4, NULL, 195, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1456, '1997-04-03 22:00:00+00', '2019-04-08 21:41:10.301225+00', 'Cruachan Jig, The', 'CRUACHAN JIG', 2, 32, 9999, 1, 3, 42, 250, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18881, '2018-10-08 18:11:53.356471+00', '2019-09-27 22:24:04.225147+00', 'Singapore Fling', 'SINGAPORE FLING', 3, 32, NULL, 1, 3, 42, 2766, '2009-07-01', 'This dance was written for Mel Whitson and Ken Heinemann and their trip to Singapore.



The dance was  was previously called "Shanghai Calling".', 71, '888/766/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1444, '1997-09-12 22:00:00+00', '2012-01-20 12:56:11.705096+00', 'Crossing of Hadrian''s Wall', 'CROSSING OF HADRIANS WALL', 2, 32, 9999, 1, 4, NULL, 318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1454, '1998-07-08 22:00:00+00', '2019-10-05 22:00:52.022978+00', 'Crown of Scotland', 'CROWN OF SCOTLAND', 3, 32, 9999, 1, 4, 11, 13, NULL, '', 88, '8008/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3286, '1998-01-15 23:00:00+00', '2012-01-20 12:56:27.054767+00', 'Jinglin'' Geordie''s Dance', 'JINGLIN GEORDIES DANCE', 1, 40, 9999, 1, 4, NULL, 95, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3292, '1997-09-05 22:00:00+00', '2012-01-20 12:56:27.097564+00', 'Jo Ibbott Strathspey', 'JO IBBOTT STRATHSPEY', 3, 80, 9999, 1, 4, NULL, 1031, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3295, '1997-04-03 22:00:00+00', '2012-01-20 12:56:27.118013+00', 'Jo''s Choice', 'JOS CHOICE', 3, 32, 9999, 1, 4, NULL, 222, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10634, '2002-07-01 22:00:00+00', '2012-01-20 12:57:22.942512+00', 'Miss Beans', 'MISS BEANS', 2, 32, 9999, 1, 4, 1, 10298, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1447, '1997-09-06 22:00:00+00', '2020-08-04 00:32:27.481325+00', 'Crossmichael', 'CROSSMICHAEL', 3, 32, 9999, 1, 3, 42, 129, '1966-01-01', '', 54, '282/606/886/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3282, '1997-09-05 22:00:00+00', '2020-08-06 15:13:13.677345+00', 'Jimmy''s Jig', 'JIMMYS JIG', 1, 40, 9999, 8, 6, NULL, 151, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1420, '1997-04-03 22:00:00+00', '2020-11-06 12:43:16.391425+00', 'Crinkum-Crankum', 'CRINKUMCRANKUM', 2, 32, 9999, 1, 3, 42, 99, '1987-01-01', '', 56, '888/822/822/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1407, '1997-04-03 22:00:00+00', '2020-12-12 10:06:47.256444+00', 'Cranston''s Rant', 'CRANSTONS RANT', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 53, '686/808/888/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1431, '1998-11-14 23:00:00+00', '2021-06-18 23:53:02.324703+00', 'Cromdel Hill', 'CROMDEL HILL', 1, 32, 9999, 1, 3, 42, 9998, '1740-01-01', 'Described as for a 4 (or 5) couple set.', 38, '800/800/808/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1429, '1997-12-29 23:00:00+00', '2021-06-18 23:59:41.131501+00', 'Over the Hill', 'OVER THE HILL', 3, 32, 9999, 1, 3, 42, 175, '1995-05-01', 'Devised in May 1995.  It is dedicated to all of his contemporary dancing friends.', 50, '880/633/633/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10636, '2002-07-01 22:00:00+00', '2012-01-20 12:57:22.956806+00', 'Spilt Milk', 'SPILT MILK', 4, 64, 5, 1, 4, 1, 10300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10637, '2002-07-01 22:00:00+00', '2012-01-20 12:57:22.964275+00', 'Spunky''s Stroll', 'SPUNKYS STROLL', 3, 32, 9999, 2, 3, 17, 10299, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3549, '2000-07-26 22:00:00+00', '2018-02-26 10:49:38.229898+00', 'Kurazukuri', 'KURAZUKURI', 3, 40, 9999, 2, 3, 18, 2780, NULL, 'This dance was named after the image of "KURAZUKURI", Japanese old warehouses in Kawagoe, Saitama.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1435, '1998-01-05 23:00:00+00', '2018-04-03 00:07:29.523081+00', 'Accordion Player, The', 'ACCORDION PLAYER', 1, 32, 9999, 1, 3, 42, 557, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1459, '1998-07-08 22:00:00+00', '2012-01-20 12:56:11.811512+00', 'Cryin'' O'' The Fair, The', 'CRYIN O THE FAIR', 3, 32, 9999, 1, 4, 11, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1462, '2003-01-28 23:00:00+00', '2012-01-20 12:56:11.83214+00', 'Crystal Palace, The', 'CRYSTAL PALACE', 3, 32, 9999, 1, 4, NULL, 35, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1468, '1997-11-24 23:00:00+00', '2012-01-20 12:56:11.873275+00', 'Cuil An Duin', 'CUIL AN DUIN', 4, 64, 5, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1472, '1997-08-31 22:00:00+00', '2012-01-20 12:56:11.901137+00', 'Culdrossan Castle', 'CULDROSSAN CASTLE', 3, 32, 9999, 2, 3, 17, 808, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1440, '1997-04-03 22:00:00+00', '2018-04-03 00:07:40.123735+00', 'Cross Creek Reel, The', 'CROSS CREEK REEL', 1, 32, 9999, 1, 3, 42, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1482, '1997-04-03 22:00:00+00', '2012-01-20 12:56:11.970911+00', 'Cupar Barn Dance', 'CUPAR BARN DANCE', 3, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1441, '1997-04-03 22:00:00+00', '2018-04-03 00:07:40.132096+00', 'Cross Hills Gardens', 'CROSS HILLS GARDENS', 2, 32, 9999, 1, 3, 42, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1442, '1998-01-05 23:00:00+00', '2018-04-03 00:07:40.223928+00', 'Cross of Saint Andrew', 'CROSS OF SAINT ANDREW', 1, 48, 9999, 1, 3, 42, 343, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1448, '1997-08-31 22:00:00+00', '2018-04-03 00:07:40.248734+00', 'Crossways', 'CROSSWAYS', 3, 40, 9999, 1, 3, 42, 806, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1450, '1998-11-17 23:00:00+00', '2018-04-03 00:07:40.257074+00', 'Crossways Cottage Jig', 'CROSSWAYS COTTAGE JIG', 2, 40, 9999, 1, 3, 42, 351, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1455, '1997-04-03 22:00:00+00', '2018-04-03 00:07:40.298801+00', 'Croydon''s Forty', 'CROYDONS FORTY', 2, 32, 9999, 1, 3, 42, 676, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1463, '1997-08-31 22:00:00+00', '2018-04-03 00:07:40.357316+00', 'Crystal Reel', 'CRYSTAL REEL', 1, 32, 9999, 1, 3, 42, 300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3290, '1997-09-05 22:00:00+00', '2018-04-03 00:07:55.88519+00', 'Jip''s Jig', 'JIPS JIG', 2, 32, 9999, 1, 3, 42, 1029, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3296, '1997-04-03 22:00:00+00', '2018-04-03 00:07:55.970944+00', 'Joan Warren''s Jig', 'JOAN WARRENS JIG', 2, 32, 9999, 1, 3, 42, 196, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3294, '1997-04-03 22:00:00+00', '2018-04-03 00:07:56.428948+00', 'Jo''s A Jolly Partner', 'JOS A JOLLY PARTNER', 1, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10633, '2002-07-01 22:00:00+00', '2018-04-03 00:07:57.705144+00', 'Kitten in the Rain', 'KITTEN IN THE RAIN', 3, 32, 9999, 1, 3, 42, 2203, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10635, '2002-07-01 22:00:00+00', '2018-04-03 00:08:15.760571+00', 'Shadow at the Door', 'SHADOW AT THE DOOR', 3, 40, 9999, 1, 3, 42, 2203, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1487, '1997-04-03 22:00:00+00', '2018-04-29 10:31:58.688053+00', 'Curtain Call', 'CURTAIN CALL', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3302, '1997-04-03 22:00:00+00', '2012-01-20 12:56:27.169224+00', 'Joan''s Strathspey', 'JOANS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1503, '1997-04-03 22:00:00+00', '2018-08-22 09:27:52.217117+00', 'Dalqueish', 'DALQUEISH', 3, 32, 9999, 1, 3, 42, 28, NULL, 'To Dorothy Bates, with whom I enjoyed sharing the teaching of the Bristol Branchchildrens classes at Torwood House.', 47, '800/833/833/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3304, '2000-02-25 23:00:00+00', '2012-01-20 12:56:27.182849+00', 'Jock Wilson''s Reel', 'JOCK WILSONS REEL', 1, 32, 9999, 1, 4, NULL, 563, '1960-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18676, '2018-10-01 12:14:29.787686+00', '2018-10-01 12:30:48.888179+00', 'August Day, An', 'AUGUST DAY', 1, 32, NULL, 1, 3, 42, 2766, '2013-08-01', 'This dance was written on an August day, thus the name.', 53, '842/482/484/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1510, '1997-09-01 22:00:00+00', '2019-03-17 23:44:28.344169+00', 'Dame Alison Munro', 'DAME ALISON MUNRO', 3, 32, 9999, 1, 3, 42, 812, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3293, '1997-04-03 22:00:00+00', '2022-08-12 09:10:04.284601+00', 'Jo Mansfield''s Rant', 'JO MANSFIELDS RANT', 1, 88, 9999, 4, 4, 3, 99, '1985-05-01', 'Inscribed "For Miss Joanne Mansfield of Reading on her 21st Birthday Devised May, 1985 and revised (bars 73-80) January, 1987".', 73, '8888/8888/8000/0800/0080/0008/8888/8888/8888/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1460, '1997-08-31 22:00:00+00', '2022-08-18 20:10:07.394549+00', 'Crystal', 'CRYSTAL', 3, 48, 9999, 1, 4, 1, 653, NULL, '"This dance is dedicated with love to my wife Phil Bowlen."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1443, '1997-04-03 22:00:00+00', '2022-11-07 16:40:34.354027+00', 'Cross at Inverness', 'CROSS AT INVERNESS', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1507, '2002-03-03 23:00:00+00', '2019-03-17 23:48:04.656276+00', 'Dalston Hall', 'DALSTON HALL', 3, 40, 9999, 1, 4, 1, 108, '1967-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1489, '1997-04-03 22:00:00+00', '2019-06-07 13:39:24.508239+00', 'D Day', 'D DAY', 1, 32, 9999, 1, 3, 42, 352, '1993-06-06', '', 47, '840/844/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3311, '1997-09-05 22:00:00+00', '2012-01-20 12:56:27.231289+00', 'Jog On', 'JOG ON', 2, 208, 9999, 2, 3, NULL, 446, '1651-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1494, '1997-04-03 22:00:00+00', '2019-09-13 14:48:07.670756+00', 'Dagg''s Of Craighouse', 'DAGGS OF CRAIGHOUSE', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1491, '1997-09-03 22:00:00+00', '2012-01-20 12:56:12.034569+00', 'Grocer, Da', 'GROCER', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1493, '1997-09-01 22:00:00+00', '2012-01-20 12:56:12.048631+00', 'Daft Willy', 'DAFT WILLY', 3, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1500, '1997-04-03 22:00:00+00', '2012-01-20 12:56:12.096336+00', 'Dalkeith Piper', 'DALKEITH PIPER', 1, 40, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1502, '1997-09-01 22:00:00+00', '2012-01-20 12:56:12.10994+00', 'Dalmahoy House', 'DALMAHOY HOUSE', 2, 64, 9999, 5, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10640, '2002-07-04 22:00:00+00', '2018-04-03 00:07:31.646293+00', 'Auld Wheel, The', 'AULD WHEEL', 1, 32, 9999, 1, 3, 42, 854, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1504, '1997-10-27 23:00:00+00', '2020-03-09 15:47:05.359456+00', 'Dalry', 'DALRY', 2, 32, 9999, 1, 3, 42, 270, NULL, '', 66, '864/888/888/468', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3291, '1997-04-03 22:00:00+00', '2020-08-06 15:14:16.162946+00', 'Jitney, The', 'JITNEY', 2, 32, 9999, 1, 3, 42, 249, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1464, '1997-09-29 22:00:00+00', '2020-12-30 12:36:20.212717+00', 'Cubbie Roo', 'CUBBIE ROO', 2, 32, 9999, 1, 2, 76, 13, NULL, '', 60, '80/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1483, '2000-10-13 22:00:00+00', '2021-06-18 17:42:23.165222+00', 'Cupar Jig, The', 'CUPAR JIG', 2, 32, 9999, 1, 2, 76, 394, NULL, 'Suited for Jig as well as Strathspey time (stated explicitly in the description of the dance).', 64, '88/88/84/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3287, '1997-04-03 22:00:00+00', '2021-05-21 20:51:06.121788+00', 'Jingling Geordie', 'JINGLING GEORDIE', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 53, '808/844/848/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1481, '1998-04-08 22:00:00+00', '2021-06-18 20:50:13.296992+00', 'Cup-of-Gold Vine, The', 'CUPOFGOLD VINE', 2, 32, 9999, 1, 3, 42, 348, '1992-01-01', '', 50, '800/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1475, '1997-08-31 22:00:00+00', '2021-06-18 20:54:21.836036+00', 'Culloden Moor', 'CULLODEN MOOR', 3, 32, 9999, 1, 3, 42, 149, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1474, '1997-04-03 22:00:00+00', '2021-06-18 21:00:46.661941+00', 'Culloden Links', 'CULLODEN LINKS', 3, 32, 9999, 1, 100, 2, 108, '1973-01-01', 'Published also in the Diamond Jubilee Collection of the RSCDS Inverness and District Branch: http://my.strathspey.org/dd/publ/1027/', 75, '8008/8888/8008/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1446, '1998-09-29 22:00:00+00', '2021-06-18 23:48:41.629978+00', 'Crossing, The', 'CROSSING', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 44, '440/440/888/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1451, '1998-01-05 23:00:00+00', '2021-07-02 18:03:31.34908+00', 'Crowberry, The', 'CROWBERRY', 1, 32, 9999, 1, 3, 42, 57, '1976-09-01', 'The Crowberry is the badge of Clan Cameron.', 55, '828/448/822/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1509, '1997-09-01 22:00:00+00', '2012-01-20 12:56:12.212903+00', 'Dambusters, The', 'DAMBUSTERS', 2, 40, 9999, 1, 98, NULL, 811, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1512, '2002-03-02 23:00:00+00', '2012-01-20 12:56:12.233939+00', 'Dame Flora''s Strathspey', 'DAME FLORAS STRATHSPEY', 3, 32, 9999, 2, 3, NULL, 146, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1514, '1997-04-03 22:00:00+00', '2012-01-20 12:56:12.247568+00', 'Dance Eternal', 'DANCE ETERNAL', 2, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1516, '2002-04-29 22:00:00+00', '2012-01-20 12:56:12.261224+00', 'Dance for Doris', 'DANCE FOR DORIS', 1, 32, 9999, 2, 3, NULL, 377, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1517, '2002-04-29 22:00:00+00', '2012-01-20 12:56:12.268831+00', 'Dance for Elva', 'DANCE FOR ELVA', 2, 32, 9999, 1, 4, 2, 425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1523, '1997-04-03 22:00:00+00', '2012-01-20 12:56:12.32304+00', 'Dance With A Friend', 'DANCE WITH A FRIEND', 3, 32, 9999, 1, 4, NULL, 204, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3316, '1997-04-03 22:00:00+00', '2012-01-20 12:56:27.268327+00', 'John Burnett Hall', 'JOHN BURNETT HALL', 1, 32, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3319, '1997-04-03 22:00:00+00', '2012-01-20 12:56:27.288747+00', 'John Farquharson''s Reel', 'JOHN FARQUHARSONS REEL', 1, 32, 9999, 1, 2, NULL, 293, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1519, '1998-01-05 23:00:00+00', '2018-04-03 00:07:35.392902+00', 'Braes of Glenisla, The', 'BRAES OF GLENISLA', 1, 32, 9999, 1, 3, 42, 722, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1506, '1998-01-12 23:00:00+00', '2016-05-11 14:01:25.946128+00', 'Dalry Kirk Reel', 'DALRY KIRK REEL', 1, 32, 9999, 103, 109, NULL, 210, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1497, '1997-04-03 22:00:00+00', '2018-04-03 00:07:40.632392+00', 'Daisy Daisy', 'DAISY DAISY', 2, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1515, '2002-04-29 22:00:00+00', '2018-04-03 00:07:40.79086+00', 'Dance for Betty, A', 'DANCE FOR BETTY', 4, 32, 1, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1522, '1997-10-08 22:00:00+00', '2018-04-03 00:07:40.916124+00', 'Dance of the Cuckoos', 'DANCE OF THE CUCKOOS', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1490, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.533351+00', 'D-Dance', 'DDANCE', 3, 32, 9999, 1, 3, 42, 108, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10643, '2002-07-04 22:00:00+00', '2018-04-03 00:07:41.800276+00', 'Dennistoun Jig, The', 'DENNISTOUN JIG', 2, 32, 9999, 1, 3, 42, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3301, '1997-11-24 23:00:00+00', '2018-04-03 00:07:55.928702+00', 'Joan''s Medley', 'JOANS MEDLEY', 4, 32, 1, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3303, '1997-04-03 22:00:00+00', '2018-04-03 00:07:56.012196+00', 'Jock Caskie''s Reel', 'JOCK CASKIES REEL', 1, 32, 9999, 1, 3, 42, 85, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3305, '1997-04-03 22:00:00+00', '2018-04-03 00:07:56.020366+00', 'Jockey''s Dance, The', 'JOCKEYS DANCE', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3306, '1997-09-05 22:00:00+00', '2018-04-03 00:07:56.028816+00', 'Jockey''s Jig', 'JOCKEYS JIG', 2, 40, 9999, 1, 3, 42, 397, '1711-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3307, '1997-04-03 22:00:00+00', '2018-04-03 00:07:56.037115+00', 'Jockie''s Burn', 'JOCKIES BURN', 2, 32, 9999, 1, 3, 42, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3308, '1997-04-03 22:00:00+00', '2018-04-03 00:07:56.045511+00', 'Joe Foster''s Jig', 'JOE FOSTERS JIG', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10645, '2002-07-04 22:00:00+00', '2018-04-03 00:08:16.861212+00', 'Silver Wedding Jig, The', 'SILVER WEDDING JIG', 2, 32, 9999, 1, 3, 42, 854, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10639, '2002-07-01 22:00:00+00', '2018-04-03 00:08:27.110173+00', 'Young Black Cat, The', 'YOUNG BLACK CAT', 1, 32, 9999, 1, 3, 42, 2203, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3322, '1998-07-08 22:00:00+00', '2012-01-20 12:56:27.31217+00', 'John Macfadyen Of Melfort', 'JOHN MACFADYEN OF MELFORT', 3, 32, 9999, 1, 4, 11, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3815, '1997-12-03 23:00:00+00', '2012-01-20 12:56:30.967695+00', 'Lincoln', 'LINCOLN', 2, 24, 9999, 1, 2, NULL, 446, '1698-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1528, '1998-01-12 23:00:00+00', '2018-04-29 22:28:58.1222+00', 'Dancers Cleekit, The', 'DANCERS CLEEKIT', 2, 32, 9999, 5, 56, NULL, 210, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10648, '2002-07-04 22:00:00+00', '2012-01-20 12:57:23.039063+00', 'Scots'' Society''s 100th Celebration, The', 'SCOTS SOCIETYS 100TH CELEBRATION', 1, 88, 9999, 4, 4, NULL, 635, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1520, '1997-04-03 22:00:00+00', '2012-06-30 15:34:39.371296+00', 'Dance Maker, The', 'DANCE MAKER', 2, 32, 9999, 3, 5, 7, 411, '1991-01-01', 'For Barry Skelton', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1554, '1997-09-01 22:00:00+00', '2018-07-13 00:22:21.365203+00', 'Danelaw Reel', 'DANELAW REEL', 1, 40, 9999, 1, 4, 1, 21, NULL, 'For Robert Whitehead and the Danelaw Band.', 93, '8888/8888/8888/8888/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18882, '2018-10-08 18:14:36.426573+00', '2018-10-08 18:14:36.426573+00', 'Sixty-Six', 'SIXTYSIX', 1, 32, NULL, 1, 3, NULL, 2766, '2014-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1527, '2002-11-26 23:00:00+00', '2012-01-20 12:56:12.351195+00', 'Dancer''s Friend, The', 'DANCERS FRIEND', 3, 32, 9999, 2, 3, NULL, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1518, '2002-04-29 22:00:00+00', '2022-07-31 10:06:50.429994+00', 'Dance for Esther, A', 'DANCE FOR ESTHER', 3, 32, 9999, 2, 3, 17, 411, '1992-01-01', 'Starrting positions diagonally opposite partner. I.e. Men 3,2,1', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3313, '1997-09-05 22:00:00+00', '2022-07-31 11:27:23.927554+00', 'John & Christine''s Wedding', 'JOHN AND CHRISTINES WEDDING', 3, 32, 9999, 1, 4, 1, 1030, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3318, '1997-10-21 22:00:00+00', '2022-11-07 16:41:56.260676+00', 'John Donald of Coullie', 'JOHN DONALD OF COULLIE', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1488, '1998-01-05 23:00:00+00', '2023-02-17 11:42:04.943108+00', 'Cutty Sark', 'CUTTY SARK', 1, 32, 9999, 1, 3, 42, 129, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1568, '1997-04-03 22:00:00+00', '2019-03-17 23:20:48.479819+00', 'Davena''s Strathspey', 'DAVENAS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 3586, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1530, '1997-04-03 22:00:00+00', '2012-01-20 12:56:12.371513+00', 'Dancers, The', 'DANCERS', 1, 32, 9999, 1, 4, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1531, '1997-04-03 22:00:00+00', '2012-01-20 12:56:12.37827+00', 'Dancie, The', 'DANCIE', 2, 32, 9999, 1, 2, NULL, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1532, '1997-04-03 22:00:00+00', '2012-01-20 12:56:12.38502+00', 'Dancie, The', 'DANCIE', 1, 32, 9999, 3, 5, NULL, 197, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1539, '1999-08-14 22:00:00+00', '2019-03-17 23:34:37.09409+00', 'Dancing Gentleman, The', 'DANCING GENTLEMAN', 3, 32, 9999, 2, 3, 18, 814, NULL, '', 67, '080/888/484/484', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1538, '1997-04-03 22:00:00+00', '2012-01-20 12:56:12.425828+00', 'Dancing Feet', 'DANCING FEET', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1551, '1997-04-03 22:00:00+00', '2019-08-02 23:54:38.254755+00', 'Dandie Dinmont', 'DANDIE DINMONT', 3, 32, 9999, 1, 2, 76, 129, NULL, '', 56, '60/88/88/77', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1545, '1997-09-01 22:00:00+00', '2012-01-20 12:56:12.476737+00', 'Dancing on the Dole', 'DANCING ON THE DOLE', 1, 96, 9999, 4, 4, NULL, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3330, '1998-01-05 23:00:00+00', '2012-01-20 12:56:27.373514+00', 'John Paul Jones'' Apologies to Lady Selkirk', 'JOHN PAUL JONES APOLOGIES TO LADY SELKIRK', 1, 32, 9999, 1, 4, NULL, 963, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3335, '2002-03-02 23:00:00+00', '2012-01-20 12:56:27.408957+00', 'Johnnie MacLeod''s Reel', 'JOHNNIE MACLEODS REEL', 1, 32, 9999, 3, 5, NULL, 318, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1525, '1997-09-01 22:00:00+00', '2018-04-03 00:07:40.857675+00', 'Dance for the Dales', 'DANCE FOR THE DALES', 2, 32, 9999, 1, 3, 42, 347, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1529, '2003-01-29 23:00:00+00', '2018-04-03 00:07:40.991157+00', 'Dancers On The Wall', 'DANCERS ON THE WALL', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3321, '1997-04-03 22:00:00+00', '2020-11-06 10:51:33.801866+00', 'John Honey''s Hornpipe', 'JOHN HONEYS HORNPIPE', 1, 32, 9999, 1, 3, 42, 99, '1987-01-01', '', 63, '880/844/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10642, '2002-07-04 22:00:00+00', '2021-02-06 13:04:24.257108+00', 'Broomielaw Reel, The', 'BROOMIELAW REEL', 1, 32, 9999, 1, 3, 42, 1415, NULL, '', 47, '800/844/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1505, '1997-04-03 22:00:00+00', '2021-06-05 20:09:52.629855+00', 'Dalry', 'DALRY', 3, 32, 9999, 1, 3, 42, 101, NULL, 'Dedicated to Hugh Foss.', 53, '888/880/840/808', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1547, '1998-07-08 22:00:00+00', '2021-06-17 21:32:14.711996+00', 'Dancing Tailor, The', 'DANCING TAILOR', 2, 32, 9999, 1, 4, 2, 82, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1498, '1997-09-01 22:00:00+00', '2021-06-18 17:36:52.978496+00', 'Daisy''s Delight', 'DAISYS DELIGHT', 2, 32, 9999, 1, 3, 42, 810, NULL, '', 41, '800/888/800/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1496, '1998-04-08 22:00:00+00', '2021-06-18 17:39:51.408029+00', 'Dainty Davie', 'DAINTY DAVIE', 3, 16, 9999, 1, 3, 42, 397, '1718-01-01', '', 25, '440/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1511, '1998-07-08 22:00:00+00', '2021-06-21 22:54:00.982946+00', 'Dame Alison''s Reel', 'DAME ALISONS REEL', 1, 48, 9999, 1, 100, 11, 813, NULL, '"For Dame Alison Munro"', 67, '8008/8888/8448/4444/4444/8448', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10657, '2002-07-21 22:00:00+00', '2012-01-20 12:57:23.100806+00', 'Selworthy Days, The', 'SELWORTHY DAYS', 3, 32, 9999, 3, 5, NULL, 3165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3395, '1998-07-08 22:00:00+00', '2012-01-20 12:56:27.840039+00', 'Kaleidoscope', 'KALEIDOSCOPE', 1, 32, 9999, 1, 4, 2, 182, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1536, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.116195+00', 'Dancing Dolls, The', 'DANCING DOLLS', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1557, '1997-04-03 22:00:00+00', '2013-01-27 00:32:42.981154+00', 'Dark Island, The', 'DARK ISLAND', 100, 40, 9999, 1, 4, 1, 108, '1975-02-02', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1565, '1997-12-22 23:00:00+00', '2012-01-20 12:56:12.649687+00', 'Daurna-mention', 'DAURNAMENTION', 1, 48, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1540, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.141325+00', 'Dancing Goose, The', 'DANCING GOOSE', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1542, '1997-09-01 22:00:00+00', '2018-04-03 00:07:41.183025+00', 'Dancing in the Park', 'DANCING IN THE PARK', 1, 32, 9999, 1, 3, 42, 792, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10652, '2002-07-21 22:00:00+00', '2017-05-15 23:11:12.233039+00', 'It''s Better by Half', 'ITS BETTER BY HALF', 3, 32, 9999, 1, 4, 1, 3167, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10654, '2002-07-21 22:00:00+00', '2017-05-16 08:34:59.757695+00', 'Gentle Jig, A', 'GENTLE JIG', 2, 48, 9999, 1, 4, 1, 1439, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1548, '1998-04-21 22:00:00+00', '2018-04-03 00:07:41.258172+00', 'Dancing the Baby', 'DANCING THE BABY', 1, 40, 9999, 1, 3, 42, 44, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1550, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.324815+00', 'Dandaleith', 'DANDALEITH', 3, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3334, '1997-09-05 22:00:00+00', '2018-04-03 00:07:56.345738+00', 'John Worth''s Jig', 'JOHN WORTHS JIG', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10646, '2002-07-04 22:00:00+00', '2018-04-03 00:08:08.1525+00', 'Not You, Malcolm!', 'NOT YOU MALCOLM', 3, 32, 9999, 1, 3, 42, 2623, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18751, '2018-10-04 23:48:21.348385+00', '2018-10-04 23:48:21.348385+00', 'First 100 Years, The', 'FIRST 100 YEARS', 3, 32, NULL, 2, 3, NULL, 2766, '2015-08-01', 'This dance is written to celebrate George Whitehorne’s 100th birthday on September 2, 2015.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1575, '1997-09-01 22:00:00+00', '2012-01-20 12:56:12.719115+00', 'Davie Work', 'DAVIE WORK', 1, 92, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1576, '1997-04-03 22:00:00+00', '2012-01-20 12:56:12.726053+00', 'Davie''s Brae', 'DAVIES BRAE', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3341, '1997-09-05 22:00:00+00', '2012-01-20 12:56:27.452883+00', 'Johnny MacClure''s Jig', 'JOHNNY MACCLURES JIG', 2, 32, 9999, 1, 4, NULL, 857, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3344, '1997-09-05 22:00:00+00', '2012-01-20 12:56:27.47346+00', 'Johnston Jig', 'JOHNSTON JIG', 2, 32, 9999, 1, 4, NULL, 592, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1571, '1997-09-09 22:00:00+00', '2019-09-14 09:23:06.929454+00', 'David Ross', 'DAVID ROSS', 2, 32, 9999, 1, 3, 42, 270, NULL, 'John Mitchell has also devised a 32 bar Reel with the same name which he published in Whetherly Book 4', 44, '800/844/822/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3348, '1997-04-03 22:00:00+00', '2012-01-20 12:56:27.500974+00', 'Jolly Scotsmen', 'JOLLY SCOTSMEN', 1, 40, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3350, '1999-04-21 22:00:00+00', '2012-01-20 12:56:27.514581+00', 'Jonzann', 'JONZANN', 3, 32, 9999, 2, 3, NULL, 23, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1605, '1997-04-03 22:00:00+00', '2018-04-02 23:56:33.928415+00', 'Deep Sleep', 'DEEP SLEEP', 1, 32, 9999, 1, 3, 42, 352, '1993-06-15', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1570, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.433055+00', 'David Gray', 'DAVID GRAY', 3, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1572, '1997-09-01 22:00:00+00', '2018-04-03 00:07:41.466544+00', 'David''s Fancy', 'DAVIDS FANCY', 2, 32, 9999, 1, 3, 42, 819, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1574, '1997-08-21 22:00:00+00', '2018-04-03 00:07:41.491612+00', 'Davie Taylor', 'DAVIE TAYLOR', 3, 32, 9999, 1, 3, 42, 108, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1585, '1997-04-03 22:00:00+00', '2012-01-20 12:56:12.794664+00', 'De''il''s Awa'', The', 'DEILS AWA', 2, 40, 9999, 1, 4, NULL, 254, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1589, '1997-04-03 22:00:00+00', '2012-01-20 12:56:12.822719+00', 'Dean Castle', 'DEAN CASTLE', 3, 40, 9999, 1, 4, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1592, '1998-07-08 22:00:00+00', '2012-01-20 12:56:12.844242+00', 'Dean''s Delight, The', 'DEANS DELIGHT', 1, 32, 9999, 1, 4, 2, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1593, '1998-11-16 23:00:00+00', '2012-01-20 12:56:12.85141+00', 'Deanston House', 'DEANSTON HOUSE', 2, 40, 9999, 1, 4, NULL, 87, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1594, '1997-04-03 22:00:00+00', '2012-01-20 12:56:12.8582+00', 'Deanston Mill', 'DEANSTON MILL', 3, 32, 9999, 1, 4, NULL, 417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1580, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.508357+00', 'Dawn Express', 'DAWN EXPRESS', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1598, '1997-04-03 22:00:00+00', '2012-01-20 12:56:12.887839+00', 'Debbie''s Little Darlings', 'DEBBIES LITTLE DARLINGS', 2, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1601, '1997-09-01 22:00:00+00', '2012-01-20 12:56:12.90964+00', 'Declaration Of Arbroath', 'DECLARATION OF ARBROATH', 1, 32, 9999, 1, 98, NULL, 111, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1604, '2002-03-02 23:00:00+00', '2012-01-20 12:56:12.930673+00', 'Deep Dreams', 'DEEP DREAMS', 1, 32, 9999, 1, 4, NULL, 355, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1584, '1998-07-06 22:00:00+00', '2020-03-09 10:55:18.09364+00', 'De''el''s Awa'' Wi'' The Exciseman, The', 'DEELS AWA WI THE EXCISEMAN', 2, 48, 9999, 4, 4, 1, 270, NULL, '', 88, '8888/8888/8888/6622/7777', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1524, '1997-08-27 22:00:00+00', '2023-02-12 16:29:10.355994+00', 'Dance for Joy', 'DANCE FOR JOY', 2, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1563, '1997-04-03 22:00:00+00', '2020-04-29 11:36:11.417559+00', 'Daunder in Dovedale, A', 'DAUNDER IN DOVEDALE', 2, 32, 9999, 1, 4, NULL, 99, NULL, '', 94, '8888/8888/8888/0888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1591, '1997-09-12 22:00:00+00', '2020-05-28 11:42:51.323996+00', 'Dean Water', 'DEAN WATER', 3, 32, 9999, 1, 4, 1, 318, NULL, '', 91, '4884/8888/8888/4888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1581, '1997-09-01 22:00:00+00', '2020-06-10 16:09:26.593539+00', 'Dawning of the Day', 'DAWNING OF THE DAY', 1, 32, 9999, 5, 53, NULL, 270, NULL, '', 92, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10656, '2002-07-21 22:00:00+00', '2020-06-14 11:36:08.429081+00', 'Invigilator, The', 'INVIGILATOR', 1, 40, 9999, 3, 5, 7, 1439, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1560, '1997-10-08 22:00:00+00', '2021-05-30 10:39:57.818804+00', 'Darksome Burn, The', 'DARKSOME BURN', 3, 32, 9999, 1, 4, 1, 352, '1991-05-31', '', 81, '8000/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3324, '1997-04-03 22:00:00+00', '2020-10-21 09:35:19.453153+00', 'John McNeil''s Reel', 'JOHN MACNEILS REEL', 1, 48, 9999, 1, 3, 42, 270, NULL, '', 42, '800/800/888/088/800/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3332, '1997-04-03 22:00:00+00', '2020-10-26 22:09:08.291744+00', 'John Stephen', 'JOHN STEPHEN', 3, 32, 9999, 2, 3, 17, 270, NULL, '', 44, '800/888/840/084', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1599, '1997-04-03 22:00:00+00', '2020-12-25 21:36:08.188331+00', 'Debonnaire', 'DEBONNAIRE', 3, 32, 9999, 1, 4, 1, 13, NULL, '', 84, '8686/8888/8484/8484', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1573, '1997-08-22 22:00:00+00', '2021-04-02 22:12:43.380295+00', 'David''s Fancy', 'DAVIDS FANCY', 3, 40, 9999, 1, 4, 1, 335, NULL, '', 72, '4004/6886/8888/6666/8844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1579, '1997-11-18 23:00:00+00', '2021-06-16 09:18:41.748031+00', 'Davy''s Locker', 'DAVYS LOCKER', 1, 24, 9999, 1, 2, 76, 9998, '1797-01-01', '', 57, '88/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1567, '1997-04-03 22:00:00+00', '2021-06-16 09:28:02.99778+00', 'Davelyn Country Dance', 'DAVELYN COUNTRY DANCE', 3, 32, 9999, 1, 3, 4, 372, NULL, 'For Evelyn and David Renton with thanks for much hospitality and friendship.



The notes also say "The art of hospitality is brought out in this dance as each dancer changes partner during the dance finally finishing with their original partner."', 79, '888/686/686/525', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1564, '1998-07-08 22:00:00+00', '2021-06-17 09:15:07.611732+00', 'Daunder, The', 'DAUNDER', 3, 32, 9999, 1, 4, 2, 136, NULL, '', 81, '6666/6666/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1555, '2002-04-22 22:00:00+00', '2021-06-17 21:23:29.277079+00', 'Dangling After Her', 'DANGLING AFTER HER', 3, 32, 9999, 1, 3, 42, 817, NULL, 'The note to the dance says that "The asymmetry in bars 1-8 is deliberate; it is an attempt to break away from the symmetry which exists in most dances and formations."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3355, '1997-09-05 22:00:00+00', '2012-01-20 12:56:27.54861+00', 'Jovial Beggars, The', 'JOVIAL BEGGARS', 2, 28, 9999, 1, 2, NULL, 446, '1701-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3359, '1997-04-03 22:00:00+00', '2012-01-20 12:56:27.577921+00', 'Joy Be With You All', 'JOY BE WITH YOU ALL', 1, 64, 9999, 1, 4, NULL, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3361, '1997-09-05 22:00:00+00', '2012-01-20 12:56:27.591902+00', 'Joy''s Kitchen', 'JOYS KITCHEN', 1, 40, 9999, 1, 4, NULL, 1034, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3362, '1997-09-05 22:00:00+00', '2012-01-20 12:56:27.599118+00', 'Joyce''s Wedding', 'JOYCES WEDDING', 4, 64, 9999, 4, 4, NULL, 606, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3363, '1997-09-05 22:00:00+00', '2018-04-03 00:07:56.512462+00', 'Jubilation', 'JUBILATION', 1, 40, 9999, 1, 3, 42, 211, '1979-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1597, '2003-01-25 23:00:00+00', '2018-04-03 00:07:41.641781+00', 'Debbie''s Dream', 'DEBBIES DREAM', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10662, '2002-07-21 22:00:00+00', '2017-05-19 10:27:32.043116+00', 'Summer Solstice Strathspey', 'SUMMER SOLSTICE STRATHSPEY', 3, 40, 9999, 1, 4, 1, 3171, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10660, '2002-07-21 22:00:00+00', '2017-05-19 14:32:53.090793+00', 'Noughts and Crosses', 'NOUGHTS AND CROSSES', 1, 32, 9999, 1, 3, 18, 3171, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10658, '2002-07-21 22:00:00+00', '2017-05-20 00:29:13.274845+00', 'Fearsome Fivesome, The', 'FEARSOME FIVESOME', 2, 40, 9999, 3, 5, 7, 1439, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1602, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.666811+00', 'Dee in Spate, The', 'DEE IN SPATE', 1, 48, 9999, 1, 3, 42, 108, '1971-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1583, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.708619+00', 'De''il Gang Wi'' It, The', 'DEIL GANG WI IT', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3346, '1998-04-12 22:00:00+00', '2018-04-03 00:07:56.370703+00', 'Jolicure Jig, The', 'JOLICURE JIG', 2, 32, 9999, 1, 3, 42, 108, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3347, '1998-01-05 23:00:00+00', '2018-04-03 00:07:56.387357+00', 'Jolly Roger, The', 'JOLLY ROGER', 1, 32, 9999, 1, 3, 42, 1032, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3353, '1997-04-03 22:00:00+00', '2018-04-03 00:07:56.437381+00', 'Joukery-Pawkery', 'JOUKERYPAWKERY', 2, 32, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3356, '1997-09-05 22:00:00+00', '2018-04-03 00:07:56.479132+00', 'Joy After Sorrow', 'JOY AFTER SORROW', 5, 40, 9999, 1, 3, 42, 446, '1719-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3357, '1998-01-05 23:00:00+00', '2018-04-03 00:07:56.487459+00', 'Joy And Jollity', 'JOY AND JOLLITY', 1, 32, 9999, 1, 3, 42, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18883, '2018-10-08 18:20:07.775265+00', '2019-06-30 09:07:33.702618+00', 'Slinky', 'SLINKY', 3, 32, NULL, 1, 3, 42, 2766, '2007-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10665, '2002-07-21 22:00:00+00', '2012-01-20 12:57:23.155829+00', 'Catch Me if You Can', 'CATCH ME IF YOU CAN', 2, 48, 9999, 4, 4, NULL, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3375, '1997-04-03 22:00:00+00', '2018-07-21 14:43:29.621711+00', 'Jumping Geordie', 'JUMPING GEORDIE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 56, ' 800/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18818, '2018-10-06 08:16:41.897354+00', '2018-10-06 08:29:31.218209+00', 'Live Long and Prosper', 'LIVE LONG AND PROSPER', 3, 32, NULL, 2, 3, 18, 2766, '2016-10-01', 'Written for a Star Trek themed geek night November 30, 2016.', 61, '860/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18677, '2018-10-01 12:56:53.02964+00', '2018-10-01 13:37:46.501379+00', 'Another Rant Day', 'ANOTHER RANT DAY', 2, 32, NULL, 1, 3, 42, 2766, '2013-08-01', 'This dance was written after another very bad day at work.', 56, '668/866/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3378, '1998-11-25 23:00:00+00', '2019-03-15 19:48:31.063434+00', 'June''s Jig', 'JUNES JIG', 2, 48, 9999, 1, 4, 1, 842, NULL, '', 46, '5005/5005/0880/8888/8000/8220', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1638, '1998-01-05 23:00:00+00', '2019-03-17 23:14:18.986639+00', 'Devorgilla Reel', 'DEVORGILLA REEL', 1, 32, 9999, 1, 4, 1, 200, NULL, '', 81, '8008/8448/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1621, '1997-08-25 22:00:00+00', '2019-03-17 23:15:28.121976+00', 'Derwent Strathspey', 'DERWENT STRATHSPEY', 3, 32, 9999, 1, 4, 1, 518, '1983-01-01', '', 81, '8080/8888/8880/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19539, '2019-08-12 16:25:46.470236+00', '2019-08-12 16:25:46.470236+00', 'Craggan Hill', 'CRAGGAN HILL', 2, 32, NULL, 1, 3, NULL, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1627, '1998-01-05 23:00:00+00', '2012-01-20 12:56:13.11812+00', 'Devil''s Beef Tub, The', 'DEVILS BEEF TUB', 1, 32, 9999, 1, 4, NULL, 212, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1630, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.144532+00', 'De''il''s Cauldron, The', 'DEILS CAULDRON', 4, 80, 9999, 1, 4, NULL, 820, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1633, '1997-09-05 22:00:00+00', '2012-01-20 12:56:13.165431+00', 'Tornie', 'TORNIE', 3, 32, 9999, 2, 3, NULL, 108, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1636, '1997-11-25 23:00:00+00', '2012-01-20 12:56:13.186122+00', 'Devil''s Punchbowl, The', 'DEVILS PUNCHBOWL', 1, 128, 9999, 4, 4, NULL, 318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3370, '1997-04-03 22:00:00+00', '2012-01-20 12:56:27.663389+00', 'Julia Alton', 'JULIA ALTON', 3, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3374, '1998-07-08 22:00:00+00', '2012-01-20 12:56:27.695147+00', 'Julie''s Jig', 'JULIES JIG', 2, 32, 9999, 1, 4, 2, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3376, '1997-09-05 22:00:00+00', '2012-01-20 12:56:27.708779+00', 'June Of Glayva', 'JUNE OF GLAYVA', 3, 32, 9999, 2, 3, NULL, 385, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10674, '2002-07-21 22:00:00+00', '2012-01-20 12:57:23.219436+00', 'Jim and Catherine', 'JIM AND CATHERINE', 3, 32, 9999, 1, 2, NULL, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1614, '1997-04-03 22:00:00+00', '2022-12-08 19:33:11.96576+00', 'Delvin House', 'DELVIN HOUSE', 3, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1606, '1997-04-03 22:00:00+00', '2022-10-26 18:13:24.595774+00', 'Deeside Delight', 'DEESIDE DELIGHT', 2, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1608, '2001-05-30 22:00:00+00', '2023-02-12 16:06:11.15034+00', 'Deeside Silver', 'DEESIDE SILVER', 2, 32, 9999, 1, 3, 42, 1324, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1595, '1998-04-08 22:00:00+00', '2023-02-12 16:12:08.986952+00', 'Dear Gladys', 'DEAR GLADYS', 3, 32, 9999, 1, 3, 42, 62, '1990-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1640, '1997-08-25 22:00:00+00', '2012-01-20 12:56:13.213458+00', 'Dewar''s Fancy', 'DEWARS FANCY', 3, 32, 9999, 1, 4, NULL, 542, '1977-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1644, '2002-04-19 22:00:00+00', '2012-01-20 12:56:13.242186+00', 'Diamond Chain, A', 'DIAMOND CHAIN', 3, 32, 9999, 1, 4, 2, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1645, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.249023+00', 'Diamond Dance, The', 'DIAMOND DANCE', 1, 32, 9999, 3, 5, NULL, 825, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10667, '2002-07-21 22:00:00+00', '2018-04-03 00:07:40.273869+00', 'Crown and Thistle', 'CROWN AND THISTLE', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1648, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.287645+00', 'Diamond Sixsome, The', 'DIAMOND SIXSOME', 3, 32, 9999, 5, 3, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1650, '2000-01-10 23:00:00+00', '2012-01-20 12:56:13.30529+00', 'Diamonds, The', 'DIAMONDS', 1, 32, 9999, 1, 4, NULL, 244, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1651, '1997-04-03 22:00:00+00', '2012-01-20 12:56:13.313987+00', 'Diana M. McIntosh', 'DIANA M MACINTOSH', 3, 32, 9999, 1, 4, NULL, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1610, '1997-09-01 22:00:00+00', '2018-04-03 00:07:41.716883+00', 'Deirdre Strathspey', 'DEIRDRE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 822, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1628, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.933764+00', 'Devil''s Bowling Green, The', 'DEVILS BOWLING GREEN', 1, 32, 9999, 1, 3, 42, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3371, '1997-09-05 22:00:00+00', '2020-10-21 09:30:53.670416+00', 'Julia McMahon', 'JULIA MACMAHON', 2, 32, 9999, 2, 3, 42, 270, NULL, '', 83, '822/884/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3377, '1998-11-02 23:00:00+00', '2021-05-22 19:21:22.887594+00', 'June Shore''s Fancy', 'JUNE SHORES FANCY', 1, 32, 9999, 1, 4, 2, 118, '1985-01-01', 'Devised during June Shore''s session, the "Teachers'' Class" at the 19th Annual Workshop of the Kingston Ontario Branch, November 1985.', 88, '8880/8884/8888/6688', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3345, '1997-04-03 22:00:00+00', '2021-05-23 08:28:05.119225+00', 'Johnstone Jig, The', 'JOHNSTONE JIG', 2, 32, 9999, 1, 3, 42, 200, NULL, '', 53, '800/844/888/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10659, '2002-07-21 22:00:00+00', '2021-11-01 07:08:11.964844+00', 'Lindsay''s Strathspey', 'LINDSAYS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 3170, NULL, 'In memory of Lindsay W. Smith (1943-1994), twin brother of Alan J. Smith, both dancers and younger brothers of Andrew Smith, devisor.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1629, '1997-04-03 22:00:00+00', '2016-07-15 05:07:09.709996+00', 'Devil''s Cauldron, The', 'DEVILS CAULDRON', 1, 32, 9999, 1, 4, 1, 352, '1993-11-22', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3369, '1997-04-03 22:00:00+00', '2018-04-03 00:07:56.61249+00', 'Jukebox, The', 'JUKEBOX', 2, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1612, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.733566+00', 'Delaware Highland Gathering', 'DELAWARE HIGHLAND GATHERING', 1, 32, 9999, 1, 3, 42, 171, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1617, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.783584+00', 'Dene House', 'DENE HOUSE', 3, 32, 9999, 1, 3, 42, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1619, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.864971+00', 'Dent''s Reel', 'DENTS REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1620, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.883704+00', 'Derry Boat', 'DERRY BOAT', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1623, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.908764+00', 'Deserts Of Tulloch', 'DESERTS OF TULLOCH', 2, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1631, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.942105+00', 'Devil''s Delight', 'DEVILS DELIGHT', 2, 40, 9999, 1, 3, 42, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1632, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.950519+00', 'Devil''s Dyke, The', 'DEVILS DYKE', 1, 32, 9999, 1, 3, 42, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10670, '2002-07-21 22:00:00+00', '2018-04-03 00:07:42.209044+00', 'Dinna Fash', 'DINNA FASH', 2, 40, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1642, '1997-09-01 22:00:00+00', '2018-04-03 00:07:42.250814+00', 'Di''s Dance', 'DIS DANCE', 2, 40, 9999, 1, 3, 42, 211, '1979-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10671, '2002-07-21 22:00:00+00', '2018-04-03 00:07:46.679754+00', 'Foxhunter''s Fiddle', 'FOXHUNTERS FIDDLE', 1, 40, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10673, '2002-07-21 22:00:00+00', '2018-04-03 00:07:53.73559+00', 'Invitation', 'INVITATION', 3, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3372, '1997-04-03 22:00:00+00', '2018-04-03 00:07:56.645957+00', 'Julia''s Jig', 'JULIAS JIG', 2, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3379, '1997-09-05 22:00:00+00', '2018-04-03 00:07:56.760901+00', 'Junior Jig', 'JUNIOR JIG', 2, 40, 9999, 1, 3, 42, 1037, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10676, '2002-07-21 22:00:00+00', '2018-04-03 00:08:00.714409+00', 'Lories'' Delight', 'LORIES DELIGHT', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10677, '2002-07-21 22:00:00+00', '2018-04-03 00:08:02.166976+00', 'Marilyn''s Reel', 'MARILYNS REEL', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1658, '1997-09-13 22:00:00+00', '2012-01-20 12:56:13.37683+00', 'Dingadoo', 'DINGADOO', 1, 32, 9999, 1, 4, NULL, 62, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1666, '1998-01-05 23:00:00+00', '2018-04-29 10:51:13.088932+00', 'Divide And Conquer', 'DIVIDE AND CONQUER', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1659, '1997-08-27 22:00:00+00', '2018-04-03 00:07:42.200696+00', 'Dingwall and Skye', 'DINGWALL AND SKYE', 1, 32, 9999, 1, 3, 42, 582, '1972-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18884, '2018-10-08 18:21:57.001589+00', '2018-10-08 18:21:57.001589+00', 'Slopoke', 'SLOPOKE', 1, 32, NULL, 2, 3, NULL, 2766, '2010-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18885, '2018-10-08 18:23:25.082039+00', '2018-10-08 18:23:25.082039+00', 'Smoke Along the Track', 'SMOKE ALONG THE TRACK', 2, 32, NULL, 1, 3, 42, 2766, '2010-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3389, '1997-08-20 22:00:00+00', '2019-03-15 19:41:42.780074+00', 'Just over the Border', 'JUST OVER THE BORDER', 3, 40, 9999, 1, 4, 1, 108, '1964-01-01', '', 85, '8668/8448/6868/8484/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1665, '1997-12-26 23:00:00+00', '2012-01-20 12:56:13.438297+00', 'Distiller''s Dream, The', 'DISTILLERS DREAM', 4, 64, 5, 3, 5, NULL, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1679, '2002-03-02 23:00:00+00', '2019-03-17 23:08:46.977664+00', 'Donald McLeod', 'DONALD MACLEOD', 3, 32, 9999, 1, 4, 1, 238, '1978-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1654, '1997-08-22 22:00:00+00', '2019-06-17 10:55:04.827846+00', 'Dick''s Dram', 'DICKS DRAM', 3, 32, 9999, 1, 4, 2, 335, NULL, '', 75, '8668/8228/8888/8008', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3386, '1997-09-05 22:00:00+00', '2012-01-20 12:56:27.777806+00', 'Just For Betty', 'JUST FOR BETTY', 2, 40, 9999, 1, 4, NULL, 377, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1660, '1997-04-03 22:00:00+00', '2018-04-03 00:07:42.217351+00', 'Dinna Fash', 'DINNA FASH', 3, 32, 9999, 1, 3, 42, 239, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1649, '1998-03-18 23:00:00+00', '2013-01-24 11:36:45.059599+00', 'Diamond Strathspey, The', 'DIAMOND STRATHSPEY', 3, 96, 9999, 4, 4, NULL, 108, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1669, '1998-09-20 22:00:00+00', '2012-01-20 12:56:13.474264+00', 'Dogwood Reel', 'DOGWOOD REEL', 1, 32, 9999, 4, 55, NULL, 382, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1671, '1997-11-25 23:00:00+00', '2012-01-20 12:56:13.492355+00', 'Don And The Dee, The', 'DON AND THE DEE', 4, 64, 9999, 4, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1662, '1997-04-03 22:00:00+00', '2018-04-03 00:07:42.225744+00', 'Dipper By The Dove', 'DIPPER BY THE DOVE', 2, 32, 9999, 1, 3, 42, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1673, '1997-04-03 22:00:00+00', '2012-01-20 12:56:13.510857+00', 'Don''s Favourite', 'DONS FAVOURITE', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1682, '1998-01-05 23:00:00+00', '2012-01-20 12:56:13.587797+00', 'Donnachadh Coir', 'DONNACHADH COIR', 1, 40, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1683, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.594662+00', 'Donsbank House', 'DONSBANK HOUSE', 2, 48, 9999, 2, 3, NULL, 417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1684, '1997-04-03 22:00:00+00', '2012-01-20 12:56:13.601433+00', 'Donvale Reel, The', 'DONVALE REEL', 1, 40, 9999, 1, 4, NULL, 156, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1685, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.608234+00', 'Doodler''s, The', 'DOODLERS', 1, 40, 9999, 5, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1657, '1998-07-08 22:00:00+00', '2022-08-20 17:49:58.010753+00', 'Dignity Of The Kilt, The', 'DIGNITY OF THE KILT', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1626, '1997-04-03 22:00:00+00', '2022-11-07 19:06:13.140345+00', 'Devil In Dublin, The', 'DEVIL IN DUBLIN', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1622, '1997-04-03 22:00:00+00', '2022-12-06 11:17:28.815629+00', 'Desborough''s Dance', 'DESBOROUGHS DANCE', 2, 48, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3393, '2002-03-11 23:00:00+00', '2023-01-10 11:58:14.415712+00', 'Kale Pot, The', 'KALE POT', 3, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1686, '1998-04-08 22:00:00+00', '2012-01-20 12:56:13.615204+00', 'Doon Hame', 'DOON HAME', 1, 112, 9999, 1, 4, NULL, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1687, '1997-04-03 22:00:00+00', '2012-01-20 12:56:13.622102+00', 'Doon The Burn', 'DOON THE BURN', 3, 32, 9999, 1, 4, NULL, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1690, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.642453+00', 'Doon The Watter', 'DOON THE WATTER', 1, 32, 9999, 2, 3, NULL, 179, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1691, '1997-11-24 23:00:00+00', '2012-01-20 12:56:13.649233+00', 'Door In The Wall, The', 'DOOR IN THE WALL', 4, 128, 2, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1692, '1997-04-03 22:00:00+00', '2012-01-20 12:56:13.656016+00', 'Doreen''s Dance', 'DOREENS DANCE', 2, 40, 9999, 1, 98, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1693, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.662797+00', 'Doreen''s Fancy', 'DOREENS FANCY', 3, 80, 9999, 1, 4, NULL, 829, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3367, '1998-11-17 23:00:00+00', '2021-05-22 19:25:43.919417+00', 'Jubilee Reel, The', 'JUBILEE REEL', 1, 32, 9999, 1, 3, 42, 185, NULL, '', 56, '800/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1688, '1997-04-03 22:00:00+00', '2020-10-21 09:49:48.252431+00', 'Doon the Burn', 'DOON THE BURN', 3, 40, 9999, 1, 2, 76, 270, NULL, '', 77, '84/88/88/88/84', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3382, '1997-04-03 22:00:00+00', '2021-02-17 12:41:45.780891+00', 'Just a Morsel', 'JUST A MORSEL', 2, 16, 9999, 4, 4, 1, 352, '1992-10-29', '', 75, '8888/8404', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3366, '1997-04-03 22:00:00+00', '2021-04-18 09:55:30.275045+00', 'Jubilee Line, The', 'JUBILEE LINE', 1, 48, 9999, 1, 3, 42, 108, '1979-01-01', '', 48, '888/822/822/844/822/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1653, '2002-03-04 23:00:00+00', '2021-06-15 11:35:10.102234+00', 'Diane''s Fancy', 'DIANES FANCY', 2, 48, 9999, 1, 4, 1, 552, '1995-01-01', 'For the deviser''s husband Malcolm.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1694, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.669599+00', 'Doreen''s Jig', 'DOREENS JIG', 2, 40, 9999, 1, 4, NULL, 830, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3385, '1997-04-03 22:00:00+00', '2018-04-03 00:07:56.820945+00', 'Just Follow Me', 'JUST FOLLOW ME', 1, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1663, '1997-04-03 22:00:00+00', '2018-04-03 00:07:42.2341+00', 'Dipper In The Dales, The', 'DIPPER IN THE DALES', 2, 32, 9999, 1, 3, 42, 53, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1667, '1998-01-05 23:00:00+00', '2018-04-03 00:07:42.292549+00', 'Do a Happy Hop', 'DO A HAPPY HOP', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1670, '1997-11-24 23:00:00+00', '2018-04-03 00:07:42.392659+00', 'Dolphin Medley', 'DOLPHIN MEDLEY', 4, 32, 12, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1680, '1997-09-01 22:00:00+00', '2018-04-03 00:07:42.442513+00', 'Donald Stewart', 'DONALD STEWART', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1674, '1997-09-01 22:00:00+00', '2018-04-03 00:07:42.500914+00', 'Don''t Fall Over', 'DONT FALL OVER', 1, 32, 9999, 1, 3, 42, 828, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1675, '2002-03-02 23:00:00+00', '2018-04-03 00:07:42.517595+00', 'Don''t Stop Now', 'DONT STOP NOW', 1, 40, 9999, 1, 3, 42, 355, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3392, '1997-04-03 22:00:00+00', '2018-04-03 00:07:56.871029+00', 'Kail-Bell, The', 'KAILBELL', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3394, '2003-01-25 23:00:00+00', '2018-04-03 00:07:56.879326+00', 'Kaleidoscope', 'KALEIDOSCOPE', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10680, '2002-07-21 22:00:00+00', '2018-04-03 00:08:10.565149+00', 'Physician, Reel Thyself', 'PHYSICIAN REEL THYSELF', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10679, '2002-07-21 22:00:00+00', '2018-04-03 00:08:10.90707+00', 'P.J.''s Strathspey', 'PJS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10683, '2002-07-21 22:00:00+00', '2018-04-03 00:08:17.962048+00', 'Spey and Thistle', 'SPEY AND THISTLE', 3, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10685, '2002-07-21 22:00:00+00', '2018-04-03 00:08:20.672238+00', 'Thistle Burn', 'THISTLE BURN', 3, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3399, '1998-07-09 22:00:00+00', '2012-01-20 12:56:27.868071+00', 'Kate Bairdet', 'KATE BAIRDET', 3, 48, 9999, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1726, '1998-01-05 23:00:00+00', '2018-04-29 10:55:40.307877+00', 'Down By The Sea', 'DOWN BY THE SEA', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3413, '1997-09-05 22:00:00+00', '2018-09-15 14:35:18.004293+00', 'Keeping Busy', 'KEEPING BUSY', 2, 32, 9999, 1, 3, 42, 259, NULL, 'This is a phrasing exercise!', 56, '844/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3404, '1997-09-05 22:00:00+00', '2012-01-20 12:56:27.914292+00', 'Kathleen''s Fancy', 'KATHLEENS FANCY', 1, 32, 9999, 1, 4, NULL, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3408, '1997-08-26 22:00:00+00', '2018-07-27 08:55:13.114382+00', 'Katie''s Jig', 'KATIES JIG', 2, 32, 9999, 1, 3, 42, 518, '1995-01-01', 'Dance devised by Stewart Adam to celebrate the 21st Birthday of Katie Fallas', 69, '880/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1709, '1998-01-05 23:00:00+00', '2018-09-24 21:26:59.709744+00', 'Double Triumph', 'DOUBLE TRIUMPH', 1, 32, 9999, 1, 3, 42, 108, '1983-01-01', '', 63, '800/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10687, '2002-07-21 22:00:00+00', '2012-01-20 12:57:23.307587+00', 'Tweedly''s Farewell', 'TWEEDLYS FAREWELL', 2, 32, 9999, 1, 2, NULL, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10692, '2002-07-21 22:00:00+00', '2018-10-07 13:09:22.364356+00', 'Cat''s Whiskers', 'CATS WHISKERS', 3, 32, 9999, 1, 3, 42, 2961, '1997-01-01', 'Bars 9-16:  The deviser specifies figures of eight on the sides, but suggests that more experienced dancers can dance mirror reels of three instead.', 41, '800/800/822/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3420, '1997-10-21 22:00:00+00', '2019-01-11 22:45:34.538885+00', 'Kelly''s Reel', 'KELLYS REEL', 2, 32, 9999, 5, 3, NULL, 270, NULL, '', 81, '886/888/844/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1716, '1998-11-03 23:00:00+00', '2019-03-17 23:00:54.839176+00', 'Douglas Water', 'DOUGLAS WATER', 3, 40, 9999, 1, 4, 1, 394, '1976-01-01', '', 80, '8880/8088/8080/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1700, '1997-04-03 22:00:00+00', '2012-01-20 12:56:13.715617+00', 'Dorothy''s Travels', 'DOROTHYS TRAVELS', 1, 32, 9999, 1, 4, NULL, 67, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1702, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.729181+00', 'Dorothy, The Belle Of St. Vinnies', 'DOROTHY THE BELLE OF ST VINNIES', 1, 32, 9999, 1, 4, NULL, 834, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1703, '2002-04-05 22:00:00+00', '2012-01-20 12:56:13.735997+00', 'Dorraton Bridge', 'DORRATON BRIDGE', 3, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1706, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.757262+00', 'Double Scotch', 'DOUBLE SCOTCH', 2, 32, 9999, 1, 2, NULL, 837, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1710, '1997-04-03 22:00:00+00', '2012-01-20 12:56:13.785261+00', 'Dougal Craiter, The', 'DOUGAL CRAITER', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1714, '1997-04-03 22:00:00+00', '2012-01-20 12:56:13.812398+00', 'Douglas Burn, The', 'DOUGLAS BURN', 3, 32, 9999, 3, 5, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1717, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.832882+00', 'Douglasdale', 'DOUGLASDALE', 2, 32, 9999, 1, 4, NULL, 732, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1718, '1997-04-03 22:00:00+00', '2012-01-20 12:56:13.839659+00', 'Doulton Figurine, The', 'DOULTON FIGURINE', 3, 32, 9999, 3, 5, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1721, '1998-07-08 22:00:00+00', '2012-01-20 12:56:13.861361+00', 'Dove Cot, The', 'DOVE COT', 3, 32, 9999, 1, 4, 2, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1723, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.874994+00', 'Dovedale', 'DOVEDALE', 1, 32, 9999, 1, 98, NULL, 840, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1724, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.881773+00', 'Dover Pier', 'DOVER PIER', 1, 32, 9999, 1, 2, NULL, 459, '1791-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1727, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.904386+00', 'Down Came The Troopers', 'DOWN CAME THE TROOPERS', 2, 32, 9999, 1, 2, NULL, 841, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3410, '1997-04-03 22:00:00+00', '2012-01-20 12:56:27.96632+00', 'Kauri Gum', 'KAURI GUM', 3, 24, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10682, '2002-07-21 22:00:00+00', '2022-09-12 21:59:18.534324+00', 'Slopes of Hlidarendi, The', 'SLOPES OF HLIDARENDI', 3, 32, 9999, 2, 3, 18, 2961, '2002-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1689, '1997-09-01 22:00:00+00', '2022-11-07 16:40:58.527253+00', 'Doon the Burn Davie Lad', 'DOON THE BURN DAVIE LAD', 3, 96, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3407, '1997-09-05 22:00:00+00', '2023-01-10 11:52:46.560876+00', 'Katie Bairdie', 'KATIE BAIRDIE', 3, 32, 9999, 2, 3, 17, 1040, '1991-08-01', 'From the notes: The dance was named after a ScottIsh nursery rhyme that Doreen''s father sang to her as a child. Katie Bairdie is the third tune in "The Dark Mile."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1678, '1997-09-01 22:00:00+00', '2023-02-10 14:54:40.461223+00', 'Donald Iain Rankine', 'DONALD IAIN RANKINE', 2, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3414, '1997-09-05 22:00:00+00', '2012-01-20 12:56:28.001552+00', 'Keeping Up With Kayleigh', 'KEEPING UP WITH KAYLEIGH', 1, 32, 9999, 1, 4, NULL, 1041, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3417, '1997-04-05 22:00:00+00', '2012-01-20 12:56:28.027717+00', 'Kelley''s Aye', 'KELLEYS AYE', 1, 32, 9999, 6, 53, NULL, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3421, '1998-01-04 23:00:00+00', '2012-01-20 12:56:28.060972+00', 'Kelmscott Cottage', 'KELMSCOTT COTTAGE', 2, 32, 9999, 1, 2, NULL, 425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1719, '1998-07-08 22:00:00+00', '2019-11-18 11:53:53.056943+00', 'Doune Ferryman, The', 'DOUNE FERRYMAN', 2, 40, 9999, 1, 100, 11, 313, NULL, '', 85, '8888/8448/8448/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3400, '1997-04-03 22:00:00+00', '2020-03-09 10:57:38.251434+00', 'Kate Kennedy', 'KATE KENNEDY', 3, 32, 9999, 1, 3, 42, 270, NULL, '', 53, '787/787/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1695, '1997-04-03 22:00:00+00', '2020-06-19 13:01:59.570962+00', 'Dornachd Head', 'DORNACHD HEAD', 2, 32, 9999, 3, 5, NULL, 270, NULL, '', 63, '80000/88880/28482/66888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1676, '1997-09-01 22:00:00+00', '2020-08-30 09:10:10.021995+00', 'Donaghadee', 'DONAGHADEE', 2, 32, 9999, 1, 3, 42, 270, NULL, '', 41, '800/833/833/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1664, '1998-01-05 23:00:00+00', '2021-01-06 11:02:46.939343+00', 'Dirleton Gate', 'DIRLETON GATE', 1, 40, 9999, 1, 3, 42, 342, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1698, '1998-01-04 23:00:00+00', '2021-04-08 10:36:04.739701+00', 'Dornoch Links', 'DORNOCH LINKS', 1, 64, 9999, 1, 4, 1, 833, NULL, '', 77, '6666/6666/8888/8008/0880/8888/8840/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3416, '1998-01-05 23:00:00+00', '2021-05-20 10:51:55.28823+00', 'Kelburn''s Reel', 'KELBURNS REEL', 1, 32, 9999, 5, 2, 76, 438, NULL, '', 94, '88/88/66/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1707, '1998-07-08 22:00:00+00', '2021-06-15 11:28:40.52921+00', 'Double Scotch', 'DOUBLE SCOTCH', 2, 40, 9999, 1, 4, 11, 836, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3405, '1997-09-05 22:00:00+00', '2016-02-15 08:00:20.737364+00', 'Kathryn Jenny''s Jig', 'KATHRYN JENNYS JIG', 2, 32, 9999, 1, 3, 42, 411, '1991-01-01', 'For my daughter Kat', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1699, '1997-08-26 22:00:00+00', '2018-04-03 00:07:42.709458+00', 'Dorothy''s Delight', 'DOROTHYS DELIGHT', 2, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1705, '2002-04-28 22:00:00+00', '2018-04-03 00:07:42.759443+00', 'Double J, The', 'DOUBLE J', 3, 40, 9999, 1, 3, 42, 835, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1715, '1998-04-08 22:00:00+00', '2018-04-03 00:07:42.817818+00', 'Douglas Henderson Of Dundee', 'DOUGLAS HENDERSON OF DUNDEE', 2, 32, 9999, 1, 3, 42, 839, '1987-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3401, '1997-04-03 22:00:00+00', '2018-04-03 00:07:56.912895+00', 'Kate Kennedy''s Reel', 'KATE KENNEDYS REEL', 1, 40, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3419, '1997-04-03 22:00:00+00', '2018-04-03 00:07:57.096402+00', 'Kelly from The Isle Of Man', 'KELLY FROM THE ISLE OF MAN', 1, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10686, '2002-07-21 22:00:00+00', '2018-04-03 00:08:21.014219+00', 'Thumbs Up', 'THUMBS UP', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10688, '2002-07-21 22:00:00+00', '2018-04-03 00:08:25.751058+00', 'Wilder''s Walkabout', 'WILDERS WALKABOUT', 3, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1752, '1997-04-03 22:00:00+00', '2018-04-29 21:31:09.79188+00', 'Drifting Snow', 'DRIFTING SNOW', 2, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13680, '2011-05-29 22:00:00+00', '2018-02-28 17:03:50.151837+00', 'Live Long and Prosper', 'LIVE LONG AND PROSPER', 3, 32, NULL, 1, 100, 2, 228, NULL, 'For Matthias Lang, long-standing member of the FSCDC and among all his other accomplishments a moderate Trekkie, who didn''t receive a proper dance from me when he should have. The Helix (in strathspey time) is taken from Hana Strathspey by Alex Gray.



Note: At the start of this dance, a Vulcan salute may be substituted for the customary bow and curtsey.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18821, '2018-10-06 08:43:38.229159+00', '2018-10-06 08:43:38.229159+00', 'Love-in-a-Mist', 'LOVEINAMIST', 3, 32, NULL, 1, 3, 42, 2766, '2007-07-01', 'Love-in-a-Mist is a lovely flower in the buttercup family; I like the name.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10702, '2002-07-21 22:00:00+00', '2019-03-02 22:52:34.333616+00', 'Oxtail Soup', 'OXTAIL SOUP', 1, 32, 9999, 1, 4, 1, 2961, NULL, '', 91, '8888/8888/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1735, '1997-11-27 23:00:00+00', '2012-01-20 12:56:13.959971+00', 'Downpatrick Medley', 'DOWNPATRICK MEDLEY', 4, 128, 2, 4, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1736, '1997-04-03 22:00:00+00', '2012-01-20 12:56:13.966762+00', 'Downside Strathspey', 'DOWNSIDE STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1737, '2003-01-28 23:00:00+00', '2012-01-20 12:56:13.974225+00', 'Dr Bob Smith''s Strathspey', 'DR BOB SMITHS STRATHSPEY', 3, 40, 9999, 1, 4, 2, 35, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1731, '1997-09-01 22:00:00+00', '2019-03-17 22:43:24.376334+00', 'Down Under', 'DOWN UNDER', 2, 32, 9999, 2, 3, 17, 791, NULL, '', 83, '888/484/888/268', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1740, '1997-09-01 22:00:00+00', '2012-01-20 12:56:13.994724+00', 'Dr John Ramsay', 'DR JOHN RAMSAY', 2, 40, 9999, 5, 1, NULL, 759, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1728, '1998-01-05 23:00:00+00', '2018-04-03 00:07:42.867908+00', 'Down From The Shielings', 'DOWN FROM THE SHIELINGS', 1, 32, 9999, 1, 3, 42, 595, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1746, '1997-09-01 22:00:00+00', '2012-01-20 12:56:14.035804+00', 'Dram for Andrew, A', 'DRAM FOR ANDREW', 1, 40, 9999, 4, 98, NULL, 333, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1748, '1997-09-01 22:00:00+00', '2012-01-20 12:56:14.051658+00', 'Draper''s Gardens', 'DRAPERS GARDENS', 5, 32, 9999, 1, 2, NULL, 459, '1799-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1750, '1997-12-03 23:00:00+00', '2012-01-20 12:56:14.065501+00', 'Fleece, The', 'FLEECE', 2, 48, 9999, 6, 3, NULL, 906, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1742, '1997-06-22 22:00:00+00', '2019-08-29 10:29:01.44506+00', 'Dr McHardy', 'DR MACHARDY', 3, 32, 9999, 1, 4, 2, 270, NULL, '', 88, '8008/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1754, '1997-09-01 22:00:00+00', '2012-01-20 12:56:14.095205+00', 'Drochil Castle', 'DROCHIL CASTLE', 3, 64, 9999, 4, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1755, '1997-09-01 22:00:00+00', '2012-01-20 12:56:14.102218+00', 'Drum House, The', 'DRUM HOUSE', 3, 32, 9999, 2, 3, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3423, '1998-07-08 22:00:00+00', '2012-01-20 12:56:28.080129+00', 'Kelpie''s Haugh', 'KELPIES HAUGH', 3, 32, 9999, 1, 4, 11, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3426, '1997-04-03 22:00:00+00', '2012-06-30 16:00:08.26725+00', 'Kelston Caper', 'KELSTON CAPER', 1, 32, 9999, 1, 3, 42, 411, '1992-01-01', 'For my fellow dancers at Waitemata SCD Club', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3425, '1997-09-05 22:00:00+00', '2012-01-20 12:56:28.098178+00', 'Kelsterne Gardens', 'KELSTERNE GARDENS', 1, 28, 9999, 1, 2, NULL, 446, '1728-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3429, '1997-04-03 22:00:00+00', '2012-01-20 12:56:28.12617+00', 'Kemnay House', 'KEMNAY HOUSE', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1734, '1997-09-01 22:00:00+00', '2018-04-03 00:07:42.893072+00', 'Downland Reel', 'DOWNLAND REEL', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1759, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.13211+00', 'Drumleys', 'DRUMLEYS', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1761, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.145732+00', 'Drummer O'' Catrine, The', 'DRUMMER O CATRINE', 1, 32, 9999, 1, 2, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1769, '1997-08-31 22:00:00+00', '2012-01-20 12:56:14.200987+00', 'Drunken Highlander, The', 'DRUNKEN HIGHLANDER', 1, 32, 9999, 1, 4, NULL, 145, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1771, '1997-09-02 22:00:00+00', '2012-01-20 12:56:14.214643+00', 'Fleet of Foot', 'FLEET OF FOOT', 1, 48, 9999, 1, 4, NULL, 329, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1730, '1997-04-03 22:00:00+00', '2018-04-03 00:07:42.917895+00', 'Down The Vale', 'DOWN THE VALE', 1, 32, 9999, 1, 3, 42, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1779, '1998-01-04 23:00:00+00', '2012-01-20 12:56:14.269657+00', 'Braist Ceilteach, An', 'BRAIST CEILTEACH', 3, 32, 9999, 4, 4, NULL, 123, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3445, '1997-11-23 23:00:00+00', '2018-04-03 00:07:57.204701+00', 'Kers'' Ruby', 'KERS RUBY', 2, 40, 9999, 1, 3, 42, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1751, '1997-04-03 22:00:00+00', '2020-08-04 00:47:41.610414+00', 'Draw the Sword, Scotland', 'DRAW THE SWORD SCOTLAND', 1, 32, 9999, 1, 3, 42, 129, NULL, '', 53, '800/822/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1765, '1997-09-01 22:00:00+00', '2020-09-11 11:06:08.064745+00', 'Drumnadrochit', 'DRUMNADROCHIT', 1, 40, 9999, 1, 4, 1, 844, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1767, '1997-09-01 22:00:00+00', '2020-12-01 10:15:47.811371+00', 'Drumrunie', 'DRUMRUNIE', 3, 32, 9999, 2, 3, 17, 13, NULL, '', 92, '888/826/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10691, '2002-07-21 22:00:00+00', '2020-12-18 13:23:31.935132+00', 'Braw Annie o'' Eire', 'BRAW ANNIE O EIRE', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', 50, '800/844/866/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3415, '2003-01-28 23:00:00+00', '2023-01-10 11:48:27.910968+00', 'Keith''s Rant', 'KEITHS RANT', 1, 32, 9999, 1, 3, 42, 35, '1978-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10696, '2002-07-21 22:00:00+00', '2020-12-23 11:35:24.899438+00', 'Isle of Bute', 'ISLE OF BUTE', 2, 32, 9999, 1, 3, 42, 2961, NULL, 'The Isle of Bute is on the southwestern coast of Scotland, where the Scottish side of my family comes from.', 56, '880/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3409, '1998-11-02 23:00:00+00', '2021-05-20 17:13:26.60548+00', 'Katie''s Strathspey', 'KATIES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1024, '1988-10-01', '', 59, '888/880/888/822', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1733, '1998-09-29 22:00:00+00', '2021-06-15 08:23:56.533224+00', 'Downie''s Humour', 'DOWNIES HUMOUR', 1, 40, 9999, 1, 3, 42, 9998, NULL, '', 40, '880/440/800/808/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1722, '1997-09-01 22:00:00+00', '2021-06-15 11:17:03.816526+00', 'Dovecot Park', 'DOVECOT PARK', 2, 40, 9999, 1, 3, 42, 617, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1712, '1997-08-27 22:00:00+00', '2021-06-15 11:19:14.924325+00', 'Dougal Of Shandon', 'DOUGAL OF SHANDON', 2, 32, 9999, 1, 3, 42, 574, NULL, '', 63, '888/808/880/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1747, '1998-04-08 22:00:00+00', '2021-07-11 10:13:57.792319+00', 'Drambuie', 'DRAMBUIE', 2, 160, 9999, 4, 4, 3, 392, '1961-01-01', '', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3432, '1997-09-06 22:00:00+00', '2015-07-20 07:26:01.955453+00', 'Ken Shaw''s Farewell', 'KEN SHAWS FAREWELL', 2, 48, 9999, 1, 4, NULL, 1042, '1954-04-24', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1729, '1998-04-05 22:00:00+00', '2016-11-08 01:12:23.051555+00', 'Down on Yon Bank', 'DOWN ON YON BANK', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 37, '800/833/833/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1732, '1997-04-03 22:00:00+00', '2018-04-03 00:07:42.9263+00', 'Down Under', 'DOWN UNDER', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1745, '1997-08-25 22:00:00+00', '2018-04-03 00:07:42.959664+00', 'Dram O'' Dalwhinnie', 'DRAM O DALWHINNIE', 1, 32, 9999, 1, 3, 42, 540, '1977-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1738, '1997-04-03 22:00:00+00', '2018-04-03 00:07:42.976285+00', 'Dr David Rorie', 'DR DAVID RORIE', 3, 32, 9999, 1, 3, 42, 108, '1985-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1739, '1997-09-01 22:00:00+00', '2018-04-03 00:07:43.018062+00', 'Dr Finlay', 'DR FINLAY', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1753, '1997-04-03 22:00:00+00', '2018-04-03 00:07:43.034709+00', 'Drinking Horn, The', 'DRINKING HORN', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1741, '1998-04-08 22:00:00+00', '2018-04-03 00:07:43.051419+00', 'Dr Kay Lane', 'DR KAY LANE', 3, 32, 9999, 1, 3, 42, 108, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1778, '1998-04-08 22:00:00+00', '2018-04-03 00:07:43.218288+00', 'Duchess'' New Slippers, The', 'DUCHESS NEW SLIPPERS', 3, 32, 9999, 1, 3, 42, 121, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3427, '2002-03-12 23:00:00+00', '2018-04-03 00:07:57.121383+00', 'Kelvinbridge', 'KELVINBRIDGE', 2, 32, 9999, 1, 3, 42, 111, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3430, '1997-04-03 22:00:00+00', '2018-04-03 00:07:57.129692+00', 'Ken & Barbara', 'KEN AND BARBARA', 3, 32, 9999, 1, 3, 42, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3434, '1997-09-05 22:00:00+00', '2018-04-03 00:07:57.138035+00', 'Kendall House', 'KENDALL HOUSE', 1, 40, 9999, 1, 3, 42, 466, '1757-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10705, '2002-07-21 22:00:00+00', '2018-04-03 00:08:13.175254+00', 'River Rock Reel', 'RIVER ROCK REEL', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1785, '2002-02-28 23:00:00+00', '2012-01-20 12:56:14.313489+00', 'Duke of Atholl''s Brogues, The', 'DUKE OF ATHOLLS BROGUES', 3, 64, 9999, 3, 5, NULL, 121, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3438, '1997-04-03 22:00:00+00', '2012-01-20 12:56:28.201827+00', 'Kennedy Gardens', 'KENNEDY GARDENS', 2, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3442, '1997-09-06 22:00:00+00', '2012-01-20 12:56:28.2294+00', 'Kensington Court', 'KENSINGTON COURT', 1, 32, 9999, 1, 2, NULL, 446, '1695-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3460, '1998-01-04 23:00:00+00', '2018-04-03 00:07:38.355299+00', 'Chrissie Paterson''s Return', 'CHRISSIE PATERSONS RETURN', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3450, '1997-04-03 22:00:00+00', '2012-01-20 12:56:28.286274+00', 'Keys of Loch Leven, The', 'KEYS OF LOCH LEVEN', 3, 32, 9999, 2, 3, NULL, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10706, '2002-07-21 22:00:00+00', '2012-01-20 12:57:23.436519+00', 'Royal Scot, Pullin'' to Edinburgh', 'ROYAL SCOT PULLIN TO EDINBURGH', 1, 32, 9999, 1, 2, NULL, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1795, '2002-03-11 23:00:00+00', '2019-09-08 13:12:49.067138+00', 'Duke of Wellington, The', 'DUKE OF WELLINGTON', 1, 32, 9999, 1, 3, 42, 44, '1978-01-01', '', 53, '800/888/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1781, '1997-04-03 22:00:00+00', '2019-08-02 23:39:42.884588+00', 'Dugald Dalgetty', 'DUGALD DALGETTY', 2, 48, 9999, 1, 4, 1, 129, NULL, '', 61, '8000/8800/8800/8884/4488/8486', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1788, '2002-02-28 23:00:00+00', '2012-01-20 12:56:14.334358+00', 'Duke of Fife, The', 'DUKE OF FIFE', 1, 32, 9999, 1, 4, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1794, '1997-08-31 22:00:00+00', '2012-01-20 12:56:14.377804+00', 'Courtship', 'COURTSHIP', 5, 32, 9999, 2, 3, NULL, 798, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1797, '1997-09-01 22:00:00+00', '2012-01-20 12:56:14.398402+00', 'Dull Sir John', 'DULL SIR JOHN', 2, 96, 9999, 4, 4, NULL, 446, '1651-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1798, '2002-04-30 22:00:00+00', '2012-01-20 12:56:14.40624+00', 'Dumbarton Castle', 'DUMBARTON CASTLE', 3, 32, 9999, 2, 3, 18, 270, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1803, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.440443+00', 'Dumfries House', 'DUMFRIES HOUSE', 2, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1805, '1997-11-27 23:00:00+00', '2012-01-20 12:56:14.454319+00', 'Dumfries Medley', 'DUMFRIES MEDLEY', 4, 96, 11, 4, 4, NULL, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1809, '1997-09-01 22:00:00+00', '2012-01-20 12:56:14.481528+00', 'Dun Telve', 'DUN TELVE', 3, 40, 9999, 1, 2, NULL, 860, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1810, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.488279+00', 'Dunbar Castle', 'DUNBAR CASTLE', 2, 32, 9999, 1, 2, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1813, '1997-12-03 23:00:00+00', '2012-01-20 12:56:14.511513+00', 'Flindersshire Scots, The', 'FLINDERSSHIRE SCOTS', 2, 40, 9999, 1, 4, NULL, 909, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3451, '1998-01-15 23:00:00+00', '2012-01-20 12:56:28.293238+00', 'Keys O'' The Castle', 'KEYS O THE CASTLE', 3, 96, 9999, 4, 4, NULL, 82, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3455, '1997-11-24 23:00:00+00', '2012-01-20 12:56:28.32078+00', 'Kilalelahmar', 'KILALELAHMAR', 4, 64, 5, 6, 98, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3457, '1997-04-03 22:00:00+00', '2012-01-20 12:56:28.334333+00', 'Kilburn''s Reel', 'KILBURNS REEL', 1, 32, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3458, '1998-07-08 22:00:00+00', '2012-01-20 12:56:28.3419+00', 'Kilcreggan', 'KILCREGGAN', 1, 32, 9999, 1, 4, 2, 199, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3462, '1997-04-03 22:00:00+00', '2012-01-20 12:56:28.369463+00', 'Kilfinan Strathspey, The', 'KILFINAN STRATHSPEY', 3, 24, 9999, 1, 2, NULL, 199, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3464, '1997-04-03 22:00:00+00', '2012-01-20 12:56:28.38314+00', 'Killarney Reel', 'KILLARNEY REEL', 1, 48, 9999, 4, 4, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3448, '1997-09-07 22:00:00+00', '2017-11-12 21:33:43.968986+00', 'Key Of The Cellar, The', 'KEY OF THE CELLAR', 3, 32, 9999, 1, 3, 42, 976, '1740-01-01', '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1812, '1998-01-05 23:00:00+00', '2018-04-03 00:07:43.343373+00', 'Dunbarney Reel, The', 'DUNBARNEY REEL', 1, 32, 9999, 1, 3, 42, 417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1808, '1997-09-01 22:00:00+00', '2018-04-03 00:07:43.360065+00', 'Dun Beag Reel', 'DUN BEAG REEL', 2, 32, 9999, 1, 3, 42, 847, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3439, '1997-09-06 22:00:00+00', '2018-04-03 00:07:57.146547+00', 'Kenneth MacKay of the 19th Cameron Highlanders', 'KENNETH MACKAY OF THE 19TH CAMERON HIGHLANDERS', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3440, '1997-04-03 22:00:00+00', '2018-04-03 00:07:57.163125+00', 'Kenneth the Bear', 'KENNETH THE BEAR', 1, 28, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3443, '1997-09-18 22:00:00+00', '2018-04-03 00:07:57.188107+00', 'Keppoch Hill', 'KEPPOCH HILL', 2, 32, 9999, 1, 3, 42, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1811, '1997-04-03 22:00:00+00', '2020-08-04 00:48:26.439685+00', 'Dunbar Road', 'DUNBAR ROAD', 1, 32, 9999, 1, 3, 42, 249, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1764, '1997-04-03 22:00:00+00', '2020-12-01 11:11:00.40496+00', 'Drummond Hill', 'DRUMMOND HILL', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 56, '800/888/888/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3878, '1997-09-17 22:00:00+00', '2021-05-14 09:14:42.411782+00', 'Lochaber', 'LOCHABER', 2, 32, 9999, 1, 4, 1, 952, '1988-01-01', 'The book erroneously calls this a 3-couple dance in a 4-couple set. 1st couple end in 4th place.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1807, '1997-09-01 22:00:00+00', '2023-02-10 14:14:49.200154+00', 'Dun Alasdair Strathspey, The', 'DUN ALASDAIR STRATHSPEY', 3, 32, 9999, 1, 3, 42, 327, NULL, 'From the notes: "Dun Alasdair was the ancient residence of the chiefs of clan Donnachaidh, or the Robertsons, situated in Rannoch."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1801, '1998-04-11 22:00:00+00', '2023-02-10 14:22:57.666756+00', 'Dumgoyne', 'DUMGOYNE', 3, 32, 9999, 1, 3, 42, 121, '1986-01-01', 'The notes say that "Dumgoyne is a singular hill on the flank of the Campsies overlooking Strathblane, Dumbartonshire."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1760, '2000-04-25 22:00:00+00', '2021-06-14 20:54:17.554659+00', 'Drumlins of Down, The', 'DRUMLINS OF DOWN', 2, 32, 9999, 1, 3, 42, 359, NULL, '', 63, '844/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1756, '1997-09-01 22:00:00+00', '2021-06-15 08:21:14.310683+00', 'Drumblair''s Reels', 'DRUMBLAIRS REELS', 3, 32, 9999, 1, 3, 42, 176, NULL, '', 63, '888/844/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3877, '1997-04-03 22:00:00+00', '2021-06-20 23:08:00.938397+00', 'Loch-na-Gar', 'LOCHNAGAR', 2, 32, 9999, 1, 3, 42, 352, '1990-11-03', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3452, '1998-01-05 23:00:00+00', '2021-07-15 22:37:22.5597+00', 'Kia Ora', 'KIA ORA', 1, 32, 9999, 1, 3, 42, 352, '1993-04-17', '', 25, '800/800/800/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3447, '1997-04-03 22:00:00+00', '2018-04-03 00:07:57.229769+00', 'Kettle''s Boiling, The', 'KETTLES BOILING', 1, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3456, '1997-09-07 22:00:00+00', '2018-04-03 00:07:57.254743+00', 'Kilberry Head', 'KILBERRY HEAD', 3, 32, 9999, 1, 3, 42, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3875, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.223932+00', 'Loch Struan', 'LOCH STRUAN', 3, 40, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10709, '2002-07-21 22:00:00+00', '2018-04-03 00:08:20.638938+00', 'Thistle Amang the Heather', 'THISTLE AMANG THE HEATHER', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10710, '2002-07-21 22:00:00+00', '2018-04-03 00:08:23.107189+00', 'Twistin'' Gates o'' My Toon', 'TWISTIN GATES O MY TOON', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10712, '2002-07-21 22:00:00+00', '2018-04-03 00:08:25.75923+00', 'Wildflower Strathspey', 'WILDFLOWER STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18823, '2018-10-06 08:53:29.546133+00', '2018-10-06 08:53:29.546133+00', 'Macramé', 'MACRAME', 3, 32, NULL, 1, 3, 42, 2766, '2009-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3881, '1997-04-03 22:00:00+00', '2012-01-20 12:56:31.439569+00', 'Lochan, The', 'LOCHAN', 2, 32, 9999, 1, 4, NULL, 159, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1815, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.527298+00', 'Duncan Davidson', 'DUNCAN DAVIDSON', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1820, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.565678+00', 'Duncan Rising, The', 'DUNCAN RISING', 2, 32, 9999, 1, 4, NULL, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1824, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.604652+00', 'Duncan''s Delight', 'DUNCANS DELIGHT', 2, 32, 9999, 1, 2, NULL, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1825, '1998-01-05 23:00:00+00', '2012-01-20 12:56:14.613518+00', 'Duncan''s Exchange', 'DUNCANS EXCHANGE', 1, 40, 9999, 1, 4, NULL, 849, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1827, '1997-09-01 22:00:00+00', '2012-01-20 12:56:14.630854+00', 'Dundee 800 Jig', 'DUNDEE 800 JIG', 2, 64, 9999, 1, 4, NULL, 851, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1832, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.669543+00', 'Dundee Fair', 'DUNDEE FAIR', 3, 32, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1835, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.690058+00', 'Dundee Royal Arch', 'DUNDEE ROYAL ARCH', 2, 32, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1836, '1997-09-29 22:00:00+00', '2012-01-20 12:56:14.697394+00', 'Dundee Strathspey', 'DUNDEE STRATHSPEY', 3, 32, 9999, 5, 2, NULL, 176, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1837, '1997-09-01 22:00:00+00', '2012-01-20 12:56:14.704482+00', 'Dundee Weaver', 'DUNDEE WEAVER', 2, 32, 9999, 1, 4, NULL, 680, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1839, '1997-09-10 22:00:00+00', '2012-01-20 12:56:14.718407+00', 'Dundern Castle', 'DUNDERN CASTLE', 3, 32, 9999, 5, 2, NULL, 454, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1817, '1998-01-05 23:00:00+00', '2018-04-02 23:56:34.049348+00', 'Duncan MacCalman', 'DUNCAN MACCALMAN', 1, 32, 9999, 1, 3, 42, 129, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10719, '2002-07-24 22:00:00+00', '2018-04-03 00:07:41.675143+00', 'Deeside', 'DEESIDE', 2, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3467, '1997-04-03 22:00:00+00', '2012-01-20 12:56:28.40609+00', 'Killin Strathspey', 'KILLIN STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 202, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3468, '1997-09-07 22:00:00+00', '2012-01-20 12:56:28.413013+00', 'Killin Water', 'KILLIN WATER', 3, 40, 9999, 1, 4, NULL, 318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3471, '1997-12-28 23:00:00+00', '2012-01-20 12:56:28.433638+00', 'Kilmory Rant', 'KILMORY RANT', 1, 0, 9999, 4, 4, NULL, 121, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10716, '2002-11-19 23:00:00+00', '2012-01-20 12:57:23.505369+00', 'Duke of Benzie, The', 'DUKE OF BENZIE', 3, 32, 9999, 1, 4, 2, 3173, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10717, '2002-07-23 22:00:00+00', '2012-01-20 12:57:23.512317+00', 'Morgan McLeod Dancers', 'MORGAN MACLEOD DANCERS', 4, 128, 2, 4, 4, NULL, 2075, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10718, '2002-07-23 22:00:00+00', '2012-01-20 12:57:23.51919+00', 'Gleneagles Jig, The', 'GLENEAGLES JIG', 2, 96, 9999, 4, 4, NULL, 3174, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10720, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.532821+00', 'Polly''s Favourite', 'POLLYS FAVOURITE', 1, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10721, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.539626+00', 'Doon the Burn', 'DOON THE BURN', 3, 64, 9999, 4, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1846, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.769684+00', 'Dunie Mains', 'DUNIE MAINS', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1855, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.832987+00', 'Dunse Dings A''', 'DUNSE DINGS A', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1821, '1997-09-01 22:00:00+00', '2016-09-04 20:42:13.176754+00', 'Duncan Smith''s Reel', 'DUNCAN SMITHS REEL', 1, 32, 9999, 1, 3, 42, 636, NULL, 'To Anne and Duncan on their Wedding Day', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1828, '1999-07-25 22:00:00+00', '2018-04-03 00:07:43.410049+00', 'Dundee Branch Diamond Jubilee', 'DUNDEE BRANCH DIAMOND JUBILEE', 1, 32, 9999, 1, 3, 42, 850, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10722, '2002-07-24 22:00:00+00', '2018-04-03 00:07:55.912008+00', 'Joan & Ann''s Jig', 'JOAN AND ANNS JIG', 2, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1844, '1997-04-03 22:00:00+00', '2018-04-03 00:07:43.516254+00', 'Dunford Jig', 'DUNFORD JIG', 2, 32, 9999, 1, 3, 42, 92, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1845, '1997-09-01 22:00:00+00', '2018-04-03 00:07:43.535043+00', 'Dungarvon Whooper, The', 'DUNGARVON WHOOPER', 2, 32, 9999, 1, 3, 42, 90, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1849, '1997-04-03 22:00:00+00', '2018-04-03 00:07:43.551778+00', 'Dunkeld Steeple', 'DUNKELD STEEPLE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3469, '1997-04-03 22:00:00+00', '2018-04-03 00:07:57.304897+00', 'Killyfaddy', 'KILLYFADDY', 1, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1840, '1997-09-06 22:00:00+00', '2020-08-04 00:51:45.84035+00', 'Dundrennan', 'DUNDRENNAN', 3, 48, 9999, 1, 4, 1, 129, '1967-01-01', '', 80, '8000/8840/8868/8888/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3465, '1997-09-07 22:00:00+00', '2020-08-06 15:19:22.900338+00', 'Killiecrankie Reel, The', 'KILLIECRANKIE REEL', 1, 32, 9999, 1, 3, 42, 921, '1969-01-01', '', 62, '844/888/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1853, '1997-09-01 22:00:00+00', '2020-08-30 09:17:03.692601+00', 'Dunnotter Castle', 'DUNNOTTER CASTLE', 2, 32, 9999, 1, 3, 42, 855, NULL, '', 59, '888/444/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10711, '2002-07-21 22:00:00+00', '2020-12-24 22:58:38.516108+00', 'Vanessa''s Garden', 'VANESSAS GARDEN', 3, 32, 9999, 1, 3, 42, 2961, NULL, '', 56, '880/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1818, '1998-04-05 22:00:00+00', '2020-12-30 20:19:57.761182+00', 'Duncan Mackay', 'DUNCAN MACKAY', 3, 32, 9999, 1, 3, 42, 9998, '1740-01-01', '', 50, '840/804/866/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3470, '1997-12-21 23:00:00+00', '2021-04-09 11:03:20.332962+00', 'Kilmadock', 'KILMADOCK', 3, 32, 9999, 1, 4, 1, 9, NULL, '', 97, '8888/8888/8888/4888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1847, '1999-04-19 22:00:00+00', '2021-06-13 08:19:47.003251+00', 'Dunivard Reel, The', 'DUNIVARD REEL', 1, 32, 9999, 1, 3, 42, 87, NULL, '', 56, '844/888/888/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3523, '1997-09-07 22:00:00+00', '2018-04-03 00:07:57.613444+00', 'Kirtlewater', 'KIRTLEWATER', 1, 32, 9999, 1, 3, 42, 1045, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1831, '1997-09-01 22:00:00+00', '2022-08-18 20:46:31.262202+00', 'Dundee Clarendon Strathspey, The', 'DUNDEE CLARENDON STRATHSPEY', 3, 32, 9999, 1, 4, 1, 176, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1850, '1997-04-03 22:00:00+00', '2022-08-20 08:01:54.254546+00', 'Dunlugas House', 'DUNLUGAS HOUSE', 3, 64, 9999, 1, 4, 1, 297, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1822, '1997-04-03 22:00:00+00', '2022-11-07 19:06:45.431039+00', 'Duncan The Gauger', 'DUNCAN THE GAUGER', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1851, '1997-08-24 22:00:00+00', '2023-02-09 18:35:52.546513+00', 'Dunnideer', 'DUNNIDEER', 2, 32, 9999, 1, 3, 42, 108, '1994-01-01', 'Inscribed "for Sheila Wilson of New York who used to live in Insch".', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1842, '1998-07-08 22:00:00+00', '2023-02-10 14:00:42.000238+00', 'Dunedin Folly', 'DUNEDIN FOLLY', 1, 32, 9999, 1, 4, 2, 517, '1995-01-01', 'Devised "for Dunedin''s first entry at the Newcastle festival."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1856, '1997-09-01 22:00:00+00', '2021-06-13 08:17:07.523416+00', 'Dunshelt Strathspey', 'DUNSHELT STRATHSPEY', 3, 32, 9999, 1, 3, 42, 566, NULL, '', 63, '888/888/880/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1819, '1998-11-02 23:00:00+00', '2021-06-13 08:52:19.050373+00', 'Duncan McArthur''s Favourite', 'DUNCAN MACARTHURS FAVOURITE', 2, 32, 9999, 1, 3, 42, 394, '1985-10-01', 'The notes explain that "Duncan MacArthur Hall is part of Queen''s University, where the Kingston Ontario Branch holds its Annual Workshop and some weekly classes."', 50, '800/844/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3459, '1997-09-07 22:00:00+00', '2021-06-16 13:51:49.241479+00', 'Kildonan Jig', 'KILDONAN JIG', 2, 48, 9999, 1, 3, 42, 318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3476, '1997-04-03 22:00:00+00', '2018-04-03 00:07:57.329896+00', 'Kilt Pin, The', 'KILT PIN', 3, 32, 9999, 1, 3, 42, 212, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3477, '1997-04-03 22:00:00+00', '2018-04-03 00:07:57.338228+00', 'Kilts an'' Canvas', 'KILTS AN CANVAS', 1, 32, 9999, 1, 3, 42, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3478, '1997-04-03 22:00:00+00', '2018-04-03 00:07:57.346601+00', 'Kilwining Archers', 'KILWINING ARCHERS', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3879, '1997-04-03 22:00:00+00', '2018-04-03 00:07:59.898734+00', 'Lochaber', 'LOCHABER', 3, 32, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3880, '1997-04-03 22:00:00+00', '2018-04-03 00:07:59.907069+00', 'Lochaber Gathering', 'LOCHABER GATHERING', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1859, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.861436+00', 'Dunstaffnage Castle', 'DUNSTAFFNAGE CASTLE', 3, 96, 9999, 1, 4, NULL, 311, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1860, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.868468+00', 'Dunster Yarn Market', 'DUNSTER YARN MARKET', 3, 32, 9999, 1, 4, NULL, 676, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3481, '1997-04-03 22:00:00+00', '2018-08-20 20:48:20.613358+00', 'Kincardine Bridge', 'KINCARDINE BRIDGE', 2, 40, 9999, 1, 3, 42, 28, NULL, 'To the late Mrs. Peach, our Bath Branch class pianist, whose nimble fingers together with Betty''s instruction, kept us on our toes.', 55, '880/800/880/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1863, '1997-09-01 22:00:00+00', '2012-01-20 12:56:14.889249+00', 'Dunvegan Garden', 'DUNVEGAN GARDEN', 3, 32, 9999, 1, 2, NULL, 857, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1865, '1998-01-05 23:00:00+00', '2012-01-20 12:56:14.902905+00', 'Dust Devils, The', 'DUST DEVILS', 1, 32, 9999, 1, 4, NULL, 615, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3482, '1997-04-03 22:00:00+00', '2019-02-21 20:06:10.46324+00', 'Kinclaven Bridge', 'KINCLAVEN BRIDGE', 3, 32, 9999, 1, 4, 1, 176, NULL, '', 72, '8888/4444/4444/4888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1871, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.945701+00', 'Eagle''s Nest, The', 'EAGLES NEST', 3, 32, 9999, 1, 4, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15517, '2014-06-27 21:16:45.505798+00', '2019-01-23 18:06:41.318718+00', 'Tapestry', 'TAPESTRY', 1, 40, NULL, 1, 3, 42, 10971, NULL, '', 43, '840 880 804 808 840', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3504, '1998-04-12 22:00:00+00', '2019-03-15 10:22:56.226251+00', 'Kingston Jig, The', 'KINGSTON JIG', 2, 32, 9999, 1, 4, 1, 146, NULL, '', 41, '4440/4440/8000/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3484, '1997-09-07 22:00:00+00', '2012-01-20 12:56:28.526055+00', 'Kind Robin', 'KIND ROBIN', 4, 64, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1870, '1997-04-03 22:00:00+00', '2018-04-03 00:07:43.668702+00', 'Dyed-in-the-Kilt Canadian', 'DYEDINTHEKILT CANADIAN', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10723, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.553183+00', 'Little & Good', 'LITTLE AND GOOD', 3, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1875, '1997-09-01 22:00:00+00', '2019-09-13 21:01:59.708778+00', 'Earl Gray', 'EARL GRAY', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 50, '800/888/866/822', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10725, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.566761+00', 'Triquetra, The', 'TRIQUETRA', 1, 48, 9999, 6, 3, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10727, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.580849+00', 'Shaftsbury Square', 'SHAFTSBURY SQUARE', 4, 64, 60, 4, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10729, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.594698+00', 'Allamande Tree, The', 'ALLAMANDE TREE', 1, 32, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1874, '1997-04-03 22:00:00+00', '2012-01-20 12:56:14.966474+00', 'Ealing Ladies', 'EALING LADIES', 2, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1879, '1999-08-06 22:00:00+00', '2012-01-20 12:56:15.000682+00', 'Earl of Burlington, The', 'EARL OF BURLINGTON', 1, 128, 9999, 4, 4, NULL, 353, '1979-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1880, '1999-08-06 22:00:00+00', '2012-01-20 12:56:15.00768+00', 'Earl of Dumfries', 'EARL OF DUMFRIES', 2, 28, 9999, 1, 98, NULL, 423, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1887, '1999-08-06 22:00:00+00', '2012-01-20 12:56:15.056551+00', 'Earl of Tyrone, The', 'EARL OF TYRONE', 2, 48, 9999, 1, 4, NULL, 829, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1889, '1998-07-08 22:00:00+00', '2012-01-20 12:56:15.070939+00', 'Earl''s Cross', 'EARLS CROSS', 1, 32, 9999, 1, 4, 2, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1890, '2003-01-28 23:00:00+00', '2012-01-20 12:56:15.078434+00', 'Earlscourt Hall', 'EARLSCOURT HALL', 3, 32, 9999, 1, 4, 1, 35, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1893, '1998-07-08 22:00:00+00', '2012-01-20 12:56:15.102804+00', 'Early Stuart Kings, The', 'EARLY STUART KINGS', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1899, '1999-04-19 22:00:00+00', '2012-01-20 12:56:15.150465+00', 'Eastwood Park', 'EASTWOOD PARK', 3, 32, 9999, 1, 4, 1, 87, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3496, '1997-09-07 22:00:00+00', '2012-01-20 12:56:28.615956+00', 'King''s Strathspey, The', 'KINGS STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 1044, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3500, '1998-07-08 22:00:00+00', '2012-01-20 12:56:28.644436+00', 'Kingfisher Jig', 'KINGFISHER JIG', 2, 40, 9999, 1, 4, 2, 135, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1872, '1997-11-25 23:00:00+00', '2015-02-24 16:30:30.557495+00', 'Eagles of the Glen', 'EAGLES OF THE GLEN', 4, 128, 2, 4, 4, NULL, 859, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1886, '1999-08-06 22:00:00+00', '2018-04-03 00:07:43.735316+00', 'Earl of Seaforth''s Reel', 'EARL OF SEAFORTHS REEL', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1895, '1997-09-01 22:00:00+00', '2018-04-03 00:07:43.777074+00', 'East Kirk Jig', 'EAST KIRK JIG', 2, 32, 9999, 1, 3, 42, 176, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1900, '1997-09-01 22:00:00+00', '2018-04-03 00:07:43.827066+00', 'Ebb Tide', 'EBB TIDE', 3, 32, 9999, 1, 3, 42, 209, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3498, '1997-11-25 23:00:00+00', '2018-04-03 00:07:57.396537+00', 'Kingarth Medley', 'KINGARTH MEDLEY', 4, 32, 1, 1, 3, 42, 476, '1965-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3501, '1997-09-07 22:00:00+00', '2018-04-03 00:07:57.421518+00', 'Kingis Quair, The', 'KINGIS QUAIR', 2, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3488, '1997-10-27 23:00:00+00', '2018-04-03 00:07:57.454805+00', 'King of the Fairies', 'KING OF THE FAIRIES', 1, 40, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3491, '1997-04-03 22:00:00+00', '2018-04-03 00:07:57.471533+00', 'King Robert The Bruce', 'KING ROBERT THE BRUCE', 1, 32, 9999, 1, 3, 42, 362, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1867, '1998-06-20 22:00:00+00', '2020-01-11 01:55:38.706041+00', 'Dutch Crossing, The', 'DUTCH CROSSING', 4, 64, 22, NULL, 8, NULL, 858, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3480, '1997-04-03 22:00:00+00', '2020-04-29 21:27:34.509609+00', 'Kincaldrum''s Reel', 'KINCALDRUMS REEL', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1892, '1997-09-01 22:00:00+00', '2020-08-14 21:09:56.994355+00', 'Early Riser', 'EARLY RISER', 2, 32, 9999, 1, 4, 1, 21, NULL, '', 78, '8008/8888/8408/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10713, '2002-07-21 22:00:00+00', '2020-09-12 22:01:58.29815+00', 'Ye Ken It Well', 'YE KEN IT WELL', 2, 32, 9999, 1, 3, 42, 2961, NULL, 'This dance may be danced as Reel, Jig or Strathspey', 44, '800/844/880/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1869, '1997-04-03 22:00:00+00', '2020-11-30 18:28:13.797546+00', 'Dwarfie Stane, The', 'DWARFIE STANE', 1, 32, 9999, 1, 3, 42, 313, NULL, '', 72, '866/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1896, '2002-03-03 23:00:00+00', '2021-04-07 20:56:07.390743+00', 'Easter Egg, The', 'EASTER EGG', 2, 64, 9999, 4, 4, 46, 575, NULL, '', 75, '8888/0808/4444/8080/0808/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1897, '2002-03-03 23:00:00+00', '2021-06-12 18:37:08.73262+00', 'Easter Wedding', 'EASTER WEDDING', 1, 40, 9999, 1, 100, 22, 3591, '1995-04-01', 'Devised to celebrate the marriage of Fiona Ogden and Ian Alexander on 8th April 1995.', 70, '8008/4444/8888/8008/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1882, '1999-08-06 22:00:00+00', '2021-06-20 21:52:35.882862+00', 'Earl of Glencairn', 'EARL OF GLENCAIRN', 1, 32, 9999, 1, 4, 11, 352, '1991-08-10', '', 78, '8844/8008/8888/8668', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1885, '1999-08-06 22:00:00+00', '2022-11-07 19:07:15.325744+00', 'Earl Of Morton''s Jig', 'EARL OF MORTONS JIG', 2, 48, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1877, '1999-08-06 22:00:00+00', '2023-02-09 10:05:31.263296+00', 'Earl of Arran, The', 'EARL OF ARRAN', 3, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1868, '1997-11-20 23:00:00+00', '2023-02-09 13:07:27.413735+00', 'Dutch Skipper, The', 'DUTCH SKIPPER', 3, 32, 9999, 1, 2, 76, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1878, '1999-08-06 22:00:00+00', '2021-06-13 13:18:33.953434+00', 'Earl of Barrymore, The', 'EARL OF BARRYMORE', 1, 32, 9999, 1, 3, 42, 352, '1991-05-25', '', 53, '840/888/880/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1861, '1997-09-01 22:00:00+00', '2021-06-21 11:39:13.062834+00', 'Dunure Castle', 'DUNURE CASTLE', 1, 32, 9999, 1, 3, 42, 856, NULL, '', 50, '606/840/866/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3494, '1997-04-03 22:00:00+00', '2018-04-03 00:07:57.496522+00', 'King''s College Strathspey', 'KINGS COLLEGE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 209, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3495, '1997-08-20 22:00:00+00', '2018-04-03 00:07:57.504888+00', 'King''s Park', 'KINGS PARK', 3, 32, 9999, 1, 3, 42, 108, '1964-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3497, '1997-04-03 22:00:00+00', '2018-04-03 00:07:57.521598+00', 'King''s X', 'KINGS X', 2, 32, 9999, 1, 3, 42, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10724, '2002-07-24 22:00:00+00', '2018-04-03 00:08:02.233758+00', 'Marjorie''s Medley', 'MARJORIES MEDLEY', 4, 32, 1, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10728, '2002-07-24 22:00:00+00', '2018-04-03 00:08:25.917741+00', 'Will You Dance?', 'WILL YOU DANCE', 3, 40, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1902, '1997-04-03 22:00:00+00', '2018-08-28 10:10:40.956446+00', 'Ecclefechan Rant, The', 'ECCLEFECHAN RANT', 1, 32, 9999, 1, 3, 42, 212, NULL, '', 59, '800/888/888/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3508, '1997-09-07 22:00:00+00', '2012-01-20 12:56:28.753761+00', 'Kinloss', 'KINLOSS', 3, 32, 9999, 2, 3, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3512, '1997-04-03 22:00:00+00', '2012-01-20 12:56:28.781226+00', 'Kinness Burn Strathspey', 'KINNESS BURN STRATHSPEY', 3, 48, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10731, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.608441+00', 'Golden Links', 'GOLDEN LINKS', 3, 40, 9999, 7, 5, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10733, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.622028+00', 'Heeliegoleerie', 'HEELIEGOLEERIE', 2, 40, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18688, '2018-10-02 09:05:21.210859+00', '2018-10-02 09:17:09.674572+00', 'Briggs Law', 'BRIGGS LAW', 3, 32, NULL, 1, 3, 42, 2766, '2012-03-01', 'This dance was written for Norma and Mike Briggs in celebration of their leading the Madison Branch for many years.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1913, '1997-11-27 23:00:00+00', '2019-03-17 12:27:00.036641+00', 'Edinburgh Medallist, The', 'EDINBURGH MEDALLIST', 4, 32, 8, 1, 4, 1, 146, NULL, '', 47, '8044/8440/8220/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3516, '1997-04-03 22:00:00+00', '2019-08-29 18:35:45.358197+00', 'Kirk''s Hornpipe', 'KIRKS HORNPIPE', 1, 32, 9999, 1, 3, 42, 108, '1989-01-01', '', 66, '888/846/888/882', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1910, '1997-04-03 22:00:00+00', '2012-01-20 12:56:15.250601+00', 'Edinburgh Lass, The', 'EDINBURGH LASS', 3, 32, 9999, 5, 2, NULL, 197, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1918, '1997-04-03 22:00:00+00', '2012-01-20 12:56:15.314136+00', 'Edith Raitt''s Jig', 'EDITH RAITTS JIG', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1920, '2003-01-28 23:00:00+00', '2012-01-20 12:56:15.327768+00', 'Edleen', 'EDLEEN', 3, 32, 9999, 1, 2, NULL, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1922, '1997-09-01 22:00:00+00', '2012-01-20 12:56:15.341621+00', 'Edwina', 'EDWINA', 1, 32, 9999, 1, 4, NULL, 377, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1923, '1998-07-08 22:00:00+00', '2012-01-20 12:56:15.349147+00', 'Eerie Grove, The', 'EERIE GROVE', 2, 32, 9999, 1, 4, 2, 734, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1925, '1997-09-01 22:00:00+00', '2012-01-20 12:56:15.363266+00', 'Eevy Atha', 'EEVY ATHA', 1, 48, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3515, '1997-04-03 22:00:00+00', '2012-01-20 12:56:28.8021+00', 'Kipper''s Jig', 'KIPPERS JIG', 2, 64, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3518, '1997-04-03 22:00:00+00', '2012-01-20 12:56:28.823324+00', 'Kirkland Hill', 'KIRKLAND HILL', 3, 24, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3519, '1997-09-07 22:00:00+00', '2012-01-20 12:56:28.830098+00', 'Kirkwhelpington Reel, The', 'KIRKWHELPINGTON REEL', 1, 32, 9999, 1, 2, NULL, 776, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1911, '2002-04-02 22:00:00+00', '2018-04-03 00:07:31.838572+00', 'Babbling Brook, The', 'BABBLING BROOK', 2, 32, 9999, 1, 3, 42, 3084, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10734, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.628822+00', 'Kennedy Capers', 'KENNEDY CAPERS', 2, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10736, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.642439+00', 'Saint Margaret''s Strathspey', 'SAINT MARGARETS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10730, '2002-07-24 22:00:00+00', '2018-04-03 00:07:37.545797+00', 'Cavehill', 'CAVEHILL', 3, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1933, '1997-04-03 22:00:00+00', '2012-01-20 12:56:15.421936+00', 'Eilean Donan Castle', 'EILEAN DONAN CASTLE', 3, 32, 9999, 1, 4, NULL, 343, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1936, '1997-09-01 22:00:00+00', '2012-01-20 12:56:15.442541+00', 'Eileen''s Wedding', 'EILEENS WEDDING', 4, 64, 9999, 4, 4, NULL, 606, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1912, '2002-03-11 23:00:00+00', '2016-07-31 17:57:14.523438+00', 'Edinburgh Lassie, The', 'EDINBURGH LASSIE', 2, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3514, '1997-11-27 23:00:00+00', '2017-07-15 01:39:01.38115+00', 'Kinnoull Hill', 'KINNOULL HILL', 4, 64, 5, 4, 4, NULL, 696, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1904, '1997-10-20 22:00:00+00', '2018-04-03 00:07:43.860456+00', 'Echo In The Hills, The', 'ECHO IN THE HILLS', 1, 40, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1917, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.060537+00', 'Edinburgh''s Pride', 'EDINBURGHS PRIDE', 3, 40, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1919, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.077165+00', 'Edith''s Tattie Cairt', 'EDITHS TATTIE CAIRT', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1926, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.135543+00', 'Eigg Strathspey', 'EIGG STRATHSPEY', 3, 32, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1929, '2002-11-29 23:00:00+00', '2018-04-03 00:07:44.154354+00', 'Eighteenth of September, The', 'EIGHTEENTH OF SEPTEMBER', 3, 32, 9999, 1, 3, 42, 2620, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1935, '1997-08-24 22:00:00+00', '2018-04-03 00:07:44.185614+00', 'Eilean Donan Story, The', 'EILEAN DONAN STORY', 3, 32, 9999, 1, 3, 42, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1939, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.210675+00', 'Either - Or', 'EITHER  OR', 3, 32, 9999, 1, 3, 42, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10732, '2002-07-24 22:00:00+00', '2018-04-03 00:07:49.307851+00', 'Golden Oriole, The', 'GOLDEN ORIOLE', 1, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3505, '1998-04-12 22:00:00+00', '2018-04-03 00:07:57.513221+00', 'Kingston Reel', 'KINGSTON REEL', 1, 32, 9999, 1, 3, 42, 488, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3513, '1998-04-12 22:00:00+00', '2018-04-03 00:07:57.546738+00', 'Kinnoull Hill', 'KINNOULL HILL', 2, 32, 9999, 1, 3, 42, 108, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3522, '1997-04-03 22:00:00+00', '2020-03-23 21:00:22.020994+00', 'Kirriemuir Jig', 'KIRRIEMUIR JIG', 2, 32, 9999, 1, 3, 42, 28, NULL, '', 44, '800/844/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3526, '1999-11-01 23:00:00+00', '2020-04-20 16:30:07.052535+00', 'Kiss for Nothing, A', 'KISS FOR NOTHING', 2, 32, 9999, 1, 2, 76, 442, '1757-01-01', '', 52, '66/66/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1921, '1997-04-03 22:00:00+00', '2020-06-11 09:23:57.692571+00', 'Edward Jay''s Jaunt', 'EDWARD JAYS JAUNT', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 48, '680/808/844/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1901, '1997-09-01 22:00:00+00', '2020-08-04 05:47:18.398189+00', 'Ebba Reel', 'EBBA REEL', 4, 32, 8, 1, 98, NULL, 82, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3521, '1997-09-07 22:00:00+00', '2020-08-06 15:23:00.211822+00', 'Kirrie Kebbuck, The', 'KIRRIE KEBBUCK', 3, 32, 9999, 1, 3, 42, 129, '1970-01-01', '', 68, '880/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3510, '1997-04-03 22:00:00+00', '2020-08-31 16:42:58.455007+00', 'Kinnegad Jig', 'KINNEGAD JIG', 2, 48, 9999, 5, 2, 76, 270, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3507, '1997-04-03 22:00:00+00', '2020-10-21 09:27:39.283594+00', 'Kinlock of Kinlock', 'KINLOCK OF KINLOCK', 2, 32, 9999, 1, 2, 76, 270, NULL, '', 56, '62/88/88/48', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10740, '2002-07-24 22:00:00+00', '2020-09-12 22:06:04.365296+00', 'Haste Ye Back', 'HASTE YE BACK', 1, 32, 9999, 1, 3, 42, 1391, NULL, '', 50, '808/880/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1928, '2002-05-04 22:00:00+00', '2021-06-12 10:22:55.18972+00', '18th Anniversary, The', '18TH ANNIVERSARY', 2, 40, 9999, 1, 3, 42, 1253, NULL, '', 70, '880/888/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1903, '1998-11-14 23:00:00+00', '2022-08-18 20:48:39.088472+00', 'Eccles'' Rant', 'ECCLES RANT', 3, 32, 9999, 1, 3, 42, 9998, '1740-01-01', '', 38, '800/800/880/808', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1932, '1997-09-01 22:00:00+00', '2022-09-06 21:22:27.074684+00', 'Eildon Hills, The', 'EILDON HILLS', 3, 32, 9999, 2, 3, 17, 313, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1924, '1999-04-21 22:00:00+00', '2023-02-09 12:31:23.722847+00', 'Eerie Shores, The', 'EERIE SHORES', 2, 40, 9999, 1, 3, 42, 108, '1977-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1905, '2002-03-11 23:00:00+00', '2023-02-09 12:58:19.157519+00', 'Eden Court', 'EDEN COURT', 2, 32, 9999, 1, 3, 42, 108, '1982-01-01', 'The notes say that "Eden Court" is the nev theatre in Inverness.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10739, '2002-07-24 22:00:00+00', '2018-04-03 00:08:02.592302+00', 'Master Brent''s Fancy', 'MASTER BRENTS FANCY', 2, 32, 9999, 1, 3, 42, 1391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10735, '2002-07-24 22:00:00+00', '2018-04-03 00:08:07.104289+00', 'Myra''s Medley', 'MYRAS MEDLEY', 4, 32, 1, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10738, '2002-07-24 22:00:00+00', '2018-04-03 00:08:18.570925+00', 'Stormont Castle', 'STORMONT CASTLE', 1, 40, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15915, '2015-01-31 14:22:46.518188+00', '2018-04-03 00:18:02.011608+00', 'Chairman''s Whim, The', 'CHAIRMANS WHIM', 2, 32, 9999, 2, 2, 76, 10568, '2010-03-01', 'Music: Todlen Hame 6x32J track # 1 with Muriel Johnstone and Keith Smith (SSCD21) 



Holly writes:  Written for Clifford Champness to celebrate his Thistle Council award in 2010. Clifford is a long time Scottish country dancer who served as chairman of the RSCDS Montreal branch for several years and arranged insurance for our branch and many other branches in Canada. He started our February social - the Chairman''s Whim.', 67, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1941, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.235629+00', 'Elegant Esther Gray', 'ELEGANT ESTHER GRAY', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1944, '1997-04-03 22:00:00+00', '2012-01-20 12:56:15.49755+00', 'Eleventh of June', 'ELEVENTH OF JUNE', 3, 32, 9999, 1, 2, NULL, 402, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3527, '1998-04-12 22:00:00+00', '2018-04-29 22:02:57.972998+00', 'Kiss of the King''s Hand, A', 'KISS OF THE KINGS HAND', 3, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1951, '1998-04-08 22:00:00+00', '2019-03-17 12:23:04.541758+00', 'Elizabeth Thomson of Saint Andrews', 'ELIZABETH THOMSON OF SAINT ANDREWS', 3, 32, 9999, 2, 3, 17, 869, NULL, '', 81, '846/686/888/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1945, '2002-04-19 22:00:00+00', '2018-04-03 00:07:44.299352+00', 'Eleventh of May, The', 'ELEVENTH OF MAY', 1, 32, 9999, 1, 3, 42, 867, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1950, '1997-04-03 22:00:00+00', '2012-01-20 12:56:15.539568+00', 'Elizabeth Mary', 'ELIZABETH MARY', 1, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3530, '1997-12-28 23:00:00+00', '2012-01-20 12:56:28.907846+00', 'Kist o'' Thistles', 'KIST O THISTLES', 4, 128, 23, 1, 4, NULL, 121, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3531, '1997-12-26 23:00:00+00', '2012-01-20 12:56:28.915039+00', 'Kist o'' Diamonds, The', 'KIST O DIAMONDS', 4, 64, 5, 4, 4, NULL, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3532, '1997-09-05 22:00:00+00', '2012-01-20 12:56:28.92194+00', 'Jimmy''s Medley', 'JIMMYS MEDLEY', 4, 96, 9999, 1, 4, NULL, 1028, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1956, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.327384+00', 'Elizabethan Strathspey', 'ELIZABETHAN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 92, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10741, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.675964+00', 'Marmalade', 'MARMALADE', 3, 32, 9999, 1, 4, NULL, 1391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10743, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.689547+00', 'Pleasure of Your Company, The', 'PLEASURE OF YOUR COMPANY', 3, 40, 9999, 1, 2, NULL, 1391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1947, '1997-09-01 22:00:00+00', '2018-04-03 00:07:44.335746+00', 'Elizabeth Donald', 'ELIZABETH DONALD', 2, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1948, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.344191+00', 'Elizabeth Garland Of Ellon', 'ELIZABETH GARLAND OF ELLON', 3, 32, 9999, 1, 3, 42, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10746, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.710452+00', 'Tam Samson''s Elegy', 'TAM SAMSONS ELEGY', 3, 32, 9999, 1, 4, NULL, 1391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1938, '1997-11-20 23:00:00+00', '2012-10-02 13:42:58.405227+00', 'Eilidh''s Jig', 'EILIDHS JIG', 2, 48, 9999, 1, 4, NULL, 476, '1965-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1964, '1997-09-01 22:00:00+00', '2012-01-20 12:56:15.638303+00', 'Ellis Court Strathspey', 'ELLIS COURT STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1967, '1997-09-01 22:00:00+00', '2012-01-20 12:56:15.658889+00', 'Elma McCausland''s Strathspey', 'ELMA MACCAUSLANDS STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 872, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1968, '1997-04-03 22:00:00+00', '2012-01-20 12:56:15.665986+00', 'Elmgrove Strathspey', 'ELMGROVE STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1970, '1997-04-03 22:00:00+00', '2012-01-20 12:56:15.690899+00', 'Elsie''s Dance', 'ELSIES DANCE', 1, 96, 9999, 1, 4, NULL, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1971, '1997-04-03 22:00:00+00', '2012-01-20 12:56:15.700214+00', 'Emblem Of Scotland, The', 'EMBLEM OF SCOTLAND', 2, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1973, '1997-09-01 22:00:00+00', '2012-01-20 12:56:15.721445+00', 'Emerald Isle Jig', 'EMERALD ISLE JIG', 2, 32, 9999, 5, 56, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1984, '1997-04-03 22:00:00+00', '2012-01-20 12:56:15.820034+00', 'Encounter, An', 'ENCOUNTER', 1, 40, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1987, '2003-01-25 23:00:00+00', '2012-01-20 12:56:15.842188+00', 'English Country Garden', 'ENGLISH COUNTRY GARDEN', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1957, '1997-09-01 22:00:00+00', '2015-09-07 14:34:36.525948+00', 'Elizabethan Strathspey', 'ELIZABETHAN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 21, '1977-01-01', 'For The Royal Sliver Jubilee 1977.', 69, '888/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1986, '1997-09-01 22:00:00+00', '2018-04-03 00:07:44.5443+00', 'Energizer, The', 'ENERGIZER', 1, 32, 9999, 1, 3, 42, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10744, '2002-07-24 22:00:00+00', '2016-05-14 22:04:00.292746+00', 'Baltic Tribute, A', 'BALTIC TRIBUTE', 3, 32, 9999, 2, 3, 17, 1391, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1979, '1997-04-03 22:00:00+00', '2016-07-15 13:48:54.204035+00', 'Empire Strathspey, The', 'EMPIRE STRATHSPEY', 3, 32, 9999, 1, 4, 1, 352, '1993-05-04', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1975, '1997-09-01 22:00:00+00', '2018-04-03 00:07:44.452551+00', 'Emerald Queen', 'EMERALD QUEEN', 2, 24, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1976, '1998-01-05 23:00:00+00', '2018-04-03 00:07:44.460899+00', 'Emigrant''s Rant, The', 'EMIGRANTS RANT', 1, 32, 9999, 1, 3, 42, 250, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1978, '1997-09-01 22:00:00+00', '2018-04-03 00:07:44.510953+00', 'Empire Rose', 'EMPIRE ROSE', 3, 32, 9999, 1, 3, 42, 873, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1980, '1997-09-01 22:00:00+00', '2018-04-03 00:07:44.519385+00', 'Ena''s Love', 'ENAS LOVE', 3, 32, 9999, 1, 3, 42, 874, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10742, '2002-07-24 22:00:00+00', '2018-04-03 00:07:45.50351+00', 'Festival on the Nemunas', 'FESTIVAL ON THE NEMUNAS', 1, 32, 9999, 1, 3, 42, 1391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3534, '2003-01-25 23:00:00+00', '2018-04-03 00:07:57.671759+00', 'Kitchener Market, The', 'KITCHENER MARKET', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3535, '2003-01-28 23:00:00+00', '2018-04-03 00:07:57.680087+00', 'Kitchener-Waterloo Reel', 'KITCHENERWATERLOO REEL', 1, 32, 9999, 1, 3, 42, 35, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3533, '1997-09-07 22:00:00+00', '2018-04-03 00:07:57.688521+00', 'Kitchen Maid, The', 'KITCHEN MAID', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3539, '1997-04-03 22:00:00+00', '2018-04-03 00:07:57.738486+00', 'Kitty''s Rambles', 'KITTYS RAMBLES', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1963, '1997-04-03 22:00:00+00', '2020-08-30 09:37:16.885221+00', 'Elliott Strathspey', 'ELLIOTT STRATHSPEY', 3, 32, 9999, 2, 3, 17, 371, NULL, '', 83, '880/888/888/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3538, '2000-04-25 22:00:00+00', '2021-05-18 20:34:35.66383+00', 'Kitty''s Happy Return', 'KITTYS HAPPY RETURN', 3, 40, 9999, 1, 4, 2, 28, '1980-01-01', '"Dedicated to Miss Kitty Lawlor by her Downpatrick class."', 70, '8008/0880/8888/8888/8008', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1962, '1997-09-29 22:00:00+00', '2021-07-03 21:56:12.765653+00', 'Elliot''s Fancy', 'ELLIOTS FANCY', 4, 64, 9999, 1, 4, NULL, 871, '1964-01-01', 'Published as a leaflet (see <<https://my.strathspey.org/dd/issue/2516/|issue 2516>> for details).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1952, '1997-09-01 22:00:00+00', '2021-07-17 18:43:57.041221+00', 'Elizabeth''s Favourite', 'ELIZABETHS FAVOURITE', 3, 32, 9999, 1, 3, 42, 377, NULL, 'Devised for Elizabeth Roberts of Ruislip', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3540, '1997-04-03 22:00:00+00', '2018-04-03 00:07:57.746888+00', 'Kiwi Strathspey, The', 'KIWI STRATHSPEY', 3, 32, 9999, 1, 3, 42, 35, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3545, '1997-04-03 22:00:00+00', '2012-01-20 12:56:29.016892+00', 'Knot Garden, The', 'KNOT GARDEN', 1, 48, 9999, 3, 5, NULL, 199, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3546, '1997-04-03 22:00:00+00', '2012-01-20 12:56:29.023781+00', 'Knotanuva Eightsome', 'KNOTANUVA EIGHTSOME', 1, 48, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3547, '1998-10-15 22:00:00+00', '2012-01-20 12:56:29.030571+00', 'Knotted Oak, The', 'KNOTTED OAK', 2, 32, 9999, 1, 4, NULL, 1046, '1983-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16871, '2016-02-12 21:18:06.943829+00', '2018-04-03 00:18:02.18742+00', 'Hoolie Haggis', 'HOOLIE HAGGIS', 4, 64, 5, 2, 2, 76, 63, '2000-01-01', '', 53, '88/88/80/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18825, '2018-10-06 09:09:04.091634+00', '2018-10-06 09:09:04.091634+00', 'Mairi''s Double Date', 'MAIRIS DOUBLE DATE', 1, 32, NULL, 3, 5, 7, 2766, '2011-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1996, '2002-12-08 23:00:00+00', '2019-03-17 12:14:23.868319+00', 'Epuni Station', 'EPUNI STATION', 1, 32, 9999, 1, 4, 80, 878, NULL, '', 69, '0888/0888/8888/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10748, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.723403+00', 'Wish for Scotland, A', 'WISH FOR SCOTLAND', 2, 32, 9999, NULL, 4, NULL, 3177, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10750, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.737762+00', 'Ruby Carousel', 'RUBY CAROUSEL', 3, 32, 9999, NULL, 4, NULL, 3177, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10752, '2002-07-24 22:00:00+00', '2012-01-20 12:57:23.750095+00', 'Highland Gillies', 'HIGHLAND GILLIES', 2, 40, 9999, NULL, 4, NULL, 3177, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2023, '1997-04-03 22:00:00+00', '2019-04-22 12:07:04.895305+00', 'Expo Steam', 'EXPO STEAM', 3, 32, 9999, 1, 4, 1, 72, '1984-01-01', '', 70, '8448/4884/2646/0888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1988, '1997-09-01 22:00:00+00', '2012-01-20 12:56:15.850479+00', 'English Lavender', 'ENGLISH LAVENDER', 3, 40, 9999, 2, 3, NULL, 876, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2019, '1997-09-02 22:00:00+00', '2019-09-15 19:22:18.155942+00', 'Exciseman''s Jig, The', 'EXCISEMANS JIG', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3554, '2000-01-10 23:00:00+00', '2018-04-03 00:07:32.889841+00', 'Belle Stuart''s Reel, La', 'BELLE STUARTS REEL', 1, 32, 9999, 1, 3, 42, 430, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1991, '1998-04-08 22:00:00+00', '2012-01-20 12:56:15.871926+00', 'Entente Cordiale', 'ENTENTE CORDIALE', 3, 96, 9999, 4, 4, NULL, 146, '1978-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1994, '1997-09-01 22:00:00+00', '2012-01-20 12:56:15.8939+00', 'Epsom Caledonian''s Reel', 'EPSOM CALEDONIANS REEL', 1, 48, 9999, 1, 4, NULL, 613, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1995, '1997-04-03 22:00:00+00', '2012-01-20 12:56:15.900689+00', 'Epsom Downs', 'EPSOM DOWNS', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1999, '2002-04-19 22:00:00+00', '2012-01-20 12:56:15.932368+00', 'Eric And Rosemary''s Farewell to the New Town', 'ERIC AND ROSEMARYS FAREWELL TO THE NEW TOWN', 1, 40, 9999, 1, 4, 1, 879, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2001, '1997-04-03 22:00:00+00', '2012-01-20 12:56:15.946208+00', 'Erin Medley', 'ERIN MEDLEY', 4, 96, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2015, '1997-04-03 22:00:00+00', '2012-01-20 12:56:16.143035+00', 'Every Which Way', 'EVERY WHICH WAY', 2, 32, 9999, 1, 2, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2017, '1997-09-02 22:00:00+00', '2012-01-20 12:56:16.163381+00', 'Ewing Anniversary Strathspey', 'EWING ANNIVERSARY STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 653, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2022, '1997-09-02 22:00:00+00', '2012-01-20 12:56:16.214948+00', 'Expo 86-some Reel', 'EXPO 86SOME REEL', 1, 40, 9999, 4, 4, NULL, 883, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3555, '1997-04-03 22:00:00+00', '2012-01-20 12:56:29.086298+00', 'Clutha, La', 'CLUTHA', 1, 24, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3556, '1997-09-29 22:00:00+00', '2012-01-20 12:56:29.093155+00', 'Coquette, La', 'COQUETTE', 1, 24, 9999, 4, 4, NULL, 675, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3557, '1998-04-12 22:00:00+00', '2012-01-20 12:56:29.100148+00', 'Donna e Immobile, La', 'DONNA E IMMOBILE', 2, 32, 9999, 1, 2, NULL, 108, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3560, '1997-09-12 22:00:00+00', '2012-01-20 12:56:29.121222+00', 'Ronde, La', 'RONDE', 3, 32, 9999, 2, 3, NULL, 1238, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3565, '1997-09-07 22:00:00+00', '2012-01-20 12:56:29.156507+00', 'Lacing Up The Ghillies', 'LACING UP THE GHILLIES', 2, 32, 9999, 1, 4, NULL, 267, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1993, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.560952+00', 'Enveloping Tartan, The', 'ENVELOPING TARTAN', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2003, '1997-09-02 22:00:00+00', '2018-04-03 00:07:44.694363+00', 'Escort, The', 'ESCORT', 1, 32, 9999, 1, 3, 42, 211, '1979-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2007, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.744347+00', 'Ettrick Valley', 'ETTRICK VALLEY', 3, 48, 9999, 1, 3, 42, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2009, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.761092+00', 'Ettrick Water, The', 'ETTRICK WATER', 1, 32, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2011, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.777779+00', 'Even Stephen''s Leavin''', 'EVEN STEPHENS LEAVIN', 1, 32, 9999, 1, 3, 42, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2018, '1998-01-07 23:00:00+00', '2018-04-03 00:07:44.819523+00', 'Ewing Fiddlers, The', 'EWING FIDDLERS', 1, 32, 9999, 1, 3, 42, 882, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3548, '1997-09-07 22:00:00+00', '2018-04-03 00:07:57.80506+00', 'Knowles Park', 'KNOWLES PARK', 3, 32, 9999, 1, 3, 42, 469, '1788-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14935, '2013-06-01 10:59:28.70389+00', '2018-04-03 00:18:02.212818+00', 'Island Breeze', 'ISLAND BREEZE', 2, 32, NULL, 2, 2, 76, 1394, '2007-10-03', 'Can also be danced as a Reel.  

Can be danced in a 2C or 4C set.  

Can be danced with 3C in a 3C or in a 4C set (modified instructions included).  ', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2002, '1997-04-03 22:00:00+00', '2020-07-07 08:43:31.020948+00', 'Eriskay Boat', 'ERISKAY BOAT', 1, 32, 9999, 3, 3, 42, 270, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2000, '1997-09-01 22:00:00+00', '2021-06-11 20:37:23.382506+00', 'Eric Hill''s Reel', 'ERIC HILLS REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 56, '888/800/888/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3564, '1997-09-07 22:00:00+00', '2020-08-31 13:43:25.226996+00', 'Lacing the Ghillies', 'LACING THE GHILLIES', 1, 32, 9999, 1, 3, 42, 1048, NULL, '', 38, '800/800/844/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10756, '2002-07-24 22:00:00+00', '2020-09-12 22:16:50.863975+00', 'Tatties and Neeps', 'TATTIES AND NEEPS', 1, 32, 9999, 1, 4, 11, 1, '1998-01-01', '', 69, '5555/5555/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10757, '2002-07-24 22:00:00+00', '2020-09-12 22:21:49.911201+00', 'Out of the Blue', 'OUT OF THE BLUE', 3, 32, 9999, 2, 3, 17, 1, '1998-01-01', '', 50, '404/404/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3551, '1997-09-07 22:00:00+00', '2021-04-17 19:48:25.054983+00', 'Kyle Strathspey', 'KYLE STRATHSPEY', 3, 48, 9999, 4, 4, 1, 82, NULL, '', 77, '7777/8080/0808/8888/6666/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3552, '1997-04-03 22:00:00+00', '2021-05-07 23:04:41.198804+00', 'Kyles of Bute, The', 'KYLES OF BUTE', 3, 32, 9999, 1, 3, 42, 1047, '1965-01-01', '', 52, '666/844/800/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3559, '2002-04-24 22:00:00+00', '2021-05-18 11:40:49.977225+00', 'Maitresse, La', 'MAITRESSE', 3, 32, 9999, 1, 3, 42, 855, NULL, 'Dedicated to the memory of Mrs. Mary C. Gudger.', 56, '800/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1997, '1997-04-03 22:00:00+00', '2021-05-27 19:06:57.914888+00', 'Equidistant Reel, The', 'EQUIDISTANT REEL', 1, 32, 9999, 1, 3, 42, 352, '1993-01-24', '', 44, '800/880/880/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2006, '1997-04-03 22:00:00+00', '2021-06-21 10:51:03.985503+00', 'Ethell and Eddie', 'ETHELL AND EDDIE', 1, 32, 9999, 1, 3, 42, 393, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3543, '1998-07-08 22:00:00+00', '2021-08-04 10:10:59.314569+00', 'Knockderry Castle', 'KNOCKDERRY CASTLE', 1, 32, 9999, 1, 4, 2, 13, NULL, '', 88, '8888/8888/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2025, '1997-04-03 22:00:00+00', '2012-01-20 12:56:16.239299+00', 'Eyemouth Harbour', 'EYEMOUTH HARBOUR', 50, 40, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2027, '1997-09-02 22:00:00+00', '2012-01-20 12:56:16.253762+00', 'Faerie Flag of the McLeods, The', 'FAERIE FLAG OF THE MACLEODS', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2066, '1997-09-02 22:00:00+00', '2012-01-20 12:56:16.54933+00', 'Falter, The', 'FALTER', 3, 32, 9999, 1, 4, NULL, 886, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10764, '2002-07-24 22:00:00+00', '2019-02-08 17:58:10.178505+00', 'Crooked Spire, The', 'CROOKED SPIRE', 2, 40, 9999, 1, 100, 11, 1, '1998-01-01', '', 70, '8888/4444/8888/4444/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10759, '2002-07-24 22:00:00+00', '2019-03-02 11:07:26.272646+00', 'Silver Woods, The', 'SILVER WOODS', 2, 32, 9999, 1, 100, 2, 1, '1998-01-01', '', 81, '8448/8888/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2040, '1997-09-02 22:00:00+00', '2012-01-20 12:56:16.346557+00', 'Fairest of Women, The', 'FAIREST OF WOMEN', 3, 40, 9999, 1, 4, NULL, 567, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10749, '2002-07-24 22:00:00+00', '2022-09-13 13:32:55.482206+00', 'Playford''s Ceilidh', 'PLAYFORDS CEILIDH', 1, 88, 9999, 2, 3, 3, 234, '1995-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2067, '1997-04-03 22:00:00+00', '2022-11-07 21:59:26.640667+00', 'Family''s Pride, The', 'FAMILYS PRIDE', 2, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10751, '2002-07-24 22:00:00+00', '2022-12-02 21:30:32.285017+00', 'Catmint', 'CATMINT', 1, 40, 9999, 1, 4, 1, 234, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10753, '2002-07-24 22:00:00+00', '2022-12-02 21:33:51.390761+00', 'May Day', 'MAY DAY', 3, 32, 9999, 2, 3, 17, 234, '1995-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3567, '1998-11-16 23:00:00+00', '2022-12-10 21:09:51.471679+00', 'Lad o'' Kyle, The', 'LAD O KYLE', 1, 32, 9999, 1, 4, 1, 87, NULL, '', 69, '8484/8484/8440/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1992, '1998-07-09 22:00:00+00', '2023-02-09 12:06:19.599931+00', 'Entente Florale', 'ENTENTE FLORALE', 2, 48, 9999, 3, 5, 6, 108, '1994-01-01', 'Inscribed "for Betty Keir to use at a concert in Perth to raise funds to support Perth''s entry in the European ''City in Bloom'' Competition."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2041, '1997-04-03 22:00:00+00', '2012-01-20 12:56:16.353366+00', 'Fairfield Reel, The', 'FAIRFIELD REEL', 1, 32, 9999, 1, 4, NULL, 719, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2052, '1997-09-02 22:00:00+00', '2019-03-17 11:46:37.308398+00', 'Falconer Hall', 'FALCONER HALL', 2, 48, 9999, 1, 4, 1, 249, NULL, '', 60, '8880/0888/8888/8400/8040/8004', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2046, '1998-04-21 22:00:00+00', '2012-01-20 12:56:16.387987+00', 'Fairy Knoll, A', 'FAIRY KNOLL', 1, 32, 9999, 1, 2, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2047, '1997-04-03 22:00:00+00', '2012-01-20 12:56:16.3948+00', 'Fairy On The Tree, The', 'FAIRY ON THE TREE', 3, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3576, '2002-04-19 22:00:00+00', '2012-01-20 12:56:29.236996+00', 'Ladies of Down, The', 'LADIES OF DOWN', 2, 32, 9999, 1, 4, 2, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2055, '1997-04-03 22:00:00+00', '2012-01-20 12:56:16.450478+00', 'Falls o'' Dochart, The', 'FALLS O DOCHART', 1, 40, 9999, 1, 4, NULL, 44, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2058, '1997-04-03 22:00:00+00', '2012-01-20 12:56:16.492904+00', 'Falls of Dochart, The', 'FALLS OF DOCHART', 3, 32, 9999, 1, 4, NULL, 347, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2059, '1997-04-03 22:00:00+00', '2012-01-20 12:56:16.499744+00', 'Falls of Fintry, The', 'FALLS OF FINTRY', 3, 96, 9999, 1, 4, NULL, 213, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2061, '1997-09-02 22:00:00+00', '2012-01-20 12:56:16.514696+00', 'Falls of Lorna, The', 'FALLS OF LORNA', 1, 32, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2071, '1997-09-02 22:00:00+00', '2012-01-20 12:56:16.584604+00', 'Fanny''s Reel', 'FANNYS REEL', 1, 40, 9999, 3, 5, NULL, 887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2038, '2000-08-01 22:00:00+00', '2018-02-27 17:50:11.29907+00', 'Fair Wind, A', 'FAIR WIND', 1, 32, 9999, 1, 3, 42, 2778, '1994-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2028, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.919521+00', 'Faery Lullaby, A', 'FAERY LULLABY', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2029, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.936281+00', 'Failte Do''Nla', 'FAILTE DONLA', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2031, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.953001+00', 'Fair Duncan of the Songs', 'FAIR DUNCAN OF THE SONGS', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2043, '2002-03-02 23:00:00+00', '2018-04-03 00:07:45.011409+00', 'Fairy Bridge, The', 'FAIRY BRIDGE', 2, 32, 9999, 1, 3, 42, 313, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2054, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.06974+00', 'Falling Trees', 'FALLING TREES', 1, 32, 9999, 1, 3, 42, 145, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2057, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.078062+00', 'Falls of Bruar', 'FALLS OF BRUAR', 1, 32, 9999, 1, 3, 42, 159, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2065, '2003-01-26 23:00:00+00', '2018-04-03 00:07:45.119803+00', 'Falstaff''s Foolishness', 'FALSTAFFS FOOLISHNESS', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2070, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.144709+00', 'Fanny Power', 'FANNY POWER', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2074, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.295026+00', 'Far from Home', 'FAR FROM HOME', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2036, '1997-09-02 22:00:00+00', '2018-04-03 00:07:46.254398+00', 'Flower of Scotland', 'FLOWER OF SCOTLAND', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3573, '1998-03-30 22:00:00+00', '2018-04-03 00:07:57.888753+00', 'Ladies Breist Knot', 'LADIES BREIST KNOT', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18826, '2018-10-06 10:13:29.514284+00', '2018-10-06 10:13:29.514284+00', 'Merry Little Jig, A', 'MERRY LITTLE JIG', 2, 32, NULL, 1, 3, 42, 2766, '2012-11-01', 'This one just came to me one day so I wrote it down.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2078, '1997-04-03 22:00:00+00', '2012-01-20 12:56:16.634936+00', 'Fare Thee Well', 'FARE THEE WELL', 3, 32, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18974, '2018-10-15 17:51:37.899862+00', '2018-10-15 17:53:45.37804+00', 'Solstice, The', 'SOLSTICE', 3, 32, NULL, 1, 4, 5, 9998, NULL, '', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2069, '2002-04-10 22:00:00+00', '2020-08-07 14:35:19.850264+00', 'Fankle, The', 'FANKLE', 3, 32, 9999, 2, 3, 17, 105, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3574, '2002-04-19 22:00:00+00', '2020-08-31 13:46:48.684397+00', 'Ladies of Brooklyn', 'LADIES OF BROOKLYN', 3, 32, 9999, 1, 3, 42, 154, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10758, '2002-07-24 22:00:00+00', '2020-09-12 22:40:23.580745+00', 'City Squirrels', 'CITY SQUIRRELS', 1, 32, 9999, 1, 3, 42, 1, '1998-01-01', '', 59, '808/484/888/884', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10762, '2002-07-24 22:00:00+00', '2020-09-12 22:50:30.560388+00', 'Paradise', 'PARADISE', 1, 32, 9999, 1, 3, 42, 1, '1998-01-01', '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10763, '2002-07-24 22:00:00+00', '2020-09-12 22:54:09.144659+00', 'Sapphire Strathspey', 'SAPPHIRE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1, '1998-01-01', '', 59, '808/804/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2073, '1997-04-03 22:00:00+00', '2020-10-03 23:18:15.809134+00', 'Far Frae Hame', 'FAR FRAE HAME', 1, 32, 9999, 3, 5, 59, 270, NULL, 'Bars 17-32 have been revised in 2020 version', 78, '88880/80202/88888/88888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2051, '1997-09-02 22:00:00+00', '2020-10-07 21:19:33.510367+00', 'Faithful Shepherd, The', 'FAITHFUL SHEPHERD', 1, 24, 9999, 1, 2, NULL, 466, '1769-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3572, '1997-04-03 22:00:00+00', '2020-12-04 21:32:37.305443+00', 'Ladebraes, The', 'LADEBRAES', 3, 32, 9999, 1, 2, 76, 28, NULL, '<<scddb:not-identical:14353>>', 60, '88/88/88/80', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10761, '2002-07-24 22:00:00+00', '2021-02-06 11:10:04.553643+00', 'Angel Bank', 'ANGEL BANK', 1, 32, 9999, 1, 3, 42, 1, '1998-01-01', '', 50, '888/880/800/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3575, '2002-04-19 22:00:00+00', '2021-05-18 11:21:33.807905+00', 'Ladies of Dingwall, The', 'LADIES OF DINGWALL', 1, 48, 9999, 1, 3, 42, 9998, NULL, '', 52, '888/844/484/848/800/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3568, '1997-04-03 22:00:00+00', '2021-02-21 11:45:22.772905+00', 'Lad With The Plaidie, The', 'LAD WITH THE PLAIDIE', 3, 24, 9999, 1, 2, 76, 392, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2060, '2000-06-12 22:00:00+00', '2021-06-09 13:50:15.098604+00', 'Falls of Foyers, The', 'FALLS OF FOYERS', 1, 48, 9999, 1, 3, 42, 9998, NULL, 'The book says this dance was "arranged by Keith Noble".', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2033, '1997-09-02 22:00:00+00', '2021-06-09 16:27:14.138409+00', 'Fair Isle Stacs, The', 'FAIR ISLE STACS', 3, 32, 9999, 1, 4, 1, 90, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2064, '1997-04-03 22:00:00+00', '2021-06-13 19:26:32.372618+00', 'Falls Valley Strathspey', 'FALLS VALLEY STRATHSPEY', 3, 32, 9999, 1, 4, 1, 352, '1991-05-26', '', 50, '8000/8400/8880/8066', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2032, '1997-04-03 22:00:00+00', '2021-06-19 21:37:53.242423+00', 'Fair Isle', 'FAIR ISLE', 1, 32, 9999, 1, 4, 1, 352, '1991-05-21', 'In the Red Book this is inscribed "for my wife June who loves Fairisle design knitting".', 53, '8000/8008/8008/4888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2082, '1997-09-02 22:00:00+00', '2012-01-20 12:56:16.662585+00', 'Farewell to Calgary', 'FAREWELL TO CALGARY', 3, 32, 9999, 2, 3, NULL, 118, '1977-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3581, '1997-04-03 22:00:00+00', '2012-01-20 12:56:29.275134+00', 'Lads and Lassies', 'LADS AND LASSIES', 1, 32, 9999, 1, 4, NULL, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3587, '1997-12-03 23:00:00+00', '2012-01-20 12:56:29.317016+00', 'Helen''s Jig', 'HELENS JIG', 2, 40, 9999, 1, 2, NULL, 619, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3591, '1997-04-03 22:00:00+00', '2012-01-20 12:56:29.347151+00', 'Lady Binning', 'LADY BINNING', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2101, '2001-04-22 22:00:00+00', '2019-04-20 10:52:26.941101+00', 'Farewell to the North', 'FAREWELL TO THE NORTH', 4, 96, 21, 1, 4, 3, 21, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3590, '1997-11-20 23:00:00+00', '2019-09-12 16:55:18.305842+00', 'Lady Belhaven''s Delight', 'LADY BELHAVENS DELIGHT', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 60, '88/88/88/80', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2085, '2002-04-10 22:00:00+00', '2012-01-20 12:56:16.684014+00', 'Farewell To Fife', 'FAREWELL TO FIFE', 2, 32, 9999, 1, 4, 1, 181, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2230, '2003-01-26 23:00:00+00', '2018-04-03 00:07:46.137469+00', 'Flirtations', 'FLIRTATIONS', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10777, '2002-08-06 22:00:00+00', '2022-09-30 12:05:22.158895+00', 'Happy Agnes', 'HAPPY AGNES', 2, 32, 9999, 1, 4, 1, 3182, NULL, '', 53, '8004/8400/8484/8282', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10769, '2002-09-25 22:00:00+00', '2022-09-30 12:08:58.592088+00', 'Celtic Border, A', 'CELTIC BORDER', 3, 32, 9999, 1, 4, 1, 175, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3586, '1997-11-20 23:00:00+00', '2022-12-10 21:07:11.708504+00', 'Lads Of Tain', 'LADS OF TAIN', 3, 32, 9999, 1, 2, 76, 9998, NULL, '', 52, '80/88/88/80', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2090, '1998-07-08 22:00:00+00', '2012-01-20 12:56:16.723609+00', 'Farewell To Misty', 'FAREWELL TO MISTY', 3, 32, 9999, 1, 4, 2, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2091, '2002-03-11 23:00:00+00', '2012-01-20 12:56:16.731076+00', 'Farewell to Nigeria', 'FAREWELL TO NIGERIA', 1, 32, 9999, 1, 4, 1, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2092, '1997-09-12 22:00:00+00', '2012-01-20 12:56:16.737877+00', 'Farewell To Oban', 'FAREWELL TO OBAN', 2, 48, 9999, 1, 4, NULL, 318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2096, '1997-09-02 22:00:00+00', '2012-01-20 12:56:16.76521+00', 'Farewell To Saint Kilda', 'FAREWELL TO SAINT KILDA', 3, 40, 9999, 1, 4, NULL, 888, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2098, '2001-04-22 22:00:00+00', '2012-01-20 12:56:16.781939+00', 'Farewell to the Creeks', 'FAREWELL TO THE CREEKS', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2099, '2001-08-19 22:00:00+00', '2012-01-20 12:56:16.788754+00', 'Farewell to the Ironworkers', 'FAREWELL TO THE IRONWORKERS', 1, 48, 9999, 1, 4, NULL, 325, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2105, '1997-09-02 22:00:00+00', '2012-01-20 12:56:16.829486+00', 'Farewell to Witney', 'FAREWELL TO WITNEY', 2, 32, 9999, 1, 4, NULL, 890, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3597, '1997-04-03 22:00:00+00', '2012-01-20 12:56:29.388637+00', 'Lady Chief, The', 'LADY CHIEF', 2, 32, 9999, 1, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3599, '2003-01-26 23:00:00+00', '2012-01-20 12:56:29.402377+00', 'Lady Di & Prince Charles Strathspey', 'LADY DI AND PRINCE CHARLES STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3600, '1997-04-03 22:00:00+00', '2012-01-20 12:56:29.409164+00', 'Lady Doune', 'LADY DOUNE', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3603, '1997-09-07 22:00:00+00', '2012-01-20 12:56:29.429994+00', 'Lady Elizabeth Of Merioneth', 'LADY ELIZABETH OF MERIONETH', 3, 32, 9999, 1, 4, NULL, 1050, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2109, '1997-09-02 22:00:00+00', '2012-01-20 12:56:16.858071+00', 'Farrier''s Daughter, The', 'FARRIERS DAUGHTER', 1, 48, 9999, 4, 4, NULL, 891, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2083, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.194877+00', 'Farewell To Cleveland', 'FAREWELL TO CLEVELAND', 3, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2086, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.203159+00', 'Farewell To Finchampstead', 'FAREWELL TO FINCHAMPSTEAD', 1, 32, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2104, '2002-04-10 22:00:00+00', '2018-04-03 00:07:45.286719+00', 'Farewell to Wiston', 'FAREWELL TO WISTON', 2, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2106, '1997-10-27 23:00:00+00', '2018-04-03 00:07:45.311767+00', 'Farmer''s Jamboree', 'FARMERS JAMBOREE', 2, 32, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2107, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.328266+00', 'Farnborough Park', 'FARNBOROUGH PARK', 2, 32, 9999, 1, 3, 42, 145, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2111, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.361594+00', 'Father Kelly', 'FATHER KELLY', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3582, '1997-04-03 22:00:00+00', '2018-04-03 00:07:58.038861+00', 'Lads O'' Dunse', 'LADS O DUNSE', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3604, '2001-10-31 23:00:00+00', '2018-04-03 00:07:58.113817+00', 'Lady Elizabeth of Moy', 'LADY ELIZABETH OF MOY', 2, 40, 9999, 1, 3, 42, 353, '1979-01-01', '10 bar phrases', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3605, '1997-09-07 22:00:00+00', '2018-04-03 00:07:58.144547+00', 'Lady Friend', 'LADY FRIEND', 2, 32, 9999, 1, 3, 42, 837, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3606, '1997-09-07 22:00:00+00', '2018-04-03 00:07:58.249311+00', 'Lady George Murray''s Reel', 'LADY GEORGE MURRAYS REEL', 1, 32, 9999, 1, 3, 42, 984, '1785-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2114, '1998-07-08 22:00:00+00', '2012-01-20 12:56:16.8936+00', 'Feast Of Shells', 'FEAST OF SHELLS', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2115, '1997-04-03 22:00:00+00', '2012-01-20 12:56:16.900399+00', 'Feeste Roiall, A', 'FEESTE ROIALL', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2116, '1998-01-05 23:00:00+00', '2012-01-20 12:56:16.907359+00', 'Feet To The Fore', 'FEET TO THE FORE', 1, 32, 9999, 1, 4, NULL, 259, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2117, '2002-11-26 23:00:00+00', '2012-01-20 12:56:16.914365+00', 'Felix Fancy Free', 'FELIX FANCY FREE', 2, 32, 9999, 2, 3, NULL, 892, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2081, '1997-09-02 22:00:00+00', '2020-01-26 22:58:11.956843+00', 'Farewell To Balmerino', 'FAREWELL TO BALMERINO', 3, 32, 9999, 6, 98, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2075, '1997-04-03 22:00:00+00', '2020-10-21 09:57:37.195662+00', 'Far O''er the Sea', 'FAR OER THE SEA', 1, 48, 9999, 1, 3, 42, 270, NULL, '', 40, '800/880/633/633/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10781, '2002-08-06 22:00:00+00', '2021-02-05 12:40:26.67703+00', 'Dawn is Breaking', 'DAWN IS BREAKING', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 56, '800/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10767, '2002-07-24 22:00:00+00', '2020-09-12 23:00:29.586181+00', 'Broadway Strathspey', 'BROADWAY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 930, '1999-01-01', '', 56, '840/822/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2088, '1997-04-03 22:00:00+00', '2020-04-29 21:26:59.41501+00', 'Farewell to Gibraltar', 'FAREWELL TO GIBRALTAR', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3602, '1997-04-03 22:00:00+00', '2020-10-21 09:20:11.352529+00', 'Lady Eliza Lindsay', 'LADY ELIZA LINDSAY', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 44, '800/808/822/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3596, '1997-09-07 22:00:00+00', '2020-10-21 09:24:31.80951+00', 'Lady Charlotte Campbell''s Medley', 'LADY CHARLOTTE CAMPBELLS MEDLEY', 1, 48, 9999, 1, 3, 42, 270, NULL, '', 58, '800/888/866/888/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2108, '1997-04-05 22:00:00+00', '2020-10-21 09:55:16.382238+00', 'Farnie House', 'FARNIE HOUSE', 1, 32, 9999, 5, 56, 4, 270, NULL, '', 48, '484/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10770, '2002-09-25 22:00:00+00', '2021-02-06 11:07:45.118337+00', 'Come up to the Top', 'COME UP TO THE TOP', 2, 32, 9999, 1, 4, 13, 175, NULL, '', 44, '8044/8404/8000/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3589, '1998-09-29 22:00:00+00', '2021-05-18 10:56:12.849965+00', 'Lady Baird''s Reel', 'LADY BAIRDS REEL', 1, 32, 9999, 1, 3, 42, 432, NULL, '', 69, '888/880/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2118, '1997-04-03 22:00:00+00', '2021-05-29 18:18:20.449082+00', 'Fellowship', 'FELLOWSHIP', 1, 24, 9999, 1, 2, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2120, '2002-05-01 22:00:00+00', '2012-01-20 12:56:16.934753+00', 'Female Saylor, The', 'FEMALE SAYLOR', 2, 32, 9999, 1, 2, NULL, 9998, '1706-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2121, '1997-09-02 22:00:00+00', '2012-01-20 12:56:16.941893+00', 'Fencers'' Quadrille', 'FENCERS QUADRILLE', 10, 32, 9999, 4, 4, NULL, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2123, '1997-09-02 22:00:00+00', '2012-01-20 12:56:16.955556+00', 'Ferguson Reel, The', 'FERGUSON REEL', 1, 32, 9999, 2, 3, NULL, 894, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2112, '1997-04-03 22:00:00+00', '2012-08-10 14:22:46.451634+00', 'Father O'' Flynn', 'FATHER O FLYNN', 2, 48, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (567, '1997-08-25 22:00:00+00', '2019-03-02 22:20:39.386763+00', 'Blaven', 'BLAVEN', 3, 32, 9999, 1, 3, 42, 108, '1992-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2132, '1997-09-02 22:00:00+00', '2012-01-20 12:56:17.019276+00', 'Festival Of Roses, A', 'FESTIVAL OF ROSES', 3, 32, 9999, 1, 4, NULL, 595, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2133, '2002-04-19 22:00:00+00', '2012-01-20 12:56:17.026793+00', 'Festival, The', 'FESTIVAL', 3, 40, 9999, 1, 4, 2, 620, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2137, '1997-04-03 22:00:00+00', '2012-01-20 12:56:17.055108+00', 'Feurach Dearg', 'FEURACH DEARG', 2, 32, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3612, '2002-03-02 23:00:00+00', '2012-01-20 12:56:29.494632+00', 'Lady Jeanne''s Farewell to California', 'LADY JEANNES FAREWELL TO CALIFORNIA', 3, 32, 9999, 1, 4, NULL, 256, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2122, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.428563+00', 'Fergie''s Fancy', 'FERGIES FANCY', 1, 32, 9999, 1, 3, 42, 204, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2087, '1997-04-03 22:00:00+00', '2022-11-07 21:52:32.750051+00', 'Farewell to Fort George', 'FAREWELL TO FORT GEORGE', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2094, '2001-04-22 22:00:00+00', '2022-12-25 17:15:29.774254+00', 'Farewell to Redcastle', 'FAREWELL TO REDCASTLE', 1, 32, 9999, 1, 4, 11, 270, NULL, '', 94, '4884/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3610, '1998-10-07 22:00:00+00', '2023-01-26 19:11:26.414393+00', 'Lady in the Boat', 'LADY IN THE BOAT', 2, 64, 9999, 8, 6, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2103, '1997-09-02 22:00:00+00', '2023-02-09 11:38:56.281689+00', 'Farewell To The South', 'FAREWELL TO THE SOUTH', 2, 32, 9999, 1, 3, 42, 617, '1977-09-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18886, '2018-10-08 18:29:23.884514+00', '2023-01-31 09:48:46.839599+00', 'Snow Scene', 'SNOW SCENE', 3, 32, NULL, 1, 3, 42, 2766, '2015-02-01', 'Inspired by a heavy snow day with up to a foot of snow predicted.', 44, '800/844/844/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2095, '1997-09-01 22:00:00+00', '2023-02-09 11:44:17.124187+00', 'Farewell To Scotland', 'FAREWELL TO SCOTLAND', 3, 32, 9999, 1, 3, 42, 108, '1988-01-01', 'Inscribed "A dance to mark the Australian Bicentenary".', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10779, '2002-08-06 22:00:00+00', '2012-12-11 10:13:10.885151+00', '2000 A&D', '2000 AANDD', 3, 32, 9999, 3, 5, 10, 2986, '2000-01-01', 'The dance was devised for the 10th wedding anniversary of Agnes and Derrick Macmichael (West Lothian) in 2000. 



', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2127, '1997-09-02 22:00:00+00', '2018-04-03 00:07:45.470196+00', 'Ferry To Lismore, The', 'FERRY TO LISMORE', 1, 32, 9999, 1, 3, 42, 896, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2143, '1997-04-03 22:00:00+00', '2012-01-20 12:56:17.09685+00', 'Fiddler In The Yard', 'FIDDLER IN THE YARD', 2, 32, 9999, 1, 4, NULL, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2144, '1999-03-01 23:00:00+00', '2012-01-20 12:56:17.103695+00', 'Make New Friends', 'MAKE NEW FRIENDS', 1, 48, 9999, 3, 5, NULL, 683, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2152, '1997-09-02 22:00:00+00', '2012-01-20 12:56:17.159192+00', 'Fiddling Fraser Takes A Wife', 'FIDDLING FRASER TAKES A WIFE', 3, 32, 9999, 1, 4, NULL, 900, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2159, '1997-09-17 22:00:00+00', '2012-01-20 12:56:17.208451+00', 'Welcome to Wiston', 'WELCOME TO WISTON', 1, 32, 9999, 1, 4, NULL, 416, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2160, '1997-09-02 22:00:00+00', '2012-01-20 12:56:17.215958+00', 'Fifeshire Reel', 'FIFESHIRE REEL', 1, 32, 9999, 1, 4, 1, 901, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2164, '1997-10-14 22:00:00+00', '2012-01-20 12:56:17.243238+00', 'Fifty Pence Piece, The', 'FIFTY PENCE PIECE', 2, 40, 9999, 1, 4, NULL, 902, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2165, '1997-08-24 22:00:00+00', '2012-01-20 12:56:17.25073+00', '50 Years Th''gither', '50 YEARS THGITHER', 3, 32, 9999, 1, 4, 2, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3622, '1997-04-03 22:00:00+00', '2012-01-20 12:56:29.563382+00', 'Lady Mary Hay', 'LADY MARY HAY', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2113, '1997-09-02 22:00:00+00', '2016-07-15 05:17:27.092765+00', 'Father Time', 'FATHER TIME', 3, 24, 9999, 1, 4, 1, 352, '1993-06-15', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2131, '1997-09-02 22:00:00+00', '2018-04-03 00:07:45.478616+00', 'Festival Fancy, The', 'FESTIVAL FANCY', 1, 32, 9999, 1, 3, 42, 897, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2146, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.57021+00', 'Fiddler''s Fancy', 'FIDDLERS FANCY', 2, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2149, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.578612+00', 'Fiddler''s Joy', 'FIDDLERS JOY', 3, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3627, '1997-04-03 22:00:00+00', '2018-04-03 00:07:58.389042+00', 'Lady Moncrief''s Medley', 'LADY MONCRIEFS MEDLEY', 4, 40, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2142, '1997-09-14 22:00:00+00', '2018-04-03 00:08:16.085715+00', 'Shapinsay', 'SHAPINSAY', 3, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18689, '2018-10-02 09:21:06.338511+00', '2018-10-02 09:21:06.338511+00', 'Broken Sleep', 'BROKEN SLEEP', 2, 32, NULL, 1, 3, 42, 2766, '2010-02-01', 'I had a bad cold and trouble sleeping; I woke in the middle of the night with this dance in my head.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3630, '1997-04-03 22:00:00+00', '2012-01-20 12:56:29.619855+00', 'Lady of the House, The', 'LADY OF THE HOUSE', 3, 40, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2161, '1997-09-02 22:00:00+00', '2013-01-24 13:47:05.400821+00', 'Fifteen and Forty-five', 'FIFTEEN AND FORTYFIVE', 1, 32, 9999, 1, 100, 2, 108, '1978-01-01', '', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2208, '1997-09-29 22:00:00+00', '2019-02-22 22:26:26.921987+00', 'Five Penny Ness', 'FIVE PENNY NESS', 2, 32, 9999, 3, 5, 16, 13, NULL, '', 60, '88088/88888/08080/80000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2138, '1997-09-02 22:00:00+00', '2012-02-22 21:40:55.220085+00', 'Fhiona Martin''s Strathspey', 'FHIONA MARTINS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 898, '1986-01-01', '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10780, '2002-08-06 22:00:00+00', '2020-03-16 10:16:47.142099+00', 'Scotland for Ever', 'SCOTLAND FOR EVER', 3, 32, 9999, 1, 3, 42, 515, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2128, '1997-04-03 22:00:00+00', '2020-05-14 22:49:43.38971+00', 'Ferry to the Islands, The', 'FERRY TO THE ISLANDS', 3, 32, 9999, 1, 2, 76, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2151, '1997-12-21 23:00:00+00', '2020-08-30 09:54:08.307099+00', 'Fiddlers of Dunkeld, The', 'FIDDLERS OF DUNKELD', 3, 32, 9999, 1, 3, 42, 9, NULL, '', 44, '844/822/822/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2147, '1998-11-25 23:00:00+00', '2020-10-31 10:32:07.831794+00', 'Fiddler''s Fancy', 'FIDDLERS FANCY', 2, 32, 9999, 1, 4, 2, 13, NULL, '', 75, '6666/6666/8888/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3619, '1997-09-07 22:00:00+00', '2020-11-07 12:55:22.043563+00', 'Lady Madelaine Sinclair', 'LADY MADELAINE SINCLAIR', 3, 32, 9999, 4, 4, 30, 270, NULL, '', 92, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10783, '2002-08-06 22:00:00+00', '2021-02-05 12:35:50.468676+00', 'Red Rose of Lancaster II, The', 'RED ROSE OF LANCASTER II', 3, 64, 9999, 7, 5, NULL, 534, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10782, '2002-11-11 23:00:00+00', '2021-02-05 12:38:36.043334+00', 'Reel Good Time', 'REEL GOOD TIME', 1, 32, 9999, 1, 3, 42, 3183, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10778, '2002-10-13 22:00:00+00', '2021-02-05 12:44:28.647807+00', 'Tribute to Patsy Rennie, A', 'TRIBUTE TO PATSY RENNIE', 4, 128, 2, 4, 4, 3, 2990, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2134, '1997-09-02 22:00:00+00', '2021-03-10 15:31:34.287573+00', 'Fete Champetre', 'FETE CHAMPETRE', 2, 32, 9999, 1, 3, 42, 466, '1780-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2162, '1997-04-03 22:00:00+00', '2021-06-08 12:41:08.28904+00', 'Fifty And A'' That', 'FIFTY AND A THAT', 2, 32, 9999, 1, 3, 42, 413, NULL, 'For Bob and Nancy Eakins on their Golden Wedding Anniversary, 1979.', 44, '880/880/800/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2130, '1997-11-23 23:00:00+00', '2021-06-08 21:14:54.927394+00', 'Feshiebridge', 'FESHIEBRIDGE', 3, 32, 9999, 1, 2, 76, 275, '1962-01-01', 'Devised by Gary Morris while in Edinburgh in 1962.', 58, '84/88/88/82', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3629, '1997-04-03 22:00:00+00', '2021-11-17 12:05:32.252676+00', 'Lady of Fettercairn', 'LADY OF FETTERCAIRN', 3, 32, 9999, 1, 4, 1, 352, '1991-07-26', '', 94, '8668/8888/8888/4888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2176, '1997-04-03 22:00:00+00', '2012-01-20 12:56:17.353159+00', 'Fintry Hills, The', 'FINTRY HILLS', 3, 64, 9999, 1, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2178, '1998-11-25 23:00:00+00', '2012-01-20 12:56:17.370558+00', 'Fiona''s Fancy', 'FIONAS FANCY', 2, 32, 9999, 3, 5, NULL, 175, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2206, '1997-04-03 22:00:00+00', '2018-04-02 23:56:34.583671+00', 'Five Horse Brake', 'FIVE HORSE BRAKE', 1, 32, 9999, 1, 3, 42, 352, '1993-04-22', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2181, '1997-04-03 22:00:00+00', '2012-01-20 12:56:17.396596+00', 'Fiona''s Fancy', 'FIONAS FANCY', 3, 32, 9999, 1, 2, NULL, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10786, '2002-10-20 22:00:00+00', '2018-04-03 00:07:31.98875+00', 'Baldyquash', 'BALDYQUASH', 1, 32, 9999, 1, 3, 42, 108, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2167, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.820529+00', 'Files Of Eugene, The', 'FILES OF EUGENE', 2, 32, 9999, 1, 3, 42, 361, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2184, '1997-09-02 22:00:00+00', '2012-01-20 12:56:17.417495+00', 'Fire Hose Reel', 'FIRE HOSE REEL', 1, 32, 9999, 1, 4, NULL, 904, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2185, '1997-09-02 22:00:00+00', '2012-01-20 12:56:17.424267+00', 'Fire In Summer', 'FIRE IN SUMMER', 3, 40, 9999, 1, 2, NULL, 905, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2190, '1998-04-12 22:00:00+00', '2012-01-20 12:56:17.458355+00', 'All Shipshape on Sirius', 'ALL SHIPSHAPE ON SIRIUS', 1, 128, 9999, 4, 4, NULL, 325, NULL, 'Official alias: The First Fleet Hornpipe', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2194, '1997-09-02 22:00:00+00', '2012-01-20 12:56:17.485624+00', 'First of May, The', 'FIRST OF MAY', 1, 32, 9999, 4, 4, NULL, 761, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3639, '1997-09-07 22:00:00+00', '2012-01-20 12:56:29.683857+00', 'Lady Valentine''s Jig', 'LADY VALENTINES JIG', 2, 32, 9999, 1, 4, NULL, 1052, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3641, '2003-04-03 22:00:00+00', '2012-01-20 12:56:29.69788+00', 'Failte gu Eilean Dubh', 'FAILTE GU EILEAN DUBH', 4, 64, 5, 1, 4, NULL, 2408, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3644, '1997-04-03 22:00:00+00', '2012-01-20 12:56:29.718611+00', 'Lager Beer', 'LAGER BEER', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2252, '1997-09-02 22:00:00+00', '2012-01-20 12:56:17.898234+00', 'Flowers of Spring', 'FLOWERS OF SPRING', 2, 64, 9999, 1, 4, NULL, 912, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2139, '1998-07-08 22:00:00+00', '2022-08-18 19:44:56.912234+00', 'Fickle Lass, The', 'FICKLE LASS', 3, 32, 9999, 1, 100, 2, 313, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2155, '1997-07-04 22:00:00+00', '2022-11-07 19:07:48.801416+00', 'Fife And Forfar', 'FIFE AND FORFAR', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3618, '1997-04-03 22:00:00+00', '2022-11-07 21:59:50.887668+00', 'Lady Mackenzie of Coul', 'LADY MACKENZIE OF COUL', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2145, '1997-09-02 22:00:00+00', '2023-01-26 19:11:42.510214+00', 'Fiddler Play the Light Strathspey', 'FIDDLER PLAY THE LIGHT STRATHSPEY', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2154, '1998-10-21 22:00:00+00', '2022-12-18 22:43:11.182939+00', 'Fiery Cross, The', 'FIERY CROSS', 1, 64, 9999, 1, 4, NULL, 44, '1967-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2124, '2000-04-25 22:00:00+00', '2023-02-09 11:33:11.684782+00', 'Fergusson Strathspey', 'FERGUSSON STRATHSPEY', 3, 32, 9999, 1, 3, 42, 577, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10796, '2002-08-26 22:00:00+00', '2012-10-31 23:33:21.263639+00', 'Highland Welcome in Switzerland, A', 'HIGHLAND WELCOME IN SWITZERLAND', 3, 64, 9999, 4, 4, NULL, 38, '1995-01-01', 'Devised in January 1995 for Minnie Bänninger', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2174, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.879+00', 'Finlayson Night', 'FINLAYSON NIGHT', 3, 32, 9999, 1, 3, 42, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2197, '1997-04-03 22:00:00+00', '2012-01-20 12:56:17.506147+00', 'Firth of Clyde', 'FIRTH OF CLYDE', 3, 32, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2198, '1997-09-02 22:00:00+00', '2012-01-20 12:56:17.513351+00', 'Firth of Forth', 'FIRTH OF FORTH', 1, 128, 9999, 4, 4, NULL, 81, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2200, '1997-04-03 22:00:00+00', '2012-01-20 12:56:17.528043+00', 'Fisher''s Hornpipe', 'FISHERS HORNPIPE', 1, 80, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2202, '1997-04-03 22:00:00+00', '2012-01-20 12:56:17.541787+00', 'Fisherman Of Eyemouth', 'FISHERMAN OF EYEMOUTH', 1, 32, 9999, 1, 2, NULL, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2204, '1998-07-09 22:00:00+00', '2012-01-20 12:56:17.558874+00', 'Fishing Reel', 'FISHING REEL', 1, 32, 9999, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2175, '1997-09-11 22:00:00+00', '2018-04-03 00:07:45.895721+00', 'Finn''s Fancy', 'FINNS FANCY', 1, 40, 9999, 1, 3, 42, 31, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2207, '1997-04-03 22:00:00+00', '2012-01-20 12:56:17.579339+00', 'Five Lums, The', 'FIVE LUMS', 1, 32, 9999, 3, 5, NULL, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2210, '1997-09-02 22:00:00+00', '2012-01-20 12:56:17.599736+00', 'Five Sisters Of Kintail, The', 'FIVE SISTERS OF KINTAIL', 1, 32, 9999, 3, 5, NULL, 617, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2187, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.920717+00', 'Firecross Song', 'FIRECROSS SONG', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2188, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.929002+00', 'Fireship', 'FIRESHIP', 1, 88, 9999, 1, 3, 42, 392, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2191, '1997-04-03 22:00:00+00', '2018-04-03 00:07:45.954057+00', 'First Footing', 'FIRST FOOTING', 2, 32, 9999, 1, 3, 42, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2193, '1997-09-17 22:00:00+00', '2018-04-03 00:07:45.962335+00', 'First of January', 'FIRST OF JANUARY', 3, 32, 9999, 1, 3, 42, 288, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2201, '1997-09-02 22:00:00+00', '2018-04-03 00:07:46.020787+00', 'Fishers of Buckie, The', 'FISHERS OF BUCKIE', 1, 32, 9999, 1, 3, 42, 108, '1971-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2209, '1998-10-19 22:00:00+00', '2018-04-03 00:07:46.062428+00', 'Five Row Reel, The', 'FIVE ROW REEL', 1, 32, 9999, 1, 3, 42, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3633, '1997-09-07 22:00:00+00', '2018-04-03 00:07:58.430761+00', 'Lady Pentweazle', 'LADY PENTWEAZLE', 3, 32, 9999, 1, 3, 42, 397, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3640, '2002-06-30 22:00:00+00', '2018-04-03 00:07:58.505738+00', 'Lady Victoria Reel, The', 'LADY VICTORIA REEL', 1, 32, 9999, 1, 3, 42, 27, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3643, '1998-01-05 23:00:00+00', '2018-04-03 00:07:58.522444+00', 'Lafayette Welcome, The', 'LAFAYETTE WELCOME', 1, 32, 9999, 1, 3, 42, 1053, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10785, '2002-08-07 22:00:00+00', '2018-04-03 00:07:59.890331+00', 'Lloyd Melhuish''s 75th Birthday Jig', 'LLOYD MELHUISHS 75TH BIRTHDAY JIG', 2, 32, 9999, 1, 3, 42, 3184, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3658, '1998-01-05 23:00:00+00', '2018-04-29 10:44:41.953728+00', 'Laird of McNab, The', 'LAIRD OF MACNAB', 1, 48, 9999, 3, 5, NULL, 1056, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2213, '1997-12-22 23:00:00+00', '2012-01-20 12:56:17.620301+00', 'Flag Of Scotland, The', 'FLAG OF SCOTLAND', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2214, '1997-11-25 23:00:00+00', '2012-01-20 12:56:17.627384+00', 'Flag Of Saint Andrew, The', 'FLAG OF SAINT ANDREW', 4, 64, 22, 1, 4, NULL, 559, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2215, '1997-04-03 22:00:00+00', '2012-01-20 12:56:17.63422+00', 'Flanagan''s Reel', 'FLANAGANS REEL', 1, 40, 9999, 1, 4, NULL, 213, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2216, '1997-11-25 23:00:00+00', '2012-01-20 12:56:17.641725+00', 'Flannigan''s Reel', 'FLANNIGANS REEL', 4, 128, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2217, '1998-07-08 22:00:00+00', '2012-01-20 12:56:17.648644+00', 'Fleet Ladies', 'FLEET LADIES', 4, 128, 2, 4, 4, NULL, 145, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2219, '1997-09-02 22:00:00+00', '2012-01-20 12:56:17.66294+00', 'Fleur de Lys', 'FLEUR DE LYS', 1, 32, 9999, 1, 3, 42, 101, NULL, 'Official Alias: The Laurentian Reel', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2233, '1997-04-03 22:00:00+00', '2018-05-17 09:21:36.316379+00', 'Flitting of Lorn, The', 'FLITTING OF LORN', 1, 32, 9999, 1, 4, 2, 13, NULL, '', 81, '8008/8888/8888/8448', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2180, '1998-01-05 23:00:00+00', '2020-08-04 01:03:25.433197+00', 'Fiona''s Fancy', 'FIONAS FANCY', 1, 32, 9999, 1, 4, 1, 151, NULL, '', 63, '8888/0800/8888/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2232, '1997-09-06 22:00:00+00', '2020-08-04 05:53:29.211989+00', 'Flitting', 'FLITTING', 2, 48, 9999, 1, 4, 1, 129, '1966-01-01', '', 67, '7000/8700/8878/7778/2626/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2205, '1997-04-03 22:00:00+00', '2021-04-12 20:54:21.122928+00', 'Five Arrows', 'FIVE ARROWS', 1, 48, 9999, 3, 3, 17, 418, NULL, '', 37, '488/488/800/844/844/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2171, '2002-03-11 23:00:00+00', '2021-06-08 09:38:58.487566+00', 'Fine Fettle', 'FINE FETTLE', 2, 48, 9999, 1, 3, 42, 167, '1976-01-01', '', 45, '800/822/844/822/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3645, '1997-04-03 22:00:00+00', '2021-05-17 22:42:21.497139+00', 'Laggan Bay', 'LAGGAN BAY', 2, 32, 9999, 1, 3, 42, 127, NULL, 'Devised for Eileen Stuart and Neil Oxlade on the occasion oftheir wedding. Laggan Bay on the Isle of Islay is Eileen and Neil''s favourite camping holiday place.', 59, '844/888/844/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2189, '1998-11-14 23:00:00+00', '2021-06-08 09:16:43.678386+00', 'Fireside Reel, The', 'FIRESIDE REEL', 1, 32, 9999, 1, 3, 42, 9998, '1740-01-01', 'Described as for a 4 (or 5) couple set.', 43, '430/840/880/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2225, '1997-04-03 22:00:00+00', '2012-01-20 12:56:17.707501+00', 'Flinder''s Fling', 'FLINDERS FLING', 1, 32, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18690, '2018-10-02 09:26:26.959935+00', '2018-10-02 09:39:44.746116+00', 'Broken Symmetry', 'BROKEN SYMMETRY', 3, 32, NULL, 2, 3, 17, 2766, '2009-06-01', '', 50, '440/880/404/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3648, '1997-09-07 22:00:00+00', '2012-01-20 12:56:29.746179+00', 'Lagos Caledonian Society, The', 'LAGOS CALEDONIAN SOCIETY', 2, 32, 9999, 1, 2, NULL, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18691, '2018-10-02 11:40:41.530916+00', '2018-10-02 11:40:41.530916+00', 'Bubble Up Lake', 'BUBBLE UP LAKE', 3, 32, NULL, 1, 3, 42, 2766, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3655, '1997-09-07 22:00:00+00', '2012-01-20 12:56:29.796797+00', 'Laird of Berryhill, The', 'LAIRD OF BERRYHILL', 3, 128, 9999, 6, 3, NULL, 1055, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10801, '2002-08-29 22:00:00+00', '2012-01-20 12:57:24.090902+00', 'Easy Peasy', 'EASY PEASY', 3, 32, 9999, 1, 4, NULL, 2982, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2218, '1997-09-02 22:00:00+00', '2018-04-03 00:07:46.07907+00', 'Fleming Link, The', 'FLEMING LINK', 2, 32, 9999, 1, 3, 42, 907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2220, '1997-04-03 22:00:00+00', '2018-04-03 00:07:46.087566+00', 'Flibbertigibbet', 'FLIBBERTIGIBBET', 1, 32, 9999, 1, 3, 42, 329, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2221, '1997-04-03 22:00:00+00', '2018-04-03 00:07:46.095954+00', 'Flight of the Bumblebee, The', 'FLIGHT OF THE BUMBLEBEE', 1, 32, 9999, 1, 3, 42, 44, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2240, '1997-04-03 22:00:00+00', '2012-01-20 12:56:17.813896+00', 'Flora Macdonald''s Strathspey', 'FLORA MACDONALDS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2241, '1997-09-02 22:00:00+00', '2012-01-20 12:56:17.820682+00', 'Flower Baskets', 'FLOWER BASKETS', 2, 32, 9999, 4, 4, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2243, '1997-10-27 23:00:00+00', '2012-01-20 12:56:17.835158+00', 'Flower of Auchattie, The', 'FLOWER OF AUCHATTIE', 2, 32, 9999, 1, 4, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2224, '1998-04-12 22:00:00+00', '2018-04-03 00:07:46.120885+00', 'Flight over Fraser Island', 'FLIGHT OVER FRASER ISLAND', 1, 32, 9999, 1, 3, 42, 108, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2248, '1997-09-02 22:00:00+00', '2012-01-20 12:56:17.87018+00', 'Flower Pot Rocks', 'FLOWER POT ROCKS', 1, 32, 9999, 1, 4, NULL, 90, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2249, '1998-07-08 22:00:00+00', '2012-01-20 12:56:17.87764+00', 'Flower Strathspey, The', 'FLOWER STRATHSPEY', 3, 32, 9999, 1, 4, 11, 913, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3642, '1997-11-18 23:00:00+00', '2022-12-10 20:00:56.922909+00', 'Lady''s Breist Knot, The', 'LADYS BREIST KNOT', 3, 16, 9999, 1, 3, 42, 9998, '1754-01-02', 'The notes say "the Lady''s Breist Knot is a Wedding Favour."', 44, '642/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2195, '1997-09-02 22:00:00+00', '2023-01-11 22:21:36.132598+00', 'Firth Jig, The', 'FIRTH JIG', 2, 48, 9999, 4, 6, NULL, 270, NULL, '', 61, '000088/080888/444488/808088/080888/808088', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3670, '1997-04-03 22:00:00+00', '2012-01-20 12:56:29.904494+00', 'Lakeside Reel', 'LAKESIDE REEL', 1, 96, 9999, 1, 4, NULL, 261, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3673, '1997-04-03 22:00:00+00', '2012-01-20 12:56:29.928479+00', 'Lambing Chair, The', 'LAMBING CHAIR', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2231, '1997-09-02 22:00:00+00', '2015-10-29 20:32:59.493027+00', 'Flirting Dance, The', 'FLIRTING DANCE', 1, 32, 9999, 4, 4, NULL, 911, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2239, '1998-12-19 23:00:00+00', '2016-05-10 22:26:25.355414+00', 'Flora Macdonald''s Fancy', 'FLORA MACDONALDS FANCY', 7, 8, 9999, 107, 51, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2246, '1997-04-03 22:00:00+00', '2017-10-03 10:50:35.283809+00', 'Flower of the Sea, The', 'FLOWER OF THE SEA', 3, 32, 9999, 1, 3, 42, 44, '1981-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2234, '1998-01-05 23:00:00+00', '2018-04-03 00:07:46.162458+00', 'Flitting, The', 'FLITTING', 1, 32, 9999, 1, 3, 42, 488, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3647, '2000-06-12 22:00:00+00', '2018-04-03 00:07:58.539145+00', 'Laggan, The', 'LAGGAN', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3657, '1997-09-07 22:00:00+00', '2018-04-03 00:07:58.555948+00', 'Laird of Garth''s Strathspey', 'LAIRD OF GARTHS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3652, '1999-08-06 22:00:00+00', '2018-04-03 00:07:58.580823+00', 'Laird o'' the Land, The', 'LAIRD O THE LAND', 2, 32, 9999, 1, 3, 42, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3661, '1997-12-22 23:00:00+00', '2018-04-03 00:07:58.589298+00', 'Laird''s Lug, The', 'LAIRDS LUG', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3663, '1997-09-07 22:00:00+00', '2018-04-03 00:07:58.597573+00', 'Laird''s Reel, The', 'LAIRDS REEL', 1, 40, 9999, 1, 3, 42, 1057, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3668, '1997-04-03 22:00:00+00', '2018-04-03 00:07:58.639186+00', 'Lake Road', 'LAKE ROAD', 3, 32, 9999, 1, 3, 42, 108, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3671, '1997-04-03 22:00:00+00', '2018-04-03 00:07:58.664205+00', 'Lakeside Strathspey, The', 'LAKESIDE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10806, '2002-09-08 22:00:00+00', '2012-01-20 12:57:24.129653+00', 'Miss Catherine Linnen''s Jig', 'MISS CATHERINE LINNENS JIG', 2, 32, 9999, 1, 4, NULL, 173, '1971-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10807, '2002-09-08 22:00:00+00', '2012-01-20 12:57:24.137285+00', 'Small Strathspey, The', 'SMALL STRATHSPEY', 3, 32, 9999, 2, 3, NULL, 173, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10808, '2002-09-08 22:00:00+00', '2012-01-20 12:57:24.144242+00', 'Jimmy Russell', 'JIMMY RUSSELL', 2, 32, 9999, 1, 4, NULL, 173, '1985-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2270, '1998-07-08 22:00:00+00', '2018-12-03 22:44:48.165895+00', 'Follow The Fiddler', 'FOLLOW THE FIDDLER', 1, 32, 9999, 1, 4, 2, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10810, '2002-09-08 22:00:00+00', '2012-01-20 12:57:24.157963+00', 'Newmain Jig, The', 'NEWMAIN JIG', 2, 32, 9999, 1, 2, NULL, 173, '1968-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10256, '2001-11-25 23:00:00+00', '2019-01-24 13:28:53.639678+00', 'Butter Churn, The', 'BUTTER CHURN', 1, 32, 9999, 1, 3, 42, 2766, '2001-04-01', 'This dance was inspired by dancing Barry Skelton''s dance *The Celtic Reel*.', 50, '800  888  844  844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (2256, '1997-04-03 22:00:00+00', '2012-01-20 12:56:17.927676+00', 'Fluffy Feathers', 'FLUFFY FEATHERS', 1, 24, 9999, 1, 2, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2261, '1997-09-03 22:00:00+00', '2012-01-20 12:56:17.963656+00', 'Happy Birthday', 'HAPPY BIRTHDAY', 3, 32, 9999, 1, 4, NULL, 329, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2262, '1997-09-02 22:00:00+00', '2012-01-20 12:56:17.970455+00', 'Flying Scotswomen, The', 'FLYING SCOTSWOMEN', 1, 48, 9999, 3, 5, NULL, 914, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3653, '1999-08-06 22:00:00+00', '2020-08-06 15:31:24.348984+00', 'Laird o'' Thrums, The', 'LAIRD O THRUMS', 3, 32, 9999, 1, 4, 1, 129, '1970-01-01', '', 75, '8888/8484/8000/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3660, '1997-04-03 22:00:00+00', '2021-05-16 17:58:27.222138+00', 'Laird of Oxgangs, The', 'LAIRD OF OXGANGS', 2, 32, 9999, 1, 2, 76, 94, NULL, '', 60, '44/88/88/88', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2227, '1997-10-22 22:00:00+00', '2020-08-14 21:14:43.433428+00', 'Lady Sophia Anne of Bute Strathspey', 'LADY SOPHIA ANNE OF BUTE STRATHSPEY', 3, 48, 9999, 1, 4, 1, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3667, '1997-04-03 22:00:00+00', '2020-08-31 13:50:03.606642+00', 'Lake Of Menteith', 'LAKE OF MENTEITH', 1, 32, 9999, 1, 3, 42, 347, NULL, '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10804, '2002-11-19 23:00:00+00', '2021-08-02 09:09:47.424851+00', 'Avalon Waltz, The', 'AVALON WALTZ', 5, 16, 9999, 7, 1, NULL, 452, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3664, '1998-07-08 22:00:00+00', '2020-12-15 11:24:33.878788+00', 'Lairds of Coll, The', 'LAIRDS OF COLL', 2, 32, 9999, 1, 100, 2, 13, NULL, '', 88, '8888/8008/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2253, '2002-10-15 22:00:00+00', '2021-06-07 10:06:09.66514+00', 'Flowers of Sydney', 'FLOWERS OF SYDNEY', 3, 32, 9999, 2, 3, 17, 325, '1990-01-01', 'Devised for all the long time dancers of Sydney, some of whom can no longer participate as actively as they would like.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2251, '2001-09-13 22:00:00+00', '2021-06-07 10:09:58.787491+00', 'Flowers of Scotland', 'FLOWERS OF SCOTLAND', 2, 24, 9999, 1, 2, 76, 863, '1982-01-01', 'The notes say this is an audience participation dance and may be danced as either jig or reel. Collected from an audience participation event Sheena led at Holy Names College when she was a student there.', 46, '88/80/80', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2237, '1998-07-09 22:00:00+00', '2021-06-07 10:30:40.009757+00', 'Flodigarry Strathspey', 'FLODIGARRY STRATHSPEY', 3, 40, 9999, 2, 3, 17, 15, '1993-01-01', '', 77, '800/866/888/808/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10803, '2002-09-01 22:00:00+00', '2021-08-02 08:56:27.651508+00', 'Richmond Two-Step, The', 'RICHMOND TWOSTEP', 11, 32, 9999, 5, 2, NULL, 452, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10802, '2002-09-01 22:00:00+00', '2021-08-02 09:02:15.444287+00', 'On the Wallaby Track', 'ON THE WALLABY TRACK', 1, 32, 9999, 1, 3, 42, 452, '2002-01-01', '', 31, '620/440/880/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2266, '1997-04-03 22:00:00+00', '2012-01-20 12:56:17.997828+00', 'Follow Me', 'FOLLOW ME', 2, 32, 9999, 1, 2, NULL, 213, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2299, '1998-01-05 23:00:00+00', '2012-01-20 12:56:18.232321+00', 'Forth at Royal Stirling', 'FORTH AT ROYAL STIRLING', 1, 48, 9999, 1, 4, NULL, 919, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2281, '1998-04-12 22:00:00+00', '2019-07-27 16:43:30.612884+00', 'Forest Of Fangorn, The', 'FOREST OF FANGORN', 3, 32, 9999, 1, 3, 42, 44, '1990-01-01', '', 66, '880/888/888/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2274, '1997-09-02 22:00:00+00', '2012-01-20 12:56:18.055614+00', 'Footdee Reel', 'FOOTDEE REEL', 2, 32, 9999, 1, 4, NULL, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2279, '1997-09-02 22:00:00+00', '2012-01-20 12:56:18.093096+00', 'Forbes Reel', 'FORBES REEL', 1, 24, 9999, 1, 4, NULL, 918, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2282, '1997-04-03 22:00:00+00', '2012-01-20 12:56:18.113875+00', 'Forest Prince, The', 'FOREST PRINCE', 2, 32, 9999, 1, 2, NULL, 44, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3674, '2002-03-02 23:00:00+00', '2012-01-20 12:56:29.936042+00', 'Lament for the Children, The', 'LAMENT FOR THE CHILDREN', 3, 32, 9999, 1, 4, 2, 35, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3675, '1997-04-03 22:00:00+00', '2012-01-20 12:56:29.944482+00', 'Lammas Fair, The', 'LAMMAS FAIR', 1, 80, 9999, 4, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3676, '1997-09-07 22:00:00+00', '2012-01-20 12:56:29.951362+00', 'Lammas Market, The', 'LAMMAS MARKET', 3, 32, 9999, 1, 4, NULL, 1059, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3683, '1997-09-07 22:00:00+00', '2012-01-20 12:56:29.999804+00', 'Lancaster Lasses', 'LANCASTER LASSES', 2, 32, 9999, 1, 2, NULL, 446, '1727-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10811, '2002-09-08 22:00:00+00', '2012-01-20 12:57:24.164833+00', 'Miss Flowerie Brown', 'MISS FLOWERIE BROWN', 3, 32, 9999, 1, 4, NULL, 173, '1962-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10812, '2002-09-08 22:00:00+00', '2012-01-20 12:57:24.17174+00', 'Bella Brown', 'BELLA BROWN', 3, 32, 9999, 1, 4, NULL, 173, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10814, '2002-09-08 22:00:00+00', '2012-01-20 12:57:24.185526+00', 'Kirrie Kebbuck, The', 'KIRRIE KEBBUCK', 3, 32, 9999, 1, 4, NULL, 173, '1967-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10815, '2002-09-08 22:00:00+00', '2012-01-20 12:57:24.192409+00', 'Black Bear Country Dance, The', 'BLACK BEAR COUNTRY DANCE', 1, 32, 9999, 1, 4, NULL, 173, '1962-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10816, '2002-09-08 22:00:00+00', '2012-01-20 12:57:24.199265+00', 'North of the Grampians', 'NORTH OF THE GRAMPIANS', 1, 32, 9999, 4, 4, NULL, 173, '1965-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2283, '1997-04-03 22:00:00+00', '2012-01-20 12:56:18.12068+00', 'Forester, The', 'FORESTER', 2, 32, 9999, 1, 2, NULL, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2290, '1997-04-03 22:00:00+00', '2018-04-02 23:56:34.675485+00', 'Fort Gautley', 'FORT GAUTLEY', 1, 32, 9999, 1, 3, 42, 352, '1993-04-23', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10813, '2002-09-08 22:00:00+00', '2018-04-03 00:07:45.161461+00', 'Farewell - farewell', 'FAREWELL  FAREWELL', 3, 32, 9999, 1, 3, 42, 173, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2293, '1997-09-28 22:00:00+00', '2012-01-20 12:56:18.189959+00', 'Fort Worden Reel', 'FORT WORDEN REEL', 2, 48, 9999, 6, 3, NULL, 923, '1980-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2280, '1997-09-02 22:00:00+00', '2018-04-03 00:07:46.479568+00', 'Fordell Wattie, The', 'FORDELL WATTIE', 2, 32, 9999, 1, 3, 42, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2264, '1997-09-02 22:00:00+00', '2018-04-03 00:07:46.404615+00', 'Fog In Summer', 'FOG IN SUMMER', 3, 40, 9999, 1, 3, 42, 915, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2265, '1997-08-25 22:00:00+00', '2018-04-03 00:07:46.412898+00', 'Folla Rule', 'FOLLA RULE', 3, 32, 9999, 1, 3, 42, 108, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2272, '1997-04-03 22:00:00+00', '2018-04-03 00:07:46.437963+00', 'Fond Farewell, A', 'FOND FAREWELL', 2, 32, 9999, 1, 3, 42, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2273, '1997-04-03 22:00:00+00', '2018-04-03 00:07:46.446248+00', 'Fond Memories', 'FOND MEMORIES', 2, 32, 9999, 1, 3, 42, 43, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2285, '1997-04-03 22:00:00+00', '2018-04-03 00:07:46.504633+00', 'Forfar Fun', 'FORFAR FUN', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2286, '1997-04-03 22:00:00+00', '2018-04-03 00:07:46.512938+00', 'Forgan Bank', 'FORGAN BANK', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2287, '1997-04-03 22:00:00+00', '2018-04-03 00:07:46.521212+00', 'Forget Me Not', 'FORGET ME NOT', 2, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10805, '2002-09-08 22:00:00+00', '2018-04-03 00:07:53.010027+00', 'Howick Strathspey, The', 'HOWICK STRATHSPEY', 3, 32, 9999, 1, 3, 42, 173, '1987-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3682, '1997-04-03 22:00:00+00', '2018-04-03 00:07:58.705943+00', 'Lamplighter''s Hornpipe, The', 'LAMPLIGHTERS HORNPIPE', 1, 32, 9999, 1, 3, 42, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3686, '1997-09-07 22:00:00+00', '2018-04-03 00:07:58.747588+00', 'Land O'' Dances', 'LAND O DANCES', 1, 32, 9999, 1, 3, 42, 70, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10809, '2002-09-08 22:00:00+00', '2018-04-03 00:08:05.669536+00', 'Mr Iain Boyd', 'MR IAIN BOYD', 3, 32, 9999, 1, 3, 42, 173, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2310, '2003-01-25 23:00:00+00', '2018-04-26 21:42:51.411133+00', 'Four Kelleys, The', 'FOUR KELLEYS', 3, 32, 9999, 1, 2, NULL, 35, '1980-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18637, '2018-09-18 21:07:00.627924+00', '2018-09-18 22:01:01.632126+00', 'Lieberman''s Ceilidh', 'LIEBERMANS CEILIDH', 1, 32, NULL, 1, 3, NULL, 11710, '2012-01-01', 'To Linda and Gary Lieberman in appreciation of their musicianship, teaching (Linda), generosity in hosting the annual after-Ball party, and occasional service as ceilidh masters.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2304, '2003-01-29 23:00:00+00', '2012-01-20 12:56:18.269251+00', 'Fountain Hills', 'FOUNTAIN HILLS', 1, 32, 9999, 4, 4, 13, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2307, '1997-10-27 23:00:00+00', '2012-01-20 12:56:18.291955+00', 'Four Counts, The', 'FOUR COUNTS', 1, 48, 9999, 1, 4, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2309, '1997-09-02 22:00:00+00', '2012-01-20 12:56:18.306099+00', 'Four Jays, The', 'FOUR JAYS', 1, 32, 9999, 1, 4, NULL, 617, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2301, '1997-09-02 22:00:00+00', '2019-02-22 22:33:41.025262+00', 'Fortypence Wood', 'FORTYPENCE WOOD', 1, 32, 9999, 1, 4, 2, 924, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3708, '1997-08-25 22:00:00+00', '2019-02-26 23:54:07.934801+00', 'Laphroaig', 'LAPHROAIG', 3, 32, 9999, 1, 4, 1, 538, '1977-01-01', '', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2276, '1997-04-03 22:00:00+00', '2020-08-04 05:54:13.711204+00', 'For Lack of Gold', 'FOR LACK OF GOLD', 1, 32, 9999, 1, 3, 42, 129, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2300, '1997-09-02 22:00:00+00', '2020-08-04 05:55:06.176414+00', 'Fortnight At Saint Andrews', 'FORTNIGHT AT SAINT ANDREWS', 3, 32, 9999, 1, 3, 42, 921, '1967-01-01', '', 62, '844/844/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2305, '1997-09-06 22:00:00+00', '2020-08-04 05:56:08.84271+00', 'Fountain, The', 'FOUNTAIN', 2, 32, 9999, 1, 4, 1, 129, '1966-01-01', '', 84, '8642/8888/8888/8484', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2271, '1997-04-03 22:00:00+00', '2020-08-30 10:05:53.332765+00', 'Following The Deer', 'FOLLOWING THE DEER', 1, 32, 9999, 1, 3, 42, 300, NULL, '', 43, '800/833/888/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3706, '1997-09-07 22:00:00+00', '2021-05-16 10:57:20.947789+00', 'Lanterns Of London', 'LANTERNS OF LONDON', 3, 32, 9999, 1, 4, 1, 896, '1973-03-01', 'According to the notes for the dance the inspiration came from the March 1973 London Workshop. A blizzard caused a power failure and a demonstration was performed with each dancer carrying a candle lantern.', 78, '6666/8888/6222/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2295, '1997-09-02 22:00:00+00', '2021-06-06 21:54:43.708641+00', 'Forth Bridge, The', 'FORTH BRIDGE', 1, 32, 9999, 1, 4, 1, 920, NULL, '', 44, '8440/8004/0808/8040', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2288, '1997-04-03 22:00:00+00', '2021-06-07 08:18:39.011546+00', 'Forres Fancy, A', 'FORRES FANCY', 3, 32, 9999, 1, 3, 42, 108, '1968-01-01', '', 66, '880/888/888/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2278, '1997-08-19 22:00:00+00', '2021-06-07 08:23:36.554348+00', 'Forbes Rant', 'FORBES RANT', 2, 32, 9999, 1, 3, 42, 104, '1991-09-01', '', 63, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2275, '1997-08-30 22:00:00+00', '2021-06-07 08:27:19.649061+00', 'For All the Ladies', 'FOR ALL THE LADIES', 3, 32, 9999, 1, 3, 42, 21, '1988-03-01', 'In memory of Frank Tranter, March 1988.', 75, '888/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2258, '1998-01-05 23:00:00+00', '2021-06-07 08:39:37.525049+00', 'Flying Cloud', 'FLYING CLOUD', 1, 32, 9999, 2, 3, 17, 23, NULL, '', 63, '800/800/888/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2255, '1998-04-21 22:00:00+00', '2021-06-21 10:48:38.469575+00', 'Flower on The Hill, The', 'FLOWER ON THE HILL', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3694, '1997-04-03 22:00:00+00', '2012-01-20 12:56:30.076264+00', 'Landlady Of Inver Inn, The', 'LANDLADY OF INVER INN', 1, 32, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2329, '1997-12-21 23:00:00+00', '2019-03-17 11:23:54.647409+00', 'Fraser', 'FRASER', 3, 32, 9999, 1, 4, 1, 9, NULL, '', 72, '8008/8448/4484/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2313, '1997-09-02 22:00:00+00', '2019-04-19 21:53:49.024478+00', 'Four of Diamonds', 'FOUR OF DIAMONDS', 2, 40, 9999, 1, 4, 1, 927, NULL, '', 90, '8888/8888/6666/6666/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2314, '1997-04-03 22:00:00+00', '2012-01-20 12:56:18.340687+00', 'Four Square', 'FOUR SQUARE', 1, 32, 9999, 1, 2, NULL, 213, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2316, '1997-09-02 22:00:00+00', '2012-01-20 12:56:18.354295+00', 'Four by Four by Eight', 'FOUR BY FOUR BY EIGHT', 3, 32, 9999, 4, 4, NULL, 925, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2320, '1997-04-03 22:00:00+00', '2012-01-20 12:56:18.381579+00', 'Foxglove Hollow', 'FOXGLOVE HOLLOW', 2, 32, 9999, 1, 2, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2324, '2002-03-12 23:00:00+00', '2012-01-20 12:56:18.409794+00', 'Frae Broomielaw Tae Tignabruigh', 'FRAE BROOMIELAW TAE TIGNABRUIGH', 3, 32, 9999, 1, 4, 1, 111, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2325, '1998-04-12 22:00:00+00', '2012-01-20 12:56:18.416784+00', 'Frances Mary''s Strathspey', 'FRANCES MARYS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 108, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2326, '1998-07-08 22:00:00+00', '2012-01-20 12:56:18.424416+00', 'Frances McDonald''s Halo', 'FRANCES MACDONALDS HALO', 1, 32, 9999, 1, 4, 2, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2327, '1997-04-03 22:00:00+00', '2012-01-20 12:56:18.431385+00', 'Francis Peacock', 'FRANCIS PEACOCK', 3, 32, 9999, 1, 4, NULL, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2330, '1997-04-03 22:00:00+00', '2012-01-20 12:56:18.451956+00', 'Fraser McLuskey Strathspey', 'FRASER MACLUSKEY STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2335, '1997-04-03 22:00:00+00', '2012-01-20 12:56:18.486159+00', 'Fred Smith''s Farewell', 'FRED SMITHS FAREWELL', 1, 32, 9999, 3, 5, NULL, 271, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3707, '1997-09-07 22:00:00+00', '2012-01-20 12:56:30.172191+00', 'Lanty Auld Man', 'LANTY AULD MAN', 2, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3709, '1998-01-05 23:00:00+00', '2012-01-20 12:56:30.185942+00', 'Lapton Reel', 'LAPTON REEL', 1, 32, 9999, 1, 2, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3688, '1997-09-08 22:00:00+00', '2018-04-03 00:08:01.725023+00', 'Malcolm of Glen Affric', 'MALCOLM OF GLEN AFFRIC', 1, 32, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3692, '1997-09-07 22:00:00+00', '2022-08-20 18:25:36.254013+00', 'Land of the Shining River', 'LAND OF THE SHINING RIVER', 2, 32, 9999, 1, 4, 1, 70, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3689, '1997-09-07 22:00:00+00', '2022-12-10 19:56:39.843713+00', 'Land of Oz, The', 'LAND OF OZ', 1, 32, 9999, 1, 3, 42, 108, '1988-01-01', 'The notes say this is "a dance to mark the Australian Bicentenary".', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2298, '1997-09-02 22:00:00+00', '2023-01-27 19:44:43.678201+00', 'Forth Railway Bridge Centenary Reel, The', 'FORTH RAILWAY BRIDGE CENTENARY REEL', 1, 32, 9999, 1, 4, 1, 146, '1989-01-01', '', 61, '8880/8800/8088/8042', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2297, '1997-08-25 22:00:00+00', '2023-01-27 19:49:48.894465+00', 'Forth Frolics', 'FORTH FROLICS', 2, 32, 9999, 1, 3, 42, 531, '1983-01-01', 'The tune is Inchkeith Island which is an island In the Firth of Forth.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2289, '1997-08-24 22:00:00+00', '2023-01-27 20:08:27.33614+00', 'Fort Beausejour', 'FORT BEAUSEJOUR', 2, 40, 9999, 1, 3, 42, 108, '1990-07-01', 'Inscribed "For the dancers of Nova Scotia and New Brunswick".', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2303, '1997-04-03 22:00:00+00', '2018-04-03 00:07:46.61302+00', 'Fountain Dale', 'FOUNTAIN DALE', 3, 32, 9999, 1, 3, 42, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2311, '1997-09-02 22:00:00+00', '2018-04-03 00:07:46.646432+00', 'Four Leaf Clover', 'FOUR LEAF CLOVER', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2318, '1997-04-03 22:00:00+00', '2018-04-03 00:07:46.671478+00', 'Fox Chase, The', 'FOX CHASE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2319, '1997-09-02 22:00:00+00', '2018-04-03 00:07:46.696487+00', 'Fox, The', 'FOX', 2, 32, 9999, 1, 3, 42, 928, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2336, '1998-05-08 22:00:00+00', '2018-04-03 00:07:46.888148+00', 'Freddy''s Fancy', 'FREDDYS FANCY', 3, 32, 9999, 1, 3, 42, 108, '1987-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2338, '1997-04-03 22:00:00+00', '2018-04-03 00:07:46.913223+00', 'Free And Easy', 'FREE AND EASY', 3, 32, 9999, 1, 3, 42, 329, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2340, '1997-04-03 22:00:00+00', '2018-04-03 00:07:46.92994+00', 'Freemason, The', 'FREEMASON', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3712, '1997-09-03 22:00:00+00', '2012-01-20 12:56:30.206584+00', 'Helen''s Twenty First Birthday', 'HELENS TWENTY FIRST BIRTHDAY', 4, 128, 2, 4, 4, NULL, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10826, '2002-09-25 22:00:00+00', '2018-04-03 00:07:42.694219+00', 'Dorothy''s Delight', 'DOROTHYS DELIGHT', 3, 40, 9999, 1, 3, 42, 555, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10825, '2002-09-25 22:00:00+00', '2012-01-20 12:57:24.272465+00', 'Caroline''s Fancy', 'CAROLINES FANCY', 3, 96, 9999, 4, 4, NULL, 555, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3724, '1998-04-21 22:00:00+00', '2018-04-29 10:21:45.852152+00', 'Lass With The Delicate Air, The', 'LASS WITH THE DELICATE AIR', 2, 32, 9999, 1, 3, 42, 44, '1976-05-01', 'Devised during April/May, 1976 . The title is taken from a line from the song "The Lass at the Ballyclare Fair".

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10827, '2002-09-25 22:00:00+00', '2012-01-20 12:57:24.286178+00', 'Hey Jude', 'HEY JUDE', 1, 32, 9999, 1, 4, NULL, 555, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17068, '2016-06-26 14:21:18.938891+00', '2018-09-08 22:24:28.788807+00', 'Lowland Ladies', 'LOWLAND LADIES', 1, 32, NULL, 1, 2, 76, 10478, '1991-09-30', '', 52, '80/88/88/80', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2343, '1997-09-02 22:00:00+00', '2012-01-20 12:56:18.541852+00', 'French Reel, The', 'FRENCH REEL', 1, 32, 9999, 1, 2, NULL, 70, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2359, '2002-04-30 22:00:00+00', '2018-04-03 00:07:46.296099+00', 'Flowers of Craigie', 'FLOWERS OF CRAIGIE', 3, 32, 9999, 1, 3, 42, 619, '1985-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2370, '1997-04-03 22:00:00+00', '2019-02-04 10:59:53.012849+00', 'Gadie Reel', 'GADIE REEL', 1, 32, 9999, 1, 2, 76, 332, NULL, '', 56, '84/84/84/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2341, '1997-09-02 22:00:00+00', '2018-04-03 00:07:46.938231+00', 'French Ambassador, The', 'FRENCH AMBASSADOR', 1, 48, 9999, 1, 3, 42, 446, '1701-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2376, '1998-11-02 23:00:00+00', '2019-03-16 17:04:11.091522+00', 'Gail''s Delight', 'GAILS DELIGHT', 3, 32, 9999, 1, 4, 1, 394, '1978-01-01', '', 44, '8000/8400/8880/8022', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2358, '1997-04-03 22:00:00+00', '2012-01-20 12:56:18.64545+00', 'Frost is all over, The', 'FROST IS ALL OVER', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3704, '2001-05-20 22:00:00+00', '2021-05-16 11:05:05.115038+00', 'Lansdowne Court', 'LANSDOWNE COURT', 1, 40, 9999, 1, 3, 42, 275, NULL, '', 55, '800/880/888/880/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2363, '1997-09-02 22:00:00+00', '2020-08-04 05:57:23.150296+00', 'Fun at the Fair', 'FUN AT THE FAIR', 2, 64, 9999, 4, 4, 54, 151, NULL, '', 75, '4444/4444/8888/8888/8080/0808/8888/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3703, '1997-09-07 22:00:00+00', '2020-08-06 15:34:04.708119+00', 'Lanimer Reel, The', 'LANIMER REEL', 1, 128, 9999, 104, 2, 3, 105, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2339, '1997-09-16 22:00:00+00', '2020-10-07 21:28:12.015042+00', 'Freemason''s Jig, The', 'FREEMASONS JIG', 2, 64, 9999, 1, 3, 42, 466, '1790-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3696, '1997-04-03 22:00:00+00', '2020-12-25 22:35:22.77827+00', 'Lang Gate, The', 'LANG GATE', 1, 32, 9999, 1, 4, 1, 13, NULL, '', 69, '8880/8880/8000/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10821, '2002-09-22 22:00:00+00', '2021-07-30 08:36:37.760166+00', 'Lady Nelthorpe', 'LADY NELTHORPE', 3, 32, 9999, 1, 3, 42, 308, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2306, '1998-01-05 23:00:00+00', '2021-04-04 21:34:36.539948+00', 'Four Black Crows', 'FOUR BLACK CROWS', 1, 32, 9999, 1, 3, 42, 352, '1993-04-18', '', 53, '800/888/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3701, '1999-08-09 22:00:00+00', '2021-05-16 11:18:36.245199+00', 'Langshaw Lassies', 'LANGSHAW LASSIES', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'The notes say that the original name of this dance was forgotten by the old shepherd from whom it was collected.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3698, '1997-11-20 23:00:00+00', '2021-05-16 17:32:13.481166+00', 'Lang Toon, The', 'LANG TOON', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 50, '800/880/808/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2361, '2000-02-22 23:00:00+00', '2012-01-20 12:56:18.667459+00', 'Fulghum''s Frolic', 'FULGHUMS FROLIC', 1, 32, 9999, 2, 3, 17, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2368, '1997-04-03 22:00:00+00', '2012-01-20 12:56:18.715553+00', 'G.L.A.D. Rant', 'GLAD RANT', 3, 40, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3714, '1997-08-31 22:00:00+00', '2012-01-20 12:56:30.225161+00', 'Chrissie''s Wedding', 'CHRISSIES WEDDING', 4, 96, 9999, 2, 3, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3716, '1997-10-23 22:00:00+00', '2012-01-20 12:56:30.239774+00', 'Lorn Silver Jubilee', 'LORN SILVER JUBILEE', 3, 40, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3717, '1997-04-03 22:00:00+00', '2012-01-20 12:56:30.247243+00', 'Lass For Andy, The', 'LASS FOR ANDY', 2, 32, 9999, 1, 2, NULL, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3718, '1997-09-07 22:00:00+00', '2012-01-20 12:56:30.254193+00', 'Lass Frae Auld Reekie, The', 'LASS FRAE AULD REEKIE', 3, 40, 9999, 4, 4, NULL, 1063, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3719, '1997-04-03 22:00:00+00', '2012-01-20 12:56:30.261151+00', 'Lass From Inverness, The', 'LASS FROM INVERNESS', 1, 32, 9999, 1, 4, NULL, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10831, '2002-09-25 22:00:00+00', '2012-01-20 12:57:24.313562+00', 'John T II Strathspey', 'JOHN T II STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 555, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2347, '1997-09-02 22:00:00+00', '2018-04-03 00:07:47.046736+00', 'Friendship Frolic', 'FRIENDSHIP FROLIC', 1, 48, 9999, 1, 3, 42, 933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10835, '2002-09-25 22:00:00+00', '2012-01-20 12:57:24.343506+00', 'St. Andrew''s And St. Paul''s', 'SAINT ANDREWS AND ST PAULS', 1, 32, 9999, 3, 5, NULL, 555, '1987-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10836, '2002-09-25 22:00:00+00', '2012-01-20 12:57:24.352314+00', 'John T Strathspey, The', 'JOHN T STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 555, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2369, '1998-07-08 22:00:00+00', '2012-01-20 12:56:18.723015+00', 'Gaberlunzie, The', 'GABERLUNZIE', 1, 32, 9999, 1, 4, 2, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2374, '1998-07-08 22:00:00+00', '2012-01-20 12:56:18.757762+00', 'Gaelic Wedding, The', 'GAELIC WEDDING', 1, 32, 9999, 1, 4, 2, 900, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2381, '1997-09-02 22:00:00+00', '2012-01-20 12:56:18.805595+00', 'Gallant Cameron, The', 'GALLANT CAMERON', 1, 16, 9999, 5, 2, NULL, 326, '1959-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2390, '1998-07-08 22:00:00+00', '2012-01-20 12:56:18.870855+00', 'Galloway Pippins', 'GALLOWAY PIPPINS', 1, 32, 9999, 1, 4, 2, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2351, '1998-04-12 22:00:00+00', '2018-04-03 00:07:47.080032+00', 'From Aberdeen', 'FROM ABERDEEN', 1, 36, 9999, 1, 3, 42, 81, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2391, '1998-01-12 23:00:00+00', '2017-01-27 00:40:00.827597+00', 'Galloway Tale, A', 'GALLOWAY TALE', 1, 32, 9999, 1, 4, 1, 210, NULL, '', 47, '8000/4444/4444/8444', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2362, '1997-04-03 22:00:00+00', '2018-04-03 00:07:47.1969+00', 'Fullarton Reel', 'FULLARTON REEL', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3713, '1998-01-05 23:00:00+00', '2018-01-13 15:29:54.054264+00', 'Larkhill Welcome, The', 'LARKHILL WELCOME', 1, 32, 9999, 1, 3, 42, 315, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2366, '1997-04-03 22:00:00+00', '2018-04-03 00:07:47.413747+00', 'Fusion', 'FUSION', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2373, '1997-04-03 22:00:00+00', '2018-04-03 00:07:47.555178+00', 'Gaelic Singer, The', 'GAELIC SINGER', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2348, '1997-09-02 22:00:00+00', '2022-08-12 08:31:53.512411+00', 'Friendship Jig', 'FRIENDSHIP JIG', 2, 32, 9999, 4, 4, 46, 934, '1993-05-01', 'Devised by two members of the Leeds Branch children''s class in May 1993.', 88, '8888/8888/4444/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3720, '1997-10-22 22:00:00+00', '2022-11-07 16:42:33.137721+00', 'Lass O''Corrie''s Mill', 'LASS OCORRIES MILL', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2334, '1997-04-03 22:00:00+00', '2022-11-07 19:08:07.842129+00', 'Frasers of Oban, The', 'FRASERS OF OBAN', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2345, '1997-09-02 22:00:00+00', '2023-01-17 11:10:45.786127+00', 'Friendly Dance, The', 'FRIENDLY DANCE', 3, 32, 9999, 1, 4, 1, 931, NULL, 'Deviser''s recommended recording is "Blue Mess Jacket" by Rob Gordon from "Caledonian Ball Vol 2".', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2375, '2001-05-21 22:00:00+00', '2018-04-03 00:07:47.580298+00', 'Gail Cordy''s Welcome To Utah', 'GAIL CORDYS WELCOME TO UTAH', 1, 32, 9999, 1, 3, 42, 2603, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2377, '1997-04-03 22:00:00+00', '2018-04-03 00:07:47.58858+00', 'Gainsborough', 'GAINSBOROUGH', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2378, '2002-03-02 23:00:00+00', '2018-04-03 00:07:47.596937+00', 'Gairloch', 'GAIRLOCH', 3, 32, 9999, 1, 3, 42, 146, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2382, '1997-09-02 22:00:00+00', '2018-04-03 00:07:47.621934+00', 'Gallant Enterprize, The', 'GALLANT ENTERPRIZE', 1, 32, 9999, 1, 3, 42, 198, '1740-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2384, '1997-04-03 22:00:00+00', '2018-04-03 00:07:47.630209+00', 'Gallaton', 'GALLATON', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2385, '1997-09-02 22:00:00+00', '2018-04-03 00:07:47.638602+00', 'Galley Of Lorn', 'GALLEY OF LORN', 2, 32, 9999, 1, 3, 42, 613, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2392, '1997-09-08 22:00:00+00', '2018-04-03 00:07:47.680304+00', 'Galtee Rangers, The', 'GALTEE RANGERS', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10828, '2002-09-25 22:00:00+00', '2018-04-03 00:07:52.025979+00', 'Hey Jude Too', 'HEY JUDE TOO', 1, 32, 9999, 1, 3, 42, 555, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10829, '2002-09-25 22:00:00+00', '2018-04-03 00:07:52.668105+00', 'Hornpipe for Anne', 'HORNPIPE FOR ANNE', 1, 32, 9999, 1, 3, 42, 555, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10830, '2002-09-25 22:00:00+00', '2018-04-03 00:07:53.435432+00', 'In Front of the Ingle', 'IN FRONT OF THE INGLE', 1, 32, 9999, 1, 3, 42, 555, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2397, '1997-04-03 22:00:00+00', '2012-01-20 12:56:18.919656+00', 'Garden City', 'GARDEN CITY', 1, 32, 9999, 1, 4, NULL, 225, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10839, '2002-09-25 22:00:00+00', '2018-10-14 00:11:06.266239+00', 'Wee Bluets of Salem Strathspey, The', 'WEE BLUETS OF SALEM STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 555, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3734, '1997-04-03 22:00:00+00', '2012-01-20 12:56:30.370306+00', 'Lassies Of Belfast', 'LASSIES OF BELFAST', 2, 32, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2399, '1997-09-02 22:00:00+00', '2019-02-07 18:25:01.21865+00', 'Garden City Jubilee, The', 'GARDEN CITY JUBILEE', 3, 32, 9999, 1, 4, 1, 940, NULL, '', 94, '8888/8088/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2416, '1997-04-03 22:00:00+00', '2019-02-22 22:12:07.993093+00', 'Gates Of India', 'GATES OF INDIA', 2, 32, 9999, 1, 4, 2, 13, NULL, '', 88, '8888/8008/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2583, '1998-04-12 22:00:00+00', '2019-03-16 16:30:24.913515+00', 'Gold in Tassie', 'GOLD IN TASSIE', 3, 32, 9999, 1, 4, 1, 108, '1995-01-01', '', 63, '8880/8880/8800/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10840, '2002-09-25 22:00:00+00', '2012-01-20 12:57:24.38755+00', 'Windy City Waltz, The', 'WINDY CITY WALTZ', 5, 32, 9999, 5, 1, NULL, 555, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10841, '2002-09-25 22:00:00+00', '2012-01-20 12:57:24.396326+00', 'Trip over the Forth Railway Bridge', 'TRIP OVER THE FORTH RAILWAY BRIDGE', 1, 32, 9999, 1, 4, NULL, 555, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2400, '1997-04-03 22:00:00+00', '2012-01-20 12:56:18.9403+00', 'Garden Isle, The', 'GARDEN ISLE', 3, 32, 9999, 1, 4, NULL, 385, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2371, '2000-07-02 22:00:00+00', '2020-02-29 15:09:23.490146+00', 'Gaelic Mod', 'GAELIC MOD', 3, 32, 9999, 1, 3, 42, 90, NULL, '', 81, '880/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10834, '2002-09-25 22:00:00+00', '2020-09-13 14:37:11.085354+00', 'Something Knotty', 'SOMETHING KNOTTY', 3, 32, 9999, 1, 3, 42, 555, '2000-01-01', '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2396, '1998-07-08 22:00:00+00', '2020-03-21 08:06:25.911598+00', 'Gannochy Reel, The', 'GANNOCHY REEL', 1, 32, 9999, 1, 4, 2, 108, '1994-01-01', 'For Betty Keir of Perth to express her gratitude to The Gannochy Trust.', 75, '8888/4444/6666/4884', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10832, '2002-09-25 22:00:00+00', '2020-09-13 14:33:25.170035+00', 'Jones Falls Hornpipe', 'JONES FALLS HORNPIPE', 1, 32, 9999, 1, 3, 42, 555, '2001-01-01', '', 63, '844/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3721, '1997-04-03 22:00:00+00', '2020-11-08 18:32:25.799297+00', 'Lass O'' Gowrie', 'LASS O GOWRIE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 52, '880/888/874/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2356, '1998-11-02 23:00:00+00', '2021-06-06 10:19:07.918705+00', 'Frontenac Strathspey, The', 'FRONTENAC STRATHSPEY', 3, 32, 9999, 1, 3, 42, 935, '1989-01-01', '', 47, '888/800/844/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2405, '1997-09-03 22:00:00+00', '2012-01-20 12:56:18.974803+00', 'Gardenvale St. Andrew''s Reel', 'GARDENVALE ST ANDREWS REEL', 1, 40, 9999, 1, 4, NULL, 941, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2406, '1998-07-08 22:00:00+00', '2012-01-20 12:56:18.982328+00', 'Gare Loch, The', 'GARE LOCH', 3, 32, 9999, 1, 4, 11, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2411, '1998-07-08 22:00:00+00', '2012-01-20 12:56:19.017921+00', 'Garthmyl', 'GARTHMYL', 3, 32, 9999, 1, 4, 2, 943, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2393, '1997-04-03 22:00:00+00', '2018-04-03 00:07:47.688824+00', 'Gamoral Strathspey, The', 'GAMORAL STRATHSPEY', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2417, '2003-01-28 23:00:00+00', '2012-01-20 12:56:19.061263+00', 'Gathering Jewels', 'GATHERING JEWELS', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2418, '1997-09-03 22:00:00+00', '2012-01-20 12:56:19.068144+00', 'Gathering o'' 79', 'GATHERING O 79', 4, 64, 9999, 1, 4, NULL, 209, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2420, '1998-07-08 22:00:00+00', '2012-01-20 12:56:19.082463+00', 'Gatineau Hills', 'GATINEAU HILLS', 1, 32, 9999, 1, 4, 2, 944, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2422, '1997-04-03 22:00:00+00', '2012-01-20 12:56:19.102639+00', 'Gay Goshawk, The', 'GAY GOSHAWK', 2, 32, 9999, 1, 2, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2581, '1997-04-03 22:00:00+00', '2012-01-20 12:56:20.599783+00', 'Gold and Silver', 'GOLD AND SILVER', 3, 96, 9999, 4, 4, NULL, 108, '1985-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2584, '1997-09-03 22:00:00+00', '2012-01-20 12:56:20.626094+00', 'Golden Apples', 'GOLDEN APPLES', 3, 32, 9999, 2, 3, NULL, 966, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2586, '1997-04-03 22:00:00+00', '2012-01-20 12:56:20.643608+00', 'Golden Fleece', 'GOLDEN FLEECE', 2, 32, 9999, 1, 4, NULL, 250, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2590, '1997-04-03 22:00:00+00', '2012-01-20 12:56:20.678672+00', 'Golden Jubilee Of Guiding', 'GOLDEN JUBILEE OF GUIDING', 1, 64, 9999, 1, 4, NULL, 54, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2594, '1997-04-03 22:00:00+00', '2012-01-20 12:56:20.714672+00', 'Golden Reel', 'GOLDEN REEL', 1, 32, 9999, 1, 98, NULL, 108, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2585, '1997-08-21 22:00:00+00', '2015-09-07 13:56:55.264159+00', 'Golden Boy, The', 'GOLDEN BOY', 2, 32, 9999, 1, 3, 42, 108, '1992-01-01', '', 50, '880/880/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2424, '1997-10-15 22:00:00+00', '2018-04-03 00:07:47.882536+00', 'General Abercrombie''s Reel', 'GENERAL ABERCROMBIES REEL', 1, 24, 9999, 1, 3, 42, 1161, '1800-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2404, '1997-04-03 22:00:00+00', '2018-04-03 00:07:47.755551+00', 'Gardener''s Strathspey, The', 'GARDENERS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 105, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2403, '1997-04-03 22:00:00+00', '2018-04-03 00:07:47.747183+00', 'Gardener''s Medley, The', 'GARDENERS MEDLEY', 4, 32, 1, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2407, '1997-09-03 22:00:00+00', '2018-04-03 00:07:47.772296+00', 'Garland, The', 'GARLAND', 1, 32, 9999, 1, 3, 42, 942, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2412, '1997-09-03 22:00:00+00', '2018-04-03 00:07:47.780683+00', 'Gary Morris'' Jig', 'GARY MORRIS JIG', 2, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2414, '1997-04-03 22:00:00+00', '2018-04-03 00:07:47.797218+00', 'Gatehouse-of-Fleet', 'GATEHOUSEOFFLEET', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2591, '1997-04-03 22:00:00+00', '2018-04-03 00:07:49.265717+00', 'Golden Memories', 'GOLDEN MEMORIES', 1, 32, 9999, 1, 3, 42, 67, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10843, '2002-09-26 22:00:00+00', '2022-05-31 11:20:03.060734+00', 'Bridgewater Mill', 'BRIDGEWATER MILL', 1, 128, 9999, 4, 4, NULL, 12135, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2410, '1998-11-15 23:00:00+00', '2022-11-07 19:45:41.991283+00', 'Garthland''s Strathspey', 'GARTHLANDS STRATHSPEY', 3, 32, 9999, 1, 4, 11, 270, NULL, '', 97, '8888/8888/8888/8668', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2395, '1997-04-03 22:00:00+00', '2022-07-31 10:50:04.866346+00', 'Gang Warily', 'GANG WARILY', 3, 32, 9999, 1, 3, 42, 413, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10848, '2002-09-26 22:00:00+00', '2022-10-14 11:33:06.794885+00', '75th Anniversary Jig', '75TH ANNIVERSARY JIG', 2, 32, 9999, 1, 3, 42, 12134, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2398, '1997-04-03 22:00:00+00', '2023-01-27 12:04:40.065958+00', 'Garden City Jig, The', 'GARDEN CITY JIG', 2, 32, 9999, 1, 3, 42, 360, '1994-03-01', 'Devised in March 1994 for Lorraine Hearne. Lorraine lives in Christchurch, known as the Garden City of New Zealand.', 53, '800/888/844/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2342, '1997-09-02 22:00:00+00', '2023-01-27 19:29:18.108124+00', 'French Connection, The', 'FRENCH CONNECTION', 3, 32, 9999, 1, 3, 42, 488, '1985-01-01', 'Inscribed "for Glenda Bourgeois and Paul Robertson on the occasion of their marriage, June I, 1985."', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10846, '2002-09-26 22:00:00+00', '2018-04-03 00:07:55.136472+00', 'Jean''s Joy', 'JEANS JOY', 2, 32, 9999, 1, 3, 42, 3181, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3736, '1997-09-22 22:00:00+00', '2018-04-03 00:07:58.914381+00', 'Lassies Of Lossiemouth', 'LASSIES OF LOSSIEMOUTH', 2, 32, 9999, 1, 3, 42, 696, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3727, '1998-04-12 22:00:00+00', '2018-04-03 00:07:58.939481+00', 'Lassie What Mair Wad Ye Ha''e', 'LASSIE WHAT MAIR WAD YE HAE', 2, 32, 9999, 1, 3, 42, 121, '1982-01-01', 'Official Alias: Sheila Scott''s Jig', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10837, '2002-09-25 22:00:00+00', '2018-04-03 00:08:12.591728+00', 'Reluctant Dancer, The', 'RELUCTANT DANCER', 3, 32, 9999, 1, 3, 42, 555, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10838, '2002-09-25 22:00:00+00', '2018-04-03 00:08:18.712623+00', 'Strathmere Tryst, The', 'STRATHMERE TRYST', 2, 32, 9999, 1, 3, 42, 555, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15705, '2014-11-18 22:50:07.46536+00', '2018-04-03 00:18:02.27136+00', 'Mary-Kate''s Super-Symmetric Symmetry Breaking Strathspey', 'MARYKATES SUPERSYMMETRIC SYMMETRY BREAKING STRATHSPEY', 3, 32, NULL, 2, 2, 76, 3100, NULL, 'As you see the main figures cut across the 8-bar phrases (bars 5-12 for the diamond poussette & bars 21-28 for the reel). Therefore it seems to me that the music should not have a pronounced 8-bar structure. CA', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10850, '2002-09-26 22:00:00+00', '2012-01-20 12:57:24.476344+00', 'Young to Some', 'YOUNG TO SOME', 1, 32, 9999, 1, 4, NULL, 3195, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2441, '1999-07-25 22:00:00+00', '2018-04-29 21:36:20.297853+00', 'Geordie''s Jubilee Jig', 'GEORDIES JUBILEE JIG', 2, 32, 9999, 1, 3, 42, 945, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2432, '1997-08-17 22:00:00+00', '2018-11-26 03:36:02.301845+00', 'Geneviève''s Jig', 'GENEVIEVES JIG', 2, 32, 9999, 1, 4, 1, 17, '1982-01-01', '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2429, '1998-07-08 22:00:00+00', '2012-01-20 12:56:19.170646+00', 'General, The', 'GENERAL', 1, 32, 9999, 1, 4, 11, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3745, '1997-12-21 23:00:00+00', '2019-03-15 10:06:30.258133+00', 'Last Womp, The', 'LAST WOMP', 2, 32, 9999, 1, 3, 42, 9, NULL, '', 50, '808/646/848/840', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2462, '1997-09-03 22:00:00+00', '2019-03-16 16:48:51.445117+00', 'Gibbs'' Valentine Party', 'GIBBS VALENTINE PARTY', 1, 32, 9999, 1, 4, 1, 792, NULL, '', 91, '8888/8888/8444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2433, '2000-04-25 22:00:00+00', '2019-03-16 17:00:45.056576+00', 'Gentle Breeze, The', 'GENTLE BREEZE', 3, 32, 9999, 1, 4, 1, 578, NULL, '', 72, '8866/8080/8008/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2435, '1997-09-03 22:00:00+00', '2012-01-20 12:56:19.226065+00', 'Gentle Maiden, The', 'GENTLE MAIDEN', 1, 64, 9999, 4, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2438, '1997-10-27 23:00:00+00', '2012-01-20 12:56:19.252473+00', 'Geordie Affleck', 'GEORDIE AFFLECK', 1, 32, 9999, 1, 4, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2408, '2001-10-25 22:00:00+00', '2018-04-02 23:56:34.847113+00', 'Garple Burn, The', 'GARPLE BURN', 1, 32, 9999, 1, 3, 42, 129, '1960-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2440, '1997-04-03 22:00:00+00', '2012-01-20 12:56:19.269937+00', 'Geordie The Roadman', 'GEORDIE THE ROADMAN', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2459, '1997-04-03 22:00:00+00', '2019-10-19 16:25:33.417459+00', 'Ghillie Laces', 'GHILLIE LACES', 3, 32, 9999, 1, 3, 42, 309, NULL, 'The deviser and composer are members of the Nottingham Branch



The Formations Represent:

1-16 Lacing the shoe.

17-24 Laces encircling the ankle.

25-32 Tying the laces.', 37, '440/404/844/880', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2442, '1997-04-03 22:00:00+00', '2012-01-20 12:56:19.287291+00', 'Geordie''s Reel', 'GEORDIES REEL', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2444, '1997-09-03 22:00:00+00', '2012-01-20 12:56:19.305004+00', 'George Bids Adieu To His Friends', 'GEORGE BIDS ADIEU TO HIS FRIENDS', 2, 48, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3746, '1997-04-03 22:00:00+00', '2018-04-02 23:56:35.844362+00', 'Late In The Morning', 'LATE IN THE MORNING', 1, 32, 9999, 1, 3, 42, 352, '1993-06-16', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2446, '1997-09-03 22:00:00+00', '2012-01-20 12:56:19.322539+00', 'George MacDonald''s Reel', 'GEORGE MACDONALDS REEL', 1, 48, 9999, 1, 4, NULL, 948, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2425, '1997-09-16 22:00:00+00', '2018-04-03 00:07:47.897388+00', 'General Abercrombie''s Reel', 'GENERAL ABERCROMBIES REEL', 1, 32, 9999, 1, 3, 42, 984, '1785-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2588, '1997-04-03 22:00:00+00', '2021-04-18 10:04:09.978907+00', 'Golden Harvest', 'GOLDEN HARVEST', 3, 32, 9999, 1, 100, 2, 108, '1979-01-01', '', 75, '8008/8448/8888/8448', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3731, '1998-04-12 22:00:00+00', '2021-05-15 19:11:18.407647+00', 'Lassie, Will Ye Come And Dance?', 'LASSIE WILL YE COME AND DANCE', 2, 32, 9999, 1, 3, 42, 44, '1980-03-01', '', 38, '800/800/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2587, '2002-01-06 23:00:00+00', '2021-06-02 23:50:58.057873+00', 'Golden Gaels Reel, The', 'GOLDEN GAELS REEL', 1, 32, 9999, 1, 3, 42, 394, '1985-01-01', '', 63, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2426, '1998-04-12 22:00:00+00', '2018-04-03 00:07:47.905635+00', 'General Bossiness', 'GENERAL BOSSINESS', 1, 32, 9999, 1, 3, 42, 108, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2449, '1997-10-27 23:00:00+00', '2012-01-20 12:56:19.348569+00', 'George Wark', 'GEORGE WARK', 1, 32, 9999, 1, 2, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3740, '2000-02-13 23:00:00+00', '2012-01-20 12:56:30.415585+00', 'Last Jig, The', 'LAST JIG', 2, 32, 9999, 2, 3, 17, 196, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3744, '1998-04-20 22:00:00+00', '2012-01-20 12:56:30.44336+00', 'Last Rose Of Summer, The', 'LAST ROSE OF SUMMER', 3, 40, 9999, 1, 4, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3749, '1997-04-03 22:00:00+00', '2012-01-20 12:56:30.479191+00', 'Laura Andrews', 'LAURA ANDREWS', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3750, '1997-09-08 22:00:00+00', '2012-01-20 12:56:30.487798+00', 'Maormor of Fife', 'MAORMOR OF FIFE', 1, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3752, '2002-04-19 22:00:00+00', '2012-01-20 12:56:30.501496+00', 'Laurie''s Favourite', 'LAURIES FAVOURITE', 3, 32, 9999, 1, 4, NULL, 222, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13798, '2011-07-24 22:00:00+00', '2012-01-20 12:57:49.20399+00', 'On the Banks of Spey', 'ON THE BANKS OF SPEY', 3, 32, NULL, 1, 4, 2, 2682, '2007-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2454, '1997-09-03 22:00:00+00', '2012-01-20 12:56:19.392179+00', 'Gepps Cross', 'GEPPS CROSS', 3, 32, 9999, 2, 3, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2460, '1997-09-03 22:00:00+00', '2012-01-20 12:56:19.445616+00', 'Ghillies', 'GHILLIES', 1, 40, 9999, 1, 4, NULL, 152, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2466, '1997-09-03 22:00:00+00', '2012-01-20 12:56:19.498581+00', 'Gillan''s Reel', 'GILLANS REEL', 1, 32, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3739, '1998-07-08 22:00:00+00', '2016-02-27 00:50:39.944404+00', 'Lassies Of Taraka', 'LASSIES OF TARAKA', 1, 40, 9999, 1, 4, 2, 1064, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2443, '2001-05-21 22:00:00+00', '2017-02-13 14:45:46.844349+00', 'Geordie''s Tunebook', 'GEORDIES TUNEBOOK', 1, 32, 9999, 1, 3, 42, 228, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2434, '1997-04-03 22:00:00+00', '2018-04-03 00:07:47.955766+00', 'Gentle Maiden, The', 'GENTLE MAIDEN', 2, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2451, '1997-09-03 22:00:00+00', '2018-04-03 00:07:48.04779+00', 'George''s Jig', 'GEORGES JIG', 2, 32, 9999, 1, 3, 42, 782, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2452, '1998-04-12 22:00:00+00', '2018-04-03 00:07:48.081077+00', 'Georgie Girl', 'GEORGIE GIRL', 2, 32, 9999, 1, 3, 42, 108, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2455, '1997-04-03 22:00:00+00', '2018-04-03 00:07:48.097779+00', 'Ger-Bob Jig, The', 'GERBOB JIG', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2461, '1997-04-03 22:00:00+00', '2018-04-03 00:07:48.156004+00', 'Ghost Piper of Kintail, The', 'GHOST PIPER OF KINTAIL', 2, 40, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3742, '1997-10-27 23:00:00+00', '2018-04-03 00:07:59.022771+00', 'Last May a Braw Wooer', 'LAST MAY A BRAW WOOER', 2, 40, 9999, 1, 3, 42, 270, '1983-01-01', '10 bar phrases', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3741, '1997-10-22 22:00:00+00', '2018-04-03 00:07:59.031157+00', 'Last May A Braw Wooer', 'LAST MAY A BRAW WOOER', 2, 40, 9999, 1, 3, 42, 199, NULL, '10 bar phrases', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3751, '1997-04-03 22:00:00+00', '2018-04-03 00:07:59.12296+00', 'Laureston Castle', 'LAURESTON CASTLE', 1, 32, 9999, 1, 3, 42, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2468, '1997-04-03 22:00:00+00', '2012-01-20 12:56:19.516222+00', 'Gillie''s Gallop', 'GILLIES GALLOP', 2, 32, 9999, 1, 1, NULL, 142, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2503, '1997-04-03 22:00:00+00', '2018-07-26 06:31:31.496983+00', 'Glasgow Peggy', 'GLASGOW PEGGY', 2, 24, 9999, 1, 3, 42, 173, '1985-03-01', '', 58, '844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2473, '1997-04-03 22:00:00+00', '2012-01-20 12:56:19.559884+00', 'Gin I Was A Bonny Lad', 'GIN I WAS A BONNY LAD', 1, 32, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2474, '1998-10-20 22:00:00+00', '2012-01-20 12:56:19.569394+00', 'Gin Worth Living', 'GIN WORTH LIVING', 3, 32, 9999, 1, 4, 1, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3737, '1999-08-09 22:00:00+00', '2022-12-10 19:33:55.053451+00', 'Lassies o'' Melrose, The', 'LASSIES O MELROSE', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2483, '1997-04-03 22:00:00+00', '2012-01-20 12:56:19.651967+00', 'Give And Take', 'GIVE AND TAKE', 3, 80, 9999, 4, 4, NULL, 197, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2598, '1998-07-08 22:00:00+00', '2012-01-20 12:56:20.753839+00', 'Golden Trumpet, The', 'GOLDEN TRUMPET', 1, 48, 9999, 1, 4, 2, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18692, '2018-10-02 11:51:42.720574+00', '2018-10-02 11:51:42.720574+00', 'Butterfly Effect, The', 'BUTTERFLY EFFECT', 2, 32, NULL, 1, 3, 42, 2766, '2011-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2601, '1997-04-03 22:00:00+00', '2012-01-20 12:56:20.78099+00', 'Golden Wedding, A', 'GOLDEN WEDDING', 1, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2486, '1997-09-03 22:00:00+00', '2012-01-20 12:56:19.681627+00', 'Gladys''s Quilt', 'GLADYSS QUILT', 3, 32, 9999, 4, 4, NULL, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2489, '1997-04-03 22:00:00+00', '2012-01-20 12:56:19.708768+00', 'Glamis Castle', 'GLAMIS CASTLE', 3, 40, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2485, '1997-09-03 22:00:00+00', '2020-08-04 21:23:19.634436+00', 'Gladstone', 'GLADSTONE', 1, 32, 9999, 1, 3, 42, 129, '1970-01-01', '', 43, '880/844/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2463, '1997-04-03 22:00:00+00', '2020-08-15 15:43:42.679653+00', 'Gibson''s Large & Gibson''s Small', 'GIBSONS LARGE AND GIBSONS SMALL', 4, 32, 9999, 1, 3, 42, 99, '1986-12-01', '', 63, '822/844/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2450, '1997-04-03 22:00:00+00', '2020-08-30 10:25:57.395669+00', 'George Will''s Jig', 'GEORGE WILLS JIG', 2, 32, 9999, 4, 4, 13, 154, NULL, '', 88, '8080/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13743, '2011-07-11 22:00:00+00', '2020-09-20 08:31:57.745126+00', 'Kachina''s Carousel', 'KACHINAS CAROUSEL', 2, 32, NULL, 1, 4, 2, 2973, '2006-03-01', 'Devised in March 2006, for a special birthday of Kachina Allen', 94, '8888/8888/8888/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2606, '1997-04-03 22:00:00+00', '2020-10-08 21:05:36.540898+00', 'Good Humour', 'GOOD HUMOUR', 1, 48, 9999, 1, 2, 76, 270, NULL, '', 90, '88/88/84/66/66/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2480, '1997-04-03 22:00:00+00', '2020-10-21 10:01:58.298165+00', 'Girl in a Blue Dream, The', 'GIRL IN A BLUE DREAM', 1, 32, 9999, 1, 4, 1, 270, NULL, '', 64, '8666/8800/8888/8000', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2596, '1998-07-08 22:00:00+00', '2020-12-30 16:46:33.209747+00', 'Golden Road, The', 'GOLDEN ROAD', 2, 32, 9999, 1, 100, 2, 13, NULL, '', 88, '8008/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2607, '1997-08-24 22:00:00+00', '2021-01-17 22:59:05.539414+00', 'Goodhind Reel, The', 'GOODHIND REEL', 1, 32, 9999, 1, 3, 42, 108, '1990-05-01', '', 63, '888/808/888/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2597, '2002-10-15 22:00:00+00', '2021-04-07 20:37:28.194763+00', 'Golden Trilium, The', 'GOLDEN TRILIUM', 1, 128, 9999, 6, 3, 3, 325, '1989-01-01', 'From the notes: "Devised to honour Dorothy Rosemond, Berenice Vale and George Wells who started their Scottish Country Dancing in Sydney in 1938. The dance was performed to celebrate their 50 years of dancing and their service to the Branch on 20th May, 1989."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3747, '1999-04-19 22:00:00+00', '2021-05-15 19:01:08.320499+00', 'Lauder Legend, The', 'LAUDER LEGEND', 2, 32, 9999, 3, 5, 16, 87, NULL, '', 55, '88088/80808/60424/20464', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2456, '1998-04-12 22:00:00+00', '2021-05-13 02:08:30.852958+00', 'German Reel, The', 'GERMAN REEL', 1, 32, 9999, 1, 2, NULL, 352, '1993-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2465, '1998-01-05 23:00:00+00', '2021-06-05 09:49:02.596624+00', 'Gigalum', 'GIGALUM', 1, 32, 9999, 1, 3, 42, 370, NULL, '', 53, '880/888/822/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2457, '1997-04-03 22:00:00+00', '2021-06-14 07:21:23.333148+00', 'German Sea, The', 'GERMAN SEA', 1, 32, 9999, 1, 2, 76, 352, '1993-04-17', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13744, '2011-07-11 22:00:00+00', '2021-09-29 05:59:16.101213+00', 'Summer Social', 'SUMMER SOCIAL', 2, 32, NULL, 1, 3, 42, 2973, '2006-05-01', 'Devised in May 2006 for the South Dorset Summer Social dance.', 56, '840/888/888/804', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2490, '1997-09-03 22:00:00+00', '2012-01-20 12:56:19.717478+00', 'Glamis Cross', 'GLAMIS CROSS', 2, 48, 9999, 4, 4, NULL, 680, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2496, '1997-04-03 22:00:00+00', '2012-01-20 12:56:19.774625+00', 'Glasgow Gaelic Club', 'GLASGOW GAELIC CLUB', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2470, '2000-01-10 23:00:00+00', '2018-04-03 00:07:48.281108+00', 'Gilt Hall, The', 'GILT HALL', 3, 32, 9999, 1, 3, 42, 951, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2500, '1997-04-03 22:00:00+00', '2012-01-20 12:56:19.810237+00', 'Glasgow Lad, The', 'GLASGOW LAD', 1, 32, 9999, 1, 4, NULL, 186, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2505, '1997-12-22 23:00:00+00', '2012-01-20 12:56:19.902795+00', 'Glasgow Street Song, A', 'GLASGOW STREET SONG', 1, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2511, '1997-09-03 22:00:00+00', '2012-01-20 12:56:19.944073+00', 'Glen Ebor Frolic, The', 'GLEN EBOR FROLIC', 2, 48, 9999, 4, 4, NULL, 959, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2512, '2002-03-02 23:00:00+00', '2012-01-20 12:56:19.950873+00', 'Glen Elg', 'GLEN ELG', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2515, '1997-04-03 22:00:00+00', '2012-01-20 12:56:19.971243+00', 'Glen Lyon', 'GLEN LYON', 1, 32, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2520, '1997-09-03 22:00:00+00', '2012-01-20 12:56:20.008035+00', 'Glenbarr', 'GLENBARR', 1, 32, 9999, 2, 3, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10867, '2002-10-13 22:00:00+00', '2012-01-20 12:57:24.631049+00', 'Holywood Romance, The', 'HOLYWOOD ROMANCE', 3, 32, 9999, 4, 4, NULL, 2694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2523, '1997-11-25 23:00:00+00', '2012-01-20 12:56:20.035332+00', 'Glen Caladh Castle', 'GLEN CALADH CASTLE', 3, 32, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2479, '1997-12-03 23:00:00+00', '2015-03-03 22:06:04.232744+00', 'Girl in Green', 'GIRL IN GREEN', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2481, '2001-05-21 22:00:00+00', '2016-06-03 13:41:46.724082+00', 'Gisela''s Welcome', 'GISELAS WELCOME', 2, 32, 9999, 1, 3, 42, 228, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2516, '1998-07-08 22:00:00+00', '2016-09-04 20:25:34.595037+00', 'Glen Nevis', 'GLEN NEVIS', 3, 32, 9999, 1, 4, 2, 963, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2478, '1998-04-21 22:00:00+00', '2018-04-03 00:07:48.322758+00', 'Girl I Left Behind, The', 'GIRL I LEFT BEHIND', 1, 48, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2502, '1997-06-25 22:00:00+00', '2018-04-03 00:07:48.381212+00', 'Glasgow Peggie', 'GLASGOW PEGGIE', 2, 32, 9999, 1, 3, 42, 3, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2519, '1997-09-03 22:00:00+00', '2018-04-03 00:07:48.472982+00', 'Glenayre Hills', 'GLENAYRE HILLS', 2, 32, 9999, 1, 3, 42, 955, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2517, '1997-04-03 22:00:00+00', '2018-04-03 00:07:48.864874+00', 'Glen Nevis Strathspey', 'GLEN NEVIS STRATHSPEY', 3, 40, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2577, '1997-09-03 22:00:00+00', '2018-04-03 00:07:49.115797+00', 'Goat Brae, The', 'GOAT BRAE', 1, 32, 9999, 1, 3, 42, 965, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2599, '1997-09-03 22:00:00+00', '2018-04-03 00:07:49.33256+00', 'Golden Wattle Jig, The', 'GOLDEN WATTLE JIG', 2, 40, 9999, 1, 3, 42, 43, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2603, '1997-04-03 22:00:00+00', '2018-04-03 00:07:49.365785+00', 'Gone Fishing', 'GONE FISHING', 2, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2605, '1998-04-12 22:00:00+00', '2018-04-03 00:07:49.382533+00', 'Good Humour', 'GOOD HUMOUR', 1, 32, 9999, 1, 3, 42, 44, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2551, '1998-01-04 23:00:00+00', '2019-02-26 12:28:15.027685+00', 'Glenlivet', 'GLENLIVET', 1, 32, 9999, 1, 4, 1, 547, '1977-01-01', '', 87, '8448/4884/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19540, '2019-08-12 16:26:40.102672+00', '2019-08-12 16:26:40.102672+00', 'Whisky Trail, The', 'WHISKY TRAIL', 2, 32, NULL, 1, 4, NULL, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2574, '1997-04-03 22:00:00+00', '2019-05-12 08:26:37.407586+00', 'Glorious Twelfth, The', 'GLORIOUS TWELFTH', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 53, '800/844/888/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2545, '1997-04-03 22:00:00+00', '2012-01-20 12:56:20.244861+00', 'Glenhead Reel', 'GLENHEAD REEL', 1, 32, 9999, 3, 5, NULL, 159, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2546, '1997-09-03 22:00:00+00', '2012-01-20 12:56:20.253549+00', 'Glenhurst Reel, The', 'GLENHURST REEL', 1, 32, 9999, 1, 2, NULL, 962, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2547, '2002-11-26 23:00:00+00', '2012-01-20 12:56:20.262367+00', 'Gleniffer Braes, The', 'GLENIFFER BRAES', 1, 32, 9999, 2, 3, NULL, 711, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10861, '2002-10-13 22:00:00+00', '2022-09-30 11:56:45.347313+00', 'Sarah''s Favourite', 'SARAHS FAVOURITE', 2, 32, 9999, 1, 3, 42, 2694, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2482, '1997-09-03 22:00:00+00', '2022-11-06 21:44:40.167251+00', 'Give a little whistle', 'GIVE A LITTLE WHISTLE', 2, 40, 9999, 5, 56, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2487, '1997-09-03 22:00:00+00', '2022-12-18 20:42:02.783336+00', 'Gladys Allan''s Fancy', 'GLADYS ALLANS FANCY', 4, 128, 9999, 4, 4, NULL, 377, NULL, 'Devised for Gladys Allan of Ickenham.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2526, '1998-01-04 23:00:00+00', '2023-01-27 11:36:36.988889+00', 'Glen Cova', 'GLEN COVA', 1, 32, 9999, 1, 3, 42, 748, NULL, '', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2427, '1997-04-03 22:00:00+00', '2023-01-27 11:58:43.091152+00', 'General Ritchie''s Reel', 'GENERAL RITCHIES REEL', 2, 32, 9999, 1, 3, 42, 62, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2548, '1997-04-03 22:00:00+00', '2012-01-20 12:56:20.271705+00', 'Glenisla', 'GLENISLA', 3, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2549, '1997-09-03 22:00:00+00', '2012-01-20 12:56:20.278572+00', 'Glenisla', 'GLENISLA', 3, 48, 9999, 1, 2, NULL, 477, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13485, '2009-11-20 23:00:00+00', '2018-03-04 17:17:52.340443+00', 'Careless Philosopher, A', 'CARELESS PHILOSOPHER', 1, 32, 9999, 1, 3, 42, 3783, NULL, 'Mr Yamagishi likes to think carefully and seriously about anything, but unfortunately for him, lost in

contemplation, he often stumbles in dancing.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2521, '1998-07-08 22:00:00+00', '2014-04-26 20:22:52.545007+00', 'Glenburnie Rant', 'GLENBURNIE RANT', 1, 32, 9999, 1, 4, 2, 101, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10873, '2002-10-29 23:00:00+00', '2012-01-20 12:57:24.683801+00', 'Travesty Reel', 'TRAVESTY REEL', 1, 32, 9999, 2, 3, NULL, 3645, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10874, '2002-10-29 23:00:00+00', '2012-01-20 12:57:24.693064+00', 'Cup o'' Kindness, A', 'CUP O KINDNESS', 1, 32, 9999, 3, 5, NULL, 3645, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2528, '1997-04-03 22:00:00+00', '2018-04-03 00:07:48.61479+00', 'Glendarroch Gathering', 'GLENDARROCH GATHERING', 2, 48, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2498, '2000-09-20 22:00:00+00', '2020-03-10 20:28:24.386967+00', 'Glasgow Highlanders, The', 'GLASGOW HIGHLANDERS', 3, 32, 9999, 1, 106, 53, 9998, NULL, 'Tue 2020-03-10 Robb Quint <volleyballjerry@aol.com> wrote: 



RQ  Having Marjorie McLaughlin "on the line" and knowing how knowledgeable she is about SCD history, I questioned her about something that had made me curious:



RQ  My source information for the dance had come from the SCDDB, that The Glasgow Highlanders had been devised by one Walter F. Gillies (1851-1909) in the 1880s.   And I had consulted my own dusty old copy of RSCDS Book 2 (no printing date, but it shows "Miss M. F. Hadden" as secretary, and she retired in 1967) to see whether there was anything more, and I had been surprised to find less, in fact nothing whatsoever about any deviser.  Now I know that the folks at the SCDDB don''t just make things up, so I figured that perhaps subsequent research had led to the Society''s having added that source information in a later printing, and indeed Marjorie solved that particular mystery with:



MM  My copy of Book 2 is a 1998 revised edition, and it does include the source as W. F. Gillies Manual of Dancing, or a Companion to the Ballroom, Glasgow, c. 1885.



RQ  This still seemed odd to me, so I queried further.  I mentioned to Marjorie that there is a "deviser gap" of about 150 years in RSCDS-published books in that dances from the 1923 founding of the Society until today have either been republished from devisers (if cited at all) in old manuscripts of the latter-18th or early-19th centuries or modern devisers whose dances were published sporadically from the 1960s onward and not consistently until the 1980s.  And this RSCDS-dance deviser Walter Gillies, listed in the SCDDB with no other dances to his name (no doubt taken from the RSCDS information) from the latter 19th century, is just an anachronistic oddity with no other such that I had e''er seen from RSCDS-published materials...i.e., as previously mentioned, devisers otherwise all seeming to be early 1800s and earlier or 1960s and later with virtually none in between.



To this Marjorie in her wisdom replied:



MM  I have no idea who found it there and thought that to be the origin of the dance, but RSCDS Publications Committee references, particularly in the early books, are suspect or nonexistent!  It is very unlikely that Mr. Gillies can be credited with "devising" the dance; rather his 1885 publication happens to be the one to which the Society had access.  I''ve reread references to The Glasgow Highlanders in Thurston''s Scotland''s Dances, Emmerson''s Scotland Through Her Country Dances, and the Fletts'' Traditional Dancing in Scotland.  All of them mention The Glasgow Highlanders frequently but not one makes mention of W.F. Gillies.  It''s quite clear that the dance was one of many that were in the repertoire of all of the itinerant dancing masters of the late 19th century.  And it appears in Mozart Allan''s 1895 Ball-room Guide (of which I own a treasured copy), which itself is mentioned in the Fletts'' book specifically with reference to The Glasgow Highlanders.  I would therefore say that Mr. Gillies was just one publisher of many who reprinted the dance.  



Eric Ferguson (co-editor): On the basis of his information I have reset "Author" to "(unknown)", and removed the date of creation.  2020-03-10.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2544, '1997-09-03 22:00:00+00', '2020-08-04 22:50:32.634707+00', 'Glengrant', 'GLENGRANT', 3, 32, 9999, 1, 2, 76, 129, '1970-01-01', '', 60, '80/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10863, '2002-10-13 22:00:00+00', '2020-09-13 14:44:57.758342+00', 'Falkirk Bairn, The', 'FALKIRK BAIRN', 3, 32, 9999, 1, 4, 15, 2694, NULL, '', 78, '6666/6666/8822/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10865, '2002-10-13 22:00:00+00', '2020-09-13 14:47:57.088332+00', 'Tribute to Miss Frances Martin, A', 'TRIBUTE TO MISS FRANCES MARTIN', 4, 64, 5, 1, 4, 3, 2694, NULL, '', 94, '8888/8888/8888/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2522, '1997-04-03 22:00:00+00', '2020-10-06 21:47:32.372567+00', 'Glencairn Reel', 'GLENCAIRN REEL', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 56, '888/888/840/480', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19212, '2019-03-03 07:16:25.696305+00', '2020-11-23 10:42:55.146499+00', 'Chongqing Fire', 'CHONGQING FIRE', 1, 32, NULL, 1, 3, 42, 1268, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2524, '1998-07-08 22:00:00+00', '2020-11-29 22:34:15.228965+00', 'Glencarron Strathspey', 'GLENCARRON STRATHSPEY', 3, 32, 9999, 1, 4, 2, 13, NULL, '', 88, '8888/8448/8888/8448', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10862, '2002-10-13 22:00:00+00', '2021-02-04 12:54:07.85631+00', 'Welcome to Callum', 'WELCOME TO CALLUM', 1, 32, 9999, 1, 4, 1, 2694, NULL, '', 81, '8888/8440/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2491, '1998-11-16 23:00:00+00', '2021-03-11 19:48:00.409944+00', 'Glasgow 1990', 'GLASGOW 1990', 2, 32, 9999, 1, 4, 1, 87, '1990-01-01', '', 69, '6666/8888/8044/0808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2514, '1997-04-03 22:00:00+00', '2021-06-06 19:20:44.17214+00', 'Glen Falloch', 'GLEN FALLOCH', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 63, '800/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10876, '2002-10-29 23:00:00+00', '2012-02-03 09:16:26.973409+00', 'It''s Raining Haggis and Herring!', 'ITS RAINING HAGGIS AND HERRING', 3, 40, 9999, 2, 3, NULL, 3645, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2553, '1998-01-05 23:00:00+00', '2012-01-20 12:56:20.348938+00', 'Glenlomond Reel', 'GLENLOMOND REEL', 1, 32, 9999, 1, 2, NULL, 173, '1968-07-04', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2554, '1997-04-03 22:00:00+00', '2012-01-20 12:56:20.355876+00', 'Glenmaeran', 'GLENMAERAN', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2560, '1997-04-03 22:00:00+00', '2012-01-20 12:56:20.410691+00', 'Glenrothes Reel', 'GLENROTHES REEL', 1, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2537, '1997-09-03 22:00:00+00', '2018-04-03 00:07:48.698206+00', 'Glenfinnan Jig, The', 'GLENFINNAN JIG', 2, 32, 9999, 1, 3, 42, 960, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2564, '2002-02-27 23:00:00+00', '2012-01-20 12:56:20.445727+00', 'Glens Of Kingussie', 'GLENS OF KINGUSSIE', 3, 32, 9999, 1, 4, NULL, 964, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2565, '1999-04-19 22:00:00+00', '2012-01-20 12:56:20.455376+00', 'Glenshee Strathspey, The', 'GLENSHEE STRATHSPEY', 3, 32, 9999, 1, 4, 1, 87, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2567, '1997-04-03 22:00:00+00', '2012-01-20 12:56:20.472772+00', 'Glentromie', 'GLENTROMIE', 3, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2569, '1997-09-03 22:00:00+00', '2012-01-20 12:56:20.492509+00', 'Glenveagh Strathspey, The', 'GLENVEAGH STRATHSPEY', 3, 40, 9999, 4, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2539, '1997-09-03 22:00:00+00', '2018-04-03 00:07:48.714864+00', 'Glenfinnan Strathspey, The', 'GLENFINNAN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 960, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10875, '2002-10-29 23:00:00+00', '2017-02-14 20:20:29.050649+00', 'Little Dolphin''s Jig', 'LITTLE DOLPHINS JIG', 2, 32, 9999, 2, 3, 17, 3645, '2002-08-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2541, '1997-09-03 22:00:00+00', '2018-04-03 00:07:48.731477+00', 'Glengarry''s March', 'GLENGARRYS MARCH', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2555, '1997-09-03 22:00:00+00', '2018-04-03 00:07:48.839989+00', 'Glenmoor, The', 'GLENMOOR', 2, 40, 9999, 1, 3, 42, 734, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2561, '1997-09-12 22:00:00+00', '2018-04-03 00:07:48.881757+00', 'Glenrowan Jig', 'GLENROWAN JIG', 2, 32, 9999, 1, 3, 42, 318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2570, '1997-04-03 22:00:00+00', '2018-04-03 00:07:48.990206+00', 'Glint of Sunlight, The', 'GLINT OF SUNLIGHT', 3, 24, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2576, '1997-04-03 22:00:00+00', '2018-04-03 00:07:49.057272+00', 'Glowing Embers', 'GLOWING EMBERS', 3, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10868, '2002-10-29 23:00:00+00', '2018-04-03 00:07:50.766862+00', 'Happy Hornpipe, The', 'HAPPY HORNPIPE', 1, 32, 9999, 1, 3, 42, 3645, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2542, '1997-09-03 22:00:00+00', '2018-04-03 00:07:50.933702+00', 'Harry''s Hornpipe', 'HARRYS HORNPIPE', 1, 32, 9999, 1, 3, 42, 989, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2559, '1997-09-03 22:00:00+00', '2018-04-03 00:07:51.092172+00', 'Hawk That Swoops on High, The', 'HAWK THAT SWOOPS ON HIGH', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10870, '2002-10-29 23:00:00+00', '2018-04-03 00:07:52.176074+00', 'Highlandman''s Only Leg, The', 'HIGHLANDMANS ONLY LEG', 3, 32, 9999, 1, 3, 42, 3645, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10871, '2002-10-29 23:00:00+00', '2018-04-03 00:08:12.433187+00', 'Reel of the Drums', 'REEL OF THE DRUMS', 1, 32, 9999, 1, 3, 42, 3645, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10869, '2002-10-29 23:00:00+00', '2018-04-03 00:08:15.343636+00', 'Scottish Flavour', 'SCOTTISH FLAVOUR', 2, 32, 9999, 1, 3, 42, 3645, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13489, '2009-11-20 23:00:00+00', '2018-03-02 17:39:26.032464+00', 'Happy Rovers', 'HAPPY ROVERS', 4, 96, 21, 4, 4, 3, 3783, NULL, 'Sendai Irish Rovers is one of the oldest Scottish Country Dance groups in Japan. Every autumn many dancers from all over the country come to Sendai to attend the annual dancing event held by Sendai Irish Rovers.



The dancers of Sendai Irish Rovers and Shinjuku Happy Meeting travelled round Scotland in 2004 and 2007. I named the tour group "Happy Rovers".', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3832, '2002-12-07 23:00:00+00', '2018-10-14 09:00:56.866966+00', 'Linn of Dee', 'LINN OF DEE', 4, 128, 2, 1, 100, 3, 108, '1971-01-01', '', 100, '8888/8888/8888/8888/8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3806, '2003-02-10 23:00:00+00', '2019-03-14 23:40:42.597644+00', 'Lights On Lochindaal, The', 'LIGHTS ON LOCHINDAAL', 1, 96, 9999, 6, 3, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3780, '1998-10-22 22:00:00+00', '2012-01-20 12:56:30.704945+00', 'Leslie House', 'LESLIE HOUSE', 4, 128, 2, 1, 4, NULL, 50, '1964-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10872, '2002-10-29 23:00:00+00', '2022-10-21 07:05:01.89638+00', 'Dancin'' Witches', 'DANCIN WITCHES', 2, 32, 9999, 1, 3, 42, 3645, '2002-01-01', '', 44, '800/800/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10882, '2002-10-23 22:00:00+00', '2022-12-22 18:29:11.244684+00', 'Mrs Nona Craig', 'MRS NONA CRAIG', 1, 32, 9999, 7, 98, NULL, 725, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10860, '2002-11-01 23:00:00+00', '2022-12-25 19:10:40.864533+00', 'Piper''s Wedding, The', 'PIPERS WEDDING', 4, 128, 2, 1, 100, 2, 1445, '1999-01-01', 'In its publication "Thistle Club Jubilee Book 1977-2002", the tune "The White Bridge" is incorrectly assigned to be "traditional" (handwritten content by Ian Slater). The tune shown there is Nancy Dickson''s tune.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2573, '1998-07-08 22:00:00+00', '2023-01-27 11:26:25.627914+00', 'Glorious Twelfth', 'GLORIOUS TWELFTH', 2, 32, 9999, 1, 4, 2, 697, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2530, '1997-09-03 22:00:00+00', '2023-01-27 11:32:09.797964+00', 'Glendyke Rant, The', 'GLENDYKE RANT', 1, 32, 9999, 1, 3, 42, 958, NULL, 'Inscribed to Miss Ethel Griffin, President of the Liverpool Burns Club 1990/91.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2472, '1997-12-21 23:00:00+00', '2023-01-27 11:54:31.106164+00', 'Gimme a Break', 'GIMME A BREAK', 1, 32, 9999, 2, 3, 17, 9, NULL, 'Inscribed to Miss E. E. Black, Ottawa Branch, R.S. C.D.S.', 92, '888/888/888/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18561, '2018-09-09 17:04:32.678489+00', '2019-09-02 11:18:09.812691+00', 'Devil''s In The Detail, The', 'DEVILS IN THE DETAIL', 1, 32, NULL, 1, 4, 1, 11000, NULL, '', 38, '8000/8000/8880/8000', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3795, '1997-04-03 22:00:00+00', '2012-01-20 12:56:30.816178+00', 'Liberty For The Sailors', 'LIBERTY FOR THE SAILORS', 2, 32, 9999, 5, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3796, '1998-07-08 22:00:00+00', '2012-01-20 12:56:30.824146+00', 'Liberty Jig', 'LIBERTY JIG', 2, 32, 9999, 1, 4, 2, 108, '1989-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3801, '2002-03-02 23:00:00+00', '2012-01-20 12:56:30.863573+00', 'Lift on Me My Pipes!', 'LIFT ON ME MY PIPES', 3, 32, 9999, 1, 4, 1, 35, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3804, '1997-04-03 22:00:00+00', '2012-01-20 12:56:30.888709+00', 'Light''s Vision', 'LIGHTS VISION', 3, 64, 9999, 1, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3797, '1998-07-08 22:00:00+00', '2020-08-31 14:39:34.680194+00', 'Lichted Ha'', The', 'LICHTED HA', 3, 32, 9999, 1, 100, 2, 108, '1975-02-02', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2579, '1997-04-03 22:00:00+00', '2020-09-28 09:30:49.218544+00', 'Gobbie Oh!, The', 'GOBBIE OH', 2, 32, 9999, 1, 4, 1, 270, NULL, '', 64, '8666/8080/8888/8000', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2572, '1997-04-03 22:00:00+00', '2020-10-02 17:51:52.299677+00', 'Gloomy Winter', 'GLOOMY WINTER', 3, 32, 9999, 1, 3, 42, 270, NULL, '', 47, '880/822/888/800', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10890, '2002-10-20 22:00:00+00', '2021-02-03 15:36:16.230752+00', 'Corner after Corner after Corner', 'CORNER AFTER CORNER AFTER CORNER', 1, 32, 9999, 1, 3, 42, 108, '2002-05-01', '', 47, '800/844/844/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10889, '2002-10-20 22:00:00+00', '2021-02-03 15:39:24.725702+00', 'Consumption Dyke', 'CONSUMPTION DYKE', 3, 40, 9999, 1, 4, 2, 108, '2002-01-01', '', 82, '8888/8228/8888/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10888, '2002-10-20 22:00:00+00', '2021-02-03 15:43:03.221528+00', 'Angela and the Swan', 'ANGELA AND THE SWAN', 3, 32, 9999, 1, 3, 42, 108, '2002-01-01', '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10887, '2002-10-20 22:00:00+00', '2021-02-03 15:45:26.019297+00', 'Touch of Disblair, A', 'TOUCH OF DISBLAIR', 1, 32, 9999, 1, 2, 76, 108, '2002-01-01', '', 52, '44/88/88/80', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10886, '2002-10-20 22:00:00+00', '2021-02-03 15:48:36.745746+00', 'Double Dose, A', 'DOUBLE DOSE', 2, 32, 9999, 1, 4, 2, 108, '2002-01-01', '', 100, '8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10878, '2002-10-15 22:00:00+00', '2021-02-04 12:07:56.207334+00', 'London Pride', 'LONDON PRIDE', 1, 32, 9999, 1, 3, 42, 325, '2002-01-01', '', 50, '800/888/888/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3778, '2000-03-30 22:00:00+00', '2021-05-15 18:29:35.273274+00', 'Lesley Nixon''s Reel', 'LESLEY NIXONS REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, 'Called Lesley''s Reel in the PDF version', 66, '880/848/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2571, '1998-04-12 22:00:00+00', '2021-06-03 00:06:06.659977+00', 'Glittering Caves, The', 'GLITTERING CAVES', 4, 32, 1, 1, 3, 42, 44, '1992-01-01', '', 56, '880/888/822/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2543, '1997-09-03 22:00:00+00', '2021-06-03 14:02:00.238194+00', 'Glen Grant', 'GLEN GRANT', 2, 32, 9999, 1, 3, 42, 21, '1977-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2566, '1997-04-03 22:00:00+00', '2021-06-17 21:39:55.961093+00', 'Glensheil Rant', 'GLENSHEIL RANT', 1, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10901, '2002-10-23 22:00:00+00', '2012-01-20 12:57:24.942194+00', 'Bodhran Drum, The', 'BODHRAN DRUM', 1, 32, 9999, 1, 4, 1, 725, '1998-01-01', 'music is The Corries singing with the bodhran drum Wha Wadna Fecht for Charlie on The Very Best of the Corries', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14423, '2012-05-01 22:17:06.13893+00', '2012-05-01 22:36:03.875357+00', 'Marr''s Jorum', 'MARRS JORUM', 2, 40, NULL, 5, 2, NULL, 10616, '1996-03-09', 'Couple face Couple RR.



For Archie and Nan Marr''s Ruby (40th) Wedding on 9th march 1996 ', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3848, '1997-04-03 22:00:00+00', '2012-01-20 12:56:31.204798+00', 'Liverpool Hornpipe', 'LIVERPOOL HORNPIPE', 1, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3846, '1997-09-07 22:00:00+00', '2016-09-04 20:26:44.242479+00', 'Little Snap, The', 'LITTLE SNAP', 3, 32, 9999, 1, 3, 42, 351, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10902, '2002-11-02 23:00:00+00', '2018-04-03 00:07:53.335373+00', 'Improviser, The', 'IMPROVISER', 2, 32, 9999, 1, 3, 42, 725, '1998-01-01', 'The dancing couple then have to tell the rest of the set what they have to do for the last 8 bars - no repeats!!!!!', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3790, '1997-09-07 22:00:00+00', '2018-04-03 00:07:59.456742+00', 'Leuchars Leap', 'LEUCHARS LEAP', 1, 32, 9999, 1, 3, 42, 719, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3817, '1997-12-27 23:00:00+00', '2018-04-03 00:07:59.590058+00', 'Lincoln Park', 'LINCOLN PARK', 2, 32, 9999, 1, 3, 42, 361, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3779, '1997-12-03 23:00:00+00', '2018-04-03 00:08:01.958531+00', 'Maple Ridge Jig', 'MAPLE RIDGE JIG', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10899, '2002-10-20 22:00:00+00', '2018-04-03 00:08:03.017981+00', 'Meikle Wartle', 'MEIKLE WARTLE', 1, 32, 9999, 1, 3, 42, 108, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18693, '2018-10-02 13:07:00.941887+00', '2018-10-02 13:07:00.941887+00', 'Caesar''s Folly', 'CAESARS FOLLY', 1, 32, NULL, 1, 3, 42, 2766, '2016-02-01', 'Leap years were introduced by Julius Caesar and this dance was written on leap day.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3836, '1998-01-05 23:00:00+00', '2018-04-02 23:56:35.919678+00', 'Lion Rampant, The', 'LION RAMPANT', 1, 24, 9999, 1, 3, 42, 352, '1993-07-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3864, '1998-04-12 22:00:00+00', '2019-03-14 22:07:37.011054+00', 'Loch Linnhe', 'LOCH LINNHE', 3, 32, 9999, 2, 3, 17, 146, '1986-01-01', '', 83, '888/888/840/848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3825, '1997-06-22 22:00:00+00', '2012-01-20 12:56:31.036592+00', 'Lindsay Ross', 'LINDSAY ROSS', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3831, '1997-04-03 22:00:00+00', '2012-01-20 12:56:31.080421+00', 'Linn Of Dee', 'LINN OF DEE', 3, 32, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3835, '1997-04-03 22:00:00+00', '2012-01-20 12:56:31.109308+00', 'Linton Ramble', 'LINTON RAMBLE', 3, 32, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3839, '1998-04-12 22:00:00+00', '2012-01-20 12:56:31.140029+00', 'Little Dither On The Marsh', 'LITTLE DITHER ON THE MARSH', 4, 32, 1, 1, 2, NULL, 389, '1987-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3841, '1997-04-03 22:00:00+00', '2012-01-20 12:56:31.15403+00', 'Little Lad, The', 'LITTLE LAD', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3843, '1997-09-07 22:00:00+00', '2012-01-20 12:56:31.170049+00', 'Little Meldrum Jig', 'LITTLE MELDRUM JIG', 2, 32, 9999, 1, 2, NULL, 719, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10913, '2002-11-11 23:00:00+00', '2014-02-10 21:35:16.986913+00', 'Alma''s Strathspey', 'ALMAS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 3211, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3850, '1997-09-18 22:00:00+00', '2012-01-20 12:56:31.218616+00', 'Lix Toll', 'LIX TOLL', 3, 32, 9999, 1, 4, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3853, '1997-09-08 22:00:00+00', '2012-01-20 12:56:31.23907+00', 'Lloyds Of Begbroke', 'LLOYDS OF BEGBROKE', 1, 32, 9999, 1, 4, NULL, 1079, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3865, '1998-07-08 22:00:00+00', '2012-01-20 12:56:31.326136+00', 'Loch McNess', 'LOCH MACNESS', 3, 32, 9999, 1, 4, 2, 108, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3867, '2002-01-08 23:00:00+00', '2012-01-20 12:56:31.342812+00', 'Loch Na Keal', 'LOCH NA KEAL', 3, 32, 9999, 1, 4, 1, 141, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3868, '2002-04-03 22:00:00+00', '2012-01-20 12:56:31.349682+00', 'Loch Ness Hornpipe', 'LOCH NESS HORNPIPE', 1, 40, 9999, 1, 4, NULL, 108, '1979-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3871, '1997-09-08 22:00:00+00', '2012-01-20 12:56:31.370438+00', 'Loch Of The Lowes, The', 'LOCH OF THE LOWES', 3, 32, 9999, 4, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4066, '1997-04-03 22:00:00+00', '2018-04-03 00:08:01.491494+00', 'Maggie', 'MAGGIE', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10898, '2002-10-20 22:00:00+00', '2020-07-06 19:13:00.922233+00', 'M-J-P', 'MJP', 1, 32, 9999, 1, 2, 76, 108, '2002-01-01', '', 60, '84/48/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2578, '1997-09-03 22:00:00+00', '2021-06-03 00:01:02.483642+00', 'Goathland Road, The', 'GOATHLAND ROAD', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 56, '800/844/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3883, '1997-11-18 23:00:00+00', '2021-05-01 21:50:59.541717+00', 'Lochanside', 'LOCHANSIDE', 5, 72, 9999, 1, 4, NULL, 9998, NULL, 'Uses walking step (and pas de basque).', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10917, '2002-11-11 23:00:00+00', '2022-09-30 11:41:31.932542+00', 'Vital Spark, The', 'VITAL SPARK', 1, 48, 9999, 4, 4, 1, 3215, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10916, '2002-11-11 23:00:00+00', '2022-09-30 11:44:24.164407+00', 'Colgrain Fancy', 'COLGRAIN FANCY', 1, 32, 9999, 1, 4, 1, 3214, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10897, '2002-10-20 22:00:00+00', '2022-09-30 11:51:27.922257+00', 'Just Like Clockwork', 'JUST LIKE CLOCKWORK', 2, 32, 9999, 1, 4, 2, 108, '2002-04-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10904, '2002-12-15 23:00:00+00', '2022-12-22 18:30:13.601151+00', 'Oliver''s Fifth', 'OLIVERS FIFTH', 1, 32, 9999, 2, 2, 76, 725, '1998-01-01', '', 50, '80/88/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3782, '1997-04-03 22:00:00+00', '2022-12-24 13:51:24.868084+00', 'Lesslie Jig, The', 'LESSLIE JIG', 2, 32, 9999, 3, 5, 7, 109, NULL, 'From the dance description: This dance is dedicated to Mrs. Florence Lesslie on the occasion of her first visit to Newcastle in May 1966.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3854, '1998-04-15 22:00:00+00', '2021-05-14 19:28:39.932494+00', 'Lobster in the Pot, A', 'LOBSTER IN THE POT', 2, 32, 9999, 1, 2, 76, 82, NULL, 'The notes say this is a children''s dance and can be danced in a four couple set or as a round the room dance.', 53, '81/88/88/80', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3842, '1997-04-03 22:00:00+00', '2020-08-06 15:46:49.403627+00', 'Little Larrikin', 'LITTLE LARRIKIN', 2, 80, 9999, 4, 4, NULL, 151, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3845, '1997-08-20 22:00:00+00', '2021-05-14 20:14:43.151593+00', 'Little Ross Light', 'LITTLE ROSS LIGHT', 2, 32, 9999, 1, 2, 76, 108, '1964-01-01', 'Little Ross Light is on an island at the mouth of the River Dee near Kirkcudbright. On clear nights the light can be seen across the Solway Firth from Whitehaven.', 60, '77/77/66/88', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3793, '1997-04-03 22:00:00+00', '2020-11-08 10:51:22.855181+00', 'Leveneep Head', 'LEVENEEP HEAD', 1, 48, 9999, 1, 3, 42, 270, NULL, '', 57, '888/888/770/880/888/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3785, '1997-12-03 23:00:00+00', '2020-08-31 14:36:30.064949+00', 'Hemmen Lane', 'HEMMEN LANE', 2, 32, 9999, 1, 3, 42, 946, NULL, '', 66, '888/888/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10918, '2002-11-12 23:00:00+00', '2021-02-02 16:52:20.443886+00', 'Cats Paw', 'CATS PAW', 1, 32, 9999, 1, 3, 42, 2673, NULL, '', 50, '800/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10915, '2002-11-11 23:00:00+00', '2021-02-02 16:59:51.145559+00', 'Golden Celebration, A', 'GOLDEN CELEBRATION', 1, 32, 9999, 1, 3, 42, 3213, '2001-01-01', '', 66, '484/888/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10896, '2002-10-20 22:00:00+00', '2021-02-03 15:19:00.323299+00', 'Holy Cow!!!', 'HOLY COW', 2, 32, 9999, 1, 2, 76, 108, '2002-01-01', '', 56, '66/66/66/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10895, '2002-10-20 22:00:00+00', '2021-02-03 15:23:18.642262+00', 'Get Your Skates On!', 'GET YOUR SKATES ON', 1, 32, 9999, 1, 3, 42, 108, '2002-01-01', '', 56, '800/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10894, '2002-10-20 22:00:00+00', '2021-02-03 15:27:26.733861+00', 'Get Yoursel'' a Toyboy!', 'GET YOURSEL A TOYBOY', 2, 32, 9999, 1, 3, 42, 108, '2002-01-01', '', 48, '888/640/880/804', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10893, '2002-10-20 22:00:00+00', '2021-04-17 17:21:18.811808+00', 'From the Black Isle to the Black Sea', 'FROM THE BLACK ISLE TO THE BLACK SEA', 1, 32, 9999, 1, 3, 42, 108, '2002-01-01', '', 53, '660/888/800/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3816, '1997-09-07 22:00:00+00', '2021-02-19 15:38:42.523065+00', 'Lincoln Assembly', 'LINCOLN ASSEMBLY', 1, 32, 9999, 1, 4, NULL, 1076, '1960-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3860, '1998-07-08 22:00:00+00', '2021-06-20 20:56:49.820091+00', 'Loch Fad', 'LOCH FAD', 3, 32, 9999, 1, 4, 11, 352, '1990-11-24', '', 72, '8844/8008/8888/8228', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3855, '1998-07-09 22:00:00+00', '2017-08-19 21:37:25.64638+00', 'Loch Assipol', 'LOCH ASSIPOL', 1, 32, 9999, 3, 5, 16, 270, NULL, '', 100, '88888/88888/88888/88888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3819, '1997-04-03 22:00:00+00', '2018-04-03 00:07:59.606806+00', 'Lincolnwood Assembly', 'LINCOLNWOOD ASSEMBLY', 1, 32, 9999, 1, 3, 42, 361, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3820, '2003-01-25 23:00:00+00', '2018-04-03 00:07:59.615108+00', 'Linda''s Fete', 'LINDAS FETE', 3, 40, 9999, 1, 3, 42, 35, '1978-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3822, '2002-04-19 22:00:00+00', '2018-04-03 00:07:59.631919+00', 'Linda''s Strathspey', 'LINDAS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3823, '1997-09-07 22:00:00+00', '2018-04-03 00:07:59.640072+00', 'Linda''s Wedding/Don''s Delight', 'LINDAS WEDDING/DONS DELIGHT', 4, 64, 9999, 1, 3, 42, 782, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3824, '1997-09-07 22:00:00+00', '2018-04-03 00:07:59.665125+00', 'Linden Jig', 'LINDEN JIG', 2, 32, 9999, 1, 3, 42, 2805, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3826, '1997-04-03 22:00:00+00', '2018-04-03 00:07:59.698507+00', 'Linen Cap, The', 'LINEN CAP', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3827, '1997-09-07 22:00:00+00', '2018-04-03 00:07:59.756873+00', 'Link with Home, A', 'LINK WITH HOME', 3, 32, 9999, 1, 3, 42, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3840, '2000-07-02 22:00:00+00', '2018-04-03 00:07:59.806882+00', 'Littlejohn''s Hame', 'LITTLEJOHNS HAME', 3, 32, 9999, 1, 3, 42, 108, '1971-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3844, '1997-04-03 22:00:00+00', '2018-04-03 00:07:59.815295+00', 'Little Pickle', 'LITTLE PICKLE', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3849, '1998-10-20 22:00:00+00', '2018-04-03 00:07:59.848568+00', 'Living Tradition, The', 'LIVING TRADITION', 2, 32, 9999, 1, 3, 42, 632, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3856, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.032053+00', 'Loch Carron', 'LOCH CARRON', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3858, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.057018+00', 'Loch Earn', 'LOCH EARN', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3863, '1997-09-08 22:00:00+00', '2018-04-03 00:08:00.148889+00', 'Loch Leven Trout', 'LOCH LEVEN TROUT', 3, 32, 9999, 1, 3, 42, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3872, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.198797+00', 'Loch Rannoch Reel', 'LOCH RANNOCH REEL', 1, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3873, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.207107+00', 'Loch Rynach', 'LOCH RYNACH', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3874, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.21554+00', 'Loch Sloy', 'LOCH SLOY', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10930, '2005-12-21 23:00:00+00', '2018-04-03 00:07:50.941997+00', 'Harry''s Jig', 'HARRYS JIG', 2, 32, 9999, 1, 3, 42, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3897, '1999-07-25 22:00:00+00', '2018-03-28 19:29:29.297884+00', 'Logan Bridge', 'LOGAN BRIDGE', 3, 32, 9999, 1, 4, 13, 134, '1966-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3884, '1997-09-08 22:00:00+00', '2012-01-20 12:56:31.460987+00', 'Lochearnhead Strathspey', 'LOCHEARNHEAD STRATHSPEY', 3, 32, 9999, 2, 3, NULL, 347, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3903, '1997-09-04 22:00:00+00', '2018-04-03 00:07:51.984244+00', 'Herne Hill Strathspey', 'HERNE HILL STRATHSPEY', 3, 32, 9999, 1, 3, 42, 43, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3899, '1997-04-03 22:00:00+00', '2019-02-21 20:12:50.804025+00', 'Logan Reel, The', 'LOGAN REEL', 1, 32, 9999, 1, 4, 1, 13, NULL, '', 81, '8444/8444/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3904, '2003-01-29 23:00:00+00', '2012-01-20 12:56:31.606048+00', 'London Bridge', 'LONDON BRIDGE', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18562, '2018-09-09 17:43:27.168786+00', '2019-09-02 11:13:56.680301+00', 'Ee Ba Gum Bu''r''am Caud', 'EE BA GUM BURAM CAUD', 1, 32, NULL, 1, 3, 42, 11000, NULL, '', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18563, '2018-09-09 17:53:03.161764+00', '2019-09-02 11:18:56.583218+00', 'Just Warming Up', 'JUST WARMING UP', 2, 32, NULL, 1, 3, 42, 11000, NULL, '', 38, '800/844/800/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3886, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.082062+00', 'Lochiel House', 'LOCHIEL HOUSE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3852, '1997-09-08 22:00:00+00', '2021-06-16 13:48:26.617207+00', 'Llanfair Reel, The', 'LLANFAIR REEL', 1, 32, 9999, 1, 3, 42, 1006, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14421, '2012-05-01 12:26:49.820869+00', '2020-02-29 12:02:00.764348+00', 'Hamburg Welcome, A', 'HAMBURG WELCOME', 1, 32, NULL, 5, 56, 76, 2108, NULL, 'DEVISED:2010', 87, '888/444/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3894, '1998-09-17 22:00:00+00', '2020-08-06 15:49:51.670162+00', 'Lochskerrow', 'LOCHSKERROW', 3, 32, 9999, 3, 5, 7, 129, '1966-01-01', '', 85, '84840/88888/84884/88888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14424, '2012-05-01 22:43:28.252415+00', '2022-08-14 08:51:27.813873+00', 'Miss Marjorie Duffield''s Jig', 'MISS MARJORIE DUFFIELDS JIG', 2, 32, NULL, 1, 4, 1, 9998, '1978-02-25', 'First danced at the RSCDS West Lothian Branch day school', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3910, '2002-03-02 23:00:00+00', '2022-08-18 19:59:01.295237+00', 'Lone Sheiling, The', 'LONE SHEILING', 3, 32, 9999, 1, 100, 11, 313, '1988-01-01', 'For some background information see this <<https://en.wikipedia.org/wiki/Lone_Shieling|wikipedia article>>.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3882, '1998-07-08 22:00:00+00', '2022-12-10 12:51:02.970702+00', 'Lochanora', 'LOCHANORA', 3, 32, 9999, 1, 4, 2, 108, '1983-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3870, '1998-04-12 22:00:00+00', '2022-12-10 12:54:05.898196+00', 'Loch Ness Monster, The', 'LOCH NESS MONSTER', 1, 32, 9999, 7, 1, 4, 44, '1977-01-01', 'For any number of couples in a single big circle.  Partner changes  each time through.', 100, '8/8/8/8', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3837, '1997-04-03 22:00:00+00', '2022-12-10 12:56:26.716682+00', 'Lions International', 'LIONS INTERNATIONAL', 2, 48, 9999, 1, 3, 42, 167, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10910, '2002-11-02 23:00:00+00', '2022-12-22 18:20:29.614622+00', 'Baiglieburn', 'BAIGLIEBURN', 3, 32, 9999, 1, 3, 42, 725, '1998-01-01', '', 53, '888/800/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10908, '2002-11-02 23:00:00+00', '2022-12-22 18:25:39.116206+00', 'Eyemouth Harbour Reel, The', 'EYEMOUTH HARBOUR REEL', 1, 32, 9999, 1, 3, 42, 725, '1998-01-01', '', 44, '800/888/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3833, '1997-11-27 23:00:00+00', '2023-01-03 15:02:22.910528+00', 'Linn of Dee Medley', 'LINN OF DEE MEDLEY', 4, 32, 1, 1, 4, 1, 697, NULL, '', 72, '8008/8444/8888/6864', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3889, '1997-09-08 22:00:00+00', '2020-08-31 14:52:13.740739+00', 'Lochmaben', 'LOCHMABEN', 1, 32, 9999, 1, 4, 1, 270, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10937, '2002-11-24 23:00:00+00', '2021-02-01 17:25:06.890641+00', 'Wedding Link, The', 'WEDDING LINK', 2, 32, 9999, 1, 3, 42, 3224, NULL, 'Devised for the wedding of Andrew and Fiona Eelbeck', 55, '886/800/808/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10936, '2002-11-28 23:00:00+00', '2021-02-01 17:28:21.452929+00', 'Kirkmaiden Strathspey', 'KIRKMAIDEN STRATHSPEY', 3, 80, 9999, 4, 4, 3, 3223, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10935, '2002-11-28 23:00:00+00', '2021-02-01 17:30:53.715279+00', 'Good Friends', 'GOOD FRIENDS', 2, 32, 9999, 1, 100, 2, 2893, '1999-02-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10934, '2002-11-14 23:00:00+00', '2021-02-01 17:35:06.794864+00', 'Bonnie Beauly Blooms, The', 'BONNIE BEAULY BLOOMS', 1, 32, 9999, 1, 3, 42, 2893, NULL, '', 75, '888/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10931, '2002-12-05 23:00:00+00', '2021-02-02 16:42:04.906623+00', 'Roddy''s Reel', 'RODDYS REEL', 1, 32, 9999, 1, 4, 2, 21, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10929, '2002-11-13 23:00:00+00', '2021-02-02 16:45:00.718571+00', 'Bennets of Invergloy', 'BENNETS OF INVERGLOY', 2, 32, 9999, 1, 4, 1, 3577, NULL, '', 75, '8000/8888/8088/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10927, '2002-11-13 23:00:00+00', '2021-02-02 16:48:33.534237+00', '75th Anniversary Reel', '75TH ANNIVERSARY REEL', 1, 32, 9999, 1, 4, 1, 1253, NULL, '', 56, '4444/4444/8888/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3909, '1997-09-06 22:00:00+00', '2021-04-17 19:04:12.334527+00', 'London Reel', 'LONDON REEL', 1, 32, 9999, 1, 3, 42, 129, '1967-01-01', '', 46, '440/888/840/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3908, '1997-04-03 22:00:00+00', '2021-05-13 21:12:39.890639+00', 'London Pride', 'LONDON PRIDE', 3, 32, 9999, 1, 2, 76, 44, NULL, '', 60, '88/88/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3893, '1997-04-03 22:00:00+00', '2021-05-14 09:05:55.676091+00', 'Lochside', 'LOCHSIDE', 1, 32, 9999, 1, 4, 1, 200, NULL, '', 69, '5555/5555/6666/8880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3861, '1998-11-16 23:00:00+00', '2021-05-14 18:57:21.289407+00', 'Loch Katrine Jig, The', 'LOCH KATRINE JIG', 2, 32, 9999, 1, 3, 42, 87, NULL, '', 59, '800/888/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3830, '1998-01-05 23:00:00+00', '2021-05-15 10:07:09.228782+00', 'Linlithgow Palace', 'LINLITHGOW PALACE', 1, 32, 9999, 1, 3, 42, 347, NULL, '', 47, '800/822/888/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3828, '1997-04-03 22:00:00+00', '2021-05-15 10:41:26.013825+00', 'Links O'' Forth, The', 'LINKS O FORTH', 1, 32, 9999, 1, 3, 42, 62, '1973-09-01', 'Devised for <<ddp:#86|Mina Corson>>. The dance shows that Mina''s interesting new progression "The Knot" is easily performed in fast time. The music should not be played too quickly.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3890, '1998-01-05 23:00:00+00', '2018-04-03 00:08:00.165526+00', 'Lochmaben Castle', 'LOCHMABEN CASTLE', 1, 32, 9999, 1, 3, 42, 108, '1968-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9761, '2002-04-02 22:00:00+00', '2014-10-26 23:36:48.299361+00', 'Above the Clouds', 'ABOVE THE CLOUDS', 3, 32, 9999, 1, 3, 42, 104, '1993-04-01', 'Devised for Andrew Cockett who, with his connection with British Airways, is frequently above the clouds.', 59, '880  888  822  888', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (12838, '2006-09-03 22:00:00+00', '2014-04-30 23:23:37.11248+00', 'Accordion Player, The', 'ACCORDION PLAYER', 1, 32, 9999, 1, 3, 42, 3703, NULL, 'Dedicated to Liz Donaldson, great musician and piano player, who impressed us al whenshe took up the accordion!', 56, '844  844  888  844', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (3961, '1998-07-08 22:00:00+00', '2012-01-20 12:56:32.019454+00', 'Lost Glen, The', 'LOST GLEN', 3, 32, 9999, 1, 4, 2, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3895, '1997-09-08 22:00:00+00', '2018-04-03 00:08:00.24901+00', 'Locomotive, The', 'LOCOMOTIVE', 2, 40, 9999, 1, 3, 42, 1080, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10923, '2002-11-12 23:00:00+00', '2015-04-01 23:24:38.321518+00', 'Glenlivet Revels', 'GLENLIVET REVELS', 2, 32, 9999, 7, 2, NULL, 9998, NULL, '', 100, '8  8  8  8', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10925, '2002-11-12 23:00:00+00', '2015-11-03 08:39:57.1834+00', 'Janet Over the Water', 'JANET OVER THE WATER', 3, 32, 9999, 1, 2, NULL, 9998, NULL, 'The dance is in memory of Janet Brabham, who was once a student of Miss Allie Anderson. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14427, '2012-05-05 08:54:56.804797+00', '2015-11-08 23:16:32.138296+00', 'Denise''s Delight', 'DENISES DELIGHT', 2, 32, 9999, 1, 4, 1, 1502, '2008-01-01', '', 75, '8008/0880/8888/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10932, '2005-03-03 23:00:00+00', '2016-05-30 12:00:35.667035+00', 'Isle of Islay, The', 'ISLE OF ISLAY', 3, 32, 9999, 4, 4, 13, 9, '2001-01-01', '', 69, '8888//4444/8440/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3902, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.265635+00', 'London Argylls, The', 'LONDON ARGYLLS', 1, 32, 9999, 1, 3, 42, 108, '1981-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3905, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.299045+00', 'London Farewell', 'LONDON FAREWELL', 3, 40, 9999, 1, 3, 42, 362, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3907, '1997-09-08 22:00:00+00', '2018-04-03 00:08:00.336021+00', 'London Jig', 'LONDON JIG', 2, 32, 9999, 1, 3, 42, 62, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3911, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.373973+00', 'Lone Star Reel', 'LONE STAR REEL', 1, 32, 9999, 1, 3, 42, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3960, '2002-04-19 22:00:00+00', '2018-04-03 00:08:00.740912+00', 'Lost Chanter, The', 'LOST CHANTER', 3, 32, 9999, 1, 3, 42, 35, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10939, '2002-11-14 23:00:00+00', '2018-04-03 00:08:17.686898+00', 'Something to Crow About', 'SOMETHING TO CROW ABOUT', 2, 32, 9999, 1, 3, 42, 108, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3951, '1998-01-05 23:00:00+00', '2018-04-29 13:08:53.517348+00', 'Lord Randall''s Bride', 'LORD RANDALLS BRIDE', 1, 32, 9999, 1, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14440, '2012-05-22 12:28:57.888687+00', '2012-05-22 12:28:57.888697+00', 'Moments in Minsk', 'MOMENTS IN MINSK', 3, 32, NULL, 2, 3, 17, 10618, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3913, '1997-08-27 22:00:00+00', '2012-01-20 12:56:31.672253+00', 'Long Island, The', 'LONG ISLAND', 1, 48, 9999, 1, 4, NULL, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3914, '1997-04-03 22:00:00+00', '2012-01-20 12:56:31.679221+00', 'Long Journey, The', 'LONG JOURNEY', 2, 32, 9999, 1, 4, NULL, 393, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3919, '1998-04-12 22:00:00+00', '2012-01-20 12:56:31.71384+00', 'Long Way Home, The', 'LONG WAY HOME', 1, 64, 9999, 1, 4, NULL, 348, '1989-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3926, '1997-09-08 22:00:00+00', '2018-04-03 00:08:00.449038+00', 'Lord Blantyre', 'LORD BLANTYRE', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3927, '1997-09-08 22:00:00+00', '2012-01-20 12:56:31.770141+00', 'Lord Byron''s Jig', 'LORD BYRONS JIG', 2, 28, 9999, 1, 2, NULL, 446, '1701-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3929, '1997-11-24 23:00:00+00', '2012-01-20 12:56:31.78417+00', 'Lord Darnley''s Medley', 'LORD DARNLEYS MEDLEY', 4, 32, 1, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3936, '1997-04-03 22:00:00+00', '2012-01-20 12:56:31.835715+00', 'Lord Kelly''s Cave', 'LORD KELLYS CAVE', 3, 32, 9999, 1, 98, NULL, 237, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3939, '1998-07-09 22:00:00+00', '2012-01-20 12:56:31.860373+00', 'Lord Lyndoch', 'LORD LYNDOCH', 3, 32, 9999, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18703, '2018-10-03 00:29:56.655685+00', '2018-10-03 00:29:56.655685+00', 'Cat Who Wasn''t There, The', 'CAT WHO WASNT THERE', 2, 32, NULL, 1, 3, 42, 2766, '2013-11-01', 'One of our cats disappeared in the house for 3 days. We nearly went crazy looking for him until one morning he just showed up again.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3962, '1997-04-03 22:00:00+00', '2022-11-07 22:00:08.27313+00', 'Lost Land, The', 'LOST LAND', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3892, '2002-02-27 23:00:00+00', '2022-12-10 12:46:14.952182+00', 'Lochnagar', 'LOCHNAGAR', 3, 32, 9999, 1, 3, 42, 108, '1986-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3928, '1997-09-08 22:00:00+00', '2018-04-03 00:08:00.457379+00', 'Lord Cathcart', 'LORD CATHCART', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3930, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.465738+00', 'Lord Duncan Forbes', 'LORD DUNCAN FORBES', 1, 48, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3949, '1997-11-20 23:00:00+00', '2018-04-03 00:08:00.540737+00', 'Lord Ogilvie''s Reel', 'LORD OGILVIES REEL', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3916, '1997-09-08 22:00:00+00', '2020-08-06 15:51:11.837892+00', 'Long Paddock, The', 'LONG PADDOCK', 2, 32, 9999, 1, 1, NULL, 151, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3937, '1997-04-03 22:00:00+00', '2020-08-31 15:19:03.744152+00', 'Lord Kilmarnock', 'LORD KILMARNOCK', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3956, '1997-04-03 22:00:00+00', '2020-11-08 19:58:46.777137+00', 'Lord Wellington', 'LORD WELLINGTON', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 53, '800/855/855/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10949, '2002-11-14 23:00:00+00', '2021-01-31 17:42:31.388333+00', 'Obelus, The', 'OBELUS', 1, 32, 9999, 1, 3, 42, 108, '2002-01-01', '', 63, '880/880/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10947, '2002-11-14 23:00:00+00', '2021-01-31 17:44:37.044493+00', 'Newmachar Reel, The', 'NEWMACHAR REEL', 1, 32, 9999, 1, 4, 2, 108, '2002-01-01', '', 81, '8080/8448/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10946, '2002-11-14 23:00:00+00', '2021-01-31 17:48:05.308834+00', 'Newmachar Jig, The', 'NEWMACHAR JIG', 2, 32, 9999, 1, 4, 2, 108, '2002-01-01', '', 69, '8080/8888/8080/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10945, '2002-11-14 23:00:00+00', '2021-02-01 10:42:42.469033+00', 'Contraflow, The', 'CONTRAFLOW', 1, 32, 9999, 1, 4, 2, 108, '2002-01-01', '', 69, '6666/6666/8448/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10943, '2003-01-16 23:00:00+00', '2021-02-01 10:47:07.67691+00', 'Cocky Wee Gordon, The', 'COCKY WEE GORDON', 2, 32, 9999, 1, 4, 2, 108, '2002-01-01', '', 75, '6666/8888/6666/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10942, '2002-11-14 23:00:00+00', '2021-02-01 17:14:25.242287+00', 'Black Burn Reel, The', 'BLACK BURN REEL', 2, 32, 9999, 1, 4, 1, 108, '2002-01-01', '', 84, '8888/8888/6222/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3887, '1998-09-29 22:00:00+00', '2021-05-14 09:10:37.161237+00', 'Lochiel''s awa'' to France', 'LOCHIELS AWA TO FRANCE', 3, 48, 9999, 1, 3, 42, 9998, '1805-01-01', '', 38, '800/080/008/880/888/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3944, '1997-04-03 22:00:00+00', '2021-10-11 02:56:17.371507+00', 'Lord of Bute, The', 'LORD OF BUTE', 2, 32, 9999, 1, 3, 42, 352, '1991-04-24', '', 56, '888/888/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10507, '2002-11-14 23:00:00+00', '2021-07-17 11:02:33.305654+00', 'Bellstane, The', 'BELLSTANE', 1, 32, 9999, 1, 3, 42, 553, '1994-01-01', 'Devised to commemorate the 10th anniversary of Queensferry SCD Club.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3959, '1997-04-03 22:00:00+00', '2019-02-21 20:15:41.552692+00', 'Lorn Strathspey, The', 'LORN STRATHSPEY', 3, 32, 9999, 1, 4, 1, 108, '1975-02-02', '', 88, '8888/8888/8888/8080', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3947, '1997-04-03 22:00:00+00', '2012-01-20 12:56:31.922372+00', 'Lord of the Dance', 'LORD OF THE DANCE', 1, 88, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3950, '1997-09-08 22:00:00+00', '2012-01-20 12:56:31.942869+00', 'Lord Phoppington', 'LORD PHOPPINGTON', 1, 24, 9999, 1, 2, NULL, 446, '1701-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3952, '1997-04-03 22:00:00+00', '2012-01-20 12:56:31.956568+00', 'Lord Randall''s Bride', 'LORD RANDALLS BRIDE', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3954, '1997-09-08 22:00:00+00', '2012-01-20 12:56:31.970743+00', 'Lord Saltoun''s Reel', 'LORD SALTOUNS REEL', 1, 40, 9999, 1, 4, NULL, 1082, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3955, '1998-01-05 23:00:00+00', '2019-06-24 20:28:11.862446+00', 'Lord Stormont', 'LORD STORMONT', 1, 96, 9999, 4, 4, 3, 885, '1951-01-01', 'Composed in honour of the coming of age, 7 July 1951, of The Viscount Stormont (William Murray 7 July 1930 - 21 October 2015) later Earl of Mansfield. Dance devised and music composed and arranged by David M. Robertson. and published by Rae Macintosh & Co Ltd, Edinburgh', 69, '4444/4444/5555/8484/8888/8080/8848/8888/0808/4444/4444/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3958, '1998-01-04 23:00:00+00', '2012-01-20 12:56:31.998132+00', 'Loreburn Reel, The', 'LOREBURN REEL', 1, 32, 9999, 1, 4, NULL, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10954, '2002-11-14 23:00:00+00', '2015-01-31 01:21:48.195653+00', 'Transit of Venus', 'TRANSIT OF VENUS', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18564, '2018-09-09 19:44:27.612899+00', '2019-09-02 11:16:46.972868+00', 'More In Hope', 'MORE IN HOPE', 2, 32, NULL, 1, 3, 42, 11000, NULL, '', 48, '800/888/824/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3924, '1997-04-03 22:00:00+00', '2016-07-15 05:04:42.904342+00', 'Loose Thread', 'LOOSE THREAD', 2, 32, 9999, 1, 4, 1, 352, '1993-06-11', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3922, '1997-04-03 22:00:00+00', '2016-07-15 05:30:00.048321+00', 'Look Both Ways', 'LOOK BOTH WAYS', 1, 32, 9999, 1, 4, 1, 352, '1993-06-19', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3917, '1997-04-03 22:00:00+00', '2016-09-04 21:04:12.370989+00', 'Long Pond Strathspey, The', 'LONG POND STRATHSPEY', 3, 32, 9999, 1, 2, 76, 351, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10951, '2002-11-14 23:00:00+00', '2016-09-23 22:49:16.192515+00', 'Lindagary Waltz, The', 'LINDAGARY WALTZ', 5, 32, 9999, 7, 1, 4, 1268, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3964, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.04009+00', 'Lothian Lassie, The', 'LOTHIAN LASSIE', 2, 32, 9999, 3, 5, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3990, '1998-01-05 23:00:00+00', '2018-04-29 21:18:45.707497+00', 'Luke Martin''s Reel', 'LUKE MARTINS REEL', 1, 40, 9999, 1, 3, 42, 755, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18566, '2018-09-09 19:56:15.507783+00', '2019-09-02 11:20:14.48005+00', 'Ten Years On', 'TEN YEARS ON', 2, 32, NULL, 1, 4, 5, 11000, NULL, '', 56, '4444/8444/8440/8606', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10964, '2002-11-18 23:00:00+00', '2012-01-20 12:57:25.532585+00', 'Cabot''s Triumph', 'CABOTS TRIUMPH', 3, 0, 9999, NULL, NULL, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10965, '2002-11-18 23:00:00+00', '2012-01-20 12:57:25.539519+00', 'Our Friend Jim', 'OUR FRIEND JIM', 2, 0, 9999, NULL, NULL, NULL, 1378, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10966, '2002-11-18 23:00:00+00', '2012-01-20 12:57:25.546468+00', 'Salmonier Special, The', 'SALMONIER SPECIAL', 1, 0, 9999, NULL, NULL, NULL, 3228, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10971, '2002-11-19 23:00:00+00', '2012-01-20 12:57:25.594641+00', 'Olive''s Farewell', 'OLIVES FAREWELL', 3, 0, 9999, NULL, NULL, NULL, 3229, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10980, '2002-11-23 23:00:00+00', '2018-04-03 00:07:48.031025+00', 'George Miller Reel, The', 'GEORGE MILLER REEL', 1, 40, 9999, 1, 3, 42, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14434, '2012-05-09 13:26:25.677265+00', '2012-05-09 13:26:25.677274+00', 'Fran''s Fancy', 'FRANS FANCY', 3, 32, 9999, 1, 4, 1, 1502, NULL, 'Devised: 2008-05', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14431, '2012-05-08 21:43:53.789767+00', '2013-01-23 13:29:08.682384+00', 'Archie''s Clootie Dumpling', 'ARCHIES CLOOTIE DUMPLING', 1, 64, NULL, 4, 4, 3, 3112, '2005-12-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3969, '1998-01-05 23:00:00+00', '2012-01-20 12:56:32.077084+00', 'Love Is Like a Dizziness', 'LOVE IS LIKE A DIZZINESS', 1, 32, 9999, 3, 5, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3978, '1998-11-02 23:00:00+00', '2019-03-14 21:58:52.058835+00', 'Luck To Len', 'LUCK TO LEN', 3, 32, 9999, 1, 4, 2, 612, '1986-01-01', '', 75, '8800/4884/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3975, '1998-01-12 23:00:00+00', '2012-01-20 12:56:32.119835+00', 'Lowp And Fling', 'LOWP AND FLING', 1, 32, 9999, 5, 56, NULL, 210, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3977, '1997-09-08 22:00:00+00', '2012-01-20 12:56:32.136201+00', 'Luck Penny, The', 'LUCK PENNY', 2, 104, 9999, 6, 54, NULL, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3981, '1997-04-03 22:00:00+00', '2012-08-28 08:02:01.741117+00', 'Lucky Scaup', 'LUCKY SCAUP', 1, 320, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3965, '1998-07-09 22:00:00+00', '2019-08-28 13:31:44.38008+00', 'Louden Woods', 'LOUDEN WOODS', 3, 32, 9999, 2, 3, 17, 517, NULL, '', 92, '888/888/565/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3983, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.195543+00', 'Lucky Middlemass''s Tavern', 'LUCKY MIDDLEMASSS TAVERN', 1, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3985, '1997-09-08 22:00:00+00', '2012-01-20 12:56:32.209245+00', 'Lucky Star', 'LUCKY STAR', 2, 32, 9999, 1, 2, NULL, 696, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3992, '1997-09-08 22:00:00+00', '2012-01-20 12:56:32.257025+00', 'Lundie Gardens', 'LUNDIE GARDENS', 3, 32, 9999, 2, 3, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3993, '1997-12-03 23:00:00+00', '2012-01-20 12:56:32.263783+00', 'Marcia''s Wedding', 'MARCIAS WEDDING', 2, 128, 9999, 3, 5, NULL, 1106, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3971, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.841065+00', 'Lovely Highlands', 'LOVELY HIGHLANDS', 3, 32, 9999, 1, 3, 42, 300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3970, '1997-09-08 22:00:00+00', '2018-04-03 00:08:00.874491+00', 'Love''s Triumph', 'LOVES TRIUMPH', 1, 48, 9999, 1, 3, 42, 446, '1701-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10979, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.663171+00', 'Betty Milne', 'BETTY MILNE', 3, 32, 9999, 2, 3, NULL, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10981, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.680596+00', 'Queen''s Cross Roundabout', 'QUEENS CROSS ROUNDABOUT', 2, 48, 9999, NULL, 3, NULL, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3976, '1997-04-03 22:00:00+00', '2022-11-07 22:06:37.329444+00', 'Lt. Col. Baillie of Leys', 'LT COL BAILLIE OF LEYS', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3968, '1997-09-08 22:00:00+00', '2020-08-06 15:53:08.957345+00', 'Lovat Scouts, The', 'LOVAT SCOUTS', 1, 32, 9999, 1, 2, 76, 129, '1970-01-01', '', 47, '44/88/80/48', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3997, '1998-07-08 22:00:00+00', '2020-08-31 15:21:42.506968+00', 'Luss Road', 'LUSS ROAD', 3, 32, 9999, 1, 4, 11, 372, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3966, '1997-09-04 22:00:00+00', '2020-11-08 21:02:15.325794+00', 'Loudon''s Bonnie Woods', 'LOUDONS BONNIE WOODS', 3, 32, 9999, 5, 56, 4, 270, NULL, '', 100, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14433, '2012-05-09 13:17:37.391938+00', '2020-09-28 19:02:31.402138+00', 'Paris Celebration Medley (3 couple version), The', 'PARIS CELEBRATION MEDLEY 3 COUPLE VERSION', 4, 64, 5, 2, 3, 17, 15, '2010-01-01', '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10961, '2002-11-14 23:00:00+00', '2021-01-30 16:23:13.005878+00', 'Young Nick''s Junk Yard', 'YOUNG NICKS JUNK YARD', 1, 32, 9999, 1, 4, 2, 108, '2002-01-01', '', 88, '4884/8888/8888/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10959, '2002-11-14 23:00:00+00', '2021-01-30 16:29:18.816491+00', 'Twenty-Four Seven', 'TWENTYFOUR SEVEN', 1, 32, 9999, 1, 2, 76, 108, '2002-01-01', '', 69, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3973, '1998-01-05 23:00:00+00', '2021-05-13 10:11:16.493717+00', 'Lowern Fair', 'LOWERN FAIR', 1, 32, 9999, 1, 3, 42, 332, NULL, '', 59, '844/888/822/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3918, '1997-08-22 22:00:00+00', '2021-05-13 21:08:29.868192+00', 'Long Sands, The', 'LONG SANDS', 3, 32, 9999, 1, 3, 42, 527, NULL, '"The Long Sands are at Tynemouth, a favourite beauty spot on the Northumbrian Coast. This glorious beach is ideal for a leisurely stroll especially when the tide is out, but you must skirt the shallow pools of water."', 69, '888/888/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3982, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.916083+00', 'Lucky Horseshoe, The', 'LUCKY HORSESHOE', 2, 32, 9999, 1, 3, 42, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3984, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.924432+00', 'Lucky Shamrock, The', 'LUCKY SHAMROCK', 3, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10987, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.734622+00', 'Chattanooga', 'CHATTANOOGA', 1, 32, 9999, 1, 4, NULL, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10988, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.743315+00', 'Fishing the Dee', 'FISHING THE DEE', 3, 32, 9999, 2, 3, NULL, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10972, '2002-11-19 23:00:00+00', '2015-01-31 01:04:15.731605+00', 'Roond the Hoose', 'ROOND THE HOOSE', 1, 32, 9999, NULL, NULL, NULL, 3229, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10970, '2002-11-19 23:00:00+00', '2015-01-31 01:06:59.419404+00', 'Burns Nicht Celebration', 'BURNS NICHT CELEBRATION', 1, 128, 9999, 4, 4, 3, 3229, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3967, '1997-11-27 23:00:00+00', '2017-07-15 01:51:34.6541+00', 'Louise Mary''s Medley', 'LOUISE MARYS MEDLEY', 4, 96, 11, 4, 4, NULL, 153, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10986, '2002-11-23 23:00:00+00', '2016-05-11 23:10:49.498012+00', 'Wheel of Fortune', 'WHEEL OF FORTUNE', 2, 48, 9999, 4, 6, NULL, 165, NULL, 'Three times through.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10976, '2002-11-19 23:00:00+00', '2016-09-23 22:13:47.884572+00', 'Glen Janet', 'GLEN JANET', 2, 32, 9999, 1, 2, 76, 345, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10969, '2002-11-19 23:00:00+00', '2016-09-23 22:15:43.15829+00', 'MacDonald Jig, The', 'MACDONALD JIG', 2, 32, 9999, 1, 4, 1, 3229, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10974, '2002-11-19 23:00:00+00', '2016-09-23 22:46:09.499576+00', 'Corryvreckan Strathspey', 'CORRYVRECKAN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3230, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10983, '2002-11-23 23:00:00+00', '2018-04-03 00:08:08.180062+00', 'Noughts and Crosses', 'NOUGHTS AND CROSSES', 2, 32, 9999, 1, 3, 42, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10984, '2002-11-23 23:00:00+00', '2018-04-03 00:08:24.099472+00', 'Wanderer, The', 'WANDERER', 1, 32, 9999, 1, 3, 42, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3995, '1997-04-03 22:00:00+00', '2018-04-03 00:08:00.982714+00', 'Luss Road', 'LUSS ROAD', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10985, '2002-11-23 23:00:00+00', '2018-04-03 00:08:09.355664+00', 'Other ''45, The', 'OTHER 45', 3, 32, 9999, 1, 3, 42, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18704, '2018-10-03 00:39:42.460765+00', '2018-10-03 00:39:42.460765+00', 'Celtic Twist', 'CELTIC TWIST', 1, 32, NULL, 1, 4, 1, 2766, '2009-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4059, '1997-09-08 22:00:00+00', '2012-01-20 12:56:32.792708+00', 'Mad Mitch''s Ninesome Reel', 'MAD MITCHS NINESOME REEL', 1, 200, 9999, 6, 98, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4000, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.31246+00', 'Lyn O'' Dee', 'LYN O DEE', 3, 32, 9999, 1, 2, NULL, 222, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4001, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.319266+00', 'Lynda Smiled At Me', 'LYNDA SMILED AT ME', 1, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4003, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.333674+00', 'MacBoehmer Jig, The', 'MACBOEHMER JIG', 2, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4006, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.407744+00', 'MacLeod Ceilidh Jig', 'MACLEOD CEILIDH JIG', 2, 32, 9999, 5, 2, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4009, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.428442+00', 'Macanorma Strathspey, The', 'MACANORMA STRATHSPEY', 3, 40, 9999, 6, 3, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4037, '1997-04-03 22:00:00+00', '2018-04-02 23:56:36.003242+00', 'Mackenzie Pass', 'MACKENZIE PASS', 1, 48, 9999, 1, 3, 42, 352, '1993-06-21', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4012, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.448987+00', 'Macbeth Strathspey', 'MACBETH STRATHSPEY', 3, 48, 9999, 1, 4, NULL, 222, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4013, '1999-08-06 22:00:00+00', '2012-01-20 12:56:32.455928+00', 'Macdhais of Tulloch', 'MACDHAIS OF TULLOCH', 4, 64, 9999, 4, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3999, '1997-04-03 22:00:00+00', '2019-07-31 15:19:00.482857+00', 'Lylestone House', 'LYLESTONE HOUSE', 3, 32, 9999, 1, 2, 76, 392, NULL, '', 50, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4021, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.514942+00', 'Macduff''s Farewell', 'MACDUFFS FAREWELL', 3, 32, 9999, 1, 4, NULL, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10997, '2002-11-23 23:00:00+00', '2018-04-03 00:07:41.132945+00', 'Dancing Feet', 'DANCING FEET', 1, 32, 9999, 1, 3, 42, 3237, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4025, '1998-07-08 22:00:00+00', '2012-01-20 12:56:32.54637+00', 'Macgillavry''s Medley', 'MACGILLAVRYS MEDLEY', 4, 32, 9999, 1, 4, 2, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10990, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.760861+00', 'To Dance and Skylark', 'TO DANCE AND SKYLARK', 1, 32, 9999, 1, 4, NULL, 27, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10993, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.788807+00', 'Tim''s Fancies', 'TIMS FANCIES', 3, 32, 9999, 1, 4, NULL, 27, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10995, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.806356+00', 'Star in the Making, A', 'STAR IN THE MAKING', 2, 32, 9999, 4, 4, NULL, 3235, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10996, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.815179+00', 'Bridge of Allen', 'BRIDGE OF ALLEN', 1, 32, 9999, 6, 3, NULL, 3236, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10998, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.8332+00', 'Fizzy Marmalade', 'FIZZY MARMALADE', 2, 32, 9999, 1, 4, NULL, 3236, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10999, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.841875+00', 'Grandpa''s Dance', 'GRANDPAS DANCE', 1, 32, 9999, 1, 4, NULL, 3238, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11000, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.850676+00', 'Jenny Boughen''s Jig', 'JENNY BOUGHENS JIG', 2, 32, 9999, 1, 4, NULL, 3239, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4060, '1997-09-08 22:00:00+00', '2012-01-20 12:56:32.799675+00', 'Mad Robin', 'MAD ROBIN', 1, 32, 9999, 1, 2, NULL, 1097, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10992, '2002-11-23 23:00:00+00', '2018-04-03 00:07:48.164288+00', 'Gibb''s Ruby', 'GIBBS RUBY', 1, 40, 9999, 1, 3, 42, 27, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4034, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.614422+00', 'Mackay Square, The', 'MACKAY SQUARE', 1, 40, 9999, 4, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3991, '1997-09-08 22:00:00+00', '2018-04-03 00:08:00.966114+00', 'Lum Hat Wantin'' the Croon, The', 'LUM HAT WANTIN THE CROON', 2, 48, 9999, 1, 3, 42, 108, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10963, '2002-11-18 23:00:00+00', '2022-01-31 09:41:58.449692+00', 'Bakeapple', 'BAKEAPPLE', 2, 32, 9999, 1, 3, 42, 3227, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10958, '2002-11-14 23:00:00+00', '2022-07-03 18:21:43.510559+00', 'Road to Banff, The', 'ROAD TO BANFF', 2, 32, 9999, 1, 4, 2, 108, '2002-08-01', '', 88, '8888/8888/8808/8088', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4030, '1997-09-08 22:00:00+00', '2022-11-06 21:46:31.386365+00', 'MacGregors'' Farewell to Whiskey', 'MACGREGORS FAREWELL TO WHISKEY', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4005, '1998-07-08 22:00:00+00', '2022-12-03 20:45:23.696774+00', 'MacFarlane''s Geese', 'MACFARLANES GEESE', 1, 32, 9999, 1, 102, 11, 13, NULL, '"A flock of wild geese used to inhabit an island on Loch Lomond, owned by the MacFarlanes, but left, never to return, when the MacFarlane''s house was destroyed."', 63, '8080/0808/8888/8008', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3994, '2002-03-11 23:00:00+00', '2022-12-10 12:31:22.010157+00', 'Lundin Links Strathspey, The', 'LUNDIN LINKS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 50, '1964-01-01', '', 44, '444/888/800/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4040, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.655753+00', 'Mackinnon Of Straithaird', 'MACKINNON OF STRAITHAIRD', 4, 64, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10960, '2002-11-14 23:00:00+00', '2020-02-10 15:49:50.428777+00', 'What''s New Pussy Cat?', 'WHATS NEW PUSSY CAT', 1, 32, 9999, 1, 3, 42, 108, '2002-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3989, '1997-04-03 22:00:00+00', '2020-02-26 22:00:30.407348+00', 'Lucy''s Flittin''', 'LUCYS FLITTIN', 2, 32, 9999, 1, 3, 42, 94, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10982, '2002-11-23 23:00:00+00', '2020-05-31 20:42:32.543575+00', 'Ballerina', 'BALLERINA', 3, 40, 9999, 2, 3, 17, 165, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4033, '2002-02-28 23:00:00+00', '2020-08-06 19:18:13.084019+00', 'Mackay of Strathnaver', 'MACKAY OF STRATHNAVER', 3, 64, 9999, 1, 4, 3, 406, '1966-01-01', '', 100, '8888/8888/8888/8888/8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10994, '2002-11-23 23:00:00+00', '2020-09-13 22:16:29.493397+00', 'Apple Turnover', 'APPLE TURNOVER', 2, 24, 9999, 5, 2, 76, 3234, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10973, '2002-11-19 23:00:00+00', '2021-01-23 23:30:24.605282+00', 'Saint John''s Jig, The', 'SAINT JOHNS JIG', 2, 32, 9999, 1, 3, 42, 3229, NULL, '<<scddb-not-identical:5830>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4007, '2002-03-02 23:00:00+00', '2021-07-07 09:20:21.728301+00', 'MacLeod''s Delight', 'MACLEODS DELIGHT', 3, 32, 9999, 1, 2, 76, 703, '1987-01-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4041, '1997-09-09 22:00:00+00', '2021-02-21 12:00:29.595195+00', 'MacKinnon''s Rant', 'MACKINNONS RANT', 2, 40, 9999, 5, 56, NULL, 255, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10977, '2002-11-19 23:00:00+00', '2021-08-04 11:50:47.369155+00', 'Tree Fern, The', 'TREE FERN', 1, 32, 9999, 1, 3, 42, 44, '2002-01-01', '', 47, '882/828/800/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4011, '1998-04-12 22:00:00+00', '2018-04-03 00:08:01.032733+00', 'Macaulay Strathspey, The', 'MACAULAY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1086, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4038, '1998-04-12 22:00:00+00', '2015-02-27 22:43:53.809359+00', 'Mackenzie Reel, The', 'MACKENZIE REEL', 1, 32, 9999, 1, 2, NULL, 1091, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4004, '1998-10-20 22:00:00+00', '2018-04-03 00:08:01.041201+00', 'MacBunyip and the Maple Leaf', 'MACBUNYIP AND THE MAPLE LEAF', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4020, '1999-08-06 22:00:00+00', '2018-04-03 00:08:01.082814+00', 'Macdonalds of Glencoe', 'MACDONALDS OF GLENCOE', 2, 32, 9999, 1, 3, 42, 347, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4029, '1997-08-24 22:00:00+00', '2018-04-03 00:08:01.116254+00', 'Macgregors and McLarens, The', 'MACGREGORS AND MACLARENS', 1, 32, 9999, 1, 3, 42, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4027, '1998-05-19 22:00:00+00', '2018-04-03 00:08:01.124494+00', 'Macgregor''s March', 'MACGREGORS MARCH', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4031, '1997-09-08 22:00:00+00', '2018-04-03 00:08:01.141273+00', 'Macguilche''s Reel', 'MACGUILCHES REEL', 1, 32, 9999, 1, 3, 42, 1015, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4035, '1997-04-03 22:00:00+00', '2018-04-03 00:08:01.16646+00', 'Mackay''s Farewell', 'MACKAYS FAREWELL', 1, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4036, '1997-04-03 22:00:00+00', '2018-04-03 00:08:01.174799+00', 'Mackenzie Of Whitehall', 'MACKENZIE OF WHITEHALL', 2, 32, 9999, 1, 3, 42, 176, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10991, '2002-11-23 23:00:00+00', '2018-04-03 00:08:06.995853+00', 'Musikmaker''s Ruby, The', 'MUSIKMAKERS RUBY', 1, 40, 9999, 1, 3, 42, 27, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10989, '2002-11-23 23:00:00+00', '2018-04-03 00:08:24.024491+00', 'Waggity Wa''', 'WAGGITY WA', 1, 48, 9999, 1, 3, 42, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18705, '2018-10-03 00:42:51.820838+00', '2018-10-03 00:42:51.820838+00', 'Cement Mixer, Putty, Putty', 'CEMENT MIXER PUTTY PUTTY', 1, 32, NULL, 1, 3, 42, 2766, '2007-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11019, '2002-11-24 23:00:00+00', '2018-12-21 01:14:07.694689+00', 'Recycled Teenagers, The', 'RECYCLED TEENAGERS', 2, 32, 9999, 1, 3, 42, 1, '2001-01-01', 'The AVERAGE age of dancers seems to be increasing year by year, although we all remain young in spirit.', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11026, '2002-11-24 23:00:00+00', '2019-02-09 16:16:57.823928+00', 'Sparrow''s Hall', 'SPARROWS HALL', 3, 32, 9999, 4, 4, 1, 1, '2001-12-01', 'For Mary Miller, who remembers with affection life with her family at Sparrow’s Hall on the edge of Windsor Great Park.', 75, '8080/8080/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4053, '1997-05-17 22:00:00+00', '2012-01-20 12:56:32.748322+00', 'Macrae''s Farewell', 'MACRAES FAREWELL', 3, 32, 9999, 1, 2, NULL, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4054, '2003-01-28 23:00:00+00', '2012-01-20 12:56:32.755821+00', 'Macraes'' Reel, The', 'MACRAES REEL', 1, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4055, '1998-07-08 22:00:00+00', '2012-01-20 12:56:32.76337+00', 'Macrihanish', 'MACRIHANISH', 3, 32, 9999, 1, 4, 11, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4056, '2003-01-28 23:00:00+00', '2012-01-20 12:56:32.770864+00', 'MacShimi''s Jig', 'MACSHIMIS JIG', 2, 40, 9999, 1, 4, 1, 35, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11002, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.868036+00', 'Mowden Madness', 'MOWDEN MADNESS', 1, 88, 9999, 4, 4, NULL, 3241, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11003, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.877025+00', 'Noughts and Crosses', 'NOUGHTS AND CROSSES', 1, 32, 9999, 4, 5, NULL, 3242, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11004, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.885846+00', 'Phillippa''s Frolic', 'PHILLIPPAS FROLIC', 1, 96, 9999, 4, 4, NULL, 3243, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11022, '2002-11-24 23:00:00+00', '2018-12-21 11:00:05.168578+00', 'Jig for Woodford, A', 'JIG FOR WOODFORD', 2, 32, 9999, 1, 3, 42, 1, '2001-03-01', 'For the Woodford Scottish Country Dance Group.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11006, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.903386+00', 'Stephanie''s Jig', 'STEPHANIES JIG', 2, 32, 9999, 1, 4, NULL, 3244, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11023, '2002-11-24 23:00:00+00', '2018-12-21 12:53:03.99706+00', 'Miss Dorothy Leurs', 'MISS DOROTHY LEURS', 3, 32, 9999, 1, 3, 42, 1, '2001-03-01', 'For Dorothy.', 47, '844/444/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11016, '2002-11-24 23:00:00+00', '2019-03-02 11:20:34.804455+00', 'Ruthin Ladies', 'RUTHIN LADIES', 3, 32, 9999, 1, 4, 13, 1, NULL, '', 81, '8448/8888/4884/8880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11009, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.933267+00', 'Thompson''s Jig', 'THOMPSONS JIG', 2, 32, 9999, NULL, 2, NULL, 3247, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11010, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.942473+00', 'Triangular Magic', 'TRIANGULAR MAGIC', 2, 32, 9999, 6, 3, NULL, 3238, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11011, '2002-11-23 23:00:00+00', '2012-01-20 12:57:25.951139+00', 'Tying Shoe Laces', 'TYING SHOE LACES', 1, 32, 9999, 1, 4, NULL, 3242, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11028, '2002-11-24 23:00:00+00', '2018-12-21 14:28:49.548503+00', 'Windyway', 'WINDYWAY', 1, 32, 9999, 1, 3, 42, 1, '2002-02-01', 'For Ann Sutcliffe, who lives at Lower Windyway Farm.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4085, '1997-09-08 22:00:00+00', '2019-07-27 21:12:41.992204+00', 'Maid of the Loch, The', 'MAID OF THE LOCH', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 63, '800/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4062, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.813435+00', 'Madcap Maggie', 'MADCAP MAGGIE', 1, 32, 9999, 1, 4, NULL, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4067, '1997-09-08 22:00:00+00', '2012-01-20 12:56:32.847953+00', 'Maggie Cameron', 'MAGGIE CAMERON', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4069, '1998-04-12 22:00:00+00', '2012-01-20 12:56:32.863832+00', 'Maggie Luv', 'MAGGIE LUV', 3, 40, 9999, 1, 4, NULL, 87, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4071, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.877499+00', 'Maggie''s Magical Moments', 'MAGGIES MAGICAL MOMENTS', 2, 32, 9999, 1, 4, NULL, 385, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4074, '1998-07-08 22:00:00+00', '2012-01-20 12:56:32.898825+00', 'Magic Box Player', 'MAGIC BOX PLAYER', 4, 32, 9999, 1, 4, 2, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4076, '2003-01-26 23:00:00+00', '2012-01-20 12:56:32.913743+00', 'Magic Wand, The', 'MAGIC WAND', 1, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4077, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.921255+00', 'Magic Words, The', 'MAGIC WORDS', 1, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4078, '1999-04-19 22:00:00+00', '2012-01-20 12:56:32.92884+00', 'Magnum Strathspey, The', 'MAGNUM STRATHSPEY', 3, 32, 9999, 1, 4, 1, 87, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4079, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.935721+00', 'Maid Marian Strathspey', 'MAID MARIAN STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4080, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.942973+00', 'Maid of Bellevue', 'MAID OF BELLEVUE', 2, 32, 9999, 3, 5, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4028, '1997-04-03 22:00:00+00', '2022-11-07 20:32:45.461116+00', 'MacGregor''s Wail', 'MACGREGORS WAIL', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4070, '1997-09-08 22:00:00+00', '2022-12-22 11:35:25.439097+00', 'Maggie o'' the Dales', 'MAGGIE O THE DALES', 3, 32, 9999, 2, 3, 17, 555, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4084, '1997-04-03 22:00:00+00', '2012-01-20 12:56:32.973414+00', 'Maid of Norway', 'MAID OF NORWAY', 1, 40, 9999, 1, 2, NULL, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4057, '1997-04-03 22:00:00+00', '2018-04-02 15:31:32.009304+00', 'Macvicar''s Hornpipe', 'MACVICARS HORNPIPE', 1, 32, 9999, 1, 3, 42, 313, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4018, '1998-07-08 22:00:00+00', '2020-08-06 19:16:34.246483+00', 'Macdonald''s Galley', 'MACDONALDS GALLEY', 3, 32, 9999, 1, 4, 2, 82, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4017, '1997-04-03 22:00:00+00', '2020-09-01 10:50:40.884386+00', 'Macdonald''s Delight', 'MACDONALDS DELIGHT', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 53, '800/888/855/855', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11017, '2002-11-24 23:00:00+00', '2020-09-14 15:18:18.430916+00', 'Bottoms Up', 'BOTTOMS UP', 2, 32, 9999, 2, 3, 18, 1, NULL, '', 38, '008/080/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4083, '1998-07-08 22:00:00+00', '2020-10-31 23:30:58.313702+00', 'Maid of Morven, The', 'MAID OF MORVEN', 3, 32, 9999, 1, 4, 2, 13, NULL, '', 81, '8448/8008/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11018, '2002-11-24 23:00:00+00', '2021-01-04 12:05:19.833239+00', 'Greenstead Strathspey', 'GREENSTEAD STRATHSPEY', 3, 40, 9999, 1, 4, 11, 1, '2000-12-01', 'For Muriel Greenstead.', 56, '8282/8686/2828/6868/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11007, '2002-11-23 23:00:00+00', '2018-04-03 00:07:44.085491+00', 'Edlington Reel, The', 'EDLINGTON REEL', 1, 32, 9999, 1, 3, 42, 3245, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11030, '2002-11-24 23:00:00+00', '2017-12-19 15:28:41.347992+00', 'Fergie''s Fancy', 'FERGIES FANCY', 2, 32, 9999, 1, 3, 42, 3250, '1988-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11008, '2002-11-23 23:00:00+00', '2018-04-03 00:07:52.584733+00', 'Honeybee, The', 'HONEYBEE', 1, 32, 9999, 1, 3, 42, 3246, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4049, '1997-04-03 22:00:00+00', '2018-04-03 00:08:01.233066+00', 'Macneil Of Ugadale', 'MACNEIL OF UGADALE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4050, '2002-03-02 23:00:00+00', '2018-04-03 00:08:01.241312+00', 'MacNus Strathspey, The', 'MACNUS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 35, '1979-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4061, '1997-09-08 22:00:00+00', '2018-04-03 00:08:01.424806+00', 'Madam Chairman', 'MADAM CHAIRMAN', 2, 40, 9999, 1, 3, 42, 211, '1979-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4072, '1997-04-03 22:00:00+00', '2018-04-03 00:08:01.508163+00', 'Maggie''s Muck Up', 'MAGGIES MUCK UP', 3, 32, 9999, 1, 3, 42, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11005, '2002-11-23 23:00:00+00', '2018-04-03 00:08:17.953699+00', 'Spen Valley Jig', 'SPEN VALLEY JIG', 2, 32, 9999, 1, 3, 42, 3240, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11012, '2002-11-24 23:00:00+00', '2018-04-03 00:08:24.633168+00', 'Wee Scolty', 'WEE SCOLTY', 3, 32, 9999, 1, 3, 42, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4089, '2003-01-28 23:00:00+00', '2018-04-03 00:08:01.533214+00', 'Maiden Feast, The', 'MAIDEN FEAST', 2, 32, 9999, 1, 3, 42, 35, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4096, '1997-04-03 22:00:00+00', '2018-04-03 00:08:01.591615+00', 'Mairead Nichol Of Drumossie', 'MAIREAD NICHOL OF DRUMOSSIE', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4090, '1998-07-08 22:00:00+00', '2012-01-20 12:56:33.016296+00', 'Maiden''s Leap, The', 'MAIDENS LEAP', 2, 32, 9999, 1, 4, 2, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4091, '1998-01-04 23:00:00+00', '2012-01-20 12:56:33.02361+00', 'Maids Of Bute, The', 'MAIDS OF BUTE', 1, 40, 9999, 1, 2, NULL, 3551, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4093, '1997-09-08 22:00:00+00', '2012-01-20 12:56:33.037754+00', 'Maids Of Micah', 'MAIDS OF MICAH', 2, 32, 9999, 1, 4, NULL, 620, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4094, '2001-05-21 22:00:00+00', '2012-01-20 12:56:33.045616+00', 'Mainhattan', 'MAINHATTAN', 2, 48, 9999, 1, 4, 2, 228, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4095, '1997-04-03 22:00:00+00', '2012-01-20 12:56:33.052738+00', 'Mains Of Dun', 'MAINS OF DUN', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18706, '2018-10-03 00:46:29.568873+00', '2018-10-03 00:46:29.568873+00', 'Chain Link', 'CHAIN LINK', 6, 32, NULL, 4, 4, 1, 2766, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4111, '2002-01-08 23:00:00+00', '2019-02-21 20:18:01.139986+00', 'Makin'' The Tartan', 'MAKIN THE TARTAN', 3, 40, 9999, 1, 4, 1, 122, NULL, '', 78, '8400/8080/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4099, '1997-09-29 22:00:00+00', '2012-01-20 12:56:33.080969+00', 'Mairi Dhu', 'MAIRI DHU', 4, 128, 9999, 1, 4, NULL, 192, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4104, '1998-01-05 23:00:00+00', '2012-01-20 12:56:33.11582+00', 'Maison Rouge', 'MAISON ROUGE', 1, 40, 9999, 1, 2, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19213, '2019-03-03 18:31:05.915199+00', '2019-03-03 18:31:05.915199+00', '5:0', '50', 1, 40, NULL, 3, 5, 35, 11527, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4108, '1997-09-08 22:00:00+00', '2012-01-20 12:56:33.147075+00', 'Major Mackie', 'MAJOR MACKIE', 2, 32, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19214, '2019-03-03 18:33:21.70654+00', '2019-03-03 18:33:21.70654+00', 'Fan Zone', 'FAN ZONE', 2, 32, NULL, 1, 3, NULL, 11527, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4065, '1997-04-03 22:00:00+00', '2019-08-01 11:30:58.630328+00', 'Magdalen Murdockson', 'MAGDALEN MURDOCKSON', 1, 32, 9999, 1, 4, 1, 129, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11034, '2002-11-24 23:00:00+00', '2012-01-20 12:57:26.181268+00', 'Hip2B²', 'HIP2B2', 1, 88, 9999, 4, 4, NULL, 64, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11035, '2002-11-24 23:00:00+00', '2012-01-20 12:57:26.188109+00', 'Irish Touch, The', 'IRISH TOUCH', 1, 32, 9999, 1, 4, NULL, 3252, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4107, '1997-04-03 22:00:00+00', '2018-04-03 00:08:01.674977+00', 'Major League Jig, The', 'MAJOR LEAGUE JIG', 2, 32, 9999, 1, 3, 42, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4109, '1997-04-03 22:00:00+00', '2018-04-03 00:08:01.691633+00', 'Major Mole', 'MAJOR MOLE', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11040, '2002-11-24 23:00:00+00', '2012-01-20 12:57:26.22349+00', 'Teddy Bears'' Centenary', 'TEDDY BEARS CENTENARY', 1, 40, 9999, 4, 4, NULL, 3254, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4116, '1997-09-08 22:00:00+00', '2018-04-03 00:08:01.758436+00', 'Mallyan Spout, The', 'MALLYAN SPOUT', 1, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4114, '1998-07-08 22:00:00+00', '2012-01-20 12:56:33.192687+00', 'Malcolm''s Jig', 'MALCOLMS JIG', 2, 32, 9999, 1, 4, 11, 1101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4117, '1997-09-10 22:00:00+00', '2012-01-20 12:56:33.213109+00', 'Mull of Kintyre Strathspey', 'MULL OF KINTYRE STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4118, '1997-11-27 23:00:00+00', '2012-01-20 12:56:33.219877+00', 'Malpas Medley', 'MALPAS MEDLEY', 4, 128, 5, 4, 4, NULL, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4088, '1997-04-03 22:00:00+00', '2016-05-19 23:16:29.100856+00', 'Maids on the Green, The', 'MAIDS ON THE GREEN', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11037, '2002-11-24 23:00:00+00', '2017-12-03 19:01:44.206027+00', 'Rob''s Rant', 'ROBS RANT', 3, 32, 9999, 1, 3, 42, 3254, '2002-01-01', 'Devised by Terry Lynne Harris, Pretoria, South Africa; August 2002



In memory of Robert Bell Cochrane (15 March 1915 - 3 May 2000). He was an enthusiastic and loyal member of the Pretoria Branch and danced right up to his 85th birthday, less than 2 months before his death.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11033, '2002-11-24 23:00:00+00', '2017-12-05 00:58:18.852915+00', 'Highveld Jig', 'HIGHVELD JIG', 2, 32, 9999, 1, 4, 2, 3251, '1988-01-01', 'Recommended music: Any good jig



Devised by Ina Bergh, South Africa; 1988.



Entered for the competition held by Pretoria Branch to submit a dance to the RSCDS for publication in their booklet of dances from around the world, "Frae A'' The Airts".', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11032, '2002-11-24 23:00:00+00', '2021-01-30 11:05:15.851694+00', 'Hallo Halloween', 'HALLO HALLOWEEN', 2, 32, 9999, 5, 51, NULL, 64, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4052, '1998-01-21 23:00:00+00', '2020-07-13 19:50:46.110261+00', 'Macpherson''s Rant', 'MACPHERSONS RANT', 1, 32, 9999, 1, 3, 42, 976, '1740-01-01', '', 50, '800/888/822/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4082, '1997-09-08 22:00:00+00', '2020-09-01 10:59:56.853214+00', 'Maid of Lorne', 'MAID OF LORNE', 3, 32, 9999, 1, 3, 42, 613, NULL, '', 63, '844/866/866/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4122, '1997-04-03 22:00:00+00', '2020-11-10 20:51:57.1835+00', 'Man from Skye, The', 'MAN FROM SKYE', 3, 32, 9999, 1, 3, 42, 270, NULL, '', 53, '800/888/844/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11045, '2002-11-24 23:00:00+00', '2022-04-27 13:14:14.961393+00', 'Trio', 'TRIO', 4, 280, 49, 1, 4, NULL, 3254, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4124, '1997-04-03 22:00:00+00', '2022-11-07 16:43:06.984411+00', 'Man from North Connel, The', 'MAN FROM NORTH CONNEL', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4113, '1997-04-03 22:00:00+00', '2022-11-07 21:53:23.392916+00', 'Malcolm of the Glen', 'MALCOLM OF THE GLEN', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4120, '1998-10-22 22:00:00+00', '2022-12-03 19:37:03.944489+00', 'Mamie''s Jig', 'MAMIES JIG', 2, 32, 9999, 1, 4, 1, 50, '1972-01-01', '', 31, '4440/4440/8000/8000', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4119, '1997-08-26 22:00:00+00', '2021-05-10 18:15:54.96554+00', 'Maltings Jig, The', 'MALTINGS JIG', 2, 32, 9999, 1, 3, 42, 551, '1993-01-01', 'Devised to celebrate the wedding of Elizabeth Wade and Nicholas Royle in April 1993.', 59, '840/888/888/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4115, '1997-04-03 22:00:00+00', '2021-05-10 21:50:04.009432+00', 'Malcolm''s Strathspey', 'MALCOLMS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 200, NULL, '', 61, '888/860/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4058, '1998-04-12 22:00:00+00', '2021-05-11 11:06:05.209569+00', 'Mad Hatter, The', 'MAD HATTER', 2, 32, 9999, 1, 3, 42, 44, NULL, '', 50, '800/844/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4097, '1997-09-08 22:00:00+00', '2021-06-15 21:07:19.217276+00', 'Mairi Allan', 'MAIRI ALLAN', 2, 32, 9999, 1, 3, 42, 976, '1740-01-01', 'The description says this is for a 4 (or 5) couple set.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11042, '2002-11-24 23:00:00+00', '2017-12-12 12:15:52.462263+00', 'Three Times Lucky', 'THREE TIMES LUCKY', 1, 48, 9999, 1, 3, 42, 3179, '2002-08-01', 'Devised by Wouter Joubert, Pretoria, South Africa; August 2002.



Dedicated to my three beautiful children, who enrich our lives and keep us busy.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11038, '2002-11-24 23:00:00+00', '2017-12-07 12:46:10.462722+00', 'Scapa Flow', 'SCAPA FLOW', 3, 80, 9999, 4, 4, 3, 3254, '2002-01-01', 'Devised by Terry Lynne Harris, Pretoria, South Africa,; August 2002



In memory of my father, Frank Raymond Cathcart Harris (15/9/1918 - 29/6/1994)



Scapa Flow, an extensive anchorage in Scotland''s Okney Islands, was the base of the British Fleet during both the First World War (1914-1918) and the Second World War (1939-1945). My father was seconded to the British Royal Navy from the South Africa Armed Forces in 1944 and trained at Scapa Flow before seeing action in the Pacific.



The movements and figures of this dance are meant to represent ship''s wheels and the intertwining of ropes.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11036, '2002-11-24 23:00:00+00', '2017-12-18 23:41:59.878184+00', 'Isobel Ross of Ballachulish', 'ISOBEL ROSS OF BALLACHULISH', 3, 32, 9999, 1, 3, 42, 3253, '1988-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11039, '2002-11-24 23:00:00+00', '2017-12-19 17:20:50.544348+00', 'Swings and Roundabouts', 'SWINGS AND ROUNDABOUTS', 3, 32, 9999, 1, 3, 42, 64, '1998-06-01', 'Devised by Irene van Maarseveen, Pretoria, South Africa; June 1998.



This dance was devised for a beginner''s class, as an introduction to turning corners and partner.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4125, '1997-04-03 22:00:00+00', '2012-01-20 12:56:33.267421+00', 'Man from Uist, The', 'MAN FROM UIST', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4128, '1997-09-08 22:00:00+00', '2012-01-20 12:56:33.287992+00', 'Manannin''s Mantle', 'MANANNINS MANTLE', 3, 32, 9999, 2, 3, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4145, '1997-09-08 22:00:00+00', '2019-03-14 21:11:22.564574+00', 'Marchioness Of Hartington''s Jig, The', 'MARCHIONESS OF HARTINGTONS JIG', 2, 32, 9999, 1, 4, 1, 1103, NULL, '', 70, '0880/8888/8008/6866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4154, '1999-10-15 22:00:00+00', '2019-03-14 21:03:01.263416+00', 'Margaret Ogilvie''s Jig', 'MARGARET OGILVIES JIG', 2, 32, 9999, 1, 4, 1, 1105, '1982-01-01', '', 72, '8888/8888/8440/8004', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4137, '1997-09-08 22:00:00+00', '2012-01-20 12:56:33.349844+00', 'Many-a-Mickle', 'MANYAMICKLE', 2, 64, 9999, 1, 4, NULL, 948, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4138, '1997-11-25 23:00:00+00', '2012-01-20 12:56:33.356582+00', 'Maple And The Thistle', 'MAPLE AND THE THISTLE', 4, 128, 9999, 4, 4, NULL, 392, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4139, '1997-09-08 22:00:00+00', '2012-01-20 12:56:33.363419+00', 'Maple Leaf Flag', 'MAPLE LEAF FLAG', 3, 40, 9999, 1, 4, NULL, 709, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14474, '2012-06-15 04:26:22.946557+00', '2019-04-01 23:26:32.135447+00', 'April Sky', 'APRIL SKY', 3, 32, NULL, 1, 100, 11, 3663, '2004-01-01', '', 66, '8228/6666/6666/8008', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4127, '1997-04-03 22:00:00+00', '2019-03-22 22:09:09.732894+00', 'Man''s a Man for a'' That, A', 'MANS A MAN FOR A THAT', 3, 32, 9999, 1, 3, 42, 108, '1968-01-01', '', 56, '888/880/880/862', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11052, '2002-12-01 23:00:00+00', '2018-04-03 00:07:52.017482+00', 'Heyington Place', 'HEYINGTON PLACE', 1, 32, 9999, 1, 3, 42, 1073, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14488, '2012-07-03 07:50:59.380659+00', '2018-04-03 00:07:52.534773+00', 'Home for Tea', 'HOME FOR TEA', 1, 32, NULL, 1, 3, 42, 635, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11049, '2002-11-24 23:00:00+00', '2012-01-20 12:57:26.288917+00', 'Whirlpool, The', 'WHIRLPOOL', 3, 32, 9999, 1, 4, NULL, 3256, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11051, '2002-11-24 23:00:00+00', '2012-01-20 12:57:26.306689+00', 'X-Y-Z Dance', 'XYZ DANCE', 2, 32, 9999, 1, 4, 1, 2822, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11059, '2002-12-01 23:00:00+00', '2012-01-20 12:57:26.377738+00', 'Winter Frolic, A', 'WINTER FROLIC', 1, 40, 9999, 1, 4, NULL, 3261, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11060, '2002-12-01 23:00:00+00', '2012-01-20 12:57:26.386435+00', 'Kiwi Black Magic', 'KIWI BLACK MAGIC', 3, 32, 9999, 1, 4, NULL, 3262, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14467, '2012-06-13 08:34:54.134056+00', '2012-06-13 08:34:54.134066+00', 'North West 50th', 'NORTH WEST 50TH', 1, 32, NULL, 3, 5, NULL, 146, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14464, '2012-06-13 08:12:50.805373+00', '2013-01-18 12:46:47.745551+00', 'Fair North West, The', 'FAIR NORTH WEST', 3, 32, NULL, 2, 3, NULL, 146, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14485, '2012-07-01 00:26:04.94132+00', '2012-07-01 00:54:32.560195+00', 'Visit from Avis, A', 'VISIT FROM AVIS', 3, 32, NULL, 2, 3, 17, 411, '2004-01-01', 'Written after a visit to Northland by Avis Harrison', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14489, '2012-07-03 17:36:03.015183+00', '2012-07-03 17:36:03.015194+00', 'Newton House', 'NEWTON HOUSE', 2, 32, NULL, 1, 100, 2, 185, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4143, '1997-10-27 23:00:00+00', '2012-01-20 12:56:33.390616+00', 'March To The Battlefield, The', 'MARCH TO THE BATTLEFIELD', 1, 48, 9999, 1, 4, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4148, '1997-04-03 22:00:00+00', '2012-01-20 12:56:33.425337+00', 'Marg''t Ann Robertson', 'MARGT ANN ROBERTSON', 3, 32, 9999, 1, 4, NULL, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4150, '1997-04-03 22:00:00+00', '2012-01-20 12:56:33.43893+00', 'Margaret Allan Strathspey', 'MARGARET ALLAN STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 247, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4157, '1997-04-03 22:00:00+00', '2012-01-20 12:56:33.486699+00', 'Margaret''s Dance', 'MARGARETS DANCE', 2, 48, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4162, '1997-09-08 22:00:00+00', '2012-01-20 12:56:33.520695+00', 'Margaret''s Strathspey', 'MARGARETS STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4163, '1997-04-03 22:00:00+00', '2012-01-20 12:56:33.527485+00', 'Margaret''s Wedding', 'MARGARETS WEDDING', 4, 32, 9999, 4, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4132, '1997-09-08 22:00:00+00', '2018-04-03 00:08:01.933503+00', 'Mansfield Ladies, The', 'MANSFIELD LADIES', 1, 48, 9999, 1, 3, 42, 1102, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4134, '1997-09-08 22:00:00+00', '2018-04-03 00:08:01.941808+00', 'Mantua Makers'' Frolic', 'MANTUA MAKERS FROLIC', 1, 32, 9999, 1, 3, 42, 466, '1758-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4159, '1998-01-04 23:00:00+00', '2018-04-03 00:08:02.058619+00', 'Margaret''s Marriage', 'MARGARETS MARRIAGE', 1, 32, 9999, 1, 3, 42, 293, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4129, '1997-04-03 22:00:00+00', '2020-11-10 18:18:51.187315+00', 'Manchester Caledonians', 'MANCHESTER CALEDONIANS', 3, 32, 9999, 1, 2, 76, 270, NULL, '', 69, '88/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4153, '1997-04-03 22:00:00+00', '2020-11-10 22:21:31.343686+00', 'Margaret Cook''s Fancy', 'MARGARET COOKS FANCY', 2, 48, 9999, 1, 3, 42, 270, NULL, '', 54, '800/800/866/866/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4158, '1997-04-03 22:00:00+00', '2021-01-25 16:32:01.363399+00', 'Margaret''s Fancy', 'MARGARETS FANCY', 3, 32, 9999, 1, 2, 76, 342, NULL, '<<scddb-not-identical:10618;13028>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11046, '2002-11-24 23:00:00+00', '2021-01-30 11:04:00.58401+00', 'Verwoerdburg Folly', 'VERWOERDBURG FOLLY', 1, 64, 9999, 4, 4, 22, 2822, '1988-01-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4152, '2002-04-19 22:00:00+00', '2021-02-28 01:25:31.729374+00', 'Margaret Archibald''s Strathpey', 'MARGARET ARCHIBALDS STRATHPEY', 3, 32, 9999, 1, 4, 11, 1104, NULL, 'Dedicated to Margaret Archibald o/Tam 0'' Shanter, Melbourne. who has guided and influenced my progress from dancer to teacher.', 94, '8448/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4173, '1997-04-03 22:00:00+00', '2021-05-09 18:38:00.916728+00', 'Marie''s Farewell', 'MARIES FAREWELL', 2, 32, 9999, 1, 3, 42, 101, NULL, 'Dedicated to Marie Penman.', 47, '880/840/822/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14490, '2012-07-03 17:39:05.973742+00', '2022-09-13 15:56:53.58571+00', 'Threesy Does It', 'THREESY DOES IT', 3, 32, NULL, 6, 3, 17, 2435, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4156, '1997-04-03 22:00:00+00', '2022-12-18 20:42:28.500537+00', 'Margaret Roberts', 'MARGARET ROBERTS', 1, 32, 9999, 1, 4, NULL, 377, NULL, 'Devised for Margaret Roberts of Ruislip.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4211, '1998-01-12 23:00:00+00', '2021-04-18 11:21:20.820914+00', 'Mary Morison', 'MARY MORISON', 3, 32, 9999, 1, 3, 42, 108, '1982-01-01', 'Drewry writes that this is for his cousin Ida Mary Morrison. The assigned tune is normally a reel but is here requested to be played in strathspey tempo.', 69, '808/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4151, '1997-09-11 22:00:00+00', '2021-02-28 02:11:14.836783+00', 'Margaret Archibald''s Reel', 'MARGARET ARCHIBALDS REEL', 1, 32, 9999, 1, 3, 42, 176, NULL, '', 47, '444/444/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4142, '1998-04-12 22:00:00+00', '2021-05-09 23:08:41.468014+00', 'March Hare, The', 'MARCH HARE', 1, 32, 9999, 1, 3, 42, 44, NULL, '', 38, '880/800/844/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4161, '1997-04-03 22:00:00+00', '2018-04-03 00:08:02.075281+00', 'Margaret''s Silver Wedding', 'MARGARETS SILVER WEDDING', 3, 40, 9999, 1, 3, 42, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4164, '1997-04-03 22:00:00+00', '2018-04-03 00:08:02.091964+00', 'Margo Bourne''s Strathspey', 'MARGO BOURNES STRATHSPEY', 3, 40, 9999, 1, 3, 42, 39, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11057, '2002-12-01 23:00:00+00', '2018-04-03 00:08:02.31713+00', 'Marquis of Huntly''s Snuff Mill, The', 'MARQUIS OF HUNTLYS SNUFF MILL', 3, 32, 9999, 1, 3, 42, 1112, '1977-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11053, '2002-12-01 23:00:00+00', '2018-04-03 00:08:11.474113+00', 'Pudding', 'PUDDING', 2, 32, 9999, 1, 3, 42, 1073, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11055, '2002-12-01 23:00:00+00', '2018-04-03 00:08:13.066942+00', 'Ringwood Folk Medley', 'RINGWOOD FOLK MEDLEY', 4, 32, 1, 1, 3, 42, 1073, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11054, '2002-12-01 23:00:00+00', '2018-04-03 00:08:14.493134+00', 'Saint Catherine''s Strathspey', 'SAINT CATHERINES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1073, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11058, '2002-12-01 23:00:00+00', '2018-04-03 00:08:26.876669+00', 'Worcester Boulevard', 'WORCESTER BOULEVARD', 1, 32, 9999, 1, 3, 42, 3260, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14486, '2012-07-01 00:42:09.601817+00', '2012-07-01 00:52:19.650097+00', 'Barry''s Dancers', 'BARRYS DANCERS', 4, 48, 11, 4, 4, 3, 411, '1991-01-01', 'For Barry Skelton’s dancing group with thanks to them for trying my dances as well.



Suitable recorded music: “The Nor’loch”, David Cunningham, Highlander 3', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4167, '1997-09-08 22:00:00+00', '2012-01-20 12:56:33.554739+00', 'Maria', 'MARIA', 3, 32, 9999, 1, 4, NULL, 1014, '1989-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4168, '2003-01-29 23:00:00+00', '2012-01-20 12:56:33.56229+00', 'Maria''s Strathspey', 'MARIAS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11056, '2002-12-01 23:00:00+00', '2013-09-07 10:06:25.557484+00', 'New New Brighton Pier, The', 'NEW NEW BRIGHTON PIER', 2, 40, 9999, 1, 4, NULL, 3259, '1997-01-01', 'The dance was devised to celebrate the rebuild of the New Brighton Pier, so therefore it became The NEW New Brighton Pier.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11457, '2003-09-22 22:00:00+00', '2018-10-06 10:36:11.587519+00', 'Milky Way, The', 'MILKY WAY', 3, 32, 9999, 4, 4, NULL, 2766, '2002-04-01', 'The Milky Way is a spiral galaxy and the figure in bars 25-32 reminds me of a spiral.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4187, '1998-11-29 23:00:00+00', '2019-02-21 20:22:04.990037+00', 'Marklands, The', 'MARKLANDS', 3, 32, 9999, 1, 4, 1, 146, NULL, '', 72, '8008/8888/8448/8444', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11062, '2002-12-01 23:00:00+00', '2012-01-20 12:57:26.40407+00', '45 Degrees South', '45 DEGREES SOUTH', 1, 32, 9999, 1, 4, NULL, 3264, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14514, '2012-07-06 08:10:30.809835+00', '2019-08-22 16:58:14.368262+00', 'Tidewater Reel', 'TIDEWATER REEL', 1, 32, NULL, 1, 4, 1, 3101, NULL, '', 55, '8000/8088/8880/8222', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14513, '2012-07-06 08:08:54.416553+00', '2019-08-23 06:29:39.136728+00', 'Sailor from Salem, The', 'SAILOR FROM SALEM', 3, 32, NULL, 2, 3, 17, 3101, NULL, '', 67, '880/880/880/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11065, '2002-12-01 23:00:00+00', '2012-01-20 12:57:26.43106+00', 'Saltire Reel, The', 'SALTIRE REEL', 1, 32, 9999, 1, 4, NULL, 3267, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11067, '2002-12-01 23:00:00+00', '2012-01-20 12:57:26.448816+00', 'Waves on the Waimak', 'WAVES ON THE WAIMAK', 2, 48, 9999, 1, 4, NULL, 3269, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11068, '2002-12-01 23:00:00+00', '2012-01-20 12:57:26.457474+00', 'Christchurch Strathspey, The', 'CHRISTCHURCH STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 3270, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11069, '2002-12-01 23:00:00+00', '2012-01-20 12:57:26.466248+00', 'Passing Time', 'PASSING TIME', 2, 32, 9999, 1, 4, NULL, 3271, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14461, '2012-06-12 22:32:37.248786+00', '2019-09-14 18:22:03.430247+00', 'Certificate dance, The', 'CERTIFICATE DANCE', 3, 32, NULL, 1, 3, 42, 146, '2006-01-01', 'For Susan Hagan to mark a special birthday and gaining her teaching certificate.', 59, '844/888/866/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11070, '2002-12-01 23:00:00+00', '2018-04-02 23:56:35.068033+00', 'Hadley House', 'HADLEY HOUSE', 2, 48, 9999, 1, 3, 42, 595, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4146, '1998-01-07 23:00:00+00', '2012-05-01 21:46:40.483228+00', 'Marchioness Of Linlithgow', 'MARCHIONESS OF LINLITHGOW', 3, 32, 9999, 1, 3, 42, 2027, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14468, '2012-06-13 08:37:34.50271+00', '2012-06-13 08:37:34.50272+00', 'Northern Lights, The', 'NORTHERN LIGHTS', 1, 32, NULL, 3, 5, NULL, 146, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4177, '1997-09-08 22:00:00+00', '2012-01-20 12:56:33.627265+00', 'Marion''s Strathspey', 'MARIONS STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 249, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4178, '1997-09-08 22:00:00+00', '2012-01-20 12:56:33.634056+00', 'Marion''s Welcome Home', 'MARIONS WELCOME HOME', 2, 48, 9999, 1, 4, NULL, 1109, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4186, '1997-04-03 22:00:00+00', '2012-01-20 12:56:33.690289+00', 'Market Town Jig', 'MARKET TOWN JIG', 2, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4188, '1999-04-19 22:00:00+00', '2012-01-20 12:56:33.705015+00', 'Marlborough Strathspey, The', 'MARLBOROUGH STRATHSPEY', 3, 32, 9999, 1, 4, 1, 87, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11075, '2002-12-01 23:00:00+00', '2012-01-20 12:57:26.519077+00', 'Golden Fields', 'GOLDEN FIELDS', 1, 64, 9999, 4, 4, NULL, 3278, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11079, '2002-12-01 23:00:00+00', '2012-01-20 12:57:26.554172+00', 'Florrie Milligan''s Farewell to Oregon', 'FLORRIE MILLIGANS FAREWELL TO OREGON', 3, 32, 9999, 1, 4, NULL, 3280, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11080, '2002-12-01 23:00:00+00', '2012-01-20 12:57:26.563775+00', 'MacFarlane''s Tartan', 'MACFARLANES TARTAN', 3, 40, 9999, 1, 4, 1, 595, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11076, '2002-12-01 23:00:00+00', '2016-11-16 00:02:14.678244+00', 'Maze, The', 'MAZE', 1, 32, 9999, 4, 4, NULL, 782, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11074, '2002-12-01 23:00:00+00', '2018-04-03 00:07:52.067746+00', 'High Desert Celtic Society Triumph, The', 'HIGH DESERT CELTIC SOCIETY TRIUMPH', 1, 32, 9999, 1, 3, 42, 3276, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11071, '2002-12-01 23:00:00+00', '2018-04-03 00:07:58.347287+00', 'Lady MacPherson''s Reign', 'LADY MACPHERSONS REIGN', 2, 32, 9999, 1, 3, 42, 3276, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4166, '1997-09-08 22:00:00+00', '2018-04-03 00:08:02.108659+00', 'Margravine''s Waltz', 'MARGRAVINES WALTZ', 5, 24, 9999, 1, 3, 42, 459, '1799-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4171, '1997-04-03 22:00:00+00', '2018-04-03 00:08:02.116865+00', 'Marianne''s Request', 'MARIANNES REQUEST', 1, 48, 9999, 1, 3, 42, 351, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4182, '1997-09-08 22:00:00+00', '2018-04-03 00:08:02.242131+00', 'Market Chorus', 'MARKET CHORUS', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14504, '2012-07-04 07:46:38.320573+00', '2020-01-05 00:24:34.116418+00', 'Auf Wiedersehen', 'AUF WIEDERSEHEN', 1, 32, NULL, 1, 3, 42, 3101, NULL, '', 63, '880/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11078, '2002-12-01 23:00:00+00', '2020-05-18 13:07:50.362586+00', 'Clarsach, The', 'CLARSACH', 3, 32, 9999, 1, 3, 42, 595, '1998-01-01', 'A clarsach is a Celtic harp.', 63, '880/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4192, '1997-09-06 22:00:00+00', '2020-08-06 19:19:57.995918+00', 'Marquis Of Huntly''s Farewell, The', 'MARQUIS OF HUNTLYS FAREWELL', 3, 32, 9999, 1, 3, 42, 129, '1969-01-01', '', 59, '606/888/888/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14460, '2012-06-12 22:20:38.385955+00', '2020-09-28 19:14:10.617657+00', 'Tribute to Trish, A', 'TRIBUTE TO TRISH', 2, 40, NULL, 1, 3, 42, 146, NULL, '', 40, '811/822/811/822/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4172, '1997-04-03 22:00:00+00', '2020-11-05 22:33:37.97258+00', 'Marie Curie''s Reel', 'MARIE CURIES REEL', 1, 40, 9999, 1, 3, 42, 99, '1988-01-01', '', 60, '880/880/880/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4160, '1997-09-08 22:00:00+00', '2020-11-24 03:30:59.399431+00', 'Margaret''s Rant', 'MARGARETS RANT', 3, 32, 9999, 1, 3, 42, 1107, NULL, '', 53, '880/808/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11063, '2002-12-01 23:00:00+00', '2021-01-30 11:00:28.434284+00', 'Ferrymead', 'FERRYMEAD', 3, 32, 9999, 1, 3, 42, 3265, '1997-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4181, '1998-11-02 23:00:00+00', '2021-05-09 18:19:32.825605+00', 'Marjorie''s Moments', 'MARJORIES MOMENTS', 1, 32, 9999, 1, 4, 1, 118, '1974-01-01', 'The instructions say "Devised by Ernst Eder in 1974 for his wife - she has ''em."', 78, '0808/8888/8888/4448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4176, '1997-09-08 22:00:00+00', '2021-05-09 18:25:54.651127+00', 'Marion''s Fancy', 'MARIONS FANCY', 2, 32, 9999, 1, 3, 42, 792, NULL, '', 53, '880/800/888/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4369, '1998-07-08 22:00:00+00', '2012-01-20 12:56:34.992993+00', 'Midwinter', 'MIDWINTER', 2, 32, 9999, 1, 4, 2, 108, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4169, '1997-09-08 22:00:00+00', '2021-05-09 18:43:46.991948+00', 'Marian''s Fancy', 'MARIANS FANCY', 3, 32, 9999, 1, 3, 42, 361, NULL, 'Dedicated to Marian Smith.', 56, '800/888/880/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4140, '2002-10-28 23:00:00+00', '2021-05-09 23:22:09.801936+00', 'Miss Lyndsey J McCrudden', 'MISS LYNDSEY J MACCRUDDEN', 2, 32, 9999, 1, 3, 42, 1415, '1993-01-01', '', 47, '800/844/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4184, '1997-04-03 22:00:00+00', '2018-04-03 00:08:02.258823+00', 'Market Days', 'MARKET DAYS', 1, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4189, '1997-09-08 22:00:00+00', '2018-04-03 00:08:02.292041+00', 'Maroon Convertible, The', 'MAROON CONVERTIBLE', 2, 32, 9999, 1, 3, 42, 1110, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4194, '1997-06-19 22:00:00+00', '2018-04-03 00:08:02.300477+00', 'Marquis Of Huntley''s Strathspey', 'MARQUIS OF HUNTLEYS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11064, '2002-12-01 23:00:00+00', '2018-04-03 00:08:07.154195+00', 'My Two Sons', 'MY TWO SONS', 2, 48, 9999, 1, 3, 42, 3266, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11077, '2002-12-01 23:00:00+00', '2018-04-03 00:08:13.025223+00', 'Ridgefield Rant', 'RIDGEFIELD RANT', 1, 32, 9999, 1, 3, 42, 3279, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11061, '2002-12-01 23:00:00+00', '2018-04-03 00:08:18.512501+00', 'Stirring the Porridge', 'STIRRING THE PORRIDGE', 2, 32, 9999, 1, 3, 42, 3263, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11082, '2002-12-01 23:00:00+00', '2012-01-20 12:57:26.584489+00', 'Scottish Professor, The', 'SCOTTISH PROFESSOR', 3, 64, 9999, 4, 4, NULL, 880, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4201, '1997-04-03 22:00:00+00', '2018-04-29 21:06:41.976329+00', 'Mary And Bessie Club, The', 'MARY AND BESSIE CLUB', 3, 40, 9999, 1, 3, 42, 39, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11086, '2002-12-05 23:00:00+00', '2012-01-20 12:57:26.61928+00', 'Over the Doon to Carrick', 'OVER THE DOON TO CARRICK', 2, 32, 9999, 1, 4, NULL, 3117, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18832, '2018-10-06 11:26:45.14021+00', '2018-10-06 11:26:45.14021+00', 'Moving Target, A', 'MOVING TARGET', 2, 32, NULL, 1, 3, 42, 2766, '2007-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14462, '2012-06-12 22:40:48.404819+00', '2012-06-12 22:40:48.40483+00', 'Dyson Gold, The', 'DYSON GOLD', 2, 32, NULL, 3, 5, NULL, 146, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18835, '2018-10-06 11:39:42.359824+00', '2018-10-06 11:39:42.359824+00', 'Music of the Spheres, The', 'MUSIC OF THE SPHERES', 3, 32, NULL, 4, 4, 1, 2766, '2007-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11083, '2002-12-05 23:00:00+00', '2018-04-03 00:07:32.356026+00', 'Bargany House', 'BARGANY HOUSE', 1, 32, 9999, 1, 3, 42, 3117, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4197, '1997-09-08 22:00:00+00', '2012-01-20 12:56:33.76877+00', 'Marriage In Reel Time, A', 'MARRIAGE IN REEL TIME', 1, 32, 9999, 1, 4, NULL, 1111, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14469, '2012-06-13 08:40:21.409068+00', '2019-09-13 00:25:18.564449+00', 'Pair of Jeans, The', 'PAIR OF JEANS', 1, 32, NULL, 1, 3, 42, 146, '2006-01-01', 'For Jean Hamilton and Jean Noble whose company we enjoyed at St Andrews Summer School', 61, '888/808/880/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4200, '2002-11-29 23:00:00+00', '2012-01-20 12:56:33.789531+00', 'Mary & Peter Braithwaite', 'MARY AND PETER BRAITHWAITE', 3, 32, 9999, 1, 4, NULL, 2615, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4207, '1997-04-03 22:00:00+00', '2012-01-20 12:56:33.837242+00', 'Mary Donald', 'MARY DONALD', 2, 40, 9999, 1, 2, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4208, '1997-04-03 22:00:00+00', '2012-01-20 12:56:33.844045+00', 'Mary Gavin', 'MARY GAVIN', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4210, '1997-09-08 22:00:00+00', '2012-01-20 12:56:33.858395+00', 'Mary Macgregor''s Farewell To Cramond', 'MARY MACGREGORS FAREWELL TO CRAMOND', 4, 96, 9999, 1, 4, NULL, 189, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4213, '1997-04-03 22:00:00+00', '2012-01-20 12:56:33.87918+00', 'Mary Of The Rock', 'MARY OF THE ROCK', 3, 32, 9999, 1, 4, NULL, 287, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4214, '1997-04-03 22:00:00+00', '2012-01-20 12:56:33.886002+00', 'Mary Queen Of Scots', 'MARY QUEEN OF SCOTS', 1, 24, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4218, '1997-09-08 22:00:00+00', '2012-01-20 12:56:33.913611+00', 'Mary The Weiver', 'MARY THE WEIVER', 2, 32, 9999, 2, 3, NULL, 225, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4220, '1997-09-08 22:00:00+00', '2012-01-20 12:56:33.927245+00', 'Mary''s Delight', 'MARYS DELIGHT', 3, 32, 9999, 1, 4, NULL, 54, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4221, '1998-01-05 23:00:00+00', '2012-01-20 12:56:33.934051+00', 'Mary''s Little Lambs', 'MARYS LITTLE LAMBS', 1, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11088, '2002-12-05 23:00:00+00', '2012-01-20 12:57:26.636952+00', 'Swinging Brig, The', 'SWINGING BRIG', 2, 32, 9999, 1, 2, NULL, 3117, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11097, '2002-12-05 23:00:00+00', '2012-01-20 12:57:26.715365+00', 'Meredith''s Mill', 'MEREDITHS MILL', 4, 128, 2, 4, 4, NULL, 554, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11098, '2002-12-05 23:00:00+00', '2012-01-20 12:57:26.724001+00', 'Paddy''s Candy', 'PADDYS CANDY', 3, 88, 9999, 4, 4, NULL, 554, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11099, '2002-12-05 23:00:00+00', '2012-01-20 12:57:26.732677+00', 'Timothy''s Battered Fiddle', 'TIMOTHYS BATTERED FIDDLE', 1, 32, 9999, 8, 6, NULL, 316, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11102, '2002-12-05 23:00:00+00', '2012-01-20 12:57:26.760304+00', 'Ingle Nook, The', 'INGLE NOOK', 2, 32, 9999, 1, 4, 2, 154, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14470, '2012-06-13 08:43:56.407471+00', '2012-06-13 08:43:56.407481+00', 'Quidenham', 'QUIDENHAM', 3, 32, NULL, 3, 5, NULL, 146, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14508, '2012-07-04 13:03:27.686295+00', '2012-07-04 13:03:27.686306+00', 'Five Couple Fugue', 'FIVE COUPLE FUGUE', 6, 32, NULL, 3, 5, 7, 3101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4212, '1997-09-08 22:00:00+00', '2018-04-03 00:08:02.508939+00', 'Mary Of Mays', 'MARY OF MAYS', 1, 32, 9999, 1, 3, 42, 617, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11090, '2002-12-05 23:00:00+00', '2018-04-03 00:07:32.764684+00', 'Beauty of Builth, The', 'BEAUTY OF BUILTH', 3, 32, 9999, 1, 3, 42, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11101, '2002-12-05 23:00:00+00', '2018-04-03 00:07:42.993021+00', 'Dreva Hill', 'DREVA HILL', 3, 32, 9999, 1, 3, 42, 154, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14463, '2012-06-12 22:43:32.10577+00', '2018-04-03 00:07:43.793642+00', 'East of the Sun', 'EAST OF THE SUN', 2, 32, NULL, 1, 3, 42, 146, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11092, '2002-12-05 23:00:00+00', '2018-04-03 00:07:45.495196+00', 'Festival Jig', 'FESTIVAL JIG', 2, 32, 9999, 1, 3, 42, 104, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11093, '2002-12-05 23:00:00+00', '2018-04-03 00:07:47.997491+00', 'Geordie''s Birthday Jig', 'GEORDIES BIRTHDAY JIG', 2, 32, 9999, 1, 3, 42, 3286, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11094, '2002-12-05 23:00:00+00', '2018-04-03 00:07:48.056005+00', 'George''s Joy', 'GEORGES JOY', 1, 32, 9999, 1, 3, 42, 3287, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11096, '2002-12-05 23:00:00+00', '2018-04-03 00:07:56.604108+00', 'Judy''s Jig', 'JUDYS JIG', 2, 32, 9999, 1, 3, 42, 1534, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11084, '2002-12-05 23:00:00+00', '2018-04-03 00:07:57.296482+00', 'Killochan Castle', 'KILLOCHAN CASTLE', 3, 32, 9999, 1, 3, 42, 3117, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4203, '1997-09-08 22:00:00+00', '2018-04-03 00:08:02.358779+00', 'Mary Bain''s Wedding', 'MARY BAINS WEDDING', 2, 32, 9999, 1, 3, 42, 1112, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4205, '2000-07-02 22:00:00+00', '2018-04-03 00:08:02.37551+00', 'Mary Branigan''s Delight', 'MARY BRANIGANS DELIGHT', 1, 32, 9999, 1, 3, 42, 121, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4206, '1997-04-03 22:00:00+00', '2018-04-03 00:08:02.383817+00', 'Mary Correll', 'MARY CORRELL', 3, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4225, '1997-04-03 22:00:00+00', '2020-08-06 19:23:36.912092+00', 'Maskelia', 'MASKELIA', 1, 32, 9999, 1, 4, NULL, 62, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4193, '1997-09-08 22:00:00+00', '2020-09-01 11:03:01.824533+00', 'Marquis of Huntly''s Snuffmill, The', 'MARQUIS OF HUNTLYS SNUFFMILL', 3, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', 69, '880/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4204, '2000-07-02 22:00:00+00', '2020-09-01 11:16:05.976719+00', 'Mary Branigan Nixon', 'MARY BRANIGAN NIXON', 1, 32, 9999, 1, 3, 42, 801, NULL, '', 44, '822/822/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14466, '2012-06-13 08:26:56.043666+00', '2020-09-28 19:16:43.132031+00', 'Judge''s Jig, The', 'JUDGES JIG', 2, 32, NULL, 1, 3, 42, 146, NULL, '', 50, '880/808/840/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4183, '1997-09-08 22:00:00+00', '2021-05-09 18:11:13.856579+00', 'Market Cross Jig', 'MARKET CROSS JIG', 2, 32, 9999, 1, 3, 42, 770, NULL, '', 56, '822/822/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4219, '1997-11-27 23:00:00+00', '2018-04-03 00:08:02.533934+00', 'Mary''s Cairngorm', 'MARYS CAIRNGORM', 4, 32, 1, 1, 3, 42, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4198, '1998-11-03 23:00:00+00', '2022-08-18 21:13:30.554852+00', 'Martello Tower, The', 'MARTELLO TOWER', 3, 32, 9999, 1, 3, 42, 394, '1980-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4224, '2002-01-08 23:00:00+00', '2022-12-03 12:14:08.617819+00', 'Marylou''s Reel', 'MARYLOUS REEL', 1, 32, 9999, 1, 4, 11, 108, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11085, '2002-12-05 23:00:00+00', '2018-04-03 00:08:05.152337+00', 'Monday Night Welcome, A', 'MONDAY NIGHT WELCOME', 2, 40, 9999, 1, 3, 42, 3117, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11089, '2002-12-05 23:00:00+00', '2018-04-03 00:08:24.333021+00', 'Weaver''s Walk, The', 'WEAVERS WALK', 3, 32, 9999, 1, 3, 42, 3117, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14471, '2012-06-13 08:46:15.196308+00', '2018-11-23 21:40:36.54977+00', 'Salt of the Earth', 'SALT OF THE EARTH', 3, 32, NULL, 1, 3, 42, 146, NULL, '', 52, '886/822/822/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4235, '1997-09-08 22:00:00+00', '2012-01-20 12:56:34.038818+00', 'Maureen''s Medley', 'MAUREENS MEDLEY', 4, 128, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4237, '1997-04-03 22:00:00+00', '2012-01-20 12:56:34.053059+00', 'Maurice''s Strathspey', 'MAURICES STRATHSPEY', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4242, '1997-09-08 22:00:00+00', '2012-01-20 12:56:34.087165+00', 'May Morning Jig', 'MAY MORNING JIG', 2, 40, 9999, 1, 4, NULL, 1115, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4226, '1997-11-27 23:00:00+00', '2019-03-14 11:38:20.972231+00', 'Mason''s 80, The', 'MASONS 80', 4, 80, 4, 1, 4, 3, 21, NULL, '', 88, '4444/6666/8888/8888/8888/8888/8888/8888/8888/4444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4247, '1997-09-08 22:00:00+00', '2012-01-20 12:56:34.1211+00', 'Maze, The', 'MAZE', 3, 32, 9999, 2, 3, NULL, 1116, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4249, '1997-09-08 22:00:00+00', '2012-01-20 12:56:34.135064+00', 'McBain''s Beans', 'MACBAINS BEANS', 1, 32, 9999, 1, 2, NULL, 1087, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4250, '1997-04-03 22:00:00+00', '2012-01-20 12:56:34.141843+00', 'McCaig''s Tower', 'MACCAIGS TOWER', 2, 32, 9999, 1, 2, NULL, 253, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4243, '1997-04-03 22:00:00+00', '2019-07-19 08:57:32.257078+00', 'May Morrison of Inverurie', 'MAY MORRISON OF INVERURIE', 1, 32, 9999, 1, 3, 42, 89, NULL, '', 47, '840/440/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11114, '2002-12-31 23:00:00+00', '2019-08-11 21:20:11.400495+00', 'Walt''s Country Dance', 'WALTS COUNTRY DANCE', 3, 32, 9999, 2, 3, 18, 3308, NULL, 'A dance to commemory Walt Metcalf''s birthday and to thank him for devising so many wonderful dances for us to enjoy.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11103, '2002-12-05 23:00:00+00', '2012-01-20 12:57:26.76899+00', 'Jelly Roll, The', 'JELLY ROLL', 1, 32, 9999, 1, 4, NULL, 154, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11106, '2002-12-07 23:00:00+00', '2012-01-20 12:57:26.797314+00', 'Joy in the Morning', 'JOY IN THE MORNING', 1, 32, 9999, 1, 4, NULL, 59, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4228, '1997-09-08 22:00:00+00', '2018-04-03 00:08:02.600725+00', 'Master Colin''s Reel', 'MASTER COLINS REEL', 1, 32, 9999, 1, 3, 42, 625, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11115, '2003-01-09 23:00:00+00', '2012-01-20 12:57:26.876182+00', 'Across the Square', 'ACROSS THE SQUARE', 4, 128, 13, 4, 4, NULL, 3307, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11116, '2003-01-08 23:00:00+00', '2012-01-20 12:57:26.885789+00', 'Aincin tae the Fit', 'AINCIN TAE THE FIT', 2, 40, 9999, 1, 4, 1, 3307, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4229, '1997-09-08 22:00:00+00', '2018-04-03 00:08:02.609094+00', 'Master Frazer Johnstone', 'MASTER FRAZER JOHNSTONE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14509, '2012-07-04 13:06:57.024591+00', '2012-07-04 13:06:57.024602+00', 'Fugue and Coda', 'FUGUE AND CODA', 6, 32, NULL, 3, 5, 7, 3101, NULL, 'This dance is the Five Couple Fugue (5x32 H) plus a 32 bar coda. The required music is 6x32 H ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4245, '1997-04-03 22:00:00+00', '2013-01-03 00:03:29.918691+00', 'Mayflower Jig, The', 'MAYFLOWER JIG', 2, 32, 9999, 1, 1, NULL, 108, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4254, '1997-04-03 22:00:00+00', '2012-01-20 12:56:34.170932+00', 'MacCrimmon Pipers, The', 'MACCRIMMON PIPERS', 1, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4259, '1997-05-17 22:00:00+00', '2012-01-20 12:56:34.205487+00', 'McGhie''s Fancy, The', 'MACGHIES FANCY', 1, 40, 9999, 1, 4, NULL, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4260, '1998-04-12 22:00:00+00', '2012-01-20 12:56:34.212282+00', 'McGhie''s Seat, The', 'MACGHIES SEAT', 3, 80, 9999, 4, 4, NULL, 99, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4264, '1997-09-08 22:00:00+00', '2012-01-20 12:56:34.239483+00', 'McIver Reel', 'MACIVER REEL', 1, 32, 9999, 1, 4, NULL, 1090, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4267, '1997-04-03 22:00:00+00', '2012-01-20 12:56:34.259893+00', 'McKenzie''s Rant', 'MACKENZIES RANT', 4, 96, 9999, 3, 5, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11100, '2002-12-05 23:00:00+00', '2014-05-07 21:20:49.830452+00', 'Alterstone, The', 'ALTERSTONE', 3, 32, 9999, 2, 3, 17, 154, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4234, '1997-09-08 22:00:00+00', '2018-04-03 00:08:02.700641+00', 'Maureen Chilles Reel', 'MAUREEN CHILLES REEL', 1, 32, 9999, 1, 3, 42, 687, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4269, '1998-01-04 23:00:00+00', '2012-01-20 12:56:34.273559+00', 'McKone''s Hornpipe', 'MACKONES HORNPIPE', 1, 40, 9999, 1, 4, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11104, '2002-12-05 23:00:00+00', '2016-08-03 19:41:32.664629+00', 'Pallindromic Date', 'PALLINDROMIC DATE', 2, 32, 9999, 1, 4, 1, 154, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4266, '1997-04-03 22:00:00+00', '2015-11-09 22:19:26.247391+00', 'McKenzie Hay', 'MACKENZIE HAY', 3, 32, 9999, 1, 2, NULL, 270, NULL, '', 64, '86/88/88/68', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4275, '2002-04-19 22:00:00+00', '2018-04-03 00:08:02.900769+00', 'McLeod Rant', 'MACLEOD RANT', 3, 32, 9999, 1, 3, 42, 581, '1983-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11110, '2002-12-16 23:00:00+00', '2017-04-05 22:47:39.475968+00', 'Carol Palmer''s Strathspey', 'CAROL PALMERS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3190, '2002-01-01', '', 62, '880/880/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4244, '1997-04-03 22:00:00+00', '2018-04-03 00:08:02.784059+00', 'May-Time', 'MAYTIME', 3, 40, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4255, '1997-08-28 22:00:00+00', '2020-01-11 01:57:03.220496+00', 'Joy in the Morning', 'JOY IN THE MORNING', 3, 32, 9999, NULL, 98, NULL, 593, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4274, '2002-03-02 23:00:00+00', '2021-04-16 22:35:39.257476+00', 'McLeod of Mull', 'MACLEOD OF MULL', 2, 32, 9999, 5, 2, 76, 270, '1980-01-01', '', 100, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4241, '1997-04-03 22:00:00+00', '2020-08-17 12:57:07.541254+00', 'May McGregor''s Strathspey', 'MAY MACGREGORS STRATHSPEY', 3, 64, 9999, 4, 4, 54, 99, NULL, '', 94, '8888/8888/8888/8888/6666/6666/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4240, '1997-04-03 22:00:00+00', '2020-11-06 12:02:01.607286+00', 'May in Minginish', 'MAY IN MINGINISH', 3, 32, 9999, 1, 3, 42, 99, '1988-01-01', '', 50, '800/808/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4258, '1997-04-03 22:00:00+00', '2020-12-24 09:42:11.503939+00', 'McGhie The Moudie-Catcher', 'MACGHIE THE MOUDIECATCHER', 1, 32, 9999, 1, 4, 1, 99, NULL, '', 88, '8448/8888/8888/8088', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4261, '1997-05-17 22:00:00+00', '2021-04-15 08:44:28.777098+00', 'McGinty''s Meal and Ale', 'MACGINTYS MEAL AND ALE', 3, 32, 9999, 1, 3, 42, 270, NULL, '', 52, '860/844/880/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4238, '1997-09-08 22:00:00+00', '2021-05-09 11:10:45.187992+00', 'Maxwell''s Mirror', 'MAXWELLS MIRROR', 1, 48, 9999, 1, 4, 1, 1114, '1967-01-01', '', 71, '8008/8448/8448/8888/8440/8448', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4270, '2001-04-04 22:00:00+00', '2021-05-09 10:04:58.846132+00', 'McLachlan''s Reel', 'MACLACHLANS REEL', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 41, '800/800/888/840', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4222, '1999-08-14 22:00:00+00', '2021-05-09 11:39:54.524546+00', 'Mary''s Strathspey', 'MARYS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 814, NULL, 'Dedicated to Mary Brown.', 53, '800/888/822/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4231, '1997-09-08 22:00:00+00', '2021-07-08 21:47:27.460576+00', 'Mattara Strathspey', 'MATTARA STRATHSPEY', 3, 48, 9999, 1, 4, 2, 977, NULL, 'From the dance notes: Mattara is a Festival held each spring in Newcastle and the Hunter Valley. Mattara is an aboriginal word meaning Hand of Friendship.', 88, '8448/8448/8668/8668/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4276, '2002-03-02 23:00:00+00', '2018-04-03 00:08:02.917545+00', 'McLeod Reel', 'MACLEOD REEL', 1, 32, 9999, 1, 3, 42, 1037, '1971-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14522, '2012-07-22 13:37:42.668389+00', '2018-04-03 00:08:07.579597+00', 'Network Strathspey, The', 'NETWORK STRATHSPEY', 3, 32, NULL, 1, 3, 42, 361, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4281, '1997-09-08 22:00:00+00', '2012-01-20 12:56:34.357963+00', 'McNab Reel, The', 'MACNAB REEL', 1, 32, 9999, 1, 4, NULL, 666, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4263, '1997-04-03 22:00:00+00', '2022-08-18 21:17:33.310639+00', 'McIntosh Hall', 'MACINTOSH HALL', 3, 32, 9999, 1, 4, 1, 28, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11111, '2002-12-16 23:00:00+00', '2022-09-30 11:26:24.546618+00', 'Lassie Frae Glasgow, The', 'LASSIE FRAE GLASGOW', 2, 32, 9999, 1, 3, 42, 2672, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4265, '2000-02-25 23:00:00+00', '2022-12-26 21:50:58.070882+00', 'McKelvie''s Rant', 'MACKELVIES RANT', 3, 64, 9999, 1, 98, NULL, 563, '1960-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11117, '2003-01-08 23:00:00+00', '2012-01-20 12:57:26.895407+00', 'Fly Fifer, The', 'FLY FIFER', 2, 40, 9999, 1, 4, 1, 3307, '2002-01-01', '10 bar phrases.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11118, '2003-01-08 23:00:00+00', '2012-01-20 12:57:26.905012+00', 'Gavin the Birler', 'GAVIN THE BIRLER', 2, 32, 9999, 1, 4, 1, 3307, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11119, '2003-01-08 23:00:00+00', '2012-01-20 12:57:26.915813+00', 'Ken an'' Doris', 'KEN AN DORIS', 1, 32, 9999, 1, 4, 1, 3307, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11120, '2003-01-08 23:00:00+00', '2012-01-20 12:57:26.925512+00', 'Mixter Maxter', 'MIXTER MAXTER', 4, 64, 5, 1, 4, 1, 3307, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11122, '2003-01-09 23:00:00+00', '2012-01-20 12:57:26.944688+00', 'Scottish Tattoo, The', 'SCOTTISH TATTOO', 4, 128, 2, 4, 4, 1, 3307, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11123, '2003-01-08 23:00:00+00', '2012-01-20 12:57:26.953477+00', 'Barbara Armstrong''s Strathspey', 'BARBARA ARMSTRONGS STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 3307, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11124, '2003-01-08 23:00:00+00', '2012-01-20 12:57:26.963068+00', 'Bring a Plate', 'BRING A PLATE', 1, 32, 9999, 2, 3, 18, 3307, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11125, '2003-01-08 23:00:00+00', '2012-01-20 12:57:26.972668+00', 'Crowstone St George', 'CROWSTONE ST GEORGE', 3, 32, 9999, 1, 4, 1, 3307, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11126, '2003-01-08 23:00:00+00', '2012-01-20 12:57:26.982267+00', 'Dance for Eilidh', 'DANCE FOR EILIDH', 2, 32, 9999, 1, 4, 11, 3307, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11127, '2003-01-08 23:00:00+00', '2012-01-20 12:57:26.992451+00', 'Dinna Forget', 'DINNA FORGET', 1, 128, 9999, 4, 4, NULL, 3307, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11128, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.006918+00', 'Distaff Side, The', 'DISTAFF SIDE', 1, 32, 9999, 1, 4, 30, 3307, '1999-01-01', 'Danced from all 8 places', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11129, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.016657+00', 'Going to the Fair', 'GOING TO THE FAIR', 2, 32, 9999, 1, 4, 2, 3307, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4285, '2000-07-02 22:00:00+00', '2018-04-02 23:56:36.236865+00', 'McPhail''s Anvil', 'MACPHAILS ANVIL', 1, 32, 9999, 1, 3, 42, 313, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4286, '1997-04-03 22:00:00+00', '2019-09-04 06:59:23.718246+00', 'McPhedrun''s Strathspey', 'MACPHEDRUNS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 270, NULL, '', 47, '800/888/822/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14523, '2012-07-22 13:42:36.212586+00', '2012-07-22 13:42:36.212596+00', 'Other Side of the World, The', 'OTHER SIDE OF THE WORLD', 3, 80, NULL, 4, 4, NULL, 788, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4304, '2002-04-19 22:00:00+00', '2018-02-27 16:47:00.178608+00', 'Memory of Mrs Mihara', 'MEMORY OF MRS MIHARA', 3, 32, 9999, 1, 2, 76, 2778, '1994-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4284, '1997-09-08 22:00:00+00', '2012-01-20 12:56:34.378565+00', 'McOuwsma''s Fancy', 'MACOUWSMAS FANCY', 3, 32, 9999, 1, 2, NULL, 672, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4287, '1997-09-08 22:00:00+00', '2012-01-20 12:56:34.398933+00', 'McUffda Strathspey, The', 'MACUFFDA STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 900, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4288, '1997-11-27 23:00:00+00', '2012-01-20 12:56:34.405733+00', 'Meadowbank Medley, The', 'MEADOWBANK MEDLEY', 4, 64, 5, 4, 4, NULL, 566, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4289, '1997-11-27 23:00:00+00', '2012-01-20 12:56:34.412562+00', 'Medley For Marilyn, A', 'MEDLEY FOR MARILYN', 4, 32, 1, 2, 3, NULL, 718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4292, '1997-04-03 22:00:00+00', '2012-01-20 12:56:34.433026+00', 'Meeting Place, The', 'MEETING PLACE', 4, 64, 9999, 1, 4, NULL, 152, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4295, '1998-01-12 23:00:00+00', '2012-01-20 12:56:34.453638+00', 'Meg, Tam''s Auld Grey Mare', 'MEG TAMS AULD GREY MARE', 2, 32, 9999, 5, 4, NULL, 210, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4296, '1997-09-08 22:00:00+00', '2012-01-20 12:56:34.463093+00', 'Melbourne Reel, The', 'MELBOURNE REEL', 1, 96, 9999, 4, 4, NULL, 1119, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4297, '1997-04-03 22:00:00+00', '2012-01-20 12:56:34.472521+00', 'Melbourne Strathspey, The', 'MELBOURNE STRATHSPEY', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4298, '1997-04-03 22:00:00+00', '2012-01-20 12:56:34.479503+00', 'Melfort Strathspey', 'MELFORT STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4305, '1997-09-08 22:00:00+00', '2012-01-20 12:56:34.527527+00', 'Men Of Angus', 'MEN OF ANGUS', 4, 96, 9999, 5, 2, NULL, 633, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4308, '1998-01-13 23:00:00+00', '2012-01-20 12:56:34.547947+00', 'Menzies'' Bannockburn Pipes, The', 'MENZIES BANNOCKBURN PIPES', 4, 80, 4, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11130, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.02976+00', 'Witham Five-O', 'WITHAM FIVEO', 3, 32, 9999, 3, 5, 21, 3307, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11131, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.039074+00', 'Bay of Islands, The', 'BAY OF ISLANDS', 3, 40, 9999, 4, 5, 16, 3307, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11133, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.053046+00', 'Hong Kong Harbour Hornpipe', 'HONG KONG HARBOUR HORNPIPE', 1, 40, 9999, 1, 4, NULL, 3307, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11134, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.060579+00', 'Long White Cloud, The', 'LONG WHITE CLOUD', 3, 32, 9999, 1, 4, 2, 3307, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11135, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.067444+00', 'Maori Welcome, A', 'MAORI WELCOME', 1, 32, 9999, 1, 2, NULL, 3307, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11137, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.081115+00', 'Bell Baxter High', 'BELL BAXTER HIGH', 3, 32, 9999, 1, 4, NULL, 3307, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11138, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.088619+00', 'Clatchard Craig', 'CLATCHARD CRAIG', 1, 32, 9999, 1, 4, 1, 3307, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11139, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.096151+00', 'County Burn, The', 'COUNTY BURN', 1, 32, 9999, 1, 4, 2, 3307, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11140, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.103706+00', 'Lindores Abbey', 'LINDORES ABBEY', 3, 32, 9999, 1, 4, 1, 3307, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11142, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.118599+00', 'Quarrymen, The', 'QUARRYMEN', 2, 32, 9999, 1, 4, 2, 3307, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11132, '2003-01-08 23:00:00+00', '2018-04-03 00:07:41.74193+00', 'Delayed in El Ay', 'DELAYED IN EL AY', 2, 32, 9999, 1, 3, 42, 3307, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11141, '2003-01-08 23:00:00+00', '2018-04-03 00:08:01.991941+00', 'March of the Oddfellows', 'MARCH OF THE ODDFELLOWS', 1, 32, 9999, 1, 3, 42, 3307, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4277, '1997-04-03 22:00:00+00', '2018-04-03 00:08:02.909149+00', 'McLeod Reel', 'MACLEOD REEL', 3, 32, 9999, 1, 3, 42, 178, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4294, '1997-09-08 22:00:00+00', '2018-04-03 00:08:02.95918+00', 'Meg Young', 'MEG YOUNG', 2, 48, 9999, 1, 3, 42, 976, '1740-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4307, '1997-04-03 22:00:00+00', '2018-04-03 00:08:03.084321+00', 'Menstrie Castle', 'MENSTRIE CASTLE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11136, '2003-01-08 23:00:00+00', '2018-04-03 00:08:03.451153+00', 'Milford Sound', 'MILFORD SOUND', 2, 32, 9999, 1, 3, 42, 3307, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11121, '2003-01-09 23:00:00+00', '2018-04-03 00:08:12.358271+00', 'Reel for Rita, A', 'REEL FOR RITA', 1, 32, 9999, 1, 3, 42, 3307, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11143, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.1255+00', 'Saint Katharine''s', 'SAINT KATHARINES', 3, 80, 9999, 4, 4, NULL, 3307, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4279, '2003-10-02 22:00:00+00', '2021-05-09 09:31:38.40304+00', 'Anne and Donald''s Jig', 'ANNE AND DONALDS JIG', 2, 32, 9999, 1, 3, 42, 2674, '1995-01-01', '', 56, '880/866/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4278, '2002-03-02 23:00:00+00', '2021-05-09 09:40:54.030572+00', 'MacLeod of Tobermory', 'MACLEOD OF TOBERMORY', 2, 32, 9999, 1, 4, 1, 87, NULL, '', 75, '2882/8888/8888/2082', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11155, '2003-01-10 23:00:00+00', '2018-04-03 00:07:30.644143+00', 'Angel Mounds Jig', 'ANGEL MOUNDS JIG', 2, 32, 9999, 1, 3, 42, 3309, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14511, '2012-07-04 13:12:34.035394+00', '2018-04-03 00:18:02.045136+00', 'Clink and Chase', 'CLINK AND CHASE', 3, 32, NULL, 2, 2, 76, 3101, NULL, '', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11153, '2003-02-12 23:00:00+00', '2018-04-03 00:07:42.325956+00', 'Dodo Johnstone''s Reel', 'DODO JOHNSTONES REEL', 1, 40, 9999, 1, 3, 42, 3117, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14525, '2012-07-22 13:52:36.364247+00', '2018-04-07 23:33:03.57521+00', 'Strathspey in Cyberspace', 'STRATHSPEY IN CYBERSPACE', 3, 32, NULL, 1, 3, 42, 3254, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4306, '1999-10-07 22:00:00+00', '2022-09-21 20:29:55.495929+00', 'Men Of Auckland, The', 'MEN OF AUCKLAND', 1, 32, 9999, 1, 3, 42, 108, '1991-06-01', 'Inscribed "for the S.C.D. Weekend in Auckland, New Zealand in October 1991".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4302, '1997-04-03 22:00:00+00', '2022-12-03 11:58:54.885247+00', 'Memory Lane', 'MEMORY LANE', 3, 24, 9999, 1, 4, 1, 352, '1993-01-07', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4283, '2002-04-24 22:00:00+00', '2022-12-26 12:32:05.826064+00', 'McNichol of the Black Isle', 'MACNICHOL OF THE BLACK ISLE', 1, 104, 9999, 4, 4, 3, 9998, NULL, '', 82, '8080/8888/8888/8888/8484/6666/6666/4444/5555/6666/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4314, '1997-04-03 22:00:00+00', '2012-01-20 12:56:34.592483+00', 'Merchant Tailors, The', 'MERCHANT TAILORS', 2, 40, 9999, 1, 4, 1, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14524, '2012-07-22 13:47:35.34076+00', '2018-04-07 23:37:59.224645+00', 'Strathspey Decadence', 'STRATHSPEY DECADENCE', 3, 32, NULL, 1, 3, 42, 3179, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4316, '1997-04-03 22:00:00+00', '2012-01-20 12:56:34.612085+00', 'Mermaid of Atholl, The', 'MERMAID OF ATHOLL', 3, 40, 9999, 1, 4, NULL, 108, '1971-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11148, '2003-01-08 23:00:00+00', '2018-04-03 00:07:52.009303+00', 'Heybridge Basin', 'HEYBRIDGE BASIN', 3, 32, 9999, 1, 3, 42, 3307, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1873, '2002-04-28 22:00:00+00', '2018-08-27 23:36:44.578439+00', 'Eagleton Strathspey, The', 'EAGLETON STRATHSPEY', 3, 32, 9999, 1, 3, 42, 325, NULL, 'William Eagleton (or Eggleton) and Mary Dickerson were amongst the first of the First Fleet convicts to be married in the colony, on 17th February 178B. Their descendants account for many eighth and ninth generation Australians.', 53, '822/808/848/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4335, '1998-11-01 23:00:00+00', '2019-02-16 11:13:59.403333+00', 'Perle and Ed', 'PERLE AND ED', 1, 32, 9999, 1, 3, 42, 2071, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4326, '1997-09-09 22:00:00+00', '2012-01-20 12:56:34.681933+00', 'Merry Margaret', 'MERRY MARGARET', 1, 32, 9999, 3, 5, NULL, 325, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4328, '2000-06-12 22:00:00+00', '2012-01-20 12:56:34.695951+00', 'Merry Medley, The', 'MERRY MEDLEY', 4, 64, 22, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4332, '1997-09-09 22:00:00+00', '2012-01-20 12:56:34.723449+00', 'Merry Moments With Morag', 'MERRY MOMENTS WITH MORAG', 1, 48, 9999, 1, 4, NULL, 1123, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4338, '1998-11-15 23:00:00+00', '2012-01-20 12:56:34.764155+00', 'Merry-Go-Round, The', 'MERRYGOROUND', 1, 32, 9999, 7, 1, NULL, 1863, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4339, '1997-09-09 22:00:00+00', '2012-01-20 12:56:34.770916+00', 'Merry-Go-Round, The', 'MERRYGOROUND', 2, 32, 9999, 1, 4, NULL, 1122, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4340, '1997-09-09 22:00:00+00', '2012-01-20 12:56:34.777758+00', 'Merrydale', 'MERRYDALE', 3, 32, 9999, 1, 4, NULL, 1121, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11145, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.139882+00', 'Tay Queen, The', 'TAY QUEEN', 1, 32, 9999, 1, 4, 1, 3307, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11146, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.147571+00', 'Tayside, The', 'TAYSIDE', 4, 32, 1, 1, 4, 1, 3307, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11147, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.154562+00', 'Boating on the Blackwater', 'BOATING ON THE BLACKWATER', 3, 32, 9999, 1, 4, NULL, 3307, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11149, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.168983+00', 'Hydrogen at the Hythe, The', 'HYDROGEN AT THE HYTHE', 3, 32, 9999, 1, 4, 2, 3307, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11150, '2003-01-09 23:00:00+00', '2012-01-20 12:57:27.176558+00', 'Plume, The', 'PLUME', 3, 32, 9999, 3, 5, 31, 3307, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11151, '2003-01-09 23:00:00+00', '2012-01-20 12:57:27.184122+00', 'Strolling on the Prom', 'STROLLING ON THE PROM', 3, 32, 9999, 1, 4, 2, 3307, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11152, '2003-01-08 23:00:00+00', '2012-01-20 12:57:27.19294+00', 'Three-Cornered Tower, The', 'THREECORNERED TOWER', 3, 48, 9999, 6, 3, 17, 3307, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4315, '1997-09-09 22:00:00+00', '2018-04-03 00:08:03.100998+00', 'Merigomish Valley Reel', 'MERIGOMISH VALLEY REEL', 1, 32, 9999, 1, 3, 42, 209, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4319, '1997-04-03 22:00:00+00', '2018-04-03 00:08:03.142707+00', 'Merrily Goes The Quaker', 'MERRILY GOES THE QUAKER', 2, 40, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4341, '1998-07-08 22:00:00+00', '2012-01-20 12:56:34.785232+00', 'Merrylea Anniversary Reel', 'MERRYLEA ANNIVERSARY REEL', 1, 32, 9999, 1, 4, 2, 247, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4342, '1998-07-08 22:00:00+00', '2012-01-20 12:56:34.792773+00', 'Merrylea Jig', 'MERRYLEA JIG', 2, 32, 9999, 1, 4, 2, 247, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4343, '1998-04-18 22:00:00+00', '2012-01-20 12:56:34.799565+00', 'Mervyn''s Reel', 'MERVYNS REEL', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4344, '1998-01-12 23:00:00+00', '2012-01-20 12:56:34.806333+00', 'Mettle In Yer Heels', 'METTLE IN YER HEELS', 2, 32, 9999, 5, 2, NULL, 210, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4345, '1997-09-09 22:00:00+00', '2012-01-20 12:56:34.813074+00', 'Mhor!', 'MHOR', 2, 64, 9999, 4, 4, NULL, 488, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4349, '1997-12-27 23:00:00+00', '2017-09-24 15:29:31.881639+00', 'Michigan Avenue', 'MICHIGAN AVENUE', 2, 32, 9999, 1, 2, NULL, 361, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14473, '2012-06-13 08:59:28.676585+00', '2018-04-03 00:08:26.926665+00', 'Worth Silver', 'WORTH SILVER', 2, 32, NULL, 1, 3, 42, 146, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4321, '1997-04-03 22:00:00+00', '2018-04-03 00:08:03.150975+00', 'Merry Andrew', 'MERRY ANDREW', 1, 48, 9999, 1, 3, 42, 300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4322, '1997-10-27 23:00:00+00', '2018-04-03 00:08:03.159249+00', 'Merry Blacksmith, The', 'MERRY BLACKSMITH', 1, 32, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4327, '1997-10-27 23:00:00+00', '2018-04-03 00:08:03.209275+00', 'Merry Mary', 'MERRY MARY', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4330, '1997-04-03 22:00:00+00', '2018-04-03 00:08:03.226066+00', 'Merry Meg''s Strathspey', 'MERRY MEGS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 332, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4331, '1998-01-05 23:00:00+00', '2018-04-03 00:08:03.234377+00', 'Merry Men Of Mey', 'MERRY MEN OF MEY', 1, 32, 9999, 1, 3, 42, 116, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11144, '2003-01-08 23:00:00+00', '2018-04-03 00:08:15.443616+00', 'Scrumping', 'SCRUMPING', 2, 32, 9999, 1, 3, 42, 3307, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4399, '1997-04-03 22:00:00+00', '2018-04-29 22:04:49.307562+00', 'Millicent Brown', 'MILLICENT BROWN', 3, 32, 9999, 1, 3, 42, 173, '1958-09-09', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4357, '1997-04-03 22:00:00+00', '2012-01-20 12:56:34.895166+00', 'Middlemuir Strathspey, The', 'MIDDLEMUIR STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 213, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14496, '2012-07-03 17:58:51.146472+00', '2020-10-01 10:39:57.415591+00', 'Return to Shieldaig', 'RETURN TO SHIELDAIG', 3, 48, NULL, 2, 3, 18, 3345, NULL, '', 72, '880/888/800/844/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14497, '2012-07-03 18:17:59.017378+00', '2020-10-01 11:06:45.235547+00', 'Ask Miriam', 'ASK MIRIAM', 2, 40, NULL, 1, 3, 42, 3345, NULL, '', 60, '880/844/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4323, '2002-02-27 23:00:00+00', '2020-11-10 23:23:17.706003+00', 'Merry Boys of Greenland', 'MERRY BOYS OF GREENLAND', 1, 32, 9999, 1, 4, 1, 270, NULL, '', 81, '8000/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11156, '2003-01-10 23:00:00+00', '2021-01-29 22:35:39.067431+00', 'Anna Maria Strathspey, The', 'ANNA MARIA STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3309, '2001-01-01', '', 48, '840/888/288/800', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4329, '1997-04-03 22:00:00+00', '2020-12-26 13:57:43.51715+00', 'Merry Meetings', 'MERRY MEETINGS', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 69, '844/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4320, '2000-07-25 22:00:00+00', '2021-01-09 23:14:10.790468+00', 'Merry Andrew', 'MERRY ANDREW', 1, 32, 9999, 1, 4, 1, 1120, '1967-01-01', '', 72, '8448/8448/8444/8484', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11154, '2003-02-12 23:00:00+00', '2021-01-29 22:37:31.375723+00', 'Ruby Strathspey, The', 'RUBY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3117, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4346, '1997-09-09 22:00:00+00', '2021-05-08 20:46:34.24262+00', 'Michael''s Journeys', 'MICHAELS JOURNEYS', 1, 32, 9999, 1, 3, 42, 1124, NULL, '', 56, '800/888/888/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4313, '1998-10-15 22:00:00+00', '2021-05-30 09:44:27.266193+00', 'Mercat Cross, The', 'MERCAT CROSS', 1, 48, 9999, 1, 4, 1, 352, '1991-05-16', '', 42, '8000/8440/8330/8440/8330/8004', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11166, '2003-02-10 23:00:00+00', '2018-04-03 00:07:45.528564+00', 'Fiddlehead Reel, The', 'FIDDLEHEAD REEL', 1, 32, 9999, 1, 3, 42, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4360, '1997-09-09 22:00:00+00', '2012-01-20 12:56:34.915976+00', 'Midge Madge', 'MIDGE MADGE', 1, 32, 9999, 1, 2, NULL, 108, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4396, '1998-04-12 22:00:00+00', '2018-09-09 09:07:26.400393+00', 'Millers'' Book Room, The', 'MILLERS BOOK ROOM', 2, 32, 9999, 1, 3, 42, 361, '1992-01-01', '', 56, '880/888/844/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4363, '1997-04-03 22:00:00+00', '2012-01-20 12:56:34.93832+00', 'Midlothian Medley, The', 'MIDLOTHIAN MEDLEY', 4, 96, 9999, 1, 4, NULL, 213, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4364, '1997-12-21 23:00:00+00', '2012-01-20 12:56:34.948191+00', 'Midnight Madness', 'MIDNIGHT MADNESS', 2, 32, 9999, 3, 5, NULL, 425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11160, '2003-01-27 23:00:00+00', '2018-04-03 00:07:48.723106+00', 'Glengairn Church', 'GLENGAIRN CHURCH', 3, 32, 9999, 1, 3, 42, 3095, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4367, '1998-07-08 22:00:00+00', '2012-01-20 12:56:34.976431+00', 'Midway Park', 'MIDWAY PARK', 3, 32, 9999, 1, 4, 2, 42, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4380, '2002-11-29 23:00:00+00', '2018-11-06 23:24:21.871638+00', 'Mill Hill Medley', 'MILL HILL MEDLEY', 4, 128, 2, 1, 4, NULL, 2617, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4351, '2000-12-07 23:00:00+00', '2022-08-17 18:03:45.953256+00', 'Michigan Shores', 'MICHIGAN SHORES', 3, 32, 9999, 1, 3, 42, 361, '1989-03-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4370, '1997-04-03 22:00:00+00', '2012-01-20 12:56:34.999852+00', 'Mighty Pretty Valley', 'MIGHTY PRETTY VALLEY', 1, 16, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11157, '2003-02-12 23:00:00+00', '2012-01-20 12:57:27.227432+00', 'Cunningham Canter, The', 'CUNNINGHAM CANTER', 2, 32, 9999, 1, 2, NULL, 3117, '1987-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11159, '2003-01-13 23:00:00+00', '2012-01-20 12:57:27.242178+00', 'Macwaters Strathspey, The', 'MACWATERS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 3310, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11162, '2003-02-12 23:00:00+00', '2012-01-20 12:57:27.257352+00', 'Miss Mary Anderson', 'MISS MARY ANDERSON', 3, 32, 9999, 2, 3, 17, 2190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4353, '1997-04-03 22:00:00+00', '2018-04-03 00:08:03.334462+00', 'Mickleton Hall', 'MICKLETON HALL', 3, 32, 9999, 1, 3, 42, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11167, '2003-02-10 23:00:00+00', '2012-01-20 12:57:27.294518+00', 'Far Frae Hame', 'FAR FRAE HAME', 3, 48, 9999, 3, 5, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4386, '1997-04-03 22:00:00+00', '2019-05-12 08:53:50.527112+00', 'Mill Rig', 'MILL RIG', 2, 32, 9999, 1, 2, 76, 13, NULL, '', 60, '80/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4388, '2001-11-20 23:00:00+00', '2019-08-29 18:38:54.287501+00', 'Mill of Towie, The', 'MILL OF TOWIE', 3, 32, 9999, 1, 3, 42, 550, '1995-01-01', '', 53, '880/880/866/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4361, '1998-01-07 23:00:00+00', '2012-05-01 21:59:29.797132+00', 'Midhope Castle', 'MIDHOPE CASTLE', 1, 32, 9999, 1, 4, 1, 2027, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4372, '1997-09-09 22:00:00+00', '2012-01-20 12:56:35.013487+00', 'Milberry Union', 'MILBERRY UNION', 3, 24, 9999, 1, 2, NULL, 401, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4376, '1998-11-25 23:00:00+00', '2012-01-20 12:56:35.040819+00', 'Milhanger', 'MILHANGER', 2, 48, 9999, 1, 4, NULL, 617, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4378, '1997-10-27 23:00:00+00', '2012-01-20 12:56:35.054409+00', 'Mill Burn, The', 'MILL BURN', 1, 32, 9999, 1, 2, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4387, '2003-01-26 23:00:00+00', '2012-01-20 12:56:35.118245+00', 'Mill at Monquhitter', 'MILL AT MONQUHITTER', 3, 40, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4391, '1997-04-03 22:00:00+00', '2012-01-20 12:56:35.147961+00', 'Millbrae', 'MILLBRAE', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4392, '1997-04-03 22:00:00+00', '2012-01-20 12:56:35.154758+00', 'Miller O'' Dervil', 'MILLER O DERVIL', 3, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4368, '1997-09-09 22:00:00+00', '2018-04-03 00:08:03.41779+00', 'Midway, The', 'MIDWAY', 2, 32, 9999, 1, 3, 42, 1125, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11172, '2003-02-12 23:00:00+00', '2012-01-20 12:57:27.32925+00', 'Double Locks', 'DOUBLE LOCKS', 2, 32, 9999, 2, 3, NULL, 3315, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11173, '2003-02-12 23:00:00+00', '2012-01-20 12:57:27.336009+00', 'Ellwood Jig, The', 'ELLWOOD JIG', 2, 32, 9999, 1, 4, NULL, 3314, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11174, '2003-02-12 23:00:00+00', '2012-01-20 12:57:27.342761+00', 'Ellwood Reel, The', 'ELLWOOD REEL', 1, 32, 9999, 1, 4, NULL, 3314, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11175, '2003-02-12 23:00:00+00', '2012-01-20 12:57:27.349659+00', 'Ellwood Strathspey, The', 'ELLWOOD STRATHSPEY', 3, 32, 9999, 2, 3, NULL, 3314, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11176, '2003-02-12 23:00:00+00', '2012-01-20 12:57:27.356433+00', 'Exeter Cathedral', 'EXETER CATHEDRAL', 3, 32, 9999, 1, 4, NULL, 3315, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4355, '1997-08-22 22:00:00+00', '2017-09-25 19:37:55.833835+00', 'Mid Fodderletter', 'MID FODDERLETTER', 3, 32, 9999, 1, 4, 1, 88, NULL, '', 83, '8686/8888/6556/8088', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4375, '1998-01-05 23:00:00+00', '2018-04-03 00:08:03.442816+00', 'Milford Sound', 'MILFORD SOUND', 1, 32, 9999, 1, 3, 42, 108, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4377, '1997-04-03 22:00:00+00', '2018-04-03 00:08:03.459446+00', 'Milkman''s Bell, The', 'MILKMANS BELL', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4379, '1997-04-03 22:00:00+00', '2018-04-03 00:08:03.476268+00', 'Mill Burn, The', 'MILL BURN', 1, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4395, '1998-10-20 22:00:00+00', '2018-04-03 00:08:03.593043+00', 'Miller''s Caper, The', 'MILLERS CAPER', 1, 32, 9999, 1, 3, 42, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4385, '1997-04-03 22:00:00+00', '2018-04-03 00:08:03.667961+00', 'Mill Pond, The', 'MILL POND', 3, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11168, '2003-02-10 23:00:00+00', '2018-04-03 00:08:09.580925+00', 'Oyster Girl, The', 'OYSTER GIRL', 2, 32, 9999, 1, 3, 42, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11169, '2003-02-10 23:00:00+00', '2018-04-03 00:08:15.4937+00', 'Sea Dew', 'SEA DEW', 1, 32, 9999, 1, 3, 42, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14526, '2012-07-22 13:57:18.541999+00', '2018-04-03 00:08:18.812752+00', '.strathspey Strathspey', 'STRATHSPEY STRATHSPEY', 3, 32, NULL, 1, 3, 42, 2683, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11177, '2003-02-12 23:00:00+00', '2012-01-20 12:57:27.363185+00', 'Golden Showers', 'GOLDEN SHOWERS', 3, 32, 9999, 1, 4, NULL, 1012, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11180, '2003-02-12 23:00:00+00', '2012-01-20 12:57:27.383435+00', 'Jubilee Party-Time', 'JUBILEE PARTYTIME', 4, 128, 2, 1, 4, NULL, 3317, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11182, '2003-02-12 23:00:00+00', '2012-01-20 12:57:27.398366+00', 'Topsham Road', 'TOPSHAM ROAD', 1, 32, 9999, 3, 5, NULL, 3315, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14498, '2012-07-03 18:22:51.339936+00', '2012-07-03 18:22:51.339947+00', 'At the Water''s Edge', 'AT THE WATERS EDGE', 6, 32, NULL, 1, 4, 2, 10638, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4401, '1997-09-06 22:00:00+00', '2020-08-07 03:18:00.6122+00', 'Millquarter', 'MILLQUARTER', 3, 32, 9999, 1, 4, 1, 129, '1969-01-01', '', 87, '8642/8888/8888/8488', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4384, '1997-04-03 22:00:00+00', '2020-10-12 17:12:41.67893+00', 'Mill of Tifty, The', 'MILL OF TIFTY', 2, 32, 9999, 1, 3, 42, 313, NULL, '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11163, '2003-01-30 23:00:00+00', '2020-10-13 16:43:35.797952+00', 'Redland Strathspey, The', 'REDLAND STRATHSPEY', 3, 32, 9999, 2, 3, 17, 3168, NULL, '', 56, '844/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4382, '1998-07-08 22:00:00+00', '2020-12-30 18:00:26.016477+00', 'Mill of Fortune', 'MILL OF FORTUNE', 2, 32, 9999, 1, 4, 11, 13, NULL, '', 88, '8888/8888/8888/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4373, '1997-09-09 22:00:00+00', '2021-04-17 20:02:19.4965+00', 'Mile Down The Road, A', 'MILE DOWN THE ROAD', 3, 32, 9999, 1, 4, 1, 82, NULL, '', 84, '8888/8888/8888/8040', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4398, '2001-11-20 23:00:00+00', '2021-05-08 19:47:22.686528+00', 'Millerton Brig', 'MILLERTON BRIG', 3, 32, 9999, 1, 3, 42, 146, '1983-01-01', 'For Wilma Miller.', 63, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4397, '2002-04-24 22:00:00+00', '2021-05-08 19:59:37.337819+00', 'Admiral John L. Worden', 'ADMIRAL JOHN L WORDEN', 4, 32, 1, 1, 4, 1, 594, '1994-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4400, '1997-04-03 22:00:00+00', '2012-01-20 12:56:35.211577+00', 'Millom', 'MILLOM', 2, 32, 9999, 1, 4, NULL, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4402, '1998-07-08 22:00:00+00', '2012-01-20 12:56:35.229997+00', 'Milton Fiddlers, The', 'MILTON FIDDLERS', 2, 32, 9999, 1, 4, 2, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11179, '2003-02-12 23:00:00+00', '2018-04-03 00:07:56.52076+00', 'Jubilee Celebration', 'JUBILEE CELEBRATION', 2, 32, 9999, 1, 3, 42, 3316, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4405, '1997-04-03 22:00:00+00', '2012-01-20 12:56:35.251435+00', 'Mimi''s Jig', 'MIMIS JIG', 2, 40, 9999, 1, 4, NULL, 67, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4406, '1997-09-09 22:00:00+00', '2012-01-20 12:56:35.258213+00', 'Min-Man Dance', 'MINMAN DANCE', 1, 32, 9999, 1, 4, NULL, 401, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4408, '1998-07-08 22:00:00+00', '2012-01-20 12:56:35.272375+00', 'Mindil Market', 'MINDIL MARKET', 1, 32, 9999, 1, 4, 2, 108, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4409, '1998-10-12 22:00:00+00', '2012-01-20 12:56:35.279268+00', 'Mini Barn Dance, The', 'MINI BARN DANCE', 2, 24, 9999, 1, 4, NULL, 666, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4414, '1998-01-05 23:00:00+00', '2012-01-20 12:56:35.315457+00', 'Minnock Burn', 'MINNOCK BURN', 1, 48, 9999, 3, 5, NULL, 855, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11215, '2003-02-17 23:00:00+00', '2012-01-20 12:57:27.629856+00', 'Targe, The', 'TARGE', 4, 128, 2, 4, 4, NULL, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4381, '1997-09-09 22:00:00+00', '2022-08-01 20:16:40.52712+00', 'Mill O'' Alloway, The', 'MILL O ALLOWAY', 3, 32, 9999, 1, 3, 42, 1126, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4412, '1997-04-03 22:00:00+00', '2022-11-07 20:31:31.149069+00', 'Minister''s Jig, The', 'MINISTERS JIG', 2, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4410, '1998-07-09 22:00:00+00', '2022-11-07 20:33:37.583195+00', 'Minister of Birse', 'MINISTER OF BIRSE', 3, 32, 9999, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4390, '1997-04-03 22:00:00+00', '2022-11-19 12:01:04.624342+00', 'Milladen', 'MILLADEN', 3, 32, 9999, 1, 3, 42, 270, NULL, '', 56, '888/800/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4383, '1998-01-05 23:00:00+00', '2022-12-03 11:48:26.465946+00', 'Mill of Haldane, The', 'MILL OF HALDANE', 1, 32, 9999, 1, 3, 42, 71, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4418, '1997-09-09 22:00:00+00', '2012-01-20 12:56:35.342616+00', 'Miss Ada Crawford', 'MISS ADA CRAWFORD', 3, 64, 9999, 6, 3, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4419, '1997-09-09 22:00:00+00', '2012-01-20 12:56:35.349376+00', 'Miss Adam''s Medley', 'MISS ADAMS MEDLEY', 4, 32, 9999, 1, 2, NULL, 70, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4423, '1997-04-03 22:00:00+00', '2012-01-20 12:56:35.377795+00', 'Miss Alison Rhona', 'MISS ALISON RHONA', 3, 32, 9999, 7, 2, NULL, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19215, '2019-03-03 18:34:27.522752+00', '2019-03-03 18:34:27.522752+00', 'Wave, The', 'WAVE', 1, 32, NULL, 1, 4, 13, 11527, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4413, '1997-09-09 22:00:00+00', '2018-04-03 00:08:03.726458+00', 'Minna''s Fancy', 'MINNAS FANCY', 2, 40, 9999, 1, 3, 42, 1127, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4429, '1997-09-09 22:00:00+00', '2012-01-20 12:56:35.420777+00', 'Miss Barbara Campbell', 'MISS BARBARA CAMPBELL', 3, 40, 9999, 1, 4, NULL, 401, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4430, '1997-04-03 22:00:00+00', '2012-01-20 12:56:35.42764+00', 'Miss Barbara Cunningham', 'MISS BARBARA CUNNINGHAM', 3, 64, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19702, '2019-10-23 13:24:30.644688+00', '2019-10-23 21:17:59.167358+00', 'Link, The', 'LINK', 3, 40, NULL, 2, 3, 17, 751, '1990-01-01', '', 85, '484/888/888/884/666', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4443, '1997-09-09 22:00:00+00', '2012-01-20 12:56:35.518899+00', 'Miss Campbell of Carnock', 'MISS CAMPBELL OF CARNOCK', 3, 32, 9999, 2, 3, NULL, 108, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19707, '2019-10-24 16:26:25.85803+00', '2019-10-24 18:58:52.220913+00', 'Butterfly, The', 'BUTTERFLY', 3, 32, NULL, 1, 3, 42, 11463, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19710, '2019-10-24 16:33:39.158726+00', '2019-10-24 19:10:03.355126+00', 'Saligo Bay', 'SALIGO BAY', 2, 32, NULL, 1, 100, 11, 11894, '2000-01-01', 'Saligo Bay is on the west coast of Islay', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4453, '1997-04-03 22:00:00+00', '2012-01-20 12:56:35.600462+00', 'Miss Dalgleish''s Fancy', 'MISS DALGLEISHS FANCY', 3, 32, 9999, 4, 4, NULL, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14483, '2012-06-15 05:21:08.069758+00', '2017-03-09 16:13:21.811979+00', 'Their Secret', 'THEIR SECRET', 1, 32, NULL, 1, 3, 42, 10633, '2009-01-01', 'For Doris and Denis Beauchamp''s 50th wedding anniversary', -1, '', 1, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (11194, '2003-02-15 23:00:00+00', '2017-06-03 23:06:40.06638+00', 'Merry Menzies'' Meeting', 'MERRY MENZIES MEETING', 1, 32, 9999, 5, 2, 76, 3324, NULL, '', 87, '88/66/66/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4415, '1997-09-09 22:00:00+00', '2018-04-03 00:08:03.776569+00', 'Mirth''s Welcome', 'MIRTHS WELCOME', 2, 32, 9999, 1, 3, 42, 689, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4416, '1997-09-09 22:00:00+00', '2018-04-03 00:08:03.793072+00', 'Mischief', 'MISCHIEF', 2, 32, 9999, 1, 3, 42, 42, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4437, '1997-09-09 22:00:00+00', '2018-04-03 00:08:03.909986+00', 'Miss Bowie''s Delight', 'MISS BOWIES DELIGHT', 3, 32, 9999, 1, 3, 42, 346, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4446, '1997-09-09 22:00:00+00', '2018-04-03 00:08:03.951562+00', 'Miss Catriona Annette Williamson', 'MISS CATRIONA ANNETTE WILLIAMSON', 1, 32, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4452, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.00172+00', 'Miss Cranston''s Tea Rooms', 'MISS CRANSTONS TEA ROOMS', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11199, '2003-02-16 23:00:00+00', '2012-01-20 12:57:27.518237+00', 'Children of the Briton', 'CHILDREN OF THE BRITON', 3, 32, 9999, 2, 3, NULL, 3327, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11206, '2003-02-17 23:00:00+00', '2012-01-20 12:57:27.56583+00', 'Twa Lads and a Lass', 'TWA LADS AND A LASS', 1, 32, 9999, 5, 56, NULL, 965, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11207, '2003-02-17 23:00:00+00', '2012-01-20 12:57:27.574406+00', 'Riverside Reel, The', 'RIVERSIDE REEL', 1, 32, 9999, 1, 4, NULL, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11209, '2003-02-17 23:00:00+00', '2012-01-20 12:57:27.588019+00', 'Awa'' Tae the Borders', 'AWA TAE THE BORDERS', 1, 32, 9999, 3, 5, NULL, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11186, '2003-02-16 23:00:00+00', '2020-03-26 16:14:19.640425+00', 'Ice Cap, The', 'ICE CAP', 3, 96, 9999, 4, 4, 3, 146, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4427, '1997-04-03 22:00:00+00', '2020-08-07 03:18:42.449915+00', 'Miss Anne Donaldson', 'MISS ANNE DONALDSON', 3, 32, 9999, 1, 4, NULL, 249, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4445, '1997-04-03 22:00:00+00', '2020-08-07 03:44:55.026101+00', 'Miss Catherine Stewart', 'MISS CATHERINE STEWART', 2, 32, 9999, 1, 3, 42, 129, NULL, '', 65, '880/888/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4475, '1997-09-05 22:00:00+00', '2020-08-07 03:45:33.555094+00', 'Miss Fleming''s Jig', 'MISS FLEMINGS JIG', 2, 32, 9999, 1, 2, 76, 129, '1969-01-01', '', 53, '80/88/77/84', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4417, '1997-09-09 22:00:00+00', '2020-09-01 11:22:25.851354+00', 'Mischief', 'MISCHIEF', 1, 48, 9999, 1, 3, 42, 1128, NULL, '', 60, '880/808/888/888/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11197, '2003-02-16 23:00:00+00', '2020-09-14 15:44:21.839966+00', 'Ard Choille', 'ARD CHOILLE', 3, 32, 9999, 1, 3, 42, 3326, NULL, '', 44, '440/840/844/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4448, '1997-04-03 22:00:00+00', '2020-11-11 23:51:00.468845+00', 'Miss Clementine Loughan', 'MISS CLEMENTINE LOUGHAN', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 56, '444/444/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4454, '1997-04-03 22:00:00+00', '2020-12-24 10:09:47.859885+00', 'Miss Davies'' Delight', 'MISS DAVIES DELIGHT', 1, 32, 9999, 1, 3, 42, 99, NULL, '', 59, '888/886/635/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11223, '2003-03-09 23:00:00+00', '2021-01-28 13:53:36.906249+00', 'Charles Upton''s Obsession', 'CHARLES UPTONS OBSESSION', 1, 32, 9999, 8, 6, 34, 3312, NULL, '', 88, '888888/668866/448844/888888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14499, '2012-07-03 18:24:46.459954+00', '2021-03-11 15:02:35.29017+00', 'One Hundred Years', 'ONE HUNDRED YEARS', 3, 32, NULL, 4, 4, 13, 185, NULL, '', 81, '8080/8888/4848/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4436, '2002-02-28 23:00:00+00', '2021-05-07 22:26:30.283682+00', 'Miss Bonny Parker', 'MISS BONNY PARKER', 3, 64, 9999, 1, 4, NULL, 406, '1967-01-01', '', -1, '', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (4451, '1998-09-30 22:00:00+00', '2021-05-08 10:37:40.554998+00', 'Miss Corbett''s Strathspey', 'MISS CORBETTS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4441, '1998-03-10 23:00:00+00', '2021-05-08 10:44:54.360491+00', 'Miss C. M. Barbour', 'MISS C M BARBOUR', 1, 32, 9999, 1, 3, 42, 538, NULL, '', 47, '880/633/633/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4420, '1997-04-03 22:00:00+00', '2021-05-15 20:33:42.888387+00', 'Miss Agnes Loudon', 'MISS AGNES LOUDON', 3, 32, 9999, 1, 3, 42, 270, NULL, '<<scddb-not-identical:4421>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4426, '1997-04-03 22:00:00+00', '2021-06-15 12:39:14.875716+00', 'Miss Ann Dickson', 'MISS ANN DICKSON', 2, 32, 9999, 1, 3, 42, 146, NULL, '', 47, '800/822/866/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11211, '2003-02-17 23:00:00+00', '2012-01-20 12:57:27.601577+00', 'Saint Cuthberts Holy Isle', 'SAINT CUTHBERTS HOLY ISLE', 1, 32, 9999, 1, 4, NULL, 965, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4462, '1997-04-03 22:00:00+00', '2012-01-20 12:56:35.671759+00', 'Miss E. Lyall', 'MISS E LYALL', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4463, '1997-09-09 22:00:00+00', '2012-01-20 12:56:35.678552+00', 'Miss E. Purcell', 'MISS E PURCELL', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4479, '1998-10-26 23:00:00+00', '2019-03-13 09:13:42.656576+00', 'Miss Forbes'' Reel', 'MISS FORBES REEL', 1, 48, 9999, 1, 4, 1, 9998, NULL, '', 42, '8400/8000/8008/0880/8440/8004', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4467, '1997-04-03 22:00:00+00', '2012-01-20 12:56:35.70636+00', 'Miss Elizabeth McGillivray', 'MISS ELIZABETH MACGILLIVRAY', 3, 64, 9999, 4, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4472, '1997-12-02 23:00:00+00', '2012-01-20 12:56:35.741064+00', 'Angeline''s Jig', 'ANGELINES JIG', 2, 32, 9999, 1, 4, NULL, 594, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11208, '2003-02-17 23:00:00+00', '2018-04-03 00:07:40.04865+00', 'Crocks of Gold', 'CROCKS OF GOLD', 3, 32, 9999, 1, 3, 42, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4482, '1997-09-09 22:00:00+00', '2012-01-20 12:56:35.812122+00', 'Miss Gayton''s Hornpipe', 'MISS GAYTONS HORNPIPE', 1, 64, 9999, 2, 3, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11212, '2003-02-17 23:00:00+00', '2012-01-20 12:57:27.608372+00', 'Roofin'' the Hall', 'ROOFIN THE HALL', 1, 32, 9999, 1, 4, NULL, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11213, '2003-02-17 23:00:00+00', '2012-01-20 12:57:27.615221+00', 'Bit of a Do, A', 'BIT OF A DO', 1, 32, 9999, 2, 3, NULL, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11214, '2003-02-17 23:00:00+00', '2012-01-20 12:57:27.622977+00', 'My Silver Haired Laddie', 'MY SILVER HAIRED LADDIE', 1, 32, 9999, 1, 4, NULL, 965, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4428, '1997-04-03 22:00:00+00', '2022-11-07 22:06:11.100042+00', 'Miss Baird of Saughton Hall', 'MISS BAIRD OF SAUGHTON HALL', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4449, '1997-09-09 22:00:00+00', '2022-11-07 22:06:58.130635+00', 'Miss Clementine Stewart of Garth''s Jig', 'MISS CLEMENTINE STEWART OF GARTHS JIG', 2, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4480, '1997-04-03 22:00:00+00', '2022-11-07 22:07:13.34988+00', 'Miss Forsyth of Elgin', 'MISS FORSYTH OF ELGIN', 2, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11218, '2003-02-24 23:00:00+00', '2012-01-20 12:57:27.657029+00', 'Half & Half', 'HALF AND HALF', 3, 32, 9999, 1, 4, 11, 2677, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4485, '1997-04-03 22:00:00+00', '2012-01-20 12:56:35.833004+00', 'Miss Girdle', 'MISS GIRDLE', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11210, '2003-02-17 23:00:00+00', '2018-04-03 00:08:24.399628+00', 'We Did That On Tuesday!', 'WE DID THAT ON TUESDAY', 1, 32, 9999, 1, 3, 42, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14501, '2012-07-03 18:28:43.386884+00', '2018-04-03 00:08:00.807786+00', 'Louisa-Jane''s Wedding', 'LOUISAJANES WEDDING', 3, 32, NULL, 1, 3, 42, 2434, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4456, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.026677+00', 'Miss Dheirdre Brown', 'MISS DHEIRDRE BROWN', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4458, '1997-09-16 22:00:00+00', '2018-04-03 00:08:04.04327+00', 'Miss Dolland''s Delight', 'MISS DOLLANDS DELIGHT', 1, 32, 9999, 1, 3, 42, 466, '1780-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4460, '2002-03-12 23:00:00+00', '2018-04-03 00:08:04.059976+00', 'Miss Dow Of Muirend', 'MISS DOW OF MUIREND', 3, 32, 9999, 1, 3, 42, 111, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4465, '1997-09-09 22:00:00+00', '2018-04-03 00:08:04.076655+00', 'Miss Elenora Robertson', 'MISS ELENORA ROBERTSON', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4468, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.102469+00', 'Miss Elizabeth Thompson', 'MISS ELIZABETH THOMPSON', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4478, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.15998+00', 'Miss Forbes Farewell To Banff', 'MISS FORBES FAREWELL TO BANFF', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14500, '2012-07-03 18:27:06.390185+00', '2013-08-19 11:45:59.684141+00', 'Pentangle, The', 'PENTANGLE', 2, 48, NULL, 102, 5, NULL, 2435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4470, '1997-09-10 22:00:00+00', '2013-10-02 12:29:54.402239+00', 'Miss Evelyn Clark', 'MISS EVELYN CLARK', 3, 32, 9999, 4, 4, 1, 370, NULL, 'To mark 30 years of SCD in Doncaster, begun by Miss Evelyn Clark.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11229, '2003-03-09 23:00:00+00', '2019-02-21 21:14:53.930047+00', 'Twa Thistles, The', 'TWA THISTLES', 2, 32, 9999, 1, 3, 42, 3312, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4490, '1998-07-09 22:00:00+00', '2012-01-20 12:56:35.870098+00', 'Miss Grant of Grant', 'MISS GRANT OF GRANT', 3, 32, 9999, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19216, '2019-03-03 18:35:42.398861+00', '2019-03-03 18:35:42.398861+00', 'Penalty', 'PENALTY', 1, 32, NULL, 1, 4, 2, 11527, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19217, '2019-03-03 18:37:25.929922+00', '2019-03-03 18:37:25.929922+00', 'Stadium', 'STADIUM', 1, 32, NULL, 7, 113, 4, 11527, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4496, '1997-04-03 22:00:00+00', '2012-01-20 12:56:35.91868+00', 'Miss Helen Peacock', 'MISS HELEN PEACOCK', 3, 40, 9999, 1, 4, NULL, 265, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4471, '1998-01-05 23:00:00+00', '2020-05-03 17:34:43.213989+00', 'Miss Falconer''s Fancy', 'MISS FALCONERS FANCY', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 52, '80/80/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4473, '1997-09-09 22:00:00+00', '2020-09-01 13:53:43.46521+00', 'Miss Fidler''s Reel', 'MISS FIDLERS REEL', 1, 32, 9999, 1, 3, 42, 1130, NULL, '', 50, '888/800/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11200, '2003-02-16 23:00:00+00', '2020-09-14 20:14:15.617311+00', 'Ian Hasnae Crossed the Braes', 'IAN HASNAE CROSSED THE BRAES', 1, 32, 9999, 1, 3, 42, 2197, NULL, '', 63, '888/888/808/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11201, '2003-02-16 23:00:00+00', '2020-09-14 21:30:13.646298+00', 'John''s Jig', 'JOHNS JIG', 2, 32, 9999, 1, 3, 42, 3328, NULL, '', 59, '880/888/888/840', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11202, '2003-02-16 23:00:00+00', '2020-09-14 22:58:16.745322+00', 'Lady Fenella Fogarty', 'LADY FENELLA FOGARTY', 2, 32, 9999, 1, 3, 42, 3329, NULL, '', 47, '880/808/800/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11227, '2003-03-09 23:00:00+00', '2020-09-15 08:20:21.09229+00', 'Next Dance, The', 'NEXT DANCE', 2, 32, 9999, 2, 3, 17, 3312, NULL, '', 59, '686/888/484/448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4457, '1997-04-03 22:00:00+00', '2020-11-22 21:55:36.427828+00', 'Miss Dickson''s Reel', 'MISS DICKSONS REEL', 2, 48, 9999, 1, 3, 42, 270, NULL, '', 44, '840/880/840/822/800/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11225, '2003-03-09 23:00:00+00', '2021-01-25 13:42:43.784527+00', 'His Other Wife', 'HIS OTHER WIFE', 1, 32, 9999, 1, 3, 42, 3312, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4459, '1997-04-03 22:00:00+00', '2020-11-23 15:20:35.534015+00', 'Miss Doreen Lambert', 'MISS DOREEN LAMBERT', 3, 40, 9999, 5, 2, NULL, 270, NULL, '', 100, '88/88/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11226, '2003-03-09 23:00:00+00', '2021-01-28 13:49:43.12406+00', 'Lost in Boston', 'LOST IN BOSTON', 3, 32, 9999, 3, 5, 35, 3312, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11222, '2003-10-02 22:00:00+00', '2021-01-28 13:56:00.613687+00', 'City of Light', 'CITY OF LIGHT', 1, 32, 9999, 1, 4, 2, 212, NULL, '', 75, '8008/8888/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11221, '2003-02-24 23:00:00+00', '2021-01-28 13:58:23.048725+00', 'Vertigo', 'VERTIGO', 1, 32, 9999, 1, 2, 76, 2169, NULL, '', 60, '66/66/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11220, '2003-02-24 23:00:00+00', '2021-01-28 14:04:36.525543+00', 'Still Together', 'STILL TOGETHER', 3, 32, 9999, 1, 3, 42, 2677, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11205, '2003-02-17 23:00:00+00', '2021-01-28 14:06:58.425375+00', 'Founders'' Reel, The', 'FOUNDERS REEL', 1, 32, 9999, 3, 5, 7, 272, NULL, '', 60, '80800/82842/88888/80800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4474, '1999-08-06 22:00:00+00', '2021-05-01 22:13:12.298627+00', 'Miss Fiona Macrae of Conchra', 'MISS FIONA MACRAE OF CONCHRA', 3, 64, 9999, 8, 6, 3, 9998, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4487, '1998-04-12 22:00:00+00', '2021-05-07 21:03:11.541461+00', 'Miss Grace Hay''s Delight', 'MISS GRACE HAYS DELIGHT', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 56, '880/808/888/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4466, '1998-01-05 23:00:00+00', '2021-05-07 21:31:52.066306+00', 'Miss Elizabeth Johnson', 'MISS ELIZABETH JOHNSON', 1, 32, 9999, 1, 3, 42, 108, '1964-01-01', 'Miss Elizabeth Johnson was a teacher of the Whitehaven Scottish Country Dance Club.', 50, '888/844/844/800', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4501, '1997-09-09 22:00:00+00', '2012-01-20 12:56:35.952587+00', 'Miss Hollingworth Of Sydney', 'MISS HOLLINGWORTH OF SYDNEY', 3, 80, 9999, 4, 4, NULL, 187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4502, '1997-04-03 22:00:00+00', '2012-01-20 12:56:35.95933+00', 'Miss Hutton', 'MISS HUTTON', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4504, '1997-04-03 22:00:00+00', '2012-01-20 12:56:35.972978+00', 'Miss Isaac Forsyth-Elgin', 'MISS ISAAC FORSYTHELGIN', 2, 32, 9999, 5, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4507, '1997-09-09 22:00:00+00', '2012-01-20 12:56:36.168571+00', 'Miss Isobel Patton Of Boonfoot', 'MISS ISOBEL PATTON OF BOONFOOT', 1, 32, 9999, 1, 98, NULL, 687, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4510, '1997-09-09 22:00:00+00', '2012-01-20 12:56:36.188995+00', 'Miss Jane Wright''s Jig', 'MISS JANE WRIGHTS JIG', 2, 32, 9999, 1, 2, NULL, 91, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4513, '1999-04-21 22:00:00+00', '2012-01-20 12:56:36.209354+00', 'Miss Jean Matheson', 'MISS JEAN MATHESON', 4, 64, 5, 1, 4, NULL, 1132, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4520, '1997-04-03 22:00:00+00', '2012-01-20 12:56:36.264074+00', 'Miss Johnstone', 'MISS JOHNSTONE', 2, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11230, '2005-12-21 23:00:00+00', '2012-01-20 12:57:27.762927+00', 'Matthew''s Strathspey', 'MATTHEWS STRATHSPEY', 3, 32, 9999, 4, 4, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11231, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.771562+00', 'Coire, The', 'COIRE', 1, 32, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11232, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.780193+00', 'Carie Corrie', 'CARIE CORRIE', 3, 32, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11233, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.7888+00', 'Loch a'' Chait', 'LOCH A CHAIT', 2, 32, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11234, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.797405+00', 'Corrie Brochain', 'CORRIE BROCHAIN', 3, 40, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4522, '1997-04-03 22:00:00+00', '2012-01-20 12:56:36.280036+00', 'Miss Joy Taylor of Forres'' Reel', 'MISS JOY TAYLOR OF FORRES REEL', 1, 40, 9999, 1, 98, NULL, 49, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4523, '1997-09-09 22:00:00+00', '2012-01-20 12:56:36.286975+00', 'Miss Judith Baillie of Dochfour', 'MISS JUDITH BAILLIE OF DOCHFOUR', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4524, '1997-04-03 22:00:00+00', '2012-01-20 12:56:36.293768+00', 'Miss Julia Waters', 'MISS JULIA WATERS', 1, 40, 9999, 1, 4, NULL, 393, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4493, '1998-07-09 22:00:00+00', '2022-11-07 20:34:26.679245+00', 'Miss Hay of Yester', 'MISS HAY OF YESTER', 1, 32, 9999, 3, 5, 7, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4488, '1997-04-03 22:00:00+00', '2022-11-07 20:34:02.479375+00', 'Miss Graham Of Inchbrakie', 'MISS GRAHAM OF INCHBRAKIE', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4498, '1997-11-20 23:00:00+00', '2022-11-27 19:54:50.939512+00', 'Miss Henderson of Fordel', 'MISS HENDERSON OF FORDEL', 2, 32, 9999, 1, 2, 76, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4532, '1997-04-03 22:00:00+00', '2012-01-20 12:56:36.349874+00', 'Miss Lyall', 'MISS LYALL', 3, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4534, '1997-09-09 22:00:00+00', '2012-01-20 12:56:36.363617+00', 'Miss M. McLaren''s Welcome', 'MISS M MACLARENS WELCOME', 3, 24, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4538, '1997-04-03 22:00:00+00', '2012-01-20 12:56:36.391756+00', 'Miss Mackie of Coullie', 'MISS MACKIE OF COULLIE', 3, 32, 9999, 1, 4, NULL, 368, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4540, '2002-03-02 23:00:00+00', '2012-01-20 12:56:36.408648+00', 'Miss Maran McLeod', 'MISS MARAN MACLEOD', 3, 64, 9999, 1, 4, NULL, 267, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4514, '2000-09-02 22:00:00+00', '2018-04-02 23:56:36.37038+00', 'Miss Jean Raeburn', 'MISS JEAN RAEBURN', 3, 32, 9999, 1, 3, 42, 129, '1968-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4492, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.335277+00', 'Miss Harvey''s Hornpipe', 'MISS HARVEYS HORNPIPE', 1, 40, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4495, '2002-02-09 23:00:00+00', '2018-04-03 00:08:04.34348+00', 'Miss Helen Campbell', 'MISS HELEN CAMPBELL', 2, 40, 9999, 1, 3, 42, 141, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4503, '1997-11-18 23:00:00+00', '2018-04-03 00:08:04.377007+00', 'Miss Irene Fidler''s Strathspey', 'MISS IRENE FIDLERS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4505, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.393683+00', 'Miss Isabel Mundie', 'MISS ISABEL MUNDIE', 3, 32, 9999, 1, 3, 42, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4509, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.418654+00', 'Miss Jane Douglas', 'MISS JANE DOUGLAS', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4516, '1997-09-09 22:00:00+00', '2018-04-03 00:08:04.435368+00', 'Miss Jeanne Hood', 'MISS JEANNE HOOD', 1, 32, 9999, 1, 3, 42, 174, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4515, '1997-09-09 22:00:00+00', '2018-04-03 00:08:04.452001+00', 'Miss Jean''s Jig', 'MISS JEANS JIG', 2, 32, 9999, 1, 3, 42, 1135, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4525, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.485406+00', 'Miss Kathleen Owens', 'MISS KATHLEEN OWENS', 1, 32, 9999, 1, 3, 42, 67, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4526, '1997-09-09 22:00:00+00', '2018-04-03 00:08:04.493764+00', 'Miss Kathy Beaton', 'MISS KATHY BEATON', 1, 32, 9999, 1, 3, 42, 680, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4533, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.602053+00', 'Miss Lydia Heatherwick', 'MISS LYDIA HEATHERWICK', 3, 32, 9999, 1, 3, 42, 417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4539, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.635558+00', 'Miss Maclachlan''s March', 'MISS MACLACHLANS MARCH', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11249, '2003-03-09 23:00:00+00', '2018-04-03 00:18:02.313403+00', 'Mull of Galloway', 'MULL OF GALLOWAY', 1, 32, 9999, 2, 2, 76, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11248, '2003-03-09 23:00:00+00', '2018-04-03 00:18:02.414088+00', 'Rhinns of Galloway', 'RHINNS OF GALLOWAY', 3, 32, 9999, 2, 2, 76, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4560, '1997-09-09 22:00:00+00', '2018-04-29 21:03:57.47621+00', 'Miss Nan Simpson', 'MISS NAN SIMPSON', 3, 40, 9999, 2, 3, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4546, '1998-07-09 22:00:00+00', '2012-01-20 12:56:36.451993+00', 'Miss Marianne Oliphant', 'MISS MARIANNE OLIPHANT', 3, 32, 9999, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11243, '2003-03-09 23:00:00+00', '2018-09-13 23:40:27.869114+00', 'Corrie Creagach', 'CORRIE CREAGACH', 4, 64, 2, 4, 4, 3, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11237, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.823391+00', 'Corrie Buidhe', 'CORRIE BUIDHE', 3, 32, 9999, 2, 3, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11238, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.832059+00', 'Corrie Gorm', 'CORRIE GORM', 2, 32, 9999, 2, 3, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11239, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.840759+00', 'Corrie Sith', 'CORRIE SITH', 3, 48, 9999, 6, 3, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11240, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.849392+00', 'Corrie Domhainn', 'CORRIE DOMHAINN', 1, 32, 9999, 6, 3, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4536, '1997-04-03 22:00:00+00', '2020-05-14 22:54:04.02787+00', 'Miss Macintosh', 'MISS MACINTOSH', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4535, '1997-09-09 22:00:00+00', '2020-10-10 12:06:58.156757+00', 'Miss MacDonald''s Reel', 'MISS MACDONALDS REEL', 1, 32, 9999, 1, 3, 42, 466, '1793-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4632, '1997-09-09 22:00:00+00', '2020-07-29 06:32:03.482427+00', 'Monchali', 'MONCHALI', 2, 32, 9999, 1, 4, 1, 209, '1983-01-01', 'The title of this dance represents a union of the home dance groups of Susan and Bill Libby for whose wedding it was devised.', 78, '6666/6666/8444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4530, '1997-04-03 22:00:00+00', '2020-11-23 22:11:32.257544+00', 'Miss Knowles', 'MISS KNOWLES', 2, 32, 9999, 1, 3, 42, 270, NULL, '', 53, '811/888/855/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4527, '1997-04-03 22:00:00+00', '2020-12-15 23:17:10.978438+00', 'Miss Kirkpatrick', 'MISS KIRKPATRICK', 3, 32, 9999, 1, 3, 42, 13, NULL, '', 56, '800/888/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4508, '1998-01-04 23:00:00+00', '2021-04-12 22:53:50.253372+00', 'Miss Jacquelyn James', 'MISS JACQUELYN JAMES', 1, 32, 9999, 1, 2, 76, 418, NULL, '', 52, '48/80/84/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11241, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.858015+00', 'Corrie Sneachda', 'CORRIE SNEACHDA', 3, 32, 9999, 6, 3, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11242, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.866648+00', 'Corrie an Dubh Lochain', 'CORRIE AN DUBH LOCHAIN', 2, 32, 9999, 6, 3, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11244, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.88394+00', 'Corrie nan Clach', 'CORRIE NAN CLACH', 1, 88, 9999, 4, 4, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11245, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.892565+00', 'Corrie na Ciche', 'CORRIE NA CICHE', 1, 32, 9999, 4, 4, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11246, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.901176+00', 'Toe and Heel the Reel', 'TOE AND HEEL THE REEL', 2, 24, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4549, '1997-04-03 22:00:00+00', '2012-01-20 12:56:36.473864+00', 'Miss Mary Kirkwood''s Reel', 'MISS MARY KIRKWOODS REEL', 1, 40, 9999, 1, 98, NULL, 73, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4551, '1997-09-09 22:00:00+00', '2012-01-20 12:56:36.487757+00', 'Miss Maul''s Strathspey', 'MISS MAULS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4566, '1997-04-03 22:00:00+00', '2012-01-20 12:56:36.599358+00', 'Miss Rae Of Eskgrove', 'MISS RAE OF ESKGROVE', 2, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4567, '1997-04-03 22:00:00+00', '2012-01-20 12:56:36.607994+00', 'Miss Rhoda Downie', 'MISS RHODA DOWNIE', 3, 32, 9999, 1, 4, NULL, 368, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19024, '2018-10-19 20:36:24.488231+00', '2018-10-22 10:02:46.97481+00', 'Jonathan''s Jig', 'JONATHANS JIG', 2, 32, NULL, 1, 3, 42, 11738, '2004-06-01', '', 69, '888/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4575, '2000-04-25 22:00:00+00', '2019-03-13 09:01:41.831665+00', 'Miss Sally Ireland', 'MISS SALLY IRELAND', 3, 32, 9999, 4, 4, 1, 573, NULL, '', 75, '8080/0808/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11250, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.936185+00', 'Foot it out', 'FOOT IT OUT', 3, 32, 9999, 1, 4, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11251, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.944926+00', 'Trippit Lightly', 'TRIPPIT LIGHTLY', 1, 32, 9999, 1, 4, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11252, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.953551+00', 'Tak Me Awa', 'TAK ME AWA', 3, 32, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11253, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.96218+00', 'Dance, Dance', 'DANCE DANCE', 1, 32, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11254, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.970799+00', 'Dorothy''s Wedding Dance', 'DOROTHYS WEDDING DANCE', 2, 32, 9999, 2, 3, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11255, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.979465+00', 'Dancing Dhonnachaidh, The', 'DANCING DHONNACHAIDH', 3, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4628, '1997-12-21 23:00:00+00', '2022-11-27 17:07:00.736535+00', 'Molly''s Mum', 'MOLLYS MUM', 1, 32, 9999, 1, 3, 42, 9, NULL, 'Inscribed to Liz Johnston, Vancouver Branch R.S.C.D.S.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4528, '1997-04-03 22:00:00+00', '2022-11-27 19:49:43.740058+00', 'Miss Kirsteen Blair', 'MISS KIRSTEEN BLAIR', 2, 32, 9999, 1, 3, 42, 48, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4499, '1998-09-29 22:00:00+00', '2022-12-03 11:39:12.809736+00', 'Miss Heyden', 'MISS HEYDEN', 3, 40, 9999, 1, 2, 76, 9998, '1710-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4497, '1998-11-17 23:00:00+00', '2022-12-16 12:38:28.845845+00', 'Miss Helen Strathdee', 'MISS HELEN STRATHDEE', 4, 128, 2, 4, 119, 3, 185, NULL, 'Helen was the founder of the Cambridge Scottish Society Dance Circle.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11256, '2003-03-09 23:00:00+00', '2012-01-20 12:57:27.988124+00', 'Dancing Circle, The', 'DANCING CIRCLE', 1, 40, 9999, 7, 1, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11262, '2003-03-17 23:00:00+00', '2012-01-20 12:57:28.042922+00', 'Old Smithy House, The', 'OLD SMITHY HOUSE', 1, 32, 9999, 1, 4, 1, 3117, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11247, '2003-03-09 23:00:00+00', '2016-09-23 22:27:33.679428+00', 'Lassie wi'' the Carroty Pow', 'LASSIE WI THE CARROTY POW', 4, 32, 5, 5, 2, 76, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11263, '2003-03-17 23:00:00+00', '2018-04-03 00:07:58.772714+00', 'Landsborough Medley, The', 'LANDSBOROUGH MEDLEY', 4, 32, 1, 1, 3, 42, 3117, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4541, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.643775+00', 'Miss Margaret Dall''s Delight', 'MISS MARGARET DALLS DELIGHT', 3, 32, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4542, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.652066+00', 'Miss Margaret Donaldson', 'MISS MARGARET DONALDSON', 2, 32, 9999, 1, 3, 42, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4547, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.710375+00', 'Miss Marston''s Strathspey', 'MISS MARSTONS STRATHSPEY', 3, 64, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4554, '1997-11-20 23:00:00+00', '2018-04-03 00:08:04.743726+00', 'Miss Milligan''s Maple Leaf', 'MISS MILLIGANS MAPLE LEAF', 1, 48, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4568, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.810528+00', 'Miss Rosaline Elliott', 'MISS ROSALINE ELLIOTT', 3, 40, 9999, 1, 3, 42, 393, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4570, '1997-09-09 22:00:00+00', '2018-04-03 00:08:04.827296+00', 'Miss Rosy Powell', 'MISS ROSY POWELL', 2, 32, 9999, 1, 3, 42, 1137, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4573, '1997-09-09 22:00:00+00', '2018-04-03 00:08:04.8356+00', 'Miss Sally Hunter', 'MISS SALLY HUNTER', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4574, '1998-12-06 23:00:00+00', '2018-04-03 00:08:04.843966+00', 'Miss Sally Hunter Of Thurston', 'MISS SALLY HUNTER OF THURSTON', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4576, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.852242+00', 'Miss Sarah Anne MacQueen', 'MISS SARAH ANNE MACQUEEN', 1, 40, 9999, 1, 3, 42, 348, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4577, '1997-09-09 22:00:00+00', '2018-04-03 00:08:04.860572+00', 'Miss Sayers'' Allemande', 'MISS SAYERS ALLEMANDE', 1, 32, 9999, 1, 3, 42, 1138, '1781-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4607, '1997-09-09 22:00:00+00', '2018-09-09 23:01:48.940327+00', 'Mistress Mary', 'MISTRESS MARY', 3, 32, 9999, 1, 3, 42, 502, NULL, '', 53, '800/844/866/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4588, '1997-09-09 22:00:00+00', '2012-01-20 12:56:36.762985+00', 'Miss Susan Patricia', 'MISS SUSAN PATRICIA', 3, 40, 9999, 1, 4, NULL, 1140, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11273, '2003-04-21 22:00:00+00', '2018-10-29 02:01:09.802045+00', 'McFarlane''s Lantern', 'MACFARLANES LANTERN', 2, 32, 9999, 1, 3, 42, 3336, NULL, '', 45, '806/808/088/840', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11271, '2003-04-21 22:00:00+00', '2018-10-29 10:00:43.342404+00', 'Mésanges, Les', 'MESANGES', 1, 40, 9999, 1, 3, 42, 3335, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4592, '1998-07-09 22:00:00+00', '2012-01-20 12:56:36.794577+00', 'Miss Thompson''s Reel', 'MISS THOMPSONS REEL', 1, 32, 9999, 3, 5, 7, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4586, '1997-04-03 22:00:00+00', '2019-01-12 16:39:20.29446+00', 'Miss Susan Campbell Menzies', 'MISS SUSAN CAMPBELL MENZIES', 3, 32, 9999, 5, 2, 30, 270, NULL, '', 100, '88/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4614, '1997-04-03 22:00:00+00', '2018-04-02 23:56:36.420421+00', 'Mix And Match', 'MIX AND MATCH', 1, 32, 9999, 1, 3, 42, 352, '1993-06-17', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4590, '1998-11-25 23:00:00+00', '2020-08-07 03:48:11.035581+00', 'Miss Taylor''s Reel', 'MISS TAYLORS REEL', 1, 32, 9999, 1, 3, 42, 129, '1969-01-01', '', 56, '840/880/888/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4545, '1997-04-03 22:00:00+00', '2020-11-24 10:56:09.650868+00', 'Miss Maria Stewart''s Jig', 'MISS MARIA STEWARTS JIG', 2, 48, 9999, 1, 3, 42, 270, NULL, '', 54, '800/866/666/888/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4557, '1997-04-03 22:00:00+00', '2020-11-24 11:25:13.388061+00', 'Miss Monaghan''s Reel', 'MISS MONAGHANS REEL', 1, 32, 9999, 5, 2, 30, 270, NULL, '', 100, '88/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11275, '2003-04-21 22:00:00+00', '2021-01-28 10:52:32.537394+00', 'Silky Business', 'SILKY BUSINESS', 3, 32, 9999, 1, 3, 42, 3338, '1999-01-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11264, '2003-03-17 23:00:00+00', '2021-01-28 11:03:55.789345+00', 'Helen''s Strathspey', 'HELENS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2626, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11261, '2003-03-17 23:00:00+00', '2021-01-28 11:13:09.415634+00', 'Calmac Strathspey, The', 'CALMAC STRATHSPEY', 3, 32, 9999, 3, 5, 33, 3577, NULL, '', 72, '80808/28882/88888/44844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11258, '2003-03-17 23:00:00+00', '2021-01-28 13:40:57.783721+00', 'Aku''s Jig', 'AKUS JIG', 2, 32, 9999, 1, 3, 42, 316, NULL, '', 50, '844/844/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6614, '1997-09-16 22:00:00+00', '2021-04-07 16:35:20.687736+00', 'Tiptoe and Sway', 'TIPTOE AND SWAY', 1, 32, 9999, 1, 3, 42, 26, NULL, 'This may also be danced as a strathspey.', 50, '844/808/448/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11257, '2005-04-06 22:00:00+00', '2021-04-18 19:08:03.684692+00', 'Wivenhoe Waves', 'WIVENHOE WAVES', 3, 32, 9999, 1, 4, 1, 3534, '2001-01-01', '', 42, '4440/4044/8222/4444', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4612, '1997-04-03 22:00:00+00', '2019-05-11 16:47:47.593724+00', 'Misty Law', 'MISTY LAW', 3, 32, 9999, 4, 4, 30, 13, NULL, '', 91, '8888/8686/8888/6666', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4598, '1997-09-09 22:00:00+00', '2012-01-20 12:56:36.838056+00', 'Miss Winnifred Hinderwell''s Delight', 'MISS WINNIFRED HINDERWELLS DELIGHT', 3, 32, 9999, 1, 98, NULL, 687, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4599, '1997-04-03 22:00:00+00', '2012-01-20 12:56:36.846163+00', 'Miss Worthington', 'MISS WORTHINGTON', 1, 40, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4600, '2002-06-30 22:00:00+00', '2012-01-20 12:56:36.853138+00', 'Missenden Abbey', 'MISSENDEN ABBEY', 3, 32, 9999, 1, 4, NULL, 27, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11272, '2003-04-21 22:00:00+00', '2018-04-03 00:07:32.81482+00', 'Behind the Bars', 'BEHIND THE BARS', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11265, '2003-03-17 23:00:00+00', '2012-01-20 12:57:28.06914+00', 'Sannox Burn', 'SANNOX BURN', 1, 32, 9999, 1, 4, NULL, 907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11266, '2003-03-18 23:00:00+00', '2012-01-20 12:57:28.07777+00', 'Not a Notion', 'NOT A NOTION', 1, 32, 9999, 5, 2, NULL, 2773, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11270, '2003-04-21 22:00:00+00', '2012-01-20 12:57:28.113452+00', 'Around the Alps', 'AROUND THE ALPS', 3, 32, 9999, 1, 4, NULL, 3335, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4584, '1997-09-09 22:00:00+00', '2019-09-15 19:18:47.062958+00', 'Miss Stewart of Bombay', 'MISS STEWART OF BOMBAY', 2, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11276, '2003-04-21 22:00:00+00', '2012-01-20 12:57:28.174548+00', 'Sherriff''s Farewell to Hong Kong, The', 'SHERRIFFS FAREWELL TO HONG KONG', 4, 96, 42, 1, 4, NULL, 3339, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14539, '2012-08-16 19:59:45.290907+00', '2012-08-16 20:01:31.756262+00', 'English Rose, An', 'ENGLISH ROSE', 1, 48, NULL, 2, 3, 17, 2682, '2012-06-02', 'Devised 2 June 2012 at the request of Bridget Newns Cooper, who truly is an

English Rose, as a present for her 60th Birthday. The figures represent the story

of the marriage of Anthea and Peter Cowley, with 1-16 the initial meeting, 17-

32 a time apart, and 33-48 the final commitment and marriage. ', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4606, '1997-04-03 22:00:00+00', '2012-01-20 12:56:36.89907+00', 'Mist On The Bog', 'MIST ON THE BOG', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4609, '1997-04-03 22:00:00+00', '2012-01-20 12:56:36.920395+00', 'Mists Of Mull, The', 'MISTS OF MULL', 3, 64, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4611, '2002-03-02 23:00:00+00', '2012-01-20 12:56:36.939483+00', 'Misty Isle, The', 'MISTY ISLE', 3, 32, 9999, 1, 4, 11, 13, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4613, '1997-04-03 22:00:00+00', '2012-01-20 12:56:36.955715+00', 'Mitchell Reel, The', 'MITCHELL REEL', 1, 48, 9999, 1, 4, NULL, 54, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4603, '1997-09-09 22:00:00+00', '2018-04-03 00:08:04.118266+00', 'Misses Gordon Of Rafford', 'MISSES GORDON OF RAFFORD', 1, 32, 9999, 1, 3, 42, 1129, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4616, '2000-10-13 22:00:00+00', '2012-01-20 12:56:36.976846+00', 'Mo-Ranch Special', 'MORANCH SPECIAL', 1, 32, 9999, 1, 2, NULL, 758, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4622, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.025901+00', 'Moira''s Fancy', 'MOIRAS FANCY', 3, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4578, '1997-09-09 22:00:00+00', '2022-11-07 21:09:37.455002+00', 'Miss Scales Hornpipe', 'MISS SCALES HORNPIPE', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4594, '1998-11-25 23:00:00+00', '2022-11-27 17:38:32.232984+00', 'Miss Watt''s Jig', 'MISS WATTS JIG', 2, 32, 9999, 1, 3, 42, 129, NULL, '', 56, '844/800/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4571, '1997-09-09 22:00:00+00', '2023-01-26 19:12:20.723815+00', 'Miss Rough of Longbank', 'MISS ROUGH OF LONGBANK', 2, 32, 9999, 1, 2, 76, 270, NULL, '', 56, '55/55/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4623, '1997-09-09 22:00:00+00', '2012-01-20 12:56:37.033259+00', 'Moira''s Jig', 'MOIRAS JIG', 2, 32, 9999, 1, 4, NULL, 1144, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4624, '1997-09-09 22:00:00+00', '2012-01-20 12:56:37.040082+00', 'Moira''s Medley', 'MOIRAS MEDLEY', 4, 64, 9999, 4, 4, NULL, 687, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4626, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.053822+00', 'Mol-A-Deas', 'MOLADEAS', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4580, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.885587+00', 'Miss Shepherd', 'MISS SHEPHERD', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4582, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.902391+00', 'Miss Sophia Campbell', 'MISS SOPHIA CAMPBELL', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4587, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.918957+00', 'Miss Susan Inglis', 'MISS SUSAN INGLIS', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4589, '1997-09-09 22:00:00+00', '2018-04-03 00:08:04.927319+00', 'Miss Tapsell''s Delight', 'MISS TAPSELLS DELIGHT', 3, 32, 9999, 1, 3, 42, 952, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4593, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.943961+00', 'Miss Trotter', 'MISS TROTTER', 3, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4604, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.977397+00', 'Mist Covered Mountains, The', 'MIST COVERED MOUNTAINS', 3, 32, 9999, 1, 3, 42, 44, '1989-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4605, '1997-09-29 22:00:00+00', '2018-04-03 00:08:04.986629+00', 'Mist In The Glen, The', 'MIST IN THE GLEN', 3, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4608, '1997-09-09 22:00:00+00', '2018-04-03 00:08:05.01898+00', 'Mists Of Dawn, The', 'MISTS OF DAWN', 1, 32, 9999, 1, 3, 42, 1142, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4615, '1997-04-03 22:00:00+00', '2018-04-03 00:08:05.060581+00', 'Mixer, The', 'MIXER', 2, 32, 9999, 1, 3, 42, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4627, '1997-09-09 22:00:00+00', '2018-04-03 00:08:05.085609+00', 'Molly''s Celebration', 'MOLLYS CELEBRATION', 1, 40, 9999, 1, 3, 42, 604, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11268, '2003-03-19 23:00:00+00', '2018-04-03 00:08:16.752761+00', 'Silver in Cyprus', 'SILVER IN CYPRUS', 3, 32, 9999, 1, 3, 42, 2626, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4631, '1997-11-27 23:00:00+00', '2012-01-20 12:56:37.08951+00', 'Monash Medley, The', 'MONASH MEDLEY', 4, 64, 22, 1, 4, NULL, 255, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11315, '2003-06-02 22:00:00+00', '2018-04-03 00:08:02.558897+00', 'Marysville Reel, The', 'MARYSVILLE REEL', 1, 32, 9999, 1, 3, 42, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11285, '2003-05-04 22:00:00+00', '2012-01-20 12:57:28.259788+00', 'Midnight Tryst at Haunted Manor', 'MIDNIGHT TRYST AT HAUNTED MANOR', 3, 32, 9999, 1, 4, 1, 2701, '2001-01-01', 'Demonstration dance.



The dance is named after the three dances that were my introduction to the figures used here (albeit somewhat altered): Haunted Manor (Barry Priddey); Midnight Dream (Ellen Aaron); Trysting Place (Iain Boyd).', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11290, '2003-05-04 22:00:00+00', '2012-03-23 23:07:31.043422+00', 'Sinclair''s Chief', 'SINCLAIRS CHIEF', 2, 40, 9999, 1, 4, 1, 3344, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4619, '1997-04-03 22:00:00+00', '2012-06-30 16:23:37.097143+00', 'Mogambo', 'MOGAMBO', 2, 32, 9999, 1, 4, 1, 411, '1992-01-01', '"Mogambo" is taken from the rallying cry used by University trampers of my era.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11279, '2003-05-04 22:00:00+00', '2012-03-21 22:47:26.342914+00', 'Dunsmuir Eightsome, The', 'DUNSMUIR EIGHTSOME', 1, 160, 9999, 4, 4, NULL, 401, '1992-01-01', 'Demonstration dance', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4667, '1997-09-09 22:00:00+00', '2018-09-10 13:46:08.27846+00', 'Morison''s Bush', 'MORISONS BUSH', 1, 40, 9999, 1, 3, 42, 1151, '1954-01-01', '', 50, '880/800/888/844/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11301, '2003-05-10 22:00:00+00', '2018-04-03 00:08:04.352055+00', 'Miss Helen Cleaves', 'MISS HELEN CLEAVES', 3, 32, 9999, 1, 3, 42, 854, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4739, '1997-09-10 22:00:00+00', '2012-01-20 12:56:37.861627+00', 'Mrs Blair''s Jig', 'MRS BLAIRS JIG', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4597, '2002-03-02 23:00:00+00', '2021-05-07 19:27:36.224727+00', 'Miss Williamson''s Reel', 'MISS WILLIAMSONS REEL', 1, 32, 9999, 1, 3, 42, 176, NULL, '', 61, '844/888/842/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4625, '1997-04-03 22:00:00+00', '2020-02-16 01:23:37.42598+00', 'Moko', 'MOKO', 1, 24, 9999, 1, 2, 76, 352, NULL, '', 34, '80/80/80', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4583, '1997-09-09 22:00:00+00', '2020-10-10 12:14:49.95268+00', 'Miss Sparks''s Maggot', 'MISS SPARKSS MAGGOT', 2, 48, 9999, 1, 3, 42, 198, '1753-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4635, '1997-04-03 22:00:00+00', '2020-12-01 10:21:03.867829+00', 'Monessie Reel, The', 'MONESSIE REEL', 1, 32, 9999, 1, 4, 1, 13, NULL, '', 63, '8000/8880/8088/8044', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4591, '1998-01-05 23:00:00+00', '2021-05-23 08:23:47.968422+00', 'Miss Taylor''s Reel', 'MISS TAYLORS REEL', 1, 32, 9999, 1, 3, 42, 352, '1993-01-24', '', 50, '800/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4621, '1997-09-04 22:00:00+00', '2021-04-15 08:47:42.884961+00', 'Hidden Loch, The', 'HIDDEN LOCH', 1, 176, 9999, 4, 98, NULL, 105, '1967-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4643, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.180952+00', 'Montrose Races', 'MONTROSE RACES', 3, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4645, '1998-01-05 23:00:00+00', '2012-01-20 12:56:37.195433+00', 'Monty''s Reel', 'MONTYS REEL', 1, 40, 9999, 1, 4, NULL, 476, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11289, '2003-05-04 22:00:00+00', '2018-12-09 23:34:16.386611+00', 'Seamstress, The', 'SEAMSTRESS', 3, 40, 9999, 2, 3, 17, 348, '1993-02-09', 'Dedicated to Jane Muirhead', 68, '888/888/888/844/868', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4657, '1997-11-25 23:00:00+00', '2012-01-20 12:56:37.282299+00', 'Morag Of Dunvegan', 'MORAG OF DUNVEGAN', 3, 32, 9999, 4, 4, NULL, 105, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4659, '1997-09-12 22:00:00+00', '2012-01-20 12:56:37.296272+00', 'Morar Strathspey', 'MORAR STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4660, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.30305+00', 'Moray Frolic', 'MORAY FROLIC', 2, 48, 9999, 1, 98, NULL, 237, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11314, '2003-06-02 22:00:00+00', '2012-01-20 12:57:28.470923+00', 'Lass of Cambourne, The', 'LASS OF CAMBOURNE', 3, 32, 9999, 1, 4, NULL, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4668, '1997-08-21 22:00:00+00', '2019-03-12 23:32:26.28465+00', 'Morland Knot, The', 'MORLAND KNOT', 2, 32, 9999, 1, 4, 2, 108, '1992-01-01', '', 75, '8484/8008/8888/4488', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4661, '1997-08-25 22:00:00+00', '2019-03-12 23:36:35.59685+00', 'Moray House Of Edinburgh, The', 'MORAY HOUSE OF EDINBURGH', 2, 48, 9999, 1, 4, 1, 529, '1986-01-01', '', 73, '4444/8888/8888/0880/8008/8884', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4633, '1998-01-12 23:00:00+00', '2019-03-25 23:45:30.596523+00', 'Grand March', 'GRAND MARCH', 11, 0, 9999, 5, 113, 54, 210, NULL, '', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11292, '2003-05-04 22:00:00+00', '2012-03-24 06:34:36.958199+00', 'Stolen Kiss, The', 'STOLEN KISS', 3, 32, 9999, 1, 3, 42, 348, '1994-02-01', 'For Eugene and Virginia Bissell of Lafayette class. California', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11297, '2003-05-06 22:00:00+00', '2018-04-03 00:08:04.593756+00', 'Miss Lindsay Martin''s Reel', 'MISS LINDSAY MARTINS REEL', 1, 32, 9999, 1, 3, 42, 854, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4665, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.33841+00', 'Morgiana In Spain', 'MORGIANA IN SPAIN', 2, 32, 9999, 1, 98, NULL, 237, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4639, '2001-05-21 22:00:00+00', '2019-10-29 07:07:48.242086+00', 'Monika''s Reel', 'MONIKAS REEL', 1, 32, 9999, 1, 3, 42, 228, '1992-03-17', 'For Monika Altenstetter', 62, '844/844/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4671, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.379914+00', 'Morning Fog', 'MORNING FOG', 3, 32, 9999, 1, 4, NULL, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4644, '2002-04-03 22:00:00+00', '2016-07-30 17:20:17.572469+00', 'Montrose Reel', 'MONTROSE REEL', 2, 40, 9999, 1, 4, 13, 248, '1955-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4636, '1998-01-05 23:00:00+00', '2016-09-04 20:20:05.668359+00', 'Monhegan Rant, The', 'MONHEGAN RANT', 1, 88, 9999, 4, 4, NULL, 608, NULL, 'For the York County (Maine) Scottish Country Dancers, Boston Branch, RSCDS', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4670, '1997-04-03 22:00:00+00', '2018-04-03 00:08:05.369306+00', 'Morley Knot', 'MORLEY KNOT', 3, 32, 9999, 1, 3, 42, 300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11302, '2003-05-10 22:00:00+00', '2022-04-09 07:18:04.191437+00', 'Emma''s Reel', 'EMMAS REEL', 1, 32, 9999, 1, 3, 42, 854, NULL, 'Devised for Emma Williams of Ferndown, Dorset.', 50, '800/888/822/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4664, '1997-04-03 22:00:00+00', '2022-11-07 16:43:36.313614+00', 'More Toast for the Boys', 'MORE TOAST FOR THE BOYS', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4652, '2001-05-03 22:00:00+00', '2022-04-10 02:18:46.066234+00', 'Moonshine', 'MOONSHINE', 3, 32, 9999, 2, 3, 17, 1149, NULL, '', 83, '844/888/808/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4630, '1997-09-09 22:00:00+00', '2022-11-27 17:01:08.183054+00', 'Monarchs, The', 'MONARCHS', 3, 32, 9999, 1, 3, 42, 1146, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4617, '1997-08-12 22:00:00+00', '2022-11-27 17:13:39.839586+00', 'MO''s Jig', 'MOS JIG', 2, 32, 9999, 1, 3, 42, 21, NULL, 'Incribed "For Margaret Osborne".', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4640, '1997-04-03 22:00:00+00', '2018-04-03 00:08:05.185765+00', 'Monk''s Muir, The', 'MONKS MUIR', 1, 32, 9999, 1, 3, 42, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4647, '2002-12-07 23:00:00+00', '2018-04-03 00:08:05.244044+00', 'Moomba Magic', 'MOOMBA MAGIC', 1, 40, 9999, 1, 3, 42, 680, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4648, '1997-04-03 22:00:00+00', '2018-04-03 00:08:05.252398+00', 'Moon Behind The Hill, The', 'MOON BEHIND THE HILL', 3, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4649, '1997-04-03 22:00:00+00', '2018-04-03 00:08:05.260739+00', 'Moon Coin, The', 'MOON COIN', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4754, '1997-04-03 22:00:00+00', '2018-04-03 00:08:06.211472+00', 'Mrs Grace Bowie', 'MRS GRACE BOWIE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15083, '2013-08-21 13:25:29.125293+00', '2018-04-03 00:18:02.296677+00', 'Miss Jacqueline Smith Strathspey', 'MISS JACQUELINE SMITH STRATHSPEY', 3, 32, NULL, 2, 2, 76, 3599, NULL, 'Interpretation:

Bars 1-8: The ferry over the Clyde to Dunoon, Scotland and the World Highland Dance Championships at Cowal

Bars 9-16: Working out the ''knots'' before the competition

Bars 17-24: Challenging the ''boys''

Bars 25-32: The joy that comes from the satisfaction of having danced your best



Dedicated to Jacqueline Smith-Bozzelli', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4704, '1998-04-19 22:00:00+00', '2018-04-29 10:26:03.987522+00', 'Mr Clement''s Fancy', 'MR CLEMENTS FANCY', 1, 32, 9999, 1, 3, 42, 108, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4678, '1997-09-09 22:00:00+00', '2012-01-20 12:56:37.428402+00', 'Mother Brown''s Cat', 'MOTHER BROWNS CAT', 1, 34, 9999, 1, 2, NULL, 446, '1701-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11309, '2003-06-02 22:00:00+00', '2018-04-03 00:07:32.873201+00', 'Belle of Victoria, The', 'BELLE OF VICTORIA', 3, 32, 9999, 1, 3, 42, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18838, '2018-10-06 12:28:03.716966+00', '2018-10-06 12:28:03.716966+00', 'New Rose, A', 'NEW ROSE', 3, 32, NULL, 4, 4, 13, 2766, '2012-01-01', 'Years ago I wrote a dance named The Rose. Re-reading it one day, I thought of this dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4682, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.456112+00', 'Mount Pleasant', 'MOUNT PLEASANT', 3, 32, 9999, 1, 4, NULL, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4683, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.463283+00', 'Mount Ruapehu', 'MOUNT RUAPEHU', 1, 32, 9999, 4, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4686, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.483733+00', 'Mount Stuart House', 'MOUNT STUART HOUSE', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11283, '2003-05-04 22:00:00+00', '2020-06-15 15:04:30.66546+00', 'Maurice', 'MAURICE', 3, 32, 9999, 1, 2, 76, 389, '2001-01-01', '', 60, '44/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4650, '1997-11-27 23:00:00+00', '2020-08-07 03:50:06.550275+00', 'Moon Dance, The', 'MOON DANCE', 4, 48, 24, 1, 4, NULL, 129, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11300, '2003-05-10 22:00:00+00', '2020-09-15 08:22:51.345352+00', 'Miss Sara Churchill', 'MISS SARA CHURCHILL', 3, 32, 9999, 2, 3, 18, 854, NULL, '', 77, '800/888/666/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11316, '2003-06-02 22:00:00+00', '2020-09-15 08:27:27.035755+00', 'Rose in the Valley, A', 'ROSE IN THE VALLEY', 4, 128, 13, 4, 4, 3, 360, NULL, '', 94, '8888/8888/4444/8888/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4653, '1999-10-15 22:00:00+00', '2020-11-26 20:52:11.397881+00', 'Moonwalkers Reel', 'MOONWALKERS REEL', 1, 32, 9999, 1, 4, NULL, 77, '1969-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18837, '2018-10-06 12:11:55.070046+00', '2021-01-04 12:36:30.212102+00', 'Needy Kneader', 'NEEDY KNEADER', 3, 32, NULL, 1, 3, 42, 2766, '2010-05-01', 'This dance is for our cat, Christopher, who kneads my lap a lot.', 63, ' 866/888/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4677, '2002-04-30 22:00:00+00', '2021-05-06 14:03:09.27806+00', 'Mosshouse', 'MOSSHOUSE', 3, 32, 9999, 1, 4, 2, 520, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4655, '1999-05-25 22:00:00+00', '2021-01-28 07:06:57.750572+00', 'Morag Hutton Strathspey, The', 'MORAG HUTTON STRATHSPEY', 3, 32, 9999, 1, 4, 1, 1351, '1983-01-01', 'Written for her Birthday.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4656, '1997-04-03 22:00:00+00', '2021-01-31 10:12:24.786735+00', 'Morag Hutton''s Strathspey', 'MORAG HUTTONS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4666, '1997-09-09 22:00:00+00', '2021-05-14 19:06:31.156261+00', 'Morison Rant, The', 'MORISON RANT', 2, 32, 9999, 1, 3, 42, 176, NULL, 'The diagram for bars 25-30 in the original instructions does not match the text description very well.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4658, '1997-09-09 22:00:00+00', '2021-08-10 18:06:52.837145+00', 'Moran Taing', 'MORAN TAING', 3, 48, 9999, 1, 4, 1, 243, NULL, 'For Don Erwood.



The notes say that "Moran taing is Scots Gaelic for Many thanks."



Iain Macfarlane was a native Gaelic speaker and for many years he taught the Calvin dance 

group in Toronto. The dance is not dated but probably is from the 1970s.  ', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4691, '2001-01-25 23:00:00+00', '2012-01-20 12:56:37.519029+00', 'Moving Cloud', 'MOVING CLOUD', 1, 32, 9999, 1, 4, 2, 270, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11306, '2003-05-14 22:00:00+00', '2012-01-20 12:57:28.416672+00', 'Hands Across the World', 'HANDS ACROSS THE WORLD', 3, 80, 9999, 4, 4, NULL, 3347, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11311, '2003-06-02 22:00:00+00', '2012-01-20 12:57:28.450569+00', 'Donwell Strathspey, The', 'DONWELL STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11312, '2003-06-02 22:00:00+00', '2012-01-20 12:57:28.45734+00', 'Forty times Two', 'FORTY TIMES TWO', 3, 32, 9999, 1, 4, NULL, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11313, '2003-06-02 22:00:00+00', '2012-01-20 12:57:28.46409+00', 'Kilbirnie Lass, The', 'KILBIRNIE LASS', 3, 32, 9999, 1, 4, NULL, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4700, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.581503+00', 'Mr Alex Menzies', 'MR ALEX MENZIES', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4702, '1997-09-02 22:00:00+00', '2012-01-20 12:56:37.597583+00', 'Football Favourite Country Dance', 'FOOTBALL FAVOURITE COUNTRY DANCE', 1, 32, 9999, 1, 2, NULL, 499, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4703, '1997-06-17 22:00:00+00', '2012-01-20 12:56:37.604411+00', 'Mr Charles Graham''s Welcome Home', 'MR CHARLES GRAHAMS WELCOME HOME', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4706, '1997-12-03 23:00:00+00', '2012-01-20 12:56:37.625401+00', 'Craigie Knowes', 'CRAIGIE KNOWES', 2, 96, 9999, 4, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4711, '1997-09-09 22:00:00+00', '2012-01-20 12:56:37.666619+00', 'Mr Isaac''s Maggot', 'MR ISAACS MAGGOT', 1, 24, 9999, 1, 2, NULL, 446, '1698-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4714, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.687542+00', 'Mr Martin', 'MR MARTIN', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4718, '1999-08-06 22:00:00+00', '2012-01-20 12:56:37.714977+00', 'Mr Norman Dunlop''s Reel', 'MR NORMAN DUNLOPS REEL', 1, 48, 9999, 1, 4, NULL, 57, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11319, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.505154+00', 'Twister', 'TWISTER', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11321, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.518723+00', 'After the Chord', 'AFTER THE CHORD', 1, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11320, '2003-06-03 22:00:00+00', '2018-03-23 20:00:07.666307+00', 'Scotland 2000', 'SCOTLAND 2000', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11310, '2003-06-02 22:00:00+00', '2018-04-03 00:07:33.223772+00', 'Between Friends', 'BETWEEN FRIENDS', 2, 32, 9999, 1, 3, 42, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11307, '2003-05-14 22:00:00+00', '2018-04-03 00:07:34.283229+00', 'Blue Badge', 'BLUE BADGE', 2, 32, 9999, 1, 3, 42, 3347, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11305, '2003-05-10 22:00:00+00', '2018-04-03 00:08:04.085035+00', 'Miss Elizabeth Green''s Reel', 'MISS ELIZABETH GREENS REEL', 1, 32, 9999, 1, 3, 42, 854, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11304, '2003-05-10 22:00:00+00', '2018-04-03 00:08:05.235736+00', 'Moodiesburn Reel, The', 'MOODIESBURN REEL', 1, 32, 9999, 1, 3, 42, 854, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4676, '1998-01-04 23:00:00+00', '2018-04-03 00:08:05.477719+00', 'Mossflower Wood', 'MOSSFLOWER WOOD', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4689, '1997-04-03 22:00:00+00', '2018-04-03 00:08:05.510936+00', 'Mountain Magic', 'MOUNTAIN MAGIC', 2, 32, 9999, 1, 3, 42, 108, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4698, '1997-04-03 22:00:00+00', '2022-11-07 21:09:59.098252+00', 'Mr and Mrs Victor Jamieson', 'MR AND MRS VICTOR JAMIESON', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4717, '1997-04-03 22:00:00+00', '2022-11-07 22:07:33.37354+00', 'Mr Morison of Bognie', 'MR MORISON OF BOGNIE', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4669, '1998-01-12 23:00:00+00', '2022-11-27 16:47:52.629455+00', 'Morland Reel, The', 'MORLAND REEL', 2, 32, 9999, 1, 3, 42, 108, '1987-01-01', 'The notes say this was a "dance devlsed ior the week of S.C.D. held in Morland, Cumbria in May 1987".', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4651, '1997-09-09 22:00:00+00', '2022-12-03 11:29:44.075299+00', 'Moonrakers', 'MOONRAKERS', 1, 32, 9999, 1, 3, 42, 282, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4687, '2003-01-28 23:00:00+00', '2018-04-03 00:08:05.535932+00', 'Mount Tum Tum', 'MOUNT TUM TUM', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4693, '1997-09-09 22:00:00+00', '2018-04-03 00:08:05.561137+00', 'Moving On', 'MOVING ON', 1, 32, 9999, 1, 3, 42, 1155, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4694, '1999-07-18 22:00:00+00', '2018-04-03 00:08:05.577858+00', 'Mowbray Strathspey, The', 'MOWBRAY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2622, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4713, '1997-09-09 22:00:00+00', '2018-04-03 00:08:05.702994+00', 'Mr Luke''s Reel', 'MR LUKES REEL', 1, 32, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4699, '1997-04-03 22:00:00+00', '2018-04-03 00:08:05.936437+00', 'Mr & Mrs Wakeman Of Lafayette', 'MR AND MRS WAKEMAN OF LAFAYETTE', 3, 32, 9999, 1, 3, 42, 348, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11318, '2003-06-03 22:00:00+00', '2018-04-03 00:08:15.677137+00', 'September Morn', 'SEPTEMBER MORN', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11317, '2003-06-03 22:00:00+00', '2018-04-03 00:08:17.219778+00', 'Skelton Reel', 'SKELTON REEL', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11322, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.525498+00', 'Threshing the Barley', 'THRESHING THE BARLEY', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11324, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.539055+00', 'Candy Swirl', 'CANDY SWIRL', 1, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11325, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.545799+00', 'Golden Child', 'GOLDEN CHILD', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11328, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.566046+00', 'Awake The Dance', 'AWAKE THE DANCE', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11329, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.575157+00', 'Summer in January', 'SUMMER IN JANUARY', 2, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4749, '1997-04-03 22:00:00+00', '2018-05-29 17:46:26.210159+00', 'Mrs Fanny Kyd', 'MRS FANNY KYD', 1, 32, 9999, 1, 3, 42, 129, NULL, '', 34, '440/880/404/804', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4707, '1997-04-03 22:00:00+00', '2018-05-29 17:39:20.355368+00', 'Mr Edward Wagstaff''s Fancy', 'MR EDWARD WAGSTAFFS FANCY', 1, 32, 9999, 1, 3, 42, 129, '1969-01-01', '', 46, '800/844/866/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4708, '1997-04-03 22:00:00+00', '2018-05-30 10:05:36.929615+00', 'Mr George A. Young', 'MR GEORGE A YOUNG', 3, 32, 9999, 1, 3, 42, 129, '1968-01-01', '', 43, '800/880/808/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4715, '1998-01-05 23:00:00+00', '2018-04-02 23:56:36.504137+00', 'Mr Michie', 'MR MICHIE', 1, 32, 9999, 1, 3, 42, 129, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4724, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.756427+00', 'Mr Tierney''s Reel', 'MR TIERNEYS REEL', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4729, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.79332+00', 'Mrs Adie', 'MRS ADIE', 3, 32, 9999, 5, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4732, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.81398+00', 'Mrs Anderson''s Reel', 'MRS ANDERSONS REEL', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4733, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.820762+00', 'Mrs Ann Robertson', 'MRS ANN ROBERTSON', 1, 32, 9999, 3, 5, NULL, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4735, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.834419+00', 'Mrs B. Jolly', 'MRS B JOLLY', 3, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4751, '1997-04-03 22:00:00+00', '2020-04-29 22:00:50.220583+00', 'Mrs Garden of Troup', 'MRS GARDEN OF TROUP', 3, 48, 9999, 5, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4690, '1997-04-03 22:00:00+00', '2020-12-26 11:12:22.690389+00', 'Mountain Of The Winds', 'MOUNTAIN OF THE WINDS', 3, 32, 9999, 1, 4, 2, 13, NULL, '', 75, '4444/8888/4444/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4688, '1997-04-03 22:00:00+00', '2021-05-13 08:03:49.611333+00', 'Mount Wellington Reel', 'MOUNT WELLINGTON REEL', 1, 32, 9999, 1, 3, 42, 352, '1993-01-23', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4740, '1997-12-28 23:00:00+00', '2012-01-20 12:56:37.868503+00', 'Forest City Reel, The', 'FOREST CITY REEL', 1, 48, 9999, 1, 4, NULL, 737, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4742, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.884172+00', 'Mrs C. Allen''s Strathspey', 'MRS C ALLENS STRATHSPEY', 3, 32, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4743, '1997-04-03 22:00:00+00', '2012-01-20 12:56:37.891146+00', 'Mrs Charlotte Harrison', 'MRS CHARLOTTE HARRISON', 4, 96, 9999, 4, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11332, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.601312+00', 'Challenge, The', 'CHALLENGE', 2, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11334, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.618641+00', 'Mind Games', 'MIND GAMES', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11336, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.636441+00', 'Break Out', 'BREAK OUT', 1, 40, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11339, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.66241+00', 'Beyond 2000', 'BEYOND 2000', 3, 40, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11341, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.679713+00', 'Jordan''s Dance', 'JORDANS DANCE', 1, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11342, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.68836+00', 'New Generation Reel, The', 'NEW GENERATION REEL', 1, 32, 9999, 4, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11345, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.714746+00', 'Celebration, A', 'CELEBRATION', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4750, '1997-04-03 22:00:00+00', '2016-04-18 23:19:03.602393+00', 'Mrs Fitchet', 'MRS FITCHET', 3, 32, 9999, 1, 2, NULL, 129, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11344, '2003-06-03 22:00:00+00', '2018-04-03 00:07:32.581126+00', 'Barry''s Birthday Jig', 'BARRYS BIRTHDAY JIG', 2, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4726, '1997-04-03 22:00:00+00', '2018-04-02 23:56:36.55423+00', 'Mr William Brown''s Reel', 'MR WILLIAM BROWNS REEL', 1, 32, 9999, 1, 3, 42, 129, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11340, '2003-06-03 22:00:00+00', '2018-04-03 00:07:33.566045+00', 'Black Boat', 'BLACK BOAT', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11343, '2003-06-03 22:00:00+00', '2018-04-03 00:07:37.111881+00', 'Caroline''s Reel', 'CAROLINES REEL', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4730, '1997-09-10 22:00:00+00', '2018-04-03 00:08:05.961273+00', 'Mrs Alexander Of Queensferry', 'MRS ALEXANDER OF QUEENSFERRY', 2, 32, 9999, 1, 3, 42, 617, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4731, '1997-04-03 22:00:00+00', '2018-04-03 00:08:05.970218+00', 'Mrs Amy', 'MRS AMY', 3, 32, 9999, 1, 3, 42, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4745, '1997-04-03 22:00:00+00', '2018-04-03 00:08:06.011287+00', 'Mrs Couts Trotter''s Favourite', 'MRS COUTS TROTTERS FAVOURITE', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4748, '1997-04-03 22:00:00+00', '2018-04-03 00:08:06.12812+00', 'Mrs Ena Meikle''s Strathspey', 'MRS ENA MEIKLES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4723, '1997-04-03 22:00:00+00', '2018-04-03 00:08:06.244811+00', 'Mr Sharpe''s Favourite', 'MR SHARPES FAVOURITE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11330, '2003-06-03 22:00:00+00', '2018-04-03 00:08:11.565878+00', 'Quarry Falls', 'QUARRY FALLS', 2, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11335, '2003-06-03 22:00:00+00', '2018-04-03 00:08:13.000185+00', 'Riddler''s Moon', 'RIDDLERS MOON', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11327, '2003-06-03 22:00:00+00', '2018-04-03 00:08:13.358877+00', 'Roaring 40''s', 'ROARING 40S', 1, 40, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11333, '2003-06-03 22:00:00+00', '2018-04-03 00:08:14.37619+00', 'Sailing Away', 'SAILING AWAY', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18840, '2018-10-06 12:40:57.118401+00', '2018-10-06 12:40:57.118401+00', 'No Time to Rest', 'NO TIME TO REST', 2, 32, NULL, 1, 3, 42, 2766, '2009-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11423, '2003-08-28 22:00:00+00', '2012-01-20 12:57:29.422156+00', 'Kiss in May, A', 'KISS IN MAY', 3, 32, 9999, 1, 4, NULL, 17, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4705, '1997-04-03 22:00:00+00', '2022-11-07 16:43:49.647185+00', 'Mr. Compton', 'MR COMPTON', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4722, '1997-09-09 22:00:00+00', '2022-11-07 21:10:46.805291+00', 'Mr Sharpe of Hoddany', 'MR SHARPE OF HODDANY', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4736, '1997-04-03 22:00:00+00', '2022-11-07 22:07:46.720891+00', 'Mrs Baird of Newbyth', 'MRS BAIRD OF NEWBYTH', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4695, '1998-11-23 23:00:00+00', '2022-12-18 20:45:18.90004+00', 'Mr & Mrs Brian Hamilton Of Boldmere', 'MR AND MRS BRIAN HAMILTON OF BOLDMERE', 2, 32, 9999, 1, 3, 42, 377, NULL, 'The author states: "This dance was devised in a dream and written down on waking."', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11358, '2003-06-11 22:00:00+00', '2018-11-26 21:22:41.068511+00', 'Portman Road', 'PORTMAN ROAD', 2, 32, 9999, 1, 3, 42, 3353, NULL, '', 63, '884/848/888/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4789, '1997-12-21 23:00:00+00', '2019-03-12 21:40:00.863411+00', 'Mrs Margaret Macwaters', 'MRS MARGARET MACWATERS', 3, 32, 9999, 1, 4, 1, 9, NULL, '', 66, '8448/6446/6446/8048', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4766, '1997-04-03 22:00:00+00', '2012-01-20 12:56:38.058905+00', 'Mrs Herries Forbes', 'MRS HERRIES FORBES', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4777, '1997-04-03 22:00:00+00', '2019-08-28 19:21:53.268924+00', 'Mrs Low''s Reel', 'MRS LOWS REEL', 1, 32, 9999, 1, 4, 2, 270, NULL, '', 75, '8008/8448/8888/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4770, '1997-09-10 22:00:00+00', '2012-01-20 12:56:38.089088+00', 'Mrs Jessie Blair', 'MRS JESSIE BLAIR', 3, 40, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4771, '1997-04-03 22:00:00+00', '2012-01-20 12:56:38.095979+00', 'Mrs Jimmy Shand''s Strathspey', 'MRS JIMMY SHANDS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11349, '2003-06-03 22:00:00+00', '2012-01-20 12:57:28.749385+00', 'Barrack Square', 'BARRACK SQUARE', 2, 32, 9999, 4, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11355, '2003-06-11 22:00:00+00', '2012-01-20 12:57:28.801507+00', 'Counting for Ivy', 'COUNTING FOR IVY', 2, 40, 9999, 3, 5, NULL, 3351, NULL, '10-bar phrases (6+4)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4778, '1997-10-29 23:00:00+00', '2012-01-20 12:56:38.151165+00', 'Mrs MacDouall Grant', 'MRS MACDOUALL GRANT', 1, 32, 9999, 1, 2, NULL, 843, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4786, '1997-09-10 22:00:00+00', '2012-01-20 12:56:38.207466+00', 'Mrs Malone Of Kilsyth', 'MRS MALONE OF KILSYTH', 3, 64, 9999, 4, 4, NULL, 847, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4787, '1997-09-10 22:00:00+00', '2012-01-20 12:56:38.214369+00', 'Mrs Margaret Clarke''s Fancy', 'MRS MARGARET CLARKES FANCY', 1, 64, 9999, 4, 4, NULL, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14546, '2012-08-28 10:57:27.9401+00', '2013-10-29 01:26:23.788716+00', 'Anne, Duchess of Waltham', 'ANNE DUCHESS OF WALTHAM', 3, 80, NULL, 6, 3, 3, 10648, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11352, '2003-06-11 22:00:00+00', '2018-04-03 00:07:41.658417+00', 'Dedicated Dancer, A', 'DEDICATED DANCER', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4783, '1998-07-09 22:00:00+00', '2020-05-14 22:54:30.380052+00', 'Mrs Macpherson of Cluny', 'MRS MACPHERSON OF CLUNY', 2, 32, 9999, 3, 5, 16, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4753, '1997-09-10 22:00:00+00', '2020-10-07 21:55:49.856693+00', 'Mrs Gordon of Troop''s Strathspey', 'MRS GORDON OF TROOPS STRATHSPEY', 3, 40, 9999, 1, 3, 42, 1161, '1800-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11323, '2003-06-03 22:00:00+00', '2021-04-03 10:29:01.95642+00', 'Chevalier de'' St George', 'CHEVALIER DE ST GEORGE', 1, 32, 9999, 1, 3, 42, 352, '1991-05-05', '', 63, '888/888/626/684', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11326, '2003-06-03 22:00:00+00', '2021-04-03 11:39:14.352161+00', 'Fiddle Sticks', 'FIDDLE STICKS', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4752, '2002-04-19 22:00:00+00', '2021-05-04 23:32:25.331361+00', 'Mrs Garthland''s Strathspey', 'MRS GARTHLANDS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 38, '822/822/800/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4746, '1997-10-28 23:00:00+00', '2021-05-06 13:40:26.350839+00', 'Mrs Double''s Strathspey', 'MRS DOUBLES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', 66, '888/884/888/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4747, '1997-09-10 22:00:00+00', '2021-05-30 12:08:59.991208+00', 'Mrs Elizabeth Smith', 'MRS ELIZABETH SMITH', 1, 32, 9999, 1, 3, 42, 352, '1991-01-01', 'Devised for her 70th Birthday.



The <<ddpub:Blue Book#604>> gives the music as "Good Hearted Glasgow" although that is a Jig and this dance is described as a Reel.', 34, '800/880/822/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4790, '1997-09-10 22:00:00+00', '2012-01-20 12:56:38.235033+00', 'Mrs Margaret Turner Of Waverley', 'MRS MARGARET TURNER OF WAVERLEY', 2, 32, 9999, 1, 4, NULL, 701, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4794, '1997-09-10 22:00:00+00', '2012-01-20 12:56:38.262559+00', 'Mrs May Sinclair', 'MRS MAY SINCLAIR', 3, 32, 9999, 3, 5, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4795, '1997-09-10 22:00:00+00', '2012-01-20 12:56:38.269345+00', 'Mrs McKie''s Strathspey', 'MRS MACKIES STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 109, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4801, '2003-01-28 23:00:00+00', '2012-01-20 12:56:38.31277+00', 'Mrs Simcoe''s Diary', 'MRS SIMCOES DIARY', 3, 32, 9999, 1, 4, NULL, 35, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4802, '1999-11-16 23:00:00+00', '2012-01-20 12:56:38.319684+00', 'Mrs Stewart Nicholson', 'MRS STEWART NICHOLSON', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11350, '2003-06-03 22:00:00+00', '2018-04-03 00:07:48.906707+00', 'Glimpse of the Past, A', 'GLIMPSE OF THE PAST', 3, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4763, '2000-01-30 23:00:00+00', '2017-03-20 23:17:31.876837+00', 'Mrs Hay Of Angus', 'MRS HAY OF ANGUS', 3, 32, 9999, 1, 4, 1, 173, NULL, '', 81, '8888/8888/8888/8000', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11347, '2003-06-03 22:00:00+00', '2018-04-03 00:07:50.441554+00', 'Halfway Home', 'HALFWAY HOME', 2, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11353, '2003-06-11 22:00:00+00', '2018-04-03 00:07:54.66118+00', 'Ivy''s Delight', 'IVYS DELIGHT', 1, 32, 9999, 1, 3, 42, 3349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11346, '2003-06-03 22:00:00+00', '2018-04-03 00:07:54.727955+00', 'I Will Follow You', 'I WILL FOLLOW YOU', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11357, '2003-06-11 22:00:00+00', '2018-04-03 00:07:55.628546+00', 'Jigsaw for Ivy, A', 'JIGSAW FOR IVY', 2, 32, 9999, 1, 3, 42, 3352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4756, '1997-04-03 22:00:00+00', '2018-04-03 00:08:06.228093+00', 'Mrs Gregory', 'MRS GREGORY', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4761, '1997-04-03 22:00:00+00', '2018-04-03 00:08:06.303293+00', 'Mrs Harvey''s Strathspey', 'MRS HARVEYS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 424, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4762, '1997-04-03 22:00:00+00', '2018-04-03 00:08:06.311549+00', 'Mrs Haswell', 'MRS HASWELL', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4764, '1997-04-03 22:00:00+00', '2018-04-03 00:08:06.329067+00', 'Mrs Helen Fleming', 'MRS HELEN FLEMING', 2, 40, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4772, '1997-04-03 22:00:00+00', '2018-04-03 00:08:06.386519+00', 'Mrs John Clark''s Delight', 'MRS JOHN CLARKS DELIGHT', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4773, '1997-04-03 22:00:00+00', '2018-04-03 00:08:06.394792+00', 'Mrs Joseph Lowe', 'MRS JOSEPH LOWE', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4775, '1997-09-10 22:00:00+00', '2018-04-03 00:08:06.436708+00', 'Mrs Leslie''s Strathspey', 'MRS LESLIES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4776, '1997-07-04 22:00:00+00', '2018-04-03 00:08:06.445038+00', 'Mrs Leslye Buchanan', 'MRS LESLYE BUCHANAN', 1, 32, 9999, 1, 3, 42, 396, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4780, '1998-01-05 23:00:00+00', '2018-04-03 00:08:06.470027+00', 'Mrs MacKinnon''s Reel', 'MRS MACKINNONS REEL', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4793, '1997-04-03 22:00:00+00', '2018-04-03 00:08:06.553811+00', 'Mrs Maule', 'MRS MAULE', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4798, '1997-04-03 22:00:00+00', '2018-04-03 00:08:06.587195+00', 'Mrs Muriel Skinner', 'MRS MURIEL SKINNER', 4, 32, 9999, 1, 3, 42, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11354, '2003-06-11 22:00:00+00', '2018-04-03 00:08:12.32476+00', 'Reel for Ivy, A', 'REEL FOR IVY', 1, 32, 9999, 1, 3, 42, 3350, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11348, '2003-06-03 22:00:00+00', '2018-04-03 00:08:17.653426+00', 'Soldier''s Return', 'SOLDIERS RETURN', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11361, '2003-06-11 22:00:00+00', '2012-01-20 12:57:28.853498+00', 'Ladies First', 'LADIES FIRST', 3, 32, 9999, 2, 3, NULL, 1243, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11362, '2003-06-11 22:00:00+00', '2012-01-20 12:57:28.86214+00', 'Memories', 'MEMORIES', 3, 32, 9999, 1, 4, NULL, 3350, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4820, '1997-04-03 22:00:00+00', '2018-04-29 13:20:03.629071+00', 'Muckle Toon, The', 'MUCKLE TOON', 3, 32, 9999, 1, 3, 42, 212, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4769, '1997-09-10 22:00:00+00', '2022-08-01 20:43:54.791601+00', 'Mrs Jean Garvin''s Strathspey', 'MRS JEAN GARVINS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 990, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4797, '1997-04-03 22:00:00+00', '2022-11-07 16:44:10.536311+00', 'Mrs. Monair of Bruach', 'MRS MONAIR OF BRUACH', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4757, '1998-07-09 22:00:00+00', '2022-11-07 21:11:27.688783+00', 'Mrs H. L. McDonald Of Dunach', 'MRS H L MACDONALD OF DUNACH', 3, 48, 9999, 3, 5, 16, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4768, '1997-09-10 22:00:00+00', '2022-11-20 16:27:03.019734+00', 'Mrs Ian Powrie of West Kirkton', 'MRS IAN POWRIE OF WEST KIRKTON', 3, 32, 9999, 1, 4, 1, 167, NULL, '', 56, '8880/8000/8880/8044', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4811, '1997-09-10 22:00:00+00', '2012-01-20 12:56:38.384928+00', 'Mrs Teddy Coutts', 'MRS TEDDY COUTTS', 2, 32, 9999, 1, 4, NULL, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4834, '1997-04-03 22:00:00+00', '2018-04-21 11:00:10.468438+00', 'Muriel Hadden''s Strathspey', 'MURIEL HADDENS STRATHSPEY', 3, 48, 9999, 1, 4, 1, 108, '1967-01-01', '', 83, '8888/8888/8800/8800/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4821, '1997-04-03 22:00:00+00', '2019-08-02 23:55:57.385296+00', 'Mucklestane Moor', 'MUCKLESTANE MOOR', 3, 32, 9999, 1, 2, 76, 129, NULL, '', 64, '66/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4823, '1997-10-27 23:00:00+00', '2012-01-20 12:56:38.470062+00', 'Muir O'' Loggie, The', 'MUIR O LOGGIE', 3, 32, 9999, 1, 4, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4824, '1997-09-10 22:00:00+00', '2012-01-20 12:56:38.477165+00', 'Muirfield Reel, The', 'MUIRFIELD REEL', 1, 40, 9999, 1, 4, NULL, 318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4826, '1997-04-03 22:00:00+00', '2012-01-20 12:56:38.491493+00', 'Muirhead Of Logie', 'MUIRHEAD OF LOGIE', 1, 32, 9999, 4, 4, NULL, 417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4829, '1997-09-10 22:00:00+00', '2012-01-20 12:56:38.514111+00', 'Munlochy Bridge', 'MUNLOCHY BRIDGE', 4, 32, 9999, 2, 3, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4831, '1997-09-10 22:00:00+00', '2012-01-20 12:56:38.527778+00', 'Murchadh Strathspey', 'MURCHADH STRATHSPEY', 3, 48, 9999, 1, 4, NULL, 161, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11377, '2003-07-06 22:00:00+00', '2012-01-20 12:57:29.004917+00', 'Gauldry Strathspey, The', 'GAULDRY STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11378, '2003-07-06 22:00:00+00', '2012-01-20 12:57:29.013614+00', 'Oliver''s Jig, The', 'OLIVERS JIG', 2, 96, 9999, 4, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11379, '2003-07-06 22:00:00+00', '2012-01-20 12:57:29.022292+00', 'Ella', 'ELLA', 3, 32, 9999, 3, 5, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11380, '2003-07-06 22:00:00+00', '2012-01-20 12:57:29.030958+00', 'Wagtails by the Wye, The', 'WAGTAILS BY THE WYE', 2, 32, 9999, 2, 3, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11381, '2003-07-06 22:00:00+00', '2012-01-20 12:57:29.039677+00', 'Mull of Galloway, The', 'MULL OF GALLOWAY', 3, 32, 9999, 4, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11382, '2003-07-06 22:00:00+00', '2012-01-20 12:57:29.050398+00', 'Beauchamp Strathspey, The', 'BEAUCHAMP STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11383, '2003-07-06 22:00:00+00', '2012-01-20 12:57:29.059141+00', 'Happy Birthday Jack', 'HAPPY BIRTHDAY JACK', 3, 32, 9999, 1, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4767, '1997-11-18 23:00:00+00', '2020-07-26 10:02:42.740868+00', 'Mrs Hill''s Delight', 'MRS HILLS DELIGHT', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4785, '1997-04-03 22:00:00+00', '2020-09-01 14:08:35.535687+00', 'Mrs Macpherson of Logie-Buchan', 'MRS MACPHERSON OF LOGIEBUCHAN', 1, 32, 9999, 1, 3, 42, 368, NULL, '', 56, '880/888/808/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14547, '2012-08-28 11:14:31.303513+00', '2020-10-01 11:17:27.80815+00', 'Summer Sunday Strathspey', 'SUMMER SUNDAY STRATHSPEY', 3, 32, NULL, 4, 4, 1, 10648, NULL, '', 100, '8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4828, '1997-09-10 22:00:00+00', '2020-10-03 12:58:31.030225+00', 'Muness Castle', 'MUNESS CASTLE', 3, 32, 9999, 1, 4, 1, 815, NULL, 'Muness Castle was built by Laurence Bruce of Cultmalindie in 1598 on his arrival in Unst, Shetland.', 88, '8888/6666/8888/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4791, '1997-09-10 22:00:00+00', '2021-04-14 22:24:38.442077+00', 'Mrs Mary McManus', 'MRS MARY MACMANUS', 3, 32, 9999, 5, 56, NULL, 270, NULL, '', 100, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4760, '1997-09-10 22:00:00+00', '2021-02-28 01:52:55.192318+00', 'Mrs Harrison''s Rant', 'MRS HARRISONS RANT', 2, 32, 9999, 1, 3, 42, 176, NULL, '', 56, '822/888/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4813, '2001-03-30 22:00:00+00', '2021-05-04 22:54:30.535761+00', 'Mrs Ward''s Fancy', 'MRS WARDS FANCY', 3, 32, 9999, 1, 2, 76, 1149, NULL, '', 60, '88/80/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4818, '1997-08-22 22:00:00+00', '2019-08-29 20:31:07.775452+00', 'Muckle Ado', 'MUCKLE ADO', 1, 32, 9999, 1, 3, 42, 101, NULL, '', 56, '800/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11385, '2003-07-06 22:00:00+00', '2012-01-20 12:57:29.077627+00', 'David''s Welcome', 'DAVIDS WELCOME', 1, 32, 9999, 2, 3, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11387, '2003-07-06 22:00:00+00', '2012-01-20 12:57:29.095141+00', 'Wells Strathspey, The', 'WELLS STRATHSPEY', 3, 32, 9999, 2, 3, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4810, '1997-04-03 22:00:00+00', '2012-05-02 11:42:12.091568+00', 'Mrs Tayler Of Hunter Valley', 'MRS TAYLER OF HUNTER VALLEY', 1, 32, 9999, 1, 100, 2, 109, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14555, '2012-09-03 21:52:21.262701+00', '2018-04-03 00:07:50.608323+00', 'Hana''s Fancy', 'HANAS FANCY', 2, 32, NULL, 1, 3, 42, 2108, NULL, 'Devised 2012 for Hana Wittmeier on occasion of her (not numbered) ''18th birthday''.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4842, '1997-11-24 23:00:00+00', '2012-01-20 12:56:38.616342+00', 'Mushmimkin Reel', 'MUSHMIMKIN REEL', 1, 96, 9999, 4, 8, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4846, '1997-04-03 22:00:00+00', '2012-01-20 12:56:38.645239+00', 'Music Of The Sea', 'MUSIC OF THE SEA', 3, 32, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4849, '1997-04-03 22:00:00+00', '2012-01-20 12:56:38.667986+00', 'My Ain Lassie', 'MY AIN LASSIE', 3, 32, 9999, 1, 2, NULL, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4850, '1997-04-03 22:00:00+00', '2012-01-20 12:56:38.674779+00', 'My Bonnie', 'MY BONNIE', 2, 32, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4851, '1997-04-03 22:00:00+00', '2012-01-20 12:56:38.681538+00', 'My Bonnie Highland Glens', 'MY BONNIE HIGHLAND GLENS', 3, 44, 9999, 1, 4, NULL, 78, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4854, '1997-09-10 22:00:00+00', '2012-01-20 12:56:38.703171+00', 'My Daddy Oh!', 'MY DADDY OH', 2, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4856, '1998-07-08 22:00:00+00', '2012-01-20 12:56:38.717427+00', 'My Friend Jean', 'MY FRIEND JEAN', 1, 32, 9999, 1, 4, 2, 247, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4822, '1998-07-08 22:00:00+00', '2013-10-02 17:15:56.822521+00', 'Muggons In May', 'MUGGONS IN MAY', 2, 32, 9999, 1, 4, 2, 313, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11363, '2003-06-11 22:00:00+00', '2016-02-15 08:03:16.900979+00', 'Mrs Thew of Mt Wellington', 'MRS THEW OF MT WELLINGTON', 3, 32, 9999, 2, 3, NULL, 411, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4825, '2000-09-21 22:00:00+00', '2016-05-11 13:53:02.878289+00', 'Muirhead Bobbie', 'MUIRHEAD BOBBIE', 2, 48, 9999, 107, 3, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4807, '1997-04-03 22:00:00+00', '2018-04-03 00:08:06.687268+00', 'Mrs Stirling of Keir', 'MRS STIRLING OF KEIR', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4817, '1998-01-05 23:00:00+00', '2018-04-03 00:08:06.795548+00', 'Much to Our Embarrassment', 'MUCH TO OUR EMBARRASSMENT', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4833, '1997-09-10 22:00:00+00', '2018-04-03 00:08:06.895521+00', 'Murdoch''s Way', 'MURDOCHS WAY', 3, 32, 9999, 1, 3, 42, 169, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4838, '1998-10-22 22:00:00+00', '2018-04-03 00:08:06.929142+00', 'Murray''s Jig', 'MURRAYS JIG', 2, 32, 9999, 1, 3, 42, 50, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4839, '1997-04-03 22:00:00+00', '2018-04-03 00:08:06.937485+00', 'Murray''s Wedding', 'MURRAYS WEDDING', 2, 32, 9999, 1, 3, 42, 3578, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4843, '1998-04-18 22:00:00+00', '2018-04-03 00:08:06.970751+00', 'Music Hath Charms', 'MUSIC HATH CHARMS', 1, 32, 9999, 1, 3, 42, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4852, '1997-04-03 22:00:00+00', '2018-04-03 00:08:07.01252+00', 'My Brown Haired Maiden', 'MY BROWN HAIRED MAIDEN', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4855, '1997-04-03 22:00:00+00', '2018-04-03 00:08:07.02918+00', 'My Dungannon Sweetheart', 'MY DUNGANNON SWEETHEART', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4859, '1997-08-28 22:00:00+00', '2012-01-20 12:56:38.739995+00', 'Flame Lily, The', 'FLAME LILY', 3, 64, 9999, 4, 4, NULL, 596, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4887, '1997-12-27 23:00:00+00', '2018-04-02 23:56:36.62103+00', 'Navy Pier', 'NAVY PIER', 3, 32, 9999, 1, 3, 42, 361, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11396, '2003-07-06 22:00:00+00', '2012-01-20 12:57:29.180244+00', 'Partnership, The', 'PARTNERSHIP', 3, 96, 9999, 4, 4, NULL, 146, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18612, '2018-09-17 14:45:11.83796+00', '2018-09-18 03:35:15.616052+00', 'Light as Air', 'LIGHT AS AIR', 3, 32, NULL, 1, 3, 42, 3617, NULL, 'Linda wrote:  One of our dancers was having problems with all of her joints.  I gave up trying to find a dance that would work for her and eventually wrote this gentle dance for her.', 50, '808/800/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11401, '2003-07-16 22:00:00+00', '2012-01-20 12:57:29.225412+00', 'Southland, Spirit of a Nation', 'SOUTHLAND SPIRIT OF A NATION', 1, 32, 9999, 1, 4, NULL, 3357, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4866, '1997-11-23 23:00:00+00', '2012-01-20 12:56:38.790881+00', 'My Piper''s Dream', 'MY PIPERS DREAM', 3, 128, 9999, 4, 4, NULL, 1054, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11424, '2003-08-28 22:00:00+00', '2012-01-20 12:57:29.430837+00', 'Lynn of Lorne', 'LYNN OF LORNE', 2, 32, 9999, 3, 5, NULL, 17, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4845, '1998-07-08 22:00:00+00', '2022-11-20 16:15:10.445134+00', 'Music o'' Spey, The', 'MUSIC O SPEY', 3, 32, 9999, 1, 100, 11, 108, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4884, '1997-04-03 22:00:00+00', '2019-03-12 21:09:44.540891+00', 'Napier''s Bones', 'NAPIERS BONES', 2, 32, 9999, 1, 4, 2, 99, NULL, '', 63, '8800/0088/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4869, '1997-09-10 22:00:00+00', '2012-01-20 12:56:38.811228+00', 'My Silver Plaidie Brooch', 'MY SILVER PLAIDIE BROOCH', 3, 64, 9999, 4, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4870, '1997-09-10 22:00:00+00', '2012-01-20 12:56:38.818034+00', 'My Sonsie Luv', 'MY SONSIE LUV', 1, 32, 9999, 3, 5, NULL, 1133, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4883, '2002-11-26 23:00:00+00', '2012-01-20 12:56:38.91076+00', 'Nancy''s Fancy', 'NANCYS FANCY', 3, 32, 9999, 2, 3, NULL, 1165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4886, '1997-04-03 22:00:00+00', '2012-01-20 12:56:38.931216+00', 'Navvie, The', 'NAVVIE', 1, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4889, '1997-04-03 22:00:00+00', '2012-01-20 12:56:38.952201+00', 'Near my ain Home', 'NEAR MY AIN HOME', 2, 32, 9999, 1, 2, NULL, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11407, '2003-08-14 22:00:00+00', '2012-01-20 12:57:29.274575+00', 'Road to Grantown, The', 'ROAD TO GRANTOWN', 1, 32, 9999, NULL, NULL, NULL, 153, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11408, '2003-08-14 22:00:00+00', '2012-01-20 12:57:29.283182+00', 'Taste of Moray, The', 'TASTE OF MORAY', 3, 40, 9999, 1, 4, NULL, 153, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4885, '1997-04-03 22:00:00+00', '2013-10-02 17:28:19.126402+00', 'Narrow Glen, The', 'NARROW GLEN', 3, 32, 9999, 1, 4, 1, 313, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4840, '1997-04-03 22:00:00+00', '2020-09-01 14:12:33.524497+00', 'Murray''s Welcome', 'MURRAYS WELCOME', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 47, '800/880/888/804', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14556, '2012-09-03 22:11:28.023124+00', '2020-10-01 11:21:49.493466+00', 'Golden Companions', 'GOLDEN COMPANIONS', 3, 32, NULL, 3, 5, 26, 3385, NULL, '', 95, '88888/88888/88888/84848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11411, '2003-08-28 22:00:00+00', '2020-11-12 13:01:19.021579+00', 'Alpine Cascade, An', 'ALPINE CASCADE', 1, 32, 9999, 1, 3, 42, 17, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4853, '1997-09-10 22:00:00+00', '2021-05-30 09:42:52.150594+00', 'My Centennial Strathspey', 'MY CENTENNIAL STRATHSPEY', 3, 32, 9999, 1, 4, 1, 352, '1991-06-04', '', 50, '8800/8800/8800/8044', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11404, '2003-07-26 22:00:00+00', '2021-01-24 12:47:46.738114+00', 'And Now we are 25', 'AND NOW WE ARE 25', 2, 32, 9999, 1, 3, 42, 3358, '2002-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11400, '2003-07-06 22:00:00+00', '2021-01-24 13:08:52.270663+00', 'Vintage ''62', 'VINTAGE 62', 2, 32, 9999, 1, 4, 1, 146, NULL, '', 59, '8880/8880/8800/8004', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11394, '2003-07-06 22:00:00+00', '2021-01-25 13:50:12.117677+00', 'Evelyn''s Dance', 'EVELYNS DANCE', 3, 32, 9999, 2, 3, 17, 146, NULL, '', 67, '844/888/822/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11391, '2003-07-06 22:00:00+00', '2021-01-25 13:55:56.51965+00', 'Cathy''s Wedding (& Colin''s Too)', 'CATHYS WEDDING AND COLINS TOO', 2, 32, 9999, 1, 4, 1, 146, NULL, 'Danced at Cathy and Colin Bray''s wedding party in April 2002.', 69, '8880/4040/8888/8484', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11390, '2003-07-06 22:00:00+00', '2021-01-25 13:59:50.306241+00', 'Brackla Hall', 'BRACKLA HALL', 1, 32, 9999, 3, 5, 16, 146, NULL, '', 40, '88800/44000/40004/80088', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4819, '2002-03-24 23:00:00+00', '2021-05-03 09:32:59.464377+00', 'Kettle River', 'KETTLE RIVER', 3, 32, 9999, 1, 3, 42, 2408, '1998-01-01', 'Devised to evoke the swirling motion of the Kettle River, near Sandstone, Minnesota.', 44, '800/844/844/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11410, '2003-08-28 22:00:00+00', '2018-04-03 00:07:49.5494+00', 'Grandma Laing''s Reel', 'GRANDMA LAINGS REEL', 1, 32, 9999, 1, 3, 42, 3387, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11409, '2003-08-25 22:00:00+00', '2012-01-20 12:57:29.292709+00', 'Four Susans, The', 'FOUR SUSANS', 3, 32, 9999, 1, 4, 1, 3367, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11413, '2003-08-28 22:00:00+00', '2012-01-20 12:57:29.327484+00', 'Genevieve''s Reel', 'GENEVIEVES REEL', 1, 48, 9999, 1, 4, NULL, 17, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4898, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.014235+00', 'Neil''s Strathspey', 'NEILS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4899, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.021031+00', 'Nellie McDonald Of Forres', 'NELLIE MACDONALD OF FORRES', 3, 32, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4900, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.027783+00', 'Nellie''s Rant', 'NELLIES RANT', 1, 48, 9999, 1, 2, NULL, 157, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4901, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.034539+00', 'Neptune''s Car', 'NEPTUNES CAR', 1, 32, 9999, 1, 4, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4902, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.041567+00', 'Neptune''s Staircase', 'NEPTUNES STAIRCASE', 1, 32, 9999, 3, 5, NULL, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4909, '1998-07-08 22:00:00+00', '2012-01-20 12:56:39.090985+00', 'Neugle, The', 'NEUGLE', 1, 32, 9999, 1, 4, 2, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4860, '1997-04-03 22:00:00+00', '2018-04-03 00:08:07.045867+00', 'My King has Landed at Moidart', 'MY KING HAS LANDED AT MOIDART', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4861, '1997-09-10 22:00:00+00', '2018-04-03 00:08:07.054108+00', 'My Lady Winwood', 'MY LADY WINWOOD', 1, 32, 9999, 1, 3, 42, 446, '1728-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4867, '1997-04-03 22:00:00+00', '2018-04-03 00:08:07.08757+00', 'My Place', 'MY PLACE', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4868, '1997-04-03 22:00:00+00', '2018-04-03 00:08:07.095967+00', 'My Pretty Maid', 'MY PRETTY MAID', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4876, '1997-04-03 22:00:00+00', '2018-04-03 00:08:07.11253+00', 'Myra''s Mirage', 'MYRAS MIRAGE', 3, 32, 9999, 1, 3, 42, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4872, '1997-04-03 22:00:00+00', '2018-04-03 00:08:07.145883+00', 'My Strath Naver Home', 'MY STRATH NAVER HOME', 2, 40, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4880, '1998-01-13 23:00:00+00', '2018-04-03 00:08:07.23752+00', 'Name Was McGuffog, The', 'NAME WAS MACGUFFOG', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4891, '2002-11-29 23:00:00+00', '2018-04-03 00:08:07.457839+00', 'Neil Browning', 'NEIL BROWNING', 3, 32, 9999, 1, 3, 42, 815, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4892, '1997-04-03 22:00:00+00', '2018-04-03 00:08:07.469478+00', 'Neil Flaherty''s Drake', 'NEIL FLAHERTYS DRAKE', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4905, '1997-08-24 22:00:00+00', '2018-04-03 00:08:07.546241+00', 'Nessie Rant, The', 'NESSIE RANT', 1, 40, 9999, 1, 3, 42, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11414, '2003-08-28 22:00:00+00', '2018-04-03 00:08:18.195659+00', 'Spring in the Air', 'SPRING IN THE AIR', 3, 32, 9999, 1, 3, 42, 17, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11412, '2003-08-28 22:00:00+00', '2018-04-03 00:08:24.808238+00', 'Well Earned Rest, A', 'WELL EARNED REST', 1, 0, 9999, 1, 3, 42, 17, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4910, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.097796+00', 'Never You Mind About That', 'NEVER YOU MIND ABOUT THAT', 1, 48, 9999, 4, 4, NULL, 1166, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4912, '1997-10-27 23:00:00+00', '2012-01-20 12:56:39.11144+00', 'New Brig Of Ayr', 'NEW BRIG OF AYR', 1, 32, 9999, 1, 4, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4920, '1997-04-03 22:00:00+00', '2018-07-17 11:15:33.057283+00', 'New Howford Brig, The', 'NEW HOWFORD BRIG', 1, 32, 9999, 1, 3, 42, 129, NULL, '', 56, '800/888/880/888', 1, 0, 1, 1, -1);
INSERT INTO 'dance' VALUES (4915, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.131973+00', 'New Dancer''s Celebration, The', 'NEW DANCERS CELEBRATION', 1, 32, 9999, 2, 3, NULL, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11415, '2003-08-28 22:00:00+00', '2012-01-20 12:57:29.350093+00', 'Peaks of the Cuillins', 'PEAKS OF THE CUILLINS', 2, 32, 9999, 1, 4, NULL, 17, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14562, '2012-09-04 19:52:20.821526+00', '2018-10-01 17:16:04.415043+00', 'Bangers and Mash', 'BANGERS AND MASH', 1, 32, NULL, 1, 3, 42, 2766, '2008-10-01', 'This dance got its name because my class refers to Inveran reels as "sausage" reels.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4938, '1998-01-05 23:00:00+00', '2018-07-24 00:19:39.983156+00', 'New York Hornpipe, The', 'NEW YORK HORNPIPE', 1, 48, 9999, 1, 3, 42, 313, NULL, 'For Grace Etherington of RSCDS New York Branch. New York is a tiny place on the west bank of Loch Awe, facing Portinnisherrich. ', 67, '888/844/888/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11418, '2003-08-28 22:00:00+00', '2012-01-20 12:57:29.376186+00', 'Ceilidh Band, The', 'CEILIDH BAND', 1, 32, 9999, 3, 5, NULL, 17, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11441, '2003-09-22 22:00:00+00', '2018-10-03 02:16:04.095507+00', 'Clockwork', 'CLOCKWORK', 2, 32, 9999, 1, 3, 42, 2766, '2003-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11442, '2003-09-22 22:00:00+00', '2018-10-05 06:17:31.95704+00', 'Flowers of Spring', 'FLOWERS OF SPRING', 3, 32, 9999, 4, 4, 13, 2766, '2003-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4893, '1997-09-10 22:00:00+00', '2022-11-06 21:47:33.797283+00', 'Neil Gow''s Farewell to Whiskey', 'NEIL GOWS FAREWELL TO WHISKEY', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4916, '1998-07-08 22:00:00+00', '2022-11-20 16:01:08.206603+00', 'New Elgin', 'NEW ELGIN', 3, 32, 9999, 1, 4, 11, 517, '1986-01-01', 'Devised "to celebrate the wedding ofAlison Mills and David Currie in June 1986".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11425, '2003-08-28 22:00:00+00', '2012-01-20 12:57:29.439564+00', 'Martin''s Harem', 'MARTINS HAREM', 2, 32, 9999, 3, 5, NULL, 17, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11426, '2003-08-28 22:00:00+00', '2012-01-20 12:57:29.448235+00', 'Road to Rum, The', 'ROAD TO RUM', 2, 40, 9999, 1, 4, NULL, 17, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4976, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.5775+00', 'Norman''s Angel', 'NORMANS ANGEL', 3, 32, 9999, 1, 4, NULL, 293, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9109, '2001-11-21 23:00:00+00', '2018-10-08 21:07:29.698016+00', 'Airyhall Delight', 'AIRYHALL DELIGHT', 2, 32, 9999, 1, 3, 42, 2665, NULL, '', 53, '844/844/822/888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (11429, '2003-09-14 22:00:00+00', '2012-01-20 12:57:29.474436+00', 'Joyce''s Birthday Surprise', 'JOYCES BIRTHDAY SURPRISE', 3, 40, 9999, 1, 4, NULL, 3369, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4924, '1998-04-19 22:00:00+00', '2019-01-14 21:39:53.629311+00', 'New Opera, The', 'NEW OPERA', 2, 32, 9999, 1, 3, 42, 108, '1995-03-01', '', 50, '800/888/844/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4921, '1998-07-08 22:00:00+00', '2013-01-24 14:19:18.062336+00', 'New John Paul Jones, The', 'NEW JOHN PAUL JONES', 1, 32, 9999, 1, 100, 11, 108, '1979-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4922, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.183286+00', 'New Kelvin Bridge, The', 'NEW KELVIN BRIDGE', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4923, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.190119+00', 'New New Nothing', 'NEW NEW NOTHING', 1, 32, 9999, 1, 2, NULL, 446, '1651-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4926, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.210808+00', 'New Park Jig', 'NEW PARK JIG', 1, 32, 9999, 1, 2, NULL, 176, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11422, '2003-08-28 22:00:00+00', '2020-04-05 00:10:26.206771+00', 'Jealous Scot, A', 'JEALOUS SCOT', 1, 48, 9999, 1, 4, 1, 17, '2005-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4917, '1997-04-03 22:00:00+00', '2021-05-03 08:17:18.386073+00', 'New Forest Circle', 'NEW FOREST CIRCLE', 1, 40, 9999, 7, 1, 4, 3591, '1993-01-01', '', 80, '8/8/4/4/8', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4906, '1997-09-10 22:00:00+00', '2021-05-03 08:26:43.783119+00', 'Nessie''s Reel', 'NESSIES REEL', 1, 32, 9999, 1, 3, 42, 351, NULL, 'A dance as serpentine as its namesake!', 38, '840/804/800/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4895, '1997-04-03 22:00:00+00', '2021-04-17 08:30:32.36584+00', 'Neil Low''s Second Wife', 'NEIL LOWS SECOND WIFE', 3, 32, 9999, 1, 3, 42, 270, NULL, '', 72, '888/888/888/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14013, '2011-08-25 22:00:00+00', '2021-08-06 09:15:45.438608+00', 'Aberdeen Hunt', 'ABERDEEN HUNT', 3, 32, NULL, 1, 3, 42, 401, '1996-01-01', '', 56, '880  888  844  844', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (4944, '1998-07-08 22:00:00+00', '2012-01-20 12:56:39.336525+00', 'Newcastleton Weavers', 'NEWCASTLETON WEAVERS', 1, 32, 9999, 1, 4, 2, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11435, '2003-09-14 22:00:00+00', '2012-01-20 12:57:29.527068+00', 'Reel of the Scotia Country Dancers', 'REEL OF THE SCOTIA COUNTRY DANCERS', 1, 32, 9999, 1, 2, NULL, 1113, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4937, '1997-04-03 22:00:00+00', '2013-01-24 14:22:06.546182+00', 'New Year''s Day', 'NEW YEARS DAY', 4, 64, 5, 1, 100, 2, 108, '1980-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4945, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.343315+00', 'Newfoundland Flag, The', 'NEWFOUNDLAND FLAG', 3, 32, 9999, 1, 4, NULL, 214, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4946, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.350197+00', 'Newhall', 'NEWHALL', 1, 48, 9999, 5, 1, NULL, 108, '1968-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4967, '1999-02-14 23:00:00+00', '2016-05-13 13:30:16.19858+00', 'Polygamous Reel, The', 'POLYGAMOUS REEL', 1, 48, 9999, 107, 53, NULL, 2558, NULL, 'For one man and two women; in sets of five people', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11433, '2003-09-14 22:00:00+00', '2018-04-03 00:08:10.014598+00', 'Patty Lindsay''s Rant', 'PATTY LINDSAYS RANT', 1, 32, 9999, 1, 3, 42, 1113, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4942, '1997-04-03 22:00:00+00', '2018-04-03 00:08:07.629658+00', 'Newcastle Reel, The', 'NEWCASTLE REEL', 1, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11428, '2003-09-14 22:00:00+00', '2018-04-03 00:07:39.988125+00', 'Crazy Eights', 'CRAZY EIGHTS', 1, 32, 9999, 1, 3, 42, 1113, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11416, '2003-08-28 22:00:00+00', '2018-04-03 00:07:43.760319+00', 'Early one Evening', 'EARLY ONE EVENING', 2, 32, 9999, 1, 3, 42, 17, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4936, '1997-12-03 23:00:00+00', '2018-04-03 00:07:46.588004+00', 'Fort Worden Fun', 'FORT WORDEN FUN', 2, 32, 9999, 1, 3, 42, 597, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4914, '1997-09-02 22:00:00+00', '2018-04-03 00:07:46.638032+00', 'Four Ems, The', 'FOUR EMS', 99, 32, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11417, '2003-08-28 22:00:00+00', '2018-04-03 00:07:48.431361+00', 'Glasshouse, The', 'GLASSHOUSE', 3, 32, 9999, 1, 3, 42, 17, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11421, '2003-08-28 22:00:00+00', '2018-04-03 00:07:49.857885+00', 'Green Fringe Jig', 'GREEN FRINGE JIG', 2, 32, 9999, 1, 3, 42, 17, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11430, '2003-09-14 22:00:00+00', '2018-04-03 00:07:57.313164+00', 'Kilmartin Glen', 'KILMARTIN GLEN', 2, 32, 9999, 1, 3, 42, 1113, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11431, '2003-09-14 22:00:00+00', '2018-04-03 00:07:59.304796+00', 'Leigh House Strathspey', 'LEIGH HOUSE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3370, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11432, '2003-09-14 22:00:00+00', '2018-04-03 00:08:01.1913+00', 'Maclellan''s Brook', 'MACLELLANS BROOK', 4, 32, 1, 1, 3, 42, 2245, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4913, '1997-04-03 22:00:00+00', '2018-04-03 00:08:07.637897+00', 'New College Hornpipe, The', 'NEW COLLEGE HORNPIPE', 1, 32, 9999, 1, 3, 42, 108, '1981-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4918, '2002-04-19 22:00:00+00', '2018-04-03 00:08:07.646233+00', 'New Haven Days', 'NEW HAVEN DAYS', 2, 32, 9999, 1, 3, 42, 1167, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4934, '1997-09-10 22:00:00+00', '2018-04-03 00:08:07.754553+00', 'New Water Kettle, The', 'NEW WATER KETTLE', 2, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4949, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.370889+00', 'Newport Dancers', 'NEWPORT DANCERS', 2, 48, 9999, 3, 5, NULL, 728, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11454, '2003-09-22 22:00:00+00', '2018-10-03 12:02:06.266386+00', 'Cross Stitch', 'CROSS STITCH', 1, 32, 9999, 1, 3, 42, 2766, '2002-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4955, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.412527+00', 'Nijmi', 'NIJMI', 2, 96, 9999, 7, 6, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4957, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.426819+00', 'Nina''s Return', 'NINAS RETURN', 4, 28, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11456, '2003-09-22 22:00:00+00', '2018-10-04 08:47:53.241285+00', 'Dos Equis', 'DOS EQUIS', 1, 32, 9999, 4, 4, 1, 2766, '2002-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11446, '2003-09-22 22:00:00+00', '2018-10-05 07:25:17.374961+00', 'Flying in Formation', 'FLYING IN FORMATION', 3, 32, 9999, 1, 3, 42, 2766, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4963, '1997-08-24 22:00:00+00', '2012-01-20 12:56:39.485204+00', 'No Strangers..Just Friends', 'NO STRANGERSJUST FRIENDS', 2, 32, 9999, 1, 4, 1, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11449, '2003-09-22 22:00:00+00', '2018-10-06 12:47:08.337001+00', 'Octothorpe', 'OCTOTHORPE', 3, 32, 9999, 4, 4, 1, 2766, '2002-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4966, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.506204+00', 'Noe Valley, The', 'NOE VALLEY', 3, 32, 9999, 1, 4, NULL, 214, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4969, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.529899+00', 'Nonsense', 'NONSENSE', 2, 32, 9999, 2, 3, NULL, 1173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18843, '2018-10-06 12:55:48.004659+00', '2018-10-06 12:55:48.004659+00', 'Off to Oregon', 'OFF TO OREGON', 1, 32, NULL, 1, 3, 42, 2766, '2016-04-01', 'Written for Mel Whitson and Ken Heinemann on their move to Portland, Oregon.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4972, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.550224+00', 'Nora''s Fandango', 'NORAS FANDANGO', 3, 32, 9999, 1, 2, NULL, 877, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4973, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.557016+00', 'Norfolk Island Strathspey', 'NORFOLK ISLAND STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 1174, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11452, '2003-09-22 22:00:00+00', '2018-10-07 11:48:22.000651+00', 'Rose, The', 'ROSE', 3, 32, 9999, 4, 4, 1, 2766, '2002-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11447, '2003-09-22 22:00:00+00', '2018-10-08 18:16:10.056449+00', 'Skating Figures', 'SKATING FIGURES', 3, 32, 9999, 1, 3, 42, 2766, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11444, '2003-09-22 22:00:00+00', '2022-09-23 17:18:08.031441+00', 'April Fool', 'APRIL FOOL', 2, 32, 9999, 1, 3, 42, 2766, '2003-04-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11451, '2003-09-22 22:00:00+00', '2022-08-17 18:28:05.633635+00', 'Partners for Life', 'PARTNERS FOR LIFE', 3, 32, 9999, 1, 3, 42, 2766, '2002-02-01', '', 56, '880/880/888/808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11420, '2003-08-28 22:00:00+00', '2022-12-08 22:33:06.976294+00', 'Gordon Strathspey', 'GORDON STRATHSPEY', 3, 32, 9999, 2, 3, 18, 17, NULL, '', 96, '884/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4984, '1997-12-21 23:00:00+00', '2019-02-15 16:49:56.636455+00', 'North Lea', 'NORTH LEA', 3, 32, 9999, 1, 4, 1, 9, NULL, '', 81, '6666/6666/8888/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4953, '2002-03-07 23:00:00+00', '2019-03-12 11:29:01.42868+00', 'Nice and Easy', 'NICE AND EASY', 1, 32, 9999, 1, 4, 1, 528, NULL, '', 66, '4444/4444/8444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4954, '2002-04-30 22:00:00+00', '2019-08-29 20:54:18.257292+00', 'Nighean Donn', 'NIGHEAN DONN', 1, 32, 9999, 3, 5, 4, 520, '1988-01-01', '', 70, '18281/48884/77877/63636', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14564, '2012-09-07 13:35:48.529622+00', '2012-09-07 13:36:35.025434+00', 'Dance of the Figures, The', 'DANCE OF THE FIGURES', 3, 32, NULL, 1, 3, 42, 10654, '2008-04-09', 'source: http://rscds-greaterdc.org/nova_dances_0708.html.  This is a teaching dance, created for that particular occasion.



1-8   1C cross, cast (2C step up), 1C dance 1/2 figure of 8 around 2C, on bar 8 2C, 1C, 3C step in for allemande



9-16 2C, 1C, 3C dance allemande



17-24 3C, 1C, 2C dance the knot, 1C finish facing first corners



25-32 2C, 1C, 3C turn corner, partner, corner partner', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4977, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.584277+00', 'North Bute Jig', 'NORTH BUTE JIG', 2, 40, 9999, 1, 4, NULL, 3551, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4979, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.597988+00', 'North Country Welcome, A', 'NORTH COUNTRY WELCOME', 1, 32, 9999, 1, 4, NULL, 1176, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11419, '2003-08-28 22:00:00+00', '2020-09-15 08:31:07.488521+00', 'Change of Heart, A', 'CHANGE OF HEART', 2, 32, 9999, 1, 3, 42, 17, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11567, '2003-11-01 23:00:00+00', '2021-01-23 11:38:40.913067+00', 'Akiko''s Medicine', 'AKIKOS MEDICINE', 2, 32, 9999, 1, 3, 42, 1445, NULL, '', 53, '880/444/808/888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (11427, '2003-09-14 22:00:00+00', '2021-01-10 14:48:13.851753+00', 'Flying Ghillies, The', 'FLYING GHILLIES', 2, 32, 9999, 1, 3, 42, 1113, '2003-01-01', '', 56, '844/800/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4919, '1998-09-30 22:00:00+00', '2021-06-15 08:09:03.876779+00', 'New Highland Laddie, The', 'NEW HIGHLAND LADDIE', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 47, '840/800/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4980, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.604765+00', 'North Down Waltz, The', 'NORTH DOWN WALTZ', 5, 24, 9999, 1, 2, NULL, 485, '1820-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4981, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.611682+00', 'North End Jig, The', 'NORTH END JIG', 2, 32, 9999, 1, 2, NULL, 719, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4989, '2002-11-29 23:00:00+00', '2012-01-20 12:56:39.66754+00', 'Northallerton Gap, The', 'NORTHALLERTON GAP', 1, 32, 9999, 1, 4, NULL, 2618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4993, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.697542+00', 'Norton Village Reel, The', 'NORTON VILLAGE REEL', 1, 32, 9999, 1, 4, NULL, 617, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4994, '1997-12-22 23:00:00+00', '2012-01-20 12:56:39.704374+00', 'Not Far From The Brig O''Doon', 'NOT FAR FROM THE BRIG ODOON', 3, 40, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4996, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.718047+00', 'Nothing In Particular', 'NOTHING IN PARTICULAR', 2, 32, 9999, 1, 2, NULL, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4997, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.724859+00', 'Nottingham Silver Celebration', 'NOTTINGHAM SILVER CELEBRATION', 3, 32, 9999, 4, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4958, '1997-08-28 22:00:00+00', '2016-05-12 22:34:26.282711+00', 'Heart to Heart', 'HEART TO HEART', 4, 64, 9999, 107, 56, NULL, 598, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4960, '1997-09-10 22:00:00+00', '2018-04-03 00:08:07.846442+00', 'Nita''s Twenty First', 'NITAS TWENTY FIRST', 3, 48, 9999, 1, 3, 42, 1171, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4961, '1997-04-03 22:00:00+00', '2018-04-03 00:08:07.86306+00', 'No Churchman Am I', 'NO CHURCHMAN AM I', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4971, '1997-04-03 22:00:00+00', '2018-04-03 00:08:07.929901+00', 'Noonday at St. Andrew''s', 'NOONDAY AT ST ANDREWS', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4962, '1997-04-03 22:00:00+00', '2018-04-03 00:08:07.938225+00', 'No Problems', 'NO PROBLEMS', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4978, '1997-04-03 22:00:00+00', '2018-04-03 00:08:08.063026+00', 'North Camp', 'NORTH CAMP', 1, 32, 9999, 1, 3, 42, 145, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4964, '2002-11-19 23:00:00+00', '2018-04-03 00:08:08.113147+00', 'No The Noo, Johnny', 'NO THE NOO JOHNNY', 1, 32, 9999, 1, 3, 42, 910, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5002, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.758861+00', 'Now Let''s Sing', 'NOW LETS SING', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11463, '2003-09-22 22:00:00+00', '2018-10-02 11:55:26.176664+00', 'Button Bright', 'BUTTON BRIGHT', 4, 32, 1, 1, 3, 42, 2766, '2002-04-01', 'Button Bright is a little boy who has many adventures in Oz. He is always getting lost, but he is always found again.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11476, '2003-09-22 22:00:00+00', '2018-10-03 00:27:03.979354+00', 'Cat''s Cradle', 'CATS CRADLE', 1, 32, 9999, 1, 3, 42, 2766, '2002-08-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11468, '2003-09-22 22:00:00+00', '2018-10-03 09:59:54.80517+00', 'Corkscrew, The', 'CORKSCREW', 2, 32, 9999, 1, 3, 42, 2766, '2002-06-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11466, '2003-09-22 22:00:00+00', '2018-10-04 07:57:46.427469+00', 'House on Dell Lane, The', 'HOUSE ON DELL LANE', 3, 32, 9999, 3, 5, 7, 2766, '2002-05-01', 'I wrote this dance to honor our demo team leaders, who open their house to us for demo practice and rehearsals. The room in which we dance is above the garage and the perfect size for a 5 couple set with no down the middle and back figure.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11459, '2003-09-22 22:00:00+00', '2018-10-04 18:00:50.11299+00', 'Emerald City, The', 'EMERALD CITY', 1, 32, 9999, 4, 4, 1, 2766, '2002-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5003, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.765627+00', 'Now We Are 10!', 'NOW WE ARE 10', 3, 32, 9999, 3, 5, NULL, 197, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5004, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.772496+00', 'Now Where''s She Gone?', 'NOW WHERES SHE GONE', 2, 40, 9999, 1, 4, NULL, 1179, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11473, '2003-09-22 22:00:00+00', '2018-10-05 09:36:23.782252+00', 'Glass Cat, The', 'GLASS CAT', 1, 32, 9999, 1, 3, 42, 2766, '2002-08-01', 'The glass cat is a creature in OZ who was brought to life by magic. It is made entirely of transparent glass and is very proud of its pink brains, which can be seen as they are working. Unfortunately, its maker created its heart of red glass, so it isn’t the nicest creature - but it is pretty.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5011, '1997-10-29 23:00:00+00', '2012-01-20 12:56:39.873804+00', 'O''Carolan''s Receipt', 'OCAROLANS RECEIPT', 3, 32, 9999, 5, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5012, '1997-10-29 23:00:00+00', '2012-01-20 12:56:39.880548+00', 'O''Keefe''s Jig', 'OKEEFES JIG', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11474, '2003-09-22 22:00:00+00', '2018-10-05 12:21:23.416824+00', 'Glinda the Good', 'GLINDA THE GOOD', 2, 32, 9999, 1, 3, 42, 2766, '2002-08-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11469, '2003-09-22 22:00:00+00', '2018-10-05 13:55:55.726643+00', 'Hourglass, The', 'HOURGLASS', 1, 32, 9999, 1, 3, 42, 2766, '2002-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5017, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.915381+00', 'O''er The Heath', 'OER THE HEATH', 2, 40, 9999, 1, 4, NULL, 347, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5018, '1997-04-03 22:00:00+00', '2012-01-20 12:56:39.922145+00', 'O''er The Hills', 'OER THE HILLS', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11467, '2003-09-22 22:00:00+00', '2018-10-05 13:59:16.491541+00', 'Ian Michael''s Reel', 'IAN MICHAELS REEL', 1, 32, 9999, 1, 3, 42, 2766, '2002-05-01', 'Ian Michael Fitak entered this world May 21, 2002, the son of avid Scottish Country Dancers.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5021, '2002-02-26 23:00:00+00', '2012-01-20 12:56:39.943298+00', 'Oaks Of Sherwood', 'OAKS OF SHERWOOD', 3, 32, 9999, 3, 5, 7, 48, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11445, '2003-09-22 22:00:00+00', '2018-10-06 13:16:00.040427+00', 'One Good Turn', 'ONE GOOD TURN', 3, 32, NULL, 1, 3, 42, 2766, '2003-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5024, '1997-09-10 22:00:00+00', '2012-01-20 12:56:39.963626+00', 'Ocean Venture, The', 'OCEAN VENTURE', 2, 40, 9999, 2, 3, NULL, 601, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4952, '1997-09-10 22:00:00+00', '2022-11-06 21:49:09.748305+00', 'Niartreg Jig, The', 'NIARTREG JIG', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4986, '2002-09-08 22:00:00+00', '2022-11-07 21:12:12.364374+00', 'North Of The Grampians', 'NORTH OF THE GRAMPIANS', 3, 32, 9999, 5, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5010, '1997-04-03 22:00:00+00', '2022-11-07 21:12:37.960465+00', 'O''Beauty''s Alarms', 'OBEAUTYS ALARMS', 2, 32, 9999, 5, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4970, '1997-09-10 22:00:00+00', '2023-01-26 19:12:41.662871+00', 'Noo I Wear the Kilt', 'NOO I WEAR THE KILT', 2, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5025, '1997-11-27 23:00:00+00', '2012-01-20 12:56:39.97041+00', 'October Wedding', 'OCTOBER WEDDING', 4, 96, 11, 1, 4, NULL, 872, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11471, '2003-09-22 22:00:00+00', '2018-10-06 13:46:45.116566+00', 'Pedal Pushers', 'PEDAL PUSHERS', 1, 32, 9999, 1, 3, 42, 2766, '2002-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5030, '1997-09-10 22:00:00+00', '2012-01-20 12:56:40.005447+00', 'Odin''s Raven', 'ODINS RAVEN', 3, 32, 9999, 2, 3, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5031, '1997-09-10 22:00:00+00', '2012-01-20 12:56:40.012206+00', 'Of That Ilk', 'OF THAT ILK', 2, 32, 9999, 1, 4, NULL, 90, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4951, '1997-09-10 22:00:00+00', '2021-05-03 08:06:37.584317+00', 'Newton Park', 'NEWTON PARK', 2, 32, 9999, 1, 3, 42, 805, NULL, 'The music for this dance was composed by Ian Muir while he was a student at Newton Park College, Bath, in the former County of Avon.', 63, '800/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4947, '1997-08-30 22:00:00+00', '2020-09-01 14:23:11.804668+00', 'Newholme Jig, The', 'NEWHOLME JIG', 2, 32, 9999, 1, 3, 42, 21, '1992-01-01', '', 69, '880/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4983, '1998-04-19 22:00:00+00', '2020-09-01 14:26:10.731084+00', 'North Grove', 'NORTH GROVE', 3, 32, 9999, 1, 3, 42, 146, '1993-01-01', '', 63, '888/888/822/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4999, '1997-04-03 22:00:00+00', '2021-04-18 22:17:43.826972+00', 'Noup of Ness', 'NOUP OF NESS', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', 60, '66/88/66/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5061, '1998-04-29 22:00:00+00', '2021-04-28 23:12:05.226527+00', 'Old Man of Hoy, The', 'OLD MAN OF HOY', 1, 32, 9999, 1, 2, 76, 44, '1969-01-01', '', 69, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5037, '2000-07-26 22:00:00+00', '2021-04-28 23:30:52.125095+00', 'Oh! Flowers', 'OH FLOWERS', 3, 64, 9999, 4, 4, 3, 2781, NULL, '', 94, '8888/8484/8888/8888/4848/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5027, '1998-07-08 22:00:00+00', '2021-04-29 20:48:01.981522+00', 'Octogenarian, The', 'OCTOGENARIAN', 3, 32, 9999, 1, 4, 11, 525, NULL, '', 94, '8888/8888/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18890, '2018-10-08 21:38:45.552261+00', '2018-10-08 21:38:45.552261+00', 'Speed Racer', 'SPEED RACER', 1, 32, NULL, 1, 3, 42, 2766, '2009-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18891, '2018-10-08 21:40:30.712363+00', '2018-10-08 21:40:30.712363+00', 'Spider Web', 'SPIDER WEB', 1, 32, NULL, 1, 3, 42, 2766, '2009-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11472, '2003-09-22 22:00:00+00', '2018-10-09 15:03:49.332829+00', 'Beware the Wheelers', 'BEWARE THE WHEELERS', 1, 32, 9999, 1, 3, 42, 2766, '2002-08-01', 'Dorothy encounters the wheelers in the book *Ozma of Oz*.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5009, '2002-02-27 23:00:00+00', '2019-03-11 19:34:17.043817+00', 'Oh My America!', 'OH MY AMERICA', 1, 88, 9999, 4, 4, 3, 23, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5036, '2002-04-22 22:00:00+00', '2012-01-20 12:56:40.048607+00', 'Officers'' Medley, The', 'OFFICERS MEDLEY', 4, 168, 57, 1, 4, NULL, 426, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5042, '1997-04-03 22:00:00+00', '2012-01-20 12:56:40.089526+00', 'Old Adam', 'OLD ADAM', 2, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5000, '1997-09-10 22:00:00+00', '2015-10-04 12:30:37.826772+00', 'Nova Scotia', 'NOVA SCOTIA', 3, 64, 9999, 4, 4, NULL, 108, '1986-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5029, '1997-09-10 22:00:00+00', '2018-04-03 00:08:08.388241+00', 'Ode To Teachers, An', 'ODE TO TEACHERS', 3, 32, 9999, 1, 3, 42, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5008, '1997-09-10 22:00:00+00', '2018-04-03 00:08:08.296761+00', 'Nutcracker, The', 'NUTCRACKER', 1, 32, 9999, 1, 3, 42, 1178, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5020, '1997-04-03 22:00:00+00', '2018-04-03 00:08:08.328453+00', 'Oakham Reel', 'OAKHAM REEL', 1, 32, 9999, 1, 3, 42, 92, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5022, '1997-09-10 22:00:00+00', '2018-04-03 00:08:08.338302+00', 'Oban Bay Strathspey', 'OBAN BAY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1180, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5014, '1997-04-03 22:00:00+00', '2018-04-03 00:08:08.396577+00', 'O''er Bogie', 'OER BOGIE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5015, '1997-04-03 22:00:00+00', '2018-04-03 00:08:08.404928+00', 'O''er the Border', 'OER THE BORDER', 2, 32, 9999, 1, 3, 42, 44, '1978-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5043, '1997-10-27 23:00:00+00', '2018-04-03 00:08:08.496986+00', 'Old Bog Hole', 'OLD BOG HOLE', 1, 40, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5045, '1997-04-03 22:00:00+00', '2012-01-20 12:56:40.109938+00', 'Old Clarsach, The', 'OLD CLARSACH', 3, 32, 9999, 4, 4, NULL, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5055, '1997-11-27 23:00:00+00', '2018-04-29 11:01:36.271654+00', 'Old Grey Tower, The', 'OLD GREY TOWER', 4, 32, 1, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5048, '1997-04-03 22:00:00+00', '2012-01-20 12:56:40.130664+00', 'Old Earn Brig, The', 'OLD EARN BRIG', 1, 48, 9999, 1, 4, NULL, 417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11491, '2003-09-22 22:00:00+00', '2019-09-12 18:21:43.884121+00', 'Busy Box', 'BUSY BOX', 1, 32, 9999, 1, 3, 42, 2766, '2002-09-01', '', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5051, '1997-04-03 22:00:00+00', '2012-01-20 12:56:40.151079+00', 'Old Ferry to Skye, The', 'OLD FERRY TO SKYE', 1, 32, 9999, 1, 4, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5052, '2003-01-28 23:00:00+00', '2012-01-20 12:56:40.158537+00', 'Old Fort Vancouver', 'OLD FORT VANCOUVER', 3, 40, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11490, '2003-09-22 22:00:00+00', '2018-10-05 14:39:28.920629+00', 'Imaginary Reel, The', 'IMAGINARY REEL', 1, 32, 9999, 1, 3, 42, 2766, '2002-09-01', 'The leader of our SCD class is a physicist and has often suggested that he’d like to see a dance with a real and an imaginary part. This is an attempt at such a dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11497, '2003-09-22 22:00:00+00', '2018-10-06 08:45:21.815004+00', 'Luce Change', 'LUCE CHANGE', 1, 32, 9999, 4, 4, NULL, 2766, '2002-11-01', 'This dance is written for Bryan Luce, a stalwart of the Fermi class and the Chicago branch - and my usual partner in demos.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18845, '2018-10-06 13:18:18.224896+00', '2018-10-06 13:18:18.224896+00', 'Ordered Chaos', 'ORDERED CHAOS', 3, 32, NULL, 1, 4, NULL, 2766, '2013-10-01', 'I had an idea for a 4 couple set and link and the dance took off from there.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11493, '2003-09-22 22:00:00+00', '2018-10-09 12:04:32.664+00', 'Tik Tok', 'TIK TOK', 1, 32, 9999, 1, 2, NULL, 2766, '2002-10-01', 'Tik Tok is a metal man Dorothy finds in Ozma of Oz; his inner workings are clockwork and this dance reminds me of a clock.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11498, '2003-09-22 22:00:00+00', '2018-10-09 10:47:22.418236+00', 'Thor''s Hammer', 'THORS HAMMER', 2, 32, 9999, 1, 2, NULL, 2766, '2002-12-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11487, '2003-09-22 22:00:00+00', '2019-03-02 11:34:02.546897+00', 'Silver Targe, The', 'SILVER TARGE', 3, 80, 9999, 4, 4, 3, 335, NULL, '', 90, '8888/8888/8888/8888/8888/8888/8888/8080/0808/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5067, '2002-04-19 22:00:00+00', '2012-01-20 12:56:40.262121+00', 'Old Sporran, The', 'OLD SPORRAN', 3, 24, 9999, 1, 2, NULL, 392, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5068, '1997-04-03 22:00:00+00', '2012-01-20 12:56:40.269588+00', 'Old-Time Favourites', 'OLDTIME FAVOURITES', 1, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5089, '1997-04-03 22:00:00+00', '2018-04-02 23:56:36.788036+00', 'One Last Time', 'ONE LAST TIME', 3, 32, 9999, 1, 3, 42, 352, '1993-10-24', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5072, '1997-04-03 22:00:00+00', '2012-01-20 12:56:40.296675+00', 'Olian Au Revoir', 'OLIAN AU REVOIR', 2, 32, 9999, 1, 4, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5077, '1998-04-19 22:00:00+00', '2012-01-20 12:56:40.33076+00', 'On the Go', 'ON THE GO', 2, 32, 9999, 1, 2, NULL, 108, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11482, '2003-09-22 22:00:00+00', '2022-03-17 09:26:08.700822+00', 'Doris''s Delight', 'DORISS DELIGHT', 3, 32, 9999, 1, 100, 11, 3376, NULL, '', 87, '8888/8888/8008/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4991, '2002-03-02 23:00:00+00', '2022-04-26 09:20:02.411527+00', 'Northern Meeting, The', 'NORTHERN MEETING', 3, 32, 9999, 1, 3, 42, 62, '1977-01-01', '', 59, '880/880/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14567, '2012-09-08 09:26:43.604397+00', '2022-06-21 14:42:53.43646+00', 'Duddingston Loch', 'DUDDINGSTON LOCH', 3, 32, NULL, 3, 5, 7, 10656, NULL, '', 66, '08080/48884/28482/84884', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5038, '1997-04-03 22:00:00+00', '2022-11-07 21:54:11.447214+00', 'Oh! She''s comical', 'OH SHES COMICAL', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5053, '1997-04-03 22:00:00+00', '2022-11-20 15:45:44.908675+00', 'Old Friends', 'OLD FRIENDS', 2, 24, 9999, 1, 3, 42, 352, '1993-06-04', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5046, '1997-09-10 22:00:00+00', '2022-11-20 15:50:06.406399+00', 'Old Course, The', 'OLD COURSE', 2, 40, 9999, 1, 4, 1, 748, NULL, 'From the instructions: "St. Andrew''s ''Old Course'' - where you have to keep attending to what you are doing!".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5019, '1997-09-10 22:00:00+00', '2022-11-20 15:57:17.300204+00', 'O''er The Muir Among The Heather', 'OER THE MUIR AMONG THE HEATHER', 3, 32, 9999, 1, 3, 42, 976, '1740-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5078, '2002-03-02 23:00:00+00', '2012-01-20 12:56:40.338325+00', 'On the Gunyard at Dunvegan Castle', 'ON THE GUNYARD AT DUNVEGAN CASTLE', 3, 40, 9999, 1, 4, 2, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5081, '1997-09-10 22:00:00+00', '2012-01-20 12:56:40.358911+00', 'On The Shores Of Lake Couchiching', 'ON THE SHORES OF LAKE COUCHICHING', 4, 64, 9999, 1, 4, NULL, 213, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5086, '2002-04-19 22:00:00+00', '2012-01-20 12:56:40.395231+00', 'Once I Loved a Maiden Fair', 'ONCE I LOVED A MAIDEN FAIR', 3, 32, 9999, 1, 2, NULL, 682, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5087, '1998-07-08 22:00:00+00', '2012-01-20 12:56:40.402684+00', 'Once Is Enough', 'ONCE IS ENOUGH', 2, 32, 9999, 1, 4, 2, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5070, '1997-12-27 23:00:00+00', '2020-09-02 11:44:18.920204+00', 'Old Water Tower', 'OLD WATER TOWER', 3, 32, 9999, 1, 3, 42, 361, NULL, '', 42, '880/860/800/808', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5082, '1997-12-27 23:00:00+00', '2020-09-02 11:46:07.313189+00', 'On The Wacker', 'ON THE WACKER', 1, 32, 9999, 1, 3, 42, 361, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11496, '2003-09-22 22:00:00+00', '2021-01-04 13:18:40.190806+00', 'Migration', 'MIGRATION', 3, 32, 9999, 2, 3, 17, 2766, '2002-10-01', '', 73, '808/868/888/008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11486, '2003-09-22 22:00:00+00', '2021-01-24 12:02:06.237149+00', 'Chorlton Reel, The', 'CHORLTON REEL', 1, 32, 9999, 1, 2, 76, 514, NULL, '', 52, '44/44/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11484, '2003-09-22 22:00:00+00', '2021-01-24 12:08:22.053327+00', 'Silver Threads', 'SILVER THREADS', 3, 40, 9999, 1, 4, 2, 3377, NULL, '', 72, '4444/8888/8008/2882/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5039, '2000-08-01 22:00:00+00', '2021-04-28 23:25:19.303301+00', 'Oh, a Hillside Cottage', 'OH A HILLSIDE COTTAGE', 3, 32, 9999, 3, 5, 58, 843, '1993-11-01', 'For Omati Ryoiti, the first chairman of Tokyo Branch.', 65, '80008/86468/82428/88880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5028, '1998-09-30 22:00:00+00', '2021-04-29 09:48:24.495781+00', 'Odd Thoughts', 'ODD THOUGHTS', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 56, '888/800/880/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5047, '1997-09-10 22:00:00+00', '2018-04-03 00:08:08.513576+00', 'Old Craigmore', 'OLD CRAIGMORE', 3, 32, 9999, 1, 3, 42, 476, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5050, '1997-09-10 22:00:00+00', '2018-04-03 00:08:08.521858+00', 'Old Fashioned Scottish Hospitality', 'OLD FASHIONED SCOTTISH HOSPITALITY', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5056, '1997-11-27 23:00:00+00', '2018-04-03 00:08:08.555318+00', 'Old Highland Toast, An', 'OLD HIGHLAND TOAST', 4, 32, 1, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5057, '1997-04-03 22:00:00+00', '2018-04-03 00:08:08.563556+00', 'Old House At Home, The', 'OLD HOUSE AT HOME', 1, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5058, '1997-04-03 22:00:00+00', '2018-04-03 00:08:08.572059+00', 'Old Ireland', 'OLD IRELAND', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5059, '1997-09-10 22:00:00+00', '2018-04-03 00:08:08.580273+00', 'Old Man Dillon', 'OLD MAN DILLON', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5066, '1997-04-03 22:00:00+00', '2018-04-03 00:08:08.622003+00', 'Old Rosin The Beau', 'OLD ROSIN THE BEAU', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5071, '1997-09-10 22:00:00+00', '2018-04-03 00:08:08.663618+00', 'Old Wick Castle', 'OLD WICK CASTLE', 2, 32, 9999, 1, 3, 42, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5073, '1997-08-21 22:00:00+00', '2018-04-03 00:08:08.680308+00', 'Olive''s Strathspey', 'OLIVES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5074, '1997-04-03 22:00:00+00', '2018-04-03 00:08:08.705283+00', 'On a Clear Day', 'ON A CLEAR DAY', 3, 32, 9999, 1, 3, 42, 44, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5075, '1997-04-03 22:00:00+00', '2018-04-03 00:08:08.722052+00', 'On A Smurrny Day', 'ON A SMURRNY DAY', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5085, '1997-09-10 22:00:00+00', '2018-04-03 00:08:08.730298+00', 'Once A Night', 'ONCE A NIGHT', 2, 40, 9999, 1, 3, 42, 466, '1774-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5076, '1998-10-05 22:00:00+00', '2018-04-03 00:08:09.047078+00', 'On the Banks of a Stream', 'ON THE BANKS OF A STREAM', 4, 32, 1, 1, 3, 42, 44, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5097, '1997-04-03 22:00:00+00', '2018-04-29 21:31:54.20779+00', 'Oopsy-Daisy', 'OOPSYDAISY', 2, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5126, '1997-04-03 22:00:00+00', '2018-04-02 23:56:36.884782+00', 'Over The Anvil', 'OVER THE ANVIL', 1, 32, 9999, 1, 3, 42, 352, '1994-01-15', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5125, '2003-01-28 23:00:00+00', '2018-04-29 22:26:31.568156+00', 'Over Hill and Dale', 'OVER HILL AND DALE', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4023, '1998-07-08 22:00:00+00', '2018-09-09 20:54:50.694538+00', 'MacFarlane''s Lantern', 'MACFARLANES LANTERN', 3, 32, 9999, 1, 100, 2, 313, NULL, 'Devised for Jean Attwood.  



At one time, in the Macfarlane country around Arrochar, the new moon is said to have been known as Macfarlane''s Lantern.', 75, '8008/8888/0880/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11509, '2003-09-22 22:00:00+00', '2018-10-05 15:10:21.458554+00', 'Jingle Bells', 'JINGLE BELLS', 1, 32, 9999, 1, 3, 42, 2766, '2001-12-01', 'This dance was written to celebrate the holiday season; it seems to dance to Jingle Bells, also - at least in my head.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11502, '2003-09-22 22:00:00+00', '2018-10-06 13:22:11.200976+00', 'Origami', 'ORIGAMI', 1, 32, 9999, 1, 3, 42, 2766, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11507, '2003-09-22 22:00:00+00', '2018-10-07 11:01:09.491081+00', 'Reel to Reel', 'REEL TO REEL', 1, 32, 9999, 1, 3, 42, 2766, '2001-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11510, '2003-09-22 22:00:00+00', '2018-10-07 11:16:48.325575+00', 'Ribbon Candy', 'RIBBON CANDY', 1, 32, 9999, 1, 4, NULL, 2766, '2001-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11503, '2003-09-22 22:00:00+00', '2018-10-08 21:44:36.113568+00', 'Spirograph', 'SPIROGRAPH', 1, 32, 9999, 4, 4, NULL, 2766, '2001-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11501, '2003-09-22 22:00:00+00', '2018-10-09 05:51:06.488028+00', 'Squash Blossom', 'SQUASH BLOSSOM', 2, 32, 9999, 1, 3, 42, 2766, '2001-11-01', 'The figure in bars 1-8 reminds me of the squash blossom motif in much Native American jewelry.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5091, '1997-09-10 22:00:00+00', '2012-01-20 12:56:40.429997+00', 'One Man''s Fancy', 'ONE MANS FANCY', 2, 48, 9999, 1, 4, NULL, 108, '1971-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11505, '2003-09-22 22:00:00+00', '2018-10-09 12:01:06.688232+00', 'Tiddlywinks', 'TIDDLYWINKS', 2, 32, 9999, 1, 3, 42, 2766, '2001-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11506, '2003-09-22 22:00:00+00', '2018-10-09 12:11:11.312446+00', 'Tit for Tat', 'TIT FOR TAT', 2, 32, 9999, 1, 3, 42, 2766, '2001-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5096, '1997-04-03 22:00:00+00', '2012-01-20 12:56:40.466348+00', 'One To Enjoy', 'ONE TO ENJOY', 1, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5095, '1997-04-03 22:00:00+00', '2019-02-09 10:56:54.734762+00', 'One Step Forward', 'ONE STEP FORWARD', 1, 32, 9999, 1, 3, 42, 352, NULL, '', 50, '880/880/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11514, '2003-10-02 22:00:00+00', '2019-02-22 12:50:43.446845+00', 'Dufftown''s 50th', 'DUFFTOWNS 50TH', 1, 40, 9999, 3, 4, 52, 3379, NULL, '', 56, '8000/8888/8888/8888/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5101, '1997-09-17 22:00:00+00', '2012-01-20 12:56:40.501391+00', 'Open Window, The', 'OPEN WINDOW', 2, 96, 9999, 4, 4, NULL, 366, '1989-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11522, '2003-10-02 22:00:00+00', '2019-03-02 11:50:46.289026+00', 'Greencourt Reel', 'GREENCOURT REEL', 1, 32, 9999, 2, 3, 17, 3522, '2000-01-01', '', 92, '888/880/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5103, '1998-07-09 22:00:00+00', '2012-01-20 12:56:40.515731+00', 'Orange and Blue', 'ORANGE AND BLUE', 3, 32, 9999, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5104, '1997-09-10 22:00:00+00', '2012-01-20 12:56:40.522538+00', 'Orange Grove', 'ORANGE GROVE', 3, 32, 9999, 1, 4, NULL, 1182, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5105, '2003-01-25 23:00:00+00', '2012-01-20 12:56:40.530026+00', 'Orangeville Rant', 'ORANGEVILLE RANT', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5108, '1998-10-15 22:00:00+00', '2012-01-20 12:56:40.550609+00', 'Ordinary Princess, The', 'ORDINARY PRINCESS', 1, 32, 9999, 1, 2, NULL, 788, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5117, '1997-09-10 22:00:00+00', '2019-04-29 16:39:07.525012+00', 'Our Compliments To William Marshall', 'OUR COMPLIMENTS TO WILLIAM MARSHALL', 3, 32, 9999, 1, 4, 1, 3461, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5119, '1997-09-10 22:00:00+00', '2012-01-20 12:56:40.626813+00', 'Our Grandsons', 'OUR GRANDSONS', 2, 40, 9999, 1, 4, NULL, 377, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5121, '1997-09-10 22:00:00+00', '2012-01-20 12:56:40.64062+00', 'Our Jean Garvin', 'OUR JEAN GARVIN', 1, 40, 9999, 3, 5, NULL, 1186, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5123, '1997-04-03 22:00:00+00', '2012-01-20 12:56:40.655112+00', 'Out In The Ocean', 'OUT IN THE OCEAN', 2, 96, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11527, '2003-10-02 22:00:00+00', '2020-07-06 11:40:05.200412+00', 'Mariner''s Jig', 'MARINERS JIG', 2, 32, 9999, 5, 2, NULL, 9998, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5064, '1997-12-21 23:00:00+00', '2022-11-20 15:41:58.621964+00', 'Old Newton', 'OLD NEWTON', 1, 32, 9999, 1, 3, 42, 9, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5129, '1997-08-24 22:00:00+00', '2020-09-02 11:59:03.495551+00', 'Over the Hill', 'OVER THE HILL', 2, 32, 9999, 1, 3, 42, 108, '1990-01-01', 'For Rita Marlow', 56, '888/844/844/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5191, '1997-09-11 22:00:00+00', '2020-09-02 17:16:31.969496+00', 'Peacock''s Close', 'PEACOCKS CLOSE', 2, 32, 9999, 1, 3, 42, 108, '1984-01-01', '', 55, '844/844/888/806', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11526, '2003-10-02 22:00:00+00', '2021-01-23 13:35:11.980137+00', 'March Wedding', 'MARCH WEDDING', 4, 128, 13, 4, 4, 3, 3386, NULL, '', 75, '8888/8080/8080/0808/0808/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11521, '2003-10-02 22:00:00+00', '2021-01-23 20:43:01.157361+00', 'Goose Burn', 'GOOSE BURN', 3, 32, 9999, 1, 4, 2, 2892, NULL, '', 75, '4884/0880/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11520, '2003-10-02 22:00:00+00', '2021-01-23 20:45:13.330571+00', 'Golden Years, The', 'GOLDEN YEARS', 3, 32, 9999, 4, 4, 1, 2075, '2003-01-01', '', 88, '8448/4884/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11519, '2003-10-02 22:00:00+00', '2021-01-23 20:47:03.68715+00', 'Golden Memories', 'GOLDEN MEMORIES', 3, 32, 9999, 2, 3, 17, 3381, NULL, '', 60, '080/844/666/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11485, '2003-09-22 22:00:00+00', '2021-01-24 12:04:40.471811+00', 'January Jig', 'JANUARY JIG', 2, 32, 9999, 1, 3, 42, 3378, '2001-01-01', '', 53, '860/806/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5109, '2002-04-08 22:00:00+00', '2021-04-08 13:33:36.601506+00', 'Oregon Rant, The', 'OREGON RANT', 4, 128, 13, 4, 4, 3, 108, '1974-01-01', '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5088, '1997-04-03 22:00:00+00', '2021-04-28 23:05:07.539174+00', 'One for the Road', 'ONE FOR THE ROAD', 1, 32, 9999, 1, 3, 42, 3586, '1994-01-01', 'Written for the Christmas Feast Dance 1994.', 50, '800/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5106, '1998-04-19 22:00:00+00', '2021-05-13 11:16:31.603228+00', 'Orb, The', 'ORB', 1, 32, 9999, 1, 2, 76, 352, '1993-01-11', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5130, '1998-01-05 23:00:00+00', '2012-01-20 12:56:40.703573+00', 'Over the Hill (and Going Strong)', 'OVER THE HILL AND GOING STRONG', 1, 32, 9999, 1, 4, NULL, 34, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5092, '1997-09-10 22:00:00+00', '2018-04-03 00:08:08.772013+00', 'One More Dance And Then', 'ONE MORE DANCE AND THEN', 1, 24, 9999, 1, 3, 42, 198, '1750-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5094, '1997-04-03 22:00:00+00', '2018-04-03 00:08:08.820619+00', 'One Plus Six', 'ONE PLUS SIX', 1, 32, 9999, 1, 3, 42, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5112, '1997-11-27 23:00:00+00', '2018-04-03 00:08:09.297532+00', 'Origin of the Kilt Pin, The', 'ORIGIN OF THE KILT PIN', 4, 32, 1, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5113, '1997-09-10 22:00:00+00', '2018-04-03 00:08:09.314088+00', 'Orleance Baffled', 'ORLEANCE BAFFLED', 1, 12, 9999, 1, 3, 42, 446, '1710-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5114, '2000-06-12 22:00:00+00', '2018-04-03 00:08:09.347357+00', 'Ospreys'' Nest, The', 'OSPREYS NEST', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5115, '1997-09-10 22:00:00+00', '2018-04-03 00:08:09.372439+00', 'Ottawa Experience, The', 'OTTAWA EXPERIENCE', 2, 32, 9999, 1, 3, 42, 1187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5116, '1997-04-03 22:00:00+00', '2018-04-03 00:08:09.380647+00', 'Our Bob''s Reel', 'OUR BOBS REEL', 1, 40, 9999, 1, 3, 42, 205, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5124, '1998-04-29 22:00:00+00', '2018-04-03 00:08:09.46414+00', 'Out on the Green', 'OUT ON THE GREEN', 1, 32, 9999, 1, 3, 42, 44, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5127, '1997-09-10 22:00:00+00', '2018-04-03 00:08:09.514218+00', 'Over the Border to Cumberland', 'OVER THE BORDER TO CUMBERLAND', 2, 32, 9999, 1, 3, 42, 108, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5131, '2002-11-26 23:00:00+00', '2012-01-20 12:56:40.710381+00', 'Over the Hills and Far Away', 'OVER THE HILLS AND FAR AWAY', 1, 32, 9999, 2, 3, NULL, 109, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5132, '1997-04-03 22:00:00+00', '2012-01-20 12:56:40.71718+00', 'Over the Rainbow', 'OVER THE RAINBOW', 1, 32, 9999, 1, 2, NULL, 44, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5144, '1997-12-29 23:00:00+00', '2018-04-29 11:06:37.130504+00', 'Oyster Wives Rant, The', 'OYSTER WIVES RANT', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5134, '1997-04-03 22:00:00+00', '2012-01-20 12:56:40.730742+00', 'Over the Sea to the West', 'OVER THE SEA TO THE WEST', 3, 96, 9999, 1, 98, NULL, 62, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18892, '2018-10-08 21:42:14.649376+00', '2018-10-08 21:42:14.649376+00', 'Spin Cycle', 'SPIN CYCLE', 1, 32, NULL, 1, 3, 42, 2766, '2010-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5140, '2002-08-13 22:00:00+00', '2012-01-20 12:56:40.77236+00', 'Owre the Friendly Main', 'OWRE THE FRIENDLY MAIN', 3, 64, 9999, 4, 4, NULL, 108, '1968-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5143, '1997-09-11 22:00:00+00', '2012-01-20 12:56:40.792855+00', 'Oyster Girl, The', 'OYSTER GIRL', 2, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11540, '2003-10-05 22:00:00+00', '2018-04-03 00:07:42.87619+00', 'Downie Reel, The', 'DOWNIE REEL', 1, 32, 9999, 1, 3, 42, 2578, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11535, '2005-04-06 22:00:00+00', '2012-01-20 12:57:30.614993+00', 'Weel May the Boatie Row', 'WEEL MAY THE BOATIE ROW', 3, 40, 9999, 1, 4, NULL, 108, '1967-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19028, '2018-10-19 21:07:47.651273+00', '2018-10-22 04:20:56.972419+00', 'Jenny''s Rant', 'JENNYS RANT', 1, 32, NULL, 1, 4, 1, 11734, '1990-01-01', '', 66, '0880/8888/8000/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11539, '2003-10-05 22:00:00+00', '2012-01-20 12:57:30.652629+00', 'Fifty Happy Years', 'FIFTY HAPPY YEARS', 3, 32, 9999, 2, 3, NULL, 3388, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5148, '2002-12-08 23:00:00+00', '2012-01-20 12:56:40.8269+00', 'Paddy On The Railroad', 'PADDY ON THE RAILROAD', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5149, '1997-04-03 22:00:00+00', '2012-01-20 12:56:40.833671+00', 'Paddy''s Dream', 'PADDYS DREAM', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5153, '1997-09-11 22:00:00+00', '2012-01-20 12:56:40.860979+00', 'Paidlin'' In The Burn', 'PAIDLIN IN THE BURN', 2, 32, 9999, 1, 2, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11544, '2003-10-05 22:00:00+00', '2018-04-03 00:07:44.352442+00', 'Elizabeth Gordon Strathspey', 'ELIZABETH GORDON STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5156, '1997-11-27 23:00:00+00', '2012-01-20 12:56:40.882015+00', 'Palos Park Assembly', 'PALOS PARK ASSEMBLY', 4, 32, 1, 1, 4, 1, 361, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5133, '1997-09-10 22:00:00+00', '2018-04-03 00:08:09.530924+00', 'Over the River and Through the Woods', 'OVER THE RIVER AND THROUGH THE WOODS', 2, 32, 9999, 1, 3, 42, 704, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5157, '1998-04-19 22:00:00+00', '2012-01-20 12:56:40.888833+00', 'Pam''s Ring', 'PAMS RING', 1, 32, 9999, 5, 2, NULL, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5164, '1997-04-03 22:00:00+00', '2012-01-20 12:56:40.938432+00', 'Parliament Gathering', 'PARLIAMENT GATHERING', 1, 32, 9999, 5, 2, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5137, '1997-04-03 22:00:00+00', '2019-03-11 19:18:51.651907+00', 'Over the Waves', 'OVER THE WAVES', 3, 24, 9999, 1, 4, 2, 352, NULL, '', 67, '8008/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5173, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.00006+00', 'Passing Glance, A', 'PASSING GLANCE', 1, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11541, '2003-10-05 22:00:00+00', '2012-01-20 12:57:30.669583+00', 'Helping Hands', 'HELPING HANDS', 3, 32, 9999, NULL, 4, NULL, 3389, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11542, '2003-10-05 22:00:00+00', '2012-01-20 12:57:30.677556+00', 'Boat Race, The', 'BOAT RACE', 2, 32, 9999, NULL, 4, NULL, 3390, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11545, '2003-10-05 22:00:00+00', '2012-01-20 12:57:30.703925+00', 'When We meet Again', 'WHEN WE MEET AGAIN', 1, 32, 9999, 1, 4, NULL, 3392, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5135, '1997-04-03 22:00:00+00', '2018-04-03 00:08:09.539315+00', 'Over the Thistle', 'OVER THE THISTLE', 1, 32, 9999, 1, 3, 42, 361, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11551, '2003-10-05 22:00:00+00', '2012-01-20 12:57:30.760865+00', 'Over The Water', 'OVER THE WATER', 3, 32, 9999, 2, 3, NULL, 3394, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11550, '2003-10-05 22:00:00+00', '2015-07-19 13:13:22.118081+00', 'Acknowledge Your Partner', 'ACKNOWLEDGE YOUR PARTNER', 1, 32, 9999, 2, 3, 17, 1042, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5138, '1997-09-11 22:00:00+00', '2018-04-03 00:08:09.555909+00', 'Owairaka Rant', 'OWAIRAKA RANT', 1, 48, 9999, 1, 3, 42, 646, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5145, '1998-05-09 22:00:00+00', '2018-04-03 00:08:09.670897+00', 'Padda Rocks', 'PADDA ROCKS', 2, 32, 9999, 1, 3, 42, 1188, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5146, '1997-09-11 22:00:00+00', '2018-04-03 00:08:09.697659+00', 'Paddy Carey', 'PADDY CAREY', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5098, '2002-04-28 22:00:00+00', '2020-09-02 11:51:06.673874+00', 'Oot o'' the World and into Kippen', 'OOT O THE WORLD AND INTO KIPPEN', 1, 32, 9999, 1, 3, 42, 9, NULL, '', 64, '848/888/828/884', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5139, '1998-07-08 22:00:00+00', '2020-09-02 12:04:05.933336+00', 'Owl and the Pussy Cat, The', 'OWL AND THE PUSSY CAT', 2, 48, 9999, 1, 100, 2, 108, '1990-07-01', '', 71, '4884/4884/8888/8448/8008/8008', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11534, '2003-10-02 22:00:00+00', '2020-10-01 11:25:42.990036+00', 'Three Rs, The', 'THREE RS', 2, 48, 9999, 3, 5, 7, 3385, NULL, '', 78, '80800/88888/88888/84884/86846/84844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5161, '1998-11-15 23:00:00+00', '2021-04-25 18:09:03.761079+00', 'Park Hotel, Dunoon, The', 'PARK HOTEL DUNOON', 1, 32, 9999, 1, 4, 1, 87, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11532, '2003-10-02 22:00:00+00', '2021-01-23 11:50:24.142809+00', 'Strathmiksa', 'STRATHMIKSA', 3, 32, 9999, 5, 4, NULL, 534, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11528, '2003-10-02 22:00:00+00', '2021-01-23 13:30:31.814835+00', 'Miss Janet Renton', 'MISS JANET RENTON', 1, 40, 9999, 1, 4, 2, 11033, NULL, '', 70, '8008/8888/8008/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11523, '2003-10-02 22:00:00+00', '2021-01-23 20:39:49.594619+00', 'Hills of Alba, The', 'HILLS OF ALBA', 1, 32, 9999, 1, 100, 2, 384, '2000-01-01', '', 63, '8008/8008/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11515, '2003-10-02 22:00:00+00', '2021-01-23 20:48:40.610496+00', 'Final Reel, The', 'FINAL REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 56, '800/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5142, '1997-09-11 22:00:00+00', '2021-04-02 22:32:13.704709+00', 'Oyster Girl', 'OYSTER GIRL', 2, 32, 9999, 1, 4, 1, 80, NULL, '', 66, '8008/8888/4444/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11536, '2003-10-02 22:00:00+00', '2021-04-03 11:33:27.451985+00', 'Trip to the Weald', 'TRIP TO THE WEALD', 2, 64, 9999, 4, 4, 3, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5102, '1997-04-03 22:00:00+00', '2021-04-28 09:22:50.042867+00', 'Opo', 'OPO', 1, 32, 9999, 1, 3, 42, 352, NULL, '', 41, '800/880/880/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5150, '1997-04-03 22:00:00+00', '2018-04-03 00:08:09.722656+00', 'Paddy''s Leather Breeches', 'PADDYS LEATHER BREECHES', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5162, '1997-09-08 22:00:00+00', '2018-04-03 00:08:09.855894+00', 'Parks Of Lochabers', 'PARKS OF LOCHABERS', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5166, '1997-04-03 22:00:00+00', '2018-04-03 00:08:09.872657+00', 'Parson, The', 'PARSON', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5167, '1997-04-03 22:00:00+00', '2018-04-03 00:08:09.881068+00', 'Partans In His Creel', 'PARTANS IN HIS CREEL', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5169, '1997-04-03 22:00:00+00', '2018-04-03 00:08:09.889401+00', 'Parting Glass, The', 'PARTING GLASS', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11547, '2003-10-05 22:00:00+00', '2018-04-03 00:08:17.178095+00', 'Sixty Milers, The', 'SIXTY MILERS', 1, 32, 9999, 1, 3, 42, 985, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11548, '2003-10-05 22:00:00+00', '2018-04-03 00:08:23.165589+00', 'Two Ladies', 'TWO LADIES', 2, 32, 9999, 1, 3, 42, 3393, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11552, '2003-10-05 22:00:00+00', '2018-04-03 00:08:26.21805+00', 'Windy Place, A', 'WINDY PLACE', 2, 32, 9999, 1, 3, 42, 723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5152, '1997-09-11 22:00:00+00', '2013-02-14 01:02:53.616285+00', 'Padre, The', 'PADRE', 3, 40, 9999, 1, 3, 42, 153, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5175, '1997-09-11 22:00:00+00', '2012-01-20 12:56:41.013807+00', 'Passing Through', 'PASSING THROUGH', 2, 32, 9999, 1, 4, NULL, 523, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5177, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.027684+00', 'Pat''s Parlour', 'PATS PARLOUR', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5180, '1998-07-08 22:00:00+00', '2012-01-20 12:56:41.049723+00', 'Patricia''s Fancy', 'PATRICIAS FANCY', 1, 32, 9999, 1, 4, 2, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11568, '2003-11-01 23:00:00+00', '2018-04-29 05:58:06.995152+00', 'Whenever the Ten Shall Meet', 'WHENEVER THE TEN SHALL MEET', 2, 40, 9999, 3, 5, 16, 1445, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5182, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.063384+00', 'Paul Jamie Reel', 'PAUL JAMIE REEL', 1, 32, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5183, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.07014+00', 'Pauline''s Jig', 'PAULINES JIG', 2, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5185, '1997-11-24 23:00:00+00', '2012-01-20 12:56:41.083738+00', 'Pavilion Medley', 'PAVILION MEDLEY', 4, 64, 5, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11555, '2003-10-19 22:00:00+00', '2018-07-28 17:39:57.274155+00', 'Maid from Morningside, The', 'MAID FROM MORNINGSIDE', 1, 32, 9999, 2, 3, 18, 3395, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13203, '2006-12-11 23:00:00+00', '2018-10-03 00:49:55.836616+00', 'Charade', 'CHARADE', 2, 32, 9999, 1, 3, 42, 2766, '2005-09-01', 'In the movie Charade you don’t know until the very end what is going on. I patterned this dance to be slightly unorthodox to reflect that.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5190, '1997-09-11 22:00:00+00', '2012-01-20 12:56:41.120604+00', 'Peaceful Shores', 'PEACEFUL SHORES', 3, 32, 9999, 1, 4, NULL, 1195, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5192, '2002-02-28 23:00:00+00', '2012-01-20 12:56:41.134347+00', 'Peacock''s Close', 'PEACOCKS CLOSE', 3, 32, 9999, 1, 4, NULL, 406, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5193, '1997-09-11 22:00:00+00', '2012-01-20 12:56:41.141226+00', 'Peacock, The', 'PEACOCK', 4, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5194, '1998-07-08 22:00:00+00', '2012-01-20 12:56:41.148684+00', 'Peaks Of Lawers', 'PEAKS OF LAWERS', 1, 32, 9999, 1, 4, 2, 697, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5196, '2001-05-20 22:00:00+00', '2012-01-20 12:56:41.16227+00', 'Pearl of Scotland, The', 'PEARL OF SCOTLAND', 3, 32, 9999, 1, 4, NULL, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5197, '1997-09-11 22:00:00+00', '2012-01-20 12:56:41.169035+00', 'Peat Bog, The', 'PEAT BOG', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5201, '2002-03-12 23:00:00+00', '2012-01-20 12:56:41.196969+00', 'Peerie, The', 'PEERIE', 1, 40, 9999, 1, 4, 1, 111, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5202, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.203768+00', 'Peg''s Folly', 'PEGS FOLLY', 3, 32, 9999, 1, 4, NULL, 247, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11557, '2003-10-30 23:00:00+00', '2012-01-20 12:57:30.821619+00', 'Party Tent, The', 'PARTY TENT', 2, 32, 9999, 1, 4, 2, 1445, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11559, '2003-10-30 23:00:00+00', '2012-01-20 12:57:30.839783+00', 'Electronic Pigeon, The', 'ELECTRONIC PIGEON', 3, 32, 9999, 4, 4, NULL, 1445, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11566, '2003-11-01 23:00:00+00', '2012-01-20 12:57:30.902411+00', 'Gent Strathspey', 'GENT STRATHSPEY', 3, 32, 9999, 4, 4, NULL, 1445, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5210, '1997-09-11 22:00:00+00', '2012-01-20 12:56:41.258283+00', 'Penblwydd Isca', 'PENBLWYDD ISCA', 1, 32, 9999, 1, 4, NULL, 1197, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5211, '1997-09-11 22:00:00+00', '2012-01-20 12:56:41.265066+00', 'Pencerrig', 'PENCERRIG', 1, 40, 9999, 4, 4, NULL, 728, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5212, '1997-09-11 22:00:00+00', '2012-01-20 12:56:41.271854+00', 'Pennine Ramble, The', 'PENNINE RAMBLE', 1, 40, 9999, 1, 4, NULL, 1198, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5214, '1997-09-11 22:00:00+00', '2012-01-20 12:56:41.28551+00', 'Penny Bap, The', 'PENNY BAP', 3, 32, 9999, 1, 4, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5218, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.312755+00', 'Penny''s Pleasure', 'PENNYS PLEASURE', 2, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5227, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.374682+00', 'Peter Baillie', 'PETER BAILLIE', 3, 48, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5229, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.388271+00', 'Peter Quinn', 'PETER QUINN', 2, 48, 9999, 1, 4, NULL, 317, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5231, '1997-09-11 22:00:00+00', '2012-01-20 12:56:41.401824+00', 'Peter Walker', 'PETER WALKER', 1, 32, 9999, 1, 4, NULL, 1200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5233, '2001-06-12 22:00:00+00', '2012-01-20 12:56:41.416137+00', 'Doune Road, The', 'DOUNE ROAD', 1, 32, 9999, 4, 4, 13, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5226, '2002-03-03 23:00:00+00', '2018-04-03 00:08:06.903905+00', 'Muriel Crawshaw''s Jig', 'MURIEL CRAWSHAWS JIG', 2, 32, 9999, 1, 3, 42, 241, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11571, '2003-11-10 23:00:00+00', '2012-01-20 12:57:30.947489+00', 'Anst''er Ludgin'', The', 'ANSTER LUDGIN', 1, 48, 9999, 1, 4, 1, 553, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11572, '2003-11-11 23:00:00+00', '2012-01-20 12:57:30.95631+00', 'Double ''H'' Jig', 'DOUBLE H JIG', 2, 96, 9999, 4, 4, NULL, 553, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5184, '1997-04-03 22:00:00+00', '2018-04-03 00:08:10.047928+00', 'Pauline''s Red Robins', 'PAULINES RED ROBINS', 3, 32, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5181, '1997-12-21 23:00:00+00', '2020-09-02 17:13:13.970157+00', 'Pau Hana', 'PAU HANA', 1, 32, 9999, 1, 3, 42, 9, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5220, '1997-09-11 22:00:00+00', '2022-11-06 21:52:01.945758+00', 'Persian Dance, The', 'PERSIAN DANCE', 1, 40, 9999, 1, 2, 76, 270, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5176, '2002-04-19 22:00:00+00', '2022-12-18 20:46:33.829226+00', 'Pat''s Fancy', 'PATS FANCY', 3, 32, 9999, 1, 2, NULL, 377, NULL, 'Devised for Pat Hamilton.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5187, '1997-09-11 22:00:00+00', '2022-11-20 14:42:56.992608+00', 'Pawky Duke, The', 'PAWKY DUKE', 1, 32, 9999, 1, 3, 42, 108, '1983-01-01', 'The Pawky Duke is a song with words by David Rorie who was a physician and a poet.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5172, '1997-04-03 22:00:00+00', '2022-12-01 14:55:24.156761+00', 'Passing Fancy', 'PASSING FANCY', 1, 32, 9999, 1, 3, 42, 377, NULL, '', 44, '840/804/888/800', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11511, '2003-10-02 22:00:00+00', '2022-12-19 14:30:24.116166+00', 'Constant Companions', 'CONSTANT COMPANIONS', 3, 32, 9999, 1, 3, 42, 2489, '2000-01-01', '', 44, '800/800/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5189, '1998-04-19 22:00:00+00', '2020-11-05 13:56:41.748901+00', 'Paying The Piper', 'PAYING THE PIPER', 1, 32, 9999, 1, 3, 42, 99, '1987-01-01', '', 39, '802/808/800/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5221, '1997-04-03 22:00:00+00', '2021-01-09 12:00:15.603402+00', 'Perth Inch', 'PERTH INCH', 2, 32, 9999, 1, 2, NULL, 392, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11537, '2003-10-02 22:00:00+00', '2021-01-23 11:44:23.583253+00', 'Windway', 'WINDWAY', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 56, '800/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5217, '1997-08-19 22:00:00+00', '2021-04-25 12:54:35.706484+00', 'Penny Whistle, The', 'PENNY WHISTLE', 2, 32, 9999, 1, 2, 76, 104, '1989-01-01', 'For Frank and Kathy Reid.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5151, '1998-11-02 23:00:00+00', '2021-04-25 18:24:46.134146+00', 'Paddy''s Milestane', 'PADDYS MILESTANE', 2, 32, 9999, 1, 3, 42, 394, '1989-01-01', '', 50, '800/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5186, '1997-04-03 22:00:00+00', '2021-05-24 12:26:45.761661+00', 'Paving Stones', 'PAVING STONES', 1, 32, 9999, 1, 3, 42, 352, '1993-01-24', '', 41, '800/800/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5163, '1997-04-03 22:00:00+00', '2021-06-16 23:52:38.428614+00', 'Parks of Kilbirnie', 'PARKS OF KILBIRNIE', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5195, '2001-05-20 22:00:00+00', '2018-04-03 00:08:10.114661+00', 'Pearl of Falmouth, The', 'PEARL OF FALMOUTH', 3, 32, 9999, 1, 3, 42, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5205, '1998-01-05 23:00:00+00', '2018-04-03 00:08:10.198062+00', 'Peggy Reel, The', 'PEGGY REEL', 1, 32, 9999, 1, 3, 42, 1196, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5206, '1998-11-29 23:00:00+00', '2018-04-03 00:08:10.206394+00', 'Peggy''s Cove', 'PEGGYS COVE', 3, 32, 9999, 1, 3, 42, 108, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5216, '1998-01-05 23:00:00+00', '2018-04-03 00:08:10.314679+00', 'Penny Wedding, The', 'PENNY WEDDING', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5228, '1997-04-03 22:00:00+00', '2018-04-03 00:08:10.456618+00', 'Peter Elmes', 'PETER ELMES', 1, 32, 9999, 1, 3, 42, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5230, '1997-04-03 22:00:00+00', '2018-04-03 00:08:10.473353+00', 'Peter Straughan', 'PETER STRAUGHAN', 2, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11560, '2003-10-30 23:00:00+00', '2018-04-03 00:08:13.992516+00', 'RR 19', 'RR 19', 1, 32, 9999, 1, 3, 42, 1445, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11573, '2003-11-11 23:00:00+00', '2012-01-20 12:57:30.965199+00', 'Erskine''s Pearl', 'ERSKINES PEARL', 2, 32, 9999, 1, 4, NULL, 553, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11576, '2003-11-11 23:00:00+00', '2012-01-20 12:57:30.993359+00', 'Jewels in the Crown', 'JEWELS IN THE CROWN', 2, 32, 9999, 1, 4, 2, 553, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11577, '2003-11-11 23:00:00+00', '2012-01-20 12:57:31.001124+00', 'Linlithgow Loch', 'LINLITHGOW LOCH', 3, 32, 9999, 2, 3, 17, 553, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11578, '2003-11-11 23:00:00+00', '2012-01-20 12:57:31.008089+00', 'Love for Life', 'LOVE FOR LIFE', 4, 128, 2, 4, 4, NULL, 553, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11579, '2003-11-11 23:00:00+00', '2012-01-20 12:57:31.015647+00', 'Mrs Mary Morrison', 'MRS MARY MORRISON', 1, 48, 9999, 1, 4, 1, 553, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5234, '1997-09-11 22:00:00+00', '2018-04-17 07:47:41.775498+00', 'Peter''s Farewell', 'PETERS FAREWELL', 1, 32, 9999, 1, 4, 1, 411, '1991-01-01', 'For my son Peter on his temporary relocation to Australia', 78, '8840/8804/8888/4888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11589, '2003-11-29 23:00:00+00', '2018-04-29 13:29:50.33778+00', 'Fronds, The', 'FRONDS', 3, 32, 9999, 6, 3, 18, 411, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18707, '2018-10-03 00:52:37.824751+00', '2018-10-03 00:52:37.824751+00', 'Charlie''s Jig', 'CHARLIES JIG', 2, 32, NULL, 1, 3, 42, 2766, '2016-06-01', 'I liked the figure on bars 17-32 which I took from one of Charlie Harrington’s dances.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5275, '1997-04-03 22:00:00+00', '2018-07-26 14:03:07.577467+00', 'Piper Johnny', 'PIPER JOHNNY', 2, 32, 9999, 1, 3, 42, 173, '1973-02-27', '', 52, '820/864/846/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5245, '1998-11-16 23:00:00+00', '2012-01-20 12:56:41.50404+00', 'Phoenix Strathspey, The', 'PHOENIX STRATHSPEY', 3, 32, 9999, 1, 4, 1, 87, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5247, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.517857+00', 'Pibroch Of Donuil Dhu', 'PIBROCH OF DONUIL DHU', 2, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5248, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.524621+00', 'Pickhurst', 'PICKHURST', 3, 32, 9999, 1, 4, NULL, 676, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5259, '1997-09-11 22:00:00+00', '2019-03-11 19:01:09.822481+00', 'Pinehills Strathspey', 'PINEHILLS STRATHSPEY', 3, 40, 9999, 1, 4, 2, 538, NULL, '', 60, '0880/8888/0660/0660/8484', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5250, '1997-09-11 22:00:00+00', '2012-01-20 12:56:41.538165+00', 'Picton Schottische', 'PICTON SCHOTTISCHE', 3, 32, 9999, 1, 4, NULL, 1201, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5251, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.545638+00', 'Pictures With Music', 'PICTURES WITH MUSIC', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11575, '2003-11-11 23:00:00+00', '2018-04-03 00:07:47.013244+00', 'Friends'' Frolic', 'FRIENDS FROLIC', 1, 40, 9999, 1, 3, 42, 553, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5254, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.566062+00', 'Pierian Jig, The', 'PIERIAN JIG', 2, 32, 9999, 3, 5, NULL, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5241, '1998-01-05 23:00:00+00', '2018-04-03 00:08:10.506729+00', 'Petticoat Tails', 'PETTICOAT TAILS', 1, 32, 9999, 1, 3, 42, 44, '1981-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5258, '1997-09-11 22:00:00+00', '2012-01-20 12:56:41.59408+00', 'Pitnacree Ferryman', 'PITNACREE FERRYMAN', 1, 32, 9999, 5, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11581, '2003-11-11 23:00:00+00', '2012-01-20 12:57:31.029683+00', 'Rena''s Golden Wedding', 'RENAS GOLDEN WEDDING', 1, 32, 9999, 4, 4, NULL, 553, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11584, '2003-12-02 23:00:00+00', '2012-01-20 12:57:31.054911+00', 'Freens A''', 'FREENS A', 1, 32, 9999, 5, 2, NULL, 2913, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5240, '1997-09-11 22:00:00+00', '2018-04-03 00:08:10.515008+00', 'Petticoat Tails', 'PETTICOAT TAILS', 2, 32, 9999, 1, 3, 42, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5235, '1998-07-08 22:00:00+00', '2012-06-30 16:34:04.812045+00', 'Peter''s Return', 'PETERS RETURN', 2, 32, 9999, 1, 100, 2, 411, '1993-01-01', 'For my son Peter on his return to NZ.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5266, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.650778+00', 'Pioneers, The', 'PIONEERS', 2, 32, 9999, 1, 2, NULL, 250, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5269, '1997-09-11 22:00:00+00', '2012-01-20 12:56:41.671439+00', 'Pipe Major Marshall''s Reel', 'PIPE MAJOR MARSHALLS REEL', 1, 40, 9999, 1, 4, NULL, 202, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5270, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.678248+00', 'Pipe Major Sam Scott', 'PIPE MAJOR SAM SCOTT', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5242, '2002-03-02 23:00:00+00', '2018-04-03 00:08:10.523387+00', 'Phantom Kilted Army', 'PHANTOM KILTED ARMY', 1, 32, 9999, 1, 3, 42, 35, '1987-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5273, '2002-03-02 23:00:00+00', '2012-01-20 12:56:41.699751+00', 'Piper From Stornoway, The', 'PIPER FROM STORNOWAY', 3, 32, 9999, 1, 4, 1, 87, '1979-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5246, '1997-09-11 22:00:00+00', '2018-04-03 00:08:10.548448+00', 'Phoenix, The', 'PHOENIX', 1, 32, 9999, 1, 3, 42, 446, '1713-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5283, '1997-11-27 23:00:00+00', '2012-01-20 12:56:41.769249+00', 'Pipers Of Oban, The', 'PIPERS OF OBAN', 4, 48, 5, 4, 4, NULL, 986, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5285, '1997-09-14 22:00:00+00', '2012-01-20 12:56:41.78307+00', 'Sweetest Music of All the Pipes Of Lucknow played', 'SWEETEST MUSIC OF ALL THE PIPES OF LUCKNOW PLAYED', 3, 40, 9999, 1, 4, NULL, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5249, '1997-09-11 22:00:00+00', '2018-04-03 00:08:10.590069+00', 'Picnic On The Grass', 'PICNIC ON THE GRASS', 3, 32, 9999, 1, 3, 42, 43, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5267, '1997-04-03 22:00:00+00', '2018-04-03 00:08:10.698582+00', 'Pipe Major C Elliot', 'PIPE MAJOR C ELLIOT', 1, 32, 9999, 1, 3, 42, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5256, '1998-07-08 22:00:00+00', '2017-02-27 22:23:54.867304+00', 'Pigeon On The Gate, The', 'PIGEON ON THE GATE', 1, 32, 9999, 1, 4, 2, 101, '1985-01-01', '', 75, '8888/8008/8008/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5286, '1997-12-03 23:00:00+00', '2017-06-07 15:47:38.410114+00', 'Highland Rose', 'HIGHLAND ROSE', 2, 96, 9999, 107, 112, 3, 763, '1975-01-01', 'During this demonstration dance, dancers enter and leave during the dance. 

At the beginning, 4 women start back to back is square formation.

After bar 60, one women dances off. 

During bars 61-64, men dance on to form a 3 couple set.



', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5213, '1997-04-03 22:00:00+00', '2020-04-14 12:01:22.438532+00', 'Pennington', 'PENNINGTON', 2, 40, 9999, 1, 3, 42, 3590, '1993-01-01', '', 65, '800/888/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11554, '2003-10-06 22:00:00+00', '2021-01-23 11:42:14.543901+00', 'Zurich Celebration', 'ZURICH CELEBRATION', 3, 32, 9999, 1, 3, 42, 671, '2003-01-01', '', 50, '888/880/844/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5257, '1998-04-19 22:00:00+00', '2021-04-07 11:14:14.025597+00', 'Piggy Bank, The', 'PIGGY BANK', 1, 32, 9999, 1, 4, 1, 59, NULL, '', 61, '6000/8888/8888/8000', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5276, '1997-04-03 22:00:00+00', '2021-04-25 11:34:59.254663+00', 'Piper of Dundee, The', 'PIPER OF DUNDEE', 3, 32, 9999, 1, 2, 76, 108, '1968-01-01', '', 58, '75/66/86/88', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5253, '1997-09-11 22:00:00+00', '2021-06-06 13:35:27.747499+00', 'Pied Piper''s Lady', 'PIED PIPERS LADY', 2, 48, 9999, 1, 3, 42, 795, '1971-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5268, '1997-04-03 22:00:00+00', '2018-04-03 00:08:10.706872+00', 'Pipe Major John Wilson', 'PIPE MAJOR JOHN WILSON', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5263, '1997-04-03 22:00:00+00', '2018-04-03 00:08:10.723606+00', 'Pipe Major T.K. Marshall''s Reel', 'PIPE MAJOR TK MARSHALLS REEL', 3, 32, 9999, 1, 3, 42, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5280, '2003-01-25 23:00:00+00', '2018-04-03 00:08:10.798695+00', 'Piper''s Love Lilt, The', 'PIPERS LOVE LILT', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5287, '1997-12-22 23:00:00+00', '2018-04-03 00:08:10.856971+00', 'Piping School at Ulva, The', 'PIPING SCHOOL AT ULVA', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11580, '2003-11-11 23:00:00+00', '2018-04-03 00:08:12.01624+00', 'Ramfoozle', 'RAMFOOZLE', 2, 32, 9999, 1, 3, 42, 553, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5288, '1998-01-04 23:00:00+00', '2012-01-20 12:56:41.803453+00', 'Piping Shrike, The', 'PIPING SHRIKE', 1, 32, 9999, 1, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11593, '2003-11-29 23:00:00+00', '2012-01-20 12:57:31.151656+00', 'Jean''s Strathspey', 'JEANS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 411, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11594, '2003-11-29 23:00:00+00', '2012-01-20 12:57:31.163184+00', 'Jig for Janette, A', 'JIG FOR JANETTE', 2, 32, 9999, 6, 3, NULL, 411, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11595, '2003-11-29 23:00:00+00', '2012-01-20 12:57:31.175444+00', 'Square Rigged Ship, The', 'SQUARE RIGGED SHIP', 2, 48, 9999, 4, 4, 1, 411, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11596, '2003-11-29 23:00:00+00', '2012-01-20 12:57:31.187799+00', 'Vice Versa', 'VICE VERSA', 1, 40, 9999, 1, 4, 2, 411, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18846, '2018-10-06 13:24:01.529704+00', '2018-10-06 13:24:01.529704+00', 'Our Purr Bear', 'OUR PURR BEAR', 3, 32, NULL, 1, 3, 42, 2766, '2010-02-01', 'We have a cat that purrs loudly when given attention; we call him our purr bear.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11599, '2003-12-02 23:00:00+00', '2012-01-20 12:57:31.220524+00', 'Birl Roond Forfar, A', 'BIRL ROOND FORFAR', 1, 64, 9999, 4, 4, 3, 3406, NULL, 'Dance devised by the 2003 ForFar Branch Committee to celebrate 50 years as a Branch of the RSCDS.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5306, '1997-09-11 22:00:00+00', '2019-04-20 09:36:35.010246+00', 'Point Your Feet And Smile', 'POINT YOUR FEET AND SMILE', 1, 32, 9999, 1, 4, NULL, 678, NULL, '', 56, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5290, '1998-07-08 22:00:00+00', '2012-01-20 12:56:41.817653+00', 'Pitmedden Gardens', 'PITMEDDEN GARDENS', 3, 32, 9999, 1, 4, 2, 108, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5289, '1998-04-19 22:00:00+00', '2019-03-04 15:04:51.726765+00', 'Pitlochry Celebration', 'PITLOCHRY CELEBRATION', 2, 40, 9999, 1, 3, 42, 276, NULL, '', 50, '800/844/844/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5305, '1997-04-03 22:00:00+00', '2019-04-25 14:32:01.690809+00', 'Pohutakawa', 'POHUTAKAWA', 1, 32, 9999, 1, 3, 42, 352, '1993-05-28', '', 50, '844/840/804/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5297, '1997-04-03 22:00:00+00', '2012-01-20 12:56:41.866192+00', 'Planxty Sir Festus Burke', 'PLANXTY SIR FESTUS BURKE', 1, 28, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5304, '1998-07-08 22:00:00+00', '2012-01-20 12:56:41.915053+00', 'Plighted Troth, The', 'PLIGHTED TROTH', 2, 32, 9999, 1, 4, 2, 900, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5313, '1998-04-19 22:00:00+00', '2012-01-20 12:56:41.978906+00', 'Pond Inlet', 'POND INLET', 3, 32, 9999, 1, 4, NULL, 488, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11612, '2003-12-04 23:00:00+00', '2012-01-20 12:57:31.33684+00', 'Tofino Strathspey', 'TOFINO STRATHSPEY', 3, 48, 9999, 1, 4, NULL, 2682, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11614, '2003-12-04 23:00:00+00', '2012-01-20 12:57:31.355178+00', 'Mary Summer, A', 'MARY SUMMER', 3, 32, 9999, 1, 4, 11, 2682, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5319, '1997-04-03 22:00:00+00', '2012-01-20 12:56:42.020656+00', 'Popinjay, The', 'POPINJAY', 1, 40, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5321, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.034337+00', 'Porridge Bowl, The', 'PORRIDGE BOWL', 2, 48, 9999, 1, 4, NULL, 1206, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5322, '1998-07-09 22:00:00+00', '2012-01-20 12:56:42.041855+00', 'Port A''Bhodaich', 'PORT ABHODAICH', 3, 48, 9999, 3, 5, 16, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5323, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.048651+00', 'Port Elgin Fair', 'PORT ELGIN FAIR', 3, 32, 9999, 2, 3, NULL, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5328, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.083085+00', 'Portsmouth', 'PORTSMOUTH', 1, 32, 9999, 1, 2, NULL, 446, '1709-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5291, '1998-10-22 22:00:00+00', '2017-04-02 19:32:42.452481+00', 'Pittenweem', 'PITTENWEEM', 1, 32, 9999, 1, 3, 42, 50, '1980-01-01', '', 50, '888/800/888/800', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11609, '2003-12-04 23:00:00+00', '2018-04-03 00:08:00.999337+00', 'Lyall Bay', 'LYALL BAY', 3, 32, 9999, 1, 3, 42, 2682, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5293, '1997-04-03 22:00:00+00', '2018-04-03 00:08:10.898842+00', 'Pixies'' Delight', 'PIXIES DELIGHT', 3, 32, 9999, 1, 3, 42, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5294, '1997-04-03 22:00:00+00', '2018-04-03 00:08:10.915408+00', 'Plaid Isna for Burying, The', 'PLAID ISNA FOR BURYING', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5298, '1997-04-03 22:00:00+00', '2018-04-03 00:08:10.940494+00', 'Plate That Came By Itself, The', 'PLATE THAT CAME BY ITSELF', 1, 32, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5299, '1997-04-03 22:00:00+00', '2018-04-03 00:08:10.948834+00', 'Playful Porpoise, The', 'PLAYFUL PORPOISE', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5309, '1997-09-11 22:00:00+00', '2018-04-03 00:08:10.99051+00', 'Polite Strathspey, The', 'POLITE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 700, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5311, '1997-10-27 23:00:00+00', '2018-04-03 00:08:10.998868+00', 'Polly Stewart', 'POLLY STEWART', 1, 32, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11605, '2003-12-04 23:00:00+00', '2020-03-17 21:29:52.261813+00', 'Jenny Freeman''s Strathspey', 'JENNY FREEMANS STRATHSPEY', 3, 32, 9999, 1, 2, 76, 2682, '1993-01-01', '', 64, '84/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5310, '1998-09-29 22:00:00+00', '2020-08-12 07:35:49.191601+00', 'Polka Country Dance', 'POLKA COUNTRY DANCE', 1, 32, 9999, 1, 109, 76, 9998, '1880-02-01', '', 60, '88/88/80/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5302, '1997-09-11 22:00:00+00', '2020-09-02 17:57:30.332852+00', 'Pleased To Meet You', 'PLEASED TO MEET YOU', 1, 32, 9999, 7, 2, 76, 1204, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11615, '2003-12-04 23:00:00+00', '2021-01-22 20:57:26.298386+00', 'Maureen Vivino', 'MAUREEN VIVINO', 1, 48, 9999, 1, 3, 42, 2682, '1993-01-01', '', 58, '888/844/866/866/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11603, '2003-12-04 23:00:00+00', '2021-01-22 21:10:53.815515+00', 'Jeanette''s Hornpipe', 'JEANETTES HORNPIPE', 1, 32, 9999, 1, 3, 42, 2682, '1999-01-01', '', 50, '800/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11600, '2003-12-02 23:00:00+00', '2021-01-22 21:16:29.376932+00', 'Birlin'' Birkie, The', 'BIRLIN BIRKIE', 2, 32, 9999, 1, 3, 42, 384, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11598, '2003-12-02 23:00:00+00', '2021-01-22 21:21:23.056961+00', 'Auld Koofie', 'AULD KOOFIE', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 69, '844/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5324, '1998-01-04 23:00:00+00', '2021-04-07 11:10:23.435063+00', 'Christian''s Strathspey', 'CHRISTIANS STRATHSPEY', 3, 40, 9999, 1, 4, 1, 619, NULL, '', 65, '8080/8008/8888/0880/0888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5303, '2002-11-26 23:00:00+00', '2021-04-18 20:21:35.822574+00', 'Pleasures Of Bath, The', 'PLEASURES OF BATH', 3, 40, 9999, 2, 3, 17, 304, '1987-01-01', '', 82, '888/888/808/828/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5424, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.751356+00', 'Queen''s Argyll''s', 'QUEENS ARGYLLS', 1, 32, 9999, 1, 4, NULL, 315, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5317, '1997-09-11 22:00:00+00', '2022-08-20 18:35:29.848926+00', 'Pools of Dee, The', 'POOLS OF DEE', 1, 32, 9999, 1, 4, 1, 868, '1975-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11608, '2003-12-04 23:00:00+00', '2022-09-13 15:09:45.702438+00', 'Isla''s Fancy', 'ISLAS FANCY', 3, 40, 9999, 2, 3, 17, 2682, '2001-01-01', '', 85, '555/888/555/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11606, '2003-12-04 23:00:00+00', '2022-09-23 17:03:46.327744+00', 'Lady in Pink, The', 'LADY IN PINK', 2, 32, 9999, 3, 5, 7, 2682, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5295, '2000-08-30 22:00:00+00', '2023-02-27 09:51:56.449425+00', 'Plain and Fancy', 'PLAIN AND FANCY', 1, 32, 9999, 1, 3, 42, 226, '1976-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5281, '1997-11-20 23:00:00+00', '2021-04-25 10:16:04.624727+00', 'Piper''s Reel, The', 'PIPERS REEL', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 47, '800/844/822/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5278, '2002-03-02 23:00:00+00', '2021-05-05 08:55:47.02101+00', 'Piper''s Cave, The', 'PIPERS CAVE', 1, 32, 9999, 1, 3, 42, 270, '1980-01-01', '', 58, '880/608/884/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5300, '1997-04-03 22:00:00+00', '2021-05-13 15:22:31.755114+00', 'Plaza, The', 'PLAZA', 1, 32, 9999, 1, 3, 42, 352, '1993-01-12', '', 38, '800/880/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5312, '1997-10-27 23:00:00+00', '2018-04-03 00:08:11.007169+00', 'Polwart On The Green', 'POLWART ON THE GREEN', 1, 32, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5314, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.023841+00', 'Ponderosa Strathspey, The', 'PONDEROSA STRATHSPEY', 3, 32, 9999, 1, 3, 42, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5315, '1997-09-11 22:00:00+00', '2018-04-03 00:08:11.040551+00', 'Pontius Pilate''s Rant', 'PONTIUS PILATES RANT', 2, 48, 9999, 1, 3, 42, 198, '1744-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5318, '1997-09-11 22:00:00+00', '2018-04-03 00:08:11.048775+00', 'Poor Nameless Thing', 'POOR NAMELESS THING', 3, 32, 9999, 1, 3, 42, 1090, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5329, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.107261+00', 'Portsmouth', 'PORTSMOUTH', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5331, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.104239+00', 'Pot O'' Luck', 'POT O LUCK', 2, 40, 9999, 1, 4, NULL, 1087, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5333, '1998-07-08 22:00:00+00', '2012-01-20 12:56:42.118468+00', 'Pots Of Rayne', 'POTS OF RAYNE', 3, 32, 9999, 1, 4, 2, 108, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11492, '2003-09-22 22:00:00+00', '2018-10-06 13:25:12.988338+00', 'Out Among the Stars', 'OUT AMONG THE STARS', 3, 32, 9999, 1, 3, 42, 2766, '2002-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5337, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.146941+00', 'Powderhorn Park', 'POWDERHORN PARK', 1, 40, 9999, 1, 4, NULL, 389, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5344, '1998-01-04 23:00:00+00', '2019-01-21 14:19:39.456887+00', 'Pretender, The', 'PRETENDER', 1, 32, 9999, 1, 4, 1, 332, NULL, '', 53, '8800/8660/8000/8088', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5339, '1998-01-05 23:00:00+00', '2012-01-20 12:56:42.161008+00', 'Poynton Reel, The', 'POYNTON REEL', 1, 48, 9999, 1, 4, NULL, 1208, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5342, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.182185+00', 'Prairie Schooner, The', 'PRAIRIE SCHOONER', 2, 48, 9999, 1, 4, NULL, 1209, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5343, '1997-04-03 22:00:00+00', '2012-01-20 12:56:42.188974+00', 'Preston Lodge Hornpipe', 'PRESTON LODGE HORNPIPE', 1, 32, 9999, 1, 4, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5345, '2002-02-27 23:00:00+00', '2019-03-11 18:53:51.615211+00', 'Pretty Ladies', 'PRETTY LADIES', 3, 80, 9999, 4, 4, 3, 94, NULL, '', 63, '8888/8080/0808/7070/7070/0707/0707/4444/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5368, '1997-09-11 22:00:00+00', '2019-09-13 19:20:01.996038+00', 'Prince William of Glo''ster''s Waltz', 'PRINCE WILLIAM OF GLOSTERS WALTZ', 5, 32, 9999, 1, 2, NULL, 459, '1801-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11624, '2003-12-04 23:00:00+00', '2012-01-20 12:57:31.44548+00', 'Carlton and Alex', 'CARLTON AND ALEX', 1, 48, 9999, 1, 4, NULL, 2682, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11626, '2003-12-04 23:00:00+00', '2012-01-20 12:57:31.463073+00', 'An Tri Daraich', 'TRI DARAICH', 4, 256, 55, 1, 4, NULL, 2682, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11630, '2004-01-01 23:00:00+00', '2012-01-20 12:57:31.496642+00', 'Steele''s Reel', 'STEELES REEL', 99, 0, 9999, NULL, NULL, NULL, 3410, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5349, '2002-02-28 23:00:00+00', '2012-01-20 12:56:42.22972+00', 'Pride Of Baltimore, The', 'PRIDE OF BALTIMORE', 3, 32, 9999, 1, 4, NULL, 406, '1979-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5352, '1997-04-03 22:00:00+00', '2012-01-20 12:56:42.250284+00', 'Primrose Waltz, The', 'PRIMROSE WALTZ', 5, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5356, '1997-09-29 22:00:00+00', '2012-01-20 12:56:42.280634+00', 'Prince Charlie''s Reel', 'PRINCE CHARLIES REEL', 1, 28, 9999, 1, 98, NULL, 192, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5361, '1997-09-04 22:00:00+00', '2012-01-20 12:56:42.315507+00', 'Honours to Jean', 'HONOURS TO JEAN', 3, 32, 9999, 1, 4, NULL, 1001, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5365, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.343604+00', 'Prince Rupert''s March', 'PRINCE RUPERTS MARCH', 50, 72, 9999, 1, 4, NULL, 446, '1651-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5370, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.379072+00', 'Princes Street', 'PRINCES STREET', 3, 32, 9999, 1, 4, NULL, 775, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11625, '2003-12-04 23:00:00+00', '2017-06-26 22:41:07.591613+00', 'Le Moyne and Roger Farrell of Ithaca', 'MOYNE AND ROGER FARRELL OF ITHACA', 3, 160, 9999, 4, 4, NULL, 2682, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5369, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.299115+00', 'Prince''s Assembly, The', 'PRINCES ASSEMBLY', 2, 32, 9999, 1, 3, 42, 209, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11641, '2004-01-14 23:00:00+00', '2018-04-03 00:07:53.118522+00', 'Hussy''f (25 Years On), The', 'HUSSYF 25 YEARS ON', 2, 32, 9999, 1, 3, 42, 9998, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11622, '2003-12-04 23:00:00+00', '2018-04-03 00:07:54.552855+00', 'Ithaca Reel', 'ITHACA REEL', 1, 32, 9999, 1, 3, 42, 2682, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5334, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.123943+00', 'Pottinger''s Reel', 'POTTINGERS REEL', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5335, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.132318+00', 'Potty Dance, The', 'POTTY DANCE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5336, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.140683+00', 'Poulton''s Pleasure, The', 'POULTONS PLEASURE', 2, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5338, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.148922+00', 'Powsowdle', 'POWSOWDLE', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5340, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.157344+00', 'Prairie Lily Strathspey, The', 'PRAIRIE LILY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 204, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5341, '1997-11-27 23:00:00+00', '2018-04-03 00:08:11.165683+00', 'Prairie Pipers, The', 'PRAIRIE PIPERS', 4, 64, 5, 1, 3, 42, 204, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5346, '1997-10-27 23:00:00+00', '2018-04-03 00:08:11.190663+00', 'Pretty Peggy', 'PRETTY PEGGY', 1, 32, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5348, '1997-09-11 22:00:00+00', '2018-04-03 00:08:11.207365+00', 'Pride Of Aberdeen, The', 'PRIDE OF ABERDEEN', 2, 32, 9999, 1, 3, 42, 1210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5353, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.249099+00', 'Prince Charles Edward Stewart', 'PRINCE CHARLES EDWARD STEWART', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11636, '2004-01-14 23:00:00+00', '2020-03-24 19:28:54.144337+00', 'Happy Weekend, The', 'HAPPY WEEKEND', 2, 32, 9999, 1, 3, 42, 3412, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11621, '2003-12-04 23:00:00+00', '2020-06-13 13:17:45.103487+00', 'Patricia London', 'PATRICIA LONDON', 2, 96, 9999, 4, 4, 30, 2682, '1993-01-01', 'Patricia London is the deviser''s mother.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11629, '2003-12-18 23:00:00+00', '2021-01-18 18:25:47.977876+00', 'Wee Nothin'', A', 'WEE NOTHIN', 2, 32, 9999, 1, 2, 76, 1760, NULL, 'An older leaflet of this dance calls it "A Wee Nothing" which is added as an alias.', 52, '88/44/44/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11644, '2004-01-14 23:00:00+00', '2021-04-03 11:31:43.341551+00', 'Squared Away', 'SQUARED AWAY', 2, 32, 9999, 4, 4, 4, 2018, NULL, '', 88, '8888/8888/6666/6666', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11637, '2004-01-14 23:00:00+00', '2021-01-21 22:59:32.944421+00', 'Let''s Celebrate', 'LETS CELEBRATE', 3, 40, 9999, 1, 4, 2, 3415, NULL, '', 82, '8668/8448/8888/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11638, '2004-01-14 23:00:00+00', '2021-01-22 10:21:11.162311+00', 'Martram, The', 'MARTRAM', 3, 32, 9999, 3, 5, 7, 3416, NULL, '', 81, '88880/88808/88808/86866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11634, '2004-01-14 23:00:00+00', '2021-01-22 10:23:23.85952+00', 'Davidson''s Delight', 'DAVIDSONS DELIGHT', 3, 32, 9999, 1, 3, 42, 3413, NULL, '', 50, '844/844/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11632, '2004-01-14 23:00:00+00', '2021-01-22 10:26:20.089341+00', 'Birthday Offering', 'BIRTHDAY OFFERING', 1, 32, 9999, 1, 3, 42, 3411, '2003-01-01', '', 59, '800/888/888/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11618, '2003-12-04 23:00:00+00', '2021-01-22 10:30:53.543269+00', 'Cayuga Reel', 'CAYUGA REEL', 1, 40, 9999, 6, 3, 18, 2682, '1993-01-01', '', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11607, '2003-12-04 23:00:00+00', '2021-01-22 21:06:52.301786+00', 'Wordsmiths, The', 'WORDSMITHS', 3, 32, 9999, 1, 100, 2, 2682, '1999-01-01', '', 75, '8008/8888/8008/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11604, '2003-12-04 23:00:00+00', '2021-01-22 21:08:58.005942+00', 'Susan''s Jig', 'SUSANS JIG', 2, 40, 9999, 1, 3, 42, 2682, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11643, '2004-01-14 23:00:00+00', '2021-04-02 22:02:19.510995+00', 'Up a Notch', 'UP A NOTCH', 1, 32, 9999, 2, 3, 17, 2018, NULL, '', 67, '440/844/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11631, '2004-01-14 23:00:00+00', '2023-02-22 09:09:20.616695+00', 'Andrew Gillies'' Strathspey', 'ANDREW GILLIES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3411, '2003-01-01', '', 50, '800/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11635, '2004-01-14 23:00:00+00', '2023-02-21 23:06:52.11776+00', 'Golden Croydon', 'GOLDEN CROYDON', 1, 32, 9999, 1, 3, 42, 3414, NULL, '', 44, '800/633/633/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5350, '1998-04-29 22:00:00+00', '2021-04-25 08:47:17.455592+00', 'Pride of the Murray, The', 'PRIDE OF THE MURRAY', 1, 32, 9999, 1, 3, 42, 44, NULL, 'Presented to the tenth Australian Winter School.', 41, '802/082/880/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5360, '1997-09-11 22:00:00+00', '2018-04-03 00:08:11.27402+00', 'Prince Edward''s Jig', 'PRINCE EDWARDS JIG', 2, 32, 9999, 1, 3, 42, 466, '1757-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5363, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.282409+00', 'Prince of Pipers, The', 'PRINCE OF PIPERS', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5367, '1997-09-11 22:00:00+00', '2018-04-03 00:08:11.315806+00', 'Prince William', 'PRINCE WILLIAM', 1, 64, 9999, 1, 3, 42, 397, '1731-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5373, '1997-04-03 22:00:00+00', '2018-04-02 23:56:37.057134+00', 'Princess Margaret''s Jig', 'PRINCESS MARGARETS JIG', 2, 32, 9999, 1, 3, 42, 129, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5374, '1997-09-11 22:00:00+00', '2012-09-02 20:55:45.978071+00', 'Princess Margaret''s Strathspey', 'PRINCESS MARGARETS STRATHSPEY', 3, 48, 9999, 1, 3, 42, 91, '1948-01-01', '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5418, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.70995+00', 'Queen of Hearts', 'QUEEN OF HEARTS', 3, 32, 9999, 1, 4, NULL, 719, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5419, '1998-07-08 22:00:00+00', '2012-01-20 12:56:42.71739+00', 'Queen of Hearts, The', 'QUEEN OF HEARTS', 1, 32, 9999, 1, 4, 2, 1211, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5420, '1997-04-03 22:00:00+00', '2012-01-20 12:56:42.7242+00', 'Queen Vic''s Washing Day', 'QUEEN VICS WASHING DAY', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5404, '1997-04-03 22:00:00+00', '2019-03-11 18:15:55.230847+00', 'Quaker, The', 'QUAKER', 2, 64, 9999, 4, 4, 14, 94, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19218, '2019-03-03 18:38:54.990677+00', '2019-03-03 18:38:54.990677+00', 'Referee Way', 'REFEREE WAY', 1, 32, NULL, 4, 4, NULL, 11527, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5413, '1997-09-11 22:00:00+00', '2019-03-11 18:10:33.298224+00', 'Queen City Strathspey, The', 'QUEEN CITY STRATHSPEY', 3, 32, 9999, 2, 3, 17, 636, NULL, '', 79, '888/808/884/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5380, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.447083+00', 'Protea And The Thistle, The', 'PROTEA AND THE THISTLE', 3, 32, 9999, 1, 4, NULL, 206, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5387, '1997-09-11 22:00:00+00', '2019-03-11 18:22:53.152438+00', 'Ptarmigan, The', 'PTARMIGAN', 3, 40, 9999, 2, 3, 17, 108, '1982-01-01', '', 87, '484/888/888/808/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5383, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.467514+00', 'Provost Skene''s House', 'PROVOST SKENES HOUSE', 4, 192, 9999, 1, 4, NULL, 91, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11645, '2004-01-14 23:00:00+00', '2019-04-10 13:24:27.156401+00', 'Tempest, The', 'TEMPEST', 1, 32, 9999, 5, 2, 76, 2018, NULL, '', 100, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5393, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.53658+00', 'Pu Pu Springs', 'PU PU SPRINGS', 3, 32, 9999, 1, 4, 1, 258, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5397, '1998-09-20 22:00:00+00', '2012-01-20 12:56:42.563808+00', 'Purple O'' The Heather, The', 'PURPLE O THE HEATHER', 1, 32, 9999, 1, 4, NULL, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5400, '1998-04-19 22:00:00+00', '2012-01-20 12:56:42.584265+00', 'Pye in the Sky', 'PYE IN THE SKY', 2, 32, 9999, 1, 4, NULL, 108, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5401, '1997-04-03 22:00:00+00', '2012-01-20 12:56:42.591108+00', 'Quad, The', 'QUAD', 3, 32, 9999, 1, 4, NULL, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11646, '2004-01-14 23:00:00+00', '2012-01-20 12:57:31.634403+00', 'Beginner''s Luck', 'BEGINNERS LUCK', 1, 32, 9999, 2, 3, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11647, '2004-01-14 23:00:00+00', '2012-01-20 12:57:31.643104+00', 'Thread the Needle', 'THREAD THE NEEDLE', 2, 32, 9999, 2, 3, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11648, '2004-01-14 23:00:00+00', '2012-01-20 12:57:31.651728+00', 'Sic a Ewie', 'SIC A EWIE', 1, 32, 9999, 2, 3, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11649, '2004-01-14 23:00:00+00', '2012-01-20 12:57:31.660389+00', 'Roun We Go', 'ROUN WE GO', 2, 32, 9999, 4, 4, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11650, '2004-01-14 23:00:00+00', '2012-01-20 12:57:31.669718+00', 'Round Reel of Six', 'ROUND REEL OF SIX', 2, 40, 9999, 6, 3, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19565, '2019-08-29 16:55:01.092821+00', '2019-08-29 16:55:01.092821+00', 'Dvorana', 'DVORANA', 1, 32, NULL, 4, 4, NULL, 390, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11653, '2004-01-14 23:00:00+00', '2012-01-20 12:57:31.695805+00', 'Dancing Roon the Green', 'DANCING ROON THE GREEN', 3, 40, 9999, NULL, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11655, '2004-01-14 23:00:00+00', '2012-01-20 12:57:31.711388+00', 'Frae Hough to Hough', 'FRAE HOUGH TO HOUGH', 2, 32, 9999, NULL, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11657, '2004-01-14 23:00:00+00', '2012-01-20 12:57:31.72871+00', 'Like to Fa''', 'LIKE TO FA', 3, 32, 9999, 1, 4, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11658, '2004-01-14 23:00:00+00', '2012-01-20 12:57:31.737352+00', 'Wi'' Mirth and Glee', 'WI MIRTH AND GLEE', 1, 40, 9999, 2, 3, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11652, '2004-01-14 23:00:00+00', '2018-04-03 00:07:40.774274+00', 'Dance Best that Dances Fast', 'DANCE BEST THAT DANCES FAST', 2, 32, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5405, '1998-01-05 23:00:00+00', '2012-01-20 12:56:42.618482+00', 'Quarrell In The Quantocks', 'QUARRELL IN THE QUANTOCKS', 1, 40, 9999, 3, 5, NULL, 333, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19706, '2019-10-24 16:24:37.850626+00', '2019-10-24 18:56:22.73668+00', 'May Day Reel, The', 'MAY DAY REEL', 1, 32, NULL, 1, 2, 76, 11893, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5408, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.639404+00', 'Quart de Centenaire', 'QUART DE CENTENAIRE', 1, 32, 9999, 1, 4, NULL, 481, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19558, '2019-08-26 12:48:08.904359+00', '2019-09-24 14:53:46.794095+00', 'Smoky Morning, A', 'SMOKY MORNING', 3, 32, NULL, 1, 3, 42, 11861, '2014-02-01', 'This dance and accompanying tune were written to celebrate Keith Smith''s and Muriel Johnstone''s visit to Walnut Creek in Feb. 2014.', 45, '860/833/833/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5415, '1997-11-27 23:00:00+00', '2012-01-20 12:56:42.689029+00', 'Queen Mother''s Reel, The', 'QUEEN MOTHERS REEL', 4, 64, 5, 1, 4, NULL, 350, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19564, '2019-08-29 15:17:46.963757+00', '2019-10-30 04:02:09.958964+00', 'Volga and Kazanka', 'VOLGA AND KAZANKA', 2, 32, NULL, 1, 3, 42, 390, NULL, 'Kazan, Russia lies at the confluence of these two rivers.', 56, '800/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11651, '2004-01-14 23:00:00+00', '2018-04-03 00:07:47.238575+00', 'Furl about the Feezings', 'FURL ABOUT THE FEEZINGS', 3, 32, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5406, '1998-01-05 23:00:00+00', '2018-04-03 00:08:11.557573+00', 'Quarrelsome Piper, The', 'QUARRELSOME PIPER', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5379, '1997-08-21 22:00:00+00', '2018-04-03 00:08:11.374085+00', 'Promenade In Space, A', 'PROMENADE IN SPACE', 3, 32, 9999, 1, 3, 42, 108, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5381, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.449151+00', 'Proud Highlander, The', 'PROUD HIGHLANDER', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5382, '2002-03-02 23:00:00+00', '2018-04-03 00:08:11.457426+00', 'Proud McLeod, The', 'PROUD MACLEOD', 1, 32, 9999, 1, 3, 42, 139, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5394, '1997-09-11 22:00:00+00', '2018-04-03 00:08:11.515869+00', 'Purling Pyper, The', 'PURLING PYPER', 2, 32, 9999, 1, 3, 42, 1104, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5396, '1997-09-11 22:00:00+00', '2018-04-03 00:08:11.524174+00', 'Purple Heather Reel', 'PURPLE HEATHER REEL', 1, 32, 9999, 1, 3, 42, 108, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5411, '1997-09-11 22:00:00+00', '2018-04-03 00:08:11.63107+00', 'Queen Bess''s Dame Of Honour', 'QUEEN BESSS DAME OF HONOUR', 2, 48, 9999, 1, 3, 42, 446, '1710-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5359, '1998-07-08 22:00:00+00', '2020-02-08 20:19:37.882473+00', 'Prince Edward Island', 'PRINCE EDWARD ISLAND', 3, 32, 9999, 1, 100, 2, 108, '1988-01-01', '', 88, '8888/8888/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5390, '1997-09-11 22:00:00+00', '2020-09-02 18:07:36.639068+00', 'Pumpkin Pie', 'PUMPKIN PIE', 2, 32, 9999, 1, 3, 42, 1203, NULL, '', 56, '844/888/844/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5392, '1997-10-15 22:00:00+00', '2020-10-07 21:56:30.803384+00', 'Punk''s Delight, The', 'PUNKS DELIGHT', 1, 64, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5385, '1998-01-05 23:00:00+00', '2021-04-18 09:26:56.106734+00', 'Provost, The', 'PROVOST', 1, 32, 9999, 1, 3, 42, 392, NULL, '', 44, '804/840/840/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5402, '1998-09-30 22:00:00+00', '2021-04-24 20:22:13.535962+00', 'Quadrille Country Dance', 'QUADRILLE COUNTRY DANCE', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 60, '44/88/88/88', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5398, '1999-12-21 23:00:00+00', '2021-04-25 08:18:14.351957+00', 'Push about the Jorum', 'PUSH ABOUT THE JORUM', 1, 32, 9999, 1, 3, 42, 455, NULL, '', 56, '404/880/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5364, '1998-09-29 22:00:00+00', '2021-04-25 08:33:42.689417+00', 'Prince of Wales', 'PRINCE OF WALES', 3, 40, 9999, 1, 3, 42, 263, '1795-01-01', '', 32, '800/800/880/822/800', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5399, '1998-01-04 23:00:00+00', '2021-05-13 07:33:14.452066+00', 'Push Pin', 'PUSH PIN', 1, 32, 9999, 1, 2, 76, 352, '1993-01-23', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5416, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.697922+00', 'Queen Mum''s Smile, The', 'QUEEN MUMS SMILE', 3, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5417, '1997-11-27 23:00:00+00', '2018-04-03 00:08:11.707629+00', 'Queen O'' The May', 'QUEEN O THE MAY', 4, 64, 5, 1, 3, 42, 348, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5427, '1998-04-19 22:00:00+00', '2012-01-20 12:56:42.77163+00', 'Queen''s Delight', 'QUEENS DELIGHT', 1, 32, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11676, '2004-02-08 23:00:00+00', '2018-12-17 17:15:49.084344+00', 'Twelfth Night Jig', 'TWELFTH NIGHT JIG', 2, 40, 9999, 1, 4, 2, 3432, '2004-01-01', '', 80, '6666/8888/6666/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5431, '2002-12-07 23:00:00+00', '2012-01-20 12:56:42.799773+00', 'Queen''s Park', 'QUEENS PARK', 2, 40, 9999, 1, 4, NULL, 414, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11660, '2004-01-14 23:00:00+00', '2012-01-20 12:57:31.754622+00', 'Blaw Up your Chanter', 'BLAW UP YOUR CHANTER', 2, 32, 9999, 2, 3, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19219, '2019-03-03 18:40:10.702798+00', '2019-03-03 18:40:10.702798+00', 'Half Final', 'HALF FINAL', 1, 32, NULL, 1, 3, 42, 11527, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11664, '2004-01-26 23:00:00+00', '2012-01-20 12:57:31.789429+00', 'Burns Night Fancy', 'BURNS NIGHT FANCY', 3, 64, 9999, 4, 4, NULL, 1829, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19221, '2019-03-03 18:42:57.642036+00', '2019-03-03 18:42:57.642036+00', 'Minions'' Column', 'MINIONS COLUMN', 3, 32, NULL, 5, 2, NULL, 11527, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11667, '2004-01-26 23:00:00+00', '2012-01-20 12:57:31.815726+00', 'Six for Dinner', 'SIX FOR DINNER', 2, 32, 9999, 2, 3, NULL, 1829, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11668, '2004-01-26 23:00:00+00', '2012-01-20 12:57:31.825304+00', 'Hard Alee!', 'HARD ALEE', 1, 64, 9999, 1, 4, 1, 1829, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11670, '2004-02-08 23:00:00+00', '2012-01-20 12:57:31.843597+00', 'Dancing Vacation', 'DANCING VACATION', 1, 32, 9999, 1, 4, 1, 3432, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11671, '2004-02-08 23:00:00+00', '2012-01-20 12:57:31.85238+00', 'Debbie''s Strathspey', 'DEBBIES STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 3432, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11672, '2004-02-08 23:00:00+00', '2012-01-20 12:57:31.861148+00', 'Homeward Bound', 'HOMEWARD BOUND', 1, 32, 9999, 1, 2, NULL, 3432, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11673, '2004-02-08 23:00:00+00', '2012-01-20 12:57:31.869894+00', 'MacGruder''s Ceilidh', 'MACGRUDERS CEILIDH', 2, 40, 9999, 4, 4, NULL, 3432, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5432, '1999-04-21 22:00:00+00', '2012-01-20 12:56:42.806607+00', 'Queen''s Representative, The', 'QUEENS REPRESENTATIVE', 3, 40, 9999, 1, 4, NULL, 852, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5433, '1998-01-15 23:00:00+00', '2012-01-20 12:56:42.813473+00', 'Queen''s Silver Jubilee, The', 'QUEENS SILVER JUBILEE', 4, 128, 9999, 1, 4, NULL, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5377, '1997-09-11 22:00:00+00', '2019-03-11 18:29:50.415049+00', 'Priory Jig', 'PRIORY JIG', 2, 32, 9999, 1, 100, 1, 546, NULL, '', 47, '8000/8888/8000/8040', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5439, '1997-09-11 22:00:00+00', '2012-01-20 12:56:42.858639+00', 'Quicken Bough, The', 'QUICKEN BOUGH', 1, 32, 9999, 5, 2, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5442, '1997-04-03 22:00:00+00', '2012-01-20 12:56:42.879076+00', 'Quilting Bee, The', 'QUILTING BEE', 3, 32, 9999, 1, 4, NULL, 361, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5453, '1997-04-03 22:00:00+00', '2012-01-20 12:56:42.95568+00', 'Radyr Dancers, The', 'RADYR DANCERS', 3, 32, 9999, 1, 4, NULL, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5457, '1997-04-03 22:00:00+00', '2012-01-20 12:56:42.983695+00', 'Raindrops On Quarterlands', 'RAINDROPS ON QUARTERLANDS', 2, 32, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11674, '2004-02-08 23:00:00+00', '2012-01-20 12:57:31.878664+00', 'Rhy''s Welcome Jig', 'RHYS WELCOME JIG', 2, 32, 9999, 5, 2, NULL, 3432, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11675, '2004-02-08 23:00:00+00', '2012-01-20 12:57:31.888333+00', 'Sweet Ginger', 'SWEET GINGER', 3, 32, 9999, 1, 4, 2, 3432, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11677, '2004-02-08 23:00:00+00', '2012-01-20 12:57:31.90668+00', 'Winter Dream', 'WINTER DREAM', 2, 24, 9999, 1, 4, NULL, 3432, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11681, '2004-02-13 23:00:00+00', '2018-04-03 00:07:32.828911+00', 'Bejant Royal, The', 'BEJANT ROYAL', 1, 48, 9999, 1, 3, 42, 99, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5459, '1998-05-03 22:00:00+00', '2016-05-10 22:25:30.53272+00', 'Earl of Erroll, The', 'EARL OF ERROLL', 7, 0, 9999, 107, 51, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5429, '1997-09-04 22:00:00+00', '2018-04-03 00:07:52.684851+00', 'Hot and Bothered', 'HOT AND BOTHERED', 1, 32, 9999, 1, 3, 42, 1002, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11662, '2004-01-26 23:00:00+00', '2018-04-03 00:08:09.147216+00', 'Opening Night', 'OPENING NIGHT', 3, 32, 9999, 1, 3, 42, 1829, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5425, '1997-09-11 22:00:00+00', '2018-04-03 00:08:11.716003+00', 'Queen''s Award, The', 'QUEENS AWARD', 1, 32, 9999, 1, 3, 42, 1212, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5428, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.724407+00', 'Queen''s Gate, The', 'QUEENS GATE', 1, 40, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5435, '1997-09-11 22:00:00+00', '2018-04-03 00:08:11.732738+00', 'Queen''s Wedding', 'QUEENS WEDDING', 3, 32, 9999, 1, 3, 42, 315, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5423, '1997-09-11 22:00:00+00', '2018-04-03 00:08:11.740998+00', 'Queen Victoria''s Well', 'QUEEN VICTORIAS WELL', 3, 32, 9999, 1, 3, 42, 108, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5447, '1997-09-11 22:00:00+00', '2018-04-03 00:08:11.799398+00', 'Rabbie Burn''s Thoughts on Modern Farming', 'RABBIE BURNS THOUGHTS ON MODERN FARMING', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5449, '1998-01-05 23:00:00+00', '2018-04-03 00:08:11.841164+00', 'Rachel Phillip''s Reel', 'RACHEL PHILLIPS REEL', 1, 32, 9999, 1, 3, 42, 57, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5452, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.8815+00', 'Radstock Rant, The', 'RADSTOCK RANT', 1, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5454, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.93269+00', 'Railway Caboose', 'RAILWAY CABOOSE', 1, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5456, '1997-09-11 22:00:00+00', '2018-04-03 00:08:11.96609+00', 'Rainbow Days', 'RAINBOW DAYS', 3, 32, 9999, 1, 3, 42, 1217, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11665, '2004-01-26 23:00:00+00', '2018-04-03 00:08:14.467989+00', 'Saint Andrew''s Reel', 'SAINT ANDREWS REEL', 1, 32, 9999, 1, 3, 42, 1829, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11663, '2004-01-26 23:00:00+00', '2018-04-03 00:08:21.681229+00', 'Travellers, The', 'TRAVELLERS', 2, 32, 9999, 1, 3, 42, 1829, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11666, '2004-01-26 23:00:00+00', '2018-04-03 00:08:23.157247+00', 'Two Hands are better than One', 'TWO HANDS ARE BETTER THAN ONE', 2, 32, 9999, 1, 3, 42, 1829, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11678, '2004-02-08 23:00:00+00', '2020-07-13 21:13:30.651886+00', 'East Coast Fiddlers'' Ball', 'EAST COAST FIDDLERS BALL', 1, 32, 9999, 1, 3, 42, 3432, '2004-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5448, '1997-04-03 22:00:00+00', '2020-09-03 08:10:21.85172+00', 'Rachan Mill', 'RACHAN MILL', 2, 32, 9999, 1, 100, 2, 154, NULL, '', 69, '8008/8228/8228/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11661, '2004-01-14 23:00:00+00', '2020-11-13 20:48:45.6189+00', 'Proud and Saucy', 'PROUD AND SAUCY', 1, 32, 9999, 2, 2, 76, 2018, NULL, '', -1, '80/88/88/86', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19220, '2019-03-03 18:41:27.552368+00', '2020-12-12 11:40:57.956114+00', 'Red Card', 'RED CARD', 2, 32, NULL, 1, 3, 101, 11527, NULL, '', 50, '804/884/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5458, '1997-04-03 22:00:00+00', '2021-04-08 11:46:35.777371+00', 'Raising Of The Mary Rose, The', 'RAISING OF THE MARY ROSE', 4, 96, 11, 1, 4, 3, 282, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11680, '2004-02-13 23:00:00+00', '2021-04-03 11:29:13.894077+00', 'Saint Andrews Welcomes Prince William', 'SAINT ANDREWS WELCOMES PRINCE WILLIAM', 2, 32, 9999, 4, 4, 46, 3433, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11683, '2004-02-18 23:00:00+00', '2021-01-27 09:32:29.601289+00', 'Brooklyn Rant, The', 'BROOKLYN RANT', 1, 32, 9999, 1, 3, 42, 710, '2000-01-01', '', 44, '800/844/822/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5421, '1998-09-30 22:00:00+00', '2021-04-24 19:30:07.117358+00', 'Queen Victoria', 'QUEEN VICTORIA', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5438, '2002-09-22 22:00:00+00', '2021-08-02 09:38:24.32573+00', 'Quick And Easy', 'QUICK AND EASY', 2, 32, 9999, 1, 4, 2, 308, '1994-09-01', '', 72, '4884/8228/8008/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5468, '1998-01-05 23:00:00+00', '2018-04-29 12:45:41.668577+00', 'Rampant Lion, The', 'RAMPANT LION', 1, 32, 9999, 1, 3, 42, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5469, '1997-04-03 22:00:00+00', '2018-07-26 07:02:17.272037+00', 'Ramsay McArthur', 'RAMSAY MACARTHUR', 3, 32, 9999, 1, 3, 42, 173, '1981-05-07', '', 75, '888/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5467, '1997-04-03 22:00:00+00', '2012-01-20 12:56:43.054711+00', 'Rambling Through Linton', 'RAMBLING THROUGH LINTON', 3, 32, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18893, '2018-10-08 21:46:25.621013+00', '2018-10-08 21:46:25.621013+00', 'Split Pea Soup', 'SPLIT PEA SOUP', 1, 32, NULL, 1, 3, 42, 2766, '2008-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5502, '1997-09-12 22:00:00+00', '2019-03-11 11:57:48.674516+00', 'Red River Welcome', 'RED RIVER WELCOME', 2, 48, 9999, 1, 4, 1, 438, NULL, '', 69, '7777/8888/8008/8888/8008/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5434, '1998-11-02 23:00:00+00', '2022-08-12 11:15:21.917435+00', 'Queen''s Visit, The', 'QUEENS VISIT', 1, 40, 9999, 1, 4, 1, 118, '1984-05-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5445, '1997-08-25 22:00:00+00', '2022-11-12 19:40:07.321001+00', 'Quirang, The', 'QUIRANG', 3, 32, 9999, 1, 4, 1, 108, '1993-02-01', 'Inscribed "for my many friends in the U.S.A."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5509, '1997-09-12 22:00:00+00', '2019-08-26 08:01:45.335694+00', 'Reekie Linn', 'REEKIE LINN', 2, 32, 9999, 1, 2, 76, 13, NULL, 'Reekie Linn is a waterfall on the River Isla in Perthshire.', 65, '84/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5472, '1997-04-03 22:00:00+00', '2012-01-20 12:56:43.088938+00', 'Rannock Moor', 'RANNOCK MOOR', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5506, '2000-08-01 22:00:00+00', '2018-02-27 15:08:17.441088+00', 'Red Shoes, The', 'RED SHOES', 2, 48, 9999, 1, 4, 1, 2778, '1994-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5477, '1998-01-05 23:00:00+00', '2012-01-20 12:56:43.123225+00', 'Ravensbourne Rant', 'RAVENSBOURNE RANT', 1, 32, 9999, 1, 2, NULL, 393, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5476, '2002-04-08 22:00:00+00', '2018-04-02 23:56:37.155175+00', 'Ravelston Reel, The', 'RAVELSTON REEL', 1, 32, 9999, 1, 3, 42, 108, '1987-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5479, '1998-01-04 23:00:00+00', '2012-01-20 12:56:43.136763+00', 'Ray Hogg''s Reel', 'RAY HOGGS REEL', 1, 32, 9999, 1, 2, NULL, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5488, '1997-04-03 22:00:00+00', '2012-01-20 12:56:43.206627+00', 'Rebecca''s Arrival', 'REBECCAS ARRIVAL', 1, 40, 9999, 1, 4, 1, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11699, '2004-02-18 23:00:00+00', '2012-01-20 12:57:32.100595+00', 'Hap, Step an'' Loup', 'HAP STEP AN LOUP', 3, 32, 9999, 2, 3, NULL, 3427, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5490, '1997-09-02 22:00:00+00', '2012-01-20 12:56:43.220365+00', 'Four Leaf Clover', 'FOUR LEAF CLOVER', 1, 48, 9999, 4, 4, NULL, 926, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5501, '1997-04-03 22:00:00+00', '2012-01-20 12:56:43.310525+00', 'Red Ribbon', 'RED RIBBON', 3, 96, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5507, '1997-04-03 22:00:00+00', '2012-01-20 12:56:43.406753+00', 'Redding Rant, The', 'REDDING RANT', 3, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5510, '1997-04-03 22:00:00+00', '2012-01-20 12:56:43.42709+00', 'Reel Connection, The', 'REEL CONNECTION', 2, 96, 9999, 1, 4, NULL, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5473, '2002-04-08 22:00:00+00', '2016-05-07 12:20:52.41986+00', 'Rantin'' Rovin'' Robin', 'RANTIN ROVIN ROBIN', 3, 32, 9999, 1, 3, 42, 108, '1986-01-01', 'For Robin Lambie of Glenfarg', 50, '800/888/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5478, '1997-12-27 23:00:00+00', '2018-02-19 00:44:33.223812+00', 'Ravenswood Strathspey', 'RAVENSWOOD STRATHSPEY', 3, 32, 9999, 1, 2, 76, 361, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11701, '2004-02-18 23:00:00+00', '2018-04-03 00:07:59.148013+00', 'Lawyer''s Lament', 'LAWYERS LAMENT', 3, 32, 9999, 1, 3, 42, 3430, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5461, '1997-04-03 22:00:00+00', '2018-04-03 00:08:11.991138+00', 'Rakes of Falcarragh', 'RAKES OF FALCARRAGH', 1, 32, 9999, 1, 3, 42, 108, '1979-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5470, '1997-09-11 22:00:00+00', '2018-04-03 00:08:12.066264+00', 'Ramsgate Assembly', 'RAMSGATE ASSEMBLY', 5, 48, 9999, 1, 3, 42, 1138, '1795-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5482, '1997-04-03 22:00:00+00', '2018-04-03 00:08:12.141258+00', 'Ray''s Dance', 'RAYS DANCE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5486, '1997-04-03 22:00:00+00', '2018-04-03 00:08:12.174707+00', 'Real McGhie, The', 'REAL MACGHIE', 2, 48, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5489, '1997-04-03 22:00:00+00', '2018-04-03 00:08:12.183021+00', 'Rebellion, The', 'REBELLION', 1, 40, 9999, 1, 3, 42, 145, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5505, '1997-04-03 22:00:00+00', '2018-04-03 00:08:12.224745+00', 'Red Rug Rant, The', 'RED RUG RANT', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5508, '1997-04-03 22:00:00+00', '2018-04-03 00:08:12.258169+00', 'Redwood Reel', 'REDWOOD REEL', 1, 32, 9999, 1, 3, 42, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5512, '1997-09-12 22:00:00+00', '2018-04-03 00:08:12.274803+00', 'Reel for Alec, A', 'REEL FOR ALEC', 2, 32, 9999, 1, 3, 42, 1220, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5566, '1997-04-03 22:00:00+00', '2018-04-03 00:08:12.983577+00', 'Richmora', 'RICHMORA', 2, 80, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11700, '2004-02-18 23:00:00+00', '2018-04-03 00:08:19.513258+00', 'Sweet Sixty', 'SWEET SIXTY', 2, 40, 9999, 1, 3, 42, 707, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5481, '1998-04-19 22:00:00+00', '2018-04-03 00:08:21.180945+00', 'Timpanogos Reels', 'TIMPANOGOS REELS', 1, 32, 9999, 1, 3, 42, 599, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5515, '2002-08-06 22:00:00+00', '2012-01-20 12:56:43.461896+00', 'Reel for Nancy', 'REEL FOR NANCY', 1, 32, 9999, 1, 98, NULL, 706, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5563, '1997-09-12 22:00:00+00', '2012-01-20 12:56:43.80019+00', 'Richardson Rant', 'RICHARDSON RANT', 3, 32, 9999, 1, 4, NULL, 799, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5500, '1997-04-03 22:00:00+00', '2020-10-01 12:49:11.669379+00', 'Red Red Rose, The', 'RED RED ROSE', 3, 32, 9999, 1, 3, 42, 108, '1968-01-01', '', 59, '888/880/880/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11690, '2004-02-18 23:00:00+00', '2020-10-04 09:37:44.70522+00', 'Professor''s Wife, The', 'PROFESSORS WIFE', 1, 32, 9999, 1, 3, 42, 3427, NULL, 'Devised to celebrate the marriage of Professor David Goldberg and Lois Rekosh.', 56, '844/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5492, '1997-09-12 22:00:00+00', '2021-01-09 12:09:06.622607+00', 'Record Reign, The', 'RECORD REIGN', 1, 32, 9999, 1, 2, 76, 499, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5495, '1998-11-14 23:00:00+00', '2020-12-16 10:17:52.949913+00', 'Red Doublet', 'RED DOUBLET', 3, 40, 9999, 1, 3, 42, 707, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5484, '1997-09-12 22:00:00+00', '2020-12-24 21:09:49.214347+00', 'Reading Round Reel, The', 'READING ROUND REEL', 4, 128, 9999, 4, 4, 54, 99, '1985-04-01', '', 100, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11689, '2004-02-18 23:00:00+00', '2020-12-31 13:04:42.411886+00', 'Green Sweater, The', 'GREEN SWEATER', 3, 32, 9999, 1, 3, 42, 3426, NULL, 'Devised for Seth Major.', 58, '888/864/844/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11694, '2004-02-18 23:00:00+00', '2021-01-21 10:08:10.219567+00', 'Ferguson''s Frolic', 'FERGUSONS FROLIC', 1, 32, 9999, 1, 3, 42, 1350, NULL, '', 64, '822/868/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11692, '2004-02-18 23:00:00+00', '2021-01-21 22:40:04.048554+00', 'Strathspey for Shelley, A', 'STRATHSPEY FOR SHELLEY', 3, 32, 9999, 2, 3, 17, 710, '1999-01-01', '', 50, '800/800/880/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11691, '2004-02-18 23:00:00+00', '2021-01-28 16:51:47.746006+00', 'Da Casan Cli', 'CASAN CLI', 2, 32, 9999, 1, 3, 42, 3428, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11696, '2004-02-18 23:00:00+00', '2021-01-29 07:26:25.160378+00', 'Haven''t a Clue', 'HAVENT A CLUE', 2, 32, 9999, 1, 3, 42, 3425, NULL, '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5494, '1997-04-03 22:00:00+00', '2021-04-24 18:50:20.653319+00', 'Red Baron, The', 'RED BARON', 1, 32, 9999, 1, 2, 76, 44, NULL, '', 50, '80/80/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11698, '2004-02-18 23:00:00+00', '2021-01-29 09:56:54.371947+00', 'Merry-Go-Round, The', 'MERRYGOROUND', 2, 40, 9999, 1, 3, 42, 3427, '2000-01-10', '', 59, '404/440/822/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5483, '1997-04-03 22:00:00+00', '2021-04-04 22:24:13.382439+00', 'Reading Road', 'READING ROAD', 3, 40, 9999, 1, 4, NULL, 145, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5491, '1997-04-03 22:00:00+00', '2021-05-05 13:17:54.430523+00', 'Reconciliation, The', 'RECONCILIATION', 1, 40, 9999, 1, 4, 1, 270, NULL, '', 78, '4444/4444/8888/8888/4888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11706, '2004-03-09 23:00:00+00', '2018-07-28 17:44:59.915216+00', 'Lindworm, The', 'LINDWORM', 2, 40, 9999, 1, 3, 42, 2974, '2003-01-01', '', 45, '800/800/880/880/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5517, '2002-08-06 22:00:00+00', '2012-01-20 12:56:43.475425+00', 'Reel for Rosalind, A', 'REEL FOR ROSALIND', 1, 40, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5523, '1999-08-09 22:00:00+00', '2012-01-20 12:56:43.518318+00', 'Reel of Six', 'REEL OF SIX', 1, 16, 9999, 4, 101, 30, 9998, NULL, '4 women, 2 men', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5551, '1997-04-03 22:00:00+00', '2012-01-20 12:56:43.717325+00', 'Reply To R. Burns by A. Mouse', 'REPLY TO R BURNS BY A MOUSE', 1, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18752, '2018-10-04 23:51:31.422324+00', '2018-10-04 23:51:31.422324+00', 'Flamingo Croquet', 'FLAMINGO CROQUET', 1, 32, NULL, 2, 3, NULL, 2766, '2015-08-01', 'This dance was written for a class celebrating the 150th anniversary of the publication of Alice in Wonderland.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11705, '2004-03-07 23:00:00+00', '2012-01-20 12:57:32.155813+00', 'Golden Knot, The', 'GOLDEN KNOT', 3, 96, 9999, 4, 4, NULL, 108, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11711, '2004-03-18 23:00:00+00', '2012-01-20 12:57:32.216969+00', 'Miss Betty MacKay''s Strathspey', 'MISS BETTY MACKAYS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 3434, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11716, '2004-04-01 22:00:00+00', '2019-09-25 08:33:46.00814+00', 'Camberley Square', 'CAMBERLEY SQUARE', 2, 32, 9999, 4, 4, 1, 1042, '2003-01-01', '', 81, '8888/8888/4444/4848', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5535, '1998-01-04 23:00:00+00', '2012-01-20 12:56:43.606477+00', 'Reel Time', 'REEL TIME', 1, 40, 9999, 1, 2, NULL, 425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11688, '2004-02-18 23:00:00+00', '2022-04-26 01:46:27.79861+00', 'Alba', 'ALBA', 3, 32, 9999, 1, 3, 42, 3424, '2000-01-01', '', 50, '880/808/844/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5475, '1997-11-12 23:00:00+00', '2022-08-12 11:19:15.475073+00', 'Rattlin'' Bog', 'RATTLIN BOG', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 53, '888/811/855/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5537, '1997-09-12 22:00:00+00', '2012-01-20 12:56:43.620099+00', 'Reeling, The', 'REELING', 1, 40, 9999, 1, 4, NULL, 1223, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5540, '1997-12-27 23:00:00+00', '2012-01-20 12:56:43.641584+00', 'Regis Reel', 'REGIS REEL', 1, 32, 9999, 1, 4, 2, 1228, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5548, '1997-08-25 22:00:00+00', '2012-01-20 12:56:43.696866+00', 'Renee Campbell''s Caper', 'RENEE CAMPBELLS CAPER', 2, 96, 9999, 1, 4, NULL, 108, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11718, '2004-04-25 22:00:00+00', '2018-04-03 00:08:10.364821+00', 'Perfect Gentleman, The', 'PERFECT GENTLEMAN', 3, 32, 9999, 1, 3, 42, 2773, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5514, '1997-04-03 22:00:00+00', '2018-04-03 00:08:12.308187+00', 'Reel for Frances, A', 'REEL FOR FRANCES', 1, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5556, '1997-09-12 22:00:00+00', '2012-01-20 12:56:43.75194+00', 'Reverie', 'REVERIE', 3, 48, 9999, 1, 4, NULL, 1117, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5557, '1997-04-03 22:00:00+00', '2012-01-20 12:56:43.758702+00', 'Reversal, The', 'REVERSAL', 1, 32, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5524, '1998-01-04 23:00:00+00', '2015-05-04 13:16:57.725406+00', 'Covered Bridge, The', 'COVERED BRIDGE', 3, 32, 9999, 1, 4, NULL, 488, '1992-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11714, '2004-04-01 22:00:00+00', '2015-07-19 12:22:51.128694+00', 'Dance for Jess, A', 'DANCE FOR JESS', 3, 32, 9999, 2, 120, 17, 1042, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11712, '2004-04-01 22:00:00+00', '2015-07-19 13:05:50.269334+00', 'Sgeul an de an diugh', 'SGEUL AN DE AN DIUGH', 3, 32, 9999, 1, 4, 1, 1042, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11717, '2004-04-01 22:00:00+00', '2015-07-20 07:21:46.934783+00', 'Short and Sweet', 'SHORT AND SWEET', 3, 32, 9999, 1, 4, 1, 1042, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11713, '2004-04-01 22:00:00+00', '2015-07-20 12:30:59.825431+00', 'Give Hands in Friendship', 'GIVE HANDS IN FRIENDSHIP', 1, 64, 9999, 4, 4, NULL, 3435, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5536, '1998-11-25 23:00:00+00', '2016-05-29 20:56:34.108459+00', 'Reeling In The Annex', 'REELING IN THE ANNEX', 3, 32, 9999, 1, 2, NULL, 382, '1993-01-01', '', 34, '80/86/88/84', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5526, '1997-04-03 22:00:00+00', '2018-04-03 00:08:12.416472+00', 'Reel of the Academy', 'REEL OF THE ACADEMY', 1, 32, 9999, 1, 3, 42, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5533, '1998-01-05 23:00:00+00', '2018-04-03 00:08:12.483273+00', 'Reel of Victoria', 'REEL OF VICTORIA', 1, 32, 9999, 1, 3, 42, 250, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5538, '1997-04-03 22:00:00+00', '2018-04-03 00:08:12.541549+00', 'Regency Reel', 'REGENCY REEL', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5541, '1997-04-03 22:00:00+00', '2018-04-03 00:08:12.566667+00', 'Reid''s Rant', 'REIDS RANT', 2, 40, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5544, '1997-04-03 22:00:00+00', '2018-04-03 00:08:12.575018+00', 'Rejected Suitor, The', 'REJECTED SUITOR', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5545, '1998-01-05 23:00:00+00', '2018-04-03 00:08:12.58336+00', 'Relative Reunion', 'RELATIVE REUNION', 1, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5546, '1997-04-03 22:00:00+00', '2018-04-03 00:08:12.599997+00', 'Remember Betty', 'REMEMBER BETTY', 2, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5550, '1998-04-19 22:00:00+00', '2018-04-03 00:08:12.677834+00', 'Repentence Keep', 'REPENTENCE KEEP', 1, 32, 9999, 1, 3, 42, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5553, '1997-09-12 22:00:00+00', '2018-04-03 00:08:12.812948+00', 'Return To The Glen', 'RETURN TO THE GLEN', 1, 32, 9999, 1, 3, 42, 1230, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5561, '2002-03-12 23:00:00+00', '2012-01-20 12:56:43.786544+00', 'Ria & Bill''s Thigether', 'RIA AND BILLS THIGETHER', 3, 48, 9999, 1, 4, 1, 111, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13840, '2011-08-21 22:00:00+00', '2018-07-07 00:47:32.534645+00', 'Remembering Regula', 'REMEMBERING REGULA', 1, 40, NULL, 2, 3, 17, 872, '2003-07-21', 'Devised in memory of Regula Gut from Switzerland who died on 21st July 2003 aged 24 years.', 45, '800/844/866/800/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5504, '2002-02-26 23:00:00+00', '2020-02-08 20:16:45.187572+00', 'Red Rose Of Dunoon, The', 'RED ROSE OF DUNOON', 3, 32, 9999, 1, 100, 2, 13, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4907, '1999-11-01 23:00:00+00', '2020-05-27 00:32:23.530227+00', 'Nether Bow has vanished, The', 'NETHER BOW HAS VANISHED', 3, 48, 9999, 1, 3, 42, 442, '1757-01-01', 'The Society’s version of this dance can be traced to Robert Bremner''s "A Second Collection of Scots Reels or Country Dances" of about 1757 where it is given as a 32-bar version. ', 40, '822/800/808/880/800/880', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5516, '2002-08-06 22:00:00+00', '2020-09-03 08:14:40.584685+00', 'Reel for Rory', 'REEL FOR RORY', 1, 48, 9999, 1, 3, 42, 1221, NULL, '', 54, '822/822/888/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14570, '2012-09-13 13:13:27.33563+00', '2020-06-01 21:47:16.844811+00', 'Mixed Nuts', 'MIXED NUTS', 2, 32, NULL, 5, 2, 76, 10593, '2008-11-01', 'Based on the RSCDS dance "The Nut".', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5530, '1997-09-12 22:00:00+00', '2021-01-01 18:06:07.186569+00', 'Reel of the Sound, The', 'REEL OF THE SOUND', 1, 32, 9999, 1, 3, 42, 1225, NULL, 'The dance represents boating on Puget Sound. They cast off from port, acknowledging other craft (Bars 1-8).   The boats weave in and out on the sound (Bars 9-16).  

The propellers churn and the sailors acknowledge each other (Bars 17-24).  

The happy sailors dance and rejoice having completed an exciting and successful outing (Bars 25-32).', 38, '800/800/880/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11708, '2004-03-10 23:00:00+00', '2021-01-20 18:41:45.399186+00', 'Reel for Chris, A', 'REEL FOR CHRIS', 1, 32, 9999, 1, 3, 42, 558, '2002-01-01', '', 67, '808/888/888/886', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11704, '2004-03-04 23:00:00+00', '2021-01-20 18:44:39.4409+00', 'Just a Wee Dance', 'JUST A WEE DANCE', 1, 32, 9999, 1, 3, 42, 2409, '2004-01-01', '', 43, '800/888/800/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11702, '2004-02-18 23:00:00+00', '2021-01-30 07:22:44.661521+00', 'Last Minute Reel', 'LAST MINUTE REEL', 1, 32, 9999, 1, 3, 42, 3431, NULL, '', 52, '802/888/808/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5534, '1997-09-12 22:00:00+00', '2021-04-07 09:47:49.56401+00', 'Reel Seahawks, The', 'REEL SEAHAWKS', 1, 40, 9999, 1, 4, 1, 1227, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5554, '1997-09-12 22:00:00+00', '2021-06-15 07:34:24.158878+00', 'Return of the Dashing White Sergeant', 'RETURN OF THE DASHING WHITE SERGEANT', 1, 32, 9999, 3, 5, 7, 94, NULL, '', 75, '84844/84884/84884/84844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5531, '1997-09-12 22:00:00+00', '2021-06-15 07:37:59.719204+00', 'Reel of the Twenty First (of April)', 'REEL OF THE TWENTY FIRST OF APRIL', 1, 32, 9999, 1, 3, 42, 1226, NULL, '', 50, '800/822/888/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18753, '2018-10-04 23:53:01.325809+00', '2018-10-04 23:53:01.325809+00', 'Flashes of Gold', 'FLASHES OF GOLD', 1, 32, NULL, 1, 3, 42, 2766, '2014-08-01', 'This dance was written after I watched goldfinches at the thistle feeder.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5558, '1997-04-03 22:00:00+00', '2018-07-17 11:07:49.148976+00', 'Rhinns of Kells, The', 'RHINNS OF KELLS', 1, 32, 9999, 1, 2, 76, 129, NULL, '', 60, '88/88/88/80', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11739, '2004-07-06 22:00:00+00', '2018-04-03 00:07:44.961294+00', 'Fairest of All, The', 'FAIREST OF ALL', 3, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18849, '2018-10-06 13:37:51.067093+00', '2018-10-06 13:37:51.067093+00', 'Parquet', 'PARQUET', 3, 64, NULL, 4, 4, 1, 2766, '2016-08-01', 'The figures of this dance remind me of the pattern of parquet flooring.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11736, '2004-07-06 22:00:00+00', '2018-04-03 00:07:48.648092+00', 'Glen Esk', 'GLEN ESK', 2, 40, 9999, 1, 3, 42, 619, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5570, '1998-07-08 22:00:00+00', '2012-01-20 12:56:43.848623+00', 'Ridge Of Kings, The', 'RIDGE OF KINGS', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5572, '1997-04-03 22:00:00+00', '2012-01-20 12:56:43.862895+00', 'Riding The Marches', 'RIDING THE MARCHES', 2, 40, 9999, 1, 4, NULL, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5565, '1998-04-21 22:00:00+00', '2018-04-03 00:08:06.979119+00', 'Music In The Glen', 'MUSIC IN THE GLEN', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5577, '1997-09-12 22:00:00+00', '2012-01-20 12:56:43.900783+00', 'Right Handed Bairn, The', 'RIGHT HANDED BAIRN', 1, 32, 9999, 2, 3, NULL, 1231, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11726, '2004-06-23 22:00:00+00', '2012-01-20 12:57:32.371986+00', 'Five by Five', 'FIVE BY FIVE', 4, 32, 9999, 3, 5, NULL, 520, NULL, 'Consists of dances (slightly modified)
Polharrow Burn
Kinfauns Castle
Gavin''s Reel
St. Columba''s Strathspey
The Ship in Full Sail', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11728, '2004-07-04 22:00:00+00', '2012-01-20 12:57:32.385698+00', 'C.O.B. Web, The', 'COB WEB', 2, 64, 9999, 6, 3, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5596, '1997-11-19 23:00:00+00', '2018-04-02 23:56:37.330585+00', 'Riverside', 'RIVERSIDE', 2, 32, 9999, 1, 3, 42, 1837, '1987-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11729, '2004-07-04 22:00:00+00', '2012-01-20 12:57:32.393183+00', 'Ramblin'' in the Glen', 'RAMBLIN IN THE GLEN', 3, 32, 9999, 1, 4, 1, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11730, '2004-07-04 22:00:00+00', '2012-01-20 12:57:32.401119+00', 'Sheila''s Strathspey', 'SHEILAS STRATHSPEY', 3, 64, 9999, 4, 4, NULL, 2913, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11733, '2004-07-04 22:00:00+00', '2012-01-20 12:57:32.427307+00', 'Welcome to Aberlemno', 'WELCOME TO ABERLEMNO', 1, 96, 9999, 4, 4, NULL, 2913, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5562, '1997-04-03 22:00:00+00', '2018-04-03 00:08:12.958606+00', 'Richard''s Rant', 'RICHARDS RANT', 1, 32, 9999, 1, 3, 42, 92, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5593, '2002-04-24 22:00:00+00', '2019-03-11 11:43:52.776222+00', 'River Mourne Strathspey, The', 'RIVER MOURNE STRATHSPEY', 3, 48, 9999, 1, 4, 1, 579, NULL, '', 43, '8000/8448/8000/0008/0008/8666', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5567, '1997-09-12 22:00:00+00', '2018-04-03 00:08:13.017021+00', 'Riddle, The', 'RIDDLE', 1, 16, 9999, 1, 3, 42, 198, '1757-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5585, '1997-09-12 22:00:00+00', '2012-01-20 12:56:43.958782+00', 'Riseley Romp, The', 'RISELEY ROMP', 1, 32, 9999, 1, 2, NULL, 686, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5589, '1998-04-19 22:00:00+00', '2019-07-27 16:20:59.953295+00', 'Rivendell', 'RIVENDELL', 1, 32, 9999, 1, 3, 42, 44, '1991-01-01', '', 56, '800/888/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5588, '2000-04-25 22:00:00+00', '2012-01-20 12:56:43.980749+00', 'Brighton Square, The', 'BRIGHTON SQUARE', 1, 32, 9999, 4, 4, NULL, 1228, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5597, '1997-04-03 22:00:00+00', '2019-07-31 15:12:48.238491+00', 'Riverside', 'RIVERSIDE', 3, 32, 9999, 1, 2, 76, 392, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5592, '1997-04-03 22:00:00+00', '2012-01-20 12:56:44.008057+00', 'River Flow', 'RIVER FLOW', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5598, '1997-09-12 22:00:00+00', '2012-01-20 12:56:44.048598+00', 'Riverside Strathspey', 'RIVERSIDE STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 1233, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5599, '1998-10-07 22:00:00+00', '2012-01-20 12:56:44.055377+00', 'Riverwood (Ups and) Downs', 'RIVERWOOD UPS AND DOWNS', 3, 32, 9999, 1, 4, NULL, 109, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5600, '1997-04-03 22:00:00+00', '2012-01-20 12:56:44.062186+00', 'Road Over The Hills, The', 'ROAD OVER THE HILLS', 3, 40, 9999, 1, 4, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5583, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.058567+00', 'Ringslade Revel', 'RINGSLADE REVEL', 1, 32, 9999, 1, 3, 42, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5586, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.100321+00', 'Rising to the Occasion', 'RISING TO THE OCCASION', 3, 32, 9999, 1, 3, 42, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5587, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.125305+00', 'Rites of Hospitality, The', 'RITES OF HOSPITALITY', 1, 40, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5594, '1997-09-12 22:00:00+00', '2018-04-03 00:08:13.158621+00', 'River Orchy', 'RIVER ORCHY', 3, 32, 9999, 1, 3, 42, 179, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5595, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.167002+00', 'River Rats, The', 'RIVER RATS', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5601, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.208774+00', 'Roadrunner, The', 'ROADRUNNER', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5603, '2002-11-14 23:00:00+00', '2018-04-03 00:08:13.225481+00', 'Road to Abernyte, The', 'ROAD TO ABERNYTE', 1, 32, 9999, 1, 3, 42, 176, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11738, '2004-07-06 22:00:00+00', '2018-04-03 00:08:23.340767+00', 'Una''s Reel', 'UNAS REEL', 2, 32, 9999, 1, 3, 42, 619, NULL, 'Inscribed to Mrs Una Howie, a Scottish Country Dancer', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11734, '2004-07-04 22:00:00+00', '2018-04-03 00:08:24.749901+00', 'Welcome to Inverurie', 'WELCOME TO INVERURIE', 1, 40, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5606, '1999-04-19 22:00:00+00', '2012-01-20 12:56:44.105199+00', 'Road To Braemar, The', 'ROAD TO BRAEMAR', 3, 32, 9999, 1, 4, 1, 87, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11741, '2004-07-06 22:00:00+00', '2012-01-20 12:57:32.488818+00', 'Strathspey for Liz, A', 'STRATHSPEY FOR LIZ', 3, 32, 9999, 2, 3, 17, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18754, '2018-10-04 23:57:13.972696+00', '2018-10-04 23:57:13.972696+00', 'Flashes of Light', 'FLASHES OF LIGHT', 3, 32, NULL, 1, 3, 42, 2766, '2008-08-01', 'The title refers to light glancing off slightly disturbed water in a lake or pond.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5578, '1998-07-08 22:00:00+00', '2020-12-16 17:49:46.616233+00', 'Rigmarie', 'RIGMARIE', 2, 32, 9999, 1, 4, 11, 13, NULL, '', 72, '8008/8668/8228/8668', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11759, '2004-08-21 22:00:00+00', '2020-09-18 01:44:36.638767+00', 'A Team, The', 'TEAM', 3, 32, 9999, 1, 3, 42, 2766, '2013-03-01', 'This dance was written for Katherine Andrefsky and Gordon Anderson - the A Team. We’re happy they were here to dance with us and sorry to see them leave.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5602, '1997-04-03 22:00:00+00', '2020-12-30 12:00:47.098661+00', 'Road That Runs By Atholl, The', 'ROAD THAT RUNS BY ATHOLL', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 56, '800/888/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11727, '2004-06-23 22:00:00+00', '2021-01-20 18:30:43.673701+00', 'Osprey Glen', 'OSPREY GLEN', 1, 32, 9999, 1, 3, 42, 520, NULL, '', 50, '800/866/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5560, '1997-09-12 22:00:00+00', '2021-02-05 10:08:29.375056+00', 'Rhododendron Strathspey, The', 'RHODODENDRON STRATHSPEY', 3, 32, 9999, 2, 3, 17, 604, NULL, '', 100, '888/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5571, '1998-07-08 22:00:00+00', '2021-04-24 09:37:11.718568+00', 'Riding The Border Marches', 'RIDING THE BORDER MARCHES', 3, 32, 9999, 1, 116, 2, 678, NULL, '', 81, '8008/8448/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5564, '1997-09-12 22:00:00+00', '2021-04-24 09:51:11.364329+00', 'Richardson''s Rant', 'RICHARDSONS RANT', 1, 32, 9999, 1, 3, 42, 361, NULL, '', 44, '840/888/800/822', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11743, '2004-07-06 22:00:00+00', '2012-01-20 12:57:32.503089+00', 'Anna''s Reel', 'ANNAS REEL', 3, 32, 9999, 3, 5, 7, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11744, '2004-07-06 22:00:00+00', '2012-01-20 12:57:32.51084+00', 'Compliments to Betty Keir', 'COMPLIMENTS TO BETTY KEIR', 3, 32, 9999, 2, 3, 18, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11745, '2004-07-06 22:00:00+00', '2012-01-20 12:57:32.518346+00', 'Alice''s Reel', 'ALICES REEL', 2, 32, 9999, 1, 4, 2, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5607, '1997-04-03 22:00:00+00', '2012-01-20 12:56:44.112175+00', 'Road to Cupar, The', 'ROAD TO CUPAR', 2, 40, 9999, 1, 2, NULL, 108, '1971-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5636, '2002-04-19 22:00:00+00', '2019-03-11 11:17:11.361101+00', 'Roberton Law', 'ROBERTON LAW', 2, 40, 9999, 1, 4, 1, 394, '1976-01-01', '', 50, '8000/8880/8000/8088/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5619, '1997-09-12 22:00:00+00', '2019-03-11 11:21:42.001516+00', 'Road to Auchnafree, The', 'ROAD TO AUCHNAFREE', 1, 32, 9999, 3, 5, 92, 1234, NULL, '', 57, '84884/88484/80006/86000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5611, '1997-09-12 22:00:00+00', '2012-01-20 12:56:44.140647+00', 'Road To Mackay, The', 'ROAD TO MACKAY', 1, 40, 9999, 1, 4, NULL, 523, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5622, '1997-11-27 23:00:00+00', '2012-01-20 12:56:44.22006+00', 'Rob Gordon''s Rant', 'ROB GORDONS RANT', 4, 128, 2, 1, 4, NULL, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5626, '2002-04-19 22:00:00+00', '2012-01-20 12:56:44.247105+00', 'Rob''s Rant', 'ROBS RANT', 1, 32, 9999, 1, 2, NULL, 1236, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5627, '1997-04-03 22:00:00+00', '2012-01-20 12:56:44.253873+00', 'Robert Byrd''s Reel', 'ROBERT BYRDS REEL', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5629, '1997-04-03 22:00:00+00', '2012-01-20 12:56:44.267366+00', 'Robert Innes', 'ROBERT INNES', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11756, '2004-07-20 22:00:00+00', '2019-09-17 21:42:44.199823+00', 'People''s Princess, The', 'PEOPLES PRINCESS', 1, 48, 9999, 1, 100, 2, 1089, NULL, '', 92, '8888/8888/8888/8008/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5632, '1997-04-03 22:00:00+00', '2012-01-20 12:56:44.28786+00', 'Robert Reid Rant', 'ROBERT REID RANT', 3, 80, 9999, 1, 4, NULL, 192, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11753, '2004-07-19 22:00:00+00', '2012-01-20 12:57:32.57839+00', 'Miss Ingrid''s Strathspey', 'MISS INGRIDS STRATHSPEY', 3, 32, 9999, 1, 4, 2, 2862, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11754, '2004-07-19 22:00:00+00', '2012-01-20 12:57:32.587362+00', 'Pia''s Welcome to San Francicso', 'PIAS WELCOME TO SAN FRANCICSO', 3, 32, 9999, 1, 2, NULL, 2862, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11755, '2004-07-19 22:00:00+00', '2012-01-20 12:57:32.596285+00', 'Sandra''s Strathspey', 'SANDRAS STRATHSPEY', 3, 48, 9999, 2, 3, NULL, 2862, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5584, '1997-08-25 22:00:00+00', '2022-11-12 18:54:00.984852+00', 'Rinty''s Rant', 'RINTYS RANT', 1, 32, 9999, 1, 3, 42, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Nancy Rintoul of Bellshill.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13, '1998-04-24 22:00:00+00', '2022-12-10 20:06:59.946401+00', 'Abergeldie Reel, The', 'ABERGELDIE REEL', 3, 32, 9999, 1, 3, 42, 108, '1971-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5634, '1997-09-12 22:00:00+00', '2012-01-20 12:56:44.301457+00', 'Roberta Riegel', 'ROBERTA RIEGEL', 2, 32, 9999, 1, 2, NULL, 401, '1978-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5640, '1997-09-12 22:00:00+00', '2012-10-31 10:50:25.294513+00', 'Robson Strathspey, The', 'ROBSON STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1237, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5639, '2003-01-28 23:00:00+00', '2012-01-20 12:56:44.33715+00', 'Robertson''s Hogmanay', 'ROBERTSONS HOGMANAY', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5646, '2002-11-26 23:00:00+00', '2012-01-20 12:56:44.384819+00', 'Rodger''s Five-O Reel', 'RODGERS FIVEO REEL', 1, 64, 9999, 2, 3, NULL, 50, '1979-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11751, '2004-07-19 22:00:00+00', '2015-05-19 19:51:53.195252+00', 'Felicidades', 'FELICIDADES', 3, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5625, '1998-05-19 22:00:00+00', '2016-02-15 08:08:11.773313+00', 'Rob Roy''s Rant', 'ROB ROYS RANT', 1, 32, 9999, 1, 3, 42, 411, '1992-01-01', 'For my daughter Robyn West.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11742, '2004-07-06 22:00:00+00', '2018-04-03 00:07:46.321111+00', 'Flowers of Scotland, The', 'FLOWERS OF SCOTLAND', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11752, '2004-07-19 22:00:00+00', '2016-11-15 23:59:45.536567+00', 'Humphrey''s Reel', 'HUMPHREYS REEL', 1, 40, 9999, 1, 4, 2, 2862, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11740, '2004-07-06 22:00:00+00', '2018-04-03 00:08:03.868114+00', 'Miss Barbara Malcolm', 'MISS BARBARA MALCOLM', 3, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5608, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.258802+00', 'Road To Dundee, The', 'ROAD TO DUNDEE', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5610, '1997-09-12 22:00:00+00', '2018-04-03 00:08:13.267025+00', 'Road to Forfar, The', 'ROAD TO FORFAR', 3, 32, 9999, 1, 3, 42, 108, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5613, '1997-10-27 23:00:00+00', '2018-04-03 00:08:13.300416+00', 'Road To Muchty, The', 'ROAD TO MUCHTY', 1, 32, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5614, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.308839+00', 'Road To Muchty, The', 'ROAD TO MUCHTY', 1, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5631, '1997-09-12 22:00:00+00', '2018-04-03 00:08:13.383864+00', 'Robert Mackintosh', 'ROBERT MACKINTOSH', 3, 32, 9999, 1, 3, 42, 108, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5633, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.392236+00', 'Robert Stuart''s Rant, The', 'ROBERT STUARTS RANT', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5645, '2002-03-02 23:00:00+00', '2018-04-03 00:08:13.433981+00', 'Roddy''s Jig', 'RODDYS JIG', 2, 32, 9999, 1, 3, 42, 267, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5673, '1997-04-03 22:00:00+00', '2018-04-17 09:26:45.572314+00', 'Rosetown Ball, The', 'ROSETOWN BALL', 1, 32, 9999, 1, 4, NULL, 411, '1983-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5651, '1997-09-12 22:00:00+00', '2012-01-20 12:56:44.421266+00', 'Romany Reel, The', 'ROMANY REEL', 1, 32, 9999, 1, 4, NULL, 1101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5652, '2003-01-25 23:00:00+00', '2012-01-20 12:56:44.428104+00', 'Romp On The Roof Of Eilean Donan', 'ROMP ON THE ROOF OF EILEAN DONAN', 1, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5682, '1997-04-03 22:00:00+00', '2018-07-26 07:25:04.409989+00', 'Rosemary And Diane', 'ROSEMARY AND DIANE', 3, 32, 9999, 1, 3, 42, 173, '1992-03-17', '', 66, '844/888/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5657, '2002-03-02 23:00:00+00', '2012-01-20 12:56:44.462315+00', 'Rory Mor''s Cup', 'RORY MORS CUP', 1, 32, 9999, 1, 4, NULL, 139, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5659, '1997-09-12 22:00:00+00', '2012-01-20 12:56:44.47586+00', 'Rory''s Rant', 'RORYS RANT', 1, 32, 9999, 1, 4, NULL, 1239, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5690, '1997-04-03 22:00:00+00', '2018-07-26 07:16:50.837049+00', 'Ross Linnen', 'ROSS LINNEN', 1, 32, 9999, 1, 3, 42, 173, '1985-04-18', '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5674, '1997-09-12 22:00:00+00', '2020-08-07 09:08:43.027642+00', 'Rose Tree, The', 'ROSE TREE', 1, 32, 9999, 1, 2, 76, 129, '1966-01-01', '', 51, '80/88/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5647, '2002-05-06 22:00:00+00', '2020-08-07 09:05:56.195012+00', 'Rogues'' Rant', 'ROGUES RANT', 2, 160, 9999, 1, 4, NULL, 151, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5630, '1997-04-03 22:00:00+00', '2020-09-03 10:35:17.119119+00', 'Robert Little''s Strathspey', 'ROBERT LITTLES STRATHSPEY', 3, 32, 9999, 1, 2, 76, 108, '1975-02-02', '', 52, '80/80/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11746, '2004-07-06 22:00:00+00', '2020-10-13 19:11:37.965305+00', 'Kings Reel, The', 'KINGS REEL', 1, 32, 9999, 1, 100, 2, 316, NULL, '', 69, '8008/6666/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5655, '1997-10-27 23:00:00+00', '2020-12-31 11:01:33.932011+00', 'Ronnie Douglas', 'RONNIE DOUGLAS', 2, 48, 9999, 1, 2, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11762, '2004-08-24 22:00:00+00', '2021-01-05 21:38:49.356283+00', 'Widdershins', 'WIDDERSHINS', 2, 32, 9999, 1, 3, 42, 3443, NULL, '', 44, '00/822/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11765, '2004-08-24 22:00:00+00', '2021-01-20 15:04:37.752958+00', 'Viking Ship, The', 'VIKING SHIP', 4, 64, 5, 1, 4, 1, 3445, NULL, 'The formations represent parts of the ship and its operation.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11750, '2004-07-06 22:00:00+00', '2021-01-20 18:15:40.670459+00', 'Just Face the Music and Dance', 'JUST FACE THE MUSIC AND DANCE', 1, 32, 9999, 1, 3, 42, 108, '2003-01-01', '', 63, '888/888/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11748, '2004-07-06 22:00:00+00', '2021-01-20 18:23:48.178835+00', 'Radyr Welcome', 'RADYR WELCOME', 1, 32, 9999, 3, 5, 7, 316, NULL, '', 68, '80800/66666/86866/84844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11747, '2004-07-06 22:00:00+00', '2021-01-20 18:26:57.628828+00', 'Mary Queen''s Strathspey', 'MARY QUEENS STRATHSPEY', 3, 32, 9999, 2, 3, 18, 316, NULL, '', 75, '484/484/888/484', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5648, '2001-03-24 23:00:00+00', '2021-04-22 20:19:20.356181+00', 'Rogues'' Gallery', 'ROGUES GALLERY', 1, 32, 9999, 1, 3, 42, 44, '1990-01-01', '', 50, '420/866/866/666', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5643, '1999-08-09 22:00:00+00', '2021-04-22 20:32:45.697958+00', 'Rocks of Gibraltar, The', 'ROCKS OF GIBRALTAR', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 47, '44/88/80/84', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11766, '2004-08-24 22:00:00+00', '2012-01-20 12:57:32.684919+00', 'Bean Shea Fancy', 'BEAN SHEA FANCY', 1, 48, 9999, 3, 5, 7, 10500, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11767, '2004-08-24 22:00:00+00', '2012-01-20 12:57:32.692888+00', 'Clan Reel, The', 'CLAN REEL', 1, 32, 9999, 1, 4, 1, 3446, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5677, '1997-09-12 22:00:00+00', '2019-03-11 11:13:45.426123+00', 'Roseberry Ridge', 'ROSEBERRY RIDGE', 1, 32, 9999, 1, 4, 1, 549, NULL, '', 91, '8484/8888/8888/8488', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11778, '2004-09-08 22:00:00+00', '2012-01-20 12:57:32.768875+00', 'Dancing in the Right Circles', 'DANCING IN THE RIGHT CIRCLES', 3, 72, 9999, 4, 4, NULL, 108, '2003-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14576, '2012-09-13 16:08:37.92057+00', '2012-09-16 21:40:36.967607+00', 'Miss Sarah Smiles', 'MISS SARAH SMILES', 3, 32, NULL, 1, 2, NULL, 10593, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18755, '2018-10-05 00:34:31.322276+00', '2018-10-05 00:41:22.585785+00', 'Flibbertigibbet', 'FLIBBERTIGIBBET', 3, 32, NULL, 1, 3, 42, 2766, '2009-02-01', '', 61, '644/484/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14592, '2012-10-08 08:24:30.377631+00', '2018-10-06 05:28:12.964827+00', 'Left of Center', 'LEFT OF CENTER', 2, 32, NULL, 1, 3, 42, 2766, '2009-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5724, '1997-11-27 23:00:00+00', '2012-01-20 12:56:44.93313+00', 'Rowallan Castle', 'ROWALLAN CASTLE', 4, 96, 11, 4, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14591, '2012-10-07 22:55:49.314205+00', '2018-10-09 06:39:03.829598+00', 'Sweet Surrender', 'SWEET SURRENDER', 3, 32, NULL, 1, 3, 42, 2766, '2010-03-01', 'Devised March 2010', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5686, '1997-11-27 23:00:00+00', '2019-02-24 23:32:07.335785+00', 'Rosette, The', 'ROSETTE', 4, 32, 1, 1, 3, 42, 128, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5665, '1997-09-12 22:00:00+00', '2012-01-20 12:56:44.517885+00', 'Rose of Achnashean, The', 'ROSE OF ACHNASHEAN', 3, 32, 9999, 1, 4, NULL, 318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5666, '1997-09-12 22:00:00+00', '2012-01-20 12:56:44.524715+00', 'Rose of Balvenie, The', 'ROSE OF BALVENIE', 3, 32, 9999, 1, 4, NULL, 680, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5662, '1997-09-12 22:00:00+00', '2019-04-29 16:41:04.332912+00', 'Rose And The Saltire, The', 'ROSE AND THE SALTIRE', 4, 32, 9999, 1, 3, 42, 3461, '1985-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5670, '1997-04-03 22:00:00+00', '2012-01-20 12:56:44.551985+00', 'Rose of the Glen', 'ROSE OF THE GLEN', 3, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5675, '2002-02-28 23:00:00+00', '2012-01-20 12:56:44.590549+00', 'Rose Valley Cottage', 'ROSE VALLEY COTTAGE', 4, 32, 1, 1, 4, NULL, 406, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5681, '1997-04-03 22:00:00+00', '2012-01-20 12:56:44.633054+00', 'Rosemary', 'ROSEMARY', 1, 40, 9999, 3, 5, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5683, '1998-07-08 22:00:00+00', '2012-01-20 12:56:44.647455+00', 'Roses Of Carterhaugh', 'ROSES OF CARTERHAUGH', 3, 32, 9999, 1, 4, 2, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5638, '1997-09-12 22:00:00+00', '2023-01-17 11:10:58.494102+00', 'Robertsons'' Anniversary', 'ROBERTSONS ANNIVERSARY', 3, 32, 9999, 1, 4, NULL, 792, NULL, 'Deviser''s recommended recording is "Blue Mess Jacket" by Rob Gordon from "Caledonian Ball Vol 2".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5684, '1997-04-03 22:00:00+00', '2012-01-20 12:56:44.654439+00', 'Rosetree, The', 'ROSETREE', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11783, '2004-09-08 22:00:00+00', '2012-01-20 12:57:32.806134+00', 'Ladybower Strathspey, The', 'LADYBOWER STRATHSPEY', 3, 32, 9999, 1, 4, 2, 108, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11775, '2004-09-08 22:00:00+00', '2017-11-07 17:18:21.572356+00', 'Line-Dance for Uncle, A', 'LINEDANCE FOR UNCLE', 1, 40, 9999, 1, 4, 2, 108, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11776, '2004-09-08 22:00:00+00', '2018-04-03 00:07:30.192198+00', '''Allo Vera!', 'ALLO VERA', 1, 32, 9999, 1, 3, 42, 108, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5649, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.467297+00', 'Roll Her on the Hill', 'ROLL HER ON THE HILL', 1, 48, 9999, 1, 3, 42, 108, '1971-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5653, '1997-09-12 22:00:00+00', '2018-04-03 00:08:13.50064+00', 'Ronas Voe', 'RONAS VOE', 2, 32, 9999, 1, 3, 42, 567, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5656, '2002-03-02 23:00:00+00', '2018-04-03 00:08:13.525714+00', 'Rory Dalls'' Harp', 'RORY DALLS HARP', 1, 32, 9999, 1, 3, 42, 267, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5663, '2002-04-19 22:00:00+00', '2018-04-03 00:08:13.550709+00', 'Rose and Thistle, The', 'ROSE AND THISTLE', 1, 32, 9999, 1, 3, 42, 1240, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5664, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.575732+00', 'Rose Garden Picnic', 'ROSE GARDEN PICNIC', 2, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5668, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.609039+00', 'Rose of Halftown, The', 'ROSE OF HALFTOWN', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5672, '1997-09-12 22:00:00+00', '2018-04-03 00:08:13.625764+00', 'Rose of the West', 'ROSE OF THE WEST', 2, 32, 9999, 1, 3, 42, 1241, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5689, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.659175+00', 'Ross House', 'ROSS HOUSE', 1, 48, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11768, '2004-08-29 22:00:00+00', '2018-04-03 00:08:17.278179+00', 'Skye Lights', 'SKYE LIGHTS', 1, 32, 9999, 1, 3, 42, 3447, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11786, '2004-09-08 22:00:00+00', '2012-01-20 12:57:32.82813+00', 'My Heavenly Twin', 'MY HEAVENLY TWIN', 1, 32, 9999, 1, 4, 2, 108, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11793, '2004-09-08 22:00:00+00', '2012-01-20 12:57:32.878029+00', 'Stainless Steel', 'STAINLESS STEEL', 1, 32, 9999, 1, 4, NULL, 108, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11789, '2004-09-08 22:00:00+00', '2013-03-21 23:00:26.630425+00', 'Planet Mars, The', 'PLANET MARS', 1, 32, 9999, 1, 4, 2, 108, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5694, '1997-09-02 22:00:00+00', '2012-01-20 12:56:44.723377+00', 'Fourteenth of September, 1992', 'FOURTEENTH OF SEPTEMBER 1992', 1, 48, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5695, '1998-07-08 22:00:00+00', '2012-01-20 12:56:44.730841+00', 'Rossie Moor Reel, The', 'ROSSIE MOOR REEL', 1, 32, 9999, 1, 4, 11, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5676, '1998-07-06 22:00:00+00', '2020-03-09 10:59:37.073471+00', 'Rose, The', 'ROSE', 3, 160, 9999, 3, 5, 3, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5650, '1997-04-03 22:00:00+00', '2020-09-03 10:37:11.343648+00', 'Rollright Reel, The', 'ROLLRIGHT REEL', 1, 32, 9999, 1, 3, 42, 89, NULL, '', 63, '888/888/880/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14589, '2012-10-07 08:16:43.589107+00', '2020-10-01 11:41:12.158461+00', 'Satin and Lace', 'SATIN AND LACE', 3, 32, NULL, 1, 3, 42, 2766, '2009-06-01', '', 44, '880/804/880/840', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14590, '2012-10-07 21:28:53.098249+00', '2020-10-01 11:45:24.436955+00', 'Lakewood High', 'LAKEWOOD HIGH', 1, 32, NULL, 1, 3, 42, 2766, '2009-06-01', '', 53, '480/880/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11788, '2004-09-08 22:00:00+00', '2021-01-19 22:06:25.587976+00', 'Palace of Atholl, The', 'PALACE OF ATHOLL', 2, 32, 9999, 1, 100, 2, 108, '2002-01-01', '', 75, '0880/8888/8448/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5661, '1998-07-08 22:00:00+00', '2021-04-18 20:04:35.564695+00', 'Rose and Crown, The', 'ROSE AND CROWN', 2, 32, 9999, 1, 4, 2, 304, '1988-01-01', '', 69, '8008/8008/8888/8448', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5687, '2002-02-11 23:00:00+00', '2021-04-21 20:25:46.867516+00', 'Roslin Castle', 'ROSLIN CASTLE', 1, 32, 9999, 1, 3, 42, 13, '1978-01-01', '', 47, '800/833/833/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5669, '1997-08-20 22:00:00+00', '2021-04-22 08:04:36.469651+00', 'Rose of Kilravock', 'ROSE OF KILRAVOCK', 3, 32, 9999, 1, 2, 76, 108, '1968-01-01', '', 69, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5700, '1997-09-12 22:00:00+00', '2012-01-20 12:56:44.764863+00', 'Rothesay Bay', 'ROTHESAY BAY', 3, 96, 9999, 4, 4, NULL, 250, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5701, '1998-10-05 22:00:00+00', '2012-01-20 12:56:44.771642+00', 'Rothesay Castle Medley', 'ROTHESAY CASTLE MEDLEY', 4, 104, 36, 1, 4, NULL, 476, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5705, '1998-04-19 22:00:00+00', '2012-01-20 12:56:44.798894+00', 'Rough Diamonds, The', 'ROUGH DIAMONDS', 1, 32, 9999, 1, 4, NULL, 1243, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5709, '1997-09-13 22:00:00+00', '2012-01-20 12:56:44.826354+00', 'Round About Our Coal Fire', 'ROUND ABOUT OUR COAL FIRE', 50, 32, 9999, 1, 2, NULL, 1245, '1766-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5714, '1997-09-13 22:00:00+00', '2012-01-20 12:56:44.86272+00', 'Round The Bend', 'ROUND THE BEND', 3, 32, 9999, 1, 4, NULL, 90, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5715, '1997-04-03 22:00:00+00', '2012-01-20 12:56:44.869512+00', 'Round We Go', 'ROUND WE GO', 3, 32, 9999, 7, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5716, '1997-09-13 22:00:00+00', '2012-01-20 12:56:44.876262+00', 'Round, The', 'ROUND', 1, 32, 9999, 1, 2, NULL, 446, '1703-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5718, '1997-09-13 22:00:00+00', '2012-01-20 12:56:44.889965+00', 'Roundabout', 'ROUNDABOUT', 2, 40, 9999, 1, 4, NULL, 666, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11794, '2004-09-08 22:00:00+00', '2012-01-20 12:57:32.885317+00', 'Starkers to Yarker''s', 'STARKERS TO YARKERS', 1, 40, 9999, 1, 4, NULL, 108, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11791, '2004-09-08 22:00:00+00', '2018-04-03 00:08:12.233057+00', 'Redun Dance', 'REDUN DANCE', 1, 32, 9999, 1, 3, 42, 108, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14579, '2012-10-02 09:23:23.880894+00', '2012-10-02 09:33:49.332137+00', 'Glasgow Dem Class, The', 'GLASGOW DEM CLASS', 2, 32, NULL, 1, 100, 2, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5729, '1997-09-13 22:00:00+00', '2012-01-20 12:56:44.968568+00', 'Rowans Jig, The', 'ROWANS JIG', 2, 32, 9999, 1, 2, NULL, 1247, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5737, '1997-09-13 22:00:00+00', '2012-01-20 12:56:45.023491+00', 'Royal Blackbird, The', 'ROYAL BLACKBIRD', 1, 40, 9999, 1, 4, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5739, '1997-04-03 22:00:00+00', '2012-01-20 12:56:45.037055+00', 'Royal Captives', 'ROYAL CAPTIVES', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5692, '1999-05-10 22:00:00+00', '2018-04-03 00:08:13.684121+00', 'Ross of Mull, The', 'ROSS OF MULL', 1, 32, 9999, 1, 3, 42, 2602, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5698, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.692485+00', 'Rotating Reel, The', 'ROTATING REEL', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5706, '1998-01-05 23:00:00+00', '2018-04-03 00:08:13.717494+00', 'Rough Wooing, The', 'ROUGH WOOING', 1, 32, 9999, 1, 3, 42, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5722, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.767585+00', 'Rover''s Return, The', 'ROVERS RETURN', 1, 32, 9999, 1, 3, 42, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5735, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.78411+00', 'Royal Archers', 'ROYAL ARCHERS', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5738, '1997-12-22 23:00:00+00', '2018-04-03 00:08:13.815546+00', 'Royal Burgh of Falkland', 'ROYAL BURGH OF FALKLAND', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5733, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.984209+00', 'Roy''s Wife', 'ROYS WIFE', 3, 32, 9999, 1, 3, 42, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11792, '2004-09-08 22:00:00+00', '2018-04-03 00:08:17.886996+00', 'Spanish Sunrise', 'SPANISH SUNRISE', 1, 32, 9999, 1, 3, 42, 108, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11825, '2004-10-21 22:00:00+00', '2018-05-17 09:31:24.584447+00', 'Hunting The Haggis', 'HUNTING THE HAGGIS', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 44, '800/844/844/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11790, '2004-09-08 22:00:00+00', '2022-09-23 16:00:46.43911+00', 'Poet and his Lass, The', 'POET AND HIS LASS', 3, 32, 9999, 2, 3, 18, 108, '2003-12-01', 'Inscribed "for Alan and Pat Dixon. A dance to mark tbeir 10th Wedding Anniversary".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11777, '2004-09-08 22:00:00+00', '2022-09-23 16:13:06.869345+00', 'Birlin'' Awa''', 'BIRLIN AWA', 1, 32, 9999, 1, 3, 42, 108, '2003-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11806, '2004-09-16 22:00:00+00', '2022-10-27 10:52:55.620279+00', 'Fair Maids of Lyon, The', 'FAIR MAIDS OF LYON', 2, 48, 9999, 4, 4, 4, 3454, '2003-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5685, '2000-04-25 22:00:00+00', '2022-11-12 18:34:49.332177+00', 'Rosetta Stone', 'ROSETTA STONE', 3, 32, 9999, 1, 3, 42, 576, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5680, '1997-09-12 22:00:00+00', '2022-11-12 18:38:36.272799+00', 'Rosedale Reel, The', 'ROSEDALE REEL', 1, 40, 9999, 1, 3, 42, 475, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5764, '1997-04-03 22:00:00+00', '2019-03-11 10:55:34.211604+00', 'Ruby Strathspey, The', 'RUBY STRATHSPEY', 3, 48, 9999, 1, 4, 1, 3550, '1994-01-01', '', 79, '8484/8844/8888/8448/4884/0888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5748, '1997-09-13 22:00:00+00', '2012-01-20 12:56:45.098229+00', 'Royal Prince, The', 'ROYAL PRINCE', 3, 40, 9999, 2, 3, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5782, '1997-04-03 22:00:00+00', '2018-04-03 00:08:14.284534+00', 'Ruth''s Rave', 'RUTHS RAVE', 3, 32, 9999, 1, 3, 42, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11826, '2004-10-31 23:00:00+00', '2020-01-26 08:27:01.448392+00', 'Norah Link, The', 'NORAH LINK', 1, 32, 9999, 1, 4, 2, 2677, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11623, '2003-12-04 23:00:00+00', '2020-05-29 23:23:55.103826+00', 'Buttermilk Falls', 'BUTTERMILK FALLS', 3, 32, 9999, 2, 3, 17, 2682, '1991-01-01', 'In an earlier version this was a 3C/4L dance.  The diagram shows the current 3C/3L version.', 100, '888/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11807, '2007-04-03 22:00:00+00', '2020-08-04 00:37:53.590664+00', 'David Findlay Jig, The', 'DAVID FINDLAY JIG', 2, 48, 9999, 1, 4, 11, 167, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5720, '1997-09-09 22:00:00+00', '2020-08-07 09:09:51.718297+00', 'Rounds of the Kitchen', 'ROUNDS OF THE KITCHEN', 1, 128, 9999, 4, 4, NULL, 1143, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11818, '2004-10-21 22:00:00+00', '2020-12-29 10:18:12.082186+00', 'Castlecary', 'CASTLECARY', 3, 32, 9999, 1, 4, 2, 13, NULL, '', 81, '8448/8888/8888/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11815, '2004-10-11 22:00:00+00', '2021-01-18 19:16:19.132237+00', 'Space Coaster', 'SPACE COASTER', 3, 32, 9999, 1, 4, 13, 2677, NULL, 'For James Kutzner, of Melbourne, FL.', 72, '8400/8044/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11812, '2004-09-16 22:00:00+00', '2021-01-19 11:15:52.508493+00', 'Glenside Welcome', 'GLENSIDE WELCOME', 3, 32, 9999, 5, 4, NULL, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11811, '2004-09-16 22:00:00+00', '2021-01-19 11:18:12.633458+00', 'Four Three Five Three', 'FOUR THREE FIVE THREE', 3, 32, 9999, 4, 4, 13, 2892, NULL, '', 75, '8888/6666/4848/8080', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11802, '2004-09-16 22:00:00+00', '2021-01-19 11:28:28.89518+00', 'Catherine''s Ceilidh', 'CATHERINES CEILIDH', 1, 32, 9999, 5, 2, NULL, 10495, '1999-01-01', '', 64, '88/88/88/66', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11801, '2004-09-16 22:00:00+00', '2021-01-19 11:31:29.167599+00', 'Austin Silver', 'AUSTIN SILVER', 3, 32, 9999, 3, 5, 7, 2924, '2000-01-01', '', 59, '80800/88888/80800/82822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11798, '2004-09-14 22:00:00+00', '2021-01-19 22:02:44.244377+00', 'Battle Creek Breeze', 'BATTLE CREEK BREEZE', 1, 32, 9999, 1, 3, 42, 3369, '2004-01-01', '', 50, '800/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11787, '2004-09-08 22:00:00+00', '2021-01-19 22:10:33.917243+00', 'Olive Tree, The', 'OLIVE TREE', 3, 32, 9999, 1, 3, 42, 108, '2002-01-01', '', 38, '880/800/822/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5727, '1997-04-03 22:00:00+00', '2021-01-23 23:33:09.100181+00', 'Rowan Tree, The', 'ROWAN TREE', 3, 32, 9999, 1, 2, 76, 28, NULL, '<<scddb-not-identical:5726;5728;14296>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5728, '1999-05-09 22:00:00+00', '2021-01-23 23:33:42.677774+00', 'Rowan Tree, The', 'ROWAN TREE', 3, 32, 9999, 3, 5, 7, 1309, NULL, '<<scddb-not-identical:5726;5727;14296>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5799, '1997-11-18 23:00:00+00', '2021-05-01 20:26:39.011069+00', 'St Andrew''s Cross', 'SAINT ANDREWS CROSS', 1, 136, 9999, 4, 4, 3, 9998, NULL, 'From the original description: "This is a Set dance arranged in honour of St Andrew, Patron Saint of Scotland - Collected in Elie, Fife."', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14596, '2012-10-15 22:50:10.622157+00', '2021-06-06 19:26:35.541567+00', 'Loch Effect', 'LOCH EFFECT', 2, 32, 9999, 4, 5, 35, 9998, '2005-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5717, '1997-09-13 22:00:00+00', '2021-04-20 18:47:34.051186+00', 'Roundabout', 'ROUNDABOUT', 2, 32, 9999, 1, 3, 42, 1244, NULL, '', 63, '565/888/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5704, '1998-09-17 22:00:00+00', '2021-04-20 19:39:32.87361+00', 'Rothiemurchus Rant', 'ROTHIEMURCHUS RANT', 3, 32, 9999, 1, 3, 42, 94, NULL, '', 59, '888/844/888/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5749, '1998-07-09 22:00:00+00', '2021-05-01 19:45:15.550951+00', 'Royal Salute, The', 'ROYAL SALUTE', 1, 112, 9999, 2, 3, 3, 9998, NULL, 'Composed in honour of the visit of Queen Victoria to Scotland, 1842.



Collected from Mrs A McLean of Vermont, USA, originally of Oban, Argyll.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5707, '1997-11-18 23:00:00+00', '2021-05-01 21:07:27.763894+00', 'Rouken Glen', 'ROUKEN GLEN', 3, 72, 9999, 1, 4, 3, 9998, NULL, '"Rouken Glen is one of the many beautiful public parks in Glasgow."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11810, '2004-09-16 22:00:00+00', '2012-10-31 14:54:01.883368+00', 'Four Scottish Moons', 'FOUR SCOTTISH MOONS', 2, 32, 9999, 1, 4, 1, 3774, NULL, 'From a Strathspey message on 18 Aug 1996 15:49:51 



Four Scottish Moons



4 couple , 32 Bars Jig



1-8  	First couple lead down the middle and back. Stay facing up.



9-16 	First couple cast behind own lines, turning towards each other dance back up behind own lines to the top.



17-24	First and Second couple dance four hands across and back.



25-28 	First couple cast to the bottom of the set, other couples move up.



29-32 	Second man and First lady advance and retire.





Bars 1-16 form the M , Bars 17-24 form the O O , Bars 25-32 form the N.

', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11817, '2004-10-21 22:00:00+00', '2018-04-03 00:07:32.130757+00', 'Banks and Braes', 'BANKS AND BRAES', 2, 32, 9999, 1, 3, 42, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5751, '1997-04-03 22:00:00+00', '2012-01-20 12:56:45.119439+00', 'Royal Sydney Reel', 'ROYAL SYDNEY REEL', 1, 40, 9999, 1, 4, NULL, 197, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14594, '2012-10-15 22:22:09.219494+00', '2014-10-28 14:00:31.459442+00', 'Stars, the Moon, and Three Ladies, The', 'STARS THE MOON AND THREE LADIES', 1, 32, 9999, 2, 53, 17, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5758, '1997-09-13 22:00:00+00', '2012-01-20 12:56:45.167026+00', 'Rubha Mor Strathspey, The', 'RUBHA MOR STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 429, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5760, '1998-07-08 22:00:00+00', '2012-01-20 12:56:45.181441+00', 'Ruby Celebration, A', 'RUBY CELEBRATION', 2, 32, 9999, 1, 4, 2, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5762, '1997-04-03 22:00:00+00', '2012-01-20 12:56:45.195065+00', 'Ruby Reel of Friendship, The', 'RUBY REEL OF FRIENDSHIP', 1, 32, 9999, 1, 4, NULL, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5767, '1997-09-13 22:00:00+00', '2012-01-20 12:56:45.229306+00', 'Rugby Reel', 'RUGBY REEL', 1, 48, 9999, 4, 4, NULL, 893, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5769, '1997-04-03 22:00:00+00', '2012-01-20 12:56:45.247752+00', 'Rumbling Bridge', 'RUMBLING BRIDGE', 2, 40, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5771, '1997-09-13 22:00:00+00', '2012-01-20 12:56:45.266302+00', 'Rumford Lilt, The', 'RUMFORD LILT', 2, 16, 9999, 1, 4, NULL, 928, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5778, '1997-04-03 22:00:00+00', '2012-01-20 12:56:45.326262+00', 'Rustington Reel, The', 'RUSTINGTON REEL', 1, 64, 9999, 4, 4, NULL, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5750, '1997-04-03 22:00:00+00', '2016-07-15 13:12:28.596574+00', 'Royal Standard, The', 'ROYAL STANDARD', 1, 32, 9999, 2, 3, 17, 352, '1992-10-11', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5740, '1997-08-25 22:00:00+00', '2018-04-03 00:08:13.882684+00', 'Royal Collection, The', 'ROYAL COLLECTION', 3, 32, 9999, 1, 3, 42, 108, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5743, '1997-09-13 22:00:00+00', '2018-04-03 00:08:13.925726+00', 'Royal Leamington Spa Strathspey', 'ROYAL LEAMINGTON SPA STRATHSPEY', 3, 32, 9999, 1, 3, 42, 706, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5747, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.942457+00', 'Royal Palace, The', 'ROYAL PALACE', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5753, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.950728+00', 'Royal Treatment, The', 'ROYAL TREATMENT', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5756, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.967453+00', 'Royal York Strathspey', 'ROYAL YORK STRATHSPEY', 3, 32, 9999, 1, 3, 42, 213, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5761, '1997-04-03 22:00:00+00', '2018-04-03 00:08:14.009229+00', 'Ruby Reel Of Hastings, The', 'RUBY REEL OF HASTINGS', 1, 32, 9999, 1, 3, 42, 275, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5770, '1997-09-13 22:00:00+00', '2018-04-03 00:08:14.092773+00', 'Rumbling Jig, The', 'RUMBLING JIG', 2, 48, 9999, 1, 3, 42, 456, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5774, '1997-09-13 22:00:00+00', '2018-04-03 00:08:14.209652+00', 'Rural Sports', 'RURAL SPORTS', 1, 64, 9999, 1, 3, 42, 198, '1748-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5742, '1997-09-14 22:00:00+00', '2018-04-03 00:08:16.094018+00', 'Sharon''s Star', 'SHARONS STAR', 1, 32, 9999, 1, 3, 42, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5745, '2002-05-06 22:00:00+00', '2018-04-03 00:08:16.185649+00', 'Shepherd''s Fancy', 'SHEPHERDS FANCY', 1, 32, 9999, 1, 3, 42, 200, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11803, '2004-09-16 22:00:00+00', '2023-01-13 22:54:32.833065+00', 'Celebration Seven, The', 'CELEBRATION SEVEN', 1, 32, 9999, 6, 112, 30, 9998, NULL, 'Dance for 3 couples and 1 man.  The W stay in the triangle. the M progress taking the middle place in turn.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14581, '2012-10-02 09:39:45.459676+00', '2012-10-02 09:39:45.459687+00', 'Half Dozen Medley, The', 'HALF DOZEN MEDLEY', 4, 288, 59, 4, 6, 51, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5779, '1997-09-13 22:00:00+00', '2012-01-20 12:56:45.333027+00', 'Ruth And Carol''s Reel', 'RUTH AND CAROLS REEL', 1, 32, 9999, 1, 2, NULL, 1077, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5781, '1997-09-13 22:00:00+00', '2012-01-20 12:56:45.346651+00', 'Ruth and John''s Wedding', 'RUTH AND JOHNS WEDDING', 2, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5783, '1997-04-03 22:00:00+00', '2012-01-20 12:56:45.360147+00', 'Ruthven House', 'RUTHVEN HOUSE', 3, 24, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19014, '2018-10-19 14:55:26.725622+00', '2018-10-20 10:43:59.437172+00', 'Catherine''s Favourite', 'CATHERINES FAVOURITE', 1, 32, NULL, 1, 3, 42, 11734, NULL, '', 63, '888/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11834, '2004-10-31 23:00:00+00', '2018-04-03 00:08:13.558937+00', 'Rose By Any Other, A', 'ROSE BY ANY OTHER', 3, 32, 9999, 1, 3, 42, 2961, NULL, 'Devised: 2002', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5789, '1997-09-13 22:00:00+00', '2012-01-20 12:56:45.400733+00', 'Sage Leaf', 'SAGE LEAF', 2, 128, 9999, 5, 4, NULL, 446, '1670-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5790, '1997-04-03 22:00:00+00', '2012-01-20 12:56:45.407601+00', 'Sail City', 'SAIL CITY', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5791, '1997-09-13 22:00:00+00', '2012-01-20 12:56:45.414349+00', 'Sailing to Liberty', 'SAILING TO LIBERTY', 2, 32, 9999, 1, 4, NULL, 108, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5793, '1997-04-03 22:00:00+00', '2012-01-20 12:56:45.428+00', 'Sailor''s Wife, The', 'SAILORS WIFE', 2, 32, 9999, 1, 2, NULL, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11819, '2004-10-21 22:00:00+00', '2020-12-29 11:16:55.044119+00', 'Chanronry Chase', 'CHANRONRY CHASE', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 59, '888/844/888/840', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6910, '2001-05-03 22:00:00+00', '2020-03-09 01:20:50.971761+00', 'Wallace''s Revolution', 'WALLACES REVOLUTION', 2, 32, 9999, 1, 4, 1, 270, NULL, '', 97, '7777/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5772, '1997-09-13 22:00:00+00', '2021-05-30 21:06:37.331906+00', 'Runes, The', 'RUNES', 2, 32, 9999, 1, 3, 42, 352, '1990-09-30', '', 63, '808/888/888/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11823, '2004-10-21 22:00:00+00', '2020-12-29 18:12:02.055151+00', 'Loup of Fintry, The', 'LOUP OF FINTRY', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 61, '864/884/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11820, '2004-10-21 22:00:00+00', '2020-12-29 20:46:55.974363+00', 'Skerryvore Light, The', 'SKERRYVORE LIGHT', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 50, '800/844/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11824, '2004-10-21 22:00:00+00', '2020-12-30 11:57:35.603591+00', 'Lichtsome Lindsays, The', 'LICHTSOME LINDSAYS', 3, 80, 9999, 4, 4, 3, 13, NULL, '', 85, '8888/8080/8888/8484/0808/8888/4848/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11835, '2005-01-19 23:00:00+00', '2021-01-18 19:08:26.492024+00', 'Left About', 'LEFT ABOUT', 2, 32, 9999, 1, 3, 42, 2479, NULL, '', 50, '800/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11832, '2005-01-19 23:00:00+00', '2021-01-18 19:11:00.495032+00', 'Kelpie from Wishaw', 'KELPIE FROM WISHAW', 3, 32, 9999, 1, 4, 2, 729, NULL, '', 81, '8888/8888/8448/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11809, '2004-09-16 22:00:00+00', '2021-01-19 11:20:37.351878+00', 'Fortrose Frolic', 'FORTROSE FROLIC', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 44, '440/448/448/448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5763, '1997-09-13 22:00:00+00', '2021-04-17 10:47:22.761282+00', 'Ruby Reel, The', 'RUBY REEL', 1, 40, 9999, 1, 3, 42, 291, '1987-01-01', '', 56, '820/888/888/844/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5744, '1998-04-19 22:00:00+00', '2021-04-20 16:49:21.206852+00', 'Royal Mile, The', 'ROYAL MILE', 2, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', 69, '888/888/888/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5773, '1997-09-13 22:00:00+00', '2021-09-27 20:45:45.672944+00', 'Running The Bulls', 'RUNNING THE BULLS', 2, 32, 9999, 1, 3, 42, 304, '1988-01-01', '', 59, '800/888/888/884', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5792, '1997-04-03 22:00:00+00', '2018-04-03 00:08:14.392974+00', 'Sailor Scotty', 'SAILOR SCOTTY', 3, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5805, '1998-07-08 22:00:00+00', '2012-01-20 12:56:45.539035+00', 'Saint Andrew''s Jig', 'SAINT ANDREWS JIG', 2, 32, 9999, 1, 4, 2, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5786, '1997-08-17 22:00:00+00', '2014-04-29 15:24:59.892715+00', 'S. S. Johnstone', 'S S JOHNSTONE', 3, 32, 9999, 1, 3, 42, 200, NULL, '', 53, '880  808  808  866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11836, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.196011+00', 'Dancing with Deidre', 'DANCING WITH DEIDRE', 2, 32, 9999, 1, 2, NULL, 2961, NULL, 'Devised: 2003', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11838, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.208837+00', 'Deby''s Two-Step', 'DEBYS TWOSTEP', 1, 32, 9999, 5, 2, NULL, 2961, NULL, 'Devised: 2003

Step: walking step', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11840, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.220957+00', 'Elgin''s Strathspey', 'ELGINS STRATHSPEY', 3, 32, 9999, NULL, 3, NULL, 2961, NULL, 'Devised: 2003', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11841, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.227735+00', 'Feline Footprints', 'FELINE FOOTPRINTS', 3, 32, 9999, 4, 4, NULL, 2961, NULL, 'Devised: 2002', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11844, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.246701+00', 'Gemmie''s Jig', 'GEMMIES JIG', 2, 32, 9999, NULL, 3, NULL, 3498, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11845, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.252856+00', 'Golden Fyrebird', 'GOLDEN FYREBIRD', 2, 32, 9999, NULL, 3, NULL, 2961, NULL, 'Devised: 2003', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11846, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.259073+00', 'Hauole Ha A''', 'HAUOLE HA A', 1, 32, 9999, NULL, 3, NULL, 2961, NULL, 'Devised:2003', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11847, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.265196+00', 'Isle of Kaui', 'ISLE OF KAUI', 3, 32, 9999, NULL, 3, NULL, 2961, NULL, 'Devised: 2000', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5813, '2002-04-19 22:00:00+00', '2018-04-03 00:08:14.476345+00', 'Saint Andrew''s Strathspey', 'SAINT ANDREWS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 222, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5811, '1997-09-13 22:00:00+00', '2012-01-20 12:56:45.592074+00', 'Saint Andrew''s Reel', 'SAINT ANDREWS REEL', 1, 48, 9999, 4, 4, NULL, 570, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5814, '1997-04-03 22:00:00+00', '2012-01-20 12:56:45.618177+00', 'Saint Andrews', 'SAINT ANDREWS', 1, 64, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5815, '1997-04-03 22:00:00+00', '2012-01-20 12:56:45.626855+00', 'Saint Andrews by the Sea', 'SAINT ANDREWS BY THE SEA', 3, 32, 9999, 1, 2, NULL, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5816, '1997-04-03 22:00:00+00', '2012-01-20 12:56:45.635513+00', 'Saint Andrews Suite', 'SAINT ANDREWS SUITE', 4, 0, 9999, 1, 4, NULL, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5822, '1997-11-27 23:00:00+00', '2015-09-21 06:45:34.941441+00', 'Saint Dunstan''s Dance', 'SAINT DUNSTANS DANCE', 4, 64, 5, 4, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5820, '1997-11-17 23:00:00+00', '2018-04-03 00:08:14.509779+00', 'Saint Connal''s Well', 'SAINT CONNALS WELL', 1, 32, 9999, 1, 3, 42, 132, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11842, '2004-10-31 23:00:00+00', '2015-11-12 00:06:29.892192+00', 'Five, Oh!', 'FIVE OH', 2, 48, 9999, 4, 5, 6, 3441, NULL, 'Written to celebrate Suzanne Bailey''s 50th birthday.

Devised: 2000

Tune: from suggested recording', 62, '88888/40408/04048/80808/08088/48448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5797, '1997-04-03 22:00:00+00', '2016-02-15 12:47:45.634738+00', 'St Aidan''s Old Hall', 'SAINT AIDANS OLD HALL', 3, 32, 9999, 1, 4, 1, 411, NULL, '', 72, '8642/8888/8888/8000', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11843, '2004-10-31 23:00:00+00', '2016-05-12 22:12:02.261336+00', 'Fiveness', 'FIVENESS', 1, 32, 9999, 107, 55, NULL, 3458, NULL, 'For 5 dancers in a U shape.   Devised: 1975', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5784, '1997-09-13 22:00:00+00', '2018-04-03 00:08:14.893217+00', 'S and M Reel', 'S AND M REEL', 1, 32, 9999, 1, 3, 42, 1257, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5780, '1997-12-28 23:00:00+00', '2018-04-03 00:08:16.335765+00', 'Shivaree or The Wedding Knot', 'SHIVAREE OR THE WEDDING KNOT', 1, 40, 9999, 1, 3, 42, 737, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5785, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.27064+00', 'S''s Math Sin', 'SS MATH SIN', 1, 40, 9999, 1, 3, 42, 329, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11833, '2004-10-31 23:00:00+00', '2018-04-03 00:08:25.375287+00', 'Whisper of the FyreDragon', 'WHISPER OF THE FYREDRAGON', 1, 32, 9999, 1, 3, 42, 2961, NULL, 'Devised: 2003', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5827, '1997-09-13 22:00:00+00', '2012-01-20 12:56:45.735376+00', 'Saint George''s Day', 'SAINT GEORGES DAY', 3, 32, 9999, 1, 4, NULL, 1248, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14595, '2012-10-15 22:28:32.757067+00', '2022-08-07 11:26:46.601052+00', 'Saint Ann Strathspey, The', 'SAINT ANN STRATHSPEY', 3, 32, 9999, 6, 53, 18, 9998, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5796, '1997-04-03 22:00:00+00', '2022-11-07 21:48:39.687096+00', 'St. Abb''s Head', 'SAINT ABBS HEAD', 3, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5810, '1997-11-24 23:00:00+00', '2022-11-07 21:48:52.600707+00', 'St. Andrew''s Pier', 'SAINT ANDREWS PIER', 4, 80, 10, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5833, '1998-04-19 22:00:00+00', '2012-01-20 12:56:45.791144+00', 'Saint Kentigern', 'SAINT KENTIGERN', 3, 32, 9999, 1, 2, NULL, 121, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5834, '1997-04-03 22:00:00+00', '2012-01-20 12:56:45.799968+00', 'Saint Kilda', 'SAINT KILDA', 3, 32, 9999, 5, 4, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11848, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.271253+00', 'Julee''s Jig', 'JULEES JIG', 2, 32, 9999, NULL, 3, NULL, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11849, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.277369+00', 'Marian''s Jig', 'MARIANS JIG', 2, 32, 9999, NULL, 3, NULL, 1395, NULL, 'Devised: 1995', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11853, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.303788+00', 'Passing Places', 'PASSING PLACES', 1, 32, 9999, 1, 4, NULL, 3499, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11854, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.309911+00', 'Rob Roy''s Sporran', 'ROB ROYS SPORRAN', 2, 32, 9999, NULL, 3, NULL, 3500, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11856, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.322693+00', 'Start Without Me', 'START WITHOUT ME', 2, 32, NULL, 1, 2, NULL, 2961, NULL, 'Devised: 2004', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11857, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.329474+00', 'Suzy Celebrates', 'SUZY CELEBRATES', 3, 32, 9999, 1, 4, NULL, 3502, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5862, '1998-04-19 22:00:00+00', '2019-03-10 19:16:39.228881+00', 'Salut Angers', 'SALUT ANGERS', 4, 64, 5, 4, 4, 11, 1253, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11859, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.342966+00', 'Tigger Love', 'TIGGER LOVE', 3, 32, 9999, 2, 3, NULL, 2961, NULL, 'Devised: 2003', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11860, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.349732+00', 'Twa Men of Lewis', 'TWA MEN OF LEWIS', 1, 32, 9999, 1, 2, NULL, 2961, NULL, 'Devised: 2003', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5857, '1997-04-03 22:00:00+00', '2019-03-10 19:20:35.987886+00', 'Sally Gardens', 'SALLY GARDENS', 3, 32, 9999, 1, 4, 1, 270, NULL, '', 94, '8888/4884/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5835, '1997-04-03 22:00:00+00', '2019-03-10 19:24:01.724561+00', 'Saint Lawrence Court, The', 'SAINT LAWRENCE COURT', 1, 40, 9999, 1, 4, 2, 153, NULL, '', 60, '4444/4444/8888/8008/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5846, '1997-08-26 22:00:00+00', '2019-04-23 11:31:44.715885+00', 'Saint Ninian''s Treasure', 'SAINT NINIANS TREASURE', 2, 32, 9999, 1, 3, 18, 567, '1979-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5819, '1997-09-13 22:00:00+00', '2020-08-07 09:39:46.664582+00', 'Saint Columban Reel', 'SAINT COLUMBAN REEL', 2, 96, 9999, 4, 98, NULL, 151, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5798, '1997-08-25 22:00:00+00', '2021-04-19 22:59:33.972871+00', 'Saint Andrew''s Course', 'SAINT ANDREWS COURSE', 2, 32, 9999, 1, 3, 42, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Andrew Cockett of London.', 56, '888/808/880/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5809, '1997-04-03 22:00:00+00', '2021-05-05 21:26:51.850761+00', 'St Andrew''s Parade', 'SAINT ANDREWS PARADE', 1, 48, 9999, 1, 4, 4, 270, NULL, '', 79, '6666/5555/6666/5555/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5841, '1997-09-13 22:00:00+00', '2019-09-13 16:55:22.082686+00', 'St. Martin''s Lane', 'SAINT MARTINS LANE', 1, 56, 9999, 2, 3, NULL, 446, '1696-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11862, '2005-03-03 23:00:00+00', '2018-04-03 00:08:02.175391+00', 'Mariner''s Strathspey, The', 'MARINERS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 9, '1987-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5845, '1998-07-08 22:00:00+00', '2012-01-20 12:56:45.897686+00', 'Saint Ninian''s Isle', 'SAINT NINIANS ISLE', 3, 32, 9999, 1, 4, 2, 199, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5850, '1997-09-13 22:00:00+00', '2012-01-20 12:56:45.941117+00', 'Saint Ronan''s Well', 'SAINT RONANS WELL', 3, 32, 9999, 2, 3, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5855, '1997-09-13 22:00:00+00', '2012-01-20 12:56:45.985339+00', 'Salamanca', 'SALAMANCA', 3, 32, 9999, 1, 4, NULL, 602, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11851, '2004-10-31 23:00:00+00', '2018-04-03 00:08:02.950841+00', 'Megan''s Feet', 'MEGANS FEET', 3, 32, 9999, 1, 3, 42, 2961, NULL, 'Devised: 2003', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5861, '1997-09-13 22:00:00+00', '2012-01-20 12:56:46.037586+00', 'Saltire, The', 'SALTIRE', 2, 64, 9999, 1, 4, NULL, 108, '1971-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11865, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.392937+00', 'With A Fifth Plus One', 'WITH A FIFTH PLUS ONE', 1, 32, 9999, 6, 3, NULL, 2961, NULL, 'Devised: 2003', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11870, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.439046+00', 'Lockerbie Manor', 'LOCKERBIE MANOR', 3, 32, 9999, 1, 4, 2, 479, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11871, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.447928+00', 'Visit to Burns'' Country, A', 'VISIT TO BURNS COUNTRY', 3, 32, 9999, 2, 3, NULL, 479, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11869, '2004-10-31 23:00:00+00', '2018-04-03 00:08:19.2881+00', 'Sunset in Seattle', 'SUNSET IN SEATTLE', 3, 32, 9999, 1, 3, 42, 479, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11867, '2004-10-31 23:00:00+00', '2018-04-03 00:08:12.283089+00', 'Reel for Anselm, A', 'REEL FOR ANSELM', 1, 40, 9999, 1, 3, 42, 479, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5849, '1997-09-13 22:00:00+00', '2018-04-03 00:08:14.634777+00', 'Saint Patrick''s Zeal', 'SAINT PATRICKS ZEAL', 4, 32, 9999, 1, 3, 42, 325, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5851, '1997-04-03 22:00:00+00', '2018-04-03 00:08:14.659771+00', 'Saint Valentine Strathspey', 'SAINT VALENTINE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5922, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.151715+00', 'Scotch Corner', 'SCOTCH CORNER', 2, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11868, '2004-10-31 23:00:00+00', '2018-04-03 00:08:15.668891+00', 'September in Seattle', 'SEPTEMBER IN SEATTLE', 1, 32, 9999, 1, 3, 42, 479, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11855, '2004-10-31 23:00:00+00', '2018-04-03 00:08:18.203966+00', 'Springtime Reel', 'SPRINGTIME REEL', 1, 32, 9999, 1, 3, 42, 3501, NULL, 'Tune: from suggested recording', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5826, '1997-09-13 22:00:00+00', '2018-04-03 00:08:18.479101+00', 'St Fillan''s Day', 'SAINT FILLANS DAY', 3, 32, 9999, 1, 3, 42, 108, '1987-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11858, '2004-10-31 23:00:00+00', '2018-04-03 00:08:19.830178+00', 'Tam the Storyteller', 'TAM THE STORYTELLER', 2, 32, 9999, 1, 3, 42, 2961, NULL, 'Devised: 2003', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11861, '2004-10-31 23:00:00+00', '2018-04-03 00:08:24.649822+00', 'Wee Stane Hoose', 'WEE STANE HOOSE', 2, 32, 9999, 1, 3, 42, 2961, NULL, 'Devised: 2003', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11863, '2004-10-31 23:00:00+00', '2018-04-03 00:08:26.151234+00', 'Winding River Reel', 'WINDING RIVER REEL', 1, 32, 9999, 1, 3, 42, 3503, NULL, 'Tune: from suggested recording', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11864, '2004-10-31 23:00:00+00', '2018-04-03 00:08:26.615601+00', 'Winter Vacation', 'WINTER VACATION', 2, 32, 9999, 1, 3, 42, 3504, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5866, '2002-05-26 22:00:00+00', '2012-01-20 12:56:46.081919+00', 'Salute to Halifax', 'SALUTE TO HALIFAX', 1, 32, 9999, 1, 4, NULL, 197, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5869, '2002-05-26 22:00:00+00', '2012-01-20 12:56:46.108045+00', 'Salute to Ms Millie Gunn', 'SALUTE TO MS MILLIE GUNN', 3, 32, 9999, 99, 99, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5870, '1997-04-03 22:00:00+00', '2012-01-20 12:56:46.116677+00', 'Salute To Rowallan', 'SALUTE TO ROWALLAN', 1, 48, 9999, 1, 4, NULL, 65, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5871, '1997-04-03 22:00:00+00', '2012-01-20 12:56:46.125667+00', 'Salute To Shieldaig', 'SALUTE TO SHIELDAIG', 1, 72, 9999, 1, 4, NULL, 192, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5873, '1997-09-13 22:00:00+00', '2012-01-20 12:56:46.143851+00', 'Salute To Susan', 'SALUTE TO SUSAN', 3, 40, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5874, '1998-07-08 22:00:00+00', '2012-01-20 12:56:46.153341+00', 'Salute To The Ottawa Branch', 'SALUTE TO THE OTTAWA BRANCH', 3, 32, 9999, 1, 4, 2, 1133, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5864, '2002-05-26 22:00:00+00', '2019-01-12 23:46:26.796098+00', 'Salute to Ayr Branch', 'SALUTE TO AYR BRANCH', 2, 32, 9999, 1, 3, 42, 640, NULL, '', 56, '844/844/888/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5880, '1997-09-13 22:00:00+00', '2012-01-20 12:56:46.205465+00', 'Sandhills Of Gaza', 'SANDHILLS OF GAZA', 1, 32, 9999, 8, 6, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5854, '1997-04-03 22:00:00+00', '2022-08-19 08:37:04.417047+00', 'Sair Saint, The', 'SAIR SAINT', 3, 32, 9999, 1, 3, 42, 35, NULL, 'According to the dance notes "King David I, was commonly called ''The Sair Saint'' because of his piousness."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5837, '1997-09-13 22:00:00+00', '2022-11-06 21:52:42.546154+00', 'Saint Maelrubba of Applecross', 'SAINT MAELRUBBA OF APPLECROSS', 4, 192, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5844, '1997-04-03 22:00:00+00', '2022-11-07 21:49:13.256439+00', 'St. Ninian''s Isle', 'SAINT NINIANS ISLE', 1, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5787, '1997-04-03 22:00:00+00', '2022-11-12 12:26:09.821938+00', 'Saddle the Pony', 'SADDLE THE PONY', 2, 32, 9999, 1, 3, 42, 270, NULL, '', 63, '880/888/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5800, '1998-09-29 22:00:00+00', '2022-11-30 10:27:37.097798+00', 'Saint Andrew''s Day', 'SAINT ANDREWS DAY', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 44, '880/800/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5881, '1997-09-13 22:00:00+00', '2012-01-20 12:56:46.214096+00', 'Sandra Of Ellerslie', 'SANDRA OF ELLERSLIE', 1, 32, 9999, 1, 2, NULL, 477, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5886, '1998-07-08 22:00:00+00', '2012-01-20 12:56:46.25849+00', 'Sandy Braes', 'SANDY BRAES', 1, 32, 9999, 1, 4, 2, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5887, '1997-09-13 22:00:00+00', '2012-01-20 12:56:46.267124+00', 'Sandy Duff', 'SANDY DUFF', 1, 32, 9999, 7, 56, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11875, '2004-10-31 23:00:00+00', '2012-01-20 12:57:33.483902+00', 'Kokushikan Scottish Dancers', 'KOKUSHIKAN SCOTTISH DANCERS', 2, 32, 9999, 1, 2, NULL, 479, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5867, '2002-05-26 22:00:00+00', '2018-04-02 23:56:37.502503+00', 'Salute to Jim Macleod', 'SALUTE TO JIM MACLEOD', 2, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11877, '2004-11-01 23:00:00+00', '2012-01-20 12:57:33.500828+00', 'Strictly Scottish', 'STRICTLY SCOTTISH', 1, 48, 9999, 4, 6, NULL, 531, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11880, '2004-11-01 23:00:00+00', '2012-01-20 12:57:33.527397+00', 'Hedgehogs in the Garden', 'HEDGEHOGS IN THE GARDEN', 2, 32, 9999, 1, 2, NULL, 1445, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11881, '2004-11-01 23:00:00+00', '2012-01-20 12:57:33.536222+00', 'Birds and the Isles, The', 'BIRDS AND THE ISLES', 3, 32, 9999, 1, 4, NULL, 1445, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5902, '1997-09-13 22:00:00+00', '2020-09-03 14:01:54.411124+00', 'Saturday Morning', 'SATURDAY MORNING', 2, 32, 9999, 1, 2, 76, 1077, NULL, '', 47, '55/55/80/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11874, '2004-10-31 23:00:00+00', '2021-01-18 19:01:49.776643+00', 'Rampant Unicorn Jig, The', 'RAMPANT UNICORN JIG', 2, 32, 9999, 1, 3, 42, 479, '2003-10-01', 'Devised: 2003-10', 56, '880/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5865, '2002-05-26 22:00:00+00', '2021-04-17 10:26:17.919254+00', 'Salute to Bath', 'SALUTE TO BATH', 1, 40, 9999, 2, 3, 17, 304, '1987-01-01', '', 70, '880/888/888/822/800', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5840, '2002-02-12 23:00:00+00', '2021-04-19 21:14:25.577256+00', 'Saint Mark''s Celebration Jig', 'SAINT MARKS CELEBRATION JIG', 2, 32, 9999, 1, 3, 42, 368, NULL, '', 53, '822/888/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5839, '1997-09-13 22:00:00+00', '2021-04-19 21:22:01.328503+00', 'Saint Margaret''s Loch', 'SAINT MARGARETS LOCH', 3, 32, 9999, 1, 3, 42, 1252, NULL, '', 53, '880/844/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5836, '1998-11-02 23:00:00+00', '2021-04-19 21:43:52.642408+00', 'Saint Lawrence Jig, The', 'SAINT LAWRENCE JIG', 2, 32, 9999, 1, 3, 42, 118, '1988-01-01', '', 50, '840/888/844/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5825, '1997-08-26 22:00:00+00', '2021-05-08 22:30:39.748643+00', 'Saint Edmund Strathspey, The', 'SAINT EDMUND STRATHSPEY', 3, 32, 9999, 1, 3, 42, 57, '1973-01-01', '', 69, '888/888/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11882, '2004-11-01 23:00:00+00', '2012-01-20 12:57:33.544963+00', 'Polish Petronella, A', 'POLISH PETRONELLA', 1, 32, 9999, 1, 2, NULL, 1445, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11886, '2004-11-01 23:00:00+00', '2012-01-20 12:57:33.580264+00', 'Brown Eyed Lassie, The', 'BROWN EYED LASSIE', 5, 32, 9999, 1, 2, NULL, 1445, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5899, '1997-11-25 23:00:00+00', '2012-01-20 12:56:46.384057+00', 'Saskatchewan Reel, The', 'SASKATCHEWAN REEL', 1, 32, 9999, 1, 4, NULL, 1259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11883, '2004-11-01 23:00:00+00', '2018-04-03 00:07:29.461651+00', 'Abbey of Saint Peter, The', 'ABBEY OF SAINT PETER', 3, 32, 9999, 1, 3, 42, 1445, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5903, '1997-04-03 22:00:00+00', '2012-01-20 12:56:46.418765+00', 'Saturday Strathspey, The', 'SATURDAY STRATHSPEY', 3, 24, 9999, 1, 2, NULL, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11888, '2004-11-01 23:00:00+00', '2018-04-03 00:07:44.419153+00', 'Elphinstones of Orkney, The', 'ELPHINSTONES OF ORKNEY', 3, 32, 9999, 1, 3, 42, 1445, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5909, '1998-01-05 23:00:00+00', '2012-01-20 12:56:46.48605+00', 'Say Goodnight, Wilma', 'SAY GOODNIGHT WILMA', 1, 48, 9999, 3, 5, NULL, 1262, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5912, '1997-04-03 22:00:00+00', '2012-01-20 12:56:46.513517+00', 'Scarlet Ribbons', 'SCARLET RIBBONS', 3, 32, 9999, 1, 4, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5914, '1998-01-05 23:00:00+00', '2012-01-20 12:56:46.531508+00', 'Scheessel Reel, The', 'SCHEESSEL REEL', 1, 128, 9999, 4, 4, NULL, 311, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5916, '1997-04-03 22:00:00+00', '2012-01-20 12:56:46.550368+00', 'Schoolmaster, The', 'SCHOOLMASTER', 2, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5920, '1997-04-03 22:00:00+00', '2012-01-20 12:56:46.586887+00', 'Scotch Broth', 'SCOTCH BROTH', 1, 32, 9999, 1, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11889, '2004-11-01 23:00:00+00', '2012-01-20 12:57:33.609029+00', 'Highland Fun', 'HIGHLAND FUN', 1, 128, 9999, 4, 4, NULL, 1445, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5863, '2002-12-07 23:00:00+00', '2018-04-03 00:08:14.776572+00', 'Salute Red Cross', 'SALUTE RED CROSS', 1, 32, 9999, 1, 3, 42, 43, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11876, '2004-10-31 23:00:00+00', '2015-03-30 00:49:41.439245+00', 'Shipwreck, The', 'SHIPWRECK', 4, 48, 61, 3, 5, NULL, 479, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5876, '1997-04-03 22:00:00+00', '2018-04-03 00:08:14.85146+00', 'Sam''s Welcome', 'SAMS WELCOME', 1, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5879, '1997-04-03 22:00:00+00', '2018-04-03 00:08:14.868258+00', 'Sanday', 'SANDAY', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5877, '2003-01-28 23:00:00+00', '2018-04-03 00:08:14.884886+00', 'San Diego Jig, The', 'SAN DIEGO JIG', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5883, '1997-09-13 22:00:00+00', '2018-04-03 00:08:14.918253+00', 'Sands of Culbin', 'SANDS OF CULBIN', 2, 32, 9999, 1, 3, 42, 153, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5891, '1997-04-03 22:00:00+00', '2018-04-03 00:08:14.943221+00', 'Sandy''s Farewell', 'SANDYS FAREWELL', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5892, '1997-09-13 22:00:00+00', '2018-04-03 00:08:14.951596+00', 'Sandy''s Favourite', 'SANDYS FAVOURITE', 1, 32, 9999, 1, 3, 42, 601, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5895, '1997-09-13 22:00:00+00', '2018-04-03 00:08:15.001586+00', 'Sarah Elizabeth', 'SARAH ELIZABETH', 3, 32, 9999, 1, 3, 42, 249, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5896, '1997-09-13 22:00:00+00', '2018-04-03 00:08:15.009907+00', 'Sarah''s Delight', 'SARAHS DELIGHT', 1, 32, 9999, 1, 3, 42, 1258, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5901, '1997-11-17 23:00:00+00', '2018-04-03 00:08:15.034927+00', 'Sassenach''s Rant', 'SASSENACHS RANT', 2, 40, 9999, 1, 3, 42, 300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5910, '1997-09-13 22:00:00+00', '2018-04-03 00:08:15.085021+00', 'Scalloway Bay', 'SCALLOWAY BAY', 2, 32, 9999, 1, 3, 42, 249, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5913, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.101746+00', 'Scented Garden, The', 'SCENTED GARDEN', 2, 32, 9999, 1, 3, 42, 44, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5918, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.1267+00', 'Scolty', 'SCOLTY', 3, 32, 9999, 1, 3, 42, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5940, '1997-12-22 23:00:00+00', '2018-04-29 10:14:19.038621+00', 'Scots Guard, The', 'SCOTS GUARD', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5894, '1997-04-03 22:00:00+00', '2018-04-02 23:56:37.545724+00', 'Sarah Anne Cheyne', 'SARAH ANNE CHEYNE', 2, 32, 9999, 1, 3, 42, 129, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11900, '2004-11-10 23:00:00+00', '2012-01-20 12:57:33.735156+00', 'Miss Betty Askew', 'MISS BETTY ASKEW', 4, 128, 2, 4, 4, NULL, 1228, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11901, '2004-11-10 23:00:00+00', '2012-01-20 12:57:33.742857+00', 'Morris MacBeth', 'MORRIS MACBETH', 1, 88, 9999, 1, 4, NULL, 1228, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14586, '2012-10-02 09:54:58.02176+00', '2012-10-02 09:54:58.02177+00', 'Gillistair Frewan', 'GILLISTAIR FREWAN', 4, 128, 2, 1, 100, 2, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18397, '2018-07-13 10:02:07.11607+00', '2018-07-13 16:34:07.578777+00', 'Teacher''s Daily Routine', 'TEACHERS DAILY ROUTINE', 1, 32, NULL, 4, 55, NULL, 11660, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11905, '2004-11-22 23:00:00+00', '2018-04-03 00:07:59.331562+00', 'Len''s Fancy', 'LENS FANCY', 2, 32, 9999, 1, 3, 42, 3771, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5928, '1997-09-13 22:00:00+00', '2019-03-10 19:07:26.025328+00', 'Scotch on the Rocks', 'SCOTCH ON THE ROCKS', 2, 32, 9999, 1, 4, 1, 179, NULL, '', 91, '8888/8888/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5890, '1997-09-13 22:00:00+00', '2022-08-20 18:42:17.238976+00', 'Sandy Robertson Bird', 'SANDY ROBERTSON BIRD', 3, 32, 9999, 1, 4, 1, 173, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5884, '1997-11-24 23:00:00+00', '2022-11-07 21:49:29.42797+00', 'Sands Of Egypt', 'SANDS OF EGYPT', 4, 48, 14, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14585, '2012-10-02 09:50:04.714586+00', '2022-11-30 12:22:06.327812+00', 'Don Bradford''s Jig', 'DON BRADFORDS JIG', 2, 48, NULL, 4, 4, 13, 1415, NULL, '', 71, '8080/8484/8484/8484/0808/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5852, '1998-04-19 22:00:00+00', '2023-01-21 14:11:23.517289+00', 'St. Valentine''s Day', 'SAINT VALENTINES DAY', 1, 32, 9999, 1, 3, 42, 270, NULL, 'The notes say this was "Devised for the London Branch R.S.C.D.S. and performed at their 1981 weekend school on St. Valentine''s Day."', 41, '800/880/808/822', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5955, '1997-09-13 22:00:00+00', '2019-04-29 16:43:15.831771+00', 'Scottish Fiddle Jig, The', 'SCOTTISH FIDDLE JIG', 2, 32, 9999, 1, 2, 76, 3461, '1984-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5933, '1997-04-03 22:00:00+00', '2012-01-20 12:56:46.706966+00', 'Scotia Reel', 'SCOTIA REEL', 1, 32, 9999, 1, 4, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5931, '1997-04-03 22:00:00+00', '2019-05-26 09:02:41.474894+00', 'Scotch Woodcock', 'SCOTCH WOODCOCK', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 53, '800/888/888/822', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5938, '1997-12-03 23:00:00+00', '2012-01-20 12:56:46.750667+00', 'Silver Bells', 'SILVER BELLS', 2, 32, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18858, '2018-10-07 08:42:20.834238+00', '2019-09-27 23:42:27.157671+00', 'Puppeteer, The', 'PUPPETEER', 1, 32, NULL, 1, 3, 42, 2766, '2009-02-01', '', 53, '820/684/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5942, '1997-12-03 23:00:00+00', '2012-01-20 12:56:46.785711+00', 'Joanne''s Fancy', 'JOANNES FANCY', 2, 32, 9999, 1, 4, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5943, '1997-04-03 22:00:00+00', '2012-01-20 12:56:46.794359+00', 'Scots Pine, The', 'SCOTS PINE', 3, 32, 9999, 1, 4, NULL, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5944, '1998-07-08 22:00:00+00', '2012-01-20 12:56:46.803935+00', 'Scots Shortcake', 'SCOTS SHORTCAKE', 2, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5947, '1998-07-08 22:00:00+00', '2012-01-20 12:56:46.83085+00', 'Scott Green', 'SCOTT GREEN', 2, 48, 9999, 1, 4, 11, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11902, '2004-11-10 23:00:00+00', '2012-01-20 12:57:33.750556+00', 'In Reel Time', 'IN REEL TIME', 4, 64, 10024, 1, 4, 22, 1228, '1994-01-01', 'A Simultaneous Medley.  The dance was devised as an exercise in step control and from a long

held desire to mix tempos for the fun of it.



All music is in reel time, steps are Reel steps or Strathspey steps.

The description has strathspey steps for bars [1-16] and [49-64], Reel steps for the rest.

1C+4C start dancing at bar 1 of the description, 2C+3C on bar 33.  



It is helpful to first practice dancing strathspey steps to reel time music.

I have also found it helpful to teach the whole dance with only first and fourth couple, then

repeating as second and third couple, before putting the whole in a four couple set.



', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5923, '1998-01-05 23:00:00+00', '2018-04-03 00:08:15.160162+00', 'Scotch Corners, The', 'SCOTCH CORNERS', 1, 40, 9999, 1, 3, 42, 70, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5888, '1997-04-03 22:00:00+00', '2021-04-17 09:57:31.585685+00', 'Sandy Nixon''s Reel', 'SANDY NIXONS REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 72, '848/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5893, '1997-04-03 22:00:00+00', '2021-04-19 20:47:08.642054+00', 'Sandy''s Reel', 'SANDYS REEL', 1, 32, 9999, 1, 3, 42, 108, '1968-01-01', 'Incribed to Sandy Milne of Aberdeen.', 53, '664/888/880/822', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11893, '2004-11-04 23:00:00+00', '2021-07-30 07:35:45.294896+00', 'Dice Dance, The', 'DICE DANCE', 1, 48, 9999, 1, 3, 42, 308, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11909, '2004-11-23 23:00:00+00', '2012-01-20 12:57:33.799886+00', 'Turn Turtle', 'TURN TURTLE', 1, 32, 9999, 1, 4, 11, 1084, NULL, 'Top and bottom alternate after each repetition.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11910, '2004-11-23 23:00:00+00', '2012-01-20 12:57:33.807353+00', 'Flittin'' Frolics', 'FLITTIN FROLICS', 2, 32, 9999, 3, 5, 7, 2943, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14587, '2012-10-02 09:57:36.360201+00', '2012-10-02 09:57:36.360212+00', 'Monty Brown', 'MONTY BROWN', 1, 32, NULL, 1, 2, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5953, '1997-09-13 22:00:00+00', '2012-01-20 12:56:46.883761+00', 'Scottish Celebration', 'SCOTTISH CELEBRATION', 2, 40, 9999, 1, 4, NULL, 620, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5954, '1997-04-03 22:00:00+00', '2012-01-20 12:56:46.892531+00', 'Scottish Engineer, The', 'SCOTTISH ENGINEER', 3, 32, 9999, 1, 4, NULL, 222, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5925, '1998-01-05 23:00:00+00', '2018-04-03 00:08:15.176775+00', 'Scotch Hop', 'SCOTCH HOP', 1, 32, 9999, 1, 3, 42, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5930, '1997-09-13 22:00:00+00', '2018-04-03 00:08:15.185151+00', 'Scotch Thistle, The', 'SCOTCH THISTLE', 3, 32, 9999, 1, 3, 42, 108, '1985-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5960, '1997-09-17 22:00:00+00', '2012-01-20 12:56:46.946272+00', 'Scottish Jig, A', 'SCOTTISH JIG', 2, 32, 9999, 5, 2, NULL, 1265, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5926, '1997-04-03 22:00:00+00', '2016-05-10 22:52:20.772378+00', 'Scotch Measure', 'SCOTCH MEASURE', 7, 0, 9999, 107, 1, NULL, 319, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5946, '1999-05-09 22:00:00+00', '2016-05-12 09:37:06.585769+00', 'Scotsman''s Choice, The', 'SCOTSMANS CHOICE', 1, 48, 9999, 105, 53, NULL, 2601, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11904, '2004-11-22 23:00:00+00', '2017-01-22 13:59:06.578285+00', 'Autumn in Pitlochry', 'AUTUMN IN PITLOCHRY', 3, 32, 9999, 4, 5, 38, 3471, '2003-01-01', '', 65, '48488/00008/88888/84448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11906, '2004-11-22 23:00:00+00', '2017-02-24 23:26:36.288119+00', 'M & J of Northmuir', 'M AND J OF NORTHMUIR', 1, 32, 9999, 4, 4, NULL, 2913, '2001-01-01', 'Devised for Muriel and James Smith of Northmuir, Kirriemuir.', -1, '', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (5950, '1997-09-13 22:00:00+00', '2017-07-16 00:38:38.640975+00', 'Scott''s Ruby', 'SCOTTS RUBY', 3, 40, 9999, 1, 4, NULL, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5935, '2000-07-26 22:00:00+00', '2018-04-03 00:08:15.226804+00', 'Scotland the Brave', 'SCOTLAND THE BRAVE', 1, 32, 9999, 1, 3, 42, 250, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5941, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.301802+00', 'Scots Marmalade', 'SCOTS MARMALADE', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5958, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.351957+00', 'Scottish Highlanders, The', 'SCOTTISH HIGHLANDERS', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5959, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.360269+00', 'Scottish Horse, The', 'SCOTTISH HORSE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5948, '1997-08-25 22:00:00+00', '2018-04-03 00:08:15.393628+00', 'Scott McCallum''s Reel', 'SCOTT MACCALLUMS REEL', 1, 32, 9999, 1, 3, 42, 108, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5949, '1997-09-14 22:00:00+00', '2018-04-03 00:08:16.802806+00', 'Silver Pendant, The', 'SILVER PENDANT', 3, 32, 9999, 1, 3, 42, 1272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11907, '2004-11-22 23:00:00+00', '2018-04-03 00:08:23.25716+00', 'Typing the Knot', 'TYPING THE KNOT', 2, 32, 9999, 1, 3, 42, 3472, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5965, '1997-09-02 22:00:00+00', '2012-01-20 12:56:46.989901+00', 'Scottish Welcome, A', 'SCOTTISH WELCOME', 2, 40, 9999, 2, 3, NULL, 325, '1985-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18859, '2018-10-07 08:50:52.693794+00', '2018-10-07 08:50:52.693794+00', 'Pussy Footin'' Around', 'PUSSY FOOTIN AROUND', 1, 32, NULL, 1, 3, 42, 2766, '2008-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5999, '1998-01-04 23:00:00+00', '2019-04-29 16:42:34.052221+00', 'Senator Robert C. Byrd of West Virginia', 'SENATOR ROBERT C BYRD OF WEST VIRGINIA', 1, 32, 9999, 1, 3, 42, 3461, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5974, '1997-09-13 22:00:00+00', '2012-01-20 12:56:47.068088+00', 'Sea Hedrig', 'SEA HEDRIG', 3, 32, 9999, 2, 3, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11911, '2004-11-23 23:00:00+00', '2012-01-20 12:57:33.814873+00', 'Reverend John Cooke', 'REVEREND JOHN COOKE', 3, 32, 9999, 3, 5, 33, 3473, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11912, '2004-11-23 23:00:00+00', '2012-01-20 12:57:33.82168+00', 'Catherine of Bon Accord', 'CATHERINE OF BON ACCORD', 1, 32, 9999, 5, 56, NULL, 3474, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11914, '2004-11-23 23:00:00+00', '2012-01-20 12:57:33.836609+00', 'Hamburg Train, The', 'HAMBURG TRAIN', 1, 32, 9999, 1, 4, 11, 3473, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11917, '2004-11-23 23:00:00+00', '2012-01-20 12:57:33.858301+00', 'Forehill Strathspey, The', 'FOREHILL STRATHSPEY', 3, 32, 9999, 1, 4, 2, 3474, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11924, '2004-11-25 23:00:00+00', '2012-01-20 12:57:33.907308+00', '4KC2', '4KC2', 2, 48, 9999, 4, 4, 1, 3432, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11923, '2004-11-25 23:00:00+00', '2018-04-03 00:07:29.514687+00', 'Abi''s Frolic', 'ABIS FROLIC', 1, 32, 9999, 1, 3, 42, 3432, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5987, '1998-07-08 22:00:00+00', '2012-01-20 12:56:47.189542+00', 'Secret Of Heather Ale', 'SECRET OF HEATHER ALE', 3, 40, 9999, 1, 4, 2, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11921, '2004-11-25 23:00:00+00', '2018-04-03 00:07:30.811027+00', 'Annie''s Romp', 'ANNIES ROMP', 1, 32, 9999, 1, 3, 42, 3432, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5990, '2001-03-13 23:00:00+00', '2012-01-20 12:56:47.217091+00', 'Silver Quarter, A', 'SILVER QUARTER', 1, 32, 9999, 2, 3, 17, 952, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11918, '2004-11-23 23:00:00+00', '2018-04-03 00:07:36.160559+00', 'Busby Road Bye-Byes', 'BUSBY ROAD BYEBYES', 1, 32, 9999, 1, 3, 42, 2943, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5994, '1998-07-08 22:00:00+00', '2012-01-20 12:56:47.254454+00', 'Selkirk Jig, The', 'SELKIRK JIG', 2, 32, 9999, 1, 4, 2, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11926, '2004-11-25 23:00:00+00', '2012-01-20 12:57:33.922265+00', 'Daybreak', 'DAYBREAK', 2, 32, 9999, 2, 3, 17, 3432, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11931, '2004-12-06 23:00:00+00', '2012-01-20 12:57:33.957162+00', 'Bruner''s Reel', 'BRUNERS REEL', 1, 32, 9999, 1, 2, NULL, 304, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11932, '2004-12-06 23:00:00+00', '2012-01-20 12:57:33.963931+00', 'Children''s Railway, The', 'CHILDRENS RAILWAY', 2, 32, 9999, 1, 4, NULL, 304, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11933, '2004-12-06 23:00:00+00', '2012-01-20 12:57:33.970716+00', 'Hopscotch', 'HOPSCOTCH', 2, 40, 9999, 4, 4, NULL, 3481, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11935, '2004-12-06 23:00:00+00', '2012-01-20 12:57:33.98427+00', 'Etive Shepherd, The', 'ETIVE SHEPHERD', 4, 128, 2, 4, 4, NULL, 3480, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6000, '1997-11-27 23:00:00+00', '2012-01-20 12:56:47.306538+00', 'Seonaid Mhor', 'SEONAID MHOR', 4, 64, 5, 4, 4, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6002, '1999-01-13 23:00:00+00', '2012-01-20 12:56:47.324146+00', 'September In Nova Scotia', 'SEPTEMBER IN NOVA SCOTIA', 2, 112, 9999, 2, 3, NULL, 425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5962, '1997-04-03 22:00:00+00', '2021-05-13 07:33:53.369813+00', 'Scottish Motif, The', 'SCOTTISH MOTIF', 1, 32, 9999, 1, 2, 76, 352, '1993-01-23', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11899, '2004-11-04 23:00:00+00', '2021-07-30 07:46:05.764906+00', 'Laird of Lochmaben, The', 'LAIRD OF LOCHMABEN', 1, 160, 9999, 4, 111, 3, 308, '2001-01-01', '4-couple set with 5th man in centre.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11915, '2004-11-23 23:00:00+00', '2021-01-18 11:14:33.56385+00', 'Tricky Troika', 'TRICKY TROIKA', 1, 32, 9999, 1, 4, 2, 2941, NULL, '', 84, '2882/8888/8888/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11895, '2004-11-04 23:00:00+00', '2021-07-30 08:18:31.329486+00', 'Merton Court Medley', 'MERTON COURT MEDLEY', 4, 64, 5, 4, 4, NULL, 308, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5984, '1997-09-13 22:00:00+00', '2021-04-02 23:30:02.966118+00', 'Seasons End', 'SEASONS END', 1, 32, 9999, 1, 102, 1, 21, NULL, '', 88, '8080/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5932, '1998-01-12 23:00:00+00', '2021-04-16 22:35:57.437284+00', 'Scotia', 'SCOTIA', 1, 32, 9999, 1, 3, 42, 108, '1982-01-01', 'Devised for the Scotia SCD group in New York.', 63, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11892, '2004-11-04 23:00:00+00', '2021-07-30 08:00:34.356304+00', 'Mideltone Silver', 'MIDELTONE SILVER', 2, 32, 9999, 3, 5, 7, 308, '2004-01-01', '', 78, '86868/88888/84884/80800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6003, '1997-09-14 22:00:00+00', '2012-01-20 12:56:47.332826+00', 'September Song', 'SEPTEMBER SONG', 3, 32, 9999, 2, 3, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6005, '1997-09-14 22:00:00+00', '2012-01-20 12:56:47.401356+00', 'Serene Lakes Strathspey', 'SERENE LAKES STRATHSPEY', 3, 32, 9999, 4, 4, NULL, 604, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5991, '1999-05-09 22:00:00+00', '2016-05-11 12:47:30.147442+00', 'Sego Lily, The', 'SEGO LILY', 3, 32, 9999, 6, 53, 17, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11925, '2004-11-25 23:00:00+00', '2018-04-03 00:07:36.977961+00', 'Captain William Patton', 'CAPTAIN WILLIAM PATTON', 1, 32, 9999, 1, 3, 42, 3432, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11922, '2004-11-25 23:00:00+00', '2018-04-03 00:07:40.849339+00', 'Dance for Susan, A', 'DANCE FOR SUSAN', 3, 32, 9999, 1, 3, 42, 3432, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11916, '2004-11-23 23:00:00+00', '2018-04-03 00:07:45.003055+00', 'Fair Puggled', 'FAIR PUGGLED', 2, 40, 9999, 1, 3, 42, 2941, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11927, '2004-11-25 23:00:00+00', '2018-04-03 00:07:46.037385+00', 'Fishing Creek Jig', 'FISHING CREEK JIG', 2, 32, 9999, 1, 3, 42, 3432, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11938, '2004-12-07 23:00:00+00', '2018-04-03 00:08:00.115475+00', 'Lochindorb', 'LOCHINDORB', 3, 32, 9999, 1, 3, 42, 854, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11937, '2004-12-07 23:00:00+00', '2018-04-03 00:08:04.477012+00', 'Miss Kate Sweeney', 'MISS KATE SWEENEY', 3, 32, 9999, 1, 3, 42, 854, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11920, '2004-11-25 23:00:00+00', '2018-04-03 00:08:11.082294+00', 'Portia''s Smile', 'PORTIAS SMILE', 3, 32, 9999, 1, 3, 42, 782, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5967, '1997-09-13 22:00:00+00', '2018-04-03 00:08:15.385299+00', 'Scottish Whirl, The', 'SCOTTISH WHIRL', 2, 24, 9999, 1, 3, 42, 1267, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5968, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.401968+00', 'Scotty''s Jig', 'SCOTTYS JIG', 2, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5969, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.410365+00', 'Scraggly Dance, A', 'SCRAGGLY DANCE', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5971, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.451972+00', 'Scuttlebutt', 'SCUTTLEBUTT', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5970, '1997-11-24 23:00:00+00', '2018-04-03 00:08:15.460361+00', 'Scuttle, The', 'SCUTTLE', 4, 32, 1, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5977, '1998-01-05 23:00:00+00', '2018-04-03 00:08:15.518673+00', 'Sea Witch', 'SEA WITCH', 1, 32, 9999, 1, 3, 42, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5985, '1997-09-13 22:00:00+00', '2018-04-03 00:08:15.543705+00', 'Second Honeymoon', 'SECOND HONEYMOON', 1, 32, 9999, 1, 3, 42, 1268, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5988, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.560331+00', 'See The Cuddy Kick', 'SEE THE CUDDY KICK', 4, 32, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5993, '2002-02-28 23:00:00+00', '2018-04-03 00:08:15.585413+00', 'Selkirk Colony, The', 'SELKIRK COLONY', 1, 32, 9999, 1, 3, 42, 406, '1975-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6001, '1997-08-25 22:00:00+00', '2018-04-03 00:08:15.660564+00', 'September ''42', 'SEPTEMBER 42', 3, 32, 9999, 1, 3, 42, 108, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6004, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.693885+00', 'Serendipity', 'SERENDIPITY', 1, 32, 9999, 1, 3, 42, 35, '1985-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6007, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.702128+00', 'Serve The Yoke', 'SERVE THE YOKE', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11936, '2004-12-06 23:00:00+00', '2018-04-03 00:08:22.606147+00', 'Trip to New Zealand, A', 'TRIP TO NEW ZEALAND', 2, 32, 9999, 1, 3, 42, 1439, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6011, '1997-04-03 22:00:00+00', '2012-01-20 12:56:47.453978+00', 'Seton''s Rant', 'SETONS RANT', 1, 32, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6015, '1997-04-03 22:00:00+00', '2012-01-20 12:56:47.490491+00', 'Shaggie Burn, The', 'SHAGGIE BURN', 2, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5998, '1998-11-17 23:00:00+00', '2019-03-10 18:54:58.844005+00', 'Senate House Square', 'SENATE HOUSE SQUARE', 4, 128, 2, 4, 4, 3, 2433, NULL, '', 69, '4040/8080/8888/8888/0404/0808/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6021, '1997-04-03 22:00:00+00', '2012-01-20 12:56:47.535239+00', 'Shandon Bells', 'SHANDON BELLS', 2, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6026, '1997-09-14 22:00:00+00', '2012-01-20 12:56:47.571056+00', 'She Loves Me, She Loves Me Not', 'SHE LOVES ME SHE LOVES ME NOT', 1, 68, 9999, 4, 4, NULL, 26, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6027, '1997-04-03 22:00:00+00', '2012-01-20 12:56:47.577844+00', 'She''ll Be Right', 'SHELL BE RIGHT', 1, 32, 9999, 4, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11940, '2004-12-08 23:00:00+00', '2012-01-20 12:57:34.01914+00', 'Take the Floor Again', 'TAKE THE FLOOR AGAIN', 1, 40, 9999, 1, 4, 2, 2419, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11942, '2004-12-08 23:00:00+00', '2012-01-20 12:57:34.03278+00', 'Witches Craig', 'WITCHES CRAIG', 2, 64, 9999, 1, 4, NULL, 2419, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11943, '2004-12-08 23:00:00+00', '2012-01-20 12:57:34.039564+00', 'Cardean Strathspey', 'CARDEAN STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 2419, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11944, '2004-12-08 23:00:00+00', '2012-01-20 12:57:34.047011+00', 'Tae Gang Aboot', 'TAE GANG ABOOT', 1, 48, 9999, 1, 4, 2, 2419, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11946, '2004-12-13 23:00:00+00', '2012-01-20 12:57:34.061578+00', 'Blairgowrie Lass', 'BLAIRGOWRIE LASS', 4, 32, 1, 1, 3, 18, 3488, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11947, '2004-12-13 23:00:00+00', '2012-01-20 12:57:34.068457+00', 'Brisbane Ferries', 'BRISBANE FERRIES', 3, 32, 9999, 1, 4, NULL, 3350, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11948, '2004-12-13 23:00:00+00', '2012-01-20 12:57:34.075302+00', 'Burnfoot House', 'BURNFOOT HOUSE', 3, 32, 9999, 1, 4, NULL, 3350, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11950, '2004-12-13 23:00:00+00', '2012-01-20 12:57:34.089031+00', 'Cloud Busters', 'CLOUD BUSTERS', 3, 32, 9999, 2, 3, NULL, 3489, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11951, '2004-12-13 23:00:00+00', '2012-01-20 12:57:34.095798+00', 'Come Follow', 'COME FOLLOW', 2, 32, 9999, 1, 4, NULL, 3490, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11952, '2004-12-13 23:00:00+00', '2012-01-20 12:57:34.102641+00', 'Double the Trouble', 'DOUBLE THE TROUBLE', 2, 32, 9999, 2, 3, NULL, 3491, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6006, '1997-04-03 22:00:00+00', '2022-08-20 19:00:13.164673+00', 'Sergeant Drummer, The', 'SERGEANT DRUMMER', 1, 40, 9999, 1, 102, 11, 21, NULL, 'Inscribed "for Colin Lander".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6033, '1997-04-03 22:00:00+00', '2012-01-20 12:56:47.63777+00', 'Sheilis', 'SHEILIS', 3, 64, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6034, '1997-04-03 22:00:00+00', '2012-01-20 12:56:47.646431+00', 'Sheldon Strathspey, The', 'SHELDON STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11941, '2004-12-08 23:00:00+00', '2018-04-03 00:07:31.612942+00', 'Auld Scots Pine, The', 'AULD SCOTS PINE', 1, 48, 9999, 1, 3, 42, 2419, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6041, '1997-04-03 22:00:00+00', '2012-01-20 12:56:47.707666+00', 'Sherwood Rangers', 'SHERWOOD RANGERS', 3, 32, 9999, 5, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6042, '1997-04-03 22:00:00+00', '2012-01-20 12:56:47.71717+00', 'Shetland Boston', 'SHETLAND BOSTON', 2, 48, 9999, 2, 3, 17, 270, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6043, '1998-01-05 23:00:00+00', '2012-01-20 12:56:47.725822+00', 'Shetland Fiddler, The', 'SHETLAND FIDDLER', 1, 32, 9999, 1, 4, NULL, 173, '1967-08-10', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6045, '1997-04-03 22:00:00+00', '2012-01-20 12:56:47.746139+00', 'Shetland Mare', 'SHETLAND MARE', 3, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4098, '1998-07-06 22:00:00+00', '2020-03-09 10:57:03.984743+00', 'Mairi Carron', 'MAIRI CARRON', 1, 40, 9999, 3, 5, 6, 270, NULL, '', 78, '80800/86846/86886/88888/84884', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6030, '1997-09-14 22:00:00+00', '2020-08-07 09:20:47.679767+00', 'Sheena''s Fancy', 'SHEENAS FANCY', 2, 32, 9999, 1, 3, 42, 101, '1968-01-01', '', 49, '844/844/800/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6028, '1997-04-03 22:00:00+00', '2020-08-07 09:21:37.723016+00', 'She''s Fair And Fause', 'SHES FAIR AND FAUSE', 2, 32, 9999, 1, 2, 76, 129, NULL, '', 51, '84 80 84 88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11928, '2004-12-06 23:00:00+00', '2021-01-18 11:11:01.032901+00', 'Ribble Link, The', 'RIBBLE LINK', 1, 40, 9999, 1, 3, 42, 3632, NULL, '', 60, '880/888/880/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5979, '1997-04-03 22:00:00+00', '2021-05-10 09:33:46.617684+00', 'Seabright, The', 'SEABRIGHT', 1, 48, 9999, 1, 3, 42, 270, NULL, '', 63, '880/888/888/844/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6024, '1997-11-24 23:00:00+00', '2021-05-10 10:44:09.49944+00', 'Shaw''s Battle', 'SHAWS BATTLE', 4, 32, 1, 1, 2, 76, 270, NULL, '', 60, '84/84/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6039, '1997-04-03 22:00:00+00', '2021-05-10 21:59:41.788829+00', 'Shepherd''s Wife, The', 'SHEPHERDS WIFE', 2, 32, 9999, 1, 2, 76, 270, NULL, '', 69, '88/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6013, '1997-04-03 22:00:00+00', '2021-10-14 16:12:41.380085+00', 'Shades of Amber', 'SHADES OF AMBER', 3, 32, 9999, 1, 4, 2, 352, '1990-09-01', '', 69, '8448/8888/8008/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6046, '1997-09-14 22:00:00+00', '2012-01-20 12:56:47.754789+00', 'Shieling Strathspey, The', 'SHIELING STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 1250, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6050, '1997-04-03 22:00:00+00', '2012-01-20 12:56:47.793096+00', 'Shining Mirror, The', 'SHINING MIRROR', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11953, '2004-12-13 23:00:00+00', '2018-04-03 00:07:46.012323+00', 'Fisherman''s Rib', 'FISHERMANS RIB', 3, 32, 9999, 1, 3, 42, 3491, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6059, '1997-04-03 22:00:00+00', '2012-01-20 12:56:47.872621+00', 'Short Bread', 'SHORT BREAD', 2, 16, 9999, 4, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6060, '1997-09-14 22:00:00+00', '2012-01-20 12:56:47.881272+00', 'Shott''s Strathspey', 'SHOTTS STRATHSPEY', 3, 32, 9999, 2, 3, NULL, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11954, '2004-12-13 23:00:00+00', '2012-01-20 12:57:34.116277+00', 'Glasgow Ferry', 'GLASGOW FERRY', 1, 40, 9999, 1, 4, NULL, 3350, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11955, '2004-12-13 23:00:00+00', '2012-01-20 12:57:34.12301+00', 'Kopu Bridge', 'KOPU BRIDGE', 3, 32, 9999, 1, 4, NULL, 3491, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11956, '2004-12-13 23:00:00+00', '2012-01-20 12:57:34.13015+00', 'Midwinter Mixture', 'MIDWINTER MIXTURE', 3, 32, 9999, 5, 56, NULL, 3490, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6023, '1997-09-14 22:00:00+00', '2017-07-16 00:42:52.421523+00', 'Sharing and Caring', 'SHARING AND CARING', 3, 40, 9999, 4, 4, NULL, 93, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11945, '2004-12-08 23:00:00+00', '2018-04-03 00:08:05.194059+00', 'Montgarrie Mill', 'MONTGARRIE MILL', 1, 40, 9999, 1, 3, 42, 2419, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6009, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.718915+00', 'Seton Castle Reel', 'SETON CASTLE REEL', 1, 32, 9999, 1, 3, 42, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6014, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.860735+00', 'Shadows On The Scores', 'SHADOWS ON THE SCORES', 3, 40, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6016, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.959316+00', 'Shaggy Dog, The', 'SHAGGY DOG', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6019, '1997-09-14 22:00:00+00', '2018-04-03 00:08:16.042623+00', 'Shakkin Brig, The', 'SHAKKIN BRIG', 2, 32, 9999, 1, 3, 42, 850, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6022, '1997-04-03 22:00:00+00', '2018-04-03 00:08:16.077348+00', 'Shandon Brae', 'SHANDON BRAE', 3, 40, 9999, 1, 3, 42, 71, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6031, '1997-11-18 23:00:00+00', '2018-04-03 00:08:16.135677+00', 'Sheerhan''s Reel', 'SHEERHANS REEL', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6032, '1997-05-18 22:00:00+00', '2018-04-03 00:08:16.160718+00', 'Sheila''s Wedding', 'SHEILAS WEDDING', 1, 32, 9999, 1, 3, 42, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6040, '1997-06-17 22:00:00+00', '2018-04-03 00:08:16.202262+00', 'Shepherd''s Reel, The', 'SHEPHERDS REEL', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6049, '1997-04-03 22:00:00+00', '2018-04-03 00:08:16.244117+00', 'Shigeru''s Strathspey', 'SHIGERUS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6054, '1997-09-14 22:00:00+00', '2018-04-03 00:08:16.327427+00', 'Shirley''s Jig', 'SHIRLEYS JIG', 2, 40, 9999, 1, 3, 42, 960, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18405, '2018-07-13 10:15:45.033747+00', '2018-07-13 16:33:47.502773+00', 'Saigon Traffic', 'SAIGON TRAFFIC', 1, 32, NULL, 2, 3, 30, 11659, NULL, 'The progression is Mens’ side: 1L, 2L, 3L; Ladies’ side: 2M, 3M, 1M. Danced six times to return to original places.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11959, '2004-12-13 23:00:00+00', '2012-01-20 12:57:34.150616+00', 'Return to New Zealand', 'RETURN TO NEW ZEALAND', 2, 48, 9999, 1, 4, NULL, 3492, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11960, '2004-12-13 23:00:00+00', '2012-01-20 12:57:34.157778+00', 'A. G. M., The', 'A G M', 2, 32, 9999, 1, 4, NULL, 3350, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18538, '2018-08-28 08:45:42.704501+00', '2018-08-28 10:38:05.53783+00', 'Wilma of Oban', 'WILMA OF OBAN', 3, 32, NULL, 1, 3, 42, 11692, '2015-06-01', 'Written for Wilma Kling (nee MacPhail) who was born in Oban but currently lives in Toronto,

on the occasion of her 80th Birthday', 50, '880/888/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11965, '2004-12-13 23:00:00+00', '2012-01-20 12:57:34.207867+00', 'Whatnot, The', 'WHATNOT', 3, 32, 9999, 1, 4, NULL, 3490, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6080, '1997-08-19 22:00:00+00', '2018-04-02 23:56:37.597674+00', 'Silver Fern Reel, The', 'SILVER FERN REEL', 1, 32, 9999, 1, 3, 42, 108, '1990-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6068, '1997-04-03 22:00:00+00', '2012-01-20 12:56:47.95249+00', 'Siege Of Lucknow', 'SIEGE OF LUCKNOW', 3, 40, 9999, 1, 4, NULL, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6069, '1997-04-03 22:00:00+00', '2012-01-20 12:56:47.961159+00', 'Signalman''s Hornpipe, The', 'SIGNALMANS HORNPIPE', 1, 24, 9999, 1, 2, NULL, 199, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6070, '2002-03-02 23:00:00+00', '2012-01-20 12:56:47.970692+00', 'Silent Pipes of Inverurie, The', 'SILENT PIPES OF INVERURIE', 3, 40, 9999, 1, 4, 1, 35, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6072, '1997-04-03 22:00:00+00', '2012-01-20 12:56:47.988118+00', 'Silver Bell', 'SILVER BELL', 3, 32, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6074, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.00544+00', 'Silver Celebration', 'SILVER CELEBRATION', 3, 80, 9999, 4, 4, NULL, 108, '1987-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6076, '1997-04-03 22:00:00+00', '2012-01-20 12:56:48.023871+00', 'Silver Circle Waltz, The', 'SILVER CIRCLE WALTZ', 5, 40, 9999, 4, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6083, '1997-09-02 22:00:00+00', '2012-01-20 12:56:48.085016+00', 'Frae Aberdeen', 'FRAE ABERDEEN', 1, 36, 9999, 1, 2, NULL, 446, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6084, '1997-04-03 22:00:00+00', '2012-01-20 12:56:48.093679+00', 'Silver Leaves', 'SILVER LEAVES', 2, 40, 9999, 1, 4, NULL, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6088, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.129591+00', 'Silver Salute', 'SILVER SALUTE', 1, 40, 9999, 1, 4, NULL, 1273, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11967, '2004-12-13 23:00:00+00', '2012-01-20 12:57:34.225378+00', 'Yin and Yang', 'YIN AND YANG', 2, 32, 9999, 2, 3, NULL, 3490, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11974, '2005-01-11 23:00:00+00', '2012-01-20 12:57:34.300781+00', 'Bride''s Favourite (V1), The', 'BRIDES FAVOURITE V1', 2, 32, 9999, 1, 2, NULL, 725, NULL, 'The deviser considers this dance obsolete and draws your attention to the dance of the same name in his collection Weird but Wonderful.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11961, '2004-12-13 23:00:00+00', '2018-04-03 00:07:41.049489+00', 'Dancie was a Lady, The', 'DANCIE WAS A LADY', 3, 40, 9999, 1, 3, 42, 3354, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11977, '2005-06-05 22:00:00+00', '2012-01-20 12:57:34.328432+00', 'Goin'' Surfin''', 'GOIN SURFIN', 3, 32, 9999, 1, 4, NULL, 1352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12029, '2005-02-20 23:00:00+00', '2018-04-03 00:08:00.000879+00', 'Loch Arkaig', 'LOCH ARKAIG', 1, 32, 9999, 1, 3, 42, 44, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6132, '2003-01-28 23:00:00+00', '2012-01-20 12:56:48.517394+00', '6600 Macdonalds', '6600 MACDONALDS', 1, 32, 9999, 1, 4, 1, 35, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6092, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.167261+00', 'Silver Towers', 'SILVER TOWERS', 3, 32, 9999, 2, 3, NULL, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6095, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.193458+00', 'Silver Wedding, The', 'SILVER WEDDING', 1, 40, 9999, 1, 4, NULL, 141, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11997, '2005-01-30 23:00:00+00', '2012-01-20 12:57:34.509009+00', 'Derwentside', 'DERWENTSIDE', 2, 32, 9999, 3, 5, 7, 692, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6090, '1997-09-14 22:00:00+00', '2020-12-26 13:52:03.701987+00', 'Silver Strand, The', 'SILVER STRAND', 3, 32, 9999, 2, 3, 42, 13, NULL, '', -50, '800/888/844/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11976, '2005-01-19 23:00:00+00', '2021-01-17 23:16:38.54359+00', 'Nice Hands', 'NICE HANDS', 2, 32, 9999, 4, 4, 4, 3027, NULL, '', 88, '8888/8888/4444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11972, '2004-12-15 23:00:00+00', '2021-03-09 23:19:27.122876+00', 'McLoughlin Strathspey and Reel', 'MACLOUGHLIN STRATHSPEY AND REEL', 4, 64, 5, 105, 2, NULL, 591, '1986-01-01', '', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6055, '1997-09-14 22:00:00+00', '2021-04-14 21:29:09.329452+00', 'Shooglie, The', 'SHOOGLIE', 1, 32, 9999, 1, 3, 42, 154, '1983-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6018, '2002-04-08 22:00:00+00', '2021-04-14 21:47:23.969221+00', 'Shakin'' The Bottle', 'SHAKIN THE BOTTLE', 2, 32, 9999, 1, 3, 42, 21, NULL, '', 53, '800/855/855/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6038, '1998-04-19 22:00:00+00', '2021-06-14 23:15:43.367729+00', 'Shepherd''s Pie', 'SHEPHERDS PIE', 1, 32, 9999, 1, 3, 42, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11968, '2004-12-15 23:00:00+00', '2021-08-06 09:46:23.901752+00', 'Catching Fireflies', 'CATCHING FIREFLIES', 1, 32, 9999, 1, 3, 42, 3494, '2004-01-01', '', 56, '844/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6075, '1997-04-03 22:00:00+00', '2015-09-21 06:40:43.49686+00', 'Silver Chain, The', 'SILVER CHAIN', 3, 48, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6078, '1997-09-14 22:00:00+00', '2016-03-02 08:05:21.4015+00', 'Silver Cross, The', 'SILVER CROSS', 3, 40, 9999, 1, 4, 1, 518, '1977-01-01', '', 90, '8888/8888/8044/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6129, '1997-08-26 22:00:00+00', '2016-05-11 23:55:06.419064+00', 'Sixteensome Medley, A', 'SIXTEENSOME MEDLEY', 4, 64, 9999, 107, 8, NULL, 175, '1976-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11962, '2004-12-13 23:00:00+00', '2018-04-03 00:08:12.091313+00', 'Rannoch Strathspey, The', 'RANNOCH STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3492, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11958, '2004-12-13 23:00:00+00', '2018-04-03 00:08:12.391716+00', 'Reeling for Joy', 'REELING FOR JOY', 2, 32, 9999, 1, 3, 42, 3354, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11963, '2004-12-13 23:00:00+00', '2018-04-03 00:08:14.059401+00', 'Rue and the Thyme, The', 'RUE AND THE THYME', 2, 40, 9999, 1, 3, 42, 3489, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6062, '1997-09-16 22:00:00+00', '2018-04-03 00:08:16.51097+00', 'Shrewsbury Lasses, The', 'SHREWSBURY LASSES', 1, 40, 9999, 1, 3, 42, 466, '1765-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6063, '1997-09-14 22:00:00+00', '2018-04-03 00:08:16.51924+00', 'Shuter''s Hornpipe', 'SHUTERS HORNPIPE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6064, '1998-04-19 22:00:00+00', '2018-04-03 00:08:16.527553+00', 'Shuttle Bus, The', 'SHUTTLE BUS', 2, 32, 9999, 1, 3, 42, 232, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6065, '2002-03-12 23:00:00+00', '2018-04-03 00:08:16.535949+00', 'Siccan Pawky Lass', 'SICCAN PAWKY LASS', 2, 32, 9999, 1, 3, 42, 111, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6082, '2002-05-06 22:00:00+00', '2018-04-03 00:08:16.761174+00', 'Silver Jubilee Horseshoe', 'SILVER JUBILEE HORSESHOE', 4, 20, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6089, '1997-04-03 22:00:00+00', '2018-04-03 00:08:16.82783+00', 'Silver Star Strathspey', 'SILVER STAR STRATHSPEY', 3, 32, 9999, 1, 3, 42, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11964, '2004-12-13 23:00:00+00', '2018-04-03 00:08:23.656767+00', 'Venus Flytrap, The', 'VENUS FLYTRAP', 1, 32, 9999, 1, 3, 42, 3489, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6099, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.228447+00', 'Simon Bruce', 'SIMON BRUCE', 3, 72, 9999, 1, 4, NULL, 1274, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11986, '2005-01-20 23:00:00+00', '2019-03-02 12:18:45.591016+00', 'Lady of the Dance, The', 'LADY OF THE DANCE', 3, 80, 9999, 4, 4, 3, 186, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6102, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.254381+00', 'Sin Enslaves', 'SIN ENSLAVES', 3, 128, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6123, '1997-04-03 22:00:00+00', '2019-08-27 02:39:03.537415+00', 'Sister Jean', 'SISTER JEAN', 1, 32, 9999, 1, 4, 1, 270, NULL, '', 75, '8080/6666/8888/8484', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6106, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.289955+00', 'Sins of My Youth, The', 'SINS OF MY YOUTH', 3, 32, 9999, 3, 5, NULL, 480, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6108, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.307297+00', 'Sion House', 'SION HOUSE', 1, 24, 9999, 1, 2, NULL, 446, '1686-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6109, '1997-10-27 23:00:00+00', '2012-01-20 12:56:48.316232+00', 'Sir Archibald Dunbar', 'SIR ARCHIBALD DUNBAR', 3, 32, 9999, 1, 2, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6110, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.325006+00', 'Sir Charles Napier', 'SIR CHARLES NAPIER', 2, 40, 9999, 1, 4, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6113, '1997-08-26 22:00:00+00', '2012-01-20 12:56:48.354731+00', 'Sir James Douglas'' Jig', 'SIR JAMES DOUGLAS JIG', 2, 32, 9999, 1, 4, NULL, 562, '1975-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6114, '1998-01-04 23:00:00+00', '2012-01-20 12:56:48.363539+00', 'Sir John A. Macdonald', 'SIR JOHN A MACDONALD', 1, 32, 9999, 1, 4, NULL, 563, '1977-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6115, '1997-04-03 22:00:00+00', '2012-01-20 12:56:48.372306+00', 'Sir John Henderson', 'SIR JOHN HENDERSON', 2, 40, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11995, '2005-01-30 23:00:00+00', '2018-04-03 00:07:37.937959+00', 'Champion, The', 'CHAMPION', 2, 32, 9999, 1, 3, 42, 692, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11992, '2005-01-30 23:00:00+00', '2012-01-20 12:57:34.461604+00', 'Baile Mor', 'BAILE MOR', 3, 32, 9999, 1, 4, 2, 692, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11993, '2005-01-30 23:00:00+00', '2012-01-20 12:57:34.471314+00', 'Celebration Dance', 'CELEBRATION DANCE', 1, 32, 9999, 1, 4, 2, 692, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6117, '1999-08-22 22:00:00+00', '2012-01-20 12:56:48.389865+00', 'Sir Reginald MacDonald', 'SIR REGINALD MACDONALD', 1, 32, 9999, 1, 2, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6118, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.398824+00', 'Sir Robert Menzies'' Scottish Thistle Strathspey', 'SIR ROBERT MENZIES SCOTTISH THISTLE STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 54, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6119, '1997-04-03 22:00:00+00', '2012-01-20 12:56:48.407515+00', 'Sir Robert Peel', 'SIR ROBERT PEEL', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6125, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.459812+00', 'Six & Sevens', 'SIX AND SEVENS', 1, 32, 9999, 1, 2, NULL, 397, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6127, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.47725+00', 'Six Sisters', 'SIX SISTERS', 3, 32, 9999, 2, 3, NULL, 247, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6097, '1997-04-03 22:00:00+00', '2018-04-03 00:08:16.777776+00', 'Silverknowes Jig, The', 'SILVERKNOWES JIG', 2, 32, 9999, 1, 3, 42, 417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6138, '1997-11-24 23:00:00+00', '2012-01-20 12:56:48.558592+00', 'Skillet, The', 'SKILLET', 4, 64, 2, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6140, '1997-08-26 22:00:00+00', '2012-01-20 12:56:48.5726+00', 'Skirmish, The', 'SKIRMISH', 2, 32, 9999, 1, 4, NULL, 565, '1973-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6142, '1997-04-03 22:00:00+00', '2012-01-20 12:56:48.587832+00', 'Skiver The Quilt', 'SKIVER THE QUILT', 2, 32, 9999, 1, 4, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6144, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.60232+00', 'Skyte Neuk', 'SKYTE NEUK', 3, 32, 9999, 1, 4, NULL, 332, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6145, '1997-08-21 22:00:00+00', '2012-01-20 12:56:48.609183+00', 'Slains Castle', 'SLAINS CASTLE', 2, 32, 9999, 1, 4, NULL, 108, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11994, '2005-01-30 23:00:00+00', '2012-01-20 12:57:34.481052+00', 'C''est la Vie', 'CEST LA VIE', 3, 32, 9999, 3, 5, 7, 692, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6096, '1997-11-23 23:00:00+00', '2020-01-11 02:01:22.533193+00', 'Silverhaired Dancer, The', 'SILVERHAIRED DANCER', 5, 256, 9999, NULL, 4, NULL, 401, '1985-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11966, '2004-12-13 23:00:00+00', '2021-06-07 08:11:22.515031+00', 'Thistle Clock Jig', 'THISTLE CLOCK JIG', 2, 32, 9999, 1, 3, 42, 3491, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11973, '2005-01-19 23:00:00+00', '2022-09-23 15:35:09.455852+00', 'Margaret''s Left-Handed Strathspey', 'MARGARETS LEFTHANDED STRATHSPEY', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6053, '1997-09-14 22:00:00+00', '2022-11-08 16:51:04.600182+00', 'Shire of Air, The', 'SHIRE OF AIR', 2, 32, 9999, 1, 2, 76, 976, '1740-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6134, '1997-11-24 23:00:00+00', '2022-12-18 22:51:17.516358+00', 'Skara Brae', 'SKARA BRAE', 4, 80, 7, 1, 4, 1, 270, NULL, '', 76, '8484/4444/8448/8888/4444/8888/4884/8888/0048/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6085, '1997-09-14 22:00:00+00', '2020-09-03 15:55:19.021497+00', 'Silver Penny', 'SILVER PENNY', 3, 96, 9999, 1, 4, 3, 697, NULL, '', 92, '8888/8888/8888/8800/8888/8448/6666/8888/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6079, '1997-09-14 22:00:00+00', '2020-12-31 14:13:40.390631+00', 'Silver Darlings', 'SILVER DARLINGS', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 50, '804/888/840/808', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11990, '2005-01-25 23:00:00+00', '2021-01-17 20:37:46.850161+00', 'Nova Scotia Nights', 'NOVA SCOTIA NIGHTS', 1, 32, 9999, 1, 3, 42, 3409, NULL, '', 56, '880/888/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11984, '2005-01-20 23:00:00+00', '2021-01-17 21:00:22.377948+00', 'Willow Strathspey', 'WILLOW STRATHSPEY', 3, 96, 9999, 4, 4, 3, 1, NULL, '', 79, '8888/8080/8888/8484/0808/8888/8080/8888/0808/8888/4848/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11982, '2005-01-20 23:00:00+00', '2021-01-17 23:04:38.490205+00', 'Sandbach Society Reel', 'SANDBACH SOCIETY REEL', 1, 32, 9999, 1, 4, 2, 3143, NULL, '', 50, '8000/0008/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11981, '2005-01-19 23:00:00+00', '2021-01-17 23:10:40.881968+00', 'Road to Kingoldrum, The', 'ROAD TO KINGOLDRUM', 3, 32, 9999, 1, 3, 42, 1642, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11978, '2005-01-19 23:00:00+00', '2021-01-17 23:13:24.542569+00', 'Pearl Strathspey, The', 'PEARL STRATHSPEY', 3, 32, 9999, 1, 3, 42, 930, NULL, '', 56, '888/888/800/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11971, '2004-12-15 23:00:00+00', '2021-03-09 23:22:45.806342+00', 'Glen Fruin Medley', 'GLEN FRUIN MEDLEY', 4, 64, 5, 1, 4, NULL, 591, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6135, '2002-03-03 23:00:00+00', '2021-04-14 11:30:29.061089+00', 'Skerry Reel Of Eight, The', 'SKERRY REEL OF EIGHT', 1, 128, 9999, 4, 4, 3, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6077, '1997-04-03 22:00:00+00', '2021-04-14 18:20:44.18483+00', 'Silver City, The', 'SILVER CITY', 3, 32, 9999, 1, 3, 42, 108, '1968-01-01', 'For the Members of the "Tuesday Class" in Aberdeen.

', 59, '888/880/822/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6067, '1997-04-03 22:00:00+00', '2021-05-11 11:20:30.303202+00', 'Siege of Delhi, The', 'SIEGE OF DELHI', 1, 48, 9999, 1, 3, 42, 270, NULL, '', 52, '800/880/880/844/888/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6100, '1997-04-03 22:00:00+00', '2018-04-03 00:08:16.894559+00', 'Simon, the Lord Lovat', 'SIMON THE LORD LOVAT', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11988, '2005-01-20 23:00:00+00', '2016-04-15 15:54:20.191573+00', 'Aileen''s Jig', 'AILEENS JIG', 2, 40, 9999, 1, 3, 42, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6128, '1997-11-27 23:00:00+00', '2016-05-11 23:08:29.013197+00', 'Sixsome Medley', 'SIXSOME MEDLEY', 4, 64, 5, 107, 101, NULL, 347, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6105, '1997-09-14 22:00:00+00', '2018-04-03 00:08:17.086343+00', 'Sinister Reel, The', 'SINISTER REEL', 1, 40, 9999, 1, 3, 42, 1070, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6120, '1997-04-03 22:00:00+00', '2018-04-03 00:08:17.1114+00', 'Sir Walter Scott''s Mother', 'SIR WALTER SCOTTS MOTHER', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6121, '1997-09-14 22:00:00+00', '2018-04-03 00:08:17.1197+00', 'Sir Watkin''s Jig', 'SIR WATKINS JIG', 2, 32, 9999, 1, 3, 42, 198, '1750-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6124, '1998-04-21 22:00:00+00', '2018-04-03 00:08:17.144798+00', 'Sitting In the Stern Of a Boat', 'SITTING IN THE STERN OF A BOAT', 4, 32, 1, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6126, '1997-09-14 22:00:00+00', '2018-04-03 00:08:17.161495+00', 'Six Penny Jig, The', 'SIX PENNY JIG', 2, 32, 9999, 1, 3, 42, 1277, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6137, '2000-02-22 23:00:00+00', '2018-04-03 00:08:17.236452+00', 'Skidaddle Ridge', 'SKIDADDLE RIDGE', 2, 32, 9999, 1, 3, 42, 90, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6139, '1998-04-19 22:00:00+00', '2018-04-03 00:08:17.253224+00', 'Skirmish at Clifton, The', 'SKIRMISH AT CLIFTON', 2, 40, 9999, 1, 3, 42, 108, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11983, '2005-01-20 23:00:00+00', '2018-04-03 00:08:21.189279+00', 'Tin Medal', 'TIN MEDAL', 4, 64, 5, 1, 3, 42, 1, NULL, 'Reel part identical to Strathspey (from 2nd place)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11998, '2005-01-30 23:00:00+00', '2012-01-20 12:57:34.518976+00', 'Eskdalemuir', 'ESKDALEMUIR', 3, 32, 9999, 2, 3, 17, 692, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12000, '2005-01-30 23:00:00+00', '2012-01-20 12:57:34.536512+00', 'Joe''s Strathspey', 'JOES STRATHSPEY', 3, 32, 9999, 2, 3, NULL, 692, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12008, '2005-02-01 23:00:00+00', '2018-04-03 00:07:29.849518+00', 'Alan and Christine''s Jig', 'ALAN AND CHRISTINES JIG', 2, 32, 9999, 1, 3, 42, 861, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6147, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.622942+00', 'Slainte Mhath', 'SLAINTE MHATH', 3, 40, 9999, 4, 4, NULL, 93, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6169, '2000-08-01 22:00:00+00', '2018-02-26 22:55:11.599206+00', 'Snowdrops in a Storm', 'SNOWDROPS IN A STORM', 3, 32, 9999, 1, 3, 42, 651, '1992-09-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6154, '1997-04-03 22:00:00+00', '2012-01-20 12:56:48.677518+00', 'Slow and Easy Does It', 'SLOW AND EASY DOES IT', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18862, '2018-10-07 10:56:29.735197+00', '2018-10-07 10:56:29.735197+00', 'Random Walk', 'RANDOM WALK', 2, 32, NULL, 1, 3, 42, 2766, '2010-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6156, '1998-07-09 22:00:00+00', '2012-01-20 12:56:48.692329+00', 'Sly Old Fox, The', 'SLY OLD FOX', 2, 48, 9999, 3, 5, 6, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6157, '1997-09-14 22:00:00+00', '2012-01-20 12:56:48.699508+00', 'Smiling Mandy', 'SMILING MANDY', 1, 32, 9999, 1, 4, NULL, 502, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6160, '1997-04-03 22:00:00+00', '2012-01-20 12:56:48.720374+00', 'Smith''s Hornpipe', 'SMITHS HORNPIPE', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11999, '2005-01-30 23:00:00+00', '2018-04-03 00:07:53.160156+00', 'Iain''s Welcome', 'IAINS WELCOME', 1, 32, 9999, 1, 3, 42, 692, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6187, '1997-09-14 22:00:00+00', '2018-10-24 14:40:03.267674+00', 'Solway Sands', 'SOLWAY SANDS', 3, 40, 9999, 1, 4, NULL, 200, NULL, '', 90, '8888/6666/8888/6666/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6185, '1998-04-02 22:00:00+00', '2019-03-10 15:18:58.62736+00', 'Solway Firth', 'SOLWAY FIRTH', 2, 48, 9999, 1, 4, 1, 108, '1964-01-01', '', 88, '8888/8448/8668/8888/8084/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6153, '2002-02-27 23:00:00+00', '2019-03-10 15:22:55.616942+00', 'Sloane Square', 'SLOANE SQUARE', 3, 64, 9999, 4, 4, 3, 617, NULL, '', 91, '8888/5555/5555/8888/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6149, '1997-12-03 23:00:00+00', '2019-03-10 15:27:44.766413+00', 'Wee Mary''s Jig', 'WEE MARYS JIG', 2, 32, 9999, 1, 4, 2, 593, '1994-01-01', '', 88, '8888/8888/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18860, '2018-10-07 09:22:29.612158+00', '2019-04-21 22:40:40.360292+00', 'Quick Jig, A', 'QUICK JIG', 2, 32, NULL, 1, 3, 42, 2766, '2007-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6155, '1997-09-14 22:00:00+00', '2018-04-03 00:08:17.353193+00', 'Slow And Simple', 'SLOW AND SIMPLE', 3, 32, 9999, 1, 3, 42, 1204, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6172, '2000-06-27 22:00:00+00', '2012-01-20 12:56:48.803647+00', 'So The Devil Can''t Corner You', 'SO THE DEVIL CANT CORNER YOU', 2, 48, 9999, 4, 4, NULL, 90, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6174, '1997-04-03 22:00:00+00', '2012-01-20 12:56:48.817427+00', 'So''ton Reel', 'SOTON REEL', 1, 48, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6181, '1997-04-03 22:00:00+00', '2019-08-27 20:40:26.652733+00', 'Soldier''s Dance, The', 'SOLDIERS DANCE', 2, 48, 9999, 1, 4, 1, 270, NULL, '', 77, '8080/4884/8888/8888/8040/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12009, '2005-02-01 23:00:00+00', '2012-01-20 12:57:34.616018+00', 'Four-Leaved Clover, The', 'FOURLEAVED CLOVER', 2, 32, 9999, NULL, NULL, NULL, 3187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12010, '2005-02-01 23:00:00+00', '2012-01-20 12:57:34.622984+00', 'Jinglebells Country Dance, The', 'JINGLEBELLS COUNTRY DANCE', 1, 32, 9999, NULL, NULL, NULL, 3187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12011, '2005-02-01 23:00:00+00', '2012-01-20 12:57:34.63027+00', 'Dancing through a Field of Daffodils', 'DANCING THROUGH A FIELD OF DAFFODILS', 2, 32, 9999, NULL, NULL, NULL, 3187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12012, '2005-02-01 23:00:00+00', '2012-01-20 12:57:34.637282+00', 'Some Flowers for You Because of so Many Reasons', 'SOME FLOWERS FOR YOU BECAUSE OF SO MANY REASONS', 1, 32, 9999, NULL, NULL, NULL, 3187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12013, '2005-02-01 23:00:00+00', '2012-01-20 12:57:34.644271+00', 'Through the Arches of Roses', 'THROUGH THE ARCHES OF ROSES', 2, 32, 9999, NULL, NULL, NULL, 3187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6180, '1997-04-03 22:00:00+00', '2012-01-20 12:56:48.858718+00', 'Soldier Dance With Me', 'SOLDIER DANCE WITH ME', 1, 32, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6189, '1997-04-03 22:00:00+00', '2012-01-20 12:56:48.92517+00', 'Somerset Strathspey', 'SOMERSET STRATHSPEY', 3, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6103, '1997-11-25 23:00:00+00', '2020-08-07 09:24:27.066409+00', 'Singing Kettle, The', 'SINGING KETTLE', 4, 64, 5, 1, 3, 42, 82, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6111, '1998-07-09 22:00:00+00', '2022-11-07 22:00:48.514572+00', 'Sir George Clark of Pennycuik', 'SIR GEORGE CLARK OF PENNYCUIK', 3, 48, 9999, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6112, '1998-04-19 22:00:00+00', '2022-11-08 16:43:54.341103+00', 'Sir James Baird''s Strathspey', 'SIR JAMES BAIRDS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 62, '1980-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6101, '1997-04-03 22:00:00+00', '2020-09-03 15:58:31.794769+00', 'Simplicity', 'SIMPLICITY', 1, 32, 9999, 1, 3, 42, 3412, NULL, '', 63, '888/808/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6146, '1997-09-14 22:00:00+00', '2020-12-31 16:59:23.720311+00', 'Slainte Mhath', 'SLAINTE MHATH', 1, 32, 9999, 1, 4, 11, 13, NULL, '', 81, '8448/8888/8888/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12018, '2005-02-13 23:00:00+00', '2021-01-17 18:24:15.361755+00', 'Sleepless in Brentwood', 'SLEEPLESS IN BRENTWOOD', 3, 32, 9999, 2, 3, 4, 3506, NULL, '', 75, '840/888/282/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12016, '2005-02-04 23:00:00+00', '2021-01-17 18:53:10.257286+00', 'Three and Two is Five', 'THREE AND TWO IS FIVE', 1, 32, 9999, 3, 5, 10, 3345, '2002-01-01', '', 70, '88800/88888/88800/08088', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12015, '2005-02-04 23:00:00+00', '2021-01-17 19:03:05.1366+00', 'Lesley''s Medley', 'LESLEYS MEDLEY', 4, 128, 13, 4, 4, 3, 3345, '2004-01-01', '', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12001, '2005-01-30 23:00:00+00', '2021-01-17 19:12:28.145748+00', 'Keep on Dancing', 'KEEP ON DANCING', 1, 32, 9999, 1, 3, 42, 692, '2003-01-01', '', 63, '880/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11996, '2005-01-30 23:00:00+00', '2021-01-17 20:33:06.32164+00', 'Crystal Quaich, The', 'CRYSTAL QUAICH', 3, 32, 9999, 1, 4, 2, 692, '2004-01-01', '', 75, '8888/8008/8008/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6158, '1998-04-21 22:00:00+00', '2021-04-14 11:24:48.075205+00', 'Smith at his Anvil, The', 'SMITH AT HIS ANVIL', 4, 40, 25, 1, 2, 76, 44, '1981-01-01', 'For Tony Wright.', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6190, '1997-11-27 23:00:00+00', '2012-01-20 12:56:48.931994+00', 'Something New', 'SOMETHING NEW', 4, 64, 22, 1, 4, NULL, 197, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6151, '1997-04-03 22:00:00+00', '2017-01-15 01:53:34.321789+00', 'Sleepy Hollow', 'SLEEPY HOLLOW', 2, 32, 9999, 1, 3, 42, 108, '1986-01-01', '', 69, '888/888/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12003, '2005-01-30 23:00:00+00', '2017-11-11 06:09:28.7673+00', 'Down the Rabbit Hole', 'DOWN THE RABBIT HOLE', 2, 32, NULL, 1, 4, 1, 3333, '2005-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6164, '1997-04-03 22:00:00+00', '2018-04-03 00:08:17.419985+00', 'Snouts And Ears', 'SNOUTS AND EARS', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6166, '1997-09-14 22:00:00+00', '2018-04-03 00:08:17.503335+00', 'Snow in March', 'SNOW IN MARCH', 3, 32, 9999, 1, 3, 42, 1279, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6175, '1997-04-03 22:00:00+00', '2018-04-03 00:08:17.528352+00', 'Sociability', 'SOCIABILITY', 3, 32, 9999, 1, 3, 42, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6176, '1997-04-03 22:00:00+00', '2018-04-03 00:08:17.536703+00', 'Social Life In The Highlands', 'SOCIAL LIFE IN THE HIGHLANDS', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6171, '1997-04-03 22:00:00+00', '2018-04-03 00:08:17.595355+00', 'So Far, So Good', 'SO FAR SO GOOD', 2, 32, 9999, 1, 3, 42, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6179, '1997-09-14 22:00:00+00', '2018-04-03 00:08:17.620212+00', 'Soft And Gentle', 'SOFT AND GENTLE', 3, 32, 9999, 1, 3, 42, 1280, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6183, '1997-09-14 22:00:00+00', '2018-04-03 00:08:17.64514+00', 'Soldier''s Leap, The', 'SOLDIERS LEAP', 2, 40, 9999, 1, 3, 42, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6184, '2003-01-28 23:00:00+00', '2018-04-03 00:08:17.661793+00', 'Solvang Rant, The', 'SOLVANG RANT', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12045, '2005-02-20 23:00:00+00', '2018-04-02 23:56:35.368485+00', 'It''s All Right', 'ITS ALL RIGHT', 2, 32, 9999, 1, 3, 42, 777, '2001-06-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6192, '1997-04-03 22:00:00+00', '2012-01-20 12:56:48.946311+00', 'Something Simple', 'SOMETHING SIMPLE', 1, 32, 9999, 1, 4, NULL, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6193, '1998-07-08 22:00:00+00', '2012-01-20 12:56:48.95379+00', 'Something To Celebrate', 'SOMETHING TO CELEBRATE', 2, 32, 9999, 1, 4, 2, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6229, '2002-02-27 23:00:00+00', '2019-03-10 14:41:35.806432+00', 'Sparkenhoe Circle', 'SPARKENHOE CIRCLE', 1, 64, 9999, 4, 4, 3, 512, NULL, '', 81, '8888/8484/8080/4848/0808/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6195, '1998-07-08 22:00:00+00', '2012-01-20 12:56:48.968812+00', 'Song of Spain, The', 'SONG OF SPAIN', 3, 32, 9999, 1, 4, 2, 676, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6198, '1998-01-05 23:00:00+00', '2012-01-20 12:56:48.990275+00', 'Song of the Wind, The', 'SONG OF THE WIND', 1, 64, 9999, 4, 4, NULL, 70, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6200, '1998-07-08 22:00:00+00', '2012-01-20 12:56:49.005159+00', 'Songsters, The', 'SONGSTERS', 1, 32, 9999, 1, 4, 2, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18412, '2018-07-17 16:11:50.86625+00', '2018-08-28 10:57:33.707817+00', 'March Hare, The', 'MARCH HARE', 2, 32, NULL, 1, 3, 42, 10720, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12022, '2005-02-13 23:00:00+00', '2018-10-01 09:33:51.915067+00', 'My 88 Jig', 'MY 88 JIG', 2, 32, 9999, 2, 3, 17, 1346, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12025, '2005-02-20 23:00:00+00', '2012-01-20 12:57:34.811618+00', 'Just a Minute', 'JUST A MINUTE', 1, 32, 9999, 1, 4, NULL, 44, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12027, '2005-02-20 23:00:00+00', '2019-02-05 17:33:30.461774+00', 'Raising The Anchor', 'RAISING THE ANCHOR', 1, 32, 9999, 3, 5, 16, 44, '2001-01-01', '', 53, '88800/80888/80008/80004', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6212, '1998-11-07 23:00:00+00', '2019-03-10 15:11:42.17774+00', 'South Inch House', 'SOUTH INCH HOUSE', 3, 32, 9999, 1, 4, 1, 1282, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6208, '2002-03-02 23:00:00+00', '2012-01-20 12:56:49.06333+00', 'Sound of Staffa, The', 'SOUND OF STAFFA', 3, 40, 9999, 4, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6213, '2002-04-19 22:00:00+00', '2012-01-20 12:56:49.100871+00', 'South Meadows', 'SOUTH MEADOWS', 3, 32, 9999, 1, 4, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6218, '1997-09-14 22:00:00+00', '2012-01-20 12:56:49.135618+00', 'Southern Cross Quadrilles', 'SOUTHERN CROSS QUADRILLES', 2, 96, 9999, 4, 4, NULL, 1008, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12035, '2005-02-20 23:00:00+00', '2018-04-02 23:56:36.395343+00', 'Miss Muriel Johnstone''s Jig', 'MISS MURIEL JOHNSTONES JIG', 2, 32, 9999, 1, 3, 42, 777, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12037, '2005-02-20 23:00:00+00', '2018-04-02 23:56:36.679478+00', 'New Year''s Eve', 'NEW YEARS EVE', 2, 32, 9999, 1, 3, 42, 777, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6222, '1997-12-27 23:00:00+00', '2018-04-02 23:56:37.689911+00', 'Southport Jig', 'SOUTHPORT JIG', 2, 32, 9999, 1, 3, 42, 361, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6225, '1997-09-14 22:00:00+00', '2012-01-20 12:56:49.183642+00', 'Spae Wife, The', 'SPAE WIFE', 1, 128, 9999, 4, 4, NULL, 311, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6226, '1997-11-27 23:00:00+00', '2012-01-20 12:56:49.190659+00', 'Spaghetti Junction', 'SPAGHETTI JUNCTION', 4, 64, 5, 1, 4, NULL, 145, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6227, '1997-04-03 22:00:00+00', '2012-01-20 12:56:49.19767+00', 'Spanish Brose', 'SPANISH BROSE', 2, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6232, '1997-09-14 22:00:00+00', '2012-01-20 12:56:49.232812+00', 'Spean Brig', 'SPEAN BRIG', 2, 32, 9999, 1, 2, NULL, 318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6262, '1997-09-14 22:00:00+00', '2012-01-20 12:56:49.44916+00', 'Springs of Banff, The', 'SPRINGS OF BANFF', 3, 72, 9999, 4, 4, NULL, 108, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6223, '1997-04-03 22:00:00+00', '2018-04-02 23:56:37.706732+00', 'Sovereign Of The Seas', 'SOVEREIGN OF THE SEAS', 1, 32, 9999, 1, 3, 42, 352, '1994-01-04', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12040, '2005-02-20 23:00:00+00', '2014-04-07 17:43:35.276167+00', 'Caledonian Society Strathspey', 'CALEDONIAN SOCIETY STRATHSPEY', 3, 32, 9999, 1, 4, 2, 777, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12041, '2005-02-20 23:00:00+00', '2014-04-07 17:55:51.37264+00', 'Clan Campbell', 'CLAN CAMPBELL', 3, 32, 9999, 1, 4, 2, 777, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12046, '2005-02-20 23:00:00+00', '2014-04-07 18:24:26.153315+00', 'Cambridge Roundabout, The', 'CAMBRIDGE ROUNDABOUT', 3, 32, 9999, 1, 4, 1, 777, '2002-08-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12047, '2005-02-20 23:00:00+00', '2014-04-07 18:28:08.76055+00', 'Fourth of July, The', 'FOURTH OF JULY', 1, 32, 9999, 2, 3, 17, 777, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12042, '2005-02-20 23:00:00+00', '2018-04-02 23:56:37.923649+00', 'Sweet and Savory', 'SWEET AND SAVORY', 1, 32, 9999, 1, 3, 42, 777, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6220, '1998-09-20 22:00:00+00', '2016-05-29 21:08:47.760286+00', 'Southern Star', 'SOUTHERN STAR', 1, 32, 9999, 102, 5, 16, 382, NULL, '', 75, '80000/88888/88888/80888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6230, '1998-07-08 22:00:00+00', '2017-07-16 00:49:02.876364+00', 'Sparkling Water', 'SPARKLING WATER', 1, 32, 9999, 1, 4, 11, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12033, '2005-02-20 23:00:00+00', '2018-04-03 00:07:48.448082+00', 'Glen Affric', 'GLEN AFFRIC', 1, 32, 9999, 1, 3, 42, 44, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12043, '2005-02-20 23:00:00+00', '2018-04-02 23:56:38.474237+00', 'Wee Bluets Rule', 'WEE BLUETS RULE', 1, 32, 9999, 1, 3, 42, 777, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12024, '2005-02-20 23:00:00+00', '2018-04-03 00:07:35.300908+00', 'Bow-Legged Bosun, The', 'BOWLEGGED BOSUN', 1, 32, 9999, 1, 3, 42, 44, '2000-05-26', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12034, '2005-02-20 23:00:00+00', '2018-04-03 00:07:48.806533+00', 'Glen Lyon', 'GLEN LYON', 1, 32, 9999, 1, 3, 42, 44, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12007, '2005-02-01 23:00:00+00', '2022-12-22 18:20:45.6029+00', 'Bannockburn', 'BANNOCKBURN', 1, 32, 9999, 4, 4, NULL, 725, '2003-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12030, '2005-02-20 23:00:00+00', '2018-04-03 00:08:00.015477+00', 'Loch Assynt', 'LOCH ASSYNT', 2, 32, 9999, 1, 3, 42, 44, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12032, '2005-02-20 23:00:00+00', '2018-04-03 00:08:00.173849+00', 'Loch Moidart', 'LOCH MOIDART', 1, 32, 9999, 1, 3, 42, 44, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6263, '1997-04-03 22:00:00+00', '2020-08-07 09:37:58.234556+00', 'Spruce Hill', 'SPRUCE HILL', 1, 40, 9999, 1, 2, NULL, 249, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6167, '1997-09-14 22:00:00+00', '2021-04-14 10:41:00.737086+00', 'Snow in Summer', 'SNOW IN SUMMER', 3, 40, 9999, 1, 3, 42, 44, NULL, '', 48, '880/800/888/844/822', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6163, '1999-07-26 22:00:00+00', '2021-04-14 10:57:58.161935+00', 'Snibbet Bibliotheck, The', 'SNIBBET BIBLIOTHECK', 1, 32, 9999, 1, 3, 42, 1278, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6283, '1997-04-03 22:00:00+00', '2021-06-19 22:32:44.21435+00', 'Star Bright', 'STAR BRIGHT', 1, 32, 9999, 4, 4, 1, 352, '1990-06-03', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12031, '2005-02-20 23:00:00+00', '2018-04-03 00:08:03.125996+00', 'Mermaid of Loch Voil, The', 'MERMAID OF LOCH VOIL', 2, 32, 9999, 1, 3, 42, 44, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12026, '2005-02-20 23:00:00+00', '2018-04-03 00:08:09.363995+00', 'Other Left Hand, The', 'OTHER LEFT HAND', 1, 32, 9999, 1, 3, 42, 44, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12028, '2005-02-20 23:00:00+00', '2018-04-03 00:08:13.050358+00', 'Ring of Bright Water', 'RING OF BRIGHT WATER', 1, 32, 9999, 1, 3, 42, 44, '1974-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6194, '1997-04-03 22:00:00+00', '2018-04-03 00:08:17.703517+00', 'Son of the Baker', 'SON OF THE BAKER', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6201, '1997-04-03 22:00:00+00', '2018-04-03 00:08:17.71194+00', 'Soor-Dook Barrels', 'SOORDOOK BARRELS', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6203, '1997-09-14 22:00:00+00', '2018-04-03 00:08:17.720209+00', 'Sorcha''s Delight', 'SORCHAS DELIGHT', 2, 32, 9999, 1, 3, 42, 819, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6215, '1997-09-14 22:00:00+00', '2018-04-03 00:08:17.770235+00', 'Southbay Curve, The', 'SOUTHBAY CURVE', 1, 32, 9999, 1, 3, 42, 691, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6216, '2002-03-02 23:00:00+00', '2018-04-03 00:08:17.786854+00', 'Southern Belle, A', 'SOUTHERN BELLE', 3, 32, 9999, 1, 3, 42, 44, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6211, '1998-04-21 22:00:00+00', '2018-04-03 00:08:17.828579+00', 'South Gate, The', 'SOUTH GATE', 3, 24, 9999, 1, 3, 42, 44, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6228, '1998-04-21 22:00:00+00', '2018-04-03 00:08:17.87036+00', 'Spanish Lady, The', 'SPANISH LADY', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6231, '1997-08-26 22:00:00+00', '2018-04-03 00:08:17.911987+00', 'Spean Bridge', 'SPEAN BRIDGE', 2, 32, 9999, 1, 3, 42, 566, '1981-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12051, '2005-02-20 23:00:00+00', '2019-10-01 00:12:49.71115+00', 'Reel for the Thirty-Fifth, The', 'REEL FOR THE THIRTYFIFTH', 1, 48, 9999, 3, 5, 16, 777, NULL, 'This dance was written to honor 35 years o/Scottish Country Dancing in Cincinnati.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6235, '1997-11-24 23:00:00+00', '2012-01-20 12:56:49.254174+00', 'Speyhead', 'SPEYHEAD', 4, 32, 1, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6237, '1997-11-24 23:00:00+00', '2012-01-20 12:56:49.270777+00', 'Spey Royal', 'SPEY ROYAL', 4, 120, 15, 4, 4, NULL, 536, '1977-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6240, '1997-08-28 22:00:00+00', '2018-02-27 22:00:47.808078+00', 'Sphagnum Moss', 'SPHAGNUM MOSS', 3, 32, 9999, 2, 3, NULL, 108, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6241, '1998-09-23 22:00:00+00', '2012-01-20 12:56:49.3008+00', 'Spinnaker In The Wind', 'SPINNAKER IN THE WIND', 3, 32, 9999, 1, 4, NULL, 385, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12060, '2005-02-23 23:00:00+00', '2018-10-01 08:46:57.088532+00', 'Sue Comes Round Again', 'SUE COMES ROUND AGAIN', 3, 32, 9999, 1, 2, NULL, 3512, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6234, '2002-04-19 22:00:00+00', '2019-03-09 22:00:14.766081+00', 'Spencer Noble''s Strathspey', 'SPENCER NOBLES STRATHSPEY', 3, 32, 9999, 1, 4, 1, 1661, NULL, '', 94, '8888/8484/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6248, '1997-04-03 22:00:00+00', '2012-01-20 12:56:49.350276+00', 'Spirits of Old Pulteney', 'SPIRITS OF OLD PULTENEY', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12049, '2005-02-20 23:00:00+00', '2018-04-02 23:56:33.020495+00', 'Big ''Un, The', 'BIG UN', 2, 40, 9999, 1, 3, 42, 777, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12061, '2005-02-23 23:00:00+00', '2012-01-20 12:57:35.115611+00', 'Mady''s Mixer', 'MADYS MIXER', 3, 32, 9999, 7, 5, NULL, 1862, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12062, '2005-02-23 23:00:00+00', '2012-01-20 12:57:35.12246+00', 'One, Two, Three Chicago', 'ONE TWO THREE CHICAGO', 3, 32, 9999, 6, 3, NULL, 3511, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6265, '1998-01-05 23:00:00+00', '2012-01-20 12:56:49.472233+00', 'Square Tower, The', 'SQUARE TOWER', 1, 64, 9999, 4, 4, NULL, 560, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6269, '2002-03-02 23:00:00+00', '2012-01-20 12:56:49.5004+00', 'Stac Polly', 'STAC POLLY', 1, 48, 9999, 1, 4, NULL, 26, '1987-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6272, '1997-04-03 22:00:00+00', '2012-01-20 12:56:49.521275+00', 'Stampede Jig, The', 'STAMPEDE JIG', 2, 40, 9999, 1, 4, NULL, 39, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6274, '1998-07-09 22:00:00+00', '2012-01-20 12:56:49.536374+00', 'Stan Drew''s Reel', 'STAN DREWS REEL', 1, 40, 9999, 3, 5, 10, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6275, '1997-11-24 23:00:00+00', '2012-01-20 12:56:49.543302+00', 'Stan Drew''s Square', 'STAN DREWS SQUARE', 4, 128, 1, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6279, '1997-04-03 22:00:00+00', '2012-01-20 12:56:49.571014+00', 'Standard, The', 'STANDARD', 3, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6281, '1998-01-05 23:00:00+00', '2012-01-20 12:56:49.584737+00', 'Standing Stones Of Clava', 'STANDING STONES OF CLAVA', 1, 32, 9999, 1, 4, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6244, '1998-01-04 23:00:00+00', '2016-11-15 18:58:13.6544+00', 'Covering the Spey', 'COVERING THE SPEY', 3, 32, 9999, 1, 4, 2, 1228, '1992-11-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12050, '2005-02-20 23:00:00+00', '2018-04-02 23:56:37.480861+00', 'Saint Andrew''s Strathspey', 'SAINT ANDREWS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 777, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12048, '2005-02-20 23:00:00+00', '2018-04-02 23:56:37.973678+00', 'Tenth Anniversary, The', 'TENTH ANNIVERSARY', 4, 32, 1, 1, 3, 42, 777, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6238, '1997-09-14 22:00:00+00', '2018-04-03 00:08:17.9704+00', 'Speyside Rant', 'SPEYSIDE RANT', 3, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6246, '1999-01-05 23:00:00+00', '2018-04-03 00:08:18.045559+00', 'Spiral Glen', 'SPIRAL GLEN', 2, 32, 9999, 1, 3, 42, 2528, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6247, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.053791+00', 'Spirit of the Dance, The', 'SPIRIT OF THE DANCE', 2, 40, 9999, 1, 3, 42, 653, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6251, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.070548+00', 'Spokin'' Four', 'SPOKIN FOUR', 2, 32, 9999, 1, 3, 42, 1286, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6245, '1998-11-25 23:00:00+00', '2020-08-07 09:37:30.074179+00', 'Spinning Wheel, The', 'SPINNING WHEEL', 3, 32, 9999, 1, 3, 42, 82, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12058, '2005-02-23 23:00:00+00', '2020-05-07 22:57:20.485491+00', 'Diligent Devisor, The', 'DILIGENT DEVISOR', 2, 40, 9999, 1, 3, 42, 3511, '2003-01-01', 'Written November 17, 2003 to honor the birthday of the Silk & Thistle class’s prolific dance devisor, Sue McKinnell.', 53, '800/888/888/866/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6217, '1997-04-03 22:00:00+00', '2020-09-03 17:30:15.263984+00', 'Southern Cairn, The', 'SOUTHERN CAIRN', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 56, '844/866/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6249, '1997-08-21 22:00:00+00', '2020-09-03 17:42:04.050117+00', 'Splat the Tattie', 'SPLAT THE TATTIE', 1, 32, 9999, 1, 3, 42, 108, '1991-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12057, '2005-02-23 23:00:00+00', '2021-01-16 20:24:27.757625+00', 'No L''s Strathspey', 'NO LS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2489, '2005-01-01', 'Written by Chuck Snowdon in honor of Noel Chavez for the 25th Anniversary of the Chicago Branch RSCDS.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12055, '2005-02-23 23:00:00+00', '2021-01-16 20:28:15.448982+00', 'Morning After, The', 'MORNING AFTER', 3, 32, 9999, 1, 2, 76, 3510, '2004-01-01', '', 69, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6466, '1997-09-14 22:00:00+00', '2012-01-20 12:56:51.034225+00', 'Tara Frolic', 'TARA FROLIC', 2, 40, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18756, '2018-10-05 05:52:03.483201+00', '2022-06-22 05:58:24.468191+00', 'Flight of Fancy, A', 'FLIGHT OF FANCY', 2, 32, NULL, 1, 3, 42, 2766, '2013-04-01', 'I love this particular cut of music and the dance just popped into my head one night and goes well with this tune.', 63, '844/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6219, '1997-08-21 22:00:00+00', '2022-11-08 16:07:38.629696+00', 'Southern Cross, The', 'SOUTHERN CROSS', 2, 32, 9999, 1, 3, 42, 108, '1991-07-01', 'Inscribed "for the dancers in New Zealand".', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6204, '2002-03-02 23:00:00+00', '2022-11-08 16:12:02.791911+00', 'Sound of Cara, The', 'SOUND OF CARA', 2, 32, 9999, 1, 3, 42, 370, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6270, '1997-04-03 22:00:00+00', '2022-12-02 14:20:25.157232+00', 'Stack of Wheat, The', 'STACK OF WHEAT', 1, 64, 9999, 1, 4, 103, 270, NULL, '', 94, '8888/8888/8888/8888/8888/8448/8888/8448', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6289, '1997-04-03 22:00:00+00', '2021-04-13 09:55:19.758675+00', 'Stars of the South', 'STARS OF THE SOUTH', 1, 32, 9999, 1, 100, 2, 108, '1978-01-01', '', 69, '8008/8008/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6207, '2002-03-02 23:00:00+00', '2021-04-23 00:00:15.675381+00', 'Sound of Luing, The', 'SOUND OF LUING', 3, 32, 9999, 1, 3, 42, 304, '1976-01-01', '', 48, '800/880/886/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6254, '1997-04-03 22:00:00+00', '2021-04-13 22:45:56.575155+00', 'Sprig of Heather, A', 'SPRIG OF HEATHER', 2, 48, 9999, 3, 5, 7, 44, '1968-01-01', 'From the notes: "Devised for Elaine Wilson (now Laidlaw) to celebrate her twenty-first birthday."', 63, '88880/80800/80800/82842/80888/80888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6253, '1998-04-08 22:00:00+00', '2018-04-03 00:08:18.087165+00', 'Sportsman''s Charity Reel', 'SPORTSMANS CHARITY REEL', 1, 32, 9999, 1, 3, 42, 184, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6256, '1997-04-03 22:00:00+00', '2018-04-03 00:08:18.112238+00', 'Spriggs Of Laurel', 'SPRIGGS OF LAUREL', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6257, '1997-04-03 22:00:00+00', '2018-04-03 00:08:18.137254+00', 'Spring Bouquet, A', 'SPRING BOUQUET', 3, 32, 9999, 1, 3, 42, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6258, '1998-01-04 23:00:00+00', '2018-04-03 00:08:18.14561+00', 'Spring Breeze', 'SPRING BREEZE', 1, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6260, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.153893+00', 'Springburn Weaver', 'SPRINGBURN WEAVER', 3, 32, 9999, 1, 3, 42, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6266, '2003-01-25 23:00:00+00', '2018-04-03 00:08:18.220648+00', 'Square Walls Of Arundel Castle', 'SQUARE WALLS OF ARUNDEL CASTLE', 3, 40, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6280, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.287335+00', 'Standburn Lass, The', 'STANDBURN LASS', 2, 32, 9999, 1, 3, 42, 964, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6277, '1997-08-25 22:00:00+00', '2018-04-03 00:08:18.295629+00', 'Stand Fast', 'STAND FAST', 1, 32, 9999, 1, 3, 42, 548, '1977-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6278, '1997-04-03 22:00:00+00', '2018-04-03 00:08:18.304008+00', 'Stand Fast, Craigellachie', 'STAND FAST CRAIGELLACHIE', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6276, '1997-04-03 22:00:00+00', '2018-04-03 00:08:18.337359+00', 'Stan Saunder''s Hornpipe', 'STAN SAUNDERS HORNPIPE', 1, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6284, '1997-04-03 22:00:00+00', '2012-01-20 12:56:49.60625+00', 'Star of the County Down', 'STAR OF THE COUNTY DOWN', 2, 88, 9999, 4, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6288, '1997-09-14 22:00:00+00', '2012-01-20 12:56:49.635258+00', 'Stars And Moons', 'STARS AND MOONS', 2, 64, 9999, 1, 4, NULL, 1288, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18979, '2018-10-17 12:17:22.549692+00', '2018-10-17 12:17:22.549692+00', '60 Years On', '60 YEARS ON', 2, 48, NULL, 1, 4, 1, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12066, '2005-02-23 23:00:00+00', '2012-01-20 12:57:35.150298+00', 'Champagne Toast', 'CHAMPAGNE TOAST', 2, 32, 9999, 1, 4, 13, 3515, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12069, '2005-02-23 23:00:00+00', '2012-01-20 12:57:35.171437+00', 'Trilliums and Cherry Blossom', 'TRILLIUMS AND CHERRY BLOSSOM', 3, 40, 9999, 1, 4, 1, 1836, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12070, '2005-02-23 23:00:00+00', '2012-01-20 12:57:35.176965+00', 'Border Cities Jig', 'BORDER CITIES JIG', 2, 32, 9999, NULL, NULL, NULL, 1836, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12072, '2005-02-28 23:00:00+00', '2012-01-20 12:57:35.192533+00', 'Circle of Friends', 'CIRCLE OF FRIENDS', 1, 32, 9999, 4, 4, NULL, 3517, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6298, '1998-01-04 23:00:00+00', '2012-01-20 12:56:49.705443+00', 'Steel City Reel', 'STEEL CITY REEL', 2, 32, 9999, 1, 4, NULL, 1289, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6300, '1997-09-14 22:00:00+00', '2012-01-20 12:56:49.719095+00', 'Step Tae It', 'STEP TAE IT', 1, 80, 9999, 3, 5, NULL, 658, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12087, '2005-03-16 23:00:00+00', '2018-04-03 00:07:36.677742+00', 'Cameron Highlands', 'CAMERON HIGHLANDS', 1, 64, 9999, 1, 3, 42, 1047, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6304, '1997-04-03 22:00:00+00', '2012-01-20 12:56:49.746965+00', 'Steps Of Trool, The', 'STEPS OF TROOL', 3, 32, 9999, 1, 2, NULL, 392, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6308, '1997-09-14 22:00:00+00', '2012-01-20 12:56:49.774616+00', 'Stirling Bridge', 'STIRLING BRIDGE', 1, 48, 9999, 1, 4, NULL, 1290, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6313, '1997-04-03 22:00:00+00', '2012-01-20 12:56:49.810947+00', 'Stirling Twosome, The', 'STIRLING TWOSOME', 3, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6315, '1997-04-03 22:00:00+00', '2012-01-20 12:56:49.824618+00', 'Stitch In Time, A', 'STITCH IN TIME', 3, 32, 9999, 1, 4, NULL, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6320, '1997-04-03 22:00:00+00', '2012-01-20 12:56:49.861759+00', 'Stonemason''s Apprentice', 'STONEMASONS APPRENTICE', 3, 96, 9999, 4, 8, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12077, '2005-02-28 23:00:00+00', '2012-01-20 12:57:35.229716+00', 'Mind Reader, The', 'MIND READER', 1, 32, 9999, 2, 3, 4, 3517, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12078, '2005-03-03 23:00:00+00', '2012-01-20 12:57:35.238755+00', 'Ayla Strathspey, The', 'AYLA STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 9, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12081, '2005-03-10 23:00:00+00', '2012-01-20 12:57:35.264997+00', 'Double Helix, The', 'DOUBLE HELIX', 2, 96, 9999, 4, 4, NULL, 3519, '1974-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12084, '2005-03-15 23:00:00+00', '2012-01-20 12:57:35.284102+00', 'Logie''s Strathspey', 'LOGIES STRATHSPEY', 3, 32, 9999, 1, 4, 1, 2907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12088, '2005-03-16 23:00:00+00', '2012-01-20 12:57:35.320654+00', 'Dusky Glen, The', 'DUSKY GLEN', 3, 40, 9999, 2, 3, 17, 1047, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6356, '1997-09-14 22:00:00+00', '2012-01-20 12:56:50.115757+00', 'Strathwhillan', 'STRATHWHILLAN', 1, 40, 9999, 4, 4, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6297, '1997-09-14 22:00:00+00', '2016-05-25 20:54:33.02222+00', 'Steamboat, The', 'STEAMBOAT', 1, 48, 9999, 1, 100, 2, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6309, '1997-04-03 22:00:00+00', '2020-08-07 09:40:59.135571+00', 'Stirling Brig', 'STIRLING BRIG', 1, 32, 9999, 1, 4, 1, 82, NULL, '', 81, '8080/8888/8888/8484', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6316, '1997-09-14 22:00:00+00', '2020-08-07 09:41:34.816981+00', 'Stobhall', 'STOBHALL', 2, 128, 9999, 4, 4, NULL, 129, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6252, '1997-09-14 22:00:00+00', '2020-09-03 17:44:14.361639+00', 'Sport Of The Chase, The', 'SPORT OF THE CHASE', 1, 32, 9999, 1, 3, 42, 44, NULL, '', 41, '800/844/844/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6306, '1997-08-20 22:00:00+00', '2020-09-03 17:47:33.81248+00', 'Stewart''s Lassie', 'STEWARTS LASSIE', 3, 32, 9999, 7, 2, 76, 101, '1993-01-01', '', 94, '88/66/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6319, '2002-04-14 22:00:00+00', '2021-04-12 22:38:14.077105+00', 'Stone of Destiny, The', 'STONE OF DESTINY', 3, 40, 9999, 1, 4, 1, 108, '1971-01-01', '', 82, '8686/8888/8008/8484/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12086, '2005-03-16 23:00:00+00', '2020-09-15 08:36:24.133444+00', 'Dance for Ivy, A', 'DANCE FOR IVY', 1, 32, 9999, 1, 3, 42, 727, '2002-01-01', '', 50, '800/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12076, '2005-02-28 23:00:00+00', '2021-01-16 20:04:29.594977+00', 'Dublin''s Farewell to the Boodes', 'DUBLINS FAREWELL TO THE BOODES', 1, 64, 9999, 1, 4, 1, 3517, '2004-01-01', '', 74, '8888/8228/0882/0888/4444/4444/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12074, '2005-02-28 23:00:00+00', '2021-01-16 20:10:00.969761+00', 'Lady Ryder of Warsaw', 'LADY RYDER OF WARSAW', 3, 48, 9999, 1, 4, 1, 2560, '1992-01-01', '', 75, '8282/4848/6868/8888/8844/8044', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12073, '2005-02-28 23:00:00+00', '2021-01-16 20:15:31.325287+00', 'Arizona Welcome, An', 'ARIZONA WELCOME', 2, 40, 9999, 1, 3, 42, 3517, '1998-01-01', '', 45, '800/844/800/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6318, '1997-09-14 22:00:00+00', '2021-04-08 10:49:10.874293+00', 'Stone Mountain Reel, The', 'STONE MOUNTAIN REEL', 1, 32, 9999, 1, 4, 1, 358, NULL, '', 44, '8220/8440/8660/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6317, '1997-09-14 22:00:00+00', '2021-04-12 22:46:22.927123+00', 'Stone Court, The', 'STONE COURT', 2, 32, 9999, 1, 2, 76, 44, NULL, 'The notes for the dance say it is dedicated to the many new friends made by Noeline O''Connor and lain Boyd during their world trip in 1984.', 56, '46/64/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6299, '1997-11-27 23:00:00+00', '2021-04-13 09:40:52.18126+00', 'Steeple Rock', 'STEEPLE ROCK', 4, 48, 14, 1, 3, 42, 44, '1988-01-01', '', 54, '888/800/888/800/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6285, '2002-04-14 22:00:00+00', '2021-04-13 09:58:35.13167+00', 'Star, The', 'STAR', 3, 32, 9999, 2, 3, 17, 9998, NULL, '', 75, '844/484/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12091, '2005-03-16 23:00:00+00', '2021-01-17 16:46:41.707058+00', 'Five-Couple Jimmy''s Fancy', 'FIVECOUPLE JIMMYS FANCY', 3, 32, 9999, 3, 5, 7, 1047, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6310, '1997-04-03 22:00:00+00', '2022-11-08 16:00:34.95449+00', 'Stirling Castle', 'STIRLING CASTLE', 3, 32, 9999, 1, 2, 76, 392, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6312, '2001-06-12 22:00:00+00', '2022-12-18 20:29:37.517757+00', 'Stirling Tensome, A', 'STIRLING TENSOME', 2, 32, 9999, 3, 5, NULL, 991, '1969-03-01', 'The leaflet states: "To commemorate the tenth anniversary of The Stirling Castle Scottish Country Dance Group."', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6311, '2002-04-14 22:00:00+00', '2021-07-06 20:33:42.779493+00', 'Stirling Castle', 'STIRLING CASTLE', 3, 32, 9999, 1, 4, 1, 103, '1961-01-01', 'Also published as a separate 4 page leaflet, with the music, by the Stirling Scottish Country Dance Group (information from <<https://my.strathspey.org/dd/issue/2518/|issue 2518>>).', 75, '8008/8668/8888/8444', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6301, '1998-04-19 22:00:00+00', '2021-05-13 11:35:36.894821+00', 'Stepping Stones', 'STEPPING STONES', 1, 32, 9999, 1, 3, 42, 352, '1993-01-12', '', 38, '800/800/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6292, '1997-04-03 22:00:00+00', '2021-06-15 10:44:46.421616+00', 'Statuette, The', 'STATUETTE', 1, 32, 9999, 1, 2, 76, 352, '1993-04-17', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12065, '2005-02-23 23:00:00+00', '2018-04-03 00:07:51.817417+00', 'Hello Neighbor', 'HELLO NEIGHBOR', 2, 32, 9999, 1, 3, 42, 3514, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6291, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.370768+00', 'Station Master''s Jig, The', 'STATION MASTERS JIG', 2, 32, 9999, 1, 3, 42, 29, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6293, '1997-04-03 22:00:00+00', '2018-04-03 00:08:18.379098+00', 'Staying Power', 'STAYING POWER', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6296, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.387401+00', 'Steamboat, The', 'STEAMBOAT', 1, 48, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6302, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.445761+00', 'Stepping Stones, The', 'STEPPING STONES', 3, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6303, '1997-04-03 22:00:00+00', '2018-04-03 00:08:18.454183+00', 'Stepping Through The Barley', 'STEPPING THROUGH THE BARLEY', 3, 40, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6305, '1998-04-19 22:00:00+00', '2018-04-03 00:08:18.462488+00', 'Sterling Of Caulder', 'STERLING OF CAULDER', 1, 32, 9999, 1, 3, 42, 401, '1978-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6307, '1997-04-03 22:00:00+00', '2018-04-03 00:08:18.504187+00', 'Stinky Willie', 'STINKY WILLIE', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6314, '1997-09-11 22:00:00+00', '2018-04-03 00:08:18.520824+00', 'Stitch In Time', 'STITCH IN TIME', 1, 32, 9999, 1, 3, 42, 31, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12075, '2005-02-28 23:00:00+00', '2018-04-03 00:08:19.371435+00', 'Susan Sirvain', 'SUSAN SIRVAIN', 1, 32, 9999, 1, 3, 42, 3517, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12067, '2005-02-23 23:00:00+00', '2018-04-03 00:08:20.438811+00', 'Thanks to the Gillans Jig', 'THANKS TO THE GILLANS JIG', 2, 32, 9999, 1, 3, 42, 3516, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5107, '2001-05-03 22:00:00+00', '2012-11-02 12:23:47.447701+00', 'Orca', 'ORCA', 2, 24, 9999, 1, 3, 42, 352, '1993-01-01', 'Note:  3rd couple does nothing.



Strathspey Message From: "Barry Skelton" <barry.skelton@clear.net.nz> Date: Fri, 10 Dec 1999 17:38:47 +1300



ORCA





8 X 24 bar Reel Devised by Barry Skelton 1st November. 1993



Suitable Music: Teviot Bridge



Record: R.S.C.D.S. Book 5 (Kenny Thomson)



A reel for three couples, danced in a longwise four couple set.



bars



1-8 First couple, turn with the right hand and cast off one place. Second couple step up on bars 3 and 4. First couple dance down between third couple and dance up around them to finish with first couple up between second couple. (Ready for a tandem reel across the dance.)



9-16 First couple dancing in tandem with first lady leading, dance a reel of three across the dance with second couple. *



17-24 First couple, dance up between second couple and cast off to second place First couple turn with the right hand.



First couple repeat from second place.



* (First couple pass second lady with the right shoulder and turn by the right, first couple with first man leading will pass second man with a right shoulder, first couple will pass second lady with a left shoulder and turn by the left, first couple with first lady leading will pass second man with a left shoulder to finish between second couple.)



', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12093, '2005-03-16 23:00:00+00', '2018-04-15 10:16:59.452679+00', 'Weakest Link, The', 'WEAKEST LINK', 3, 32, 9999, 1, 4, 1, 1047, '2002-02-05', 'Inspired by the ''ruthless quiz'' on BBC TV. 2nd, 3rd and 4th couples are successively dropped.', 71, '8484/8888/8088/8004', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6324, '1997-09-14 22:00:00+00', '2012-01-20 12:56:49.889314+00', 'Stork Town Jig', 'STORK TOWN JIG', 2, 40, 9999, 1, 4, NULL, 1291, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12095, '2005-03-16 23:00:00+00', '2018-04-15 10:45:17.508076+00', 'Lindisfarne Strathspey, The', 'LINDISFARNE STRATHSPEY', 3, 32, 9999, 1, 4, 2, 1047, '2003-05-29', '', 90, '4884/8668/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6329, '1997-04-03 22:00:00+00', '2012-01-20 12:56:49.926295+00', 'Stow is Still Alert', 'STOW IS STILL ALERT', 2, 32, 9999, 1, 4, NULL, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6330, '1997-04-03 22:00:00+00', '2012-01-20 12:56:49.933821+00', 'Stranger''s Welcome, The', 'STRANGERS WELCOME', 4, 32, 1, 1, 4, 1, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12096, '2005-03-16 23:00:00+00', '2018-09-12 20:29:52.488871+00', 'Neidpath Five', 'NEIDPATH FIVE', 3, 32, 9999, 3, 5, 7, 1047, '2002-05-02', '', 80, '88888/88888/04444/88448', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18757, '2018-10-05 06:04:40.270949+00', '2018-10-05 06:04:40.270949+00', 'Flip Flop', 'FLIP FLOP', 2, 32, NULL, 2, 3, NULL, 2766, '2015-03-01', 'I was intrigued by the idea of swapping ends of the set each time through a dance and wrote several dances to try it out. This is the jig.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6333, '1997-09-14 22:00:00+00', '2012-01-20 12:56:49.954439+00', 'Strathaven', 'STRATHAVEN', 3, 32, 9999, 2, 3, NULL, 480, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6335, '2002-04-19 22:00:00+00', '2012-01-20 12:56:49.968098+00', 'Strathavon Strathspey', 'STRATHAVON STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6341, '1997-04-03 22:00:00+00', '2019-03-09 21:46:31.567454+00', 'Strathcona Reel', 'STRATHCONA REEL', 1, 32, 9999, 1, 4, 1, 107, NULL, '', 63, '8000/0800/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6338, '1997-04-03 22:00:00+00', '2012-01-20 12:56:49.988722+00', 'Strathclyde Jig', 'STRATHCLYDE JIG', 2, 48, 9999, 1, 4, NULL, 342, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6339, '1997-09-14 22:00:00+00', '2012-01-20 12:56:49.995646+00', 'Strathcona Assembly', 'STRATHCONA ASSEMBLY', 3, 32, 9999, 1, 4, NULL, 1292, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6340, '1997-04-03 22:00:00+00', '2012-01-20 12:56:50.002963+00', 'Strathcona Jig', 'STRATHCONA JIG', 2, 32, 9999, 3, 5, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6342, '1997-09-29 22:00:00+00', '2012-01-20 12:56:50.016646+00', 'Strathcona Strathspey', 'STRATHCONA STRATHSPEY', 3, 32, 9999, 1, 98, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6343, '1997-09-14 22:00:00+00', '2012-01-20 12:56:50.023455+00', 'Strathcona-Davie Strathspey', 'STRATHCONADAVIE STRATHSPEY', 3, 32, 9999, 4, 4, NULL, 9, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6345, '1997-04-03 22:00:00+00', '2012-01-20 12:56:50.037144+00', 'Strathearn Strathspey', 'STRATHEARN STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14603, '2012-12-04 21:37:35.095154+00', '2019-07-27 11:28:50.810542+00', 'Tailored for Christine', 'TAILORED FOR CHRISTINE', 2, 32, 9999, 1, 4, 11, 3445, '2003-01-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12098, '2005-03-16 23:00:00+00', '2012-01-20 12:57:35.410836+00', 'Short and Sweet', 'SHORT AND SWEET', 1, 32, 9999, 1, 4, NULL, 1047, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12100, '2005-03-16 23:00:00+00', '2012-01-20 12:57:35.429236+00', 'Joyce''s Jubilation', 'JOYCES JUBILATION', 1, 32, 9999, 5, 2, NULL, 1047, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12101, '2005-03-16 23:00:00+00', '2012-01-20 12:57:35.438737+00', 'Caerleon ''03', 'CAERLEON 03', 3, 32, 9999, 1, 4, 5, 1047, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12102, '2005-03-16 23:00:00+00', '2012-01-20 12:57:35.448237+00', 'Mr Dowling''s Delight', 'MR DOWLINGS DELIGHT', 1, 32, 9999, 1, 4, 1, 1047, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12103, '2005-03-16 23:00:00+00', '2012-01-20 12:57:35.457745+00', 'Saint Andrew''s Eve', 'SAINT ANDREWS EVE', 3, 32, 9999, 1, 4, 5, 1047, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6321, '1997-04-03 22:00:00+00', '2018-04-03 00:08:18.546265+00', 'Stones of Clava, The', 'STONES OF CLAVA', 1, 40, 9999, 1, 3, 42, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6352, '2002-02-12 23:00:00+00', '2012-01-20 12:56:50.085328+00', 'Strathspey for Stella', 'STRATHSPEY FOR STELLA', 3, 40, 9999, 4, 4, NULL, 222, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6353, '1997-04-03 22:00:00+00', '2012-01-20 12:56:50.092804+00', 'Strathspey of Strone', 'STRATHSPEY OF STRONE', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14602, '2012-12-03 22:16:05.35117+00', '2016-06-03 13:59:37.357378+00', 'First Snow of December, The', 'FIRST SNOW OF DECEMBER', 2, 32, NULL, 1, 2, 76, 228, '2012-12-03', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12094, '2005-03-16 23:00:00+00', '2021-01-16 18:19:19.088673+00', 'Palindrome Reel, The', 'PALINDROME REEL', 1, 32, 9999, 2, 3, 17, 1047, '2000-11-01', '', 67, '800/888/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12063, '2005-02-23 23:00:00+00', '2021-01-16 20:17:41.860597+00', 'Year of Dance, A', 'YEAR OF DANCE', 3, 32, 9999, 1, 3, 42, 3513, NULL, '', 44, '808/844/800/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6465, '1997-04-03 22:00:00+00', '2012-01-20 12:56:51.027444+00', 'Tara Brooch', 'TARA BROOCH', 2, 96, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6325, '1998-04-19 22:00:00+00', '2018-04-03 00:08:18.579247+00', 'Storms Of Rockall', 'STORMS OF ROCKALL', 2, 32, 9999, 1, 3, 42, 212, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6331, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.654361+00', 'Strathalbyn Jig', 'STRATHALBYN JIG', 2, 40, 9999, 1, 3, 42, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6332, '1997-04-03 22:00:00+00', '2018-04-03 00:08:18.66281+00', 'Strathallan Castle', 'STRATHALLAN CASTLE', 3, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6334, '2002-11-13 23:00:00+00', '2018-04-03 00:08:18.670966+00', 'Strathaven Rant', 'STRATHAVEN RANT', 1, 32, 9999, 1, 3, 42, 394, '1980-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6344, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.68764+00', 'Strathearn Reel, The', 'STRATHEARN REEL', 1, 32, 9999, 1, 3, 42, 176, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6346, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.695848+00', 'Stratheden Jig', 'STRATHEDEN JIG', 2, 32, 9999, 1, 3, 42, 120, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6351, '2002-04-19 22:00:00+00', '2018-04-03 00:08:18.796061+00', 'Strathspey for September, A', 'STRATHSPEY FOR SEPTEMBER', 3, 32, 9999, 1, 3, 42, 172, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6395, '1997-04-03 22:00:00+00', '2018-09-04 12:57:11.755955+00', 'Sunset On The Tay', 'SUNSET ON THE TAY', 3, 32, 9999, 2, 3, 17, 173, '1989-10-11', '', 79, '888/822/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12306, '2005-04-25 22:00:00+00', '2018-10-05 06:12:00.341455+00', 'Mairi''s Flowers', 'MAIRIS FLOWERS', 1, 32, 9999, 1, 3, 42, 2766, '2004-03-01', 'This dance was written for Mike Fitak, a dancer who loves to flirt while dancing.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6364, '1997-04-03 22:00:00+00', '2012-01-20 12:56:50.175528+00', 'Stuart Town Welcomes John Drewry', 'STUART TOWN WELCOMES JOHN DREWRY', 3, 32, 9999, 1, 4, NULL, 108, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6375, '2002-11-28 23:00:00+00', '2019-03-09 21:42:38.703659+00', 'Sugar On Snow', 'SUGAR ON SNOW', 3, 32, 9999, 2, 3, 18, 480, '1987-05-31', '', 88, '888/888/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6374, '1997-04-03 22:00:00+00', '2012-01-20 12:56:50.2523+00', 'Sugar Mountain Breakdown', 'SUGAR MOUNTAIN BREAKDOWN', 1, 40, 9999, 1, 2, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6378, '1997-09-14 22:00:00+00', '2012-01-20 12:56:50.279544+00', 'Sullivan''s Rant', 'SULLIVANS RANT', 1, 32, 9999, 1, 4, NULL, 650, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12116, '2005-03-23 23:00:00+00', '2018-04-03 00:07:38.238519+00', 'Cheviot Ramble, The', 'CHEVIOT RAMBLE', 3, 32, 9999, 1, 3, 42, 881, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12112, '2005-03-23 23:00:00+00', '2012-01-20 12:57:35.537762+00', 'Merse Medley, The', 'MERSE MEDLEY', 4, 32, 1, 3, 5, NULL, 3525, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12113, '2005-03-23 23:00:00+00', '2012-01-20 12:57:35.546373+00', 'Greetings', 'GREETINGS', 1, 32, 9999, 5, 2, NULL, 3527, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12115, '2005-03-23 23:00:00+00', '2018-04-03 00:07:43.585107+00', 'Duns Dings A''', 'DUNS DINGS A', 1, 32, 9999, 1, 3, 42, 3528, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12109, '2005-03-23 23:00:00+00', '2018-04-03 00:07:43.593462+00', 'Duns Golden Years', 'DUNS GOLDEN YEARS', 1, 32, 9999, 1, 3, 42, 3524, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6396, '1997-09-14 22:00:00+00', '2012-01-20 12:56:50.425975+00', 'Sunshine Medley', 'SUNSHINE MEDLEY', 4, 64, 9999, 1, 4, NULL, 916, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6403, '1997-09-14 22:00:00+00', '2012-01-20 12:56:50.489929+00', 'Susi Newman', 'SUSI NEWMAN', 4, 32, 9999, 4, 4, NULL, 90, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12118, '2005-03-23 23:00:00+00', '2012-01-20 12:57:35.591303+00', 'Market Place', 'MARKET PLACE', 3, 32, 9999, 1, 4, 2, 3529, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12119, '2005-03-23 23:00:00+00', '2012-01-20 12:57:35.600014+00', 'Gunsgreen House', 'GUNSGREEN HOUSE', 3, 80, 9999, 4, 98, NULL, 3529, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12125, '2005-04-10 22:00:00+00', '2012-01-20 12:57:35.654073+00', 'Day at the Fair, A', 'DAY AT THE FAIR', 2, 32, 9999, 5, 2, NULL, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12126, '2005-04-10 22:00:00+00', '2012-01-20 12:57:35.662748+00', 'Summer Frolic, A', 'SUMMER FROLIC', 2, 48, 9999, 1, 4, NULL, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12127, '2005-04-10 22:00:00+00', '2012-01-20 12:57:35.671414+00', 'Tribute to Robert, A', 'TRIBUTE TO ROBERT', 2, 32, 9999, 1, 4, NULL, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12104, '2005-03-20 23:00:00+00', '2016-09-06 07:27:25.918091+00', 'Calzona Ramble', 'CALZONA RAMBLE', 1, 32, 9999, 1, 3, 42, 11250, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12111, '2005-03-23 23:00:00+00', '2018-04-03 00:08:01.974991+00', 'Marchmont House', 'MARCHMONT HOUSE', 1, 32, 9999, 1, 3, 42, 3526, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12114, '2005-03-23 23:00:00+00', '2018-04-03 00:08:01.983456+00', 'Marchmont Strathspey, The', 'MARCHMONT STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3526, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12123, '2005-03-29 22:00:00+00', '2018-04-03 00:08:16.819513+00', 'Silver Spirtle, The', 'SILVER SPIRTLE', 1, 32, 9999, 1, 3, 42, 3533, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6365, '1997-04-03 22:00:00+00', '2018-04-03 00:08:18.879403+00', 'Stuart''s Fancy', 'STUARTS FANCY', 3, 32, 9999, 1, 3, 42, 365, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6366, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.887744+00', 'Stuart''s Rant', 'STUARTS RANT', 1, 32, 9999, 1, 3, 42, 976, '1740-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6369, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.896102+00', 'Such Tomfoolery!', 'SUCH TOMFOOLERY', 1, 32, 9999, 1, 3, 42, 1125, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6370, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.905161+00', 'Sue''s Dance', 'SUES DANCE', 1, 40, 9999, 1, 3, 42, 488, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6372, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.912789+00', 'Sugar Bush Frolic', 'SUGAR BUSH FROLIC', 1, 32, 9999, 1, 3, 42, 1295, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6376, '1997-04-03 22:00:00+00', '2018-04-03 00:08:18.945996+00', 'Suilean Donn''', 'SUILEAN DONN', 1, 32, 9999, 1, 3, 42, 392, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6377, '1998-01-04 23:00:00+00', '2018-04-03 00:08:18.954301+00', 'Suilean Gorma', 'SUILEAN GORMA', 1, 32, 9999, 1, 3, 42, 392, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6385, '1997-04-03 22:00:00+00', '2018-04-03 00:08:19.162964+00', 'Summer Sunset', 'SUMMER SUNSET', 3, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6371, '1998-07-08 22:00:00+00', '2020-02-08 20:13:23.13289+00', 'Suffolk Lanes', 'SUFFOLK LANES', 2, 48, 9999, 1, 100, 11, 943, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6363, '1997-04-03 22:00:00+00', '2020-01-31 03:48:20.600922+00', 'Stuart Of Bute', 'STUART OF BUTE', 3, 32, 9999, 1, 3, 42, 13, NULL, '', 50, '844/808/880/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6397, '1998-11-02 23:00:00+00', '2021-04-11 23:13:19.219508+00', 'Sunshine Village Ramble', 'SUNSHINE VILLAGE RAMBLE', 3, 40, 9999, 1, 4, 1, 118, '1972-01-01', 'Devised in 1972 for a ski weekend in Sunshine Village, Banff National Park, Alberta.', 55, '8880/8800/8000/8044/8088', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6379, '1997-04-03 22:00:00+00', '2020-12-16 22:07:55.963255+00', 'Sumburgh Roost', 'SUMBURGH ROOST', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 63, '800/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12121, '2005-03-26 23:00:00+00', '2021-01-15 20:51:28.048353+00', 'Julia', 'JULIA', 3, 48, 9999, 1, 4, 13, 3358, '1994-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12120, '2005-03-26 23:00:00+00', '2021-01-15 20:54:05.868791+00', 'Jan Harmon''s Reel', 'JAN HARMONS REEL', 1, 32, 9999, 1, 3, 42, 3531, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12105, '2005-03-20 23:00:00+00', '2021-01-15 20:58:23.744109+00', 'Canny Tails fae Aberdeen', 'CANNY TAILS FAE ABERDEEN', 2, 32, 9999, 1, 3, 42, 1, NULL, '', 56, '800/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6360, '1997-09-06 22:00:00+00', '2021-01-30 11:28:20.885346+00', 'Stroangassel', 'STROANGASSEL', 1, 32, 9999, 1, 3, 42, 129, '1969-01-01', 'Stroangassel is a stone circle of about 20 cairns just north of Dalry where Hugh Foss used to live.', 49, '800/880/888/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12117, '2005-03-23 23:00:00+00', '2021-03-22 12:07:45.633213+00', 'Berwickshire', 'BERWICKSHIRE', 1, 32, 9999, 3, 5, 7, 3527, NULL, '', 70, '88888/80800/84844/84844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6348, '1998-01-05 23:00:00+00', '2021-04-12 22:14:56.492292+00', 'Strathgade Reel, The', 'STRATHGADE REEL', 1, 40, 9999, 1, 3, 42, 917, NULL, '', 69, '866/888/864/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6392, '1997-04-03 22:00:00+00', '2021-05-15 14:47:39.974175+00', 'Sunday Stroll, A', 'SUNDAY STROLL', 2, 32, 9999, 1, 2, 76, 352, '1993-01-16', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6383, '1997-04-03 22:00:00+00', '2021-06-19 20:35:22.856025+00', 'Summer in Winter', 'SUMMER IN WINTER', 3, 32, 9999, 1, 3, 42, 352, '1990-01-01', 'The inscription to the dance (in the Red Book) reads "June is summer in Scotland and winter in New Zealand. June is also my wife".', 41, '800/822/844/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6388, '1997-09-14 22:00:00+00', '2018-04-03 00:08:19.19639+00', 'Sun Assembly', 'SUN ASSEMBLY', 1, 32, 9999, 1, 3, 42, 466, '1757-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6401, '1997-04-03 22:00:00+00', '2022-08-20 19:03:27.640933+00', 'Susan''s Delight', 'SUSANS DELIGHT', 3, 32, 9999, 1, 4, 1, 211, NULL, 'Inscribed "For our elder daughter".', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6398, '2002-11-29 23:00:00+00', '2018-04-03 00:08:19.329736+00', 'Sure And Steadfast', 'SURE AND STEADFAST', 1, 32, 9999, 1, 3, 42, 2621, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6400, '1997-04-03 22:00:00+00', '2018-04-03 00:08:19.346455+00', 'Susan Jane''s Jig', 'SUSAN JANES JIG', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6402, '1997-09-14 22:00:00+00', '2018-04-03 00:08:19.354706+00', 'Susanna Of Glen Rosa', 'SUSANNA OF GLEN ROSA', 1, 32, 9999, 1, 3, 42, 706, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6462, '1997-09-14 22:00:00+00', '2018-04-03 00:08:19.880165+00', 'Tappit Hen, The', 'TAPPIT HEN', 1, 32, 9999, 1, 3, 42, 90, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6433, '1998-04-21 22:00:00+00', '2018-08-18 09:59:16.578972+00', 'Tae Ane An'' A''', 'TAE ANE AN A', 2, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12129, '2005-04-10 22:00:00+00', '2012-01-20 12:57:35.689033+00', 'Alice''s Jig', 'ALICES JIG', 2, 32, 9999, 1, 4, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12130, '2005-04-10 22:00:00+00', '2012-01-20 12:57:35.698077+00', 'Alison''s Lament', 'ALISONS LAMENT', 3, 64, 9999, 4, 4, NULL, 3537, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6408, '1997-09-14 22:00:00+00', '2012-01-20 12:56:50.533483+00', 'Sutters'' Reel', 'SUTTERS REEL', 1, 32, 9999, 4, 4, NULL, 734, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6409, '2002-04-28 22:00:00+00', '2012-01-20 12:56:50.542348+00', 'Sutton Strathspey, The', 'SUTTON STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18981, '2018-10-17 12:24:39.838391+00', '2019-01-29 00:20:23.771071+00', 'Ann''s Wee Break', 'ANNS WEE BREAK', 1, 32, NULL, 1, 3, 42, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6415, '1997-04-03 22:00:00+00', '2012-01-20 12:56:50.595605+00', 'Sweet 16', 'SWEET 16', 3, 16, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6432, '1997-04-03 22:00:00+00', '2019-03-09 20:05:17.34081+00', 'Tae Gar Ye Loup', 'TAE GAR YE LOUP', 3, 40, 9999, 1, 4, 1, 108, '1968-01-01', '', 88, '8888/8888/8008/8888/8488', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6443, '1997-08-27 22:00:00+00', '2019-06-01 12:54:34.328377+00', 'Talisker', 'TALISKER', 1, 32, 9999, 1, 2, NULL, 537, '1977-01-01', '', 39, '80/28/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6425, '2003-01-25 23:00:00+00', '2012-01-20 12:56:50.686196+00', 'Sword And The Rose, The', 'SWORD AND THE ROSE', 3, 40, 9999, 1, 4, 1, 35, '1978-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6435, '1997-04-03 22:00:00+00', '2012-01-20 12:56:50.775614+00', 'Tail Of My Coat', 'TAIL OF MY COAT', 2, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12132, '2005-04-10 22:00:00+00', '2012-01-20 12:57:35.715511+00', 'Amersham Fair', 'AMERSHAM FAIR', 2, 48, 9999, 1, 4, NULL, 3462, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12133, '2005-04-10 22:00:00+00', '2012-01-20 12:57:35.724324+00', 'Annie''s Antics', 'ANNIES ANTICS', 1, 32, 9999, 1, 4, NULL, 385, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12134, '2005-04-10 22:00:00+00', '2012-01-20 12:57:35.73322+00', 'Saint Machar Jig, The', 'SAINT MACHAR JIG', 2, 32, 9999, 1, 2, NULL, 108, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12137, '2005-04-10 22:00:00+00', '2012-01-20 12:57:35.751052+00', 'Around Loch Affric', 'AROUND LOCH AFFRIC', 3, 32, 9999, 1, 4, NULL, 3539, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12138, '2005-04-10 22:00:00+00', '2012-01-20 12:57:35.759806+00', 'Auld Luckie', 'AULD LUCKIE', 3, 32, 9999, 2, 3, NULL, 57, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12139, '2005-04-10 22:00:00+00', '2012-01-20 12:57:35.768563+00', 'Australia Fair', 'AUSTRALIA FAIR', 1, 128, 9999, 4, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12141, '2005-04-11 22:00:00+00', '2012-01-20 12:57:35.785958+00', 'Baa Lamb Trees, The', 'BAA LAMB TREES', 1, 40, 9999, 1, 4, NULL, 3540, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6445, '1997-04-03 22:00:00+00', '2012-01-20 12:56:50.863886+00', 'Tall And Proud', 'TALL AND PROUD', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12145, '2005-04-11 22:00:00+00', '2018-04-03 00:07:33.482593+00', 'Bishop''s House Reel', 'BISHOPS HOUSE REEL', 1, 32, 9999, 1, 3, 42, 3444, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6452, '1997-11-25 23:00:00+00', '2012-01-20 12:56:50.924779+00', 'Tame Her When Da Snaw Comes', 'TAME HER WHEN DA SNAW COMES', 1, 32, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6454, '1999-05-10 22:00:00+00', '2012-01-20 12:56:50.945167+00', 'Tammie Norie', 'TAMMIE NORIE', 1, 32, 9999, 1, 4, NULL, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6458, '1997-09-14 22:00:00+00', '2012-01-20 12:56:50.975732+00', 'Tantallon', 'TANTALLON', 3, 96, 9999, 4, 4, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6411, '2003-01-28 23:00:00+00', '2018-04-03 00:08:19.413162+00', 'Swan Lake', 'SWAN LAKE', 3, 32, 9999, 1, 3, 42, 35, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6453, '1997-09-14 22:00:00+00', '2016-09-04 20:23:33.717995+00', 'Tami Lane', 'TAMI LANE', 4, 32, 1, 1, 2, 76, 351, NULL, 'To the Howards, of Tami Lane', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6427, '1997-09-14 22:00:00+00', '2016-02-06 00:38:10.461309+00', 'Sylvan Moon', 'SYLVAN MOON', 3, 64, 9999, 4, 4, NULL, 719, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6430, '1999-05-09 22:00:00+00', '2016-05-11 12:50:52.946876+00', 'TZK Reel, The', 'TZK REEL', 1, 32, 9999, 6, 53, 17, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6459, '1997-11-13 23:00:00+00', '2016-06-13 19:27:56.363204+00', 'Tappie Toorie', 'TAPPIE TOORIE', 1, 24, 9999, 1, 3, 42, 146, NULL, '', 50, '800/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6418, '1997-12-22 23:00:00+00', '2018-04-03 00:08:19.479976+00', 'Sweetie Sandy', 'SWEETIE SANDY', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6421, '1997-08-26 22:00:00+00', '2018-04-03 00:08:19.529935+00', 'Swillies, The', 'SWILLIES', 2, 32, 9999, 1, 3, 42, 1, '1979-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6422, '1997-09-14 22:00:00+00', '2018-04-03 00:08:19.538282+00', 'Swindons Farewell To the Gordons', 'SWINDONS FAREWELL TO THE GORDONS', 2, 32, 9999, 1, 3, 42, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6423, '1997-09-14 22:00:00+00', '2018-04-03 00:08:19.546739+00', 'Swine''s Tale To Georgia', 'SWINES TALE TO GEORGIA', 3, 48, 9999, 1, 3, 42, 397, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6437, '1998-01-05 23:00:00+00', '2018-04-03 00:08:19.726803+00', 'Take A Turn', 'TAKE A TURN', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6456, '1997-04-03 22:00:00+00', '2021-04-08 13:46:36.51346+00', 'Tangled Web We Weave, A', 'TANGLED WEB WE WEAVE', 4, 32, 5, 1, 4, NULL, 67, '1991-01-01', 'To celebrate Ted Carson''s "semi" retirement.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6434, '1997-04-03 22:00:00+00', '2020-08-07 09:46:32.006104+00', 'Tae The Lassies', 'TAE THE LASSIES', 1, 32, 9999, 1, 2, NULL, 82, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6426, '1998-11-17 23:00:00+00', '2021-05-15 10:04:41.734336+00', 'Syd Chalmers', 'SYD CHALMERS', 2, 32, 9999, 1, 3, 42, 270, NULL, '', 44, '884/884/800/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6412, '1997-04-03 22:00:00+00', '2021-04-11 19:15:19.182672+00', 'Swan on the Lake, The', 'SWAN ON THE LAKE', 3, 32, 9999, 1, 3, 42, 44, '1978-01-01', 'For Romaine Butterfield.', 50, '800/888/840/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6410, '2002-12-09 23:00:00+00', '2021-04-11 19:28:19.124794+00', 'Suzanne Barbour', 'SUZANNE BARBOUR', 1, 32, 9999, 1, 3, 42, 21, NULL, 'Some versions of the instructions mention the tune as "Ian''s Fancy". Later(?) ones specify the "original" tune (Miss Suzanne Barbour.)', 69, '808/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6416, '1997-04-03 22:00:00+00', '2021-05-15 09:29:10.267898+00', 'Sweet Maid of Glendaruel, The', 'SWEET MAID OF GLENDARUEL', 1, 32, 9999, 1, 3, 42, 270, NULL, 'For Anne Large who gave me the inspiration.', 53, '800/888/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6429, '1997-04-03 22:00:00+00', '2021-05-16 08:39:11.194985+00', 'T. B. Laing Esq.', 'T B LAING ESQ', 2, 32, 9999, 1, 2, 76, 270, NULL, '', 60, '66/88/66/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6447, '1997-09-14 22:00:00+00', '2021-05-15 22:18:04.538842+00', 'Tam Bain''s Lum', 'TAM BAINS LUM', 3, 192, 9999, 4, 4, 3, 270, NULL, '', 65, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6438, '1997-04-03 22:00:00+00', '2021-06-14 23:09:52.126317+00', 'Take Half Of My Plaidie', 'TAKE HALF OF MY PLAIDIE', 2, 32, 9999, 1, 3, 42, 116, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6440, '1997-04-03 22:00:00+00', '2018-04-03 00:08:19.755068+00', 'Take Partners Please', 'TAKE PARTNERS PLEASE', 2, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6441, '1997-04-03 22:00:00+00', '2018-04-03 00:08:19.763448+00', 'Take The Boat To Inversnaid', 'TAKE THE BOAT TO INVERSNAID', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6442, '1997-04-03 22:00:00+00', '2018-04-03 00:08:19.780044+00', 'Take Your Partners', 'TAKE YOUR PARTNERS', 1, 32, 9999, 1, 3, 42, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6446, '1997-09-14 22:00:00+00', '2018-04-03 00:08:19.813555+00', 'Tall Ships, The', 'TALL SHIPS', 1, 40, 9999, 1, 3, 42, 42, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12144, '2005-04-11 22:00:00+00', '2022-09-19 12:36:22.366644+00', 'Betty''s Reel', 'BETTYS REEL', 1, 32, 9999, 1, 4, 1, 3541, '1985-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6390, '1997-04-03 22:00:00+00', '2022-11-07 22:01:11.348616+00', 'Sunday is my Wedding Day', 'SUNDAY IS MY WEDDING DAY', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6428, '1997-09-14 22:00:00+00', '2023-01-26 19:13:33.439093+00', 'T. A .Norris', 'T A NORRIS', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12173, '2005-04-13 22:00:00+00', '2018-10-03 00:31:34.33134+00', 'Celtic Braid', 'CELTIC BRAID', 1, 32, 9999, 3, 5, NULL, 2766, '2004-07-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12174, '2005-04-13 22:00:00+00', '2018-10-03 01:16:41.772247+00', 'Cinnamon Swirl', 'CINNAMON SWIRL', 2, 32, 9999, 1, 3, 42, 2766, '2004-02-01', 'This dance honors my red tabby cat, Cinnamon, who has weathered many diseases and is currently doing well at 17 years of age!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18759, '2018-10-05 06:22:07.437018+00', '2018-10-05 06:22:07.437018+00', 'Flying Blue Angels', 'FLYING BLUE ANGELS', 1, 32, NULL, 1, 3, NULL, 2766, '2015-07-01', 'Love the idea of hands across into snake pass doubled – it feels like flying to me.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12170, '2005-04-13 22:00:00+00', '2019-03-03 07:10:02.332823+00', 'Carriage House Reel, The', 'CARRIAGE HOUSE REEL', 1, 24, 9999, 1, 3, 42, 1268, NULL, '', 50, '800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12161, '2005-04-13 22:00:00+00', '2012-01-20 12:57:35.95492+00', 'Caddy''s Rant', 'CADDYS RANT', 1, 32, 9999, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6467, '1997-11-25 23:00:00+00', '2012-01-20 12:56:51.042801+00', 'Tara Rant', 'TARA RANT', 1, 32, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6469, '1997-09-14 22:00:00+00', '2012-01-20 12:56:51.056662+00', 'Tara Strathspey', 'TARA STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6470, '1997-11-24 23:00:00+00', '2012-01-20 12:56:51.063428+00', 'Tarholm To Glasgow', 'TARHOLM TO GLASGOW', 4, 64, 1, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6475, '1997-09-14 22:00:00+00', '2012-01-20 12:56:51.098672+00', 'Tartan Hoppers, The', 'TARTAN HOPPERS', 2, 32, 9999, 1, 2, NULL, 401, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6476, '1997-04-03 22:00:00+00', '2012-01-20 12:56:51.10584+00', 'Tartan King, The', 'TARTAN KING', 1, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6487, '1998-04-19 22:00:00+00', '2012-01-20 12:56:51.187091+00', 'Tatting', 'TATTING', 1, 24, 9999, 1, 4, NULL, 352, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6491, '1997-04-03 22:00:00+00', '2012-01-20 12:56:51.217673+00', 'Tea for Two', 'TEA FOR TWO', 1, 32, 9999, 1, 4, NULL, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6493, '2001-07-05 22:00:00+00', '2012-01-20 12:56:51.231239+00', 'My Trusty Fiere', 'MY TRUSTY FIERE', 3, 32, 9999, 1, 4, NULL, 1163, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6494, '2002-04-05 22:00:00+00', '2012-01-20 12:56:51.238233+00', 'Teetotaller, The', 'TEETOTALLER', 1, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6495, '1997-04-03 22:00:00+00', '2012-01-20 12:56:51.245024+00', 'Tekeli', 'TEKELI', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6496, '1997-09-15 22:00:00+00', '2012-01-20 12:56:51.251781+00', 'Tel-el Kebir', 'TELEL KEBIR', 2, 64, 9999, 1, 4, NULL, 1299, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12148, '2005-04-11 22:00:00+00', '2018-03-21 10:23:42.403167+00', 'Bob Boy', 'BOB BOY', 1, 40, 9999, 1, 4, 1, 3542, '2001-01-01', '', 86, '8642/8888/8688/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12165, '2005-04-13 22:00:00+00', '2012-01-20 12:57:35.989643+00', 'Camera, The', 'CAMERA', 3, 32, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12168, '2005-04-13 22:00:00+00', '2012-01-20 12:57:36.015693+00', 'Carmad Hill', 'CARMAD HILL', 3, 32, 9999, 6, 3, NULL, 3546, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12172, '2005-04-13 22:00:00+00', '2012-01-20 12:57:36.051295+00', 'Cedar Grove', 'CEDAR GROVE', 2, 32, 9999, 2, 3, NULL, 3548, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12175, '2005-04-14 22:00:00+00', '2012-01-20 12:57:36.080105+00', 'Debbie''s Delight', 'DEBBIES DELIGHT', 3, 64, 9999, 4, 4, NULL, 3537, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14605, '2012-12-11 15:49:36.009257+00', '2012-12-11 15:49:36.009267+00', 'Back On The Floor', 'BACK ON THE FLOOR', 3, 32, NULL, 2, 3, 17, 228, '2012-12-11', 'For Birgit Böhm, who recently started dancing again after having recovered from an injury.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12167, '2005-04-13 22:00:00+00', '2016-05-12 07:35:19.307348+00', 'Carlingwark', 'CARLINGWARK', 7, 0, 9999, 107, 51, NULL, 3545, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12163, '2005-04-13 22:00:00+00', '2017-12-20 12:37:33.465208+00', 'Caley Medley', 'CALEY MEDLEY', 4, 64, 5, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12171, '2005-04-13 22:00:00+00', '2018-03-26 13:25:24.592472+00', 'Castle Garden, The', 'CASTLE GARDEN', 3, 32, 9999, 2, 3, NULL, 3547, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12157, '2005-04-11 22:00:00+00', '2018-03-21 12:12:38.366495+00', 'Brisk Snake, A', 'BRISK SNAKE', 1, 32, 9999, 2, 3, 17, 3544, '2001-04-01', '', 96, '888/888/888/848', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12146, '2005-04-11 22:00:00+00', '2018-04-03 00:07:34.233096+00', 'Blithe to See You', 'BLITHE TO SEE YOU', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12150, '2005-04-11 22:00:00+00', '2018-04-03 00:07:34.658464+00', 'Bonnie Betty', 'BONNIE BETTY', 3, 32, 9999, 1, 3, 42, 385, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12151, '2005-04-11 22:00:00+00', '2018-04-03 00:07:34.741987+00', 'Bonnie Kinnoul', 'BONNIE KINNOUL', 3, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12152, '2005-04-11 22:00:00+00', '2018-04-03 00:07:35.192553+00', 'Boswell''s Fancy', 'BOSWELLS FANCY', 3, 32, 9999, 1, 3, 42, 3491, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12154, '2005-04-11 22:00:00+00', '2018-04-03 00:07:35.711434+00', 'Bride from Dumfries, The', 'BRIDE FROM DUMFRIES', 1, 40, 9999, 1, 3, 42, 3354, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12155, '2005-04-11 22:00:00+00', '2018-04-03 00:07:35.718368+00', 'Bridgecastle Reel, The', 'BRIDGECASTLE REEL', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12156, '2005-04-11 22:00:00+00', '2018-04-03 00:07:35.818448+00', 'Bring me Sunshine', 'BRING ME SUNSHINE', 1, 32, 9999, 1, 3, 42, 3543, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6468, '1997-04-03 22:00:00+00', '2018-04-03 00:08:19.913532+00', 'Tara Road', 'TARA ROAD', 2, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6474, '1997-04-03 22:00:00+00', '2018-04-03 00:08:19.938535+00', 'Tartan Day Reel, The', 'TARTAN DAY REEL', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6461, '1997-08-24 22:00:00+00', '2020-06-09 14:29:00.818996+00', 'Tappie Toorie', 'TAPPIE TOORIE', 1, 96, 9999, 4, 4, 54, 108, '1990-07-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6460, '1998-11-25 23:00:00+00', '2020-06-09 20:02:38.481744+00', 'Tappie Toorie', 'TAPPIE TOORIE', 2, 48, 9999, 1, 3, 42, 313, NULL, '', 60, '800/888/888/888/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6482, '1997-04-03 22:00:00+00', '2020-08-07 09:48:52.583068+00', 'Tartan, The', 'TARTAN', 1, 32, 9999, 1, 4, 1, 129, NULL, '', 62, '8004/8848/8448/8008', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12149, '2005-04-11 22:00:00+00', '2021-01-15 20:46:37.900754+00', 'Bonded Warehouse, The', 'BONDED WAREHOUSE', 1, 48, 9999, 1, 3, 42, 108, '2003-01-01', '', 58, '880/888/880/888/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12159, '2005-04-11 22:00:00+00', '2021-01-23 10:24:22.532824+00', 'Bus Tour Reel, The', 'BUS TOUR REEL', 1, 32, 9999, 1, 3, 42, 2525, '1998-08-01', '', 50, '800/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12153, '2005-04-11 22:00:00+00', '2021-01-24 15:46:31.122606+00', 'Bothwellhaugh Jig', 'BOTHWELLHAUGH JIG', 2, 32, 9999, 1, 3, 42, 2525, NULL, '', 53, '800/888/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6485, '1997-09-14 22:00:00+00', '2021-04-10 11:49:43.211062+00', 'Tattie Bogle, The', 'TATTIE BOGLE', 2, 32, 9999, 1, 4, 1, 880, NULL, '', 50, '4004/8008/8440/8448', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6472, '2002-04-15 22:00:00+00', '2021-04-11 11:21:05.159143+00', 'Tarry Hat Jig, The', 'TARRY HAT JIG', 2, 40, 9999, 1, 3, 42, 394, '1979-11-01', 'According to the notes for the dance the street urchins had a derogatory rhyme about the "Tarry Hat", the tall helmet worn by Aberdeen policemen.', 60, '800/888/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6463, '2002-03-12 23:00:00+00', '2021-04-11 11:33:39.368386+00', 'Tapsalteerie', 'TAPSALTEERIE', 2, 32, 9999, 1, 3, 42, 111, NULL, '', 63, '888/888/888/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12162, '2005-04-13 22:00:00+00', '2021-08-13 11:31:06.233408+00', 'Caldwells'' Coral Caper, The', 'CALDWELLS CORAL CAPER', 3, 32, 9999, 1, 3, 42, 3538, '1991-01-01', 'Originally entered in SCDDB with apostrophe before s as "Caldwell''s", now changed to Caldwells'' with the other kept as a spelling alias.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6480, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.055329+00', 'Tartan Twilight', 'TARTAN TWILIGHT', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6486, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.088723+00', 'Tattie Howkers, The', 'TATTIE HOWKERS', 1, 40, 9999, 1, 3, 42, 417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6488, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.097003+00', 'Tay''s Fancy', 'TAYS FANCY', 3, 40, 9999, 1, 3, 42, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6498, '1997-09-15 22:00:00+00', '2012-01-20 12:56:51.266252+00', 'Tell Na Me O'' Wind And Rain', 'TELL NA ME O WIND AND RAIN', 3, 32, 9999, 1, 4, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6499, '1997-09-15 22:00:00+00', '2012-01-20 12:56:51.273064+00', 'Temple Bar', 'TEMPLE BAR', 1, 22, 9999, 1, 2, NULL, 446, '1728-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6501, '1997-11-25 23:00:00+00', '2012-01-20 12:56:51.286889+00', 'Tenth Anniversary, The', 'TENTH ANNIVERSARY', 3, 32, 9999, 4, 4, NULL, 1103, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12188, '2005-04-14 22:00:00+00', '2018-10-04 08:46:25.171545+00', 'Dolphins at Play', 'DOLPHINS AT PLAY', 2, 32, 9999, 1, 3, 42, 2766, '2004-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6503, '1998-01-05 23:00:00+00', '2012-01-20 12:56:51.300855+00', 'Teri Odin', 'TERI ODIN', 1, 32, 9999, 3, 5, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6504, '1997-04-03 22:00:00+00', '2012-01-20 12:56:51.308299+00', 'Testing of the Piper', 'TESTING OF THE PIPER', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18980, '2018-10-17 12:23:34.902483+00', '2019-01-29 00:21:43.916753+00', 'Dance for Doris, A', 'DANCE FOR DORIS', 1, 40, NULL, 1, 3, 42, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6515, '1997-04-03 22:00:00+00', '2012-01-20 12:56:51.596251+00', 'That''s My Jo''', 'THATS MY JO', 2, 32, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6516, '2002-11-26 23:00:00+00', '2012-01-20 12:56:51.603213+00', 'Millstream, The', 'MILLSTREAM', 3, 32, 9999, 2, 3, NULL, 109, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6506, '1997-11-27 23:00:00+00', '2019-03-09 19:56:05.34529+00', 'Tey Medley, The', 'TEY MEDLEY', 4, 128, 2, 4, 4, 3, 755, NULL, '', 86, '8888/4444/8888/7777/4444/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6528, '1997-09-17 22:00:00+00', '2012-01-20 12:56:51.679977+00', 'Welcome Wanderer, The', 'WELCOME WANDERER', 1, 32, 9999, 3, 5, NULL, 950, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12176, '2005-04-13 22:00:00+00', '2012-01-20 12:57:36.088768+00', 'Climbing the Tables', 'CLIMBING THE TABLES', 1, 32, 9999, 1, 4, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12178, '2005-04-13 22:00:00+00', '2018-04-03 00:07:39.832119+00', 'Craiglwyd', 'CRAIGLWYD', 3, 32, 9999, 1, 3, 42, 1, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12180, '2005-04-14 22:00:00+00', '2012-01-20 12:57:36.123503+00', 'Demelza House', 'DEMELZA HOUSE', 1, 48, 9999, 1, 4, NULL, 1315, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12184, '2005-04-14 22:00:00+00', '2012-01-20 12:57:36.158546+00', 'Dancing on Skye', 'DANCING ON SKYE', 1, 32, 9999, 1, 4, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12181, '2005-04-14 22:00:00+00', '2018-04-03 00:07:40.62408+00', 'Daisy Chain, The', 'DAISY CHAIN', 1, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6529, '1997-04-03 22:00:00+00', '2012-01-20 12:56:51.686878+00', 'Third Of May, The', 'THIRD OF MAY', 2, 40, 9999, 1, 2, NULL, 362, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6530, '1997-04-03 22:00:00+00', '2012-01-20 12:56:51.693961+00', 'Third Quinquennium, The', 'THIRD QUINQUENNIUM', 2, 40, 9999, 3, 5, NULL, 305, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6533, '1997-04-03 22:00:00+00', '2012-01-20 12:56:51.714731+00', 'Thirty Fifth Anniversary Reel', 'THIRTY FIFTH ANNIVERSARY REEL', 1, 32, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6544, '1997-04-03 22:00:00+00', '2012-01-20 12:56:51.79353+00', 'Thistle and Vine, The', 'THISTLE AND VINE', 2, 32, 9999, 1, 4, NULL, 605, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6546, '1997-12-21 23:00:00+00', '2012-01-20 12:56:51.808053+00', 'Thistle Jig, The', 'THISTLE JIG', 2, 32, 9999, 1, 4, NULL, 425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6727, '2001-11-25 23:00:00+00', '2012-01-20 12:56:53.098607+00', 'Trip to Orlando', 'TRIP TO ORLANDO', 1, 32, 9999, 1, 4, NULL, 1319, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6541, '1997-04-03 22:00:00+00', '2016-09-09 22:33:01.562996+00', 'Thistle & The Trillium, The', 'THISTLE AND THE TRILLIUM', 3, 40, 9999, 1, 4, 1, 213, '1971-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12185, '2005-04-14 22:00:00+00', '2018-04-03 00:07:41.391533+00', 'Daphne Gow''s Strathspey', 'DAPHNE GOWS STRATHSPEY', 3, 0, 9999, 1, 3, 42, 3553, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6500, '1998-01-04 23:00:00+00', '2018-04-03 00:08:20.363775+00', 'Tensegrity Reel', 'TENSEGRITY REEL', 1, 40, 9999, 1, 3, 42, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6502, '1997-09-28 22:00:00+00', '2018-04-03 00:08:20.372137+00', 'Tenth Annual Fort Worden Reel', 'TENTH ANNUAL FORT WORDEN REEL', 1, 48, 9999, 1, 3, 42, 1300, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6509, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.405638+00', 'Thane Of Cawdor, The', 'THANE OF CAWDOR', 1, 40, 9999, 1, 3, 42, 347, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6512, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.422145+00', 'Thanks for the Memory', 'THANKS FOR THE MEMORY', 3, 32, 9999, 1, 3, 42, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6511, '1997-08-26 22:00:00+00', '2018-04-03 00:08:20.463734+00', 'Thank You Norah', 'THANK YOU NORAH', 3, 32, 9999, 1, 3, 42, 568, '1980-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6517, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.472135+00', 'Theatre Lights', 'THEATRE LIGHTS', 2, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6519, '1997-09-15 22:00:00+00', '2018-04-03 00:08:20.480506+00', 'Then There Were Four', 'THEN THERE WERE FOUR', 1, 32, 9999, 1, 3, 42, 377, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6524, '1997-09-28 22:00:00+00', '2018-04-03 00:08:20.564013+00', 'These Are Your Mountains', 'THESE ARE YOUR MOUNTAINS', 3, 32, 9999, 1, 3, 42, 1013, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6525, '2003-01-28 23:00:00+00', '2018-04-03 00:08:20.572182+00', 'They''ll Nae Let Him Catch Her', 'THEYLL NAE LET HIM CATCH HER', 2, 32, 9999, 1, 3, 42, 35, '1976-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6507, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.580611+00', 'Th''githerness', 'THGITHERNESS', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6531, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.605553+00', 'Thirlestane', 'THIRLESTANE', 2, 32, 9999, 1, 3, 42, 108, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6534, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.61396+00', 'Thirty Years On', 'THIRTY YEARS ON', 2, 32, 9999, 1, 3, 42, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6538, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.622232+00', 'This Dear Paradise', 'THIS DEAR PARADISE', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6542, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.647259+00', 'Thistle and the Bee, The', 'THISTLE AND THE BEE', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12183, '2005-04-14 22:00:00+00', '2020-10-13 19:26:52.173368+00', 'Dancing Confetti', 'DANCING CONFETTI', 1, 32, 9999, 1, 102, 1, 843, '2001-02-01', '', 84, '8888/8888/2648/4488', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6540, '1997-04-03 22:00:00+00', '2020-09-04 07:46:04.996996+00', 'This Is No My Ain Lassie', 'THIS IS NO MY AIN LASSIE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 44, '840/880/880/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6522, '1998-04-21 22:00:00+00', '2021-04-10 11:11:36.666593+00', 'There Cam'' a Young Man', 'THERE CAM A YOUNG MAN', 2, 32, 9999, 1, 3, 42, 44, '1980-01-01', 'The dance was inadvertently published as “There Cam’ A Young Man” (the name of the recommended music). The title the deviser prefers is “There Came A Young Man”.', 47, '840/880/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12187, '2005-04-14 22:00:00+00', '2021-01-25 02:48:23.267941+00', 'Doing My Own Thing', 'DOING MY OWN THING', 1, 32, 9999, 1, 4, 1, 2525, '2003-05-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6492, '1998-01-05 23:00:00+00', '2021-04-10 11:32:46.29153+00', 'Teacher''s Pet, The', 'TEACHERS PET', 1, 32, 9999, 1, 3, 42, 127, NULL, 'Devised for my daughter Sheena, her favourite figure being "Hello-Goodbye" setting.', 52, '842/880/822/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6510, '1997-04-03 22:00:00+00', '2021-08-04 10:37:38.287608+00', 'Thane Of Fife', 'THANE OF FIFE', 3, 32, 9999, 1, 3, 42, 13, NULL, '', 53, '844/822/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6537, '1997-08-28 22:00:00+00', '2018-04-03 00:08:26.951596+00', 'Xtra, Xtra (Reel all about it)', 'XTRA XTRA REEL ALL ABOUT IT', 1, 32, 9999, 1, 3, 42, 593, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6555, '1997-04-03 22:00:00+00', '2018-05-30 10:14:19.415537+00', 'Thorngrove Anniversary Strathspey, The', 'THORNGROVE ANNIVERSARY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 129, NULL, '', 51, '660/880/707/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6548, '1997-04-03 22:00:00+00', '2012-01-20 12:56:51.82178+00', 'Thistle of Scotland', 'THISTLE OF SCOTLAND', 1, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6553, '1997-09-15 22:00:00+00', '2012-01-20 12:56:51.85589+00', 'Thistledown', 'THISTLEDOWN', 4, 104, 9999, 4, 4, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6554, '1997-09-15 22:00:00+00', '2012-01-20 12:56:51.862769+00', 'Thistledown Jig', 'THISTLEDOWN JIG', 2, 40, 9999, 5, 53, NULL, 401, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6557, '1997-11-20 23:00:00+00', '2012-01-20 12:56:51.884047+00', 'Thornhill Reel', 'THORNHILL REEL', 1, 48, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12193, '2005-04-14 22:00:00+00', '2012-01-20 12:57:36.236525+00', 'Douglas Reel, The', 'DOUGLAS REEL', 7, 0, 9999, 4, 54, NULL, 3545, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12191, '2005-04-14 22:00:00+00', '2018-10-04 10:05:02.012881+00', 'Double Time', 'DOUBLE TIME', 1, 32, 9999, 4, 4, NULL, 2766, '2004-09-01', 'The figure in bars 1-16 reminds me of a pair of hourglasses, thus the name of the dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12194, '2005-04-14 22:00:00+00', '2022-09-19 12:25:49.902326+00', 'Douro Sixsome Jig, The', 'DOURO SIXSOME JIG', 2, 48, 9999, 6, 3, 17, 3538, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6556, '1998-11-17 23:00:00+00', '2022-11-01 19:21:25.677075+00', 'Thornham Reel, The', 'THORNHAM REEL', 2, 32, 9999, 1, 100, 2, 185, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6543, '1997-04-03 22:00:00+00', '2022-12-01 16:28:39.370818+00', 'Thistle and the Rose, The', 'THISTLE AND THE ROSE', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 63, '888/848/888/804', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12197, '2005-04-14 22:00:00+00', '2012-01-20 12:57:36.27045+00', 'Drumrunie Jig, The', 'DRUMRUNIE JIG', 2, 40, 9999, 1, 2, NULL, 3555, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12198, '2005-04-14 22:00:00+00', '2012-01-20 12:57:36.279085+00', 'Duchess of Halsway, The', 'DUCHESS OF HALSWAY', 1, 32, 9999, 1, 4, NULL, 3444, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12199, '2005-04-14 22:00:00+00', '2012-01-20 12:57:36.28776+00', 'Dunderave Castle', 'DUNDERAVE CASTLE', 3, 32, 9999, 1, 4, NULL, 3546, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18894, '2018-10-08 21:50:19.120767+00', '2018-10-08 21:50:19.120767+00', 'Spool Knitting', 'SPOOL KNITTING', 1, 32, NULL, 1, 3, 42, 2766, '2016-03-01', 'The figures in this dance remind me of spool knitting.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6565, '1997-04-03 22:00:00+00', '2012-01-20 12:56:51.942852+00', 'Threave Castle', 'THREAVE CASTLE', 3, 96, 9999, 4, 4, NULL, 229, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6549, '1997-09-16 22:00:00+00', '2019-02-08 11:58:12.18675+00', 'Thistle Reel', 'THISTLE REEL', 1, 32, 9999, 1, 4, 1, 1307, NULL, '', 69, '8000/8800/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6569, '1997-09-16 22:00:00+00', '2019-03-09 19:44:29.727585+00', 'Three Kings Of Cullen, The', 'THREE KINGS OF CULLEN', 3, 32, 9999, 2, 3, 17, 127, NULL, '', 83, '888/888/822/686', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6567, '2000-08-01 22:00:00+00', '2018-02-28 09:40:39.451722+00', 'Three Bouncing Lads', 'THREE BOUNCING LADS', 3, 32, 9999, 6, 3, 18, 827, '1994-04-01', 'For Mr. and Mrs. Seiji Iwasaki and their three sons like a bee.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6568, '1998-11-17 23:00:00+00', '2019-04-20 22:34:28.381573+00', 'Three Cornered Hat, The', 'THREE CORNERED HAT', 4, 64, 5, 6, 3, 17, 2435, NULL, '', 92, '888/888/800/888/888/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12204, '2005-04-16 22:00:00+00', '2019-06-09 23:56:56.57375+00', 'Eight of Diamonds', 'EIGHT OF DIAMONDS', 2, 32, 9999, 1, 4, NULL, 2677, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6580, '1997-09-16 22:00:00+00', '2012-01-20 12:56:52.047331+00', 'Three''s A Crowd', 'THREES A CROWD', 2, 32, 9999, 2, 3, NULL, 152, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6581, '1997-12-03 23:00:00+00', '2012-01-20 12:56:52.054214+00', 'Wendy''s Jigaround', 'WENDYS JIGAROUND', 2, 24, 9999, 4, 4, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12203, '2005-04-16 22:00:00+00', '2012-01-20 12:57:36.323412+00', 'Ecclefechan Strathspey, The', 'ECCLEFECHAN STRATHSPEY', 3, 64, 9999, 1, 4, NULL, 3558, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12189, '2005-04-14 22:00:00+00', '2018-04-03 00:07:42.425973+00', 'Donald MacNeil', 'DONALD MACNEIL', 1, 32, 9999, 1, 3, 42, 179, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12208, '2005-04-16 22:00:00+00', '2012-01-20 12:57:36.367004+00', 'Every Which Way', 'EVERY WHICH WAY', 1, 32, 9999, 2, 3, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12211, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.392892+00', 'Fair Fa'' Peggy', 'FAIR FA PEGGY', 3, 32, 9999, 1, 4, NULL, 3272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12195, '2005-04-14 22:00:00+00', '2018-04-03 00:07:42.901364+00', 'Downley Reel', 'DOWNLEY REEL', 1, 32, 9999, 1, 3, 42, 57, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6574, '1999-05-09 22:00:00+00', '2016-05-11 12:49:14.887035+00', 'Three Plus One', 'THREE PLUS ONE', 1, 32, 9999, 4, 54, 30, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6552, '1998-09-30 22:00:00+00', '2016-11-15 11:06:11.270303+00', 'Thistle, The', 'THISTLE', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'Can be danced in a longways set for as many as will; a new top couple begins on every 2nd repetition.', 50, '800/800/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12207, '2005-04-16 22:00:00+00', '2018-04-03 00:07:44.719376+00', 'Esther''s Reel', 'ESTHERS REEL', 1, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12209, '2005-04-16 22:00:00+00', '2018-04-03 00:07:44.852794+00', 'Exciseman, The', 'EXCISEMAN', 2, 32, 9999, 1, 3, 42, 57, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6547, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.697289+00', 'Thistle of Scotland, The', 'THISTLE OF SCOTLAND', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6561, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.850713+00', 'Thousand Island Strathspey', 'THOUSAND ISLAND STRATHSPEY', 3, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6559, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.872381+00', 'Thou Tuck-Shop King', 'THOU TUCKSHOP KING', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6564, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.880823+00', 'Threads of Margaret''s Life', 'THREADS OF MARGARETS LIFE', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6570, '1997-09-16 22:00:00+00', '2018-04-03 00:08:20.905794+00', 'Three Little Boys', 'THREE LITTLE BOYS', 2, 32, 9999, 1, 3, 42, 377, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6572, '1998-04-19 22:00:00+00', '2018-04-03 00:08:20.93079+00', 'Three Of Us, The', 'THREE OF US', 1, 40, 9999, 1, 3, 42, 348, '1989-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6573, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.939157+00', 'Three On The Side', 'THREE ON THE SIDE', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6576, '1997-09-16 22:00:00+00', '2018-04-03 00:08:20.972393+00', 'Three Sheets in the Wind', 'THREE SHEETS IN THE WIND', 1, 32, 9999, 1, 3, 42, 108, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6578, '1997-04-03 22:00:00+00', '2018-04-03 00:08:20.980874+00', 'Three Strawberry Flowers', 'THREE STRAWBERRY FLOWERS', 3, 40, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12212, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.401531+00', 'Fair Maid Medley, The', 'FAIR MAID MEDLEY', 4, 64, 5, 4, 4, NULL, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12201, '2005-04-14 22:00:00+00', '2021-01-15 12:04:01.024222+00', 'Dyke on the 49th, The', 'DYKE ON THE 49TH', 1, 32, 9999, 1, 4, 2, 108, '2004-01-01', '', 69, '6666/4444/4444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12205, '2005-04-16 22:00:00+00', '2021-01-25 07:58:58.994281+00', 'Elizabeth''s Request', 'ELIZABETHS REQUEST', 1, 32, 9999, 3, 5, 7, 2525, '2002-10-02', '', 68, '86860/84840/84884/82822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6575, '1999-08-09 22:00:00+00', '2021-04-08 14:28:39.785599+00', 'Three Sheepskins, The', 'THREE SHEEPSKINS', 2, 40, 9999, 1, 4, 1, 9998, NULL, '', 69, '8880/8880/8000/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6563, '1998-11-02 23:00:00+00', '2021-04-08 14:34:21.704087+00', 'Thread The Loom', 'THREAD THE LOOM', 2, 32, 9999, 1, 4, 2, 118, '1986-01-01', '', 72, '5555/4444/6666/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6551, '1998-01-05 23:00:00+00', '2021-04-08 14:43:57.596575+00', 'Thistle''s Fancy', 'THISTLES FANCY', 1, 40, 9999, 2, 3, 17, 70, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6579, '1997-04-03 22:00:00+00', '2021-05-17 10:33:12.546699+00', 'Three Times Three', 'THREE TIMES THREE', 1, 48, 9999, 1, 2, 76, 270, NULL, '', 64, '82/88/88/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12210, '2005-04-17 22:00:00+00', '2021-07-30 08:33:54.531645+00', '40 Merks', '40 MERKS', 3, 32, 9999, 1, 3, 42, 308, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6786, '1997-04-03 22:00:00+00', '2021-09-19 12:55:51.02703+00', 'Twa Corbies', 'TWA CORBIES', 1, 32, 9999, 1, 3, 42, 352, '1990-09-25', '', 63, '844/844/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12213, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.410186+00', 'Fair Maid Strathspey, The', 'FAIR MAID STRATHSPEY', 3, 40, 9999, 4, 4, NULL, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18863, '2018-10-07 10:59:44.027432+00', '2018-10-07 10:59:44.027432+00', 'Red Rover, Red Rover', 'RED ROVER RED ROVER', 3, 32, NULL, 1, 3, 42, 2766, '2012-05-01', 'The figure in bars 1-8 reminded me of the childrens’ game *Red Rover*.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12215, '2005-04-17 22:00:00+00', '2018-04-26 21:20:45.294782+00', 'Festival of Trees Reel', 'FESTIVAL OF TREES REEL', 1, 48, 9999, 107, 98, NULL, 3559, '1998-01-01', '48 Bar Demonstration Reel for 4 Couples and 4 Corners', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6562, '1997-09-16 22:00:00+00', '2013-07-23 07:50:33.481639+00', 'Thrang Wynd, The', 'THRANG WYND', 1, 32, 9999, 1, 4, NULL, 628, NULL, 'The Thrang Wynd translates as The Crowded Lane.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12226, '2005-04-17 22:00:00+00', '2018-03-26 01:22:55.917874+00', 'Flitting Small White, A', 'FLITTING SMALL WHITE', 1, 32, 9999, 1, 3, 42, 3561, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6588, '1997-09-10 22:00:00+00', '2012-01-20 12:56:52.108103+00', 'Through A Looking Glass', 'THROUGH A LOOKING GLASS', 3, 40, 9999, 1, 4, NULL, 43, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6589, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.114901+00', 'Through The Elms To Bluebell Hill', 'THROUGH THE ELMS TO BLUEBELL HILL', 2, 40, 9999, 1, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6611, '1997-09-16 22:00:00+00', '2019-09-15 19:15:46.708484+00', 'Timour the Tartar', 'TIMOUR THE TARTAR', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6593, '1997-12-03 23:00:00+00', '2012-01-20 12:56:52.149518+00', 'Thursday Night', 'THURSDAY NIGHT', 2, 32, 9999, 1, 4, NULL, 1311, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6615, '1997-09-16 22:00:00+00', '2019-04-18 17:38:24.611102+00', 'Tiptoe Jig', 'TIPTOE JIG', 2, 32, 9999, 1, 3, 42, 26, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6602, '1997-09-16 22:00:00+00', '2012-01-20 12:56:52.217648+00', 'Tidal River Reel', 'TIDAL RIVER REEL', 1, 96, 9999, 4, 4, NULL, 1119, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6603, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.224415+00', 'Tigh-Na-Cloich', 'TIGHNACLOICH', 4, 96, 9999, 4, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6583, '1997-09-16 22:00:00+00', '2022-11-01 19:16:43.447463+00', 'Threesome Jig', 'THREESOME JIG', 2, 32, 9999, 5, 53, 4, 82, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6610, '1997-09-16 22:00:00+00', '2012-01-20 12:56:52.272218+00', 'Tim''s Trout', 'TIMS TROUT', 1, 32, 9999, 5, 56, NULL, 565, '1973-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12217, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.445478+00', 'Fields of Heather', 'FIELDS OF HEATHER', 1, 32, 9999, 1, 4, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12218, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.454122+00', 'Figures of Eight', 'FIGURES OF EIGHT', 3, 40, 9999, 1, 4, NULL, 3350, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12220, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.474298+00', 'Findlater''s Reel', 'FINDLATERS REEL', 1, 64, 9999, 4, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12221, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.483335+00', 'Finnigan''s Reel', 'FINNIGANS REEL', 1, 32, 9999, 1, 4, NULL, 1, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12222, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.492174+00', 'Fire in the Summer', 'FIRE IN THE SUMMER', 3, 40, 9999, 1, 2, NULL, 905, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12224, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.501105+00', 'Five Minute Reel', 'FIVE MINUTE REEL', 1, 96, 9999, 4, 4, NULL, 930, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12225, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.509849+00', 'Flight of the Heron, The', 'FLIGHT OF THE HERON', 3, 32, 9999, 1, 2, NULL, 3560, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12230, '2005-04-17 22:00:00+00', '2018-03-26 02:15:19.484295+00', 'Friendship, The', 'FRIENDSHIP', 2, 32, 9999, 1, 3, 42, 3562, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12214, '2005-04-17 22:00:00+00', '2018-04-03 00:07:45.061464+00', 'Fallingbrook Strathspey', 'FALLINGBROOK STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12229, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.545064+00', 'Four on the Floor', 'FOUR ON THE FLOOR', 1, 32, 9999, 1, 4, NULL, 2677, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12231, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.56262+00', 'Hare on the Hearth', 'HARE ON THE HEARTH', 2, 48, 9999, 1, 4, NULL, 3462, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6617, '1997-09-16 22:00:00+00', '2012-01-20 12:56:52.320978+00', 'Tirling Pin, The', 'TIRLING PIN', 2, 32, 9999, 5, 2, NULL, 90, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6622, '1997-11-24 23:00:00+00', '2012-01-20 12:56:52.35623+00', 'Tmanyi Gamb', 'TMANYI GAMB', 4, 32, 1, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6626, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.384494+00', 'To Friendship', 'TO FRIENDSHIP', 3, 32, 9999, 1, 4, NULL, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6604, '1997-12-03 23:00:00+00', '2018-04-03 00:07:56.220518+00', 'John O'' Groats', 'JOHN O GROATS', 2, 32, 9999, 1, 3, 42, 670, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6560, '1998-11-02 23:00:00+00', '2018-04-03 00:08:20.797468+00', 'Thousand Islands Hornpipe, The', 'THOUSAND ISLANDS HORNPIPE', 1, 32, 9999, 1, 3, 42, 118, '1982-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6590, '1998-01-05 23:00:00+00', '2018-04-03 00:08:20.997427+00', 'Through The Narrows', 'THROUGH THE NARROWS', 1, 32, 9999, 1, 3, 42, 477, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6591, '1997-09-18 22:00:00+00', '2018-04-03 00:08:21.005896+00', 'Thrum, The', 'THRUM', 1, 32, 9999, 1, 3, 42, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6594, '1997-04-03 22:00:00+00', '2018-04-03 00:08:21.030909+00', 'Thursday''s Child', 'THURSDAYS CHILD', 1, 32, 9999, 1, 3, 42, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6598, '1997-04-03 22:00:00+00', '2018-04-03 00:08:21.05597+00', 'Tibbie''s New Petticoat', 'TIBBIES NEW PETTICOAT', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6605, '1997-04-03 22:00:00+00', '2018-04-03 00:08:21.130857+00', 'Tighna Maureen', 'TIGHNA MAUREEN', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6608, '2003-01-28 23:00:00+00', '2018-04-03 00:08:21.139244+00', 'Tillamook Tides', 'TILLAMOOK TIDES', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6620, '1997-09-16 22:00:00+00', '2018-04-03 00:08:21.264376+00', 'Tittensor Chase', 'TITTENSOR CHASE', 1, 32, 9999, 1, 3, 42, 606, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6623, '1997-04-03 22:00:00+00', '2018-04-03 00:08:21.314418+00', 'To A Mouse', 'TO A MOUSE', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6625, '1997-09-16 22:00:00+00', '2018-04-03 00:08:21.422748+00', 'To Dance To', 'TO DANCE TO', 1, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6630, '2002-02-26 23:00:00+00', '2012-01-20 12:56:52.412945+00', 'Aaron''s Strathspey', 'AARONS STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 600, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6635, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.447414+00', 'Todmorden Fair', 'TODMORDEN FAIR', 4, 64, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6628, '1997-09-16 22:00:00+00', '2020-12-17 11:14:25.732326+00', 'Toast To Alltshellach, A', 'TOAST TO ALLTSHELLACH', 3, 32, 9999, 2, 3, NULL, 13, NULL, '', 53, '800/888/822/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12216, '2005-04-17 22:00:00+00', '2021-01-15 11:56:18.731185+00', 'Fiddler''s Bairn, The', 'FIDDLERS BAIRN', 2, 32, 9999, 1, 3, 42, 3374, '2003-01-01', '', 63, '888/888/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6624, '2001-12-04 23:00:00+00', '2021-01-05 19:01:38.357726+00', 'To Ane An'' A''', 'TO ANE AN A', 3, 32, 9999, 5, 4, NULL, 1313, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6613, '1998-11-03 23:00:00+00', '2021-03-26 07:36:48.886913+00', 'Tinto Hill', 'TINTO HILL', 1, 40, 9999, 1, 3, 42, 394, '1976-01-01', '', 75, '800/888/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6606, '1998-04-19 22:00:00+00', '2021-04-03 09:10:06.984203+00', 'Tiki, The', 'TIKI', 1, 32, 9999, 1, 4, 1, 352, '1991-08-10', '', 53, '8444/8800/8080/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6631, '1997-04-03 22:00:00+00', '2021-04-07 15:15:57.770426+00', 'Tobermory Bay', 'TOBERMORY BAY', 2, 40, 9999, 1, 4, 1, 372, NULL, '', 85, '8888/8888/8888/8000/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6618, '2002-02-16 23:00:00+00', '2021-04-07 16:04:36.52284+00', 'Tis Nice Tae See Ye', 'TIS NICE TAE SEE YE', 1, 32, 9999, 1, 4, 1, 141, NULL, '', 69, '8008/0880/8888/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6600, '1997-04-03 22:00:00+00', '2021-04-07 16:54:17.063243+00', 'Tibby Walker''s Jig', 'TIBBY WALKERS JIG', 2, 32, 9999, 1, 3, 42, 200, NULL, '', 50, '840/888/822/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6586, '1998-11-17 23:00:00+00', '2021-04-08 14:23:29.224908+00', 'Thro'' The Sma'' Glen', 'THRO THE SMA GLEN', 3, 32, 9999, 3, 5, 21, 87, NULL, '', 62, '80408/82428/80008/88888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6595, '1997-04-03 22:00:00+00', '2021-05-17 20:56:38.369215+00', 'Thurso Wedding, The', 'THURSO WEDDING', 1, 32, 9999, 1, 2, 76, 270, NULL, '', 60, '88/88/80/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6587, '1997-09-16 22:00:00+00', '2021-11-22 18:36:48.069089+00', 'Through A Glass Darkly', 'THROUGH A GLASS DARKLY', 3, 32, 9999, 1, 4, 1, 352, '1991-07-30', '', 66, '8880/8880/8840/8044', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12245, '2005-04-19 22:00:00+00', '2018-04-30 20:58:32.608116+00', 'St Machar Strathspey, The', 'SAINT MACHAR STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '2004-01-01', '', 62, '888/808/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6639, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.475818+00', 'Tom Kettles', 'TOM KETTLES', 1, 32, 9999, 5, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6641, '1997-09-16 22:00:00+00', '2012-01-20 12:56:52.48956+00', 'Tom Stephen''s Jig', 'TOM STEPHENS JIG', 2, 24, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6642, '1997-09-08 22:00:00+00', '2012-01-20 12:56:52.496681+00', 'Mary Jamieson''s Favourite', 'MARY JAMIESONS FAVOURITE', 1, 96, 9999, 1, 4, NULL, 81, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18864, '2018-10-07 11:06:51.80787+00', '2018-10-07 11:06:51.80787+00', 'Reflection Reel', 'REFLECTION REEL', 1, 32, NULL, 1, 4, 2, 2766, '2007-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12232, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.571359+00', 'Hurleygush, The', 'HURLEYGUSH', 2, 40, 9999, 1, 4, NULL, 57, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12233, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.580346+00', 'By the Fleet', 'BY THE FLEET', 7, 0, 9999, 6, 53, NULL, 3545, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12234, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.588988+00', 'Galloway', 'GALLOWAY', 7, 0, 9999, 4, 54, NULL, 3545, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12235, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.597775+00', 'Isle of Threave, The', 'ISLE OF THREAVE', 7, 0, 9999, 6, 53, NULL, 3545, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12236, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.606416+00', 'Ladies of Threave, The', 'LADIES OF THREAVE', 7, 0, 9999, 4, 54, NULL, 3545, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12237, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.61428+00', 'Lady Margaret''s Delight', 'LADY MARGARETS DELIGHT', 7, 0, 9999, NULL, 98, NULL, 3545, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12238, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.623145+00', 'Medley of Memories', 'MEDLEY OF MEMORIES', 7, 0, 9999, 4, 54, NULL, 3545, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6643, '2000-08-01 22:00:00+00', '2018-02-27 08:13:37.142037+00', 'Tom''s Delight', 'TOMS DELIGHT', 2, 32, 9999, 1, 3, 42, 651, '1992-09-01', 'For Tom Toriyama.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12240, '2005-04-17 22:00:00+00', '2012-01-20 12:57:36.639902+00', 'Waters of Dee, The', 'WATERS OF DEE', 7, 0, 9999, NULL, 54, NULL, 3545, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12244, '2005-04-19 22:00:00+00', '2012-01-20 12:57:36.675874+00', 'Saint Machar Reel, The', 'SAINT MACHAR REEL', 1, 32, 9999, 1, 2, NULL, 108, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6927, '1997-04-03 22:00:00+00', '2018-04-03 00:08:24.157858+00', 'Was It Fate?', 'WAS IT FATE', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6619, '1997-04-03 22:00:00+00', '2022-08-20 19:08:39.545162+00', 'Titirangi Reel', 'TITIRANGI REEL', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6655, '1997-09-16 22:00:00+00', '2019-03-09 19:35:47.521904+00', 'Torpheen', 'TORPHEEN', 3, 32, 9999, 1, 4, 1, 241, NULL, '', 78, '8008/8888/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6647, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.531122+00', 'Toorie, The', 'TOORIE', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6648, '1997-08-26 22:00:00+00', '2012-01-20 12:56:52.538562+00', 'Top O'' The Grange', 'TOP O THE GRANGE', 1, 32, 9999, 1, 4, NULL, 176, '1974-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6640, '2002-04-19 22:00:00+00', '2019-03-09 19:41:04.247115+00', 'Tom Steele', 'TOM STEELE', 3, 32, 9999, 1, 4, 2, 104, '1991-01-01', '', 88, '8888/8008/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6651, '2002-02-27 23:00:00+00', '2012-01-20 12:56:52.559181+00', 'Tops and Bottoms', 'TOPS AND BOTTOMS', 1, 32, 9999, 1, 4, NULL, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6672, '2000-05-17 22:00:00+00', '2019-05-04 00:46:06.126547+00', 'Cat on the Fiddle, The', 'CAT ON THE FIDDLE', 2, 32, 9999, 1, 2, 76, 2203, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6660, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.621093+00', 'Torwood House', 'TORWOOD HOUSE', 1, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18865, '2018-10-07 11:12:49.803123+00', '2019-09-27 23:55:39.589617+00', 'Regency Faire', 'REGENCY FAIRE', 3, 32, NULL, 1, 4, 2, 2766, '2009-03-01', '', 75, ' 8888/4444/8888/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6665, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.656503+00', 'Tour O'' The Downs', 'TOUR O THE DOWNS', 3, 32, 9999, 1, 4, NULL, 225, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6667, '1997-09-16 22:00:00+00', '2012-01-20 12:56:52.670833+00', 'Tournee-Do', 'TOURNEEDO', 2, 32, 9999, 2, 3, NULL, 43, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6668, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.677759+00', 'Toward Castle', 'TOWARD CASTLE', 1, 92, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6669, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.684547+00', 'Tower, The', 'TOWER', 1, 32, 9999, 4, 4, NULL, 159, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12251, '2005-04-19 22:00:00+00', '2018-04-03 00:07:46.246055+00', 'Flourish, The', 'FLOURISH', 3, 32, 9999, 1, 3, 42, 2701, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6673, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.712167+00', 'Traditions Of Edinburgh', 'TRADITIONS OF EDINBURGH', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6674, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.720625+00', 'Trafalgar Square, The', 'TRAFALGAR SQUARE', 1, 32, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12239, '2005-04-17 22:00:00+00', '2016-05-12 07:35:47.456429+00', 'Miss Alison Little', 'MISS ALISON LITTLE', 7, 0, 9999, 107, 51, NULL, 3545, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6653, '1998-04-19 22:00:00+00', '2016-05-24 22:38:12.042528+00', 'Topsy Turvy', 'TOPSY TURVY', 1, 32, 9999, 1, 3, 42, 352, '1993-01-01', '', 50, '800/800/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6633, '1997-04-03 22:00:00+00', '2017-03-27 16:42:30.043954+00', 'Toddlin'' Tim', 'TODDLIN TIM', 1, 32, 9999, 1, 4, 1, 104, NULL, '', 72, '8008/0880/8888/4888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6636, '1997-04-03 22:00:00+00', '2018-04-03 00:08:21.431147+00', 'Toetoe', 'TOETOE', 1, 24, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6652, '1997-09-16 22:00:00+00', '2018-04-03 00:08:21.547762+00', 'Topsy Turvy', 'TOPSY TURVY', 3, 32, 9999, 1, 3, 42, 300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6654, '2002-04-19 22:00:00+00', '2018-04-03 00:08:21.5729+00', 'Torf''s Watching!', 'TORFS WATCHING', 3, 32, 9999, 1, 3, 42, 758, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6663, '1997-09-16 22:00:00+00', '2018-04-03 00:08:21.614603+00', 'Touch Of Gold', 'TOUCH OF GOLD', 3, 32, 9999, 1, 3, 42, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6664, '1997-09-16 22:00:00+00', '2018-04-03 00:08:21.631312+00', 'Touchstone, The', 'TOUCHSTONE', 1, 32, 9999, 1, 3, 42, 466, '1780-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6719, '1997-04-03 22:00:00+00', '2018-04-26 22:38:29.86211+00', 'Trip to Geneva, A', 'TRIP TO GENEVA', 2, 32, 9999, 1, 3, 42, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12257, '2005-04-24 22:00:00+00', '2012-01-20 12:57:36.794573+00', 'Glenesk Pheasants', 'GLENESK PHEASANTS', 3, 32, 9999, 1, 4, NULL, 3547, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12261, '2005-04-24 22:00:00+00', '2018-10-05 13:03:06.857502+00', 'Greg''s Place', 'GREGS PLACE', 1, 32, 9999, 1, 3, 42, 2766, '2004-06-01', 'This dance was written to celebrate Greg Canfield’s purchase of his first house.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12255, '2005-04-24 22:00:00+00', '2018-04-03 00:07:48.064324+00', 'George Todd Reel', 'GEORGE TODD REEL', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12266, '2005-04-24 22:00:00+00', '2018-10-05 13:16:45.149961+00', 'Happy Heart', 'HAPPY HEART', 1, 32, 9999, 1, 3, 42, 2766, '2005-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12253, '2005-04-24 22:00:00+00', '2020-07-13 21:27:13.428324+00', 'Gallagher''s Rant', 'GALLAGHERS RANT', 2, 40, 9999, 1, 4, 1, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6656, '1997-04-03 22:00:00+00', '2020-09-04 07:51:38.02523+00', 'Torridon', 'TORRIDON', 3, 32, 9999, 1, 3, 42, 270, NULL, '', 56, '840/844/866/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12249, '2005-04-19 22:00:00+00', '2021-01-15 11:47:09.054991+00', 'Cast''n Reel, The', 'CASTN REEL', 1, 32, 9999, 1, 2, 76, 1760, '2003-01-01', '', 52, '80/88/80/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12242, '2005-04-19 22:00:00+00', '2021-01-15 11:50:44.996448+00', 'Steppe Dance for Olga, A', 'STEPPE DANCE FOR OLGA', 1, 32, 9999, 1, 2, 76, 108, '2004-01-01', '', 52, '44/44/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6675, '1998-01-12 23:00:00+00', '2021-04-05 19:56:41.532125+00', 'Trail Of The Swan, The', 'TRAIL OF THE SWAN', 3, 32, 9999, 1, 3, 42, 108, '1977-01-02', '', 47, '840/866/866/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6661, '1998-01-05 23:00:00+00', '2021-04-05 20:03:14.192149+00', 'Tosson Hill', 'TOSSON HILL', 1, 32, 9999, 1, 3, 42, 524, NULL, 'From the notes: "Tosson Hill (1447 ft.) is the highest point of the Simonside Hills near Rothbury, Northumberland and forms part of the Reivers Way. The small area enclosing the triangulation point gives magnificent views to the North and North-West."', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6681, '2001-05-24 22:00:00+00', '2012-01-20 12:56:52.772927+00', 'Travelling Dancers, The', 'TRAVELLING DANCERS', 2, 64, 9999, 4, 4, NULL, 70, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18866, '2018-10-07 11:19:39.868124+00', '2018-10-07 11:19:39.868124+00', 'Riding the Wave', 'RIDING THE WAVE', 1, 32, NULL, 1, 3, 42, 2766, '2010-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6694, '1997-09-16 22:00:00+00', '2012-01-20 12:56:52.863274+00', 'Tribute to Babs', 'TRIBUTE TO BABS', 2, 32, 9999, 1, 4, NULL, 735, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6696, '2001-05-20 22:00:00+00', '2012-01-20 12:56:52.877007+00', 'Tribute to Bobby Brown, A', 'TRIBUTE TO BOBBY BROWN', 1, 32, 9999, 4, 4, NULL, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6697, '1998-01-05 23:00:00+00', '2012-01-20 12:56:52.883833+00', 'Tribute to Emma, The', 'TRIBUTE TO EMMA', 1, 32, 9999, 1, 4, NULL, 247, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6698, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.890705+00', 'Tribute to Jan', 'TRIBUTE TO JAN', 1, 32, 9999, 1, 4, NULL, 203, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6700, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.90429+00', 'Tribute to Norfolk Island', 'TRIBUTE TO NORFOLK ISLAND', 3, 96, 9999, 4, 4, NULL, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6702, '1997-09-16 22:00:00+00', '2012-01-20 12:56:52.91972+00', 'Tribute to Walter Sutherland, A', 'TRIBUTE TO WALTER SUTHERLAND', 2, 32, 9999, 1, 4, NULL, 368, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6703, '1997-11-27 23:00:00+00', '2012-01-20 12:56:52.926729+00', 'Tricorne, The', 'TRICORNE', 4, 64, 5, 6, 3, NULL, 791, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12260, '2005-04-24 22:00:00+00', '2012-01-20 12:57:36.820503+00', 'Great House Quadrille, The', 'GREAT HOUSE QUADRILLE', 3, 64, 9999, 4, 4, NULL, 3491, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12262, '2005-04-24 22:00:00+00', '2012-01-20 12:57:36.837864+00', 'Gypsy Rover', 'GYPSY ROVER', 3, 32, 9999, 5, 2, NULL, 2677, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12268, '2005-04-24 22:00:00+00', '2012-01-20 12:57:36.889755+00', 'Harpenden', 'HARPENDEN', 4, 128, 2, 4, 4, NULL, 3574, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12269, '2005-04-24 22:00:00+00', '2012-01-20 12:57:36.898377+00', 'Hazelhurst Reel', 'HAZELHURST REEL', 1, 32, 9999, 1, 4, NULL, 3273, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12270, '2005-04-24 22:00:00+00', '2012-01-20 12:57:36.907029+00', 'Heart of Heene, The', 'HEART OF HEENE', 3, 32, 9999, 2, 3, NULL, 3468, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12272, '2005-04-24 22:00:00+00', '2012-01-20 12:57:36.924753+00', 'Here''s Some Fun', 'HERES SOME FUN', 1, 32, 9999, 1, 4, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12273, '2005-04-24 22:00:00+00', '2012-01-20 12:57:36.933389+00', 'Hilary Johnson''s Reel', 'HILARY JOHNSONS REEL', 1, 40, 9999, 1, 4, NULL, 3575, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12271, '2005-04-24 22:00:00+00', '2012-07-03 18:52:58.509177+00', 'Heidelberg Exchange, The', 'HEIDELBERG EXCHANGE', 1, 48, 9999, 2, 3, 17, 2434, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6706, '1997-09-16 22:00:00+00', '2012-01-20 12:56:52.947936+00', 'Trinity Street', 'TRINITY STREET', 3, 32, 9999, 1, 4, NULL, 1258, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12256, '2005-04-24 22:00:00+00', '2022-09-06 19:10:14.465869+00', 'Gillian''s Jig', 'GILLIANS JIG', 2, 32, 9999, 2, 3, 42, 3538, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6632, '1998-04-19 22:00:00+00', '2022-11-01 19:13:55.666984+00', 'Tocher Band, The', 'TOCHER BAND', 1, 32, 9999, 1, 3, 42, 146, '1982-01-01', 'Inscribed "For Elizabeth and Gerry Yates on the occasion of their wedding, 2nd October 1982."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6708, '1997-04-03 22:00:00+00', '2012-01-20 12:56:52.962256+00', 'Trip Along the Royal Mile', 'TRIP ALONG THE ROYAL MILE', 1, 28, 9999, 4, 4, NULL, 307, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12258, '2005-04-24 22:00:00+00', '2018-04-03 00:07:49.14066+00', 'Gold and Silver', 'GOLD AND SILVER', 2, 32, 9999, 1, 3, 42, 3556, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6714, '1999-05-09 22:00:00+00', '2012-01-20 12:56:53.008159+00', 'Trip To Boston, A', 'TRIP TO BOSTON', 2, 32, 9999, 2, 3, 17, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12259, '2005-04-24 22:00:00+00', '2018-04-03 00:07:49.274155+00', 'Golden Memories', 'GOLDEN MEMORIES', 1, 32, 9999, 1, 3, 42, 3573, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6716, '1997-09-04 22:00:00+00', '2012-01-20 12:56:53.021778+00', 'Trip To Charlotte', 'TRIP TO CHARLOTTE', 3, 32, 9999, 1, 4, NULL, 724, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6723, '1997-04-03 22:00:00+00', '2012-01-20 12:56:53.070578+00', 'Trip to Jerusalem, The', 'TRIP TO JERUSALEM', 3, 32, 9999, 3, 5, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6726, '1999-05-09 22:00:00+00', '2012-01-20 12:56:53.091793+00', 'Trip to Moab, A', 'TRIP TO MOAB', 2, 32, 9999, 1, 4, 1, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6717, '1997-04-03 22:00:00+00', '2016-05-29 21:31:00.868535+00', 'Trip to Cincinnati', 'TRIP TO CINCINNATI', 1, 32, 9999, 6, 3, NULL, 382, '1994-03-01', '', 83, '888/888/888/440', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6676, '1997-04-03 22:00:00+00', '2016-07-15 12:56:42.611359+00', 'Transformation', 'TRANSFORMATION', 3, 24, 9999, 1, 4, 1, 352, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6699, '2001-06-12 22:00:00+00', '2017-07-16 00:56:49.483086+00', 'Tribute to Jimmy Strachan', 'TRIBUTE TO JIMMY STRACHAN', 3, 64, 9999, 4, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12263, '2005-04-24 22:00:00+00', '2018-04-03 00:07:50.541708+00', 'Hamilton & Clydesdale Reel', 'HAMILTON AND CLYDESDALE REEL', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12264, '2005-04-24 22:00:00+00', '2018-04-03 00:07:50.725142+00', 'Happy 50th Anniversary', 'HAPPY 50TH ANNIVERSARY', 3, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12267, '2005-04-24 22:00:00+00', '2018-04-03 00:07:50.825167+00', 'Happy Valentine', 'HAPPY VALENTINE', 2, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6684, '1997-09-16 22:00:00+00', '2018-04-03 00:08:21.698052+00', 'Travelling Scots, The', 'TRAVELLING SCOTS', 2, 32, 9999, 1, 3, 42, 42, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6690, '1997-04-03 22:00:00+00', '2018-04-03 00:08:21.756428+00', 'Trefoil, The', 'TREFOIL', 2, 32, 9999, 1, 3, 42, 156, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6692, '1997-09-16 22:00:00+00', '2018-04-03 00:08:21.773082+00', 'Tribe of Galen, The', 'TRIBE OF GALEN', 3, 32, 9999, 1, 3, 42, 108, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6693, '1997-04-03 22:00:00+00', '2018-04-03 00:08:21.781302+00', 'Tribute to Alexander III, A', 'TRIBUTE TO ALEXANDER III', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6695, '2001-05-20 22:00:00+00', '2018-04-03 00:08:21.806563+00', 'Tribute to Blairgowrie', 'TRIBUTE TO BLAIRGOWRIE', 1, 32, 9999, 1, 3, 42, 1317, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6730, '1997-09-16 22:00:00+00', '2012-01-20 12:56:53.120259+00', 'Trip to Saint Andrews, A', 'TRIP TO SAINT ANDREWS', 3, 32, 9999, 1, 2, NULL, 70, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6731, '1997-04-03 22:00:00+00', '2012-01-20 12:56:53.127052+00', 'Trip To Tasmania', 'TRIP TO TASMANIA', 1, 32, 9999, 1, 4, NULL, 329, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6732, '1997-09-16 22:00:00+00', '2012-01-20 12:56:53.133892+00', 'Trip to the Altar', 'TRIP TO THE ALTAR', 2, 40, 9999, 2, 3, NULL, 56, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12275, '2005-12-21 23:00:00+00', '2012-01-20 12:57:36.951925+00', 'Michael''s Southern Reel', 'MICHAELS SOUTHERN REEL', 1, 32, 9999, 1, 4, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12280, '2005-04-25 22:00:00+00', '2018-04-03 00:07:53.385321+00', 'Inchtuthil', 'INCHTUTHIL', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12295, '2005-04-25 22:00:00+00', '2018-10-05 15:56:22.698705+00', 'Kitty Rae Strathspey', 'KITTY RAE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2766, '2004-04-01', 'This dance was written in honor of Mary Luce’s beloved cat Kitty Rae.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12297, '2005-04-25 22:00:00+00', '2019-02-25 16:57:40.267611+00', 'Knotwork', 'KNOTWORK', 1, 32, 9999, 4, 4, 13, 2766, '2004-03-01', '', 66, '5252/2525/8888/4848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12282, '2005-04-25 22:00:00+00', '2012-01-20 12:57:37.019022+00', 'It''s a Ceilidh', 'ITS A CEILIDH', 1, 0, 9999, 1, 4, NULL, 62, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6713, '1998-07-08 22:00:00+00', '2020-09-04 08:46:30.523328+00', 'Trip to Belgium', 'TRIP TO BELGIUM', 1, 32, 9999, 1, 4, 2, 212, NULL, '', 75, '8008/8888/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6683, '1997-04-03 22:00:00+00', '2021-04-05 19:42:23.053133+00', 'Travelling Procters, The', 'TRAVELLING PROCTERS', 2, 40, 9999, 1, 3, 42, 3586, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6691, '1997-11-27 23:00:00+00', '2021-04-18 20:46:26.10801+00', 'Trewyn Court', 'TREWYN COURT', 4, 64, 5, 2, 3, 17, 304, '1984-01-01', 'Each 32 bar section is a two couple dance. After both strathspey and reel sections 1st couple have progressed to the bottom.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6724, '2003-01-26 23:00:00+00', '2021-05-03 08:12:27.066881+00', 'Trip to Lismore, A', 'TRIP TO LISMORE', 2, 24, 9999, 1, 3, 42, 35, NULL, '', 50, '880/880/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6722, '1997-09-16 22:00:00+00', '2021-06-14 23:05:17.922298+00', 'Trip to Japan', 'TRIP TO JAPAN', 2, 32, 9999, 1, 3, 42, 787, '1988-01-01', '', 41, '800/800/844/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12298, '2005-04-25 22:00:00+00', '2018-10-05 21:37:50.541582+00', 'Lady Gwen', 'LADY GWEN', 3, 32, 9999, 1, 4, 11, 2766, '2015-01-01', 'This dance is written for Gwen Leyffer, always a lady, in celebration of her birthday.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6733, '1997-09-16 22:00:00+00', '2012-01-20 12:56:53.141607+00', 'Trip to the Cowal Games, A', 'TRIP TO THE COWAL GAMES', 2, 32, 9999, 1, 4, NULL, 1320, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6735, '1997-09-16 22:00:00+00', '2012-01-20 12:56:53.158217+00', 'Trip to the East, A', 'TRIP TO THE EAST', 2, 32, 9999, 1, 2, NULL, 1321, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6737, '1997-04-03 22:00:00+00', '2012-01-20 12:56:53.17206+00', 'Trip to the Philippines', 'TRIP TO THE PHILIPPINES', 2, 40, 9999, 1, 4, NULL, 293, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6742, '1997-09-16 22:00:00+00', '2012-01-20 12:56:53.209491+00', 'Trip To Vermont', 'TRIP TO VERMONT', 2, 32, 9999, 1, 4, NULL, 1322, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6729, '1998-07-08 22:00:00+00', '2019-02-08 17:58:57.943182+00', 'Trip to South Africa', 'TRIP TO SOUTH AFRICA', 1, 32, 9999, 1, 4, 11, 377, NULL, 'To mark Barrie and Valerie''s holiday 1985', 84, '8448/4884/8668/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6749, '1998-07-09 22:00:00+00', '2012-01-20 12:56:53.263257+00', 'Troon Medley', 'TROON MEDLEY', 4, 32, 1, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6752, '1997-09-16 22:00:00+00', '2012-01-20 12:56:53.284619+00', 'True North, The', 'TRUE NORTH', 1, 40, 9999, 5, 2, NULL, 401, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6755, '1997-09-16 22:00:00+00', '2012-01-20 12:56:53.305268+00', 'Tryst, The', 'TRYST', 1, 32, 9999, 7, 2, NULL, 666, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6757, '1997-11-25 23:00:00+00', '2012-01-20 12:56:53.319064+00', 'Tuarie Burn', 'TUARIE BURN', 2, 128, 9999, 4, 4, NULL, 318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6760, '1997-11-23 23:00:00+00', '2012-01-20 12:56:53.339683+00', 'Tullchan Lodge', 'TULLCHAN LODGE', 3, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12285, '2005-04-25 22:00:00+00', '2012-01-20 12:57:37.045198+00', 'Jersey Cream', 'JERSEY CREAM', 2, 32, 9999, 1, 4, NULL, 1, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12287, '2005-04-25 22:00:00+00', '2012-01-20 12:57:37.07181+00', 'Joe''s Jig', 'JOES JIG', 2, 32, 9999, 3, 5, NULL, 692, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12294, '2005-04-25 22:00:00+00', '2012-01-20 12:57:37.128816+00', 'Keswick Reel, The', 'KESWICK REEL', 1, 32, 9999, 8, 6, NULL, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6762, '1997-04-03 22:00:00+00', '2012-01-20 12:56:53.353429+00', 'Tullibole Castle', 'TULLIBOLE CASTLE', 1, 64, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12283, '2005-04-25 22:00:00+00', '2018-04-03 00:07:55.044802+00', 'Jean Auld''s Reel', 'JEAN AULDS REEL', 1, 32, 9999, 1, 3, 42, 3576, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12286, '2005-04-25 22:00:00+00', '2018-04-03 00:07:55.686909+00', 'Jimmy Frae Dundee', 'JIMMY FRAE DUNDEE', 1, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12292, '2005-04-25 22:00:00+00', '2022-09-06 19:11:58.969504+00', 'Katchewanooka Lake', 'KATCHEWANOOKA LAKE', 3, 32, 9999, 1, 2, 76, 3538, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6686, '1997-09-16 22:00:00+00', '2022-11-01 18:30:21.678357+00', 'Travelling Triangles', 'TRAVELLING TRIANGLES', 1, 40, 9999, 1, 3, 42, 1315, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6685, '1997-09-16 22:00:00+00', '2022-11-01 18:46:27.707425+00', 'Travelling Tinker, The', 'TRAVELLING TINKER', 2, 32, 9999, 1, 3, 42, 179, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6740, '1997-09-16 22:00:00+00', '2022-11-07 10:16:23.580007+00', 'Trip to Transylvania, A', 'TRIP TO TRANSYLVANIA', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6741, '1997-09-16 22:00:00+00', '2016-07-28 14:34:16.16928+00', 'Trip to Tunbridge, A', 'TRIP TO TUNBRIDGE', 3, 32, 9999, 1, 3, 42, 459, '1793-01-01', 'Official alias: Chorus Jig', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12288, '2005-04-25 22:00:00+00', '2018-04-03 00:07:56.395674+00', 'Jolly Tars, The', 'JOLLY TARS', 1, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12289, '2005-04-25 22:00:00+00', '2018-04-03 00:07:56.454043+00', 'Journey North', 'JOURNEY NORTH', 1, 32, 9999, 1, 3, 42, 3374, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6746, '1997-09-16 22:00:00+00', '2018-04-03 00:08:21.906486+00', 'Triple Crown, The', 'TRIPLE CROWN', 2, 48, 9999, 1, 3, 42, 359, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6747, '1997-09-16 22:00:00+00', '2018-04-03 00:08:22.164409+00', 'Tripping Over Scotia''s Shores', 'TRIPPING OVER SCOTIAS SHORES', 1, 32, 9999, 1, 3, 42, 598, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6745, '1997-04-03 22:00:00+00', '2018-04-03 00:08:22.473353+00', 'Trip to Fife, A', 'TRIP TO FIFE', 1, 40, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6750, '1997-04-03 22:00:00+00', '2018-04-03 00:08:22.690256+00', 'Troubled Water', 'TROUBLED WATER', 3, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6753, '2003-01-25 23:00:00+00', '2018-04-03 00:08:22.706975+00', 'Trumpet Hornpipe, The', 'TRUMPET HORNPIPE', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6754, '1997-09-16 22:00:00+00', '2018-04-03 00:08:22.716057+00', 'Trustlands Diamond Strathspey', 'TRUSTLANDS DIAMOND STRATHSPEY', 3, 40, 9999, 1, 3, 42, 907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6759, '1997-04-03 22:00:00+00', '2018-04-03 00:08:22.740324+00', 'Tulchan Lodge', 'TULCHAN LODGE', 3, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6761, '1997-10-27 23:00:00+00', '2018-04-03 00:08:22.748589+00', 'Tullamore Piper, The', 'TULLAMORE PIPER', 1, 32, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6765, '1997-04-03 22:00:00+00', '2018-04-03 00:08:22.756917+00', 'Tullochgorum', 'TULLOCHGORUM', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6770, '1997-04-03 22:00:00+00', '2018-04-03 00:08:22.840284+00', 'Tune Your Fiddle', 'TUNE YOUR FIDDLE', 3, 40, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6772, '1997-04-03 22:00:00+00', '2018-04-03 00:08:22.865232+00', 'Turn Again Whittington', 'TURN AGAIN WHITTINGTON', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12303, '2005-04-25 22:00:00+00', '2018-10-05 06:28:33.010068+00', 'Little Folderol, A', 'LITTLE FOLDEROL', 1, 32, 9999, 1, 3, 42, 2766, '2004-10-01', 'I like the figures in this dance and put them together for fun.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6776, '1997-11-23 23:00:00+00', '2012-01-20 12:56:53.450786+00', 'Turning Point', 'TURNING POINT', 1, 32, 9999, 1, 2, NULL, 389, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6777, '1998-04-24 22:00:00+00', '2012-01-20 12:56:53.457683+00', 'Turning Thirty', 'TURNING THIRTY', 2, 32, 9999, 1, 2, NULL, 348, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6778, '1997-04-03 22:00:00+00', '2012-01-20 12:56:53.464836+00', 'Turnpike Rant', 'TURNPIKE RANT', 2, 32, 9999, 1, 4, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6779, '1997-09-17 22:00:00+00', '2012-01-20 12:56:53.471629+00', 'Westbury Strathspey', 'WESTBURY STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 3735, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18904, '2018-10-09 06:41:45.177054+00', '2018-10-09 06:41:45.177054+00', 'Sweet Violets', 'SWEET VIOLETS', 3, 32, NULL, 1, 3, 42, 2766, '2009-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12301, '2005-04-25 22:00:00+00', '2019-03-02 12:33:38.765332+00', 'Leslie''s Strathspey', 'LESLIES STRATHSPEY', 3, 64, 9999, 4, 4, 3, 108, '2004-01-01', '', 75, '8888/4444/4444/8888/4444/4444/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6743, '1997-09-16 22:00:00+00', '2020-02-08 20:08:59.861099+00', 'Trip to Wetwang, A', 'TRIP TO WETWANG', 2, 40, 9999, 1, 100, 2, 1128, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6751, '2002-04-30 22:00:00+00', '2020-03-22 15:38:13.835846+00', 'Troy''s Wedding', 'TROYS WEDDING', 2, 48, 9999, 1, 4, 2, 520, '1993-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6738, '1997-09-16 22:00:00+00', '2020-08-07 09:53:10.243236+00', 'Trip to the Vineyards', 'TRIP TO THE VINEYARDS', 1, 32, 9999, 1, 3, 42, 109, NULL, '', 37, '800/844/844/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6781, '1997-09-16 22:00:00+00', '2020-08-07 09:53:39.331641+00', 'Turtle In The Marsh, The', 'TURTLE IN THE MARSH', 2, 40, 9999, 4, 55, NULL, 151, NULL, '5 ladies', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12281, '2005-04-25 22:00:00+00', '2020-09-15 09:15:49.740041+00', 'Ingleton Rant', 'INGLETON RANT', 1, 32, 9999, 1, 3, 42, 534, NULL, '', 50, '880/822/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12296, '2005-04-25 22:00:00+00', '2020-09-15 09:21:10.10769+00', 'Knot Garden, The', 'KNOT GARDEN', 3, 32, 9999, 1, 3, 42, 930, NULL, '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12290, '2005-04-25 22:00:00+00', '2021-03-03 23:01:18.657265+00', 'Mist on the Mountain', 'MIST ON THE MOUNTAIN', 3, 32, 9999, 1, 3, 42, 479, '2005-01-01', '', 44, '880/800/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12293, '2005-04-25 22:00:00+00', '2021-01-23 02:56:18.495151+00', 'Keeper of the Purse, The', 'KEEPER OF THE PURSE', 2, 32, 9999, 1, 4, 1, 2525, '2000-05-01', 'Devised for Chris Smithers, Tayside Dancers treasurer.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6758, '1997-09-16 22:00:00+00', '2021-04-05 13:11:05.53892+00', 'Tudor Rose, The', 'TUDOR ROSE', 1, 32, 9999, 1, 4, 1, 1323, NULL, '', 78, '8888/8668/8440/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6767, '1997-04-03 22:00:00+00', '2021-04-05 12:26:55.071281+00', 'Tullynessle', 'TULLYNESSLE', 3, 32, 9999, 1, 4, 1, 108, '1977-01-01', '', 81, '8484/8888/8880/8484', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6764, '2002-04-15 22:00:00+00', '2021-04-07 15:12:46.821647+00', 'Tulloch Rant, The', 'TULLOCH RANT', 4, 64, 5, 4, 4, 3, 1324, NULL, '', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12302, '2005-04-25 22:00:00+00', '2021-07-30 07:51:45.746313+00', 'Let''s Celebrate!', 'LETS CELEBRATE', 2, 40, 9999, 1, 100, 2, 308, NULL, '', 73, '8008/8228/8888/0880/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12274, '2005-04-24 22:00:00+00', '2021-07-25 20:10:00.258346+00', 'Hogmanay Strathspey', 'HOGMANAY STRATHSPEY', 3, 32, 9999, 2, 3, 17, 264, '1995-01-03', 'Devised for my wife Emma.', 50, '800/844/800/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6789, '2002-03-12 23:00:00+00', '2012-01-20 12:56:53.543455+00', 'Twa For The Road', 'TWA FOR THE ROAD', 1, 40, 9999, 1, 4, 1, 111, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6790, '1997-09-16 22:00:00+00', '2012-01-20 12:56:53.550283+00', 'Twa Heids Are Better Than Yin', 'TWA HEIDS ARE BETTER THAN YIN', 2, 96, 9999, 4, 5, NULL, 1326, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6801, '1997-09-16 22:00:00+00', '2019-03-09 13:53:12.77101+00', 'Twenty-First, The', 'TWENTYFIRST', 3, 32, 9999, 2, 3, 17, 146, NULL, '', 71, '880/880/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4672, '1997-12-21 23:00:00+00', '2019-03-12 23:09:03.070675+00', 'Mornins'' Awa''', 'MORNINS AWA', 3, 32, 9999, 1, 4, 1, 9, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12304, '2005-04-25 22:00:00+00', '2012-01-20 12:57:37.199109+00', 'MacLeod Romp', 'MACLEOD ROMP', 2, 32, 9999, 1, 4, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12305, '2005-04-25 22:00:00+00', '2012-01-20 12:57:37.205859+00', 'MacLeodary', 'MACLEODARY', 2, 32, 9999, 2, 3, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6807, '1997-04-03 22:00:00+00', '2019-03-16 19:43:01.979127+00', 'Twiddle In The Middle', 'TWIDDLE IN THE MIDDLE', 1, 32, 9999, 1, 3, 42, 48, NULL, '', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12324, '2005-04-27 22:00:00+00', '2019-04-02 20:37:32.878326+00', 'Moment for Marilynn, A', 'MOMENT FOR MARILYNN', 3, 32, 9999, 1, 2, 76, 2677, NULL, '', 60, '84/88/88/84', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12308, '2005-04-25 22:00:00+00', '2012-01-20 12:57:37.224785+00', 'Manx Mallets', 'MANX MALLETS', 1, 32, 9999, NULL, NULL, NULL, 3549, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12316, '2005-04-26 22:00:00+00', '2019-09-24 22:02:25.13733+00', 'Meopham Green', 'MEOPHAM GREEN', 2, 48, 9999, 3, 5, 7, 186, NULL, '', 53, '80800/80880/80800/88888/80800/80800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12313, '2005-04-26 22:00:00+00', '2012-01-20 12:57:37.251742+00', 'McPhail''s Reel', 'MACPHAILS REEL', 1, 32, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6782, '1998-01-04 23:00:00+00', '2019-04-27 20:12:43.555571+00', 'Tushielaw Brae', 'TUSHIELAW BRAE', 1, 32, 9999, 1, 3, 42, 48, NULL, '', 50, '862/888/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6815, '1998-04-24 22:00:00+00', '2019-08-04 16:53:41.116967+00', 'Twixt Silver And Gold', 'TWIXT SILVER AND GOLD', 3, 32, 9999, 1, 3, 42, 146, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6796, '1997-09-16 22:00:00+00', '2012-01-20 12:56:53.593756+00', 'Tweedale Reel', 'TWEEDALE REEL', 1, 32, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6799, '1998-04-24 22:00:00+00', '2012-01-20 12:56:53.617586+00', 'Twenty-Eighth Of February, The', 'TWENTYEIGHTH OF FEBRUARY', 2, 48, 9999, 1, 4, 1, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6802, '1997-09-16 22:00:00+00', '2012-01-20 12:56:53.638884+00', 'Twenty-Five Today', 'TWENTYFIVE TODAY', 1, 32, 9999, 1, 4, NULL, 327, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6806, '1997-04-03 22:00:00+00', '2012-01-20 12:56:53.667524+00', 'Twice Over', 'TWICE OVER', 2, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6808, '1997-09-16 22:00:00+00', '2012-01-20 12:56:53.681166+00', 'Twin Cathedrals, The', 'TWIN CATHEDRALS', 3, 80, 9999, 4, 4, NULL, 620, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6810, '1997-09-16 22:00:00+00', '2012-01-20 12:56:53.694914+00', 'Twin Towns', 'TWIN TOWNS', 3, 48, 9999, 1, 4, NULL, 1328, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6942, '1997-09-16 22:00:00+00', '2018-04-03 00:08:24.166116+00', 'Wateraid Jig', 'WATERAID JIG', 2, 32, 9999, 1, 3, 42, 1340, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12315, '2005-04-26 22:00:00+00', '2012-01-20 12:57:37.266139+00', 'Memories of Lindsay Ross', 'MEMORIES OF LINDSAY ROSS', 1, 32, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12317, '2005-04-26 22:00:00+00', '2012-01-20 12:57:37.279684+00', 'Mermaid''s Trail, The', 'MERMAIDS TRAIL', 3, 32, 9999, 1, 2, NULL, 385, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12319, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.293533+00', 'Miss Katherine MacKinnon''s Strathspey', 'MISS KATHERINE MACKINNONS STRATHSPEY', 3, 32, 9999, 2, 3, NULL, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6804, '1998-01-04 23:00:00+00', '2018-04-03 00:07:29.690275+00', 'Adrienne', 'ADRIENNE', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12312, '2005-04-26 22:00:00+00', '2018-03-25 19:05:58.637287+00', 'Mayumi''s Fancy', 'MAYUMIS FANCY', 3, 32, 9999, 4, 4, 1, 3542, '2001-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12322, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.313727+00', 'Miss Margaret McLaren''s Welcome', 'MISS MARGARET MACLARENS WELCOME', 3, 24, 9999, NULL, NULL, NULL, 406, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6795, '1997-09-16 22:00:00+00', '2018-04-03 00:08:22.973698+00', 'Twas O''er The Hills And Far Awa', 'TWAS OER THE HILLS AND FAR AWA', 3, 32, 9999, 1, 3, 42, 446, '1713-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12300, '2005-04-25 22:00:00+00', '2018-04-03 00:07:58.87271+00', 'Larnach''s Folly', 'LARNACHS FOLLY', 1, 32, 9999, 1, 3, 42, 3272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12307, '2005-04-25 22:00:00+00', '2018-04-03 00:08:01.800006+00', 'Mandeville Jig, The', 'MANDEVILLE JIG', 2, 32, 9999, 1, 3, 42, 3553, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6773, '1998-04-24 22:00:00+00', '2018-04-03 00:08:22.873597+00', 'Turn For The Better, A', 'TURN FOR THE BETTER', 1, 32, 9999, 1, 3, 42, 352, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6794, '1999-07-25 22:00:00+00', '2018-04-03 00:08:22.940346+00', 'Twa'' Brigs O'' Dundee, The', 'TWA BRIGS O DUNDEE', 3, 32, 9999, 1, 3, 42, 1325, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6788, '1998-01-05 23:00:00+00', '2018-04-03 00:08:22.957091+00', 'Twa Corbies, The', 'TWA CORBIES', 1, 40, 9999, 1, 3, 42, 332, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6809, '1997-04-03 22:00:00+00', '2018-04-03 00:08:23.040469+00', 'Twin City Reel', 'TWIN CITY REEL', 1, 32, 9999, 1, 3, 42, 108, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6812, '1997-09-16 22:00:00+00', '2018-04-03 00:08:23.098961+00', 'Twirl For Jean, A', 'TWIRL FOR JEAN', 2, 40, 9999, 1, 3, 42, 1333, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6854, '1997-09-16 22:00:00+00', '2018-08-09 11:44:06.962302+00', 'Uppies and the Doonies, The', 'UPPIES AND THE DOONIES', 2, 48, 9999, 1, 4, 1, 678, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6820, '1997-09-16 22:00:00+00', '2012-01-20 12:56:53.766814+00', 'Two by Two', 'TWO BY TWO', 1, 24, 9999, 1, 2, NULL, 666, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12325, '2005-04-27 22:00:00+00', '2018-10-06 10:46:58.892124+00', 'Monkey Wrench', 'MONKEY WRENCH', 1, 32, 9999, 1, 3, 42, 2766, '2003-07-01', 'The first formation in this dance suggests the patchwork pattern *Monkey Wrench* to me.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6825, '1997-04-03 22:00:00+00', '2012-01-20 12:56:53.801726+00', 'Two''s Company', 'TWOS COMPANY', 3, 32, 9999, 1, 2, NULL, 199, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6829, '1997-08-22 22:00:00+00', '2019-03-09 13:47:51.846373+00', 'Tyneside Schottische, The', 'TYNESIDE SCHOTTISCHE', 3, 80, 9999, 4, 4, 3, 523, NULL, '', 95, '8888/8888/8888/8888/8888/8484/4848/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6861, '1999-03-09 23:00:00+00', '2019-03-20 23:21:40.028567+00', 'Vale Of Singing Gold, The', 'VALE OF SINGING GOLD', 1, 32, 9999, 1, 3, 42, 44, '1992-01-01', '', 44, '800/880/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6832, '1997-09-16 22:00:00+00', '2012-01-20 12:56:53.849748+00', 'Uncle Dudley', 'UNCLE DUDLEY', 1, 48, 9999, 1, 4, NULL, 563, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6784, '1997-04-03 22:00:00+00', '2020-11-06 11:24:37.032071+00', 'Twa Auld Hens', 'TWA AULD HENS', 1, 32, 9999, 1, 3, 42, 99, '1988-01-01', '', 50, '804/840/888/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6862, '1997-08-19 22:00:00+00', '2021-01-01 19:43:58.456808+00', 'Vale Of Strathmore, The', 'VALE OF STRATHMORE', 3, 32, 9999, 2, 3, 17, 104, '1992-01-01', '', 92, '880/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6860, '1997-09-16 22:00:00+00', '2021-04-04 12:03:20.734204+00', 'Vale Of Atholl, The', 'VALE OF ATHOLL', 2, 32, 9999, 1, 3, 42, 3461, NULL, '"The dance illustrates both the pastoral and craggy mountainous aspects of the region."', 50, '800/888/800/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6814, '1998-04-24 22:00:00+00', '2021-04-05 10:56:23.467443+00', 'Twixt Keir and Kent', 'TWIXT KEIR AND KENT', 2, 40, 9999, 1, 3, 42, 855, NULL, '', 50, '808/888/880/808/800', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6783, '1997-04-03 22:00:00+00', '2021-04-05 12:12:35.52038+00', 'Tushker, The', 'TUSHKER', 1, 32, 9999, 1, 3, 42, 101, NULL, 'Dedicated to Lloyd Leland.', 56, '800/888/888/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12291, '2005-04-25 22:00:00+00', '2021-07-30 07:43:45.56466+00', 'Kaleidoscope Reel, The', 'KALEIDOSCOPE REEL', 1, 80, 9999, 4, 4, NULL, 308, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12327, '2005-04-27 22:00:00+00', '2018-04-03 00:08:05.277392+00', 'Moonshine Valley', 'MOONSHINE VALLEY', 3, 32, 9999, 1, 3, 42, 3488, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6844, '1997-04-03 22:00:00+00', '2012-01-20 12:56:53.935494+00', 'Up And Away', 'UP AND AWAY', 2, 40, 9999, 1, 4, NULL, 213, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12329, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.362106+00', 'Mr William Meikle''s Reel', 'MR WILLIAM MEIKLES REEL', 1, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12330, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.368857+00', 'Mrs Esther Goodfellow', 'MRS ESTHER GOODFELLOW', 3, 32, 9999, 1, 2, NULL, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12332, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.382362+00', 'New Bees, The', 'NEW BEES', 2, 32, 9999, 1, 4, NULL, 2677, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12333, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.389164+00', 'New Bridge, A', 'NEW BRIDGE', 1, 32, 9999, 1, 4, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12338, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.422882+00', 'Rainbows on Skye', 'RAINBOWS ON SKYE', 1, 32, 9999, 1, 4, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12339, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.429614+00', 'Skye Time', 'SKYE TIME', 1, 32, 9999, 1, 4, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12340, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.4364+00', 'White Heather Hills', 'WHITE HEATHER HILLS', 1, 32, 9999, 1, 4, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6851, '1998-04-24 22:00:00+00', '2012-01-20 12:56:53.988426+00', 'Up the Muddy Mary', 'UP THE MUDDY MARY', 2, 32, 9999, 1, 4, NULL, 108, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6856, '1998-01-15 23:00:00+00', '2012-01-20 12:56:54.026893+00', 'Urquhart Castle', 'URQUHART CASTLE', 4, 96, 9999, 4, 98, NULL, 315, NULL, '4 men, 8 ladies', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6857, '1997-04-03 22:00:00+00', '2012-01-20 12:56:54.034034+00', 'Uscita', 'USCITA', 1, 80, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12331, '2005-04-27 22:00:00+00', '2018-04-03 00:08:06.194733+00', 'Mrs Gladys Allen', 'MRS GLADYS ALLEN', 2, 40, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12336, '2005-04-27 22:00:00+00', '2018-04-03 00:08:07.854675+00', 'Nixon''s Jig', 'NIXONS JIG', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6865, '1997-04-03 22:00:00+00', '2012-01-20 12:56:54.097688+00', 'Valerie', 'VALERIE', 2, 40, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6868, '1997-09-16 22:00:00+00', '2012-01-20 12:56:54.119923+00', 'Valerie''s Wedding', 'VALERIES WEDDING', 1, 64, 9999, 1, 4, NULL, 620, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6839, '1997-09-16 22:00:00+00', '2016-09-04 20:13:48.316848+00', 'Uninvited Dance, The', 'UNINVITED DANCE', 3, 32, 9999, 1, 3, 42, 351, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12341, '2005-04-27 22:00:00+00', '2018-04-03 00:08:16.886573+00', 'Simon''s Reel', 'SIMONS REEL', 1, 32, 9999, 1, 3, 42, 930, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6821, '1997-11-27 23:00:00+00', '2018-04-03 00:08:23.14889+00', 'Two Celtic Hearts', 'TWO CELTIC HEARTS', 4, 32, 1, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6859, '1997-04-03 22:00:00+00', '2017-09-15 07:19:47.685325+00', 'Val''s Fancy', 'VALS FANCY', 3, 32, 9999, 1, 3, 42, 129, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6822, '1997-11-24 23:00:00+00', '2018-04-03 00:08:23.173874+00', 'Two Misses, The', 'TWO MISSES', 4, 32, 1, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6827, '1997-09-16 22:00:00+00', '2018-04-03 00:08:23.207341+00', 'Tying the Knot', 'TYING THE KNOT', 3, 32, 9999, 1, 3, 42, 1331, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6828, '1997-09-16 22:00:00+00', '2018-04-03 00:08:23.249009+00', 'Tynedale Jig, The', 'TYNEDALE JIG', 2, 32, 9999, 1, 3, 42, 108, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6774, '1998-07-08 22:00:00+00', '2022-01-30 20:15:50.342046+00', 'Turn Ye To Me', 'TURN YE TO ME', 2, 32, 9999, 1, 114, 2, 313, NULL, '', 81, '8888/8448/8448/8448', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6787, '1997-09-17 22:00:00+00', '2022-06-17 20:04:04.548+00', 'Twa Corbies, The', 'TWA CORBIES', 2, 32, 9999, 1, 2, 76, 44, '1991-05-03', '', 43, '80/08/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12318, '2005-04-27 22:00:00+00', '2022-09-06 19:14:10.929546+00', 'Miss Jane Bremner of Keith', 'MISS JANE BREMNER OF KEITH', 1, 32, 9999, 1, 3, 42, 3538, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12326, '2005-04-27 22:00:00+00', '2022-09-19 12:20:45.873337+00', 'Moodies of Douro, The', 'MOODIES OF DOURO', 3, 32, 9999, 1, 4, 1, 3538, '1993-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6831, '2003-01-26 23:00:00+00', '2018-04-03 00:08:23.325876+00', 'Ulysses S. Grant', 'ULYSSES S GRANT', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6840, '1997-04-03 22:00:00+00', '2018-04-03 00:08:23.365775+00', 'University Reel', 'UNIVERSITY REEL', 1, 32, 9999, 1, 3, 42, 197, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6842, '1997-04-03 22:00:00+00', '2018-04-03 00:08:23.399062+00', 'Until He Saw The Dance', 'UNTIL HE SAW THE DANCE', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6852, '2000-01-10 23:00:00+00', '2018-04-03 00:08:23.440635+00', 'Upham Park', 'UPHAM PARK', 3, 32, 9999, 1, 3, 42, 430, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6850, '1997-09-16 22:00:00+00', '2018-04-03 00:08:23.482323+00', 'Up With Aily', 'UP WITH AILY', 1, 32, 9999, 1, 3, 42, 446, '1703-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6855, '2002-04-19 22:00:00+00', '2018-04-03 00:08:23.490648+00', 'Urquhart Bay', 'URQUHART BAY', 3, 32, 9999, 1, 3, 42, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6863, '1997-09-16 22:00:00+00', '2018-04-03 00:08:23.507304+00', 'Valentine Wedding Knot, A', 'VALENTINE WEDDING KNOT', 2, 32, 9999, 1, 3, 42, 900, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6866, '1997-04-03 22:00:00+00', '2018-04-03 00:08:23.524016+00', 'Valerie Craig''s Reel', 'VALERIE CRAIGS REEL', 1, 32, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6867, '1998-04-24 22:00:00+00', '2018-04-03 00:08:23.532609+00', 'Valerie Rixon''s Jig', 'VALERIE RIXONS JIG', 2, 32, 9999, 1, 3, 42, 168, '1989-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6869, '1997-04-03 22:00:00+00', '2018-04-03 00:08:23.540752+00', 'Valiant Heart, The', 'VALIANT HEART', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6871, '1997-09-16 22:00:00+00', '2018-04-03 00:08:23.557389+00', 'Valley Wedding, The', 'VALLEY WEDDING', 3, 32, 9999, 1, 3, 42, 400, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12337, '2005-04-27 22:00:00+00', '2018-04-03 00:08:24.941694+00', 'Westview Regulars', 'WESTVIEW REGULARS', 2, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6872, '1997-09-16 22:00:00+00', '2012-01-20 12:56:54.149478+00', 'Vancouver Celebration', 'VANCOUVER CELEBRATION', 3, 32, 9999, 4, 4, NULL, 562, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6874, '1997-04-03 22:00:00+00', '2012-01-20 12:56:54.166347+00', 'Vera Hughes'' Fancy', 'VERA HUGHES FANCY', 1, 32, 9999, 5, 1, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6875, '1997-09-16 22:00:00+00', '2012-01-20 12:56:54.175407+00', 'Vera''s Strathspey', 'VERAS STRATHSPEY', 3, 32, 9999, 2, 3, NULL, 606, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12342, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.449896+00', 'Stealing a Kiss', 'STEALING A KISS', 2, 32, 9999, 1, 4, NULL, 1, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12350, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.504227+00', 'Reverend Thomas Burns, The', 'REVEREND THOMAS BURNS', 3, 32, 9999, 1, 4, NULL, 3582, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12351, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.510985+00', 'Settlers'' Dance, The', 'SETTLERS DANCE', 1, 48, 9999, 2, 3, NULL, 3274, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18709, '2018-10-03 01:03:14.773726+00', '2018-10-03 01:03:14.773726+00', 'Chickadees at the Feeder', 'CHICKADEES AT THE FEEDER', 1, 32, NULL, 1, 3, 42, 2766, '2016-07-01', 'We have a thistle feeder in the backyard and chickadees come in, land, eat and leave to be replaced by other chickadees.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18730, '2018-10-04 07:54:03.542568+00', '2018-10-04 07:54:03.542568+00', 'Deer in the Headlights', 'DEER IN THE HEADLIGHTS', 1, 32, NULL, 1, 3, 42, 2766, '2009-11-01', 'This dance was inspired by Derek Haynes’ dance The Startled Rabbits about dancers to whom the next 8 bars is always a surprise.

  	', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6830, '1998-01-12 23:00:00+00', '2020-01-17 18:56:58.886704+00', 'Tyrebagger, The', 'TYREBAGGER', 1, 32, 9999, 1, 3, 42, 108, '1986-01-01', '', 50, '880/844/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6864, '1997-09-16 22:00:00+00', '2020-05-31 20:41:38.427656+00', 'Valentine''s Strathspey', 'VALENTINES STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 1334, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6847, '1998-07-08 22:00:00+00', '2021-04-04 19:25:58.954386+00', 'Up Helly'' Aa', 'UP HELLY AA', 1, 48, 9999, 1, 4, 2, 567, NULL, 'Up Helly Aa is the Viking fire festival held each January in the Shetland Islands.

', 71, '8008/8888/5555/5555/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6826, '1998-12-08 23:00:00+00', '2020-08-04 08:36:19.07964+00', '2d Jig', '2D JIG', 2, 64, 9999, 1, 3, 42, 82, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6838, '1997-04-03 22:00:00+00', '2020-08-07 10:02:03.898957+00', 'Underneath The Arches', 'UNDERNEATH THE ARCHES', 2, 32, 9999, 1, 4, 1, 151, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12354, '2005-04-27 22:00:00+00', '2021-04-02 21:53:32.866895+00', 'Road to Blantyre, The', 'ROAD TO BLANTYRE', 1, 32, 9999, 1, 4, 1, 2525, NULL, '', 72, '8080/8484/8484/8488', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6890, '2002-06-19 22:00:00+00', '2021-04-04 11:38:19.068745+00', 'Visit to Balfron, A', 'VISIT TO BALFRON', 3, 32, 9999, 1, 3, 42, 259, NULL, '', 72, '888/888/884/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6833, '1998-04-24 22:00:00+00', '2021-04-04 19:37:50.616736+00', 'Under a Shady Tree', 'UNDER A SHADY TREE', 1, 32, 9999, 1, 3, 42, 788, '1989-01-01', '', 48, '800/886/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6877, '1997-09-16 22:00:00+00', '2012-01-20 12:56:54.194342+00', 'Victoria Reel', 'VICTORIA REEL', 1, 40, 9999, 2, 3, NULL, 1335, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6878, '1997-09-16 22:00:00+00', '2012-01-20 12:56:54.203899+00', 'Victorian Scots Bicentennial Reel', 'VICTORIAN SCOTS BICENTENNIAL REEL', 2, 80, 9999, 4, 4, NULL, 1166, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6881, '1997-04-03 22:00:00+00', '2012-01-20 12:56:54.239954+00', 'Victory Hornpipe', 'VICTORY HORNPIPE', 2, 64, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6882, '1997-09-16 22:00:00+00', '2012-01-20 12:56:54.249047+00', 'Victory Hornpipe, The', 'VICTORY HORNPIPE', 1, 48, 9999, 2, 3, NULL, 385, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6883, '1997-04-03 22:00:00+00', '2012-01-20 12:56:54.258603+00', 'Viking Longship, The', 'VIKING LONGSHIP', 1, 32, 9999, 1, 4, NULL, 264, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12345, '2005-04-27 22:00:00+00', '2019-02-09 16:14:27.828079+00', 'Primrose Strathspey, The', 'PRIMROSE STRATHSPEY', 3, 32, 9999, 4, 4, 1, 3581, NULL, '', 88, '6666/6666/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6886, '1997-04-03 22:00:00+00', '2012-01-20 12:56:54.285484+00', 'Village Square, The', 'VILLAGE SQUARE', 3, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6888, '1998-01-04 23:00:00+00', '2012-01-20 12:56:54.302989+00', 'Vineyard, The', 'VINEYARD', 1, 40, 9999, 1, 4, NULL, 1166, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6887, '1998-01-04 23:00:00+00', '2019-03-09 13:09:21.707611+00', 'Vin Tyndall Of Forfar', 'VIN TYNDALL OF FORFAR', 1, 32, 9999, 1, 4, 1, 231, NULL, '', 88, '8484/8888/8484/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6891, '2002-06-19 22:00:00+00', '2012-01-20 12:56:54.355444+00', 'Visit to Denork, A', 'VISIT TO DENORK', 2, 24, 9999, 1, 2, NULL, 199, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6892, '2002-06-19 22:00:00+00', '2012-01-20 12:56:54.364205+00', 'Visit to Saint Andrew''s', 'VISIT TO SAINT ANDREWS', 3, 32, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6896, '1998-10-20 22:00:00+00', '2012-01-20 12:56:54.400338+00', 'Waefu'' Heart, The', 'WAEFU HEART', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6898, '1997-04-03 22:00:00+00', '2012-01-20 12:56:54.417942+00', 'Waggle O''The Feiladh-Beg, The', 'WAGGLE OTHE FEILADHBEG', 2, 40, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12359, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.565339+00', 'One Finger, One Thumb', 'ONE FINGER ONE THUMB', 1, 48, 9999, 6, 3, NULL, 3574, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12361, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.578865+00', 'Strawberry Fool', 'STRAWBERRY FOOL', 3, 40, 9999, 1, 4, NULL, 3540, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12363, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.592397+00', 'Wrought Iron Gate, The', 'WROUGHT IRON GATE', 1, 40, 9999, 1, 4, NULL, 3574, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14608, '2012-12-17 23:16:14.325192+00', '2012-12-17 23:16:45.442882+00', 'Ardvreck Castle', 'ARDVRECK CASTLE', 3, 48, NULL, 6, 3, NULL, 10668, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14621, '2012-12-18 09:40:50.026555+00', '2012-12-18 09:50:40.064985+00', 'Square Cut Diamond', 'SQUARE CUT DIAMOND', 4, 128, 2, 4, 4, 3, 2627, '2011-12-06', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12365, '2005-04-27 22:00:00+00', '2016-12-04 00:21:47.576369+00', 'Old Friends', 'OLD FRIENDS', 3, 32, 9999, 1, 3, 42, 2677, NULL, '', 44, '800/880/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12346, '2005-04-27 22:00:00+00', '2018-03-21 14:23:07.924516+00', 'Ring of the Hearts, The', 'RING OF THE HEARTS', 3, 32, 9999, 2, 3, 17, 3561, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12349, '2005-04-27 22:00:00+00', '2018-03-22 14:35:06.865895+00', 'Temari, The', 'TEMARI', 1, 64, 9999, 4, 4, 3, 2780, '1999-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12353, '2005-04-27 22:00:00+00', '2018-04-03 00:08:09.422341+00', 'Our Good Friend Tom', 'OUR GOOD FRIEND TOM', 2, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6843, '1997-09-16 22:00:00+00', '2022-12-11 13:22:33.991646+00', 'Until We Meet Again', 'UNTIL WE MEET AGAIN', 3, 40, 9999, 1, 4, 22, 318, NULL, '', 75, '8888/0880/0880/4884/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6900, '2002-05-14 22:00:00+00', '2018-04-03 00:08:11.791072+00', 'Quite Contrary', 'QUITE CONTRARY', 2, 32, 9999, 1, 3, 42, 1215, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12355, '2005-04-27 22:00:00+00', '2018-04-03 00:08:16.786172+00', 'Silver Memories', 'SILVER MEMORIES', 1, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12360, '2005-04-27 22:00:00+00', '2018-04-03 00:08:18.821053+00', 'Strawberries and Cream', 'STRAWBERRIES AND CREAM', 1, 32, 9999, 1, 3, 42, 3540, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12362, '2005-04-27 22:00:00+00', '2018-04-03 00:08:19.821884+00', 'Tally Ho Corner', 'TALLY HO CORNER', 2, 32, 9999, 1, 3, 42, 3543, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12356, '2005-04-27 22:00:00+00', '2018-04-03 00:08:20.105329+00', 'Tayside Ladies', 'TAYSIDE LADIES', 1, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6884, '1997-04-03 22:00:00+00', '2018-04-03 00:08:23.707509+00', 'Village Dance, A', 'VILLAGE DANCE', 1, 32, 9999, 1, 3, 42, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6895, '1997-09-16 22:00:00+00', '2018-04-03 00:08:23.916922+00', 'Volpony', 'VOLPONY', 50, 32, 9999, 1, 3, 42, 397, '1712-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6889, '1997-04-03 22:00:00+00', '2013-01-03 08:39:45.435453+00', 'Virginia Reel', 'VIRGINIA REEL', 1, 128, 9999, 4, 4, NULL, 181, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6907, '2001-07-30 22:00:00+00', '2012-01-20 12:56:54.515412+00', 'Wallace Hall', 'WALLACE HALL', 4, 80, 9999, 1, 4, NULL, 1556, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6908, '2002-04-19 22:00:00+00', '2012-01-20 12:56:54.524318+00', 'Wallace Strathspey, The', 'WALLACE STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 153, '1981-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11499, '2003-09-22 22:00:00+00', '2018-10-03 01:11:44.611749+00', 'Child of Wonder', 'CHILD OF WONDER', 1, 32, 9999, 1, 3, 42, 2766, '2002-12-01', 'This dance was written to celebrate Ian Michael Fitak’s first Christmas.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6914, '1997-04-03 22:00:00+00', '2012-01-20 12:56:54.58589+00', 'Wallington Jig', 'WALLINGTON JIG', 2, 32, 9999, 1, 2, NULL, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6920, '1997-04-03 22:00:00+00', '2012-01-20 12:56:54.647169+00', 'Wardie Welcome to Pony Pipers', 'WARDIE WELCOME TO PONY PIPERS', 2, 48, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6921, '1997-09-16 22:00:00+00', '2012-01-20 12:56:54.658301+00', 'Wardlaw Hall', 'WARDLAW HALL', 3, 40, 9999, 1, 4, NULL, 318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6923, '1997-09-16 22:00:00+00', '2012-01-20 12:56:54.676915+00', 'Warm Winter''s Evening, A', 'WARM WINTERS EVENING', 3, 32, 9999, 1, 4, NULL, 704, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6924, '1997-04-03 22:00:00+00', '2012-01-20 12:56:54.686038+00', 'Warriors of the Rainbow', 'WARRIORS OF THE RAINBOW', 1, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6926, '1997-09-16 22:00:00+00', '2012-01-20 12:56:54.70024+00', 'Warwickshire Medley', 'WARWICKSHIRE MEDLEY', 4, 128, 9999, 1, 4, NULL, 1317, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6929, '1998-01-05 23:00:00+00', '2012-01-20 12:56:54.721425+00', 'Washington Crossing', 'WASHINGTON CROSSING', 1, 48, 9999, 1, 4, NULL, 1338, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6947, '1997-09-06 22:00:00+00', '2020-08-07 10:14:23.921148+00', 'Waterfall, The', 'WATERFALL', 2, 64, 9999, 1, 4, 1, 129, '1967-01-01', '', 62, '8000/8800/8880/0088/4008/8848/4686/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6901, '1997-09-16 22:00:00+00', '2020-08-07 10:13:30.795585+00', 'Waiting for the Bairns', 'WAITING FOR THE BAIRNS', 1, 64, 9999, 4, 98, NULL, 105, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12357, '2005-04-27 22:00:00+00', '2021-01-22 19:42:52.741043+00', 'Uddingston Fair', 'UDDINGSTON FAIR', 2, 32, 9999, 1, 4, 1, 2525, NULL, '', 78, '8448/8088/8448/8488', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12352, '2005-04-27 22:00:00+00', '2021-03-01 12:09:13.502741+00', 'Oo''r Aileen''s Reel', 'OOR AILEENS REEL', 1, 32, 9999, 1, 3, 42, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12358, '2005-04-27 22:00:00+00', '2021-01-24 19:48:20.674992+00', 'Come Join the Dance', 'COME JOIN THE DANCE', 1, 32, 9999, 2, 3, 17, 2525, '2003-01-11', '', 83, '888/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6876, '1997-09-16 22:00:00+00', '2021-04-04 11:46:58.097659+00', 'Vi MacPhail', 'VI MACPHAIL', 1, 32, 9999, 1, 4, 1, 21, NULL, '', 81, '8448/8888/8448/8088', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6899, '1998-11-02 23:00:00+00', '2021-04-05 21:55:25.861467+00', 'Wagon''s West', 'WAGONS WEST', 2, 96, 9999, 1, 4, 28, 630, '1979-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6909, '1997-08-21 22:00:00+00', '2019-05-26 12:48:06.332349+00', 'Wallace Tower, The', 'WALLACE TOWER', 3, 128, 9999, 4, 4, 3, 108, '1991-01-01', '', 89, '8888/8888/8888/8888/8888/8080/8282/8888/8888/0808/2828/8888/8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6916, '1998-04-21 22:00:00+00', '2019-10-28 12:48:50.28896+00', 'Wandering Drummer, The', 'WANDERING DRUMMER', 1, 32, 9999, 2, 3, 17, 44, NULL, '', 58, '888/800/800/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12374, '2005-04-27 22:00:00+00', '2012-01-20 12:57:37.669859+00', 'Primrose Path, The', 'PRIMROSE PATH', 4, 32, 1, 1, 4, NULL, 57, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12378, '2005-04-28 22:00:00+00', '2012-01-20 12:57:37.698481+00', 'Richard''s Rose Field', 'RICHARDS ROSE FIELD', 1, 32, 9999, 1, 4, NULL, 57, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12379, '2005-04-28 22:00:00+00', '2012-01-20 12:57:37.70524+00', 'Richmond Reel', 'RICHMOND REEL', 2, 32, 9999, 2, 3, NULL, 3587, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12380, '2005-04-28 22:00:00+00', '2012-01-20 12:57:37.712551+00', 'River Kaduna, The', 'RIVER KADUNA', 1, 48, 9999, 1, 4, NULL, 3588, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12370, '2005-04-27 22:00:00+00', '2018-04-03 00:08:09.780966+00', 'Pam''s Dance', 'PAMS DANCE', 3, 32, 9999, 1, 3, 42, 3584, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12383, '2005-04-28 22:00:00+00', '2012-01-20 12:57:37.734729+00', 'Ruby Reflections', 'RUBY REFLECTIONS', 3, 32, 9999, 2, 3, NULL, 42, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14609, '2012-12-17 23:20:15.13686+00', '2012-12-17 23:20:15.136871+00', 'Carriage to Schiehallion', 'CARRIAGE TO SCHIEHALLION', 2, 48, NULL, 4, 4, NULL, 10669, '2012-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6934, '2003-01-28 23:00:00+00', '2012-01-20 12:56:54.755975+00', 'Watch Dog''s Folly, The', 'WATCH DOGS FOLLY', 1, 32, 9999, 1, 2, NULL, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6935, '1997-04-03 22:00:00+00', '2012-01-20 12:56:54.763669+00', 'Watch from the Hayloft', 'WATCH FROM THE HAYLOFT', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6937, '1998-01-04 23:00:00+00', '2012-01-20 12:56:54.777813+00', 'Ahint the Kirk', 'AHINT THE KIRK', 3, 32, 9999, 1, 4, NULL, 610, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6938, '1998-01-04 23:00:00+00', '2012-01-20 12:56:54.7846+00', 'Water Kelpie, The', 'WATER KELPIE', 1, 32, 9999, 1, 2, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12371, '2005-04-27 22:00:00+00', '2018-04-03 00:08:09.897664+00', 'Partington''s Mill', 'PARTINGTONS MILL', 1, 32, 9999, 1, 3, 42, 3354, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6944, '1998-07-08 22:00:00+00', '2012-01-20 12:56:54.82717+00', 'Wateraid Strathspey', 'WATERAID STRATHSPEY', 3, 32, 9999, 1, 4, 2, 1342, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6945, '1997-09-16 22:00:00+00', '2012-01-20 12:56:54.834037+00', 'Waterdown Reel, The', 'WATERDOWN REEL', 1, 32, 9999, 1, 4, NULL, 761, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6943, '1997-09-16 22:00:00+00', '2017-07-16 01:00:44.403905+00', 'Wateraid Reel', 'WATERAID REEL', 1, 32, 9999, 1, 4, NULL, 1341, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12373, '2005-04-27 22:00:00+00', '2018-04-03 00:08:10.656852+00', 'Pine Woods, The', 'PINE WOODS', 1, 32, 9999, 1, 3, 42, 3491, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12376, '2005-04-28 22:00:00+00', '2018-04-03 00:08:12.083072+00', 'Rannoch Reel', 'RANNOCH REEL', 1, 32, 9999, 1, 3, 42, 3328, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6905, '1997-04-03 22:00:00+00', '2018-04-03 00:08:24.074485+00', 'Walking History Book, A', 'WALKING HISTORY BOOK', 3, 40, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6906, '1997-10-27 23:00:00+00', '2018-04-03 00:08:24.082739+00', 'Walking The Floor', 'WALKING THE FLOOR', 2, 32, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6911, '1997-04-03 22:00:00+00', '2018-04-03 00:08:24.091064+00', 'Wallace''s Welcome, The', 'WALLACES WELCOME', 1, 32, 9999, 1, 3, 42, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6917, '1997-09-28 22:00:00+00', '2018-04-03 00:08:24.116123+00', 'Wandering Scots', 'WANDERING SCOTS', 1, 32, 9999, 1, 3, 42, 1337, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6925, '2003-01-28 23:00:00+00', '2018-04-03 00:08:24.141173+00', 'Warwickshire Lassie', 'WARWICKSHIRE LASSIE', 3, 32, 9999, 1, 3, 42, 35, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6903, '1997-09-16 22:00:00+00', '2022-07-04 22:33:47.185468+00', 'Wakefield Hunt', 'WAKEFIELD HUNT', 2, 48, 9999, 1, 3, 42, 466, '1779-01-01', '', 38, '401/401/888/800/880/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12377, '2005-04-28 22:00:00+00', '2022-09-19 12:13:11.603085+00', 'Retiring, The', 'RETIRING', 2, 32, 9999, 1, 4, 1, 3538, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12372, '2005-04-27 22:00:00+00', '2022-09-19 12:16:09.288592+00', 'Peterborough Reel, The', 'PETERBOROUGH REEL', 1, 32, 9999, 1, 3, 42, 3538, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6946, '1997-09-16 22:00:00+00', '2022-11-01 17:25:19.462055+00', 'Waterfall Gill', 'WATERFALL GILL', 2, 32, 9999, 1, 4, 1, 549, NULL, '', 69, '8008/8888/0880/8088', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6940, '2002-04-19 22:00:00+00', '2018-04-03 00:08:24.182798+00', 'Water Mirages', 'WATER MIRAGES', 3, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6950, '1997-04-03 22:00:00+00', '2018-04-03 00:08:24.191187+00', 'Waterside', 'WATERSIDE', 2, 32, 9999, 1, 3, 42, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6951, '1997-09-04 22:00:00+00', '2012-01-20 12:56:54.8774+00', 'Houghton''s Farewell to New York City, The', 'HOUGHTONS FAREWELL TO NEW YORK CITY', 4, 32, 9999, 1, 4, NULL, 1004, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18731, '2018-10-04 08:11:47.185164+00', '2018-10-04 08:11:47.185164+00', 'Diamondback', 'DIAMONDBACK', 2, 32, NULL, 1, 3, NULL, 2766, '2014-03-01', 'The figures in this dance remind me of the pattern of a diamondback snake.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6960, '1997-09-17 22:00:00+00', '2012-01-20 12:56:54.945096+00', 'Way Down Under', 'WAY DOWN UNDER', 2, 64, 9999, 4, 98, NULL, 1009, NULL, '8 men, 4 ladies', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6963, '1997-09-17 22:00:00+00', '2018-09-16 01:50:55.708484+00', 'We Canna Gang Tae Brenda''s Wedding', 'WE CANNA GANG TAE BRENDAS WEDDING', 2, 32, 9999, 1, 3, 42, 636, NULL, '', 50, '800/888/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12384, '2005-04-28 22:00:00+00', '2012-01-20 12:57:37.742088+00', 'Samphire Strathspey, The', 'SAMPHIRE STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 385, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12403, '2005-04-28 22:00:00+00', '2018-04-03 00:07:50.424874+00', 'Half a Telegram', 'HALF A TELEGRAM', 1, 32, 9999, 1, 3, 42, 2627, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12389, '2005-04-28 22:00:00+00', '2012-01-20 12:57:37.778318+00', 'Sir Gordon Manzie Strathspey', 'SIR GORDON MANZIE STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 3444, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12391, '2005-04-28 22:00:00+00', '2018-10-08 21:43:46.684524+00', 'Spiral Galaxies', 'SPIRAL GALAXIES', 1, 32, 9999, 1, 3, 42, 2766, '2004-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12393, '2005-04-28 22:00:00+00', '2012-01-20 12:57:37.810197+00', 'Saint Andrew''s Cross', 'SAINT ANDREWS CROSS', 1, 64, 9999, 1, 4, NULL, 3575, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12405, '2005-04-28 22:00:00+00', '2018-04-03 00:07:56.735871+00', 'June Rose, A', 'JUNE ROSE', 3, 32, 9999, 1, 3, 42, 3591, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6966, '1997-12-03 23:00:00+00', '2019-08-28 18:24:48.527219+00', 'Freshwater Bay', 'FRESHWATER BAY', 2, 32, 9999, 2, 3, 17, 11113, NULL, 'Author corrected; source: <<http://www.scottish-country-dancing-dictionary.com/dance-crib/freshwater-bay.html>>', 63, '800/844/844/848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14622, '2012-12-18 13:06:13.404704+00', '2012-12-18 13:06:13.404715+00', 'Hamilton Bay', 'HAMILTON BAY', 3, 32, NULL, 1, 100, 2, 1089, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7010, '1997-04-03 22:00:00+00', '2012-01-20 12:56:55.383993+00', 'Wee Totee Thing, A', 'WEE TOTEE THING', 3, 16, 9999, 4, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6967, '1997-09-17 22:00:00+00', '2020-08-07 10:34:55.679632+00', 'We''re A Noddin', 'WERE A NODDIN', 3, 96, 9999, 107, 101, NULL, 82, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6933, '1997-09-16 22:00:00+00', '2020-09-04 10:38:20.236342+00', 'Wasps of Mulben, The', 'WASPS OF MULBEN', 3, 32, 9999, 1, 100, 11, 108, '1988-01-01', '', 94, '4884/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12401, '2005-04-28 22:00:00+00', '2021-01-15 00:42:59.276019+00', 'Frolic in the Poppy Field, A', 'FROLIC IN THE POPPY FIELD', 1, 40, 9999, 1, 3, 42, 3597, '1998-01-01', '', 55, '844/844/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6952, '1998-09-29 22:00:00+00', '2021-04-03 18:25:32.098792+00', 'Watson''s Reel', 'WATSONS REEL', 2, 24, 9999, 1, 2, 76, 9998, NULL, '', 57, '88/80/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6941, '1997-08-25 22:00:00+00', '2021-04-03 18:36:22.728322+00', 'Water''s Edge', 'WATERS EDGE', 3, 32, 9999, 1, 3, 42, 108, '1976-01-01', 'John Drewry wrote in the original description that the dance was for May Yarker, who lives at "Water''s Edge".', 63, '808/880/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6932, '1997-04-03 22:00:00+00', '2021-04-03 19:09:16.145835+00', 'Wasn''t It a Party!', 'WASNT IT A PARTY', 2, 32, 9999, 1, 4, 2, 35, '1990-01-01', '', 63, '8008/8888/8008/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14487, '2012-07-01 00:59:12.917724+00', '2012-12-31 18:49:14.246405+00', 'Celtic Square', 'CELTIC SQUARE', 2, 32, NULL, 4, 4, 1, 411, '2003-01-01', 'Suggested recorded music "The British Immigrant" by Ed Brydie in the album  "Memory Lane"', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6968, '1998-07-08 22:00:00+00', '2012-01-20 12:56:55.001129+00', 'We''re Nae That Fou', 'WERE NAE THAT FOU', 3, 32, 9999, 1, 4, 2, 108, '1985-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6969, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.008454+00', 'We''re Ten Ye Ken', 'WERE TEN YE KEN', 2, 48, 9999, 1, 4, NULL, 1356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6970, '1997-04-03 22:00:00+00', '2012-01-20 12:56:55.01554+00', 'Wean, The', 'WEAN', 3, 16, 9999, 4, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6973, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.037134+00', 'Weaver''s Daughter-in-law, The', 'WEAVERS DAUGHTERINLAW', 4, 128, 9999, 1, 4, NULL, 488, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6974, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.043922+00', 'Weaver''s Dream, The', 'WEAVERS DREAM', 3, 32, 9999, 1, 4, NULL, 896, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6975, '1997-04-03 22:00:00+00', '2012-01-20 12:56:55.050956+00', 'Weaver''s Knot', 'WEAVERS KNOT', 2, 32, 9999, 1, 4, NULL, 67, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6979, '1997-04-03 22:00:00+00', '2012-01-20 12:56:55.078555+00', 'Weaving The Kilt', 'WEAVING THE KILT', 3, 40, 9999, 1, 4, NULL, 300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6980, '1998-11-25 23:00:00+00', '2012-01-20 12:56:55.085336+00', 'Websters'' Eightsome, The', 'WEBSTERS EIGHTSOME', 2, 128, 9999, 4, 4, NULL, 57, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6983, '1998-04-24 22:00:00+00', '2012-01-20 12:56:55.106193+00', 'Wedding Bouquet, The', 'WEDDING BOUQUET', 4, 104, 27, 4, 4, NULL, 348, '1987-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6984, '1998-03-19 23:00:00+00', '2012-01-20 12:56:55.113092+00', 'Wedding Day', 'WEDDING DAY', 3, 32, 9999, 2, 3, NULL, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6986, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.127923+00', 'Wedding Knot, The', 'WEDDING KNOT', 4, 160, 9999, 1, 4, NULL, 1351, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6987, '1997-04-03 22:00:00+00', '2012-01-20 12:56:55.135044+00', 'Wedding Medley', 'WEDDING MEDLEY', 4, 64, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6988, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.141934+00', 'Wedding Night, The', 'WEDDING NIGHT', 2, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6989, '1997-04-03 22:00:00+00', '2012-01-20 12:56:55.149329+00', 'Wedding Of Bonnie Jean', 'WEDDING OF BONNIE JEAN', 3, 72, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12398, '2005-04-28 22:00:00+00', '2012-01-20 12:57:37.851277+00', 'Suzanne''s Wedding', 'SUZANNES WEDDING', 1, 32, 9999, NULL, 5, NULL, 3595, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12400, '2005-04-28 22:00:00+00', '2012-01-20 12:57:37.872932+00', 'Flowers of June', 'FLOWERS OF JUNE', 2, 32, 9999, 2, 3, 17, 697, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12407, '2005-05-01 22:00:00+00', '2012-01-20 12:57:37.933896+00', 'To Catch a Haggis', 'TO CATCH A HAGGIS', 3, 32, 9999, NULL, NULL, NULL, 3599, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12408, '2005-05-01 22:00:00+00', '2012-01-20 12:57:37.942735+00', 'Total Eclipse', 'TOTAL ECLIPSE', 3, 80, 9999, 4, 4, NULL, 1374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14633, '2012-12-30 22:56:49.883777+00', '2016-05-13 15:52:18.448525+00', 'Frohnau Centenary Reel, The', 'FROHNAU CENTENARY REEL', 1, 88, NULL, 107, 4, 3, 9998, NULL, 'source: see the video by "Hopalots".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6955, '1997-09-16 22:00:00+00', '2016-07-27 21:37:09.404678+00', 'Waukrife Laddie', 'WAUKRIFE LADDIE', 2, 32, 9999, 2, 3, NULL, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6958, '1997-04-03 22:00:00+00', '2018-04-03 00:08:24.216178+00', 'Waverley Steps', 'WAVERLEY STEPS', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6976, '1997-04-03 22:00:00+00', '2018-04-03 00:08:24.324756+00', 'Weaver''s Retirement, The', 'WEAVERS RETIREMENT', 4, 32, 9999, 1, 3, 42, 67, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6893, '2002-06-19 22:00:00+00', '2018-07-13 14:16:58.014211+00', 'Visits to Glamis Castle', 'VISITS TO GLAMIS CASTLE', 1, 40, 9999, 1, 3, 42, 347, NULL, 'My paternal grandmother made a number of visits to Glamis Castle, as she did other castles in Scotland, with families for whom she worked as a children''s nurse.', 55, '844/800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12395, '2005-04-28 22:00:00+00', '2022-09-19 11:52:41.214858+00', 'Stoney Lake Stone, The', 'STONEY LAKE STONE', 1, 32, 9999, 1, 3, 42, 3554, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12387, '2005-04-28 22:00:00+00', '2022-09-19 12:07:19.742556+00', 'Scott''s Plains Reel, The', 'SCOTTS PLAINS REEL', 3, 72, 9999, 104, 2, 3, 3538, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6982, '1997-09-17 22:00:00+00', '2022-10-23 21:19:10.751416+00', 'Wedding At Roche Harbor', 'WEDDING AT ROCHE HARBOR', 3, 32, 9999, 1, 3, 42, 348, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6962, '1998-12-01 23:00:00+00', '2022-11-01 17:18:30.178821+00', 'Waylen Bay Jig, The', 'WAYLEN BAY JIG', 2, 32, 9999, 1, 3, 42, 83, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12420, '2005-05-01 22:00:00+00', '2022-12-02 21:17:48.502028+00', 'Wellmeadow, The', 'WELLMEADOW', 3, 32, 9999, 6, 3, 17, 3599, '2000-01-01', 'From the notes: "The Wellmeadow'' is a three sided open space in the centre of the town of Blairgowrie.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12413, '2005-05-01 22:00:00+00', '2018-10-09 12:39:13.027254+00', 'Triquetra, The', 'TRIQUETRA', 3, 32, 9999, 6, 3, NULL, 2766, '2004-10-01', 'This dance and The Triskel were inspired by a catalog of *Irish gifts* I received that had pictures of jewelry in the shapes of the triskel and the trinity celtic knot, aka the triquetra.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6992, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.171016+00', 'Wee Barra', 'WEE BARRA', 1, 48, 9999, 4, 4, NULL, 1204, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6993, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.177958+00', 'Wee Beastie, The', 'WEE BEASTIE', 1, 32, 9999, 4, 4, NULL, 1302, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6994, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.186227+00', 'Wee Bit o'' Scotland', 'WEE BIT O SCOTLAND', 3, 32, 9999, 1, 4, NULL, 1346, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14624, '2012-12-18 13:12:21.631274+00', '2012-12-18 13:12:21.631284+00', 'Pretty Woman', 'PRETTY WOMAN', 2, 32, NULL, 1, 100, 2, 1089, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12399, '2005-04-28 22:00:00+00', '2019-03-03 21:12:49.137111+00', 'Thady, You Gander', 'THADY YOU GANDER', 1, 40, 9999, 1, 4, 1, 3596, NULL, '', 39, '8000/4444/4444/8220/8002', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6977, '1997-04-03 22:00:00+00', '2018-04-02 23:56:38.440696+00', 'Weaver''s Wife, The', 'WEAVERS WIFE', 2, 40, 9999, 1, 3, 42, 108, '1975-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6978, '1998-11-16 23:00:00+00', '2013-10-21 07:39:56.663262+00', 'Weaver, The', 'WEAVER', 2, 32, 9999, 1, 3, 42, 87, '1973-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6998, '1998-04-24 22:00:00+00', '2012-01-20 12:56:55.216159+00', 'Wee Gordon Waltz, The', 'WEE GORDON WALTZ', 5, 16, 9999, 4, 4, NULL, 1347, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7001, '1997-04-03 22:00:00+00', '2012-01-20 12:56:55.236854+00', 'Wee MacIver', 'WEE MACIVER', 1, 40, 9999, 1, 4, NULL, 264, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7004, '1997-04-03 22:00:00+00', '2012-01-20 12:56:55.257292+00', 'Wee Rikki Medley', 'WEE RIKKI MEDLEY', 4, 60, 9999, 1, 4, NULL, 192, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7005, '1997-04-03 22:00:00+00', '2012-01-20 12:56:55.264071+00', 'Wee Sammy', 'WEE SAMMY', 3, 40, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7007, '1997-04-03 22:00:00+00', '2012-01-20 12:56:55.361519+00', 'Wee Stumpie-Stouzie', 'WEE STUMPIESTOUZIE', 3, 16, 9999, 4, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7008, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.368856+00', 'Wee Swelchie', 'WEE SWELCHIE', 3, 32, 9999, 1, 4, NULL, 389, '1985-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6990, '1998-01-05 23:00:00+00', '2020-03-14 07:44:07.139248+00', 'Wedding Reel, The', 'WEDDING REEL', 1, 32, 9999, 1, 3, 42, 101, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6953, '1997-04-03 22:00:00+00', '2020-04-28 23:29:45.301322+00', 'Wattle O''t, The', 'WATTLE OT', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7009, '1998-11-24 23:00:00+00', '2020-12-31 18:01:41.552324+00', 'Wee Torry', 'WEE TORRY', 2, 32, 9999, 3, 5, 7, 13, NULL, '', 78, '80800/88888/88888/84844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6965, '1997-09-17 22:00:00+00', '2021-01-12 16:34:37.010833+00', 'We''ll Dance, and Sing, and Rejoice, Man', 'WELL DANCE AND SING AND REJOICE MAN', 2, 40, 9999, 1, 2, 76, 108, '1968-01-01', '', 65, '88/84/88/88/88', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12402, '2005-04-28 22:00:00+00', '2021-01-15 00:39:49.159841+00', 'Jigsaw', 'JIGSAW', 3, 40, 9999, 2, 3, 17, 3590, '1998-01-01', '', 80, '888/844/866/866/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7011, '1998-01-12 23:00:00+00', '2012-01-20 12:56:55.391312+00', 'Weel Danced, Lucky Hare', 'WEEL DANCED LUCKY HARE', 2, 32, 9999, 1, 4, NULL, 210, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7014, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.418825+00', 'Welcome Back Norah', 'WELCOME BACK NORAH', 3, 32, 9999, 1, 4, NULL, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14623, '2012-12-18 13:08:19.919249+00', '2018-04-03 00:08:19.746774+00', 'Take My Hand', 'TAKE MY HAND', 2, 32, NULL, 1, 3, 42, 1089, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7021, '2001-06-04 22:00:00+00', '2012-01-20 12:56:55.478673+00', 'Welcome to Hayes', 'WELCOME TO HAYES', 2, 32, 9999, 1, 2, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7022, '2001-06-04 22:00:00+00', '2012-01-20 12:56:55.494582+00', 'Welcome to Kirkconnel', 'WELCOME TO KIRKCONNEL', 1, 32, 9999, 5, 2, NULL, 1353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7023, '2001-06-04 22:00:00+00', '2012-01-20 12:56:55.503412+00', 'Welcome to Lisa', 'WELCOME TO LISA', 1, 32, 9999, 1, 2, NULL, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7024, '2001-06-04 22:00:00+00', '2012-01-20 12:56:55.512162+00', 'Welcome to Luss', 'WELCOME TO LUSS', 3, 40, 9999, 1, 98, NULL, 328, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7026, '2001-06-04 22:00:00+00', '2012-01-20 12:56:55.530764+00', 'Welcome to Niagara', 'WELCOME TO NIAGARA', 3, 32, 9999, 1, 4, NULL, 213, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12417, '2005-05-01 22:00:00+00', '2012-01-20 12:57:38.021656+00', 'Waves on the Sand', 'WAVES ON THE SAND', 1, 32, 9999, 1, 4, NULL, 3350, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12419, '2005-05-01 22:00:00+00', '2012-01-20 12:57:38.030295+00', 'Welcome to Feltham', 'WELCOME TO FELTHAM', 2, 32, 9999, 1, 4, NULL, 179, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7032, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.584783+00', 'Welcome To Summer''s End', 'WELCOME TO SUMMERS END', 1, 100, 9999, 1, 4, NULL, 1176, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7012, '1998-01-12 23:00:00+00', '2016-05-11 14:03:59.794501+00', 'Weel Done, Cutty Sark', 'WEEL DONE CUTTY SARK', 1, 32, 9999, 103, 109, NULL, 210, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7003, '2002-03-12 23:00:00+00', '2018-04-03 00:08:24.583133+00', 'Wee Moira''s Jig', 'WEE MOIRAS JIG', 2, 32, 9999, 1, 3, 42, 111, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6985, '1997-08-21 22:00:00+00', '2018-04-03 00:08:24.366357+00', 'Wedding In Balquhidder, A', 'WEDDING IN BALQUHIDDER', 3, 32, 9999, 1, 3, 42, 108, '1991-01-01', 'See <<ddd:Balquidder Strathspey>> for information about Balquhidder.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6999, '1997-09-17 22:00:00+00', '2018-04-03 00:08:24.549737+00', 'Wee Hornpipe, The', 'WEE HORNPIPE', 1, 32, 9999, 1, 3, 42, 209, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7006, '1997-09-17 22:00:00+00', '2018-04-03 00:08:24.641471+00', 'Wee Small Hours', 'WEE SMALL HOURS', 3, 32, 9999, 1, 3, 42, 1348, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7015, '1997-09-17 22:00:00+00', '2018-04-03 00:08:24.674812+00', 'Welcome Home', 'WELCOME HOME', 3, 32, 9999, 1, 3, 42, 653, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12442, '2005-05-09 22:00:00+00', '2018-04-03 00:18:02.430861+00', 'Ruth''s List', 'RUTHS LIST', 3, 32, 9999, 2, 2, 76, 118, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7080, '1997-04-03 22:00:00+00', '2018-07-27 01:50:07.143236+00', 'When The Kye Come Hame', 'WHEN THE KYE COME HAME', 3, 32, 9999, 1, 3, 42, 173, '1974-06-23', '', 69, '880/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7040, '1997-04-03 22:00:00+00', '2012-01-20 12:56:55.640817+00', 'Wellington Square', 'WELLINGTON SQUARE', 1, 48, 9999, 4, 4, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7047, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.69168+00', 'Wendy''s Wedding', 'WENDYS WEDDING', 2, 32, 9999, 1, 4, NULL, 900, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7048, '1999-05-10 22:00:00+00', '2012-01-20 12:56:55.698726+00', 'Wendy''s Welcome', 'WENDYS WELCOME', 1, 32, 9999, 1, 2, NULL, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18712, '2018-10-03 01:22:15.260407+00', '2018-10-03 01:22:15.260407+00', 'Circling the Globe', 'CIRCLING THE GLOBE', 2, 32, NULL, 1, 3, 42, 2766, '2010-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7051, '1997-04-03 22:00:00+00', '2012-01-20 12:56:55.719836+00', 'West Coast Jig, The', 'WEST COAST JIG', 2, 32, 9999, 1, 2, NULL, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7052, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.726771+00', 'West End Strathspey, The', 'WEST END STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7054, '1997-04-03 22:00:00+00', '2012-01-20 12:56:55.740528+00', 'West Port, St. Andrews', 'WEST PORT ST ANDREWS', 1, 40, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12424, '2005-05-01 22:00:00+00', '2012-01-20 12:57:38.074015+00', 'We''re Getting Married', 'WERE GETTING MARRIED', 2, 40, 9999, NULL, NULL, NULL, 3602, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12430, '2005-05-09 22:00:00+00', '2012-01-20 12:57:38.129295+00', 'Kingston Silver Celebration, The', 'KINGSTON SILVER CELEBRATION', 4, 128, 62, 4, 4, NULL, 118, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12431, '2005-05-09 22:00:00+00', '2012-01-20 12:57:38.138881+00', 'Tying the Knot', 'TYING THE KNOT', 3, 32, 9999, 2, 3, 18, 2793, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12433, '2005-05-09 22:00:00+00', '2012-01-20 12:57:38.157861+00', 'Mony a Pickle Maks a Muckle', 'MONY A PICKLE MAKS A MUCKLE', 2, 48, 9999, 4, 5, NULL, 118, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12435, '2005-05-09 22:00:00+00', '2012-01-20 12:57:38.176237+00', 'Reiss Sands Reel, The', 'REISS SANDS REEL', 1, 40, 9999, 2, 3, 17, 3606, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7000, '1997-04-03 22:00:00+00', '2022-09-06 19:32:27.18117+00', 'Wee Hours, The', 'WEE HOURS', 2, 32, 9999, 1, 4, 1, 322, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12423, '2005-05-01 22:00:00+00', '2022-09-19 10:14:06.014828+00', 'Swings and Roundabouts', 'SWINGS AND ROUNDABOUTS', 2, 32, 9999, 1, 3, 42, 3601, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12421, '2005-05-01 22:00:00+00', '2022-09-19 10:48:28.900077+00', 'Cinq Chapeaux, Les', 'CINQ CHAPEAUX', 3, 32, 9999, 3, 5, 16, 3554, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7002, '1997-04-03 22:00:00+00', '2022-11-07 21:54:52.770936+00', 'Wee Man at the Loom', 'WEE MAN AT THE LOOM', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12436, '2005-05-09 22:00:00+00', '2012-01-20 12:57:38.18583+00', 'Janet''s Folly', 'JANETS FOLLY', 3, 32, 9999, 1, 4, 1, 3607, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7039, '1998-04-24 22:00:00+00', '2018-03-18 23:22:27.240114+00', 'Well Met', 'WELL MET', 3, 32, 9999, 1, 3, 42, 349, '1992-01-01', '', 31, '440/440/422/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7038, '1997-09-17 22:00:00+00', '2019-09-13 22:18:36.518536+00', 'Well Hall   TRANSFER LINKS TO DANCE 456', 'WELL HALL   TRANSFER LINKS TO DANCE 456', 1, 32, 9999, 1, 2, NULL, 446, '1686-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12443, '2005-05-09 22:00:00+00', '2018-04-03 00:07:39.731843+00', 'Cowdy Jig, The', 'COWDY JIG', 2, 32, 9999, 1, 3, 42, 1024, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12441, '2005-05-09 22:00:00+00', '2018-04-03 00:07:42.649264+00', 'Dorothy Pearson''s Jig', 'DOROTHY PEARSONS JIG', 2, 32, 9999, 1, 3, 42, 3608, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7063, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.834791+00', 'Westwood Reel', 'WESTWOOD REEL', 1, 64, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7025, '2001-06-04 22:00:00+00', '2020-07-14 08:37:07.000301+00', 'Welcome to Miss Milligan', 'WELCOME TO MISS MILLIGAN', 3, 32, 9999, 1, 2, 76, 70, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6996, '1998-10-17 22:00:00+00', '2021-04-03 17:56:11.055999+00', 'Wee Croft, The', 'WEE CROFT', 1, 32, 9999, 1, 3, 42, 26, NULL, '', 53, '800/888/822/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7030, '1998-01-05 23:00:00+00', '2020-08-07 10:33:41.274446+00', 'Welcome To Scotland', 'WELCOME TO SCOTLAND', 1, 32, 9999, 1, 3, 42, 82, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7034, '1998-12-17 23:00:00+00', '2020-09-04 10:46:16.265633+00', 'Welcome To The Ball', 'WELCOME TO THE BALL', 2, 32, 9999, 1, 3, 42, 440, NULL, '', 47, '800/844/844/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7044, '1998-07-08 22:00:00+00', '2020-11-30 18:31:05.571316+00', 'Wells Of Swona, The', 'WELLS OF SWONA', 3, 32, 9999, 1, 4, 2, 313, NULL, 'The Wells of Swona is a whirlpool to the north of the Scottish mainland. It was supposed to be caused by a witch’s struggles to free herself from the grasp of a drowning man.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12416, '2005-05-01 22:00:00+00', '2021-01-14 20:22:43.332664+00', 'Unsung Hero', 'UNSUNG HERO', 1, 32, 9999, 1, 3, 42, 3374, '2002-01-01', '', 64, '886/888/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7027, '2002-04-15 22:00:00+00', '2021-04-02 17:59:29.833053+00', 'Welcome to Nova Scotia', 'WELCOME TO NOVA SCOTIA', 3, 32, 9999, 1, 3, 42, 108, '1995-01-01', 'For Pat Kent of Halifax, Nova Scotia.', 63, '808/888/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7016, '2002-04-19 22:00:00+00', '2021-04-02 18:04:37.548189+00', 'Welcome in Oak Park, A', 'WELCOME IN OAK PARK', 3, 32, 9999, 1, 2, 76, 361, NULL, '', 60, '80/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7013, '1997-09-17 22:00:00+00', '2021-04-02 18:07:00.630852+00', 'Welcome All', 'WELCOME ALL', 3, 32, 9999, 5, 2, NULL, 1191, NULL, '', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12411, '2006-09-03 22:00:00+00', '2021-04-05 11:37:39.543779+00', 'Winter''s Walk, A', 'WINTERS WALK', 2, 32, 9999, 1, 3, 42, 3703, NULL, '', 50, '804/833/833/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7064, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.841562+00', 'Wha Widna Fecht', 'WHA WIDNA FECHT', 2, 32, 9999, 5, 56, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7076, '1998-01-05 23:00:00+00', '2012-01-20 12:56:55.929376+00', 'Wheeler Reeler, The', 'WHEELER REELER', 1, 40, 9999, 1, 4, NULL, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7082, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.970747+00', 'Where are You Going my Pretty Maid?', 'WHERE ARE YOU GOING MY PRETTY MAID', 2, 32, 9999, 1, 4, NULL, 1362, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7083, '1997-09-17 22:00:00+00', '2012-01-20 12:56:55.977579+00', 'Where Did You Get That Hat?', 'WHERE DID YOU GET THAT HAT', 2, 32, 9999, 1, 2, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12439, '2005-05-09 22:00:00+00', '2012-01-20 12:57:38.21302+00', 'Limestone City Scot, The', 'LIMESTONE CITY SCOT', 3, 40, 9999, 4, 4, 1, 118, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14613, '2012-12-17 23:27:24.614964+00', '2016-05-25 21:15:23.15144+00', 'Double Triangles', 'DOUBLE TRIANGLES', 3, 32, NULL, 107, 6, 30, 10670, '2012-03-01', 'Six couples in two triangular sets.  Three times through', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7053, '1998-04-24 22:00:00+00', '2015-03-11 09:20:32.577147+00', 'West Park', 'WEST PARK', 3, 32, 9999, 1, 3, 42, 146, '1986-01-01', '"For Avril Jones"', 59, '626/662/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7041, '1997-08-24 22:00:00+00', '2017-02-23 19:44:20.543926+00', 'Wellington Square', 'WELLINGTON SQUARE', 1, 64, 9999, 4, 4, 28, 108, '1990-02-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12438, '2005-05-09 22:00:00+00', '2018-04-03 00:08:10.765251+00', 'Piper Sam''s Reel', 'PIPER SAMS REEL', 1, 32, 9999, 1, 3, 42, 394, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12444, '2005-05-09 22:00:00+00', '2018-04-03 00:08:12.299806+00', 'Reel for Dorothy, A', 'REEL FOR DOROTHY', 1, 32, 9999, 1, 3, 42, 1024, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7046, '1997-04-03 22:00:00+00', '2018-04-03 00:08:24.85819+00', 'Wendy''s Delight', 'WENDYS DELIGHT', 1, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7050, '1997-09-17 22:00:00+00', '2018-04-03 00:08:24.891578+00', 'Wessex Wanderer, The', 'WESSEX WANDERER', 1, 32, 9999, 1, 3, 42, 1086, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7056, '1997-04-03 22:00:00+00', '2018-04-03 00:08:24.908228+00', 'Westbroke', 'WESTBROKE', 2, 32, 9999, 1, 3, 42, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7058, '1997-09-17 22:00:00+00', '2018-04-03 00:08:24.924887+00', 'Western Fountains', 'WESTERN FOUNTAINS', 3, 32, 9999, 1, 3, 42, 1358, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7059, '1997-08-21 22:00:00+00', '2018-04-03 00:08:24.933342+00', 'Westerton', 'WESTERTON', 3, 32, 9999, 1, 3, 42, 108, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7066, '1997-08-24 22:00:00+00', '2018-04-03 00:08:25.000054+00', 'Wha''s Like Us?', 'WHAS LIKE US', 1, 40, 9999, 1, 3, 42, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7069, '1997-04-03 22:00:00+00', '2018-04-03 00:08:25.01678+00', 'What Do You Want', 'WHAT DO YOU WANT', 2, 32, 9999, 1, 3, 42, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7070, '1997-04-03 22:00:00+00', '2018-04-03 00:08:25.025116+00', 'What Is Lost Is Safe', 'WHAT IS LOST IS SAFE', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7072, '1997-04-03 22:00:00+00', '2018-04-03 00:08:25.058432+00', 'What the Pipers Say', 'WHAT THE PIPERS SAY', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7078, '1997-04-03 22:00:00+00', '2018-04-03 00:08:25.091808+00', 'When Auld Friends Meet', 'WHEN AULD FRIENDS MEET', 3, 32, 9999, 1, 3, 42, 44, '1978-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12425, '2005-05-01 22:00:00+00', '2018-04-03 00:08:25.809263+00', 'William''s Welcome', 'WILLIAMS WELCOME', 1, 32, 9999, 1, 3, 42, 1374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12447, '2005-06-05 22:00:00+00', '2012-01-20 12:57:38.282726+00', 'Mount Seymour Strathspey', 'MOUNT SEYMOUR STRATHSPEY', 3, 32, 9999, 2, 3, NULL, 1727, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7106, '1998-01-05 23:00:00+00', '2018-04-29 21:32:53.598666+00', 'Whitburn Reel', 'WHITBURN REEL', 1, 32, 9999, 1, 3, 42, 366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7118, '1998-01-05 23:00:00+00', '2019-01-27 00:14:45.187828+00', 'White Rabbit, The', 'WHITE RABBIT', 1, 32, 9999, 1, 2, 76, 44, NULL, '', 52, '44/88/44/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12462, '2005-06-28 22:00:00+00', '2018-04-03 00:07:38.964356+00', 'Cochrane Hall', 'COCHRANE HALL', 1, 32, 9999, 1, 3, 42, 352, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18735, '2018-10-04 08:33:33.135385+00', '2018-10-04 08:33:33.135385+00', 'Disco Ball Reel, The', 'DISCO BALL REEL', 1, 32, NULL, 1, 3, 42, 2766, '2006-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12460, '2005-06-28 22:00:00+00', '2018-04-03 00:07:41.7669+00', 'Delph Pond', 'DELPH POND', 1, 32, 9999, 1, 3, 42, 352, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7089, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.019355+00', 'Where''s That Midge?', 'WHERES THAT MIDGE', 2, 32, 9999, 5, 2, NULL, 356, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7091, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.033166+00', 'Whim-Whams', 'WHIMWHAMS', 1, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7097, '1997-09-17 22:00:00+00', '2012-01-20 12:56:56.096702+00', 'Whisky In The Jar', 'WHISKY IN THE JAR', 1, 240, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7098, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.105581+00', 'Whisky Galore', 'WHISKY GALORE', 4, 32, 9999, 1, 4, NULL, 278, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7100, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.124561+00', 'Whisky In The Jar', 'WHISKY IN THE JAR', 2, 48, 9999, 1, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12463, '2005-06-28 22:00:00+00', '2018-04-03 00:07:42.359201+00', 'Dollar Dance', 'DOLLAR DANCE', 1, 32, 9999, 1, 3, 42, 352, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7203, '1998-07-08 22:00:00+00', '2012-01-20 12:56:56.856275+00', 'Wisecarver Hall', 'WISECARVER HALL', 1, 32, 9999, 1, 4, 2, 348, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12453, '2005-06-05 22:00:00+00', '2022-09-19 10:01:01.55341+00', 'Swans of Salt Spring Island, The', 'SWANS OF SALT SPRING ISLAND', 3, 40, 9999, 2, 3, 17, 3610, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12446, '2005-06-05 22:00:00+00', '2022-09-19 10:11:55.713248+00', 'Miss Anderson of Hobart', 'MISS ANDERSON OF HOBART', 2, 32, 9999, 1, 2, 76, 2096, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7092, '1997-04-03 22:00:00+00', '2022-10-23 21:12:38.485071+00', 'Whimpey the Clown', 'WHIMPEY THE CLOWN', 2, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7102, '1998-07-08 22:00:00+00', '2012-01-20 12:56:56.141048+00', 'Whistler''s Glen, The', 'WHISTLERS GLEN', 2, 32, 9999, 1, 4, 2, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7103, '1997-09-17 22:00:00+00', '2012-01-20 12:56:56.147984+00', 'Whistler, The', 'WHISTLER', 2, 144, 9999, 4, 4, NULL, 173, '1969-01-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14614, '2012-12-17 23:29:58.958532+00', '2018-04-03 00:07:46.554663+00', 'For Sybil', 'FOR SYBIL', 2, 32, NULL, 1, 3, 42, 10671, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12456, '2005-06-28 22:00:00+00', '2012-01-20 12:57:38.361696+00', 'Gartmorn Walk', 'GARTMORN WALK', 1, 40, 9999, 1, 4, NULL, 352, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14627, '2012-12-18 13:22:08.288635+00', '2018-04-03 00:07:59.531674+00', 'Like a Prayer', 'LIKE A PRAYER', 3, 32, NULL, 1, 3, 42, 1089, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12459, '2005-06-28 22:00:00+00', '2012-01-20 12:57:38.387936+00', 'Sun over Sauchie', 'SUN OVER SAUCHIE', 1, 32, 9999, 1, 4, NULL, 352, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12461, '2005-06-28 22:00:00+00', '2012-01-20 12:57:38.405393+00', 'Clackmannan Strathspey', 'CLACKMANNAN STRATHSPEY', 3, 32, 9999, 4, 4, NULL, 352, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12464, '2005-06-28 22:00:00+00', '2012-01-20 12:57:38.431619+00', 'Cambus Bridge', 'CAMBUS BRIDGE', 3, 32, 9999, 1, 4, NULL, 352, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7036, '1997-04-03 22:00:00+00', '2020-09-04 10:51:30.377385+00', 'Welcome To Witney', 'WELCOME TO WITNEY', 1, 40, 9999, 1, 3, 42, 89, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7112, '1997-09-17 22:00:00+00', '2020-09-04 10:55:22.908406+00', 'White Heather Strathspey, The', 'WHITE HEATHER STRATHSPEY', 3, 96, 9999, 4, 4, 3, 1035, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14625, '2012-12-18 13:15:22.266835+00', '2020-10-20 09:21:34.680131+00', 'Letters to Juliet', 'LETTERS TO JULIET', 1, 32, NULL, 1, 3, 42, 1089, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7067, '1997-04-03 22:00:00+00', '2020-11-05 13:53:51.084374+00', 'Whale Rock, The', 'WHALE ROCK', 3, 32, 9999, 1, 3, 42, 99, NULL, '', 56, '800/888/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7110, '1998-07-08 22:00:00+00', '2021-03-30 20:54:52.056212+00', 'White Gull Of Tay, The', 'WHITE GULL OF TAY', 3, 32, 9999, 1, 4, 5, 1363, NULL, '', 80, '8888/8888/8008/8644', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7107, '2000-04-25 22:00:00+00', '2021-03-30 21:13:16.32032+00', 'Whitby Wedding', 'WHITBY WEDDING', 2, 40, 9999, 1, 4, 1, 543, '1987-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7081, '1998-04-24 22:00:00+00', '2021-03-31 09:34:03.162971+00', 'When The Tide Comes In', 'WHEN THE TIDE COMES IN', 2, 40, 9999, 1, 3, 42, 59, '1992-01-01', '', 52, '844/822/888/822/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14615, '2012-12-17 23:40:13.691403+00', '2012-12-17 23:40:13.691414+00', 'Haphazard', 'HAPHAZARD', 1, 48, NULL, 3, 5, NULL, 10669, '2012-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7114, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.232659+00', 'White Heron Strathspey, The', 'WHITE HERON STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7115, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.239448+00', 'White Heron, The', 'WHITE HERON', 3, 32, 9999, 1, 4, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7119, '1997-09-17 22:00:00+00', '2012-01-20 12:56:56.267911+00', 'White Rose Jubilee Reel', 'WHITE ROSE JUBILEE REEL', 1, 32, 9999, 1, 4, 1, 1364, '1979-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7122, '1999-04-19 22:00:00+00', '2012-01-20 12:56:56.29002+00', 'White Stag Of Arran, The', 'WHITE STAG OF ARRAN', 4, 72, 28, 1, 4, 14, 751, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7127, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.32486+00', 'Whiteinch', 'WHITEINCH', 1, 32, 9999, 4, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7101, '2001-05-21 22:00:00+00', '2016-06-03 13:54:56.297133+00', 'Whisky Punch, The', 'WHISKY PUNCH', 2, 40, 9999, 1, 4, 1, 228, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12457, '2005-06-28 22:00:00+00', '2016-11-14 15:50:55.612686+00', 'Tullibody Reel', 'TULLIBODY REEL', 1, 32, 9999, 1, 4, 1, 352, '2001-01-14', 'The original instructions are not quite clear for bars 27-32.  More detail needed.', 66, '8080/8484/8484/8282', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12455, '2005-06-28 22:00:00+00', '2017-03-26 00:44:01.490831+00', 'Alloa Reel', 'ALLOA REEL', 1, 48, 9999, 1, 4, 2, 352, '2002-05-02', '', 58, '8448/8228/8228/8228/8228/8000', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14626, '2012-12-18 13:19:44.860596+00', '2018-04-03 00:08:05.118981+00', 'Moments of Magic', 'MOMENTS OF MAGIC', 1, 48, NULL, 1, 3, 42, 1089, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12458, '2005-06-28 22:00:00+00', '2018-04-03 00:08:21.147753+00', 'Tillicoultry Glen', 'TILLICOULTRY GLEN', 1, 32, 9999, 1, 3, 42, 352, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7086, '1997-09-17 22:00:00+00', '2018-04-03 00:08:25.250328+00', 'Where Gadie Rins', 'WHERE GADIE RINS', 1, 32, 9999, 1, 3, 42, 981, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7095, '1997-09-17 22:00:00+00', '2018-04-03 00:08:25.316883+00', 'Whirlijig, The', 'WHIRLIJIG', 2, 32, 9999, 1, 3, 42, 595, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7108, '1997-04-03 22:00:00+00', '2018-04-03 00:08:25.510001+00', 'White Adder Water', 'WHITE ADDER WATER', 3, 32, 9999, 1, 3, 42, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7126, '1997-09-17 22:00:00+00', '2018-04-03 00:08:25.542009+00', 'Whitehall Minuet', 'WHITEHALL MINUET', 50, 24, 9999, 1, 3, 42, 446, '1701-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7123, '1998-04-24 22:00:00+00', '2018-04-03 00:08:25.608748+00', 'White Stag of Mormond, The', 'WHITE STAG OF MORMOND', 1, 32, 9999, 1, 3, 42, 108, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7128, '1997-04-03 22:00:00+00', '2018-04-03 00:08:25.633665+00', 'Whitlock''s Whimsey', 'WHITLOCKS WHIMSEY', 2, 32, 9999, 1, 3, 42, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7094, '1997-12-03 23:00:00+00', '2018-04-03 00:08:25.684283+00', 'Wicks o'' Baiglie, The', 'WICKS O BAIGLIE', 2, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12452, '2005-06-05 22:00:00+00', '2018-04-03 00:08:26.943417+00', 'XL aration', 'XL ARATION', 1, 32, 9999, 1, 3, 42, 3572, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7148, '1997-12-22 23:00:00+00', '2018-04-29 10:15:38.784166+00', 'Wild Goats Of Scotland, The', 'WILD GOATS OF SCOTLAND', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7131, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.352639+00', 'Whitterick, The', 'WHITTERICK', 2, 32, 9999, 1, 2, NULL, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7136, '1998-01-04 23:00:00+00', '2012-01-20 12:56:56.386775+00', 'Airth Castle', 'AIRTH CASTLE', 3, 32, 9999, 2, 3, NULL, 218, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18736, '2018-10-04 08:51:10.372916+00', '2018-10-04 08:51:10.372916+00', 'Double Cross', 'DOUBLE CROSS', 2, 32, NULL, 1, 3, 42, 2766, '2007-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13200, '2006-12-11 23:00:00+00', '2018-10-04 08:53:08.578095+00', 'Double Duty', 'DOUBLE DUTY', 1, 32, 9999, 1, 3, 42, 2766, '2005-09-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12467, '2005-06-28 22:00:00+00', '2012-01-20 12:57:38.457949+00', 'Prickly Thistle', 'PRICKLY THISTLE', 2, 32, 9999, 1, 4, NULL, 352, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12468, '2005-06-28 22:00:00+00', '2012-01-20 12:57:38.466684+00', 'All Reel Together', 'ALL REEL TOGETHER', 3, 32, 9999, 1, 4, NULL, 352, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12484, '2005-07-24 22:00:00+00', '2018-10-06 12:26:05.835483+00', 'New Beginning, A', 'NEW BEGINNING', 1, 32, 9999, 1, 3, 42, 2766, '2005-07-01', 'I learned this month that I lost my job due to declining enrollment. This dance reflects my view of the occasion.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12470, '2005-06-28 22:00:00+00', '2012-01-20 12:57:38.4842+00', 'Kinnairdy Castle', 'KINNAIRDY CASTLE', 1, 40, 9999, 4, 4, NULL, 352, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12471, '2005-06-28 22:00:00+00', '2012-01-20 12:57:38.492955+00', 'Halfway Home', 'HALFWAY HOME', 3, 24, 9999, 1, 4, NULL, 352, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12472, '2005-06-28 22:00:00+00', '2012-01-20 12:57:38.501668+00', 'White Lightning', 'WHITE LIGHTNING', 2, 32, 9999, 1, 4, NULL, 352, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12473, '2005-06-28 22:00:00+00', '2012-01-20 12:57:38.5104+00', 'Trident Reel, The', 'TRIDENT REEL', 1, 32, 9999, 1, 4, NULL, 352, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7145, '1997-09-17 22:00:00+00', '2018-03-07 18:30:49.685169+00', 'Wife She Brewed It, The', 'WIFE SHE BREWED IT', 3, 32, 9999, 1, 4, 1, 129, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12480, '2005-07-24 22:00:00+00', '2018-10-06 13:31:07.794194+00', 'Pandora''s Box', 'PANDORAS BOX', 3, 32, 9999, 1, 3, 42, 2766, '2005-06-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18867, '2018-10-07 11:30:48.499369+00', '2018-10-07 11:31:01.332118+00', 'Ripples on the Pond', 'RIPPLES ON THE POND', 3, 32, NULL, 1, 3, 42, 2766, '2011-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7153, '1997-09-17 22:00:00+00', '2019-02-21 21:17:06.88262+00', 'Wileycat Wood', 'WILEYCAT WOOD', 3, 32, 9999, 1, 4, 2, 21, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12465, '2005-06-28 22:00:00+00', '2018-04-03 00:07:33.273923+00', 'Beyond the Pale', 'BEYOND THE PALE', 1, 32, 9999, 1, 3, 42, 352, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12466, '2005-06-28 22:00:00+00', '2019-02-28 22:21:59.483777+00', 'French Connection, The', 'FRENCH CONNECTION', 1, 32, 9999, 1, 4, 2, 352, '2002-01-01', '', 66, '8008/8888/8008/8228', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7159, '2000-04-25 22:00:00+00', '2022-10-23 21:09:48.371813+00', 'Willesden Park', 'WILLESDEN PARK', 1, 48, 9999, 4, 4, 54, 573, NULL, '', 71, '6666/6666/8080/0808/6666/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7140, '1997-11-24 23:00:00+00', '2023-01-26 19:14:24.182654+00', 'Wicker Chair, The', 'WICKER CHAIR', 4, 64, 2, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7135, '2002-03-03 23:00:00+00', '2019-03-08 18:51:47.088568+00', 'Why Not?', 'WHY NOT', 1, 40, 9999, 1, 4, 2, 104, '1992-01-01', '', 88, '8888/8888/8448/8228/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14629, '2012-12-18 13:26:32.729476+00', '2018-04-03 00:07:36.052093+00', 'Buccleuch''s Favourite', 'BUCCLEUCHS FAVOURITE', 1, 32, NULL, 1, 3, 42, 1089, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7150, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.483276+00', 'Wild Rose Of Lorne', 'WILD ROSE OF LORNE', 3, 64, 9999, 3, 5, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7155, '2000-07-02 22:00:00+00', '2012-01-20 12:56:56.519485+00', 'Will Ye Run Awa'' Wi'' Me', 'WILL YE RUN AWA WI ME', 1, 32, 9999, 1, 2, NULL, 108, '1971-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7156, '1998-01-04 23:00:00+00', '2012-01-20 12:56:56.52635+00', 'Alice Through The Looking Glass', 'ALICE THROUGH THE LOOKING GLASS', 3, 32, 9999, 1, 4, NULL, 616, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7113, '1997-04-03 22:00:00+00', '2020-09-04 10:57:15.572875+00', 'White Heather Strathspey, The', 'WHITE HEATHER STRATHSPEY', 3, 32, 9999, 1, 2, 76, 28, NULL, '', 60, '88/88/80/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12448, '2005-06-05 22:00:00+00', '2021-01-14 20:10:22.209811+00', 'Nellie McKenzie''s Jig', 'NELLIE MACKENZIES JIG', 2, 32, 9999, 1, 3, 42, 2685, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7129, '1997-04-03 22:00:00+00', '2021-03-30 20:36:46.195537+00', 'Whitesands Jig, The', 'WHITESANDS JIG', 2, 32, 9999, 1, 3, 42, 200, NULL, '', 59, '844/844/888/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7121, '2002-04-15 22:00:00+00', '2021-03-30 20:47:26.430595+00', 'White Rose Of York, The', 'WHITE ROSE OF YORK', 3, 32, 9999, 2, 3, 18, 1365, NULL, '', 50, '844/800/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7085, '2002-02-16 23:00:00+00', '2021-03-31 09:19:31.619586+00', 'Where Friends Meet', 'WHERE FRIENDS MEET', 3, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7116, '1998-04-21 22:00:00+00', '2021-06-13 10:17:34.947046+00', 'White Knight, The', 'WHITE KNIGHT', 1, 32, 9999, 1, 3, 42, 44, NULL, '', 47, '800/844/844/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7199, '1997-04-03 22:00:00+00', '2021-07-13 09:56:30.754754+00', 'Winsten Gallop', 'WINSTEN GALLOP', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 31, '800/800/800/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7160, '1997-09-17 22:00:00+00', '2012-01-20 12:56:56.55842+00', 'William B. Cunningham', 'WILLIAM B CUNNINGHAM', 3, 32, 9999, 5, 56, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7166, '1997-09-17 22:00:00+00', '2012-01-20 12:56:56.599178+00', 'Willie Cook', 'WILLIE COOK', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7167, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.606013+00', 'Willie Davie', 'WILLIE DAVIE', 1, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7168, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.612834+00', 'Willie Kelman''s Capers', 'WILLIE KELMANS CAPERS', 2, 32, 9999, 1, 4, NULL, 89, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7170, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.62638+00', 'Willie Shaw', 'WILLIE SHAW', 3, 32, 9999, 5, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12487, '2005-07-24 22:00:00+00', '2012-01-20 12:57:38.664981+00', 'Trip to Beverly Hills', 'TRIP TO BEVERLY HILLS', 3, 40, 9999, 1, 4, 1, 3531, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12469, '2005-06-28 22:00:00+00', '2018-04-03 00:07:42.159011+00', 'Diane''s Dance', 'DIANES DANCE', 1, 32, 9999, 1, 3, 42, 352, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12474, '2005-06-28 22:00:00+00', '2018-04-03 00:07:46.054101+00', 'Five Minute Reel', 'FIVE MINUTE REEL', 1, 32, 9999, 1, 3, 42, 352, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7151, '1997-12-03 23:00:00+00', '2018-04-03 00:08:07.521073+00', 'Nellie Murphy', 'NELLIE MURPHY', 2, 32, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14628, '2012-12-18 13:24:31.183804+00', '2018-04-03 00:08:16.067716+00', 'Shall We Dance', 'SHALL WE DANCE', 3, 32, NULL, 1, 3, 42, 1089, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7130, '1997-08-21 22:00:00+00', '2018-04-03 00:08:25.600419+00', 'Whiteshell Park', 'WHITESHELL PARK', 3, 32, 9999, 1, 3, 42, 108, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7134, '1998-04-21 22:00:00+00', '2018-04-03 00:08:25.650427+00', 'Why Left I My Hame?', 'WHY LEFT I MY HAME', 3, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7146, '1997-04-03 22:00:00+00', '2018-04-03 00:08:25.734249+00', 'Wigamog Whirl', 'WIGAMOG WHIRL', 3, 32, 9999, 1, 3, 42, 67, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7163, '1997-12-22 23:00:00+00', '2018-04-03 00:08:25.817653+00', 'William The Lion''s Grave', 'WILLIAM THE LIONS GRAVE', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7165, '1997-04-03 22:00:00+00', '2018-04-03 00:08:25.825962+00', 'Willie Brewed a Peck o'' Maut', 'WILLIE BREWED A PECK O MAUT', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7169, '1997-09-17 22:00:00+00', '2018-04-03 00:08:25.851052+00', 'Willie Maclean of Aultbea', 'WILLIE MACLEAN OF AULTBEA', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7154, '2002-04-19 22:00:00+00', '2018-04-03 00:08:25.900994+00', 'Will Ye Come Awa'' Wi'' Me?', 'WILL YE COME AWA WI ME', 3, 32, 9999, 1, 3, 42, 44, '1977-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7221, '1997-09-17 22:00:00+00', '2018-04-03 00:08:26.859898+00', 'Wood''s Hornpipe', 'WOODS HORNPIPE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18567, '2018-09-09 20:53:21.390505+00', '2018-09-09 21:00:12.150914+00', 'Margaret''s Jig', 'MARGARETS JIG', 2, 32, NULL, 2, 3, 17, 11701, '2010-07-01', 'This dance was devised by members of the RSCDS Wirral Branch Children''s Class in July 2010 to celebrate the 10th Anniversary of the Children''s Class.', 65, '800/880/806/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12492, '2005-07-26 22:00:00+00', '2018-10-06 05:11:33.56208+00', 'Left and Left Again', 'LEFT AND LEFT AGAIN', 3, 32, 9999, 1, 3, 42, 2766, '2005-04-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12499, '2005-07-30 22:00:00+00', '2018-10-06 09:49:12.580435+00', 'Major Milestones', 'MAJOR MILESTONES', 2, 32, 9999, 1, 3, 42, 2766, '2005-07-01', 'Several dancers in my local class are turning "significant" ages this year.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12501, '2005-07-30 22:00:00+00', '2018-10-10 03:59:20.612226+00', 'Curlicue', 'CURLICUE', 1, 32, 9999, 1, 3, 42, 2766, '2005-07-01', 'I love dancing consecutive half reels where you can loop between half reels; this dance is named for those loops.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7176, '2002-12-07 23:00:00+00', '2012-01-20 12:56:56.670176+00', 'Wilson''s Prom Strathspey', 'WILSONS PROM STRATHSPEY', 3, 96, 9999, 4, 4, NULL, 1119, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7177, '1997-09-17 22:00:00+00', '2012-01-20 12:56:56.676992+00', 'Wiltshire Rant, The', 'WILTSHIRE RANT', 2, 40, 9999, 1, 4, NULL, 710, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14618, '2012-12-17 23:46:16.673082+00', '2012-12-17 23:46:16.673092+00', 'Sparsholt Strathspey, The', 'SPARSHOLT STRATHSPEY', 3, 32, NULL, 2, 3, NULL, 10672, '2012-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7181, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.70507+00', 'Wind that Shak, The', 'WIND THAT SHAK', 2, 32, 9999, 1, 2, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12490, '2005-07-26 22:00:00+00', '2019-04-18 22:39:28.308577+00', 'Home Again', 'HOME AGAIN', 2, 32, 9999, 1, 3, 42, 2766, '2005-01-01', 'This dance was written as I returned from a trip to visit my family.', 41, '840/848/800/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7184, '2002-11-26 23:00:00+00', '2012-01-20 12:56:56.725657+00', 'Wind that Shaks the Piggery', 'WIND THAT SHAKS THE PIGGERY', 2, 64, 9999, 2, 3, NULL, 425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7185, '1997-09-17 22:00:00+00', '2012-01-20 12:56:56.73241+00', 'Wind, The', 'WIND', 1, 40, 9999, 2, 3, NULL, 195, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7218, '1997-04-03 22:00:00+00', '2019-08-28 17:24:42.290644+00', 'Wonder Hornpipe, The', 'WONDER HORNPIPE', 6, 32, 9999, 1, 3, 42, 270, NULL, '', 50, '800/884/866/862', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7187, '1997-09-17 22:00:00+00', '2012-01-20 12:56:56.745935+00', 'Winding Deveron', 'WINDING DEVERON', 4, 256, 9999, 4, 4, NULL, 297, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7191, '1997-09-17 22:00:00+00', '2012-01-20 12:56:56.77307+00', 'Windmill Reel, The', 'WINDMILL REEL', 2, 96, 9999, 4, 4, NULL, 1291, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7192, '1997-09-17 22:00:00+00', '2012-01-20 12:56:56.779839+00', 'Windmill, The', 'WINDMILL', 2, 32, 9999, 1, 2, NULL, 1037, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7194, '1997-09-17 22:00:00+00', '2012-01-20 12:56:56.793612+00', 'Windmills of Majorca, The', 'WINDMILLS OF MAJORCA', 1, 48, 9999, 4, 4, NULL, 676, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12503, '2005-08-21 22:00:00+00', '2012-01-20 12:57:38.836449+00', 'Saint Martin Summer', 'SAINT MARTIN SUMMER', 2, 64, 9999, 4, 4, 14, 3618, '1993-01-01', 'For the dancers at Saint Martin In-The-Fields, Victoria, B.C.

Danced twice through only.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14630, '2012-12-18 13:29:48.637614+00', '2012-12-18 13:29:48.637625+00', 'So Very Special', 'SO VERY SPECIAL', 3, 32, NULL, 1, 98, 30, 1089, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7200, '1997-12-21 23:00:00+00', '2012-01-20 12:56:56.83513+00', 'Winter Joys', 'WINTER JOYS', 2, 32, 9999, 3, 5, NULL, 425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12495, '2005-07-29 22:00:00+00', '2018-04-03 00:07:35.601637+00', 'Brenda''s Walk', 'BRENDAS WALK', 2, 32, 9999, 1, 3, 42, 3531, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7158, '1997-04-03 22:00:00+00', '2022-11-15 11:35:52.858107+00', 'Willafjord', 'WILLAFJORD', 1, 48, 9999, 1, 3, 42, 270, NULL, '', 38, '844/844/800/844/800/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12493, '2005-07-26 22:00:00+00', '2020-09-13 08:43:02.064687+00', '10th Frolic, The', '10TH FROLIC', 1, 32, 9999, 4, 5, 35, 2766, '2005-05-01', '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12491, '2005-07-26 22:00:00+00', '2021-01-20 19:07:46.203402+00', 'Wizard''s Walk', 'WIZARDS WALK', 3, 32, 9999, 1, 3, 42, 2766, '2005-04-01', '', 38, '800/844/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7195, '2000-04-25 22:00:00+00', '2021-03-29 09:55:42.328524+00', 'Windsor Welcome, The', 'WINDSOR WELCOME', 1, 40, 9999, 1, 100, 2, 28, '1986-01-01', 'From the original: Devised in 1986 on the occasion of the 40th anniversary of the Belfast Branch. For Mary Kersley, a founder member of the Branch, in appreciation of the warm welcome given to me by her and other members of her Windsor class when I visited Ulster in 1956."', 70, '8008/8888/0880/8448/8448', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7162, '1997-04-03 22:00:00+00', '2021-04-04 13:57:17.554612+00', 'William McDonald Black', 'WILLIAM MACDONALD BLACK', 3, 32, 9999, 1, 3, 42, 129, NULL, '', 54, '844/866/866/822', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7144, '1997-09-17 22:00:00+00', '2021-04-21 11:20:22.366258+00', 'Wife of Bath, The', 'WIFE OF BATH', 2, 32, 9999, 1, 3, 42, 304, '1988-01-01', '', 47, '888/880/800/822', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7138, '1997-04-03 22:00:00+00', '2021-06-13 10:13:47.009192+00', 'Wicks o'' Baiglie, The', 'WICKS O BAIGLIE', 1, 32, 9999, 1, 3, 42, 417, '1983-01-01', 'The original instructions use the spelling "Wick''s" with apostrophe.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7205, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.86994+00', 'Witch Of The Wave', 'WITCH OF THE WAVE', 3, 32, 9999, 1, 4, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7208, '1998-01-12 23:00:00+00', '2012-01-20 12:56:56.892499+00', 'Witches'' Score, The', 'WITCHES SCORE', 1, 32, 9999, 5, 4, NULL, 210, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7209, '1998-07-08 22:00:00+00', '2012-01-20 12:56:56.899953+00', 'With Fortitude', 'WITH FORTITUDE', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7212, '1997-11-27 23:00:00+00', '2012-01-20 12:56:56.921655+00', 'Withycombe Mill', 'WITHYCOMBE MILL', 4, 128, 1, 4, 4, NULL, 1368, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7217, '1997-09-17 22:00:00+00', '2012-01-20 12:56:56.957014+00', 'Won''t You Join The Dance', 'WONT YOU JOIN THE DANCE', 1, 120, 9999, 4, 4, NULL, 1369, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12496, '2005-07-30 22:00:00+00', '2018-04-03 00:08:15.576992+00', 'Seldom Seen Slim''s Strathspey', 'SELDOM SEEN SLIMS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3531, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12497, '2005-07-30 22:00:00+00', '2018-04-03 00:08:16.427572+00', 'Shortbread Bramble', 'SHORTBREAD BRAMBLE', 2, 32, 9999, 1, 3, 42, 3531, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14617, '2012-12-17 23:44:14.776282+00', '2018-04-03 00:08:17.86198+00', 'Spaghetti Reel, The', 'SPAGHETTI REEL', 1, 40, NULL, 1, 3, 42, 10672, '2012-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7186, '1997-09-17 22:00:00+00', '2018-04-03 00:08:26.126253+00', 'Windermere', 'WINDERMERE', 1, 32, 9999, 1, 3, 42, 1277, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7196, '1997-04-03 22:00:00+00', '2018-04-03 00:08:26.201286+00', 'Windy Hill', 'WINDY HILL', 1, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7198, '1997-09-17 22:00:00+00', '2018-04-03 00:08:26.23456+00', 'Winghouse Jig, The', 'WINGHOUSE JIG', 2, 32, 9999, 1, 3, 42, 606, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7202, '1997-09-17 22:00:00+00', '2018-04-03 00:08:26.276332+00', 'Winterlude Reel, The', 'WINTERLUDE REEL', 1, 32, 9999, 1, 3, 42, 1367, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7213, '1998-04-24 22:00:00+00', '2018-04-03 00:08:26.759836+00', 'Withywindle, The', 'WITHYWINDLE', 3, 32, 9999, 1, 3, 42, 44, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7214, '1997-04-03 22:00:00+00', '2018-04-03 00:08:26.784869+00', 'Wm. Birse Esq.', 'WM BIRSE ESQ', 2, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7216, '2003-01-26 23:00:00+00', '2018-04-03 00:08:26.801509+00', 'Women''s Lib', 'WOMENS LIB', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7222, '1997-04-03 22:00:00+00', '2012-01-20 12:56:56.991288+00', 'Wooden Bridge, The', 'WOODEN BRIDGE', 2, 32, 9999, 1, 2, NULL, 108, '1979-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7224, '1997-09-17 22:00:00+00', '2012-01-20 12:56:57.005415+00', 'Woodhaven Chase', 'WOODHAVEN CHASE', 2, 32, 9999, 4, 4, NULL, 502, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7225, '1997-09-07 22:00:00+00', '2012-01-20 12:56:57.01233+00', 'Woodhaven Pier', 'WOODHAVEN PIER', 2, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7228, '1997-04-03 22:00:00+00', '2012-01-20 12:56:57.032855+00', 'Woodside Strathspey, The', 'WOODSIDE STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12505, '2005-08-21 22:00:00+00', '2012-01-20 12:57:38.855003+00', 'Caledonian Memory', 'CALEDONIAN MEMORY', 1, 88, 9999, 4, 4, NULL, 3618, '1999-01-01', 'Devised for teaching at the Edmonton Caledonian Society Workshop', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12548, '2005-10-11 22:00:00+00', '2012-01-20 12:57:39.264801+00', 'Every September', 'EVERY SEPTEMBER', 1, 32, 9999, 1, 4, NULL, 3637, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12507, '2005-08-21 22:00:00+00', '2012-01-20 12:57:38.873493+00', 'Craigdarroch Castle', 'CRAIGDARROCH CASTLE', 2, 32, 9999, 1, 3, 42, 3618, '1997-12-01', 'For a Burns Anniversary celebration at Craigdarroch Castle, Victoria B.C.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12509, '2005-08-21 22:00:00+00', '2012-01-20 12:57:38.892734+00', 'Spirit of Summer', 'SPIRIT OF SUMMER', 1, 40, 9999, 1, 100, 2, 3618, '1994-01-01', 'For the summer dancers in Victoria, B.C.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12510, '2005-08-21 22:00:00+00', '2012-01-20 12:57:38.902318+00', 'Tribute to the Twins', 'TRIBUTE TO THE TWINS', 3, 32, 9999, 3, 5, 7, 3618, '1996-01-01', 'For Vicky Simpson and het twin sister, Mary, on the occasion of their birthdays', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12513, '2005-08-21 22:00:00+00', '2012-01-20 12:57:38.930033+00', 'Northern Cruisers', 'NORTHERN CRUISERS', 4, 112, 18, 4, 4, NULL, 3618, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12514, '2005-08-26 22:00:00+00', '2012-01-20 12:57:38.939611+00', 'Double Dutch', 'DOUBLE DUTCH', 1, 32, 9999, 1, 4, 2, 108, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12515, '2005-08-26 22:00:00+00', '2012-01-20 12:57:38.948829+00', 'Flora''s Favourites', 'FLORAS FAVOURITES', 1, 40, 9999, 1, 4, NULL, 108, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7232, '1998-04-02 22:00:00+00', '2012-01-20 12:56:57.060284+00', 'Work of the Weaver, The', 'WORK OF THE WEAVER', 1, 92, 9999, 4, 4, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7236, '1997-04-03 22:00:00+00', '2012-01-20 12:56:57.088062+00', 'Wyn''s Jig', 'WYNS JIG', 2, 32, 9999, 1, 4, 1, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7237, '1997-09-17 22:00:00+00', '2012-01-20 12:56:57.094828+00', 'Wyndley Reel', 'WYNDLEY REEL', 1, 64, 9999, 5, 2, NULL, 313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12525, '2005-08-29 22:00:00+00', '2018-04-03 00:07:55.194799+00', 'Jenny Pluck Pears', 'JENNY PLUCK PEARS', 3, 32, 9999, 1, 3, 42, 172, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7244, '1998-01-05 23:00:00+00', '2012-01-20 12:56:57.14374+00', 'Ye''re No Awa'' Tae Bide Awa''', 'YERE NO AWA TAE BIDE AWA', 1, 32, 9999, 1, 4, NULL, 1370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7246, '1997-04-03 22:00:00+00', '2012-01-20 12:56:57.157442+00', 'Year of the Heart', 'YEAR OF THE HEART', 3, 32, 9999, 1, 4, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7250, '1997-09-17 22:00:00+00', '2012-01-20 12:56:57.184723+00', 'Yetts Of Muchart, The', 'YETTS OF MUCHART', 3, 32, 9999, 2, 3, NULL, 347, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12531, '2005-08-29 22:00:00+00', '2019-02-28 22:05:22.500442+00', 'Queen Elizabeth of Mey', 'QUEEN ELIZABETH OF MEY', 2, 40, 9999, 1, 4, 1, 534, NULL, '', 45, '8000/8440/8444/8400/8044', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7253, '1997-09-17 22:00:00+00', '2012-01-20 12:56:57.206114+00', 'Yoshi''s Farewell', 'YOSHIS FAREWELL', 3, 80, 9999, 4, 4, NULL, 1263, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7254, '1998-07-08 22:00:00+00', '2012-01-20 12:56:57.213576+00', 'You Go To Your Death', 'YOU GO TO YOUR DEATH', 2, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12519, '2005-08-29 22:00:00+00', '2020-04-12 20:47:11.956537+00', 'Bell Rock Reel, The', 'BELL ROCK REEL', 1, 40, 9999, 1, 3, 42, 3626, NULL, '', 49, '800/855/855/844/855', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12511, '2005-08-21 22:00:00+00', '2021-10-05 10:50:08.814312+00', 'Invigilator, The', 'INVIGILATOR', 2, 48, 9999, 4, 6, 98, 3618, '1999-06-01', 'Devised while invigilating 200 students (with 6 other teachers). The instructions suggest dancing this three times (3x48 jig music).', 56, '808088/505088/080888/888888/808000/060600', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12522, '2005-08-29 22:00:00+00', '2020-07-09 18:09:29.61248+00', 'Earl of Inverness, The', 'EARL OF INVERNESS', 2, 40, 9999, 4, 4, 4, 3711, NULL, '', 70, '8888/8080/0808/4444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7223, '1997-04-03 22:00:00+00', '2020-08-04 10:59:27.192026+00', 'Wooden Legged Whistler, The', 'WOODEN LEGGED WHISTLER', 1, 32, 9999, 1, 4, NULL, 99, NULL, '', 69, '8686/4844/4848/8080', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7190, '1997-04-03 22:00:00+00', '2022-10-23 20:55:08.181575+00', 'Winding Spey, The', 'WINDING SPEY', 3, 40, 9999, 1, 3, 42, 28, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7183, '1997-04-03 22:00:00+00', '2022-11-07 16:38:20.030579+00', 'Wind That Shakes The Piggery', 'WIND THAT SHAKES THE PIGGERY', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7207, '1997-04-03 22:00:00+00', '2020-08-07 10:37:34.775806+00', 'Witches'' Brew', 'WITCHES BREW', 1, 32, 9999, 4, 4, NULL, 151, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7211, '1997-09-10 22:00:00+00', '2021-05-30 11:43:38.902203+00', 'Without', 'WITHOUT', 1, 32, 9999, 1, 4, 1, 352, '1991-05-12', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12526, '2005-08-29 22:00:00+00', '2021-01-14 11:37:00.33517+00', 'Love Stricken', 'LOVE STRICKEN', 1, 32, 9999, 1, 4, 1, 3628, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7252, '2002-04-15 22:00:00+00', '2021-03-28 13:45:07.571914+00', 'York and North Humberside Strathspey', 'YORK AND NORTH HUMBERSIDE STRATHSPEY', 3, 32, 9999, 1, 4, 1, 1371, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7157, '2002-08-13 22:00:00+00', '2021-03-30 20:25:52.388183+00', 'Will Ye No'' Come Back Again', 'WILL YE NO COME BACK AGAIN', 3, 32, 9999, 1, 3, 42, 108, '1967-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18905, '2018-10-09 06:45:30.921357+00', '2021-06-08 09:40:37.688484+00', 'Taking Turns', 'TAKING TURNS', 1, 32, NULL, 1, 3, 42, 2766, '2009-01-01', '', 41, '844/844/800/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12521, '2005-08-29 22:00:00+00', '2019-02-28 22:16:27.950831+00', 'Blair Silver Jubilee, The', 'BLAIR SILVER JUBILEE', 3, 40, 9999, 1, 4, 2, 3627, NULL, '', 83, '8008/8448/8668/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7229, '1997-04-03 22:00:00+00', '2019-03-08 18:33:32.060705+00', 'Wootton Bridge', 'WOOTTON BRIDGE', 1, 48, 9999, 1, 4, 1, 3590, '1992-01-01', '', 54, '8000/8800/8880/8000/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7231, '1997-09-28 22:00:00+00', '2018-04-03 00:08:26.893246+00', 'Worden Welcome', 'WORDEN WELCOME', 1, 40, 9999, 1, 3, 42, 23, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12516, '2005-08-26 22:00:00+00', '2017-06-18 23:57:25.274321+00', 'Sharon''s Strathspey', 'SHARONS STRATHSPEY', 3, 32, 9999, 1, 2, 76, 108, '2004-01-01', 'For Sharon Brannon



Suggested music: *Mira River*, composed by Muriel Johnstone', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7230, '2002-04-15 22:00:00+00', '2019-06-12 22:56:01.679279+00', 'Worcester Permain', 'WORCESTER PERMAIN', 3, 32, 9999, 1, 3, 42, 108, '1989-01-01', '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7235, '1997-04-03 22:00:00+00', '2018-04-03 00:08:26.9351+00', 'Wrekin Havoc', 'WREKIN HAVOC', 1, 32, 9999, 1, 3, 42, 329, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7240, '2002-11-29 23:00:00+00', '2017-11-12 23:10:36.583212+00', 'Yarm Fair', 'YARM FAIR', 2, 32, 9999, 3, 5, NULL, 2616, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7248, '1997-04-03 22:00:00+00', '2018-04-03 00:08:27.018336+00', 'Yemen Reel, The', 'YEMEN REEL', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7241, '1997-09-17 22:00:00+00', '2018-04-03 00:08:27.035046+00', 'Ye Social Powers', 'YE SOCIAL POWERS', 3, 48, 9999, 1, 3, 42, 466, '1780-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7249, '1997-04-03 22:00:00+00', '2018-04-03 00:08:27.043412+00', 'Yetts o'' Muckhart, The', 'YETTS O MUCKHART', 2, 40, 9999, 1, 3, 42, 211, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7251, '1997-04-03 22:00:00+00', '2018-04-03 00:08:27.084971+00', 'York House', 'YORK HOUSE', 1, 32, 9999, 1, 3, 42, 676, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7255, '1997-04-03 22:00:00+00', '2018-04-03 00:08:27.101768+00', 'You Have Killed Your Prince', 'YOU HAVE KILLED YOUR PRINCE', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7238, '1997-09-17 22:00:00+00', '2019-09-15 19:12:55.924381+00', 'X Marks the Spot', 'X MARKS THE SPOT', 2, 40, 9999, 3, 5, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5158, '2001-10-25 22:00:00+00', '2018-04-29 22:24:03.059454+00', 'Pannaich Wells', 'PANNAICH WELLS', 3, 48, 9999, 2, 3, 17, 108, '1981-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14632, '2012-12-18 13:34:13.071665+00', '2012-12-18 13:34:13.071675+00', 'Dance Me to the End of Love', 'DANCE ME TO THE END OF LOVE', 1, 32, NULL, 1, 4, 1, 1089, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18733, '2018-10-04 08:17:39.062669+00', '2018-10-04 08:17:39.062669+00', 'Dipsy Doodle', 'DIPSY DOODLE', 1, 32, NULL, 1, 3, 42, 2766, '2013-01-01', 'As I was playing around with the figures in the dance, the name phrase dipsy doodle came into my mind, so that became the name of the dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7258, '1997-04-03 22:00:00+00', '2012-01-20 12:56:57.241109+00', 'Young Hero Of Tumbledown, The', 'YOUNG HERO OF TUMBLEDOWN', 3, 32, 9999, 1, 4, NULL, 353, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7263, '1998-07-08 22:00:00+00', '2012-01-20 12:56:57.278006+00', 'Your Ain Doorkey', 'YOUR AIN DOORKEY', 1, 32, 9999, 1, 4, 2, 82, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14620, '2012-12-17 23:59:35.202018+00', '2019-01-19 07:39:34.71711+00', 'Willow Bank, The', 'WILLOW BANK', 3, 32, NULL, 2, 3, 17, 10673, '2012-02-01', '', 75, '800/888/808/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7268, '1997-09-17 22:00:00+00', '2012-01-20 12:56:57.31214+00', 'Zephyrs And Flora', 'ZEPHYRS AND FLORA', 3, 32, 9999, 1, 2, NULL, 397, '1715-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7269, '1998-04-24 22:00:00+00', '2012-01-20 12:56:57.31903+00', 'Zip Up', 'ZIP UP', 2, 32, 9999, 1, 4, NULL, 108, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7271, '1997-08-26 22:00:00+00', '2012-01-20 12:56:57.332663+00', 'Swinging Jig', 'SWINGING JIG', 2, 48, 9999, 1, 4, NULL, 17, '1980-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12534, '2005-08-29 22:00:00+00', '2019-02-28 21:56:19.921087+00', 'Tartan Baggies', 'TARTAN BAGGIES', 1, 40, 9999, 1, 4, 1, 3630, NULL, '', 75, '8888/8000/8888/6262/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7276, '2002-01-08 23:00:00+00', '2012-01-20 12:56:57.369113+00', 'Delphine''s Delight', 'DELPHINES DELIGHT', 3, 32, 9999, 1, 4, NULL, 17, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7262, '2002-02-27 23:00:00+00', '2019-03-08 18:27:08.594422+00', 'Young Wilson''s Reel', 'YOUNG WILSONS REEL', 1, 32, 9999, 1, 4, 1, 513, NULL, '', 63, '8888/8000/8000/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7279, '1997-08-26 22:00:00+00', '2012-01-20 12:56:57.389696+00', 'Heart of the Highlands', 'HEART OF THE HIGHLANDS', 3, 32, 9999, 1, 4, NULL, 17, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7280, '2002-01-08 23:00:00+00', '2012-01-20 12:56:57.396526+00', 'Honour Your Partner', 'HONOUR YOUR PARTNER', 1, 48, 9999, 1, 4, NULL, 17, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7281, '2002-01-08 23:00:00+00', '2012-01-20 12:56:57.403418+00', 'Michael''s Ceilidh Band', 'MICHAELS CEILIDH BAND', 1, 32, 9999, 4, 4, NULL, 17, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12544, '2005-10-09 22:00:00+00', '2012-01-20 12:57:39.238749+00', 'Dance Willie Dance', 'DANCE WILLIE DANCE', 2, 32, 9999, 1, 4, 2, 515, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12546, '2005-10-11 22:00:00+00', '2012-01-20 12:57:39.251196+00', 'Chisholm''s Trail', 'CHISHOLMS TRAIL', 4, 128, 2, 8, 6, NULL, 3635, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12549, '2005-10-11 22:00:00+00', '2012-01-20 12:57:39.271652+00', 'Maggie of Braes Bayou', 'MAGGIE OF BRAES BAYOU', 3, 32, 9999, 3, 5, NULL, 3638, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7278, '2006-08-30 22:00:00+00', '2012-05-01 22:09:30.105214+00', 'Mary McLeod''s Reel', 'MARY MACLEODS REEL', 1, 32, 9999, 1, 3, 42, 979, '2006-01-01', 'For her mother''s 80th birthday on 27 July 2006', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7286, '2002-01-08 23:00:00+00', '2012-10-14 23:45:39.036273+00', 'Moulin Rouge, Le', 'MOULIN ROUGE', 1, 64, 9999, 4, 4, 3, 70, NULL, 'The following corrections were included on a loose sheet "Notes on Dances by Bob Grant June 1996", when Book 39 was first sold in the Summer School bookshop:



1-8  Men must come out of the 4 hands round quickly to get round partners in time



17-24  At the end the men are back to back in the middle



53-56  Women keep turning so that they actually face anticlockwise



See also the "notes for dances" in the Manual (2005), and the partially disagreeing TACnotes', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7287, '2002-01-08 23:00:00+00', '2012-01-20 12:56:57.447282+00', 'Kirkintilloch', 'KIRKINTILLOCH', 3, 32, 9999, 2, 3, 18, 17, '1989-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7294, '1998-01-04 23:00:00+00', '2012-01-20 12:56:57.501264+00', 'Allansford Strathspey, The', 'ALLANSFORD STRATHSPEY', 3, 64, 9999, 4, 4, NULL, 42, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12545, '2005-10-09 22:00:00+00', '2020-07-26 08:14:10.951645+00', 'Jig for Pudsey Bear, A', 'JIG FOR PUDSEY BEAR', 2, 32, 9999, 5, 2, NULL, 3634, '1997-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7273, '2001-05-20 22:00:00+00', '2020-09-04 13:32:50.256847+00', 'Tribute to the Basques', 'TRIBUTE TO THE BASQUES', 2, 32, 9999, 1, 3, 42, 17, '1995-01-01', '', 50, '800/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12535, '2005-08-29 22:00:00+00', '2021-01-14 00:40:31.835114+00', 'Who Cares', 'WHO CARES', 2, 32, 9999, 3, 5, 16, 2673, NULL, '', 62, '88088/84048/40804/60688', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12529, '2005-08-29 22:00:00+00', '2021-01-14 00:46:32.140777+00', 'Nae Chance', 'NAE CHANCE', 3, 40, 9999, 4, 4, 13, 2673, NULL, '', 80, '8080/8888/0808/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12524, '2005-08-29 22:00:00+00', '2021-01-14 11:39:27.635308+00', 'Glenesk', 'GLENESK', 2, 32, 9999, 1, 100, 2, 2673, NULL, '', 56, '4444/8008/4884/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12523, '2005-08-29 22:00:00+00', '2021-01-14 11:52:23.24076+00', 'Glasgow Skye Reel', 'GLASGOW SKYE REEL', 1, 32, 9999, 1, 100, 2, 2673, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7272, '2001-12-16 23:00:00+00', '2022-10-23 20:38:33.661167+00', 'Alister''s Reel', 'ALISTERS REEL', 1, 32, 9999, 1, 3, 42, 265, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7259, '1998-10-21 22:00:00+00', '2022-12-18 22:43:48.049268+00', 'Young Man''s Dream, The', 'YOUNG MANS DREAM', 1, 48, 9999, 1, 4, NULL, 44, '1969-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12517, '2005-08-29 22:00:00+00', '2021-01-14 11:54:06.363351+00', 'Angel Mounds Reel, The', 'ANGEL MOUNDS REEL', 1, 32, 9999, 1, 3, 42, 3309, NULL, '', 50, '800/888/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7260, '1997-09-17 22:00:00+00', '2021-03-28 13:06:35.268879+00', 'Young Pretender, The', 'YOUNG PRETENDER', 2, 32, 9999, 8, 6, 90, 313, NULL, '', 92, '808808/888888/888888/888888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7289, '2006-03-07 23:00:00+00', '2021-03-28 13:01:17.788884+00', 'We Twa Encore', 'WE TWA ENCORE', 3, 32, NULL, 1, 3, 42, 370, NULL, '', 50, '800/844/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7270, '1997-09-17 22:00:00+00', '2021-04-08 14:00:53.361643+00', 'Zutyazelph', 'ZUTYAZELPH', 4, 48, 10052, 3, 5, 16, 270, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15473, '2014-06-17 00:51:13.221311+00', '2014-06-17 00:51:13.221311+00', 'Carse of Stirling, The', 'CARSE OF STIRLING', 1, 32, 9999, 1, 3, 42, 386, '1973-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7298, '2002-01-08 23:00:00+00', '2012-01-20 12:56:57.533071+00', 'Circassian Jig', 'CIRCASSIAN JIG', 2, 32, 9999, 5, 2, NULL, 17, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7277, '2002-01-08 23:00:00+00', '2018-04-03 00:07:44.686137+00', 'Erskine Bridge', 'ERSKINE BRIDGE', 1, 32, 9999, 1, 3, 42, 17, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7290, '1997-12-02 23:00:00+00', '2018-04-03 00:07:30.09202+00', 'Allana''s Jig', 'ALLANAS JIG', 2, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7274, '2006-03-07 23:00:00+00', '2017-07-02 19:48:04.788906+00', 'Horsewells Jig', 'HORSEWELLS JIG', 2, 32, 9999, 1, 3, 42, 370, '2003-01-01', '', 50, '804/480/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12540, '2005-10-09 22:00:00+00', '2018-04-03 00:07:44.86114+00', 'Expanding Circles', 'EXPANDING CIRCLES', 3, 32, 9999, 1, 3, 42, 3374, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12541, '2005-10-09 22:00:00+00', '2018-04-03 00:07:46.896525+00', 'Frederick Frolic, The', 'FREDERICK FROLIC', 2, 40, 9999, 1, 3, 42, 3374, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12537, '2005-09-24 22:00:00+00', '2018-04-03 00:07:55.086472+00', 'Jeanette''s Joy', 'JEANETTES JOY', 2, 40, 9999, 1, 3, 42, 3632, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7275, '2002-01-08 23:00:00+00', '2018-04-03 00:08:03.759799+00', 'Mirkwood Mere', 'MIRKWOOD MERE', 3, 32, 9999, 1, 3, 42, 17, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12536, '2005-09-09 22:00:00+00', '2018-04-03 00:08:10.832029+00', 'Pipes and Drums', 'PIPES AND DRUMS', 2, 32, 9999, 1, 3, 42, 3631, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7291, '2002-01-08 23:00:00+00', '2018-04-03 00:08:12.099649+00', 'Raphael''s Rant', 'RAPHAELS RANT', 1, 40, 9999, 1, 3, 42, 17, '1985-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7292, '1997-08-26 22:00:00+00', '2018-04-03 00:08:12.925167+00', 'Rhone Valley Reel', 'RHONE VALLEY REEL', 1, 40, 9999, 1, 3, 42, 17, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12543, '2005-10-09 22:00:00+00', '2018-04-03 00:08:13.367336+00', 'Rob Brown''s Reel', 'ROB BROWNS REEL', 1, 32, 9999, 1, 3, 42, 515, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7266, '1997-04-03 22:00:00+00', '2018-04-03 00:08:27.176851+00', 'Ythan Bar', 'YTHAN BAR', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18713, '2018-10-03 02:14:36.01099+00', '2018-10-03 02:14:36.01099+00', 'Cloak of Invisibility, The', 'CLOAK OF INVISIBILITY', 3, 32, NULL, 1, 3, 42, 2766, '2015-04-01', 'This dance is written especially for a Harry Potter themed dance night.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7303, '2002-01-08 23:00:00+00', '2012-01-20 12:56:57.571116+00', 'Flowers by the Loch', 'FLOWERS BY THE LOCH', 3, 32, 9999, 2, 3, 18, 17, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7326, '2006-03-23 23:00:00+00', '2018-12-17 20:02:04.003304+00', 'Burlington Bay', 'BURLINGTON BAY', 3, 32, 9999, 2, 3, 17, 403, NULL, '', 75, '800/888/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7306, '1997-08-26 22:00:00+00', '2012-01-20 12:56:57.594748+00', 'Glendaruel Square', 'GLENDARUEL SQUARE', 1, 32, 9999, 4, 4, NULL, 17, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7307, '1997-08-26 22:00:00+00', '2012-01-20 12:56:57.601744+00', 'Infidelity', 'INFIDELITY', 1, 32, 9999, 1, 4, NULL, 17, '1982-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7308, '1997-08-26 22:00:00+00', '2012-01-20 12:56:57.608644+00', 'Jamalfna', 'JAMALFNA', 2, 48, 9999, 1, 4, NULL, 17, '1969-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12558, '2005-10-12 22:00:00+00', '2018-04-03 00:07:29.707097+00', 'After Hours', 'AFTER HOURS', 3, 32, 9999, 1, 3, 42, 2998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7322, '2006-03-23 23:00:00+00', '2018-04-03 00:07:30.385181+00', 'Ancaster Mill, The', 'ANCASTER MILL', 2, 32, 9999, 1, 3, 42, 2115, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12552, '2005-10-11 22:00:00+00', '2012-01-20 12:57:39.291322+00', 'Star of Texas, The', 'STAR OF TEXAS', 1, 40, 9999, 3, 5, NULL, 3641, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12554, '2005-10-11 22:00:00+00', '2012-01-20 12:57:39.304969+00', 'Wimberley Willie', 'WIMBERLEY WILLIE', 2, 40, 9999, 1, 4, NULL, 3640, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7301, '2006-03-07 23:00:00+00', '2019-06-04 15:22:09.401297+00', 'Gábor''s Wedding', 'GABORS WEDDING', 3, 40, 9999, 2, 3, 17, 3662, '2002-01-01', '', 93, '888/888/888/848/848', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12557, '2005-10-12 22:00:00+00', '2012-01-20 12:57:39.32549+00', 'Insignificant Foolishness', 'INSIGNIFICANT FOOLISHNESS', 3, 32, 9999, 1, 2, NULL, 2998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12559, '2005-10-12 22:00:00+00', '2012-01-20 12:57:39.33923+00', 'Middleton-Shore Strathspey, The', 'MIDDLETONSHORE STRATHSPEY', 3, 48, 9999, 4, 4, NULL, 3642, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12560, '2005-10-12 22:00:00+00', '2012-01-20 12:57:39.34633+00', 'Committee''s Decision, The', 'COMMITTEES DECISION', 2, 48, 9999, 1, 4, NULL, 3642, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12561, '2005-10-12 22:00:00+00', '2012-01-20 12:57:39.353301+00', 'Welcome to Fort San', 'WELCOME TO FORT SAN', 3, 32, 9999, 1, 4, NULL, 3643, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12562, '2005-10-12 22:00:00+00', '2012-01-20 12:57:39.360429+00', 'River Tay', 'RIVER TAY', 2, 32, 9999, 1, 4, NULL, 3643, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12563, '2005-10-12 22:00:00+00', '2012-01-20 12:57:39.367462+00', 'Hangover', 'HANGOVER', 1, 32, 9999, 1, 4, NULL, 3643, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7314, '2006-03-18 23:00:00+00', '2012-01-20 12:56:57.653418+00', 'Wickstead Delight', 'WICKSTEAD DELIGHT', 99, 0, 9999, 4, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7315, '1997-12-03 23:00:00+00', '2012-01-20 12:56:57.660306+00', 'Pentagon', 'PENTAGON', 2, 32, 9999, 7, 5, NULL, 17, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7320, '2002-01-08 23:00:00+00', '2012-01-20 12:56:57.696633+00', 'Scots around the World', 'SCOTS AROUND THE WORLD', 1, 32, 9999, 3, 5, 4, 17, '1989-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7321, '1997-09-14 22:00:00+00', '2012-01-20 12:56:57.705674+00', 'Tarry in Tucson', 'TARRY IN TUCSON', 1, 32, 9999, 1, 4, NULL, 1283, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7323, '1997-08-26 22:00:00+00', '2012-01-20 12:56:57.719316+00', 'Thirtieth of October', 'THIRTIETH OF OCTOBER', 2, 32, 9999, 1, 4, NULL, 17, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7324, '1997-08-26 22:00:00+00', '2012-01-20 12:56:57.726241+00', 'Spring in the Cairngorms', 'SPRING IN THE CAIRNGORMS', 3, 32, 9999, 4, 4, NULL, 17, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7328, '2006-03-23 23:00:00+00', '2012-01-20 12:56:57.753867+00', 'Debbie''s Chase', 'DEBBIES CHASE', 2, 32, 9999, 1, 2, NULL, 3666, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7330, '1997-08-26 22:00:00+00', '2012-01-20 12:56:57.767644+00', '17th February', '17TH FEBRUARY', 1, 32, 9999, 1, 4, NULL, 17, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7341, '2002-11-26 23:00:00+00', '2012-01-20 12:56:57.869366+00', 'Aracos', 'ARACOS', 1, 32, 9999, 1, 2, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7342, '1998-01-04 23:00:00+00', '2012-01-20 12:56:57.878027+00', 'Aries Strathspey', 'ARIES STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 441, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12564, '2005-10-12 22:00:00+00', '2012-01-20 12:57:39.37477+00', 'Haggis on the Window', 'HAGGIS ON THE WINDOW', 3, 128, 9999, 4, 4, NULL, 204, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7305, '2002-01-06 23:00:00+00', '2018-04-03 00:07:37.587483+00', 'Ceilidh in the Clachan', 'CEILIDH IN THE CLACHAN', 1, 32, 9999, 1, 3, 42, 17, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12575, '2005-11-01 23:00:00+00', '2012-01-20 12:57:39.465097+00', 'Rhinns of Islay, The', 'RHINNS OF ISLAY', 3, 32, 9999, 1, 4, NULL, 13, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12551, '2005-10-11 22:00:00+00', '2016-09-23 22:05:00.492661+00', 'Bluebonnet Trail, The', 'BLUEBONNET TRAIL', 2, 32, 9999, 1, 3, 42, 3640, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12568, '2005-10-20 22:00:00+00', '2021-01-13 20:40:50.801706+00', 'Short and Very Sweet', 'SHORT AND VERY SWEET', 2, 32, 9999, 2, 3, 17, 2682, '2004-01-01', '', 67, '800/888/880/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7319, '2002-01-08 23:00:00+00', '2021-01-23 23:37:50.807942+00', 'Ross Strathspey', 'ROSS STRATHSPEY', 3, 32, 9999, 2, 3, 18, 17, '1993-01-01', '<<scddb-not-identical:12671>>', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7340, '2002-03-03 23:00:00+00', '2021-03-27 12:26:01.553599+00', 'Ansey Strathspey', 'ANSEY STRATHSPEY', 3, 32, 9999, 1, 4, 2, 1, '1978-05-01', '', 72, '8228/8888/4004/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7300, '2006-03-07 23:00:00+00', '2021-03-27 16:21:02.893013+00', 'First Ray of the Sun', 'FIRST RAY OF THE SUN', 2, 32, 9999, 1, 2, 76, 3661, '2002-01-01', '', 69, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7297, '2006-03-07 23:00:00+00', '2021-03-28 12:44:58.243539+00', 'Donau Strathspey, The', 'DONAU STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3660, '2003-01-01', '', 47, '444/800/880/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7295, '2002-01-08 23:00:00+00', '2022-10-23 20:36:45.671205+00', 'Schauchlin Jamie', 'SCHAUCHLIN JAMIE', 2, 32, 9999, 1, 3, 42, 17, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7257, '1997-09-17 22:00:00+00', '2021-03-28 13:11:50.510624+00', 'Young Chevalier, The', 'YOUNG CHEVALIER', 3, 32, 9999, 1, 3, 42, 1372, NULL, '', 63, '888/880/884/848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7256, '1997-09-08 22:00:00+00', '2021-03-28 13:21:38.841898+00', 'Mary''s Strathspey', 'MARYS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 693, NULL, '', 53, '840/880/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7264, '1998-04-24 22:00:00+00', '2021-06-12 23:44:57.124921+00', 'Your Turn Next', 'YOUR TURN NEXT', 1, 32, 9999, 1, 3, 42, 352, '1993-04-17', '', 44, '844/844/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12571, '2005-10-26 22:00:00+00', '2018-04-03 00:07:55.636898+00', 'Jill''s Dental Jig', 'JILLS DENTAL JIG', 2, 40, 9999, 1, 3, 42, 2682, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12555, '2005-10-12 22:00:00+00', '2018-04-03 00:08:17.478292+00', 'Snow Flurry Jig', 'SNOW FLURRY JIG', 2, 32, 9999, 1, 3, 42, 2998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7299, '2002-01-08 23:00:00+00', '2018-04-03 00:07:40.972223+00', 'Dancers Anonymous', 'DANCERS ANONYMOUS', 1, 32, 9999, 1, 3, 42, 17, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7309, '1997-08-26 22:00:00+00', '2018-04-03 00:07:57.896993+00', 'Ladies First', 'LADIES FIRST', 2, 32, 9999, 1, 3, 42, 17, '1986-01-01', 'There is a variant by Martin Sheffield called "Ladies and Lads", differing in the first 8 bars.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12553, '2005-10-11 22:00:00+00', '2018-04-03 00:08:00.407248+00', 'Longhorn Haggis', 'LONGHORN HAGGIS', 1, 32, 9999, 1, 3, 42, 3635, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12556, '2005-10-12 22:00:00+00', '2018-04-03 00:08:12.991869+00', 'Rick''s Farewell to Saskatoon', 'RICKS FAREWELL TO SASKATOON', 1, 40, 9999, 1, 3, 42, 2998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12573, '2005-10-27 22:00:00+00', '2018-04-03 00:08:19.171258+00', 'Summer with McKinnon', 'SUMMER WITH MACKINNON', 3, 32, 9999, 1, 3, 42, 2682, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7325, '1997-12-03 23:00:00+00', '2018-04-03 00:08:22.640165+00', 'Trip to the Atlas', 'TRIP TO THE ATLAS', 2, 32, 9999, 1, 3, 42, 17, '1977-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7327, '2002-01-08 23:00:00+00', '2018-04-03 00:08:24.274578+00', 'Ways and Means', 'WAYS AND MEANS', 1, 32, 9999, 1, 3, 42, 17, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12565, '2005-10-12 22:00:00+00', '2018-04-03 00:08:24.824797+00', 'Wellington Rant', 'WELLINGTON RANT', 2, 32, 9999, 1, 3, 42, 204, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12570, '2005-10-20 22:00:00+00', '2018-04-03 00:08:24.833139+00', 'We''ll Meet Again', 'WELL MEET AGAIN', 2, 32, 9999, 1, 3, 42, 2682, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7317, '2006-03-22 23:00:00+00', '2018-04-03 00:08:25.366954+00', 'Whisky Mac', 'WHISKY MAC', 2, 32, 9999, 1, 3, 42, 531, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7329, '2002-01-08 23:00:00+00', '2018-04-03 00:08:26.743316+00', 'With the Malt abo'' the Meal', 'WITH THE MALT ABO THE MEAL', 2, 32, 9999, 1, 3, 42, 17, '1989-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7343, '2002-11-26 23:00:00+00', '2018-12-16 16:43:56.88411+00', 'At the Studio', 'AT THE STUDIO', 2, 32, 9999, 2, 3, NULL, 3566, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7345, '1998-01-04 23:00:00+00', '2012-01-20 12:56:57.901435+00', 'Autumn Serenade', 'AUTUMN SERENADE', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7346, '2002-11-26 23:00:00+00', '2012-01-20 12:56:57.908214+00', 'Avalon', 'AVALON', 1, 16, 9999, 1, 2, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7347, '1998-01-05 23:00:00+00', '2012-01-20 12:56:57.915295+00', 'Avon Reel, The', 'AVON REEL', 1, 32, 9999, 5, 2, NULL, 441, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7358, '1998-01-04 23:00:00+00', '2019-03-08 17:30:04.309689+00', 'Castle Square', 'CASTLE SQUARE', 3, 32, 9999, 4, 4, 13, 1, '1995-01-01', 'The dance is named after the town square in Caernafon, North Wales, which is overlooked by the imposing castle built by Edward I in the 13th century', 72, '4444/4444/7777/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7361, '2002-11-26 23:00:00+00', '2012-01-20 12:56:58.012131+00', 'Celtic Drum, The', 'CELTIC DRUM', 1, 32, 9999, 1, 2, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7363, '2002-04-19 22:00:00+00', '2012-01-20 12:56:58.026743+00', 'Chief o''Scotia''s Food', 'CHIEF OSCOTIAS FOOD', 3, 32, 9999, 2, 3, 17, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7378, '1998-09-23 22:00:00+00', '2019-10-18 13:19:13.887322+00', 'Diamond Strathspey', 'DIAMOND STRATHSPEY', 3, 32, 9999, 1, 3, 42, 352, '1995-06-08', '', 58, '808/848/848/864', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12578, '2005-11-01 23:00:00+00', '2012-01-20 12:57:39.491123+00', 'All For One', 'ALL FOR ONE', 3, 32, 9999, 2, 3, NULL, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7344, '1999-01-03 23:00:00+00', '2018-04-03 00:07:31.638051+00', 'Auld Toon of Ayr', 'AULD TOON OF AYR', 3, 32, 9999, 1, 3, 42, 480, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12581, '2005-11-01 23:00:00+00', '2012-01-20 12:57:39.517444+00', 'Claymore and Thistle', 'CLAYMORE AND THISTLE', 1, 32, 9999, 1, 2, NULL, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12582, '2005-12-21 23:00:00+00', '2012-01-20 12:57:39.526114+00', 'Saint Catherine Strathspey', 'SAINT CATHERINE STRATHSPEY', 3, 80, 9999, 4, 4, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12588, '2005-11-01 23:00:00+00', '2012-01-20 12:57:39.577968+00', 'Kitty Blossom', 'KITTY BLOSSOM', 3, 32, 9999, NULL, 3, NULL, 3646, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7371, '1998-01-04 23:00:00+00', '2012-01-20 12:56:58.08164+00', 'Columba''s Isle', 'COLUMBAS ISLE', 3, 32, 9999, 6, 3, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7372, '1997-04-04 22:00:00+00', '2012-01-20 12:56:58.089327+00', 'Come Dance with Me', 'COME DANCE WITH ME', 1, 40, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7374, '1997-08-31 22:00:00+00', '2012-01-20 12:56:58.103335+00', 'Courting, The', 'COURTING', 1, 72, 9999, 7, 5, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7379, '1998-09-23 22:00:00+00', '2012-01-20 12:56:58.13862+00', 'Dolmen, The', 'DOLMEN', 1, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7380, '1997-12-03 23:00:00+00', '2012-01-20 12:56:58.1456+00', 'Dominie, The', 'DOMINIE', 2, 32, 9999, 1, 4, NULL, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7384, '1998-04-24 22:00:00+00', '2012-01-20 12:56:58.17426+00', 'Dream Time', 'DREAM TIME', 1, 32, 9999, 1, 4, NULL, 352, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7354, '1998-01-04 23:00:00+00', '2018-04-03 00:07:35.309342+00', 'Boy and the Adder, The', 'BOY AND THE ADDER', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7390, '1997-04-04 22:00:00+00', '2012-01-20 12:56:58.227302+00', 'Esk''s Clear River, The', 'ESKS CLEAR RIVER', 1, 32, 9999, 2, 3, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7393, '1997-12-28 23:00:00+00', '2012-01-20 12:56:58.249816+00', 'Feminine Majority', 'FEMININE MAJORITY', 3, 96, 9999, 4, 98, NULL, 441, NULL, '4 men, 8 ladies', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12580, '2005-11-01 23:00:00+00', '2017-01-22 00:56:19.504415+00', 'Billabong Birl', 'BILLABONG BIRL', 2, 32, 9999, 1, 3, 42, 2961, '2005-01-01', '', 50, '800/844/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7359, '1997-12-27 23:00:00+00', '2017-03-16 11:18:12.626426+00', 'All Square at the 40th', 'ALL SQUARE AT THE 40TH', 4, 80, 4, 4, 4, 3, 1228, '1992-01-01', 'For the Brighton and Hove Club on the occasion of their 40th anniversary Tartan Ball 9th May 1992', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7357, '2002-11-26 23:00:00+00', '2018-04-03 00:07:36.544202+00', 'Calling It Off Strathspey', 'CALLING IT OFF STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3565, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7365, '1997-12-02 23:00:00+00', '2018-04-03 00:07:38.36369+00', 'Christie MacLeod', 'CHRISTIE MACLEOD', 2, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7954, '1997-12-03 23:00:00+00', '2012-01-20 12:57:02.590248+00', 'SouthSea Castle', 'SOUTHSEA CASTLE', 2, 64, 9999, 2, 3, NULL, 774, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12587, '2005-11-01 23:00:00+00', '2021-01-13 20:24:31.230165+00', 'Insomnia', 'INSOMNIA', 3, 32, 9999, 1, 2, 76, 3502, NULL, '', 64, '66/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12577, '2005-11-01 23:00:00+00', '2021-01-13 20:32:06.3006+00', 'Dragonfly', 'DRAGONFLY', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', 56, '880/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7385, '1998-10-18 22:00:00+00', '2021-03-27 00:06:58.926322+00', 'Drummer''s Daunder', 'DRUMMERS DAUNDER', 2, 32, 9999, 3, 5, 16, 118, '1996-01-01', '', 82, '80408/88888/88888/80888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7336, '1998-01-05 23:00:00+00', '2021-03-27 12:50:20.946129+00', 'Alasdair''s Reel', 'ALASDAIRS REEL', 1, 32, 9999, 1, 4, 2, 154, NULL, '"For my son Alasdair."', 66, '8008/6666/6886/8008', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7356, '1998-01-05 23:00:00+00', '2021-03-27 00:21:25.270838+00', 'Caernangle Reel', 'CAERNANGLE REEL', 1, 32, 9999, 1, 4, 11, 1, '1993-01-01', '"Devised to mark the 40th anniversary of the Caernarfonshire and Anglesey Caledonian Society, 1993."', 88, '4884/8888/8448/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7348, '2002-04-24 22:00:00+00', '2021-03-27 11:26:27.549281+00', 'Back to Dundee', 'BACK TO DUNDEE', 3, 32, 9999, 1, 3, 42, 173, '1992-09-23', '', 66, '888/888/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7408, '2002-11-26 23:00:00+00', '2018-04-03 00:07:49.999679+00', 'Green Man, The', 'GREEN MAN', 1, 24, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7364, '1997-04-04 22:00:00+00', '2022-08-20 19:33:33.58644+00', 'Chris Pollard''s Reel', 'CHRIS POLLARDS REEL', 1, 40, 9999, 1, 3, 42, 173, '1979-08-22', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7373, '1999-01-03 23:00:00+00', '2022-10-23 20:12:10.512003+00', 'Cool as a Cucumber', 'COOL AS A CUCUMBER', 2, 32, 9999, 2, 3, 17, 480, '1994-04-19', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7352, '1998-10-18 22:00:00+00', '2022-10-23 20:30:47.092645+00', 'Bobby''s Favourite', 'BOBBYS FAVOURITE', 1, 32, 9999, 1, 4, 1, 394, '1996-12-01', '', 53, '8880/8000/8088/8004', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7333, '1997-08-26 22:00:00+00', '2021-03-27 15:49:46.287569+00', '13th of September', '13TH OF SEPTEMBER', 1, 32, 9999, 1, 3, 42, 17, '1991-01-01', '"Devised for my daughter''s birthday."', 50, '800/888/866/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7304, '2006-03-07 23:00:00+00', '2021-03-27 16:16:28.474886+00', 'Perpetuum Mobile', 'PERPETUUM MOBILE', 2, 40, 9999, 1, 4, 2, 3663, '2002-01-01', '', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7367, '1998-01-04 23:00:00+00', '2018-04-03 00:07:38.488805+00', 'Circle of Light', 'CIRCLE OF LIGHT', 3, 24, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7370, '2002-11-26 23:00:00+00', '2018-04-03 00:07:39.114506+00', 'Collie Wobbles', 'COLLIE WOBBLES', 2, 32, 9999, 1, 3, 42, 3567, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7381, '1997-04-04 22:00:00+00', '2018-04-03 00:07:42.592762+00', 'Dorothy and Dianne Miles', 'DOROTHY AND DIANNE MILES', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12583, '2005-11-01 23:00:00+00', '2018-04-03 00:07:42.734451+00', 'Double Dragon', 'DOUBLE DRAGON', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7383, '1997-04-04 22:00:00+00', '2018-04-03 00:07:42.984646+00', 'Dream On', 'DREAM ON', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7386, '1998-01-05 23:00:00+00', '2018-04-03 00:07:43.526685+00', 'Dun Fuinary', 'DUN FUINARY', 1, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7391, '2002-11-26 23:00:00+00', '2018-04-03 00:07:44.794444+00', 'Evergreen Oak, The', 'EVERGREEN OAK', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7394, '1997-04-04 22:00:00+00', '2018-04-03 00:07:45.643291+00', 'Fiddler, The', 'FIDDLER', 1, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7392, '1997-09-02 22:00:00+00', '2018-04-03 00:07:46.980005+00', 'Friday Night, Clive', 'FRIDAY NIGHT CLIVE', 1, 32, 9999, 1, 3, 42, 329, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12585, '2005-11-01 23:00:00+00', '2018-04-03 00:07:47.446923+00', 'Fyre and Flask', 'FYRE AND FLASK', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12586, '2005-11-01 23:00:00+00', '2018-04-03 00:07:47.464801+00', 'Fyrefly Reel', 'FYREFLY REEL', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12589, '2005-11-01 23:00:00+00', '2018-04-03 00:07:57.8134+00', 'Kodi''s Jig', 'KODIS JIG', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12590, '2005-11-01 23:00:00+00', '2018-04-03 00:07:59.206487+00', 'L''Chaim', 'LCHAIM', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12591, '2005-11-01 23:00:00+00', '2018-04-03 00:07:59.506705+00', 'Lighthouse', 'LIGHTHOUSE', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12592, '2005-11-01 23:00:00+00', '2018-04-03 00:08:01.466452+00', 'Mad Jack', 'MAD JACK', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13205, '2006-12-11 23:00:00+00', '2018-10-03 08:37:38.832317+00', 'Cloverleaf Reel, The', 'CLOVERLEAF REEL', 3, 32, 9999, 1, 100, 2, 2766, '2005-08-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19019, '2018-10-19 20:17:00.705066+00', '2018-10-20 17:18:59.818994+00', 'Morna''s Medley', 'MORNAS MEDLEY', 4, 32, 1, 1, 3, 42, 881, '1994-01-01', '', 55, '880/820/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7398, '1997-04-05 22:00:00+00', '2012-01-20 12:56:58.284558+00', 'Flower of Scottish Soil, The', 'FLOWER OF SCOTTISH SOIL', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7400, '1998-10-19 22:00:00+00', '2012-01-20 12:56:58.298126+00', 'Johnstone Rant, The', 'JOHNSTONE RANT', 1, 32, 9999, 1, 4, NULL, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7421, '1998-09-23 22:00:00+00', '2018-12-22 23:36:26.823868+00', 'All the Lads They Smile at Me', 'ALL THE LADS THEY SMILE AT ME', 2, 48, 9999, 1, 112, 30, 624, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7396, '1997-04-04 22:00:00+00', '2018-04-03 00:07:46.221043+00', 'Florence Adams', 'FLORENCE ADAMS', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12597, '2005-11-01 23:00:00+00', '2012-01-20 12:57:39.654812+00', 'Song of the Selkie', 'SONG OF THE SELKIE', 3, 32, 9999, 2, 3, NULL, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12598, '2005-11-01 23:00:00+00', '2012-01-20 12:57:39.663446+00', 'Shunt', 'SHUNT', 1, 40, 9999, 1, 4, NULL, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7414, '1997-12-27 23:00:00+00', '2019-03-08 12:28:52.597791+00', 'Helen''s Wedding', 'HELENS WEDDING', 4, 64, 5, 1, 4, 14, 1, '1985-06-15', '', 78, '8888/8004/8004/8888/8448/4884/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7404, '1997-04-10 22:00:00+00', '2019-03-08 16:42:05.46271+00', 'George Stirrat''s Rant', 'GEORGE STIRRATS RANT', 3, 32, 9999, 1, 4, 1, 146, NULL, '', 75, '8888/4444/6666/8088', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7402, '1997-04-04 22:00:00+00', '2012-01-20 12:56:58.311869+00', 'Friendship Reel, The', 'FRIENDSHIP REEL', 1, 40, 9999, 1, 4, NULL, 441, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7401, '1998-01-05 23:00:00+00', '2019-03-08 16:58:14.483135+00', 'Friars Reel', 'FRIARS REEL', 1, 32, 9999, 1, 3, 42, 930, NULL, '', 53, '800/888/822/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7405, '1997-04-04 22:00:00+00', '2012-01-20 12:56:58.33343+00', 'Ghillies'' Rant, The', 'GHILLIES RANT', 1, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7407, '2000-10-08 22:00:00+00', '2012-01-20 12:56:58.350702+00', 'Granite City Strathspey, The', 'GRANITE CITY STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12606, '2005-11-08 23:00:00+00', '2019-07-26 19:57:31.773918+00', 'Irish Maid, An', 'IRISH MAID', 3, 32, 9999, 2, 3, 17, 3647, NULL, '', 75, '800/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7410, '1997-12-03 23:00:00+00', '2012-01-20 12:56:58.37206+00', 'Hardy Scot, A', 'HARDY SCOT', 2, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7413, '1998-04-24 22:00:00+00', '2012-01-20 12:56:58.392933+00', 'Heather Harvest', 'HEATHER HARVEST', 1, 40, 9999, 1, 4, NULL, 352, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7417, '1997-04-04 22:00:00+00', '2012-01-20 12:56:58.424313+00', 'Hero''s Welcome', 'HEROS WELCOME', 3, 32, 9999, 2, 3, NULL, 3565, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7422, '1998-09-23 22:00:00+00', '2012-01-20 12:56:58.460397+00', 'Hotspots, The', 'HOTSPOTS', 3, 32, 9999, 1, 4, NULL, 360, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7424, '1997-12-28 23:00:00+00', '2012-01-20 12:56:58.474156+00', 'In Royal Circles', 'IN ROYAL CIRCLES', 2, 32, 9999, 5, 2, NULL, 441, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7427, '1997-04-04 22:00:00+00', '2012-01-20 12:56:58.494949+00', 'Initial', 'INITIAL', 1, 32, 9999, 2, 3, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12604, '2005-11-02 23:00:00+00', '2012-01-20 12:57:39.716012+00', 'They Stole My Wife From Me Last Night', 'THEY STOLE MY WIFE FROM ME LAST NIGHT', 3, 128, 9999, 4, 4, NULL, 2682, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12605, '2005-11-02 23:00:00+00', '2012-01-20 12:57:39.725654+00', 'Fyreladdie, The', 'FYRELADDIE', 2, 32, 9999, 1, 4, 11, 2682, '2005-09-13', 'Devised in Wellington. This is an advanced dance inspired by some of Alec Hay''s dances. Alec of course was the New Zealand deviser who gave us set and link, amongst other formations. Given to Bob McMurtry, "the

fyreladdie," from Santa Cruz. Bob is a fine deviser of both dances and music.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14638, '2013-01-02 16:34:14.003842+00', '2013-01-02 16:34:14.003853+00', 'Annan Tribute', 'ANNAN TRIBUTE', 1, 32, 9999, NULL, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7430, '1997-12-28 23:00:00+00', '2012-01-20 12:56:58.515648+00', 'Jane Alexandra''s Medley', 'JANE ALEXANDRAS MEDLEY', 4, 128, 2, 1, 4, NULL, 441, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7434, '1997-12-28 23:00:00+00', '2012-01-20 12:56:58.544219+00', 'Kalahari Kaper', 'KALAHARI KAPER', 1, 96, 9999, 4, 4, NULL, 441, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7425, '1997-04-04 22:00:00+00', '2018-04-03 00:07:53.558617+00', 'In the Days of Sailing Ships', 'IN THE DAYS OF SAILING SHIPS', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7429, '1997-12-03 23:00:00+00', '2018-01-21 22:41:57.897443+00', 'Jamie''s Jig', 'JAMIES JIG', 2, 32, 9999, 1, 3, 42, 1, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7399, '1997-04-04 22:00:00+00', '2018-04-03 00:07:46.387916+00', 'Fly The Banner', 'FLY THE BANNER', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7403, '1997-04-04 22:00:00+00', '2018-04-03 00:07:47.980879+00', 'Gentle Push, A', 'GENTLE PUSH', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12611, '2005-11-08 23:00:00+00', '2021-01-13 20:09:21.763579+00', 'Harold House Jig', 'HAROLD HOUSE JIG', 2, 32, 9999, 1, 2, 76, 3647, NULL, '', 69, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12609, '2005-11-08 23:00:00+00', '2021-01-13 20:18:27.820653+00', 'French Delight, A', 'FRENCH DELIGHT', 1, 40, 9999, 1, 3, 42, 3647, NULL, '', 72, '888/888/888/888/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12607, '2005-11-08 23:00:00+00', '2021-01-13 20:22:28.363959+00', 'Betty from Chester', 'BETTY FROM CHESTER', 3, 32, 9999, 1, 3, 42, 3647, NULL, '', 69, '844/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12584, '2005-11-01 23:00:00+00', '2021-01-13 20:29:44.041084+00', 'Friday Night Reel', 'FRIDAY NIGHT REEL', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', 38, '800/808/800/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7416, '1998-12-17 23:00:00+00', '2021-03-23 13:42:54.305035+00', 'Here''s to the Heaths', 'HERES TO THE HEATHS', 3, 32, 9999, 1, 4, 2, 440, NULL, 'Written for Doug and Elizabeth Heath, friends and fellow members of St Andrew''s of Brampton.', 84, '8668/8888/8888/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7419, '1998-09-23 22:00:00+00', '2021-04-05 21:47:37.366647+00', 'Home And Away', 'HOME AND AWAY', 1, 32, 9999, 1, 3, 42, 352, '1994-09-08', '', 44, '800/844/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7411, '1997-12-03 23:00:00+00', '2018-04-03 00:07:50.917028+00', 'Harmonica, The', 'HARMONICA', 2, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7418, '1997-04-04 22:00:00+00', '2018-04-03 00:07:52.12602+00', 'Highland Hospitality', 'HIGHLAND HOSPITALITY', 1, 32, 9999, 1, 3, 42, 3552, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7426, '1997-04-04 22:00:00+00', '2018-04-03 00:07:53.591967+00', 'In the Hall of a Highland Chief', 'IN THE HALL OF A HIGHLAND CHIEF', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7431, '1997-09-05 22:00:00+00', '2018-04-03 00:07:56.254017+00', 'John''s Delight', 'JOHNS DELIGHT', 3, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12593, '2005-11-01 23:00:00+00', '2018-04-03 00:08:07.771205+00', 'New Zealand Fern', 'NEW ZEALAND FERN', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12599, '2005-11-01 23:00:00+00', '2018-04-03 00:08:20.304565+00', 'Teaching Toronto', 'TEACHING TORONTO', 3, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12602, '2005-11-01 23:00:00+00', '2018-04-03 00:08:25.742634+00', 'Wild Creek', 'WILD CREEK', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7437, '1997-04-04 22:00:00+00', '2012-01-20 12:56:58.564797+00', 'Keeneland', 'KEENELAND', 1, 32, 9999, 2, 3, NULL, 3568, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7444, '1997-04-04 22:00:00+00', '2012-01-20 12:56:58.632846+00', 'Land O'' the Leal, The', 'LAND O THE LEAL', 3, 32, 9999, 2, 3, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7445, '1997-12-03 23:00:00+00', '2012-01-20 12:56:58.642119+00', 'Land of the Golden Oatcake', 'LAND OF THE GOLDEN OATCAKE', 2, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7485, '2002-03-03 23:00:00+00', '2019-03-07 23:06:36.58121+00', 'Perfect Ending', 'PERFECT ENDING', 3, 40, 9999, 1, 4, 1, 480, '1994-01-01', '', 78, '8000/8888/8888/8444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7449, '2002-04-19 22:00:00+00', '2012-01-20 12:56:58.669781+00', 'Lindesay House', 'LINDESAY HOUSE', 3, 32, 9999, 1, 4, NULL, 197, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7452, '1997-12-03 23:00:00+00', '2012-01-20 12:56:58.690561+00', 'Lynx Lake Loons', 'LYNX LAKE LOONS', 2, 40, 9999, 2, 3, NULL, 441, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7453, '1998-01-05 23:00:00+00', '2012-01-20 12:56:58.69777+00', 'Macquarie''s Own', 'MACQUARIES OWN', 1, 32, 9999, 1, 4, NULL, 197, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7480, '1997-09-10 22:00:00+00', '2019-03-07 23:09:50.311136+00', 'Old Rustic Bridge, The', 'OLD RUSTIC BRIDGE', 1, 32, 9999, 1, 4, 2, 1, NULL, '', 69, '8008/8448/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7472, '1997-12-03 23:00:00+00', '2019-03-07 23:16:34.914648+00', 'My Big Kilmarnock Bunnet', 'MY BIG KILMARNOCK BUNNET', 2, 32, 9999, 1, 3, 42, 1, NULL, '', 50, '800/888/822/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7451, '1998-01-07 23:00:00+00', '2012-02-22 23:19:59.891981+00', 'May''s Delight', 'MAYS DELIGHT', 2, 32, 9999, 1, 3, 42, 2027, NULL, 'Devised for her friend Miss May Dick, now Mrs. May Whyte', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7458, '1999-01-03 23:00:00+00', '2019-03-08 11:32:37.832289+00', 'Memories', 'MEMORIES', 1, 32, 9999, 1, 3, 42, 480, '1994-01-01', '', 56, '800/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7463, '1997-12-03 23:00:00+00', '2012-01-20 12:56:58.766205+00', 'Miss Isabella Ord', 'MISS ISABELLA ORD', 2, 32, 9999, 1, 4, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7454, '1997-04-04 22:00:00+00', '2019-03-08 11:34:39.957498+00', 'Macrame', 'MACRAME', 3, 32, 9999, 1, 4, 1, 441, NULL, '', 86, '8888/8888/8888/8222', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7467, '1998-01-04 23:00:00+00', '2012-01-20 12:56:58.793575+00', 'Almond Valley Strathspey', 'ALMOND VALLEY STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7443, '1997-12-27 23:00:00+00', '2019-03-08 11:53:32.175345+00', 'Lammonbie Mill', 'LAMMONBIE MILL', 4, 128, 2, 4, 4, 54, 434, NULL, '', 88, '8888/8888/8888/8888/8888/8080/0808/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7442, '2002-11-28 23:00:00+00', '2019-03-08 11:57:29.949528+00', 'Laird''s Levity', 'LAIRDS LEVITY', 3, 32, 9999, 2, 3, 17, 394, '1996-01-01', '', 71, '800/804/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7471, '1997-04-04 22:00:00+00', '2012-01-20 12:56:58.821384+00', 'Music Square Reel', 'MUSIC SQUARE REEL', 1, 32, 9999, 1, 4, NULL, 3569, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7477, '1997-04-04 22:00:00+00', '2012-01-20 12:56:58.862916+00', 'Ngaio Celebration', 'NGAIO CELEBRATION', 3, 32, 9999, 2, 3, NULL, 439, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7438, '1998-11-02 23:00:00+00', '2019-03-08 12:00:11.839555+00', 'Keyboard Kapers', 'KEYBOARD KAPERS', 1, 32, 9999, 1, 4, 2, 118, '1996-01-01', '', 75, '8008/8888/8008/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7479, '1997-12-28 23:00:00+00', '2012-01-20 12:56:58.877556+00', '''Nuff Said', 'NUFF SAID', 4, 32, 1, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7481, '2003-01-30 23:00:00+00', '2012-01-20 12:56:58.893101+00', 'On Heather Island', 'ON HEATHER ISLAND', 1, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7955, '1997-09-14 22:00:00+00', '2012-01-20 12:57:02.597046+00', 'Stalker Castle', 'STALKER CASTLE', 4, 64, 9999, 4, 4, NULL, 1287, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7486, '1997-09-11 22:00:00+00', '2020-09-09 13:56:11.644582+00', 'Peter''s Pride', 'PETERS PRIDE', 1, 128, 9999, 4, 4, 3, 1, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12614, '2005-11-08 23:00:00+00', '2021-01-13 11:47:07.981656+00', 'Paula''s Wedding to Lyndon', 'PAULAS WEDDING TO LYNDON', 1, 40, 9999, 1, 3, 42, 3647, NULL, '', 42, '800/888/800/844/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12623, '2005-11-08 23:00:00+00', '2021-01-12 12:27:58.977422+00', 'Ferry Boats on the Mersey', 'FERRY BOATS ON THE MERSEY', 1, 40, 9999, 2, 3, 17, 3647, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12621, '2005-11-08 23:00:00+00', '2021-01-12 12:30:22.027093+00', 'Around About in Saint George''s Hall', 'AROUND ABOUT IN SAINT GEORGES HALL', 1, 32, 9999, 4, 4, 4, 3647, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12617, '2005-11-08 23:00:00+00', '2021-01-12 12:33:09.277846+00', 'Square Petronella, The', 'SQUARE PETRONELLA', 1, 256, 9999, 4, 4, 3, 3647, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12612, '2005-11-08 23:00:00+00', '2021-01-13 16:20:45.714296+00', 'Lady from Wimbledon, The', 'LADY FROM WIMBLEDON', 1, 32, 9999, 1, 3, 42, 3647, NULL, '', 44, '800/888/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12610, '2005-11-08 23:00:00+00', '2021-01-13 20:15:44.374207+00', 'Gravy Train, The', 'GRAVY TRAIN', 2, 40, 9999, 1, 3, 42, 3647, NULL, '', 65, '880/888/822/666/648', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7461, '1998-12-17 23:00:00+00', '2021-03-20 20:21:34.874889+00', 'Minister, The', 'MINISTER', 1, 32, 9999, 1, 100, 1, 440, NULL, 'Written in honour of my late father, the Reverend George S. Campbell, formerly of the High Church, Dumbarton, Scotland', 72, '8008/8008/8888/8488', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7468, '1998-12-17 23:00:00+00', '2021-03-25 09:20:37.102692+00', 'Mrs Florence Campbell', 'MRS FLORENCE CAMPBELL', 1, 40, 9999, 4, 4, 13, 440, NULL, 'Written for my mother, Mrs Florence Campbell, of Cardross, Scotland.', 70, '8888/7777/7777/7070/0707', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7450, '1998-11-22 23:00:00+00', '2021-03-26 23:46:46.894725+00', 'Baltic Voyager, The', 'BALTIC VOYAGER', 2, 48, 9999, 1, 100, 2, 185, NULL, '', 67, '8008/8008/8888/8008/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7459, '1998-11-20 23:00:00+00', '2021-04-09 00:49:50.217779+00', 'Merlindale House', 'MERLINDALE HOUSE', 3, 32, 9999, 4, 4, 1, 154, NULL, '', 87, '8080/8888/8888/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7482, '1997-12-28 23:00:00+00', '2012-01-20 12:56:58.900585+00', 'One and Only Way, The', 'ONE AND ONLY WAY', 4, 32, 1, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7483, '1997-04-04 22:00:00+00', '2012-01-20 12:56:58.908162+00', 'Pairtisay', 'PAIRTISAY', 3, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7470, '1998-01-05 23:00:00+00', '2018-04-03 00:08:06.562137+00', 'Mrs Minto''s Reel', 'MRS MINTOS REEL', 1, 32, 9999, 1, 3, 42, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7436, '1998-10-19 22:00:00+00', '2015-09-07 15:25:21.114349+00', 'Ian Powrie''s Hornpipe', 'IAN POWRIES HORNPIPE', 1, 32, 9999, 1, 3, 42, 173, '1967-12-24', '', 75, '888/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7435, '1997-04-04 22:00:00+00', '2022-08-03 18:29:56.627359+00', 'Kath Moffat''s Strathspey', 'KATH MOFFATS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 173, '1989-06-20', 'Named after a member ofthe Howick Club.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7476, '1997-04-04 22:00:00+00', '2022-08-19 08:52:23.357197+00', 'Newtyle Strathspey, The', 'NEWTYLE STRATHSPEY', 3, 32, 9999, 1, 4, 1, 173, '1968-07-09', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7428, '1997-04-04 22:00:00+00', '2022-08-20 19:36:39.439948+00', 'J.D.MacDonald', 'JDMACDONALD', 1, 32, 9999, 1, 3, 42, 173, '1966-08-09', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7432, '1997-04-04 22:00:00+00', '2022-08-20 19:42:22.75012+00', 'Jewel In The Crown', 'JEWEL IN THE CROWN', 3, 32, 9999, 1, 4, 1, 352, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7464, '1998-01-05 23:00:00+00', '2022-10-23 19:55:29.256939+00', 'Montebello Castle', 'MONTEBELLO CASTLE', 1, 32, 9999, 1, 100, 2, 434, '1996-11-01', 'Inscribed "For Burton and Pauline MacLeod, whose home is at Montebello Castle."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7423, '1999-01-03 23:00:00+00', '2022-10-23 19:58:23.689317+00', 'Icebreaker', 'ICEBREAKER', 2, 32, 9999, 1, 3, 42, 480, '1965-10-27', 'Revised: April 19, 1996.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7462, '1998-11-12 23:00:00+00', '2016-02-06 01:26:33.770112+00', 'Miss Becky Flower', 'MISS BECKY FLOWER', 3, 32, 9999, 4, 4, NULL, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7439, '1997-04-04 22:00:00+00', '2018-04-03 00:07:57.288108+00', 'Kilkenny Cats', 'KILKENNY CATS', 3, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7447, '1998-01-05 23:00:00+00', '2018-04-03 00:07:59.056223+00', 'Last Of The Line, The', 'LAST OF THE LINE', 1, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7456, '1997-04-04 22:00:00+00', '2018-04-03 00:08:02.517242+00', 'Mary Ronnie', 'MARY RONNIE', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7478, '1997-12-03 23:00:00+00', '2018-04-03 00:08:08.044864+00', 'Norfolk Jig, The', 'NORFOLK JIG', 2, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18715, '2018-10-03 09:58:20.462897+00', '2018-10-03 09:58:20.462897+00', 'Corinthian Columns', 'CORINTHIAN COLUMNS', 2, 32, NULL, 1, 3, 42, 2766, '2015-06-01', 'The reels on the sides reminded me of columns, thus the name.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7518, '1997-05-18 22:00:00+00', '2019-03-07 22:50:01.582605+00', 'Solway Sunset', 'SOLWAY SUNSET', 3, 32, 9999, 6, 3, 4, 434, NULL, '', 88, '888/666/666/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7488, '2002-03-03 23:00:00+00', '2019-03-07 22:57:01.31087+00', 'Pinewoods Medley', 'PINEWOODS MEDLEY', 4, 64, 5, 1, 4, 2, 480, '1986-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12641, '2005-12-02 23:00:00+00', '2012-01-20 12:57:40.061337+00', 'Scottish Spirit, The', 'SCOTTISH SPIRIT', 3, 32, 9999, 1, 4, NULL, 3652, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12632, '2005-11-08 23:00:00+00', '2019-07-05 00:19:09.367538+00', 'Travelling to America', 'TRAVELLING TO AMERICA', 1, 40, 9999, 1, 3, 42, 3379, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7492, '2000-12-12 23:00:00+00', '2012-01-20 12:56:58.9721+00', 'Pride of Place', 'PRIDE OF PLACE', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7497, '1997-12-03 23:00:00+00', '2012-01-20 12:56:59.007131+00', 'Remarkable Tribute, A', 'REMARKABLE TRIBUTE', 2, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7498, '1997-04-04 22:00:00+00', '2012-01-20 12:56:59.013974+00', 'River Avon, The', 'RIVER AVON', 3, 32, 9999, 2, 3, NULL, 441, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7502, '1997-04-04 22:00:00+00', '2012-01-20 12:56:59.042949+00', 'Robertsons of Aberfeldy, The', 'ROBERTSONS OF ABERFELDY', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12640, '2005-11-19 23:00:00+00', '2018-04-03 00:07:46.604727+00', 'Founder, The', 'FOUNDER', 3, 32, 9999, 1, 3, 42, 2677, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7505, '1998-09-23 22:00:00+00', '2012-01-20 12:56:59.063641+00', 'Sacred Circle, The', 'SACRED CIRCLE', 1, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7507, '1997-04-04 22:00:00+00', '2012-01-20 12:56:59.443114+00', 'Sandy Oswald''s Reel', 'SANDY OSWALDS REEL', 1, 32, 9999, 2, 3, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7508, '1997-12-03 23:00:00+00', '2012-01-20 12:56:59.449899+00', 'Scarlet Poppies', 'SCARLET POPPIES', 2, 48, 9999, 1, 4, NULL, 441, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7510, '1997-04-04 22:00:00+00', '2012-01-20 12:56:59.463648+00', 'Scotia Reel', 'SCOTIA REEL', 1, 24, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7512, '1998-01-05 23:00:00+00', '2012-01-20 12:56:59.478141+00', 'Scottish Soldiers, The', 'SCOTTISH SOLDIERS', 1, 32, 9999, 3, 5, 7, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7514, '1998-09-23 22:00:00+00', '2012-01-20 12:56:59.491756+00', 'Shapeshifting', 'SHAPESHIFTING', 1, 40, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7515, '2002-04-19 22:00:00+00', '2012-01-20 12:56:59.498839+00', 'Sheena''s Wedding', 'SHEENAS WEDDING', 3, 48, 9999, 1, 4, NULL, 441, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7516, '1997-04-04 22:00:00+00', '2012-01-20 12:56:59.505725+00', 'Silver Bracelet', 'SILVER BRACELET', 1, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7519, '1998-10-19 22:00:00+00', '2012-01-20 12:56:59.526271+00', 'Peter Hind', 'PETER HIND', 3, 32, 9999, 1, 4, NULL, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12643, '2005-12-21 23:00:00+00', '2012-01-20 12:57:40.078779+00', 'It''s Right all the Way', 'ITS RIGHT ALL THE WAY', 2, 32, 9999, 4, 5, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12644, '2005-12-21 23:00:00+00', '2012-01-20 12:57:40.087443+00', 'Miller''s Wheel, The', 'MILLERS WHEEL', 3, 32, 9999, 4, 3, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12645, '2005-12-21 23:00:00+00', '2012-01-20 12:57:40.096091+00', 'Playground, The', 'PLAYGROUND', 1, 40, 9999, 1, 4, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12647, '2005-12-21 23:00:00+00', '2012-01-20 12:57:40.113349+00', 'Dawn', 'DAWN', 3, 32, 9999, 2, 3, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12649, '2005-12-21 23:00:00+00', '2012-01-20 12:57:40.130981+00', 'Grove, The', 'GROVE', 3, 80, 9999, 4, 4, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12650, '2005-12-21 23:00:00+00', '2012-01-20 12:57:40.139619+00', 'Lauren''s Strathspey', 'LAURENS STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7526, '1997-12-03 23:00:00+00', '2012-01-20 12:56:59.575852+00', 'Tartan Hens, The', 'TARTAN HENS', 2, 48, 9999, 1, 4, NULL, 441, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12648, '2005-12-21 23:00:00+00', '2018-04-03 00:08:03.743182+00', 'Mintcake', 'MINTCAKE', 1, 32, 9999, 1, 3, 42, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7535, '1997-04-04 22:00:00+00', '2012-01-20 12:56:59.640462+00', 'What is a Scotsman?', 'WHAT IS A SCOTSMAN', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7536, '1998-12-16 23:00:00+00', '2012-01-20 12:56:59.648392+00', 'Two by two', 'TWO BY TWO', 3, 32, 9999, 2, 3, 17, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7537, '1997-04-04 22:00:00+00', '2012-01-20 12:56:59.655464+00', 'Whirlpool, The', 'WHIRLPOOL', 1, 40, 9999, 1, 4, NULL, 441, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7501, '2002-02-11 23:00:00+00', '2015-10-13 12:42:07.616487+00', 'Roberta Buckel''s Strathspey', 'ROBERTA BUCKELS STRATHSPEY', 3, 32, 9999, 3, 5, 26, 1, '1955-10-01', '', 70, '80408/88888/82428/84844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7525, '2002-11-26 23:00:00+00', '2018-04-03 00:08:19.78849+00', 'Taliesin', 'TALIESIN', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12652, '2005-12-21 23:00:00+00', '2020-02-05 22:28:04.627341+00', 'Gull''s Flight, The', 'GULLS FLIGHT', 3, 32, 9999, 2, 3, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12619, '2005-11-08 23:00:00+00', '2020-09-15 09:53:48.28705+00', 'Touch of Wales, A', 'TOUCH OF WALES', 2, 32, 9999, 1, 3, 42, 3647, NULL, '', 38, '800/844/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7487, '1998-09-23 22:00:00+00', '2020-09-14 11:28:01.725141+00', 'Pin The Kilt', 'PIN THE KILT', 1, 32, 9999, 1, 3, 42, 352, '1994-06-24', '', 67, '868/888/888/62', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12627, '2005-11-08 23:00:00+00', '2021-01-12 11:56:50.938407+00', 'Where are We Going?', 'WHERE ARE WE GOING', 2, 32, 9999, 1, 3, 42, 3647, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12615, '2005-11-08 23:00:00+00', '2021-01-13 11:35:04.971943+00', 'Rodney Rooms Rant', 'RODNEY ROOMS RANT', 2, 32, 9999, 1, 3, 42, 3647, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7506, '1997-09-13 22:00:00+00', '2021-03-26 11:16:55.918369+00', 'Sandbox', 'SANDBOX', 3, 32, 9999, 5, 2, NULL, 441, NULL, '', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7484, '1998-12-17 23:00:00+00', '2021-03-19 18:15:38.907921+00', 'Paul Maloney''s Strathspey', 'PAUL MALONEYS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 440, NULL, 'Written for Dr. Paul Maloney, teacher of the St. Andrew''s Scottish Country Dance group.', 63, '888/888/822/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7499, '1998-11-02 23:00:00+00', '2021-03-26 22:34:10.100232+00', 'Rob''s Delight', 'ROBS DELIGHT', 2, 32, 9999, 1, 4, 1, 1024, '1997-01-01', '', 66, '8888/8080/8800/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7469, '2000-01-17 23:00:00+00', '2021-03-26 23:39:53.142975+00', 'Mrs Henry''s Bonnet', 'MRS HENRYS BONNET', 2, 32, 9999, 1, 3, 42, 438, '1996-01-01', '', 44, '880/808/844/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12629, '2005-11-08 23:00:00+00', '2021-07-15 23:05:11.848946+00', 'Black Hole, The', 'BLACK HOLE', 1, 32, 9999, 1, 4, 1, 3350, '2002-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7489, '1997-12-03 23:00:00+00', '2018-04-03 00:08:10.7903+00', 'Piper''s Joy, The', 'PIPERS JOY', 2, 24, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7491, '1997-12-03 23:00:00+00', '2018-04-03 00:08:11.065645+00', 'Porringer, The', 'PORRINGER', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7493, '1997-04-04 22:00:00+00', '2018-04-03 00:08:11.422648+00', 'Proof of the Pudding', 'PROOF OF THE PUDDING', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7495, '1998-01-05 23:00:00+00', '2018-04-03 00:08:12.024647+00', 'Rampant Lions, The', 'RAMPANT LIONS', 1, 32, 9999, 1, 3, 42, 2792, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7509, '1997-04-04 22:00:00+00', '2018-04-03 00:08:15.135122+00', 'Scorched Earth', 'SCORCHED EARTH', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7522, '1997-04-04 22:00:00+00', '2018-04-03 00:08:19.221338+00', 'Sunday Dinner', 'SUNDAY DINNER', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7500, '1998-09-23 22:00:00+00', '2022-08-03 18:35:25.644523+00', 'Robbie Stewart', 'ROBBIE STEWART', 3, 32, 9999, 1, 3, 42, 173, '1989-08-20', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7504, '1997-09-13 22:00:00+00', '2022-08-13 09:24:23.525373+00', 'Ruthin Square', 'RUTHIN SQUARE', 1, 32, 9999, 4, 4, 1, 1, '1995-11-01', 'Devised for the 20th anniversary of Ruthin Scottish Country Dance Society.', 87, '8888/8080/8888/8888/', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7538, '1997-12-27 23:00:00+00', '2018-04-03 00:08:25.700842+00', 'Wide Awake', 'WIDE AWAKE', 4, 64, 17, 1, 3, 42, 3570, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12646, '2005-12-21 23:00:00+00', '2018-04-03 00:08:27.010139+00', 'Yellow Rose, The', 'YELLOW ROSE', 1, 40, 9999, 1, 3, 42, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7556, '1998-01-05 23:00:00+00', '2018-04-03 00:07:30.426865+00', 'Ancrum Moor', 'ANCRUM MOOR', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7562, '1998-01-05 23:00:00+00', '2018-04-03 00:07:30.560574+00', 'Angela''s Dance', 'ANGELAS DANCE', 1, 32, 9999, 1, 3, 42, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7549, '1997-12-02 23:00:00+00', '2012-01-20 12:56:59.74371+00', 'Amber Jig', 'AMBER JIG', 2, 32, 9999, 2, 3, NULL, 626, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7571, '1998-01-05 23:00:00+00', '2018-04-03 00:07:30.660808+00', 'Angus Urqhuart', 'ANGUS URQHUART', 1, 32, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12653, '2005-12-21 23:00:00+00', '2012-01-20 12:57:40.165555+00', 'March Hare, The', 'MARCH HARE', 3, 32, 9999, 6, 3, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12654, '2005-12-21 23:00:00+00', '2012-01-20 12:57:40.17431+00', 'Kendall''s Way', 'KENDALLS WAY', 3, 40, 9999, 6, 3, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12655, '2005-12-21 23:00:00+00', '2012-01-20 12:57:40.183043+00', 'Pam''s Jig', 'PAMS JIG', 2, 32, 9999, 1, 4, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12656, '2005-12-21 23:00:00+00', '2012-01-20 12:57:40.191677+00', 'Heather''s Strathspey', 'HEATHERS STRATHSPEY', 3, 32, 9999, 6, 3, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12657, '2005-12-21 23:00:00+00', '2012-01-20 12:57:40.200298+00', 'Light and Shade', 'LIGHT AND SHADE', 3, 32, 9999, 4, 5, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12658, '2005-12-21 23:00:00+00', '2012-01-20 12:57:40.208989+00', 'Cashmore Strathspey, The', 'CASHMORE STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12659, '2005-12-21 23:00:00+00', '2012-01-20 12:57:40.217664+00', 'Reigate Reel', 'REIGATE REEL', 1, 32, 9999, 1, 4, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12660, '2005-12-21 23:00:00+00', '2012-01-20 12:57:40.226292+00', 'Fraser''s Jig', 'FRASERS JIG', 2, 48, 9999, 1, 4, NULL, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12661, '2006-01-01 23:00:00+00', '2012-01-20 12:57:40.234957+00', 'Grey Cairns of Canster', 'GREY CAIRNS OF CANSTER', 1, 32, 9999, 3, 4, NULL, 17, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18678, '2018-10-01 13:41:00.087226+00', '2018-10-01 13:57:56.82629+00', 'App Madness', 'APP MADNESS', 1, 32, NULL, 1, 3, 42, 2766, '2013-07-01', 'Playing with my iPad I added enough apps to fill it completely and had to spend a bunch if time selectively cleaning them up to have room for things like - updates.', 56, '800/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7578, '2002-04-14 22:00:00+00', '2019-02-17 01:12:28.831845+00', 'Sugar Loaf Jig, The', 'SUGAR LOAF JIG', 2, 32, 9999, 1, 3, 42, 127, NULL, 'The Sugar Loaf Mountain stands in Rio harbour.', 56, '800/866/866/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7539, '2002-04-15 22:00:00+00', '2019-03-07 22:43:45.867939+00', 'Wigtown Cross, The', 'WIGTOWN CROSS', 1, 88, 9999, 4, 4, 3, 146, '1995-01-01', '', 55, '8080/0808/8080/0808/6262/2626/6262/2626/4444/4444/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14639, '2013-01-03 08:36:24.414023+00', '2013-01-03 08:36:24.414035+00', 'Virginia Reel', 'VIRGINIA REEL', 1, 64, 9999, 1, 4, 1, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7580, '1998-01-04 23:00:00+00', '2018-04-03 00:07:30.794246+00', 'Annie Douglas', 'ANNIE DOUGLAS', 3, 32, 9999, 1, 3, 42, 637, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7573, '1997-08-10 22:00:00+00', '2012-01-20 12:56:59.92795+00', 'Rhuallen Rant, The', 'RHUALLEN RANT', 3, 72, 9999, 4, 4, NULL, 100, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7579, '1998-01-04 23:00:00+00', '2012-01-20 12:56:59.971618+00', 'Anne''s Happiness', 'ANNES HAPPINESS', 3, 32, 9999, 2, 3, 17, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7581, '1997-12-02 23:00:00+00', '2012-01-20 12:56:59.985669+00', 'Anniversary Jig, The', 'ANNIVERSARY JIG', 2, 128, 9999, 4, 4, NULL, 639, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7583, '1998-01-04 23:00:00+00', '2012-01-20 12:57:00.000183+00', 'Anniversary Strathspey', 'ANNIVERSARY STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 641, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12667, '2006-01-25 23:00:00+00', '2012-01-20 12:57:40.30154+00', 'Thistle of Dauphiné', 'THISTLE OF DAUPHINE', 2, 40, 9999, 1, 4, NULL, 17, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12673, '2006-02-12 23:00:00+00', '2012-01-20 12:57:40.355145+00', 'Tribute to West Renfrewshire, A', 'TRIBUTE TO WEST RENFREWSHIRE', 2, 40, 9999, 1, 4, 2, 3616, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12676, '2006-02-14 23:00:00+00', '2012-01-20 12:57:40.383346+00', 'Ben Macdhui', 'BEN MACDHUI', 3, 32, 9999, 3, 5, 7, 17, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12677, '2006-02-14 23:00:00+00', '2012-01-20 12:57:40.394791+00', 'Belle of Belledonne', 'BELLE OF BELLEDONNE', 3, 32, 9999, 3, 5, NULL, 17, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7563, '2002-04-08 22:00:00+00', '2012-02-27 09:16:01.683949+00', 'Queen''s View, The', 'QUEENS VIEW', 1, 32, 9999, 1, 3, 42, 127, NULL, 'Devised for Arthur and Eva Hirst', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7568, '1998-11-28 23:00:00+00', '2018-04-03 00:07:43.226561+00', 'Duchess of Argyll, The', 'DUCHESS OF ARGYLL', 3, 32, 9999, 1, 3, 42, 127, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7550, '1997-10-23 22:00:00+00', '2016-05-12 23:23:26.699854+00', 'Tobermory Two-Step', 'TOBERMORY TWOSTEP', 50, 16, 9999, 99, 98, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12932, '2006-10-19 22:00:00+00', '2020-01-11 02:01:35.735955+00', 'Stalwarts, The', 'STALWARTS', 2, 32, 9999, NULL, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14640, '2013-01-04 15:27:47.970692+00', '2020-07-08 14:49:53.189701+00', 'Meeting and Greeting', 'MEETING AND GREETING', 2, 32, 9999, 5, 56, 30, 952, '2007-04-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7554, '1999-12-21 23:00:00+00', '2020-09-04 13:56:21.996974+00', 'Pride of Erin Waltz', 'PRIDE OF ERIN WALTZ', 5, 32, 9999, 5, 1, NULL, 1999, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12672, '2006-02-12 23:00:00+00', '2021-01-11 11:35:48.603709+00', 'Compliments to the Lawsons', 'COMPLIMENTS TO THE LAWSONS', 3, 32, 9999, 1, 4, 2, 640, '2005-01-01', '', 88, '8888/8888/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7569, '2002-03-11 23:00:00+00', '2021-03-24 11:42:21.458325+00', 'Homeward Bound', 'HOMEWARD BOUND', 1, 32, 9999, 1, 3, 42, 127, '1991-01-01', '"Devised for Neville and Pam Jemmett of Dunedin NZ."', 55, '882/844/888/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12642, '2005-12-04 23:00:00+00', '2021-01-11 11:43:45.943561+00', 'Mrs Ina Wilson', 'MRS INA WILSON', 1, 32, 9999, 1, 3, 42, 2922, NULL, '', 44, '800/844/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12671, '2006-02-12 23:00:00+00', '2021-01-23 23:37:27.543253+00', 'Ross Strathspey, The', 'ROSS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 2020, NULL, '<<scddb-not-identical:7319>>', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7567, '1997-07-16 22:00:00+00', '2021-03-24 11:50:39.03907+00', 'Glen Alva', 'GLEN ALVA', 1, 32, 9999, 1, 3, 42, 127, NULL, '"Devised for Sue and Alan Davis. Glen Alva, a picturesque beauty spot in Clackmannanshire, is a favourite with Sue and Alan."', 56, '888/866/844/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7547, '2002-04-30 22:00:00+00', '2021-03-25 23:42:31.70994+00', 'Nor'' Loch, The', 'NOR LOCH', 4, 96, 11, 4, 4, NULL, 1175, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14641, '2013-01-04 16:23:35.217974+00', '2017-05-13 16:06:13.824076+00', 'Susan''s Souvenir', 'SUSANS SOUVENIR', 3, 32, 9999, 2, 3, 17, 2701, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12678, '2006-02-14 23:00:00+00', '2017-09-16 00:22:16.83212+00', 'Clishmaclaver', 'CLISHMACLAVER', 2, 128, 9999, 4, 4, 3, 17, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12666, '2006-01-25 23:00:00+00', '2018-04-03 00:07:49.882829+00', 'Green Fringe Medley', 'GREEN FRINGE MEDLEY', 4, 64, 17, 1, 3, 42, 17, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12679, '2006-02-14 23:00:00+00', '2018-04-03 00:08:25.859329+00', 'Willie on the Muirs', 'WILLIE ON THE MUIRS', 2, 32, 9999, 1, 3, 42, 17, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7541, '2002-11-26 23:00:00+00', '2018-04-03 00:08:25.867603+00', 'Willie''s Wife', 'WILLIES WIFE', 2, 32, 9999, 1, 3, 42, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7574, '1998-10-04 22:00:00+00', '2013-02-04 19:33:22.391139+00', 'Bluebell Polka', 'BLUEBELL POLKA', 13, 16, 9999, 5, 1, NULL, 1990, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7584, '1997-12-02 23:00:00+00', '2012-01-20 12:57:00.007+00', 'Appin Rant, The', 'APPIN RANT', 2, 88, 9999, 4, 4, NULL, 644, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7585, '1997-12-02 23:00:00+00', '2012-01-20 12:57:00.013865+00', 'Archery Jig', 'ARCHERY JIG', 2, 32, 9999, 1, 4, NULL, 646, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18642, '2018-09-18 22:26:25.43996+00', '2018-09-18 22:26:32.153306+00', 'Over the Moon', 'OVER THE MOON', 1, 32, NULL, 1, 3, 42, 11714, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7587, '1997-12-02 23:00:00+00', '2012-01-20 12:57:00.027573+00', 'Archie McHarg''s Jig', 'ARCHIE MACHARGS JIG', 2, 32, 9999, 1, 2, NULL, 1831, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7540, '1997-04-04 22:00:00+00', '2022-08-19 08:58:39.565361+00', 'Wild Rose Of The Mountain, The', 'WILD ROSE OF THE MOUNTAIN', 3, 32, 9999, 1, 3, 42, 173, '1980-05-19', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12639, '2005-11-10 23:00:00+00', '2022-09-19 09:55:21.804869+00', 'Wherever She Goes', 'WHEREVER SHE GOES', 2, 32, 9999, 1, 3, 42, 3649, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7545, '2002-02-26 23:00:00+00', '2022-10-23 19:45:26.478824+00', 'Long Pond Reel', 'LONG POND REEL', 1, 32, 9999, 1, 3, 42, 1763, '1980-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7588, '1997-08-28 22:00:00+00', '2012-01-20 12:57:00.034375+00', 'Argyll Gathering', 'ARGYLL GATHERING', 4, 64, 9999, 4, 4, NULL, 650, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7590, '1997-08-28 22:00:00+00', '2012-01-20 12:57:00.048214+00', 'Argyll Ramblers, The', 'ARGYLL RAMBLERS', 4, 32, 9999, 1, 4, NULL, 652, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7591, '1998-01-04 23:00:00+00', '2019-02-08 17:44:32.556641+00', 'Arun Waters', 'ARUN WATERS', 3, 32, 9999, 1, 4, 2, 654, NULL, '', 75, '8008/8448/8888/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7593, '1997-12-02 23:00:00+00', '2012-01-20 12:57:00.068818+00', 'Atholl Palace Jig', 'ATHOLL PALACE JIG', 2, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7594, '1998-01-04 23:00:00+00', '2012-01-20 12:57:00.075586+00', 'Auld Alliance, The', 'AULD ALLIANCE', 3, 32, 9999, 2, 3, NULL, 108, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7595, '1997-12-02 23:00:00+00', '2012-01-20 12:57:00.082474+00', 'Auld Commandment, The', 'AULD COMMANDMENT', 2, 32, 9999, 5, 56, NULL, 659, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7597, '1998-01-04 23:00:00+00', '2012-01-20 12:57:00.096198+00', 'Avon Water', 'AVON WATER', 3, 32, 9999, 2, 3, NULL, 26, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7599, '1998-01-05 23:00:00+00', '2012-01-20 12:57:00.109824+00', 'Awesome Reel, The', 'AWESOME REEL', 1, 32, 9999, 1, 4, NULL, 652, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7600, '1997-12-02 23:00:00+00', '2012-01-20 12:57:00.116591+00', 'Ayrespin', 'AYRESPIN', 2, 32, 9999, 1, 2, NULL, 663, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7601, '2000-04-25 22:00:00+00', '2012-01-20 12:57:00.123443+00', 'Mrs Inwood''s Strathspey', 'MRS INWOODS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 665, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7603, '1998-01-05 23:00:00+00', '2012-01-20 12:57:00.137192+00', 'Bamburgh Castle', 'BAMBURGH CASTLE', 1, 32, 9999, 3, 5, NULL, 316, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7586, '1998-01-04 23:00:00+00', '2018-04-03 00:07:31.053319+00', 'Arches of the Years', 'ARCHES OF THE YEARS', 3, 32, 9999, 1, 3, 42, 647, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7606, '1997-12-02 23:00:00+00', '2012-01-20 12:57:00.15996+00', 'Barbara''s Jig', 'BARBARAS JIG', 2, 32, 9999, 1, 2, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7598, '1997-12-02 23:00:00+00', '2019-09-13 00:33:21.861877+00', 'Awa'' O''er the Border', 'AWA OER THE BORDER', 2, 32, 9999, 1, 4, 1, 146, '1984-01-01', 'For John and Lesley Broadhead when they left Yorkshire for Scotland', 82, '8888/8888/8484/8282', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7610, '1997-12-02 23:00:00+00', '2012-01-20 12:57:00.190224+00', 'Bee in Your Bonnet', 'BEE IN YOUR BONNET', 2, 32, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7612, '1998-06-25 22:00:00+00', '2012-01-20 12:57:00.205212+00', 'Evelyn''s Joy', 'EVELYNS JOY', 1, 32, 9999, 1, 4, NULL, 2071, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7682, '1997-09-01 22:00:00+00', '2012-01-20 12:57:00.690897+00', 'Dornoch Bridge', 'DORNOCH BRIDGE', 1, 40, 9999, 1, 4, NULL, 832, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7614, '1997-12-02 23:00:00+00', '2012-01-20 12:57:00.218803+00', 'Berry Husker''s Jig, The', 'BERRY HUSKERS JIG', 2, 32, 9999, 1, 2, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7619, '1998-01-05 23:00:00+00', '2012-01-20 12:57:00.253564+00', 'Bobbity', 'BOBBITY', 1, 32, 9999, 1, 4, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7620, '1997-12-02 23:00:00+00', '2012-01-20 12:57:00.260336+00', 'Bombardier, The', 'BOMBARDIER', 2, 40, 9999, 1, 4, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7624, '1998-01-04 23:00:00+00', '2012-01-20 12:57:00.287885+00', 'Caerlaverock Castle', 'CAERLAVEROCK CASTLE', 3, 32, 9999, 6, 3, NULL, 1, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7625, '1998-01-04 23:00:00+00', '2012-01-20 12:57:00.294671+00', 'Cairneyflappit', 'CAIRNEYFLAPPIT', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7626, '1997-12-02 23:00:00+00', '2012-01-20 12:57:00.302129+00', 'Calico Kid, The', 'CALICO KID', 2, 32, 9999, 1, 3, 42, 737, NULL, 'Official Alias: Callum''s Revelry', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7627, '1997-12-02 23:00:00+00', '2012-01-20 12:57:00.310529+00', 'Camberwell Capers', 'CAMBERWELL CAPERS', 2, 32, 9999, 3, 5, NULL, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7628, '1997-08-31 22:00:00+00', '2012-01-20 12:57:00.319193+00', 'Cam''s Reel', 'CAMS REEL', 1, 32, 9999, 1, 4, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7589, '1997-12-28 23:00:00+00', '2018-03-20 19:53:26.98637+00', 'Argyll Jig', 'ARGYLL JIG', 2, 32, 9999, 1, 3, 42, 651, '1991-02-01', 'Devised by Shun Inagaki, February 1991.  

For Mrs. Hitomi Sato.', 56, '800/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7611, '1998-06-22 22:00:00+00', '2018-03-24 00:17:24.730495+00', 'Chocolate Meringues', 'CHOCOLATE MERINGUES', 1, 40, 9999, 1, 4, 2, 2203, '1998-01-01', 'Check needed on number of bars; could be 32', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7592, '1997-12-02 23:00:00+00', '2018-04-03 00:07:31.262186+00', 'Aschaffenburg Reel, The', 'ASCHAFFENBURG REEL', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7596, '1998-01-05 23:00:00+00', '2018-04-03 00:07:31.579508+00', 'Auld Mercat Cross, The', 'AULD MERCAT CROSS', 1, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7602, '1997-12-02 23:00:00+00', '2018-04-03 00:07:31.95532+00', 'Balancing Act', 'BALANCING ACT', 2, 40, 9999, 1, 3, 42, 667, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7607, '1997-12-02 23:00:00+00', '2018-04-03 00:07:32.639612+00', 'Bass Rock, The', 'BASS ROCK', 2, 32, 9999, 1, 3, 42, 677, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8275, '1998-01-12 23:00:00+00', '2012-01-20 12:57:04.978356+00', 'Lucky Lady', 'LUCKY LADY', 3, 32, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7608, '2002-05-06 22:00:00+00', '2020-08-02 23:16:04.383792+00', 'Bateau Bay', 'BATEAU BAY', 2, 80, 9999, 4, 8, NULL, 151, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12681, '2006-02-16 23:00:00+00', '2021-01-05 21:41:38.353602+00', 'Bristol Fashion', 'BRISTOL FASHION', 3, 32, 9999, 2, 3, 17, 146, '2000-01-01', '', 67, '840/888/804/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12689, '2006-02-16 23:00:00+00', '2021-01-11 11:04:13.461127+00', 'Memories', 'MEMORIES', 3, 32, 9999, 2, 3, 17, 146, NULL, '', 50, '822/888/822/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12686, '2006-02-16 23:00:00+00', '2021-01-11 11:18:14.832845+00', 'Innes Dancers'' Reel, The', 'INNES DANCERS REEL', 1, 32, 9999, 1, 4, 1, 146, NULL, '', 50, '8400/8400/8088/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12684, '2006-02-16 23:00:00+00', '2021-01-11 11:24:25.485487+00', 'Full Circle', 'FULL CIRCLE', 2, 32, 9999, 1, 4, 1, 146, NULL, '', 45, '4240/8880/4400/8440', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12683, '2006-02-16 23:00:00+00', '2021-01-11 11:30:21.118941+00', 'Deeside Wanderer, The', 'DEESIDE WANDERER', 3, 64, 9999, 4, 4, 3, 146, NULL, 'For Ian Findlay - composer and fiddler.', 75, '8888/8080/8888/0808/6262/2626/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7564, '2002-02-16 23:00:00+00', '2021-03-25 00:52:43.782206+00', 'Train Journey North', 'TRAIN JOURNEY NORTH', 1, 40, 9999, 1, 100, 2, 127, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12664, '2006-01-02 23:00:00+00', '2021-07-30 08:07:34.407557+00', 'Moffat Jig, The', 'MOFFAT JIG', 2, 32, 9999, 1, 4, 1, 308, '2005-01-01', 'Written for the Moffat Scottish Country Dance Class ', 84, '7777/7777/8888/4844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12663, '2006-01-02 23:00:00+00', '2021-07-30 08:14:05.374865+00', 'Hartfell Jig, The', 'HARTFELL JIG', 2, 32, 9999, 1, 3, 42, 308, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7557, '2002-11-18 23:00:00+00', '2021-08-02 08:40:44.800355+00', 'Trip to Newfoundland, A', 'TRIP TO NEWFOUNDLAND', 1, 32, 9999, 1, 3, 42, 451, '1996-01-01', '', 56, '800/866/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7609, '1998-01-04 23:00:00+00', '2018-04-03 00:07:32.706319+00', 'B.D.A. Strathspey', 'BDA STRATHSPEY', 3, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7615, '1998-01-04 23:00:00+00', '2018-04-03 00:07:33.282218+00', 'Bidwell Park', 'BIDWELL PARK', 3, 32, 9999, 1, 3, 42, 667, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7616, '1998-01-04 23:00:00+00', '2018-04-03 00:07:33.365764+00', 'Bill Martin''s Reel', 'BILL MARTINS REEL', 3, 32, 9999, 1, 3, 42, 692, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7618, '1998-01-04 23:00:00+00', '2018-04-03 00:07:34.258245+00', 'Blooms of Spinkie Den, The', 'BLOOMS OF SPINKIE DEN', 3, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7621, '1998-01-04 23:00:00+00', '2018-04-03 00:07:34.633459+00', 'Bonnie Beatons, The', 'BONNIE BEATONS', 3, 32, 9999, 1, 3, 42, 703, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7623, '1998-01-05 23:00:00+00', '2018-04-03 00:07:34.892247+00', 'Bonnie Lass of Luss, The', 'BONNIE LASS OF LUSS', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7622, '1998-10-19 22:00:00+00', '2018-04-03 00:08:03.894492+00', 'Miss Betty Keddie', 'MISS BETTY KEDDIE', 3, 40, 9999, 1, 3, 42, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7669, '1998-04-24 22:00:00+00', '2018-04-03 16:03:30.596172+00', 'Dancers of Don, The', 'DANCERS OF DON', 4, 112, 29, 1, 4, NULL, 91, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7634, '1998-01-04 23:00:00+00', '2012-01-20 12:57:00.361598+00', 'Caroline Robertson''s Wedding', 'CAROLINE ROBERTSONS WEDDING', 3, 64, 9999, 4, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7636, '1997-12-02 23:00:00+00', '2012-01-20 12:57:00.375169+00', 'Carol''s Caper', 'CAROLS CAPER', 2, 32, 9999, 1, 4, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12682, '2006-02-16 23:00:00+00', '2022-09-23 15:07:36.820641+00', 'Bruce that Was, The', 'BRUCE THAT WAS', 2, 32, 9999, 1, 3, 42, 146, NULL, 'Inscribed "For Jean Baldwin (nee Bruce)".', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7551, '2002-02-16 23:00:00+00', '2022-10-23 19:40:13.196296+00', 'Wee Bairn''s Noo Awa'', The', 'WEE BAIRNS NOO AWA', 1, 32, 9999, 1, 3, 42, 2008, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7671, '2002-04-24 22:00:00+00', '2018-04-02 23:56:38.457454+00', 'Weaving 101', 'WEAVING 101', 1, 32, 9999, 1, 3, 42, 3097, '1997-03-27', '', 39, '8000|8880|8200|8000', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7638, '1997-08-31 22:00:00+00', '2012-01-20 12:57:00.38865+00', 'Castle Campbell', 'CASTLE CAMPBELL', 1, 48, 9999, 4, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7639, '1997-08-31 22:00:00+00', '2012-01-20 12:57:00.395436+00', 'Castle Keep, The', 'CASTLE KEEP', 1, 32, 9999, 4, 4, NULL, 757, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7640, '1997-09-30 22:00:00+00', '2012-01-20 12:57:00.4024+00', 'Castle Reel', 'CASTLE REEL', 1, 32, 9999, 1, 4, NULL, 1481, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7641, '1998-01-04 23:00:00+00', '2012-01-20 12:57:00.40923+00', 'Catherine Shaw''s Strathspey', 'CATHERINE SHAWS STRATHSPEY', 3, 32, 9999, 3, 5, NULL, 737, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7642, '1997-08-31 22:00:00+00', '2012-01-20 12:57:00.416011+00', 'Celebration, A', 'CELEBRATION', 4, 64, 9999, 1, 4, NULL, 762, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18644, '2018-09-18 22:38:03.313757+00', '2018-09-19 08:29:29.954611+00', 'Set and Think', 'SET AND THINK', 3, 32, NULL, 1, 3, 42, 11709, '2014-12-01', '', 59, '833/833/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12697, '2006-03-23 23:00:00+00', '2012-01-20 12:57:40.585209+00', 'Golden Crown, The', 'GOLDEN CROWN', 3, 32, 9999, 3, 5, NULL, 2115, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12698, '2006-03-23 23:00:00+00', '2012-01-20 12:57:40.593879+00', 'Golden Thread, The', 'GOLDEN THREAD', 2, 96, 9999, 4, 4, NULL, 146, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12700, '2006-03-23 23:00:00+00', '2012-01-20 12:57:40.611315+00', 'Hamilton Rendezvous', 'HAMILTON RENDEZVOUS', 1, 48, 9999, 1, 4, NULL, 3668, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12701, '2006-03-23 23:00:00+00', '2012-01-20 12:57:40.619973+00', 'Hamilton Steel', 'HAMILTON STEEL', 2, 32, 9999, 4, 4, NULL, 172, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12702, '2006-03-23 23:00:00+00', '2012-01-20 12:57:40.629009+00', 'Jackson Square', 'JACKSON SQUARE', 3, 32, 9999, 4, 4, NULL, 403, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18716, '2018-10-03 10:05:31.611797+00', '2018-10-03 10:05:31.611797+00', 'Crisscross', 'CRISSCROSS', 1, 32, NULL, 1, 3, 42, 2766, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12703, '2006-03-23 23:00:00+00', '2019-08-09 12:39:44.974135+00', 'Linked for Life', 'LINKED FOR LIFE', 3, 32, 9999, 1, 3, 42, 172, '2003-01-01', '', 44, '880/808/800/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12708, '2006-03-23 23:00:00+00', '2012-01-20 12:57:40.681365+00', 'Old 91st, The', 'OLD 91ST', 2, 32, 9999, 1, 4, NULL, 403, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14662, '2013-01-13 22:59:24.827808+00', '2013-01-13 22:59:24.82782+00', 'Nothing To Do', 'NOTHING TO DO', 2, 40, NULL, 1, 3, 42, 2918, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7643, '1997-12-02 23:00:00+00', '2012-01-20 12:57:00.422822+00', 'Celebration Jig', 'CELEBRATION JIG', 2, 40, 9999, 2, 3, NULL, 763, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7644, '1998-01-04 23:00:00+00', '2012-01-20 12:57:00.429686+00', 'Chain Gang, The', 'CHAIN GANG', 3, 64, 9999, 1, 4, NULL, 769, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7649, '1997-08-31 22:00:00+00', '2012-01-20 12:57:00.46366+00', 'Clatterin'' o'' Cheltenham', 'CLATTERIN O CHELTENHAM', 4, 64, 9999, 1, 4, NULL, 784, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7651, '2000-01-10 23:00:00+00', '2012-01-20 12:57:00.477188+00', 'Cobham Caper', 'COBHAM CAPER', 4, 64, 9999, 4, 4, NULL, 786, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7655, '1997-12-03 23:00:00+00', '2012-01-20 12:57:00.504683+00', 'Cooper''s Jig', 'COOPERS JIG', 2, 32, 9999, 1, 4, NULL, 737, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7657, '2002-04-29 22:00:00+00', '2012-01-20 12:57:00.519048+00', 'Coylumbridge', 'COYLUMBRIDGE', 1, 48, 9999, 3, 5, 16, 205, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7658, '1997-08-31 22:00:00+00', '2012-01-20 12:57:00.525879+00', 'Craigdarroch Reel', 'CRAIGDARROCH REEL', 1, 32, 9999, 1, 4, NULL, 801, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7661, '1998-01-04 23:00:00+00', '2012-01-20 12:57:00.546206+00', 'Crimson Together, The', 'CRIMSON TOGETHER', 3, 32, 9999, 1, 4, NULL, 232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7663, '1998-01-04 23:00:00+00', '2012-01-20 12:57:00.559829+00', 'Cross of Scotland Strathspey, The', 'CROSS OF SCOTLAND STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7664, '1998-01-04 23:00:00+00', '2012-01-20 12:57:00.566619+00', 'Crown Imperial', 'CROWN IMPERIAL', 3, 96, 9999, 1, 4, NULL, 807, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12709, '2006-03-23 23:00:00+00', '2012-01-20 12:57:40.690104+00', 'Paradise Road', 'PARADISE ROAD', 1, 32, 9999, 1, 4, NULL, 3665, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12710, '2006-03-23 23:00:00+00', '2012-01-20 12:57:40.69923+00', 'Piper of Saint Giles, The', 'PIPER OF SAINT GILES', 1, 128, 9999, 4, 4, NULL, 403, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12714, '2006-03-23 23:00:00+00', '2012-01-20 12:57:40.733903+00', 'Thinker, The', 'THINKER', 1, 32, 9999, 1, 4, NULL, 2115, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7632, '1997-08-31 22:00:00+00', '2018-04-03 00:07:37.045158+00', 'Carlisle Castle', 'CARLISLE CASTLE', 1, 40, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7633, '1997-08-31 22:00:00+00', '2018-04-03 00:07:37.053492+00', 'Carlisle Hornpipe, The', 'CARLISLE HORNPIPE', 1, 32, 9999, 1, 3, 42, 416, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7635, '1997-12-02 23:00:00+00', '2018-04-03 00:07:37.103538+00', 'Caroline''s Birthday', 'CAROLINES BIRTHDAY', 2, 32, 9999, 1, 3, 42, 750, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7646, '1997-12-03 23:00:00+00', '2018-04-03 00:07:38.396936+00', 'Christine''s Reel', 'CHRISTINES REEL', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7659, '1997-12-03 23:00:00+00', '2018-04-03 00:07:39.806824+00', 'Craigie Maidens, The', 'CRAIGIE MAIDENS', 2, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7660, '1997-08-31 22:00:00+00', '2018-04-03 00:07:40.015338+00', 'Crimson Tipped Flow''r', 'CRIMSON TIPPED FLOWR', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7666, '1997-12-03 23:00:00+00', '2018-04-03 00:07:40.490648+00', 'Culloden Moor', 'CULLODEN MOOR', 2, 32, 9999, 1, 3, 42, 809, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7667, '1997-09-01 22:00:00+00', '2018-04-03 00:07:40.866052+00', 'Dance for the Dales, A', 'DANCE FOR THE DALES', 1, 32, 9999, 1, 3, 42, 26, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7668, '1997-09-01 22:00:00+00', '2018-04-03 00:07:40.92441+00', 'Dance of the Demons', 'DANCE OF THE DEMONS', 1, 32, 9999, 1, 3, 42, 616, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12704, '2006-03-23 23:00:00+00', '2018-04-03 00:08:01.216309+00', 'MacNab Moment, A', 'MACNAB MOMENT', 1, 32, 9999, 1, 3, 42, 2115, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12688, '2006-02-16 23:00:00+00', '2021-01-11 11:11:28.582808+00', 'Maunby Reel, The', 'MAUNBY REEL', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 55, '707/888/844/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12685, '2006-02-16 23:00:00+00', '2021-01-11 11:20:57.39419+00', 'In Balance', 'IN BALANCE', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 53, '822/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7647, '2003-10-02 22:00:00+00', '2021-03-23 23:32:29.252307+00', 'Celtic Connection', 'CELTIC CONNECTION', 3, 64, 9999, 4, 4, 46, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7631, '2002-03-02 23:00:00+00', '2021-03-24 11:21:35.731076+00', 'Captain Bruce''s Jig', 'CAPTAIN BRUCES JIG', 2, 32, 9999, 1, 3, 42, 744, NULL, '', 34, '800/840/800/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12705, '2006-03-23 23:00:00+00', '2018-04-03 00:08:01.224785+00', 'MacNab Strathspey, The', 'MACNAB STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3665, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12707, '2006-03-23 23:00:00+00', '2018-04-03 00:08:02.708941+00', 'Maureen of Hamilton', 'MAUREEN OF HAMILTON', 3, 32, 9999, 1, 3, 42, 3666, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12711, '2006-03-23 23:00:00+00', '2018-04-03 00:08:12.916712+00', 'Rhonda''s 40th', 'RHONDAS 40TH', 3, 32, 9999, 1, 3, 42, 3669, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12712, '2006-03-23 23:00:00+00', '2018-04-03 00:08:14.834881+00', 'Salute to the Lancaster', 'SALUTE TO THE LANCASTER', 4, 32, 1, 1, 3, 42, 3670, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12713, '2006-03-23 23:00:00+00', '2018-04-03 00:08:20.047038+00', 'Tartan Tree, The', 'TARTAN TREE', 1, 32, 9999, 1, 3, 42, 172, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12721, '2006-04-25 22:00:00+00', '2012-01-20 12:57:40.796488+00', 'Miss Isabelle McCrearie''s Strathspey', 'MISS ISABELLE MACCREARIES STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12722, '2006-04-26 22:00:00+00', '2012-01-20 12:57:40.805172+00', 'Roving the Hebrides', 'ROVING THE HEBRIDES', 2, 48, 9999, 3, 5, NULL, 2886, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14663, '2013-01-13 23:03:50.580295+00', '2013-01-13 23:03:50.580306+00', 'Fifteen Years Ago', 'FIFTEEN YEARS AGO', 1, 32, NULL, 1, 4, 1, 3200, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7675, '1997-09-01 22:00:00+00', '2012-01-20 12:57:00.642507+00', 'De''il Tak the Hindmost', 'DEIL TAK THE HINDMOST', 1, 40, 9999, 1, 4, NULL, 821, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7704, '1998-11-01 23:00:00+00', '2019-06-15 12:57:11.034959+00', 'Helen''s Shortbread', 'HELENS SHORTBREAD', 1, 32, 9999, 1, 3, 42, 2071, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7677, '1997-12-03 23:00:00+00', '2012-01-20 12:57:00.656494+00', 'Devil''s Delight', 'DEVILS DELIGHT', 2, 48, 9999, 1, 4, NULL, 823, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7680, '1997-12-03 23:00:00+00', '2012-01-20 12:57:00.677061+00', 'Diane''s Delight', 'DIANES DELIGHT', 2, 32, 9999, 1, 4, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7683, '1997-09-01 22:00:00+00', '2012-01-20 12:57:00.698158+00', 'Dorothy''s Fancy', 'DOROTHYS FANCY', 1, 32, 9999, 1, 4, NULL, 815, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7684, '1997-12-03 23:00:00+00', '2012-01-20 12:57:00.704942+00', 'Dr Finlay', 'DR FINLAY', 2, 32, 9999, 1, 4, NULL, 1, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7689, '1997-09-01 22:00:00+00', '2012-01-20 12:57:00.753293+00', 'Duke and Duchess of Rothesay, The', 'DUKE AND DUCHESS OF ROTHESAY', 4, 96, 9999, 4, 4, NULL, 476, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7691, '1997-09-01 22:00:00+00', '2012-01-20 12:57:00.768051+00', 'Dundurn Castle', 'DUNDURN CASTLE', 3, 32, 9999, 5, 2, NULL, 852, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7693, '1997-09-01 22:00:00+00', '2012-01-20 12:57:00.781872+00', 'Dunmudden', 'DUNMUDDEN', 4, 128, 9999, 5, 2, NULL, 605, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7697, '1997-12-28 23:00:00+00', '2012-01-20 12:57:00.812064+00', 'Eadie was a Lady', 'EADIE WAS A LADY', 3, 32, 9999, 1, 2, NULL, 737, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7698, '1997-09-18 22:00:00+00', '2012-01-20 12:57:00.81882+00', 'Eildon Hills, The', 'EILDON HILLS', 1, 32, 9999, 3, 5, NULL, 1, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7699, '1997-12-03 23:00:00+00', '2012-01-20 12:57:00.825646+00', 'Eilean Donan Castle', 'EILEAN DONAN CASTLE', 2, 96, 9999, 1, 4, NULL, 864, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12723, '2006-04-26 22:00:00+00', '2012-01-20 12:57:40.813931+00', 'Lochranza Castle', 'LOCHRANZA CASTLE', 1, 48, 9999, 4, 4, NULL, 2886, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12725, '2006-04-26 22:00:00+00', '2012-01-20 12:57:40.832321+00', 'Craignure Reel', 'CRAIGNURE REEL', 1, 32, 9999, 3, 5, 16, 2886, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12727, '2006-04-26 22:00:00+00', '2012-01-20 12:57:40.850728+00', 'Round Douglas Reel', 'ROUND DOUGLAS REEL', 1, 88, 9999, 4, 4, NULL, 27, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12730, '2006-05-02 22:00:00+00', '2012-01-20 12:57:40.876919+00', 'Welcome Back', 'WELCOME BACK', 2, 40, 9999, 4, 4, NULL, 2886, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14664, '2013-01-13 23:06:36.321454+00', '2013-01-13 23:15:20.319646+00', 'Butterfly, The', 'BUTTERFLY', 3, 128, NULL, 10, 8, NULL, 10708, '1984-01-01', 'This is a very complicated 8 Couple dance, suitable only for demonstrations by very advanced dancers.  For details the original instructions are the only suitable source.', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7702, '1997-12-03 23:00:00+00', '2012-01-20 12:57:00.846425+00', 'Elder Statesman of Sandbach, The', 'ELDER STATESMAN OF SANDBACH', 2, 32, 9999, 1, 4, NULL, 866, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7703, '2001-07-05 22:00:00+00', '2012-01-20 12:57:00.853258+00', 'End is Oft the Beginning, The', 'END IS OFT THE BEGINNING', 1, 80, 9999, 4, 4, NULL, 875, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7708, '2000-02-13 23:00:00+00', '2012-01-20 12:57:00.88801+00', 'Fair City Strathspey, The', 'FAIR CITY STRATHSPEY', 3, 32, 9999, 2, 3, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7709, '1998-01-05 23:00:00+00', '2012-01-20 12:57:00.894816+00', 'Fairy Hillock, The', 'FAIRY HILLOCK', 1, 32, 9999, 1, 2, NULL, 788, '1983-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7710, '1997-09-02 22:00:00+00', '2012-01-20 12:57:00.901694+00', 'Falmouth Oyster, The', 'FALMOUTH OYSTER', 1, 32, 9999, 6, 3, NULL, 626, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7712, '1997-09-02 22:00:00+00', '2012-01-20 12:57:00.915813+00', 'Farewell to Stover', 'FAREWELL TO STOVER', 1, 32, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7672, '2000-07-26 22:00:00+00', '2018-04-03 00:07:41.358166+00', 'Dannsa Air Son Ceither An T-Uichar, An', 'DANNSA AIR SON CEITHER AN TUICHAR', 1, 32, 9999, 1, 3, 42, 818, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7673, '1997-12-03 23:00:00+00', '2018-04-03 00:07:41.525008+00', 'Dawn''s Delight', 'DAWNS DELIGHT', 2, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7676, '1997-09-01 22:00:00+00', '2018-04-03 00:07:41.791988+00', 'Denmore Reel, The', 'DENMORE REEL', 1, 32, 9999, 1, 3, 42, 108, '1979-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7685, '1997-09-01 22:00:00+00', '2018-04-03 00:07:43.001331+00', 'Drewry Days, The', 'DREWRY DAYS', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7688, '1997-09-01 22:00:00+00', '2018-04-03 00:07:43.209916+00', 'Dubliners', 'DUBLINERS', 1, 32, 9999, 1, 3, 42, 214, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7690, '1997-12-03 23:00:00+00', '2018-04-03 00:07:43.276755+00', 'Duke of Claverhouse, The', 'DUKE OF CLAVERHOUSE', 2, 32, 9999, 1, 3, 42, 824, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7695, '1997-09-01 22:00:00+00', '2018-04-03 00:07:43.626937+00', 'Durham Reel, The', 'DURHAM REEL', 1, 32, 9999, 1, 3, 42, 824, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7701, '1997-12-28 23:00:00+00', '2018-04-03 00:07:44.193999+00', 'Eilean Donan Strathspey, The', 'EILEAN DONAN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 737, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7706, '1997-12-03 23:00:00+00', '2018-04-03 00:07:44.769334+00', 'Evelyn''s Reel', 'EVELYNS REEL', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12734, '2006-05-02 22:00:00+00', '2019-12-06 11:28:20.094777+00', 'Christmas Party Jig, A', 'CHRISTMAS PARTY JIG', 2, 128, 9999, 4, 4, 3, 2886, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7692, '1997-09-01 22:00:00+00', '2020-01-11 01:55:24.623394+00', 'Dunedin Ha''', 'DUNEDIN HA', 1, 128, 9999, NULL, 4, NULL, 853, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12733, '2006-05-02 22:00:00+00', '2020-01-22 18:01:16.232682+00', 'River Dee Strathspey, The', 'RIVER DEE STRATHSPEY', 3, 64, 9999, 4, 4, 3, 2886, '2005-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7656, '2002-04-30 22:00:00+00', '2020-09-04 14:01:40.55092+00', 'Wee Bus, The', 'WEE BUS', 1, 32, 9999, 1, 3, 42, 520, '1995-01-01', '', 50, '880/880/844/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7687, '1997-12-03 23:00:00+00', '2020-09-04 14:26:42.21412+00', 'Drunkard''s Dream, The', 'DRUNKARDS DREAM', 2, 32, 9999, 1, 3, 42, 845, NULL, '', 50, '840/804/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12719, '2006-04-02 22:00:00+00', '2020-12-29 12:12:38.156341+00', 'Dancing Professor, The', 'DANCING PROFESSOR', 3, 32, 9999, 2, 3, 17, 3673, '2004-01-01', '', 77, '880/868/228/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7678, '1997-09-01 22:00:00+00', '2020-12-31 23:06:06.338902+00', 'Devil''s Elbow, The', 'DEVILS ELBOW', 1, 32, 9999, 1, 3, 42, 824, NULL, '', 63, '800/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12732, '2006-05-02 22:00:00+00', '2021-01-09 21:34:16.604157+00', '15th Anniversary Reel', '15TH ANNIVERSARY REEL', 1, 40, 9999, 1, 4, 1, 2886, '2005-01-01', '', 91, '8888/8888/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12731, '2006-05-02 22:00:00+00', '2021-01-09 21:36:29.486256+00', '15th Anniversary Strathspey', '15TH ANNIVERSARY STRATHSPEY', 3, 32, 9999, 4, 5, 16, 2886, '2005-01-01', '', 63, '80808/08088/44448/84448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12724, '2006-04-26 22:00:00+00', '2021-01-10 21:00:51.042609+00', 'Welcome to Mull, A', 'WELCOME TO MULL', 2, 32, 9999, 5, 56, NULL, 2886, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12706, '2006-03-23 23:00:00+00', '2021-01-10 21:11:59.065889+00', 'Mansewood Reel, The', 'MANSEWOOD REEL', 1, 32, 9999, 1, 3, 42, 463, NULL, '', 59, '888/840/808/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12728, '2006-04-27 22:00:00+00', '2021-01-27 16:21:47.873379+00', 'Betty Grant''s Strathspey', 'BETTY GRANTS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 440, NULL, '', 56, '800/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7711, '1997-09-02 22:00:00+00', '2018-04-03 00:07:45.219869+00', 'Farewell to Rodney', 'FAREWELL TO RODNEY', 3, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7713, '1997-09-02 22:00:00+00', '2018-04-03 00:07:45.395202+00', 'Felizitations', 'FELIZITATIONS', 3, 40, 9999, 1, 3, 42, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7674, '1997-09-02 22:00:00+00', '2018-04-03 00:07:47.030006+00', 'Friends From The South', 'FRIENDS FROM THE SOUTH', 3, 32, 9999, 1, 3, 42, 932, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7707, '1997-12-03 23:00:00+00', '2018-04-03 00:07:47.188481+00', 'Frustration', 'FRUSTRATION', 2, 32, 9999, 1, 3, 42, 936, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12716, '2006-03-23 23:00:00+00', '2018-04-03 00:08:24.916618+00', 'Westdale Strathspey, The', 'WESTDALE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3671, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7717, '1997-09-02 22:00:00+00', '2012-01-20 12:57:00.950491+00', 'G.A.F.L.A.C. Jubilee Strathspey', 'GAFLAC JUBILEE STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7719, '1998-11-01 23:00:00+00', '2012-01-20 12:57:00.964298+00', 'Galloway Dancers Salute to St Valery, The', 'GALLOWAY DANCERS SALUTE TO ST VALERY', 1, 40, 9999, 1, 4, NULL, 852, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7724, '1997-09-03 22:00:00+00', '2012-01-20 12:57:00.998704+00', 'George MacGregor-Reid Strathspey, The', 'GEORGE MACGREGORREID STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7725, '1997-09-03 22:00:00+00', '2012-01-20 12:57:01.00582+00', 'George''s 80th', 'GEORGES 80TH', 4, 128, 9999, 4, 4, NULL, 949, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7726, '1997-09-03 22:00:00+00', '2012-01-20 12:57:01.012719+00', 'Gillian''s Wedding', 'GILLIANS WEDDING', 3, 48, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7727, '1997-09-03 22:00:00+00', '2012-01-20 12:57:01.019486+00', 'Glamis Castle', 'GLAMIS CASTLE', 1, 128, 9999, 4, 4, NULL, 953, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12741, '2006-05-11 22:00:00+00', '2012-01-20 12:57:40.97452+00', 'Surfing the Web', 'SURFING THE WEB', 3, 32, 9999, 2, 3, 17, 1445, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7728, '1997-09-03 22:00:00+00', '2012-01-20 12:57:01.026268+00', 'Glasgow Green', 'GLASGOW GREEN', 1, 40, 9999, 1, 4, NULL, 929, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7729, '1997-09-03 22:00:00+00', '2012-01-20 12:57:01.033452+00', 'Glen Etive', 'GLEN ETIVE', 3, 32, 9999, 3, 5, NULL, 606, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7732, '1997-09-03 22:00:00+00', '2012-01-20 12:57:01.054366+00', 'Golden Dreams', 'GOLDEN DREAMS', 3, 32, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7734, '1997-09-03 22:00:00+00', '2012-01-20 12:57:01.067984+00', 'Golden Leaf, The', 'GOLDEN LEAF', 3, 48, 9999, 1, 4, NULL, 729, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7735, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.074854+00', 'Goldsmith', 'GOLDSMITH', 2, 32, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7740, '2000-04-25 22:00:00+00', '2012-01-20 12:57:01.11225+00', 'Green Oak Tree, The', 'GREEN OAK TREE', 3, 96, 9999, 4, 4, NULL, 974, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7746, '1997-09-04 22:00:00+00', '2012-01-20 12:57:01.155631+00', 'Hutchings Tribute, The', 'HUTCHINGS TRIBUTE', 3, 32, 9999, 1, 4, NULL, 216, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7747, '1997-09-04 22:00:00+00', '2012-01-20 12:57:01.162455+00', 'Ian Powrie''s Return to Scotland', 'IAN POWRIES RETURN TO SCOTLAND', 1, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7749, '1997-10-29 23:00:00+00', '2012-01-20 12:57:01.176521+00', 'In Memory of Sheila', 'IN MEMORY OF SHEILA', 3, 32, 9999, 3, 5, NULL, 606, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7750, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.183345+00', 'Inner Wheel Jig, The', 'INNER WHEEL JIG', 2, 48, 9999, 1, 4, NULL, 988, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7752, '2000-04-25 22:00:00+00', '2012-01-20 12:57:01.19703+00', 'Inverclyde', 'INVERCLYDE', 2, 32, 9999, 1, 2, NULL, 108, '1985-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7754, '1997-09-04 22:00:00+00', '2012-01-20 12:57:01.211963+00', 'Iska''s Reel', 'ISKAS REEL', 1, 32, 9999, 1, 4, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7757, '1997-09-04 22:00:00+00', '2012-01-20 12:57:01.232904+00', 'Jacobite, The', 'JACOBITE', 1, 48, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12738, '2006-05-11 22:00:00+00', '2018-04-03 00:07:46.029054+00', 'Fisherwoman''s Strathspey, The', 'FISHERWOMANS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1445, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12740, '2006-05-11 22:00:00+00', '2015-03-03 22:18:01.603932+00', 'Joanna''s Reel', 'JOANNAS REEL', 1, 40, 9999, 1, 3, 42, 1445, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7716, '1997-09-02 22:00:00+00', '2018-04-03 00:07:47.422058+00', 'Fyfe''s Fancy', 'FYFES FANCY', 1, 32, 9999, 1, 3, 42, 146, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7718, '1997-09-02 22:00:00+00', '2018-04-03 00:07:47.563561+00', 'G.A.F.L.A.C.''s Farewell to Rodney', 'GAFLACS FAREWELL TO RODNEY', 3, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7720, '1997-12-03 23:00:00+00', '2018-04-03 00:07:47.672031+00', 'Galloway Pageant Reel, The', 'GALLOWAY PAGEANT REEL', 2, 40, 9999, 1, 3, 42, 939, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7721, '2000-04-25 22:00:00+00', '2018-04-03 00:07:47.713747+00', 'Gantock Gathering, The', 'GANTOCK GATHERING', 1, 32, 9999, 1, 3, 42, 663, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7722, '1997-12-03 23:00:00+00', '2018-04-03 00:07:47.763981+00', 'Garden Festival Jig, The', 'GARDEN FESTIVAL JIG', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7730, '1997-09-03 22:00:00+00', '2018-04-03 00:07:49.040627+00', 'Gloucester Reel, The', 'GLOUCESTER REEL', 1, 32, 9999, 1, 3, 42, 616, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7733, '1997-09-03 22:00:00+00', '2018-04-03 00:07:49.240775+00', 'Golden Harvest', 'GOLDEN HARVEST', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7737, '1997-12-03 23:00:00+00', '2018-04-03 00:07:49.440833+00', 'Go Straight Home', 'GO STRAIGHT HOME', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7739, '1997-09-03 22:00:00+00', '2018-04-03 00:07:49.75783+00', 'Greenbank Garden', 'GREENBANK GARDEN', 1, 32, 9999, 1, 3, 42, 972, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7743, '2001-07-05 22:00:00+00', '2018-04-03 00:07:50.591703+00', 'Hamish''s Trip to Inverary', 'HAMISHS TRIP TO INVERARY', 3, 32, 9999, 1, 3, 42, 636, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7742, '2001-07-05 22:00:00+00', '2018-04-03 00:07:52.951663+00', 'Housemouse, The', 'HOUSEMOUSE', 2, 32, 9999, 1, 3, 42, 259, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7753, '1997-12-03 23:00:00+00', '2018-04-03 00:07:53.685525+00', 'Inverlea', 'INVERLEA', 2, 32, 9999, 1, 3, 42, 783, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7755, '1997-09-04 22:00:00+00', '2018-04-03 00:07:53.927541+00', 'Isle of Arran', 'ISLE OF ARRAN', 3, 32, 9999, 1, 3, 42, 824, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7756, '1997-12-03 23:00:00+00', '2018-04-03 00:07:54.752904+00', 'Jackanella', 'JACKANELLA', 2, 32, 9999, 1, 3, 42, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7879, '1997-12-03 23:00:00+00', '2018-04-03 00:08:09.497635+00', 'Overlander', 'OVERLANDER', 2, 48, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7741, '1997-12-03 23:00:00+00', '2020-08-05 11:36:37.236598+00', 'Grey Mare''s Tail, The', 'GREY MARES TAIL', 4, 96, 63, 2, 3, NULL, 105, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7714, '1997-09-02 22:00:00+00', '2020-09-04 14:29:32.876928+00', 'Fellowship Reel, The', 'FELLOWSHIP REEL', 1, 32, 9999, 1, 3, 42, 190, NULL, '', 56, '800/888/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12718, '2006-03-23 23:00:00+00', '2020-09-15 09:57:57.778674+00', 'Wind in Our Sails, The', 'WIND IN OUR SAILS', 2, 32, 9999, 1, 3, 42, 2115, NULL, '', 72, '866/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7748, '1997-12-03 23:00:00+00', '2020-09-16 07:50:25.073603+00', 'I Love to Wear the Kilt', 'I LOVE TO WEAR THE KILT', 2, 32, 9999, 1, 3, 18, 1, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7723, '2003-01-19 23:00:00+00', '2021-03-23 21:25:14.188302+00', 'George Fleming''s Tribute to the Timor', 'GEORGE FLEMINGS TRIBUTE TO THE TIMOR', 4, 64, 9999, 4, 4, NULL, 947, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12761, '2006-05-21 22:00:00+00', '2018-08-20 13:48:06.242025+00', 'Fiona Mackie''s Jig', 'FIONA MACKIES JIG', 2, 32, 9999, 1, 4, 2, 2910, '2005-01-01', 'Dedicated to Fiona Mackie who has been Scottish Country Dancing since the age of four.', 88, '8888/8448/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12763, '2006-05-21 22:00:00+00', '2018-08-21 21:31:15.857791+00', 'Fiona Paulin''s Bairns', 'FIONA PAULINS BAIRNS', 1, 32, 9999, 1, 2, 76, 3682, NULL, 'As Fiona is Youth Co-ordinator it seemed appropriate that this dance should be a children''s dance. Therefore it is a simple dance that even the adults should be able to cope with, although there are of course no guarantees. ', 38, '80/88/80/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7744, '1998-01-01 23:00:00+00', '2012-05-07 20:47:41.980359+00', 'Howkin'' the Parks', 'HOWKIN THE PARKS', 2, 32, 9999, 1, 3, 42, 1007, '1988-10-01', 'Devised at a Branch Weekend at Pitlochry Hydro Hotel, for Tom Miller (The Barman)', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7758, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.241056+00', 'Jane''s Jig', 'JANES JIG', 2, 48, 9999, 1, 4, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7783, '1997-09-07 22:00:00+00', '2019-02-08 20:34:50.518034+00', 'Kirrie Kebbuck, The', 'KIRRIE KEBBUCK', 3, 32, 9999, 1, 3, 42, 108, '1971-01-01', '', 59, '800/888/888/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7761, '1997-09-04 22:00:00+00', '2012-01-20 12:57:01.261823+00', 'Jean Crepin''s Jig', 'JEAN CREPINS JIG', 1, 48, 9999, 1, 4, NULL, 1018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7762, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.268594+00', 'Jeanette''s Jig', 'JEANETTES JIG', 2, 32, 9999, 1, 4, NULL, 1019, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7763, '2002-01-08 23:00:00+00', '2012-01-20 12:57:01.275375+00', 'Jean of Logie Park', 'JEAN OF LOGIE PARK', 2, 72, 9999, 4, 4, NULL, 1026, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7765, '1997-09-04 22:00:00+00', '2012-01-20 12:57:01.28917+00', 'Jean''s Reel', 'JEANS REEL', 3, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7766, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.295945+00', 'Jig for Allan and Gladys, A', 'JIG FOR ALLAN AND GLADYS', 2, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7768, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.310036+00', 'Jig for Mr Twhigg, A', 'JIG FOR MR TWHIGG', 2, 32, 9999, 1, 2, NULL, 667, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18645, '2018-09-18 22:40:55.553709+00', '2018-09-19 08:28:25.198405+00', 'Siller in Baith Pouches', 'SILLER IN BAITH POUCHES', 2, 32, NULL, 1, 3, 42, 11710, '2014-09-01', '', 56, '800/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1069, '1997-08-31 22:00:00+00', '2018-10-30 04:46:10.619656+00', 'Castle in the Glen, The', 'CASTLE IN THE GLEN', 3, 32, 9999, 1, 3, 42, 44, NULL, '', 44, '880/800/822/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7773, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.344347+00', 'Julie''s Jig', 'JULIES JIG', 2, 32, 9999, 3, 5, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7798, '1997-12-03 23:00:00+00', '2018-04-03 00:07:59.373274+00', 'Letham Glen', 'LETHAM GLEN', 2, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7816, '1997-09-08 22:00:00+00', '2012-01-20 12:57:01.655082+00', 'McLellan Strathspey, The', 'MACLELLAN STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 1093, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12747, '2006-05-11 22:00:00+00', '2022-12-22 18:21:06.647467+00', 'Bill Jacob''s Jig', 'BILL JACOBS JIG', 2, 32, 9999, 1, 4, 1, 725, '2001-01-01', '', 66, '8080/8080/8888/8444', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12755, '2006-05-11 22:00:00+00', '2022-12-22 18:24:54.667027+00', 'Dance of the Red Moon, The', 'DANCE OF THE RED MOON', 1, 32, 9999, 1, 4, NULL, 3681, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12749, '2006-05-11 22:00:00+00', '2022-12-22 18:26:34.297851+00', 'Glenys Pearce''s Strathspey', 'GLENYS PEARCES STRATHSPEY', 3, 32, 9999, 1, 4, 1, 725, '2001-01-01', '', 67, '8484/8888/8080/8222', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12750, '2006-05-11 22:00:00+00', '2022-12-22 18:27:56.396561+00', 'Lochiel''s Farewell to Tony Szeto', 'LOCHIELS FAREWELL TO TONY SZETO', 1, 40, 9999, 1, 3, 42, 3679, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12752, '2006-05-11 22:00:00+00', '2022-12-22 18:31:02.212006+00', 'Simon Barbour''s Rant', 'SIMON BARBOURS RANT', 2, 64, 9999, 1, 4, NULL, 725, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12765, '2006-05-21 22:00:00+00', '2019-02-03 21:02:41.013279+00', 'Tom McLeod''s Strathspey', 'TOM MACLEODS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3682, NULL, 'Tom McLeod has been a member of the Dundee Branch of the RSCDS for many years. He has also been chairman and treasurer, and still enjoys his dancing.', 48, '880/860/844/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12760, '2006-05-21 22:00:00+00', '2019-02-28 21:27:53.66416+00', 'Old Harbour, The', 'OLD HARBOUR', 1, 96, 9999, 4, 4, 3, 3682, NULL, '', 75, '4444/4444/4444/4444/8888/6666/6666/4444/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7784, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.436498+00', 'Kitty''s Knitting', 'KITTYS KNITTING', 2, 32, 9999, 1, 2, NULL, 932, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7786, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.450042+00', 'Ladies of the Board', 'LADIES OF THE BOARD', 2, 40, 9999, 3, 5, NULL, 600, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12780, '2006-06-14 22:00:00+00', '2018-04-03 00:07:33.746824+00', 'Bleary-Eyed Laddie', 'BLEARYEYED LADDIE', 1, 32, 9999, 1, 3, 42, 9998, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7881, '1997-12-03 23:00:00+00', '2012-01-20 12:57:02.088603+00', 'Pam''s Party', 'PAMS PARTY', 2, 32, 9999, 1, 4, NULL, 1191, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7787, '1997-09-07 22:00:00+00', '2012-01-20 12:57:01.456884+00', 'Victoria Reel', 'VICTORIA REEL', 1, 160, 9999, 4, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7759, '1997-09-04 22:00:00+00', '2018-04-03 00:07:54.903048+00', 'Janet''s Reel', 'JANETS REEL', 3, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7760, '1997-12-03 23:00:00+00', '2018-04-03 00:07:55.05308+00', 'Jean Black''s Jig', 'JEAN BLACKS JIG', 2, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7767, '1997-12-03 23:00:00+00', '2018-04-03 00:07:55.545165+00', 'Jig for Molly Brown, A', 'JIG FOR MOLLY BROWN', 2, 32, 9999, 1, 3, 42, 1022, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7769, '1997-12-03 23:00:00+00', '2018-04-03 00:07:55.570239+00', 'Jig for Wendy, A', 'JIG FOR WENDY', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7764, '1997-12-03 23:00:00+00', '2018-04-03 00:07:56.287326+00', 'Johnson''s Jaunt, The', 'JOHNSONS JAUNT', 2, 32, 9999, 1, 3, 42, 136, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7770, '1997-12-03 23:00:00+00', '2018-04-03 00:07:56.295757+00', 'John''s Salute to Figures of Eight', 'JOHNS SALUTE TO FIGURES OF EIGHT', 2, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7771, '1997-12-03 23:00:00+00', '2018-04-03 00:07:56.304121+00', 'John''s Salute to Frank Robertson', 'JOHNS SALUTE TO FRANK ROBERTSON', 2, 48, 9999, 1, 3, 42, 619, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7772, '1997-09-05 22:00:00+00', '2018-04-03 00:07:56.46244+00', 'Journey''s End', 'JOURNEYS END', 3, 32, 9999, 1, 3, 42, 114, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7776, '1997-09-05 22:00:00+00', '2018-04-03 00:07:56.829249+00', 'Just for Jack', 'JUST FOR JACK', 4, 64, 9999, 1, 3, 42, 968, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7777, '1997-12-03 23:00:00+00', '2018-04-03 00:07:56.845897+00', 'Just Short', 'JUST SHORT', 2, 24, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7779, '1997-09-07 22:00:00+00', '2018-04-03 00:07:57.404942+00', 'King Arthur and His Knights', 'KING ARTHUR AND HIS KNIGHTS', 99, 48, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7789, '1997-09-07 22:00:00+00', '2018-04-03 00:07:58.272191+00', 'Lady Graham''s Strathspey', 'LADY GRAHAMS STRATHSPEY', 3, 48, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7791, '1997-09-07 22:00:00+00', '2018-04-03 00:07:58.464049+00', 'Lady Stewart MacPherson', 'LADY STEWART MACPHERSON', 1, 48, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7792, '1997-12-03 23:00:00+00', '2018-04-03 00:07:58.60585+00', 'Lake House', 'LAKE HOUSE', 2, 32, 9999, 1, 3, 42, 329, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12778, '2006-06-14 22:00:00+00', '2018-04-03 00:08:01.624902+00', 'Mairi''s Scandalous Illicit Affair', 'MAIRIS SCANDALOUS ILLICIT AFFAIR', 1, 40, 9999, 1, 3, 42, 1113, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7788, '1997-09-07 22:00:00+00', '2018-04-03 00:08:06.760708+00', 'Mrs Will', 'MRS WILL', 3, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7794, '1997-09-07 22:00:00+00', '2012-01-20 12:57:01.504624+00', 'Lang Toun, The', 'LANG TOUN', 1, 48, 9999, 1, 4, NULL, 1062, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7796, '1997-09-07 22:00:00+00', '2012-01-20 12:57:01.518234+00', 'Last Week, The', 'LAST WEEK', 3, 32, 9999, 2, 3, NULL, 1066, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7800, '1997-09-07 22:00:00+00', '2012-01-20 12:57:01.545372+00', 'Lifeboat Service, A', 'LIFEBOAT SERVICE', 1, 32, 9999, 1, 4, NULL, 1074, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7801, '1997-09-07 22:00:00+00', '2012-01-20 12:57:01.552164+00', 'Linthouse Park', 'LINTHOUSE PARK', 1, 128, 9999, 4, 4, NULL, 929, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7780, '1997-09-07 22:00:00+00', '2020-08-06 15:21:44.001595+00', 'Kingdom of Strathclyde, The', 'KINGDOM OF STRATHCLYDE', 3, 96, 9999, 4, 4, NULL, 105, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7790, '1997-09-07 22:00:00+00', '2020-09-05 10:08:31.58187+00', 'Lichted Ha'', The', 'LICHTED HA', 3, 40, 9999, 1, 3, 42, 270, NULL, '', 42, '800/800/844/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7781, '1998-04-24 22:00:00+00', '2021-03-23 20:58:39.469829+00', 'King Neptune', 'KING NEPTUNE', 1, 32, 9999, 1, 3, 42, 352, NULL, '', 50, '800/888/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7803, '1997-09-07 22:00:00+00', '2012-01-20 12:57:01.565771+00', 'Little Loch Broom', 'LITTLE LOCH BROOM', 3, 32, 9999, 2, 3, NULL, 26, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7804, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.572548+00', 'Little Miss Cindy', 'LITTLE MISS CINDY', 2, 40, 9999, 1, 2, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14683, '2013-01-23 12:30:20.811374+00', '2018-10-24 21:17:48.790903+00', 'Platinum Strathspey, The', 'PLATINUM STRATHSPEY', 3, 32, NULL, 2, 3, 17, 10724, '2005-12-01', 'Dedicated to her husband Crichton and other dancing friends', 75, '484/484/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15490, '2014-06-27 20:59:28.973559+00', '2019-01-22 23:12:15.213681+00', 'Take It One Step at a Time', 'TAKE IT ONE STEP AT A TIME', 2, 32, NULL, 1, 4, 1, 10971, NULL, '', 61, '8008/0880/8888/8222', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7808, '1997-12-28 23:00:00+00', '2012-01-20 12:57:01.599671+00', 'London Lassies', 'LONDON LASSIES', 3, 40, 9999, 1, 4, NULL, 737, NULL, '8 ladies', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7815, '1997-09-08 22:00:00+00', '2019-02-23 12:07:47.80068+00', 'McCrae Homestead', 'MACCRAE HOMESTEAD', 3, 40, 9999, 4, 4, NULL, 9998, NULL, 'Previously, but incorrectly, attributed to John A Johnston (see http://my.strathspey.org/dd/issue/1643/).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7810, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.61368+00', 'Lorri''s Jig', 'LORRIS JIG', 2, 32, 9999, 5, 2, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7813, '1997-09-08 22:00:00+00', '2012-01-20 12:57:01.634115+00', 'Lynda''s Reel', 'LYNDAS REEL', 3, 32, 9999, 2, 3, NULL, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12783, '2006-06-14 22:00:00+00', '2012-01-20 12:57:41.322096+00', 'Nessie to the Bottom', 'NESSIE TO THE BOTTOM', 3, 32, 9999, 1, 4, 1, 3369, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7802, '1997-12-03 23:00:00+00', '2018-04-02 23:56:35.928028+00', 'Lisburn Lad, The', 'LISBURN LAD', 2, 32, 9999, 1, 3, 42, 1078, '1992-01-01', 'The ''Lisburn Lad'' was devised in 1992 by Angus Stephen, President, for Bob Brown (since sadly deceased) who was ASHMERG Dance Director for many years, and hailed from Lisburn.', -1, '888 800 844 888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12787, '2006-06-14 22:00:00+00', '2012-01-20 12:57:41.360149+00', 'Sylvander & Clarinda', 'SYLVANDER AND CLARINDA', 3, 32, 9999, 1, 2, NULL, 1113, '2005-01-01', 'Devised: 2005', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12791, '2006-06-25 22:00:00+00', '2012-01-20 12:57:41.39871+00', 'Breton Gathering, A', 'BRETON GATHERING', 3, 48, 9999, 2, 3, 17, 872, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14682, '2013-01-23 11:37:36.920704+00', '2013-01-23 13:27:12.998808+00', 'Reel o'' Deans', 'REEL O DEANS', 1, 32, NULL, 1, 4, 1, 10723, '2006-02-01', 'Deans Community Centre Livingston, where Grace holds her class.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12782, '2006-06-14 22:00:00+00', '2018-04-03 00:07:36.819705+00', 'Candy is Dandy but Liquor is Quicker', 'CANDY IS DANDY BUT LIQUOR IS QUICKER', 4, 32, 1, 1, 3, 42, 1113, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11737, '2004-07-06 22:00:00+00', '2018-04-03 00:07:58.280479+00', 'Lady in a Shawl, The', 'LADY IN A SHAWL', 3, 32, 9999, 1, 3, 42, 619, '1999-01-01', 'Inscribed to Mrs Dorothy Reid for her birthday March 1999', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12781, '2006-06-14 22:00:00+00', '2022-08-19 09:12:14.775779+00', 'Don''t Forget Your Ghillies', 'DONT FORGET YOUR GHILLIES', 2, 32, 9999, 1, 3, 42, 3371, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12785, '2006-06-14 22:00:00+00', '2022-09-30 11:23:41.346777+00', 'Halloween Medley', 'HALLOWEEN MEDLEY', 4, 32, 1, 1, 4, 1, 3369, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12757, '2006-05-11 22:00:00+00', '2022-12-22 18:23:40.66478+00', 'Cuddy Alang', 'CUDDY ALANG', 2, 32, 9999, 1, 3, 42, 725, '2000-01-01', '', 47, '402/402/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12758, '2006-05-11 22:00:00+00', '2022-12-22 18:29:56.345689+00', 'Odd Couple, The', 'ODD COUPLE', 2, 32, 9999, 1, 3, 42, 3679, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7817, '1997-09-08 22:00:00+00', '2012-01-20 12:57:01.662001+00', 'MacQuarie Harbour', 'MACQUARIE HARBOUR', 1, 32, 9999, 1, 4, NULL, 1095, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7818, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.668779+00', 'Edmund Mackenzie of Plockton', 'EDMUND MACKENZIE OF PLOCKTON', 2, 48, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12784, '2006-06-14 22:00:00+00', '2016-05-11 22:35:10.265325+00', 'PLWOGDHSCDTTBLD', 'PLWOGDHSCDTTBLD', 1, 32, 9999, 105, 54, NULL, 3371, NULL, 'A 32 bar Jig, Reel, or Strathspey for four (or more) people in a line. Great for areas where you have limited space to form a set, as in a small pub and you want to dance between the tables.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7837, '1999-02-14 23:00:00+00', '2016-05-13 14:38:25.04018+00', 'Spinster, The', 'SPINSTER', 1, 48, 9999, 107, 55, NULL, 2558, NULL, 'For two men, three women; in sets of seven people', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7799, '1997-12-03 23:00:00+00', '2018-04-03 00:07:59.381563+00', 'Letham Saint Mark''s Jig', 'LETHAM SAINT MARKS JIG', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7805, '1997-12-03 23:00:00+00', '2018-04-03 00:07:59.832005+00', 'Little Steven''s Jig', 'LITTLE STEVENS JIG', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7806, '1997-09-07 22:00:00+00', '2018-04-03 00:07:59.873626+00', 'Liz''s Strathspey', 'LIZS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7807, '1997-09-08 22:00:00+00', '2018-04-03 00:08:00.048743+00', 'Loch Creran', 'LOCH CRERAN', 3, 32, 9999, 1, 3, 42, 644, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7809, '1997-12-03 23:00:00+00', '2018-04-03 00:08:00.730903+00', 'Lorna''s Jig', 'LORNAS JIG', 2, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7819, '1997-12-03 23:00:00+00', '2018-04-03 00:08:01.441344+00', 'Madge Bayne', 'MADGE BAYNE', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7821, '1997-09-08 22:00:00+00', '2018-04-03 00:08:01.483125+00', 'Maelga''s Heart', 'MAELGAS HEART', 1, 32, 9999, 1, 3, 42, 1099, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12788, '2006-06-14 22:00:00+00', '2018-04-03 00:08:13.350526+00', 'Roamin'' Robbie', 'ROAMIN ROBBIE', 3, 32, 9999, 1, 3, 42, 3369, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7822, '1997-09-08 22:00:00+00', '2012-01-20 12:57:01.689216+00', 'Memories of Bulawayo', 'MEMORIES OF BULAWAYO', 4, 128, 9999, 1, 4, NULL, 329, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7824, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.703566+00', 'Merry Mandy', 'MERRY MANDY', 2, 32, 9999, 1, 4, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7827, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.724181+00', 'Merry Round, The', 'MERRY ROUND', 2, 32, 9999, 5, 2, NULL, 647, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7830, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.744662+00', 'Milton of Campsie, The', 'MILTON OF CAMPSIE', 2, 32, 9999, 1, 4, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18646, '2018-09-18 22:46:00.371644+00', '2018-09-23 22:42:41.026707+00', 'Skunk River Reel', 'SKUNK RIVER REEL', 1, 32, NULL, 1, 3, 42, 11171, NULL, '', 56, '800/888/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7833, '1997-09-09 22:00:00+00', '2012-01-20 12:57:01.765011+00', 'Miss Blackley Blair', 'MISS BLACKLEY BLAIR', 3, 32, 9999, 1, 4, NULL, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7855, '2002-04-08 22:00:00+00', '2019-03-07 22:11:43.36467+00', 'Mrs Douglas of Invergloy', 'MRS DOUGLAS OF INVERGLOY', 3, 64, 9999, 4, 4, 3, 1159, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7831, '1997-09-09 22:00:00+00', '2019-05-27 09:53:44.621738+00', 'Mind The Dresser', 'MIND THE DRESSER', 1, 48, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7839, '1997-12-28 23:00:00+00', '2012-01-20 12:57:01.807882+00', 'Miss Lenore''s Blueberries and Cream', 'MISS LENORES BLUEBERRIES AND CREAM', 3, 40, 9999, 1, 4, NULL, 737, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7840, '1997-09-09 22:00:00+00', '2012-01-20 12:57:01.814709+00', 'Sir Reginald MacDonald', 'SIR REGINALD MACDONALD', 1, 64, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7843, '1997-09-09 22:00:00+00', '2012-01-20 12:57:01.835242+00', 'Miss Vyvian Wells', 'MISS VYVIAN WELLS', 1, 48, 9999, 1, 4, NULL, 1141, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12789, '2006-06-15 22:00:00+00', '2021-01-23 21:53:09.130606+00', 'Whirlwind, The', 'WHIRLWIND', 1, 32, 9999, 1, 2, 76, 406, '2005-03-01', '<<scddb-not-identical:13179;13729;16505;20205>>', 62, '84/68/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7880, '1997-12-03 23:00:00+00', '2021-02-26 18:45:21.952589+00', 'Paddy O''Rafferty', 'PADDY ORAFFERTY', 2, 32, 9999, 1, 3, 42, 9998, NULL, 'A version of this dance is described in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-036-May-1968.pdf#page=2|issue 36 of The Thistle magazine>> (as part of an article about <<ddd:Rory O''More#5658>>).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7844, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.842012+00', 'Miss Wishart''s Jig', 'MISS WISHARTS JIG', 2, 48, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7845, '1997-09-09 22:00:00+00', '2012-01-20 12:57:01.848782+00', 'Mitcham Society Strathspey', 'MITCHAM SOCIETY STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14684, '2013-01-23 12:37:24.462465+00', '2013-01-23 13:25:37.318784+00', 'Joymobile, The', 'JOYMOBILE', 2, 32, NULL, 1, 3, 42, 10725, NULL, 'Dedicated to Joy Galloway.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12798, '2006-07-02 22:00:00+00', '2012-01-20 12:57:41.463093+00', 'Saint Andrews Roundabout', 'SAINT ANDREWS ROUNDABOUT', 1, 32, 9999, 1, 4, 2, 3695, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7825, '1998-01-04 23:00:00+00', '2018-03-19 14:39:58.874613+00', 'Merry Mate, The', 'MERRY MATE', 1, 32, 9999, 1, 3, 42, 651, '1987-10-01', 'To the memory of Mr. Yoshio Matsuhashi (1931-1987),  

the first president of Urawa Scottish Country Dance Group.', 53, '880/888/840/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12804, '2006-07-02 22:00:00+00', '2012-01-20 12:57:41.519566+00', 'Anita''s Dance', 'ANITAS DANCE', 3, 32, 9999, 3, 5, 6, 3697, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12806, '2006-07-02 22:00:00+00', '2012-01-20 12:57:41.538348+00', 'Jewellery Quarter, The', 'JEWELLERY QUARTER', 1, 32, 9999, 1, 4, 1, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7856, '1997-12-03 23:00:00+00', '2014-05-10 16:40:18.826883+00', 'Helen Atkinson of Brechin', 'HELEN ATKINSON OF BRECHIN', 2, 64, 9999, 4, 4, NULL, 619, '1985-01-01', 'Inscribed to a niece whom John met for the first time in 20 years, 1985', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7846, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.855545+00', 'Moira''s Jig', 'MOIRAS JIG', 2, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7847, '1997-09-09 22:00:00+00', '2012-01-20 12:57:01.862388+00', 'Monarch of the Glen', 'MONARCH OF THE GLEN', 1, 32, 9999, 2, 3, NULL, 1145, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7848, '1997-09-09 22:00:00+00', '2012-01-20 12:57:01.869358+00', 'Moncrieffe Strathspey', 'MONCRIEFFE STRATHSPEY', 3, 80, 9999, 4, 4, NULL, 1136, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7850, '1997-09-09 22:00:00+00', '2012-01-20 12:57:01.882937+00', 'Morven''s Mirligo', 'MORVENS MIRLIGO', 1, 32, 9999, 4, 4, NULL, 1152, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7853, '1997-09-10 22:00:00+00', '2012-01-20 12:57:01.896684+00', 'Mrs Catherine Sherrit', 'MRS CATHERINE SHERRIT', 3, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7854, '1997-12-28 23:00:00+00', '2012-01-20 12:57:01.903461+00', 'Mrs Clarke''s Last Waltz', 'MRS CLARKES LAST WALTZ', 3, 32, 9999, 5, 56, NULL, 737, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7857, '1997-09-10 22:00:00+00', '2012-01-20 12:57:01.924308+00', 'Mrs Helen Hunter''s Reel', 'MRS HELEN HUNTERS REEL', 1, 96, 9999, 4, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7858, '1997-09-10 22:00:00+00', '2012-01-20 12:57:01.931106+00', 'Mrs Helen Hunter''s Reel (original)', 'MRS HELEN HUNTERS REEL ORIGINAL', 1, 80, 9999, 4, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7860, '1997-09-12 22:00:00+00', '2012-01-20 12:57:01.944685+00', 'Mrs McCulloch Haggs'' Hall', 'MRS MACCULLOCH HAGGS HALL', 3, 40, 9999, 1, 4, NULL, 930, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7862, '1997-09-10 22:00:00+00', '2012-01-20 12:57:01.95891+00', 'Mrs Nellie MacDonald', 'MRS NELLIE MACDONALD', 3, 32, 9999, 1, 4, 1, 173, '1957-01-01', 'Devised: 1957', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7863, '1997-09-10 22:00:00+00', '2012-01-20 12:57:01.965797+00', 'Muddle or Two, I''ll Dance with Who!, A', 'MUDDLE OR TWO ILL DANCE WITH WHO', 1, 40, 9999, 3, 5, NULL, 616, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7864, '2002-11-18 23:00:00+00', '2012-01-20 12:57:01.972619+00', 'Newfoundland Flag, The', 'NEWFOUNDLAND FLAG', 3, 32, 9999, 1, 4, NULL, 345, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7828, '1997-12-28 23:00:00+00', '2018-03-20 18:52:43.570682+00', 'Millbrae', 'MILLBRAE', 1, 32, 9999, 3, 5, 7, 843, '1991-04-01', 'Devised by Masaaki Obata, April 1991.', 70, '80800/84800/88888/86688', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7812, '1997-10-23 22:00:00+00', '2023-01-29 23:22:59.0768+00', 'Lothian Lass, The', 'LOTHIAN LASS', 3, 32, 9999, 1, 3, 42, 1084, NULL, '', 56, '844/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7823, '1997-12-03 23:00:00+00', '2018-04-03 00:08:03.184419+00', 'Merry-Go-Round, The', 'MERRYGOROUND', 2, 32, 9999, 1, 3, 42, 824, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7829, '1997-12-03 23:00:00+00', '2018-04-03 00:08:03.568115+00', 'Miller of Clatt, The', 'MILLER OF CLATT', 2, 32, 9999, 1, 3, 42, 108, '1971-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7832, '1997-12-03 23:00:00+00', '2018-04-03 00:08:03.834893+00', 'Miss Alli''s Fancy', 'MISS ALLIS FANCY', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7834, '1997-09-09 22:00:00+00', '2018-04-03 00:08:04.134942+00', 'Miss Fiona''s Fancy', 'MISS FIONAS FANCY', 1, 40, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7836, '1997-09-09 22:00:00+00', '2018-04-03 00:08:04.443703+00', 'Miss Jeanne R. Hood', 'MISS JEANNE R HOOD', 1, 32, 9999, 1, 3, 42, 885, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7841, '1997-09-09 22:00:00+00', '2018-04-03 00:08:04.735519+00', 'Miss Mary Russell', 'MISS MARY RUSSELL', 3, 32, 9999, 1, 3, 42, 1136, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7859, '1997-09-10 22:00:00+00', '2018-04-03 00:08:06.411432+00', 'Mrs Kathleen Essex', 'MRS KATHLEEN ESSEX', 1, 32, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7861, '1997-09-10 22:00:00+00', '2018-04-03 00:08:06.512116+00', 'Mrs Mary Robertson', 'MRS MARY ROBERTSON', 3, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12797, '2006-07-02 22:00:00+00', '2018-04-03 00:08:10.573433+00', 'Physician''s Fancy, The', 'PHYSICIANS FANCY', 2, 32, 9999, 1, 3, 42, 610, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7865, '1997-12-03 23:00:00+00', '2012-01-20 12:57:01.979392+00', 'New Mercat Cross, The', 'NEW MERCAT CROSS', 2, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7867, '1997-09-10 22:00:00+00', '2012-01-20 12:57:01.992947+00', 'New Queen''s Strathspey, The', 'NEW QUEENS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7868, '1997-09-10 22:00:00+00', '2012-01-20 12:57:01.999712+00', 'No Left Turn', 'NO LEFT TURN', 3, 32, 9999, 1, 4, NULL, 968, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7869, '1997-09-10 22:00:00+00', '2012-01-20 12:57:02.006765+00', 'No Mean Feat', 'NO MEAN FEAT', 3, 32, 9999, 1, 2, NULL, 43, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7870, '2002-05-06 22:00:00+00', '2012-01-20 12:57:02.013839+00', 'No More Teacher''s Dirty Looks', 'NO MORE TEACHERS DIRTY LOOKS', 1, 32, 9999, 1, 4, NULL, 737, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7871, '1997-09-10 22:00:00+00', '2012-01-20 12:57:02.020687+00', 'North Country Lass, A', 'NORTH COUNTRY LASS', 1, 32, 9999, 1, 4, NULL, 123, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7872, '1997-09-10 22:00:00+00', '2012-01-20 12:57:02.027433+00', 'North East West South', 'NORTH EAST WEST SOUTH', 4, 160, 9999, 4, 4, NULL, 683, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12808, '2006-07-09 22:00:00+00', '2012-01-20 12:57:41.558076+00', 'Dilly Dally', 'DILLY DALLY', 2, 48, 9999, 1, 4, 1, 2605, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12815, '2006-08-17 22:00:00+00', '2012-01-20 12:57:41.625333+00', 'Murrays of Glasgow, The', 'MURRAYS OF GLASGOW', 3, 32, 9999, 1, 4, 2, 640, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12831, '2006-08-27 22:00:00+00', '2020-06-28 10:58:11.843749+00', 'Bellringer, The', 'BELLRINGER', 2, 32, 9999, 1, 3, 42, 831, NULL, '', 52, '868/888/800/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12818, '2006-08-24 22:00:00+00', '2020-08-04 05:50:11.07642+00', 'Fiacaill Ridge, The', 'FIACAILL RIDGE', 1, 40, 9999, 3, 5, NULL, 105, '1970-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12816, '2006-08-24 22:00:00+00', '2020-08-04 00:28:17.081187+00', 'Corriearrack', 'CORRIEARRACK', 3, 32, 9999, 1, 4, 22, 105, '1976-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12802, '2006-07-02 22:00:00+00', '2020-09-15 10:00:35.550397+00', 'Grumpy Gentleman, The', 'GRUMPY GENTLEMAN', 2, 32, 9999, 1, 3, 42, 3694, NULL, '', 56, '880/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12795, '2006-07-02 22:00:00+00', '2021-01-09 10:24:04.344559+00', 'Langleys Road', 'LANGLEYS ROAD', 2, 32, 9999, 1, 3, 42, 3694, NULL, '', 56, '880/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7835, '2002-05-06 22:00:00+00', '2021-03-23 20:12:13.677857+00', 'Miss Frances l''Anson''s Strathspey', 'MISS FRANCES LANSONS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1131, NULL, '', 44, '606/444/844/448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7852, '1997-09-10 22:00:00+00', '2021-05-31 22:19:06.390969+00', 'Tudor Rose, The', 'TUDOR ROSE', 1, 32, 9999, 1, 3, 42, 352, '1990-09-30', '', 50, '800/888/888/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7875, '1997-09-10 22:00:00+00', '2012-01-20 12:57:02.048029+00', 'O''er the Sea with Jean', 'OER THE SEA WITH JEAN', 1, 32, 9999, 1, 4, NULL, 1181, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7877, '1997-09-10 22:00:00+00', '2012-01-20 12:57:02.061589+00', 'Ormiston Lad', 'ORMISTON LAD', 3, 48, 9999, 1, 4, NULL, 750, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7883, '1997-09-11 22:00:00+00', '2012-01-20 12:57:02.10211+00', 'Paul and Marjie''s Wedding', 'PAUL AND MARJIES WEDDING', 3, 32, 9999, 1, 4, NULL, 1194, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7884, '1997-09-11 22:00:00+00', '2012-01-20 12:57:02.108888+00', 'Pearl, The', 'PEARL', 3, 32, 9999, 2, 3, NULL, 626, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7885, '1997-09-11 22:00:00+00', '2012-01-20 12:57:02.115645+00', 'Pentland Skerries, The', 'PENTLAND SKERRIES', 3, 32, 9999, 2, 3, NULL, 1099, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7889, '1997-10-19 22:00:00+00', '2012-01-20 12:57:02.142961+00', 'Peter Quinn''s Strathspey', 'PETER QUINNS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 1372, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7891, '1997-12-28 23:00:00+00', '2012-01-20 12:57:02.156529+00', 'Piece of Cake, A', 'PIECE OF CAKE', 4, 32, 1, 1, 2, NULL, 737, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7893, '1998-11-25 23:00:00+00', '2012-01-20 12:57:02.170127+00', 'Pinewoods Silver', 'PINEWOODS SILVER', 3, 32, 9999, 2, 3, NULL, 259, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7894, '1997-12-03 23:00:00+00', '2012-01-20 12:57:02.176906+00', 'Rachel''s Roundabout', 'RACHELS ROUNDABOUT', 2, 32, 9999, 5, 2, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7895, '1997-09-11 22:00:00+00', '2012-01-20 12:57:02.183926+00', 'Piper''s Dance, The', 'PIPERS DANCE', 3, 32, 9999, 1, 2, NULL, 116, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7896, '1997-12-03 23:00:00+00', '2012-01-20 12:57:02.19126+00', 'Pittenweem Jig, The', 'PITTENWEEM JIG', 2, 40, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7897, '1997-09-11 22:00:00+00', '2012-01-20 12:57:02.198752+00', 'Poolbrook Academy', 'POOLBROOK ACADEMY', 3, 32, 9999, 2, 3, NULL, 26, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18541, '2018-08-28 18:20:48.609876+00', '2018-09-23 21:31:37.541563+00', 'Hayesfield Park', 'HAYESFIELD PARK', 1, 40, NULL, 4, 4, 13, 11695, NULL, 'Hayesfield Park is in the southern part of Bath, where the deviser lives.', 80, '6666/6666/8888/4444/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12488, '2005-07-26 22:00:00+00', '2018-10-03 12:00:23.584534+00', 'Crossing the Square', 'CROSSING THE SQUARE', 1, 32, 9999, 1, 3, 42, 2766, '2004-02-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7901, '1997-09-12 22:00:00+00', '2012-01-20 12:57:02.226368+00', 'Really!!', 'REALLY', 1, 128, 9999, 4, 98, NULL, 769, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7902, '1997-09-12 22:00:00+00', '2012-01-20 12:57:02.233256+00', 'Reeling Round the World', 'REELING ROUND THE WORLD', 1, 32, 9999, 4, 4, NULL, 1224, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12813, '2006-08-17 22:00:00+00', '2018-12-19 11:48:27.11972+00', 'Bonnie Dancers, The', 'BONNIE DANCERS', 1, 32, 9999, 3, 5, 16, 640, '2006-01-01', '', 61, '88088/84084/88300/80464', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12826, '2006-08-24 22:00:00+00', '2012-01-20 12:57:41.746181+00', 'Rutherford Medley, The', 'RUTHERFORD MEDLEY', 4, 32, 1, 4, 4, NULL, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12814, '2006-08-17 22:00:00+00', '2018-04-03 00:08:02.041985+00', 'Margaret''s Farewell', 'MARGARETS FAREWELL', 1, 32, 9999, 1, 3, 42, 640, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7876, '1998-04-21 22:00:00+00', '2018-04-03 00:08:08.738691+00', 'Once Upon A Time', 'ONCE UPON A TIME', 3, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7882, '1997-09-11 22:00:00+00', '2018-04-03 00:08:09.989537+00', 'Pat''s Silver Kangaroo', 'PATS SILVER KANGAROO', 1, 32, 9999, 1, 3, 42, 605, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7886, '1998-10-19 22:00:00+00', '2018-04-03 00:08:10.356593+00', 'Percy Reserve', 'PERCY RESERVE', 3, 32, 9999, 1, 3, 42, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7887, '1997-12-03 23:00:00+00', '2018-04-03 00:08:10.39834+00', 'Perth Ladies, The', 'PERTH LADIES', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7898, '1997-09-11 22:00:00+00', '2018-04-03 00:08:11.924305+00', 'Rae''s Reel', 'RAES REEL', 3, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7899, '1997-09-11 22:00:00+00', '2018-04-03 00:08:12.074614+00', 'Randwick Welcome', 'RANDWICK WELCOME', 1, 32, 9999, 1, 3, 42, 774, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12807, '2006-07-02 22:00:00+00', '2019-06-10 17:27:41.751407+00', 'Second City Strathspey', 'SECOND CITY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3694, NULL, '', 63, '888/844/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12834, '2006-09-03 22:00:00+00', '2012-01-20 12:57:41.816756+00', 'Wee Fox, The', 'WEE FOX', 2, 16, 9999, 7, 1, NULL, 608, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7890, '1997-12-03 23:00:00+00', '2022-07-03 18:32:34.437324+00', 'Piccadilly Circus', 'PICCADILLY CIRCUS', 1, 32, 9999, 1, 4, 2, 80, '1965-01-01', 'Revised 2004 on Vancouver Island', 81, '8888/8008/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7838, '1997-12-28 23:00:00+00', '2022-09-21 20:25:07.554936+00', 'Miss Kirsten''s Fancy', 'MISS KIRSTENS FANCY', 2, 40, 9999, 1, 3, 42, 737, NULL, 'Inscribed "This dance was written for my daughter."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14706, '2013-02-01 10:32:01.650231+00', '2018-04-02 23:56:33.497973+00', 'Clay Cutters, The', 'CLAY CUTTERS', 2, 40, NULL, 1, 3, 42, 854, NULL, 'Duncan writes:



> The »Clay Cutters« was a name given to men working for the china clay companies in

> Chudleigh Knighton, where I now live. Clay is still extracted in the local area but it is no longer

> done by a man with a spade!

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14690, '2013-01-29 14:06:12.468697+00', '2013-01-29 14:38:21.930757+00', 'All Saints by the Sea', 'ALL SAINTS BY THE SEA', 2, 32, 9999, 2, 3, 18, 10476, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7903, '1997-12-28 23:00:00+00', '2012-01-20 12:57:02.240063+00', 'Reel of the Four Diamonds', 'REEL OF THE FOUR DIAMONDS', 1, 32, 9999, 1, 4, NULL, 692, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7904, '1997-09-12 22:00:00+00', '2012-01-20 12:57:02.246932+00', 'Return to Cheltenham', 'RETURN TO CHELTENHAM', 3, 48, 9999, 2, 3, NULL, 479, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7905, '1997-09-12 22:00:00+00', '2012-01-20 12:57:02.253761+00', 'Richmond Strathspey, The', 'RICHMOND STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 323, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7906, '1997-09-12 22:00:00+00', '2012-01-20 12:57:02.260555+00', 'Rio Reel, The', 'RIO REEL', 1, 32, 9999, 1, 4, NULL, 1232, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7908, '1997-09-12 22:00:00+00', '2012-01-20 12:57:02.274073+00', 'River Esk, The', 'RIVER ESK', 1, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7909, '1997-09-12 22:00:00+00', '2012-01-20 12:57:02.28084+00', 'Road to Mount Barker, The', 'ROAD TO MOUNT BARKER', 1, 32, 9999, 1, 4, NULL, 605, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7911, '2002-04-08 22:00:00+00', '2019-03-07 22:09:21.478768+00', 'Rockcliffe Rant', 'ROCKCLIFFE RANT', 1, 32, 9999, 1, 4, 1, 1, NULL, '', 81, '8888/8888/8000/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7912, '1997-09-12 22:00:00+00', '2012-01-20 12:57:02.301271+00', 'Rose Worthy O'' Jean, A', 'ROSE WORTHY O JEAN', 3, 32, 9999, 1, 4, NULL, 85, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7913, '1997-09-12 22:00:00+00', '2012-01-20 12:57:02.308048+00', 'Ross''s Ramble', 'ROSSS RAMBLE', 4, 144, 9999, 4, 4, NULL, 1242, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12832, '2006-08-27 22:00:00+00', '2020-01-04 23:37:32.668334+00', 'Forever Friends', 'FOREVER FRIENDS', 1, 32, 9999, 1, 3, 42, 831, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12827, '2006-08-27 22:00:00+00', '2020-01-23 10:21:56.329525+00', 'Wortham Manor', 'WORTHAM MANOR', 1, 48, 9999, 1, 4, 1, 831, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12817, '2006-08-24 22:00:00+00', '2020-08-04 00:44:47.795428+00', 'Dr Donald''s Delight', 'DR DONALDS DELIGHT', 1, 40, 9999, 1, 4, 2, 3700, '1963-01-01', '', 70, '4444/8448/8008/8888/4884', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12811, '2006-08-17 22:00:00+00', '2021-01-09 10:12:18.728779+00', 'Eaglesham Fancy, An', 'EAGLESHAM FANCY', 1, 32, 9999, 1, 3, 42, 3699, NULL, '', 50, '800/880/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12821, '2006-08-24 22:00:00+00', '2020-08-06 15:52:36.481078+00', 'Lord of the Dance, The', 'LORD OF THE DANCE', 2, 32, 9999, 1, 3, 42, 105, '1972-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12822, '2006-08-24 22:00:00+00', '2020-08-07 03:17:27.865245+00', 'Mill Wheel, The', 'MILL WHEEL', 3, 32, 9999, 1, 4, NULL, 105, '1971-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12829, '2006-08-27 22:00:00+00', '2020-09-15 10:08:42.527142+00', 'Closeburn Lassies', 'CLOSEBURN LASSIES', 2, 32, 9999, 1, 3, 42, 831, NULL, '', 50, '444/444/880/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12819, '2006-08-24 22:00:00+00', '2021-06-06 12:06:43.955081+00', 'Hanselling the Hoose', 'HANSELLING THE HOOSE', 1, 64, 9999, 1, 4, 14, 105, '1968-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12830, '2006-08-27 22:00:00+00', '2020-09-15 10:10:51.604741+00', 'Loch Maree Twostep, The', 'LOCH MAREE TWOSTEP', 11, 32, 9999, 5, 2, 76, 831, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12841, '2006-09-03 22:00:00+00', '2021-01-08 18:01:51.760594+00', 'Three Quarters = Seventy-Five Sense', 'THREE QUARTERS  SEVENTYFIVE SENSE', 3, 32, 9999, 2, 3, 18, 23, NULL, '', 96, '888/668/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12825, '2006-08-24 22:00:00+00', '2021-01-08 18:13:00.200403+00', 'Sands of Seamill, The', 'SANDS OF SEAMILL', 3, 32, 9999, 1, 3, 42, 640, '2006-01-01', '', 56, '880/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12820, '2006-08-24 22:00:00+00', '2021-01-08 18:25:15.823845+00', 'Landscape Gardener, The', 'LANDSCAPE GARDENER', 3, 32, 9999, 1, 4, 1, 105, NULL, '', 45, '8110/8440/8440/8044', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7795, '2002-03-11 23:00:00+00', '2021-03-23 20:49:32.917365+00', 'Lass of Richmond Hill, The', 'LASS OF RICHMOND HILL', 1, 32, 9999, 1, 3, 42, 1065, NULL, '', 31, '800/800/633/633', 1, 1, 1, 1, 41);
INSERT INTO 'dance' VALUES (12823, '2006-08-24 22:00:00+00', '2021-04-02 21:46:37.364006+00', 'Mrs Rigby''s Rant', 'MRS RIGBYS RANT', 1, 32, 9999, 1, 4, 1, 105, '1964-01-01', '', 80, '4884/8448/8448/8688', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14701, '2013-02-01 09:18:51.825723+00', '2018-04-02 23:56:34.424967+00', 'Exeter''s Ruby', 'EXETERS RUBY', 2, 32, NULL, 1, 3, 42, 3316, NULL, '»Devised by Pauline Beeson to commemorate the 40th anniversary of RSCDS Exeter Branch, which was founded in 1969.«', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7916, '1997-09-13 22:00:00+00', '2012-01-20 12:57:02.328372+00', 'Royal Australian Tour, The', 'ROYAL AUSTRALIAN TOUR', 3, 32, 9999, 1, 4, NULL, 343, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7917, '1997-12-03 23:00:00+00', '2012-01-20 12:57:02.335148+00', 'Roy Smith''s Farewell to Parkside', 'ROY SMITHS FAREWELL TO PARKSIDE', 2, 48, 9999, 1, 4, NULL, 79, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7918, '1997-12-03 23:00:00+00', '2012-01-20 12:57:02.341922+00', 'Royton Jig, The', 'ROYTON JIG', 2, 48, 9999, 1, 4, NULL, 201, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7919, '1997-09-13 22:00:00+00', '2012-01-20 12:57:02.348692+00', 'Ruby Reelers, The', 'RUBY REELERS', 1, 32, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7920, '1997-12-03 23:00:00+00', '2012-01-20 12:57:02.355452+00', 'Ruby Wedding Jig, The', 'RUBY WEDDING JIG', 2, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7922, '1997-09-13 22:00:00+00', '2012-01-20 12:57:02.368959+00', 'Rutherford House', 'RUTHERFORD HOUSE', 3, 32, 9999, 4, 4, NULL, 504, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7925, '1997-12-27 23:00:00+00', '2012-01-20 12:57:02.390045+00', 'Saint Brendan''s Jig', 'SAINT BRENDANS JIG', 2, 32, 9999, 1, 4, 1, 1228, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7926, '1997-12-03 23:00:00+00', '2012-01-20 12:57:02.396934+00', 'Saint John''s Centre', 'SAINT JOHNS CENTRE', 2, 48, 9999, 4, 4, NULL, 205, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7927, '2002-05-14 22:00:00+00', '2012-01-20 12:57:02.403716+00', 'Saint Kilda''s Strathspey', 'SAINT KILDAS STRATHSPEY', 3, 64, 9999, 4, 4, NULL, 1251, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7930, '1997-09-13 22:00:00+00', '2012-01-20 12:57:02.424026+00', 'Salute to Correze', 'SALUTE TO CORREZE', 4, 104, 9999, 2, 3, NULL, 763, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7931, '1997-09-13 22:00:00+00', '2012-01-20 12:57:02.430873+00', 'Salute to Craigie Church SCD Class, A', 'SALUTE TO CRAIGIE CHURCH SCD CLASS', 3, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14702, '2013-02-01 09:22:44.13616+00', '2013-02-01 09:22:44.136172+00', 'Articulation', 'ARTICULATION', 3, 32, NULL, 2, 3, 17, 10733, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7900, '1997-09-12 22:00:00+00', '2014-09-28 20:54:06.899036+00', 'Reading Strathspey, The', 'READING STRATHSPEY', 3, 32, 9999, 1, 4, 1, 1218, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12844, '2006-09-12 22:00:00+00', '2018-04-03 00:07:30.275741+00', 'Alphadoodle', 'ALPHADOODLE', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7932, '1997-09-13 22:00:00+00', '2012-01-20 12:57:02.437732+00', 'Salute to Jean Conway', 'SALUTE TO JEAN CONWAY', 3, 32, 9999, 1, 2, NULL, 1254, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7934, '1997-12-03 23:00:00+00', '2012-01-20 12:57:02.451399+00', 'Sandhurst Diggers, The', 'SANDHURST DIGGERS', 2, 40, 9999, 1, 4, NULL, 1256, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14686, '2013-01-23 12:50:09.250243+00', '2015-03-19 07:30:53.08211+00', 'Horologist, The', 'HOROLOGIST', 2, 32, NULL, 1, 3, 42, 979, '2005-12-01', 'Dedicated to her father Dave McLeod', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14691, '2013-01-29 14:07:17.383315+00', '2018-04-03 00:07:33.499298+00', 'Bit of Both', 'BIT OF BOTH', 2, 32, 9999, 1, 3, 42, 3610, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12847, '2006-09-12 22:00:00+00', '2018-04-03 00:07:37.679397+00', 'Celtic Cat Crunchies', 'CELTIC CAT CRUNCHIES', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12833, '2006-09-03 22:00:00+00', '2018-04-03 00:07:45.536839+00', 'Fiddler of Dooney, The', 'FIDDLER OF DOONEY', 2, 32, 9999, 1, 3, 42, 3704, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12840, '2006-09-03 22:00:00+00', '2018-04-03 00:08:09.472504+00', 'Outside the Box', 'OUTSIDE THE BOX', 3, 32, 9999, 1, 3, 42, 3703, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12843, '2006-09-12 22:00:00+00', '2018-04-03 00:08:10.48999+00', 'Petit Chat Celtique, Le', 'PETIT CHAT CELTIQUE', 3, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7907, '1997-09-12 22:00:00+00', '2018-04-03 00:08:13.108625+00', 'Rita''s Reel', 'RITAS REEL', 1, 32, 9999, 1, 3, 42, 127, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7910, '1997-09-12 22:00:00+00', '2018-04-03 00:08:13.40055+00', 'Rob Gordon''s Strathspey', 'ROB GORDONS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 141, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7915, '1997-09-13 22:00:00+00', '2018-04-03 00:08:13.792589+00', 'Royal Arch, The', 'ROYAL ARCH', 1, 40, 9999, 1, 3, 42, 824, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7921, '1997-09-13 22:00:00+00', '2018-04-03 00:08:14.084351+00', 'Rumbling Brig', 'RUMBLING BRIG', 1, 32, 9999, 1, 3, 42, 280, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7923, '1997-09-13 22:00:00+00', '2018-04-03 00:08:14.351236+00', 'Saddler''s Daughter, The', 'SADDLERS DAUGHTER', 1, 40, 9999, 1, 3, 42, 1089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7924, '1997-09-13 22:00:00+00', '2018-04-03 00:08:14.45974+00', 'Saint Andrew''s Reel', 'SAINT ANDREWS REEL', 1, 32, 9999, 1, 3, 42, 521, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7929, '1997-09-13 22:00:00+00', '2018-04-03 00:08:14.701527+00', 'Sally''s Sparkle', 'SALLYS SPARKLE', 1, 32, 9999, 1, 3, 42, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7933, '1997-09-13 22:00:00+00', '2018-04-03 00:08:14.818262+00', 'Salute to Sue Crosbie', 'SALUTE TO SUE CROSBIE', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7937, '1997-09-13 22:00:00+00', '2012-01-20 12:57:02.472502+00', 'Sara''s Reel', 'SARAS REEL', 1, 32, 9999, 1, 4, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7946, '2002-04-30 22:00:00+00', '2019-03-07 18:42:55.11419+00', 'Silver Wedding, The', 'SILVER WEDDING', 1, 32, 9999, 1, 4, 1, 449, NULL, '', 81, '8888/8888/8000/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7942, '1997-09-14 22:00:00+00', '2012-01-20 12:57:02.507325+00', 'Shadows', 'SHADOWS', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7945, '1997-09-14 22:00:00+00', '2012-01-20 12:57:02.527715+00', 'Silver Threads', 'SILVER THREADS', 3, 32, 9999, 1, 2, NULL, 349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7947, '1997-12-03 23:00:00+00', '2012-01-20 12:57:02.541282+00', 'Sir William Alexander Smith', 'SIR WILLIAM ALEXANDER SMITH', 2, 48, 9999, 1, 4, NULL, 1275, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7949, '2002-02-12 23:00:00+00', '2019-02-12 18:50:06.788113+00', 'Skatie Shore', 'SKATIE SHORE', 3, 32, 9999, 1, 4, 1, 89, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7979, '2000-01-10 23:00:00+00', '2012-01-20 12:57:02.763039+00', 'Toast to Cobham', 'TOAST TO COBHAM', 3, 32, 9999, 4, 4, NULL, 1314, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7981, '1997-09-16 22:00:00+00', '2012-01-20 12:57:02.776645+00', 'Tremough Strathspey, The', 'TREMOUGH STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 1316, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7982, '2002-12-08 23:00:00+00', '2012-01-20 12:57:02.784136+00', 'Tribute to Aschaffenburg, A', 'TRIBUTE TO ASCHAFFENBURG', 3, 32, 9999, 1, 4, 2, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7944, '2002-04-14 22:00:00+00', '2019-03-07 22:06:18.933674+00', 'Silver Star, The', 'SILVER STAR', 3, 96, 9999, 4, 4, 3, 353, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7953, '1999-12-06 23:00:00+00', '2012-01-20 12:57:02.583475+00', 'South From Prague', 'SOUTH FROM PRAGUE', 2, 32, 9999, 1, 4, NULL, 304, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12839, '2006-09-03 22:00:00+00', '2020-09-07 11:39:24.506974+00', 'Bonny Heather, The', 'BONNY HEATHER', 3, 32, 9999, 1, 2, 76, 406, '2000-05-01', 'Among the many small privately owned boats joining the flotilla that crossed the channel to Dunkirk in May of 1940 to assist in the evacuation of the Allied Armies was a Chris-Craft named Bonny Heather.', 64, '84/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12846, '2006-09-12 22:00:00+00', '2021-01-08 18:00:04.197644+00', 'Cat Atrophy', 'CAT ATROPHY', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', 50, '800/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12836, '2006-09-03 22:00:00+00', '2021-01-08 18:05:18.512745+00', 'On Hudson Creek', 'ON HUDSON CREEK', 1, 32, 9999, 1, 3, 42, 3706, NULL, '', 56, '800/866/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12864, '2006-09-12 22:00:00+00', '2012-09-28 13:38:50.816348+00', 'Tuilidh', 'TUILIDH', 3, 32, 9999, 1, 2, NULL, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14703, '2013-02-01 09:30:09.137784+00', '2013-02-01 09:30:09.137795+00', 'Bodmin Rotarians, The', 'BODMIN ROTARIANS', 3, 32, NULL, 6, 3, 18, 10734, NULL, '»This dance was devised for the occasion of the Burn''s [sic] Night Dinner of the Bodmin Rotary Club in January 2008.«', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7962, '1997-09-14 22:00:00+00', '2012-01-20 12:57:02.645454+00', 'Surbiton Ladies', 'SURBITON LADIES', 3, 32, 9999, 1, 4, NULL, 616, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7963, '1997-09-14 22:00:00+00', '2012-01-20 12:57:02.652374+00', 'Surprise for Janet, A', 'SURPRISE FOR JANET', 1, 32, 9999, 1, 4, NULL, 989, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7964, '2000-04-25 22:00:00+00', '2012-01-20 12:57:02.659203+00', 'Tail of the Bank', 'TAIL OF THE BANK', 2, 48, 9999, 1, 4, NULL, 663, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12849, '2006-09-12 22:00:00+00', '2018-04-03 00:07:44.811165+00', 'Ewie Dubh', 'EWIE DUBH', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12854, '2006-09-12 22:00:00+00', '2018-04-03 00:07:57.838485+00', 'Kuo Dubh', 'KUO DUBH', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12851, '2006-09-12 22:00:00+00', '2018-04-03 00:07:47.455401+00', 'Fyrefly Jig', 'FYREFLY JIG', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12857, '2006-09-12 22:00:00+00', '2018-04-03 00:08:08.363242+00', 'Odd Bob', 'ODD BOB', 2, 32, 9999, 1, 3, 42, 3646, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12858, '2006-09-12 22:00:00+00', '2018-04-03 00:08:09.189054+00', 'Opossum Impossible', 'OPOSSUM IMPOSSIBLE', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12859, '2006-09-12 22:00:00+00', '2018-04-03 00:08:10.081313+00', 'Paws in my Coffee', 'PAWS IN MY COFFEE', 3, 32, 9999, 1, 3, 42, 3646, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7936, '1997-12-03 23:00:00+00', '2018-04-03 00:08:14.968294+00', 'Sandy Watson', 'SANDY WATSON', 2, 32, 9999, 1, 3, 42, 179, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7952, '1997-12-03 23:00:00+00', '2018-04-03 00:08:17.545069+00', 'Social Whirl, The', 'SOCIAL WHIRL', 2, 32, 9999, 1, 3, 42, 798, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12860, '2006-09-12 22:00:00+00', '2018-04-03 00:08:17.853629+00', 'Spaghetti Paw Prints', 'SPAGHETTI PAW PRINTS', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7957, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.420771+00', 'Stella Grieg''s Strathspey', 'STELLA GRIEGS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 932, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7958, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.470806+00', 'Stewart''s Lassie', 'STEWARTS LASSIE', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7959, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.604266+00', 'Stourie Castle', 'STOURIE CASTLE', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7961, '1997-09-14 22:00:00+00', '2018-04-03 00:08:19.212968+00', 'Sunday Brunch', 'SUNDAY BRUNCH', 1, 32, 9999, 1, 3, 42, 214, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7965, '1997-09-14 22:00:00+00', '2018-04-03 00:08:19.771836+00', 'Take Your Choice', 'TAKE YOUR CHOICE', 1, 48, 9999, 1, 3, 42, 418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7978, '1997-12-03 23:00:00+00', '2018-04-03 00:08:21.080974+00', 'Ticket of Leave', 'TICKET OF LEAVE', 2, 48, 9999, 1, 3, 42, 1312, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14708, '2013-02-01 10:50:11.322819+00', '2018-04-02 23:56:37.247062+00', 'Reggie''s Reel Without Reason', 'REGGIES REEL WITHOUT REASON', 1, 32, NULL, 1, 3, 42, 10736, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7973, '2002-03-02 23:00:00+00', '2012-01-20 12:57:02.722195+00', 'Three Feathers', 'THREE FEATHERS', 2, 128, 9999, 4, 4, NULL, 315, '1980-01-01', 'Official Alias: The Thingummy Jig

', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7976, '1997-09-16 22:00:00+00', '2012-01-20 12:57:02.742714+00', 'Three-Thirty in the Morning', 'THREETHIRTY IN THE MORNING', 1, 48, 9999, 1, 4, NULL, 1310, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18544, '2018-08-28 18:50:32.092596+00', '2018-09-23 21:42:21.535423+00', 'Lucia''s Jig', 'LUCIAS JIG', 2, 32, NULL, 1, 3, 42, 11696, NULL, '', 68, '844/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18721, '2018-10-03 22:36:36.621338+00', '2019-09-13 19:05:30.343519+00', 'Iron Man, The', 'IRON MAN', 3, 32, NULL, 2, 3, 17, 3453, NULL, '', 92, '888/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8025, '1997-09-17 22:00:00+00', '2012-01-20 12:57:03.143015+00', 'Carfax', 'CARFAX', 1, 32, 9999, 1, 4, NULL, 1375, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8026, '1998-01-04 23:00:00+00', '2012-01-20 12:57:03.149832+00', 'Craigmoor', 'CRAIGMOOR', 3, 32, 9999, 1, 4, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8027, '1997-09-17 22:00:00+00', '2012-01-20 12:57:03.156583+00', 'Five by Five', 'FIVE BY FIVE', 1, 32, 9999, 3, 5, NULL, 190, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8030, '2002-12-01 23:00:00+00', '2012-01-20 12:57:03.177676+00', 'McIndoe Hall', 'MACINDOE HALL', 3, 32, 9999, 1, 4, NULL, 1073, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8031, '1997-09-17 22:00:00+00', '2012-01-20 12:57:03.184425+00', 'Princess Henrietta', 'PRINCESS HENRIETTA', 3, 32, 9999, 2, 3, NULL, 1012, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8032, '1997-09-17 22:00:00+00', '2012-01-20 12:57:03.191182+00', 'Reel of Friendship', 'REEL OF FRIENDSHIP', 1, 32, 9999, 4, 4, NULL, 1377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7928, '1997-12-03 23:00:00+00', '2022-08-13 09:32:37.94267+00', 'Saint Nicholas Gardens', 'SAINT NICHOLAS GARDENS', 2, 32, 9999, 1, 2, 76, 1255, NULL, '', 52, '80/08/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7968, '1998-04-24 22:00:00+00', '2022-12-18 19:19:20.118334+00', 'Dance No. 3 (Strathspey)', 'DANCE NO 3 STRATHSPEY', 3, 128, 9999, 4, 4, NULL, 181, NULL, 'The original title is as shown, basically just a number and the type of dance. The editorial team came up with an unofficial alias name for this dance for better search reference.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18868, '2018-10-07 11:34:02.835196+00', '2018-10-07 11:34:02.835196+00', 'Robin''s Rowdy Reel', 'ROBINS ROWDY REEL', 1, 32, NULL, 1, 3, 42, 2766, '2013-07-01', 'Written for the daughter of a dancing friend.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8034, '1997-09-17 22:00:00+00', '2012-01-20 12:57:03.204725+00', 'Shores of Ballantrae, The', 'SHORES OF BALLANTRAE', 3, 32, 9999, 1, 2, NULL, 1376, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8035, '1997-09-17 22:00:00+00', '2012-01-20 12:57:03.211573+00', 'Simkins of Dartmoor, The', 'SIMKINS OF DARTMOOR', 3, 32, 9999, 2, 3, NULL, 1378, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8038, '1997-09-17 22:00:00+00', '2012-01-20 12:57:03.231947+00', 'Ten Tors, The', 'TEN TORS', 1, 32, 9999, 3, 5, NULL, 1380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12865, '2006-09-12 22:00:00+00', '2012-01-20 12:57:42.068204+00', 'Yarn Tails', 'YARN TAILS', 2, 32, 9999, 5, 2, NULL, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7969, '1997-09-14 22:00:00+00', '2019-04-30 08:59:29.900161+00', 'Tasmanian Devil Reel', 'TASMANIAN DEVIL REEL', 1, 32, 9999, 1, 4, NULL, 1294, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7956, '1997-12-03 23:00:00+00', '2020-01-11 02:01:47.640004+00', 'Star and Garter, The', 'STAR AND GARTER', 2, 32, 9999, NULL, 98, NULL, 616, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7950, '1997-09-14 22:00:00+00', '2020-09-05 10:22:35.651562+00', 'Skeen''s Medley', 'SKEENS MEDLEY', 4, 32, 8, 1, 3, 42, 369, NULL, '', 38, '800/844/880/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14692, '2013-01-29 14:08:55.76041+00', '2020-10-03 13:07:58.090576+00', 'Daytripper, The', 'DAYTRIPPER', 1, 32, 9999, 1, 2, 76, 3610, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12853, '2006-09-12 22:00:00+00', '2020-09-15 10:38:57.371984+00', 'Griffin, The', 'GRIFFIN', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', 44, '800/844/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12870, '2006-10-08 22:00:00+00', '2021-01-08 11:13:02.284538+00', 'Canadian Memories', 'CANADIAN MEMORIES', 1, 32, 9999, 1, 3, 42, 3708, NULL, '', 56, '844/822/866/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12862, '2006-09-12 22:00:00+00', '2021-01-08 11:46:51.420987+00', 'Tae the Beggin''', 'TAE THE BEGGIN', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', 41, '800/800/866/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12856, '2006-09-12 22:00:00+00', '2021-01-08 11:49:35.008164+00', 'Lap of Luxury', 'LAP OF LUXURY', 3, 32, 9999, 1, 3, 42, 2961, NULL, '', 47, '844/800/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8029, '2002-03-11 23:00:00+00', '2021-03-22 17:54:43.15729+00', 'Honour Your Partner', 'HONOUR YOUR PARTNER', 3, 32, 9999, 1, 4, 2, 692, NULL, '', 81, '8888/8008/8448/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12868, '2006-10-08 22:00:00+00', '2021-05-02 17:34:39.271545+00', 'Autumn Leaves', 'AUTUMN LEAVES', 2, 32, 9999, 1, 3, 42, 2634, NULL, '', 56, '800/880/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7970, '2002-05-14 22:00:00+00', '2021-03-23 19:17:36.356189+00', 'Teanlowe Strathspey', 'TEANLOWE STRATHSPEY', 3, 32, 9999, 2, 3, 17, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14704, '2013-02-01 09:37:49.640463+00', '2013-02-01 09:38:35.24281+00', 'Brig O'' Broon Reel', 'BRIG O BROON REEL', 1, 32, NULL, 1, 4, 1, 1376, NULL, 'The title refers to Brown Bridge, in Scotland.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7999, '1998-10-14 22:00:00+00', '2019-10-18 11:17:13.388193+00', 'John T', 'JOHN T', 3, 32, 9999, 1, 3, 42, 431, NULL, '', 50, '800/880/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7985, '1997-12-03 23:00:00+00', '2012-01-20 12:57:02.804548+00', 'Tribute to Rob, A', 'TRIBUTE TO ROB', 2, 32, 9999, 1, 4, NULL, 1019, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7986, '1997-09-16 22:00:00+00', '2012-01-20 12:57:02.811463+00', 'Tribute to the Kirk on the Hill, A', 'TRIBUTE TO THE KIRK ON THE HILL', 3, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7987, '1997-09-16 22:00:00+00', '2012-01-20 12:57:02.818353+00', 'Tribute to Tom and Iris, A', 'TRIBUTE TO TOM AND IRIS', 4, 64, 9999, 4, 4, NULL, 226, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7988, '1997-09-16 22:00:00+00', '2012-01-20 12:57:02.82516+00', 'Trip Down the Aisle, A', 'TRIP DOWN THE AISLE', 3, 32, 9999, 1, 4, NULL, 1318, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7991, '1997-12-03 23:00:00+00', '2012-01-20 12:57:02.846341+00', 'Trip to Austria, A', 'TRIP TO AUSTRIA', 2, 32, 9999, 1, 4, 2, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7998, '1997-09-16 22:00:00+00', '2012-01-20 12:57:02.894188+00', 'Twa Braw Callants, The', 'TWA BRAW CALLANTS', 3, 32, 9999, 1, 2, NULL, 722, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8000, '1998-07-16 22:00:00+00', '2012-01-20 12:57:02.908371+00', 'Twenty-First, The', 'TWENTYFIRST', 2, 48, 9999, 1, 4, 15, 1228, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8002, '1997-09-16 22:00:00+00', '2012-01-20 12:57:02.922371+00', 'Two Bonnie Maidens', 'TWO BONNIE MAIDENS', 3, 32, 9999, 6, 98, NULL, 1330, NULL, '3 men, 6 ladies', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8003, '1997-09-16 22:00:00+00', '2012-01-20 12:57:02.92911+00', 'Uppermill', 'UPPERMILL', 3, 32, 9999, 1, 4, NULL, 989, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8004, '1997-09-16 22:00:00+00', '2012-01-20 12:57:02.935927+00', 'Victoria Strathspey, The', 'VICTORIA STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 824, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8036, '1997-12-03 23:00:00+00', '2018-04-03 00:08:17.811891+00', 'Southernhay Gardens', 'SOUTHERNHAY GARDENS', 2, 40, 9999, 1, 3, 42, 1374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7971, '1997-12-03 23:00:00+00', '2018-04-03 00:08:20.388761+00', 'Teuchan', 'TEUCHAN', 2, 48, 9999, 1, 3, 42, 279, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7974, '1997-09-16 22:00:00+00', '2018-04-03 00:08:20.922493+00', 'Three O''Clock in the Morning', 'THREE OCLOCK IN THE MORNING', 3, 32, 9999, 1, 3, 42, 1308, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7977, '1997-12-28 23:00:00+00', '2018-04-03 00:08:21.022563+00', 'Thursday Night', 'THURSDAY NIGHT', 2, 40, 9999, 1, 3, 42, 737, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7983, '1997-12-03 23:00:00+00', '2018-04-03 00:08:21.814684+00', 'Tribute to Girl Guides', 'TRIBUTE TO GIRL GUIDES', 2, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7984, '1997-12-03 23:00:00+00', '2018-04-03 00:08:21.831396+00', 'Tribute to Kathie', 'TRIBUTE TO KATHIE', 2, 32, 9999, 1, 3, 42, 1006, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7989, '2002-02-16 23:00:00+00', '2018-04-03 00:08:22.306906+00', 'Trip to Aberfeldy', 'TRIP TO ABERFELDY', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7990, '1997-09-16 22:00:00+00', '2018-04-03 00:08:22.351134+00', 'Trip to Alva, A', 'TRIP TO ALVA', 3, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7993, '1997-12-03 23:00:00+00', '2018-04-03 00:08:22.515037+00', 'Trip to Kinloch Rannoch, A', 'TRIP TO KINLOCH RANNOCH', 2, 48, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7995, '1997-12-03 23:00:00+00', '2018-04-03 00:08:22.565072+00', 'Trip to Moulin, A', 'TRIP TO MOULIN', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7996, '1997-09-16 22:00:00+00', '2018-04-03 00:08:22.817764+00', 'Tulloch Strathspey, The', 'TULLOCH STRATHSPEY', 3, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7997, '1997-12-03 23:00:00+00', '2018-04-03 00:08:22.856959+00', 'Turlingham''s Round', 'TURLINGHAMS ROUND', 2, 32, 9999, 1, 3, 42, 616, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8001, '1997-12-03 23:00:00+00', '2018-04-03 00:08:23.007155+00', 'Twenty-Fourth Stanley, The', 'TWENTYFOURTH STANLEY', 2, 32, 9999, 1, 3, 42, 1327, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8061, '1997-12-03 23:00:00+00', '2018-04-16 09:12:48.353999+00', 'June Festival', 'JUNE FESTIVAL', 2, 32, 9999, 1, 4, 1, 615, '1989-01-01', '', 38, '8000/8800/8040/8004', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8007, '1997-12-03 23:00:00+00', '2012-01-20 12:57:02.956926+00', 'Wallace Place Reel, The', 'WALLACE PLACE REEL', 2, 80, 9999, 4, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8008, '1997-12-03 23:00:00+00', '2012-01-20 12:57:03.027595+00', 'Wandering Dancer, The', 'WANDERING DANCER', 2, 32, 9999, 1, 2, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8009, '1997-09-16 22:00:00+00', '2012-01-20 12:57:03.034521+00', 'Waring Green Reel', 'WARING GREEN REEL', 1, 40, 9999, 1, 4, NULL, 1344, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8010, '1997-09-16 22:00:00+00', '2012-01-20 12:57:03.041297+00', 'Waterfield Weavers, The', 'WATERFIELD WEAVERS', 1, 40, 9999, 1, 4, NULL, 1345, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8011, '1997-09-16 22:00:00+00', '2012-01-20 12:57:03.048086+00', 'Waverley Medley', 'WAVERLEY MEDLEY', 4, 120, 9999, 1, 4, NULL, 701, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8014, '1997-12-03 23:00:00+00', '2012-01-20 12:57:03.068457+00', 'William''s Fancy', 'WILLIAMS FANCY', 2, 32, 9999, 6, 3, NULL, 1366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14694, '2013-01-29 14:16:02.62267+00', '2019-04-20 08:52:43.725536+00', 'Falconer, The', 'FALCONER', 1, 32, 9999, 1, 3, 42, 10476, NULL, '', 47, '800/866/800/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8018, '1997-09-17 22:00:00+00', '2012-01-20 12:57:03.095622+00', 'Woodlands Strathspey', 'WOODLANDS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12885, '2006-10-10 22:00:00+00', '2021-01-07 11:46:41.76204+00', 'Hearts Content', 'HEARTS CONTENT', 1, 32, 9999, 1, 3, 42, 3495, '2005-01-01', '', 50, '800/880/808/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12867, '2006-10-08 22:00:00+00', '2022-09-19 09:38:34.754079+00', 'Amstel Court', 'AMSTEL COURT', 3, 32, 9999, 2, 3, 18, 104, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8054, '1998-07-09 22:00:00+00', '2022-10-14 21:42:54.321332+00', 'Helping Hand, A', 'HELPING HAND', 1, 32, 9999, 2, 3, 17, 44, '1996-01-01', 'To teach giving of hands', 31, '800/080/800/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14705, '2013-02-01 09:42:28.959105+00', '2018-04-02 23:56:36.60429+00', 'Naomi Dunkin''s Jig', 'NAOMI DUNKINS JIG', 2, 32, NULL, 1, 3, 42, 3316, NULL, '»Dedicated to Naomi Fraser-Holland (née Dunkin), one of the founder members of RSCDS Exeter Branch. She was also a Branch teacher for many years.«', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8020, '1997-09-17 22:00:00+00', '2012-01-20 12:57:03.109161+00', 'Wyberton Rant', 'WYBERTON RANT', 1, 32, 9999, 1, 4, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8021, '1997-09-17 22:00:00+00', '2012-01-20 12:57:03.115907+00', 'Yvonne''s Chase', 'YVONNES CHASE', 1, 32, 9999, 1, 4, NULL, 631, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12873, '2006-10-08 22:00:00+00', '2019-02-26 22:38:48.005221+00', 'Chat Club, The', 'CHAT CLUB', 3, 32, 9999, 1, 4, 1, 3312, NULL, '', 88, '8448/8888/4884/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8012, '1997-12-28 23:00:00+00', '2012-02-22 23:38:00.879527+00', 'Westlothiana', 'WESTLOTHIANA', 3, 128, 9999, 4, 4, 3, 1359, '1994-03-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8043, '2003-01-30 23:00:00+00', '2019-05-09 22:38:39.127613+00', 'Circle of Cheer', 'CIRCLE OF CHEER', 1, 32, 9999, 7, 1, 4, 758, '1995-01-01', '', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12874, '2006-10-08 22:00:00+00', '2020-06-27 21:16:50.356791+00', 'Circonstances Particulieres', 'CIRCONSTANCES PARTICULIERES', 3, 40, 9999, 1, 4, 2, 3709, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7994, '1999-07-24 22:00:00+00', '2020-09-05 10:28:07.837443+00', 'Trip to Maney, A', 'TRIP TO MANEY', 1, 48, 9999, 1, 4, 1, 815, NULL, '', 70, '4664/4664/6446/8888/8082/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8037, '1997-12-03 23:00:00+00', '2020-09-06 09:43:05.030232+00', 'South West Way, The', 'SOUTH WEST WAY', 2, 32, 9999, 1, 4, 2, 1379, NULL, '', 81, '8008/8448/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12889, '2006-10-12 22:00:00+00', '2020-09-07 12:18:46.04521+00', 'Locomotion No. 1', 'LOCOMOTION NO 1', 2, 32, 9999, 1, 3, 42, 3714, NULL, '', 52, '800/684/888/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12883, '2006-10-10 22:00:00+00', '2021-01-07 11:53:20.776603+00', 'Hank''s Dance', 'HANKS DANCE', 1, 32, 9999, 2, 3, 17, 9998, NULL, '', 50, '888/880/800/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12879, '2006-10-08 22:00:00+00', '2021-01-07 16:54:09.754832+00', 'Glasgow Gold', 'GLASGOW GOLD', 4, 192, 3, 4, 4, 1, 3712, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12876, '2006-10-08 22:00:00+00', '2021-01-07 16:55:35.86548+00', 'Duncan''s Dance', 'DUNCANS DANCE', 1, 32, 9999, 1, 4, 1, 1309, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12875, '2006-10-08 22:00:00+00', '2021-01-07 17:01:05.574189+00', 'Derek''s Reel', 'DEREKS REEL', 1, 32, 9999, 4, 5, 55, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12871, '2006-10-08 22:00:00+00', '2021-01-07 17:11:46.378402+00', 'Carthusian Capers', 'CARTHUSIAN CAPERS', 1, 32, 9999, 1, 3, 42, 17, NULL, '', 63, '880/888/880/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8033, '2002-02-11 23:00:00+00', '2021-03-22 17:52:02.615709+00', 'Rob of Balbeggie', 'ROB OF BALBEGGIE', 1, 32, 9999, 1, 3, 42, 265, NULL, '', 53, '880/888/804/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12869, '2006-10-08 22:00:00+00', '2021-01-08 16:04:37.697982+00', 'Birlin'' Sporrans', 'BIRLIN SPORRANS', 1, 40, 9999, 1, 3, 42, 276, '2006-01-01', '', 59, '864/866/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8063, '1997-09-18 22:00:00+00', '2019-08-03 09:00:41.410915+00', 'Lads and Lassies of Livermore, The', 'LADS AND LASSIES OF LIVERMORE', 1, 32, 9999, 1, 4, 1, 863, '1991-01-01', '', 62, '4444/4444/4444/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8044, '1997-09-17 22:00:00+00', '2012-01-20 12:57:03.282245+00', 'Corn Dawgs', 'CORN DAWGS', 1, 32, 9999, 1, 2, NULL, 1382, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8050, '1997-12-03 23:00:00+00', '2019-09-26 21:46:08.528841+00', 'Further Expectations', 'FURTHER EXPECTATIONS', 2, 32, 9999, 1, 3, 42, 146, NULL, 'High Expectations and Further Expectations are variations of "Great Expectations" from *Let''s All Dance.*', 50, '404/404/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8096, '1997-10-14 22:00:00+00', '2012-01-20 12:57:03.667007+00', 'McEwan Hall', 'MACEWAN HALL', 1, 48, 9999, 3, 5, NULL, 518, '1970-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8019, '1997-09-17 22:00:00+00', '2016-05-18 21:26:29.585707+00', 'Worcester Scots, The', 'WORCESTER SCOTS', 4, 96, 9999, 107, 101, NULL, 354, NULL, '2 men, 4 ladies', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8005, '1997-12-03 23:00:00+00', '2018-04-03 00:08:23.749075+00', 'Visit to Edinburgh, A', 'VISIT TO EDINBURGH', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8013, '1997-12-03 23:00:00+00', '2018-04-03 00:08:25.725919+00', 'Wife''s Awa'', The', 'WIFES AWA', 2, 32, 9999, 1, 3, 42, 824, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8015, '1997-09-17 22:00:00+00', '2018-04-03 00:08:25.892652+00', 'Willow Wand, The', 'WILLOW WAND', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8016, '1997-09-17 22:00:00+00', '2018-04-03 00:08:26.259651+00', 'Winter Daydream', 'WINTER DAYDREAM', 3, 32, 9999, 1, 3, 42, 246, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8017, '1997-09-17 22:00:00+00', '2018-04-03 00:08:26.793223+00', 'Wolf of Badenoch, The', 'WOLF OF BADENOCH', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8022, '1997-09-17 22:00:00+00', '2018-04-03 00:08:27.210206+00', 'Yvonne''s Get Well Card', 'YVONNES GET WELL CARD', 3, 32, 9999, 1, 3, 42, 1373, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8072, '1997-12-03 23:00:00+00', '2018-04-16 08:39:10.38354+00', 'Persuasion', 'PERSUASION', 2, 32, 9999, 1, 3, 42, 348, '1995-01-01', '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8091, '1997-12-28 23:00:00+00', '2019-04-19 22:05:29.219099+00', 'Corryvreckan', 'CORRYVRECKAN', 4, 128, 2, 1, 4, 3, 519, '1977-01-01', 'This is a demonstration medley.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14695, '2013-01-29 14:18:33.601314+00', '2013-01-29 15:15:05.34727+00', 'Hammock Jig, The', 'HAMMOCK JIG', 2, 32, 9999, 2, 3, 17, 10476, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8080, '1997-12-03 23:00:00+00', '2018-05-21 19:07:07.10801+00', 'Third Grey Cat, The', 'THIRD GREY CAT', 2, 32, 9999, 1, 3, 42, 1394, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8070, '1997-09-18 22:00:00+00', '2012-01-20 12:57:03.470915+00', 'Palnackie', 'PALNACKIE', 1, 32, 9999, 5, 56, NULL, 146, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8114, '1997-10-26 23:00:00+00', '2018-04-03 00:07:30.953045+00', 'Answering Machine, The', 'ANSWERING MACHINE', 1, 32, 9999, 1, 3, 42, 1445, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8089, '1998-01-04 23:00:00+00', '2012-01-20 12:57:03.610132+00', 'Cuchullins, The', 'CUCHULLINS', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8090, '1997-10-14 22:00:00+00', '2012-01-20 12:57:03.616924+00', 'Saint George''s Reel', 'SAINT GEORGES REEL', 1, 32, 9999, 3, 5, NULL, 1848, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8092, '1998-11-21 23:00:00+00', '2012-01-20 12:57:03.636292+00', 'Square Tango', 'SQUARE TANGO', 50, 0, 9999, 99, 99, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8095, '1997-10-14 22:00:00+00', '2012-01-20 12:57:03.660119+00', 'Stationmaster''s Reel, The', 'STATIONMASTERS REEL', 1, 136, 9999, 4, 98, NULL, 1850, '1989-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8106, '1997-12-03 23:00:00+00', '2019-03-07 09:27:46.771959+00', 'Roxburgh''s Fancy', 'ROXBURGHS FANCY', 2, 32, 9999, 1, 4, 1, 1858, '1984-01-01', '', 56, '8888/4040/8080/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8098, '1997-10-14 22:00:00+00', '2019-03-07 09:35:41.232614+00', 'Miss Jane Purves''s Delight', 'MISS JANE PURVESS DELIGHT', 1, 32, 9999, 1, 4, 2, 1600, '1996-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12900, '2006-10-12 22:00:00+00', '2019-12-06 11:39:37.420496+00', 'Sisters of the Heart', 'SISTERS OF THE HEART', 3, 32, 9999, 1, 4, 1, 2927, '2004-01-01', '', 84, '8888/8111/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12881, '2006-10-10 22:00:00+00', '2021-01-07 11:58:53.102583+00', 'Green Grandparents, The', 'GREEN GRANDPARENTS', 2, 64, 9999, 4, 4, 4, 3312, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12907, '2006-10-12 22:00:00+00', '2021-01-05 20:56:22.797802+00', 'Welcome to Nerja', 'WELCOME TO NERJA', 2, 48, 9999, 4, 5, 16, 3717, NULL, 'Devised for Jean Rennie, teacher of the Nerja Group.  There are five big arches welcoming visitors to Nerja.', 53, '88888/40008/00408/08088/80808/24442', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12906, '2006-10-12 22:00:00+00', '2021-01-05 21:00:43.229003+00', 'Trip to Nerja', 'TRIP TO NERJA', 1, 32, 9999, 1, 4, 2, 3717, NULL, '', 62, '8008/8448/8448/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12890, '2006-10-12 22:00:00+00', '2021-01-07 11:32:26.781165+00', 'Mary''s Garden', 'MARYS GARDEN', 3, 32, 9999, 2, 3, 17, 23, '1995-01-01', '', 53, '800/822/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12888, '2006-10-10 22:00:00+00', '2021-01-07 11:36:48.061603+00', 'Larkin''s Song', 'LARKINS SONG', 2, 32, 9999, 1, 3, 42, 758, NULL, '', 56, '800/888/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12887, '2006-10-10 22:00:00+00', '2021-01-07 11:39:58.079306+00', 'Joan Tyler Jig', 'JOAN TYLER JIG', 2, 32, 9999, 1, 3, 42, 2742, NULL, '', 56, '880/808/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12886, '2006-10-10 22:00:00+00', '2021-01-07 11:42:13.849461+00', 'Helen & Tom Smith''s Jig', 'HELEN AND TOM SMITHS JIG', 2, 32, 9999, 1, 4, 11, 3713, NULL, '', 100, '8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8053, '1997-09-18 22:00:00+00', '2022-10-14 21:45:07.084414+00', 'Goodtime Reel, The', 'GOODTIME REEL', 1, 32, 9999, 1, 3, 42, 1384, NULL, 'From the notes: "This dance was devised for an audience participation workshop at the Northwest Folklife Festival in Seattle, Washington."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8052, '1997-12-03 23:00:00+00', '2022-10-14 22:15:05.746232+00', 'Glen Falloch', 'GLEN FALLOCH', 2, 32, 9999, 1, 3, 42, 44, '1995-01-01', 'Devised to introduce cross over reels of three.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12872, '2006-10-08 22:00:00+00', '2021-01-07 17:07:07.847756+00', 'Celtic Ribbons', 'CELTIC RIBBONS', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 56, '800/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8087, '1999-08-09 22:00:00+00', '2021-03-22 12:37:56.187548+00', 'Highlandman Kissed His Mother, The', 'HIGHLANDMAN KISSED HIS MOTHER', 1, 32, 9999, 1, 3, 42, 9998, NULL, '<<scddb:not-identical:2934>>

', 44, '800/804/844/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8084, '1997-09-18 22:00:00+00', '2021-03-22 12:45:45.589787+00', 'Winter''s Ride, A', 'WINTERS RIDE', 1, 24, 9999, 1, 2, 76, 895, '1993-01-01', 'Devised for introducing pas de basque.', 57, '88/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8082, '1997-12-03 23:00:00+00', '2021-03-22 12:47:26.274327+00', 'Wee Willie''s Jig', 'WEE WILLIES JIG', 2, 32, 9999, 5, 2, 76, 615, '1990-01-01', '', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8073, '1997-12-03 23:00:00+00', '2021-03-22 12:56:40.282492+00', 'Queen Anne''s Lace', 'QUEEN ANNES LACE', 2, 32, 9999, 1, 4, 1, 1389, NULL, '', 69, '4444/8888/8440/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8067, '1997-09-18 22:00:00+00', '2021-03-22 15:34:43.785516+00', 'Mulligan Stew', 'MULLIGAN STEW', 1, 32, 9999, 1, 3, 42, 598, NULL, '', 38, '880/800/800/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8066, '1998-07-09 22:00:00+00', '2021-03-22 15:36:32.564879+00', 'Miss Margaret Bryson', 'MISS MARGARET BRYSON', 3, 32, 9999, 2, 3, 17, 1387, NULL, '', 50, '880/880/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8060, '1997-12-03 23:00:00+00', '2021-03-22 17:12:21.290526+00', 'January Welcome', 'JANUARY WELCOME', 2, 32, 9999, 1, 2, 76, 1382, NULL, '', 43, '80/08/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8059, '1997-12-03 23:00:00+00', '2021-03-22 17:17:45.078843+00', 'Jane''s Jig', 'JANES JIG', 2, 32, 9999, 1, 2, 76, 1386, NULL, '', 52, '44/44/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8049, '1997-09-18 22:00:00+00', '2021-03-22 17:27:22.285742+00', 'Flowers of Texas', 'FLOWERS OF TEXAS', 1, 32, 9999, 1, 3, 42, 1382, NULL, '', 31, '800/800/800/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8024, '2002-03-02 23:00:00+00', '2021-03-22 17:58:11.944622+00', 'Caerleol Cross', 'CAERLEOL CROSS', 1, 32, 9999, 1, 3, 42, 692, NULL, '', 59, '880/884/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12893, '2006-10-12 22:00:00+00', '2013-11-18 20:31:13.973314+00', 'Poussez et Tirez', 'POUSSEZ ET TIREZ', 2, 32, 9999, 1, 3, 42, 3312, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8068, '1998-07-09 22:00:00+00', '2019-08-18 17:04:10.994257+00', 'Muse Cottage', 'MUSE COTTAGE', 3, 32, 9999, 2, 3, 17, 146, '1995-01-01', 'Muse Cottage is the home of Muriel Johnstone (alias Mrs. Zobel) and Bill Zobel (RG).', 83, '888/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14696, '2013-01-29 14:21:56.807484+00', '2013-01-29 15:38:34.257148+00', 'Katannuta', 'KATANNUTA', 1, 40, 9999, 1, 4, 1, 10731, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8099, '1997-12-03 23:00:00+00', '2012-01-20 12:57:03.691982+00', 'Taikoo''s Revenge', 'TAIKOOS REVENGE', 2, 48, 9999, 4, 4, NULL, 1851, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8100, '1997-10-14 22:00:00+00', '2012-01-20 12:57:03.699263+00', 'Fivepenny Piece, The', 'FIVEPENNY PIECE', 3, 72, 9999, 4, 55, NULL, 1852, '1970-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8101, '1998-07-08 22:00:00+00', '2012-01-20 12:57:03.706832+00', 'Fifty Years Th''gither', 'FIFTY YEARS THGITHER', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8108, '1997-10-14 22:00:00+00', '2012-01-20 12:57:03.759587+00', 'Rowan-berry Reel, The', 'ROWANBERRY REEL', 1, 40, 9999, 1, 4, NULL, 1855, '1994-01-01', 'May be danced as 4R40, 4S40 or S40,R40,S40,R40', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8109, '1998-04-24 22:00:00+00', '2012-01-20 12:57:03.766621+00', 'Golden Thistle, The', 'GOLDEN THISTLE', 2, 48, 9999, 1, 4, NULL, 1856, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8115, '2002-03-12 23:00:00+00', '2012-01-20 12:57:03.808154+00', 'Springtime in Cambridge', 'SPRINGTIME IN CAMBRIDGE', 3, 32, 9999, 1, 2, NULL, 1445, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8119, '1998-04-24 22:00:00+00', '2012-01-20 12:57:03.837091+00', 'Never Say Never Say Never Again', 'NEVER SAY NEVER SAY NEVER AGAIN', 2, 40, 9999, 1, 2, NULL, 1445, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8093, '1998-01-05 23:00:00+00', '2016-05-12 22:18:08.177838+00', 'Away and Together', 'AWAY AND TOGETHER', 1, 32, 9999, 8, 6, 73, 1848, '1992-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14710, '2013-02-01 10:59:33.237971+00', '2018-04-03 00:08:23.215755+00', 'Tylers of Exmouth, The', 'TYLERS OF EXMOUTH', 3, 32, NULL, 1, 3, 42, 3316, NULL, '»Dedicated to Sue and Vic Tyler to thank them for their many years of support and teaching in RSCDS Exeter Branch.«', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8122, '1998-01-04 23:00:00+00', '2012-01-20 12:57:03.857935+00', 'Bells and Tooters', 'BELLS AND TOOTERS', 3, 32, 9999, 1, 4, NULL, 1445, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12929, '2006-10-19 22:00:00+00', '2019-06-15 07:39:24.906399+00', 'Miri''s Wedding', 'MIRIS WEDDING', 1, 32, 9999, 2, 3, 17, 2409, '2006-01-01', '', 85, '844/888/666/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12915, '2006-10-19 22:00:00+00', '2012-01-20 12:57:42.415274+00', 'Brian Fogg''s Jigsaw', 'BRIAN FOGGS JIGSAW', 2, 32, 9999, 2, 3, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14697, '2013-01-29 14:24:30.248588+00', '2013-01-29 16:35:32.921967+00', 'Sansum Narrows', 'SANSUM NARROWS', 3, 32, 9999, 1, 4, 1, 10476, NULL, 'The Sansum Narrows separate Salt Spring Island from Vancouver Island.

Depending on the tide small whirlpools and eddies can make it difficult to navigate. Each of the 8 bar phrases represents a different aspect of tidal waters.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8126, '1998-04-24 22:00:00+00', '2012-01-20 12:57:03.885746+00', 'Hobby Horse, The', 'HOBBY HORSE', 2, 32, 9999, 4, 4, NULL, 1445, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8130, '1998-04-24 22:00:00+00', '2012-01-20 12:57:03.918167+00', 'Level Crossing, The', 'LEVEL CROSSING', 2, 32, 9999, 1, 4, NULL, 1445, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8134, '1997-10-26 23:00:00+00', '2012-01-20 12:57:03.948767+00', 'Major Flea''s Frolic, The', 'MAJOR FLEAS FROLIC', 1, 32, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8149, '1997-12-06 23:00:00+00', '2019-04-18 17:09:43.999853+00', 'Kelvingrove Two Step', 'KELVINGROVE TWO STEP', 50, 16, 9999, 5, 1, 54, 9998, NULL, '', 94, '24/44/44/44', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8137, '1998-04-24 22:00:00+00', '2012-01-20 12:57:03.971309+00', 'Pop Goes the Weasel', 'POP GOES THE WEASEL', 3, 16, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8139, '1997-12-03 23:00:00+00', '2012-01-20 12:57:03.985742+00', 'Robertson of Strowan', 'ROBERTSON OF STROWAN', 2, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8145, '1997-12-06 23:00:00+00', '2012-01-20 12:57:04.030657+00', 'Elephant Walk', 'ELEPHANT WALK', 50, 8, 9999, 5, 1, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8147, '1997-12-06 23:00:00+00', '2012-01-20 12:57:04.044341+00', 'Friendly Waltz', 'FRIENDLY WALTZ', 5, 16, 9999, 5, 1, NULL, 1995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8150, '1997-12-06 23:00:00+00', '2012-01-20 12:57:04.066718+00', 'Lambeth Walk', 'LAMBETH WALK', 50, 16, 9999, 5, 1, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8151, '1997-12-06 23:00:00+00', '2012-01-20 12:57:04.073494+00', 'Lomond Waltz', 'LOMOND WALTZ', 5, 32, 9999, 5, 1, NULL, 1997, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12926, '2006-10-19 22:00:00+00', '2012-01-20 12:57:42.512468+00', 'Jist a Wee', 'JIST A WEE', 3, 32, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8148, '1997-12-06 23:00:00+00', '2019-11-11 01:32:23.119467+00', 'Hesitation Waltz', 'HESITATION WALTZ', 5, 16, 9999, 5, 1, 54, 1996, NULL, 'Source: dance originally devised by John Evans. Collected by Johan Maclean.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12894, '2006-10-12 22:00:00+00', '2021-08-06 20:46:13.079826+00', 'Preparation Reel', 'PREPARATION REEL', 2, 32, 9999, 1, 3, 42, 2975, NULL, '', 47, '804/800/880/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12935, '2006-10-20 22:00:00+00', '2020-04-12 21:40:27.138215+00', 'Thistle House', 'THISTLE HOUSE', 1, 32, 9999, 1, 3, 42, 3583, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12911, '2006-10-19 22:00:00+00', '2020-04-12 21:26:11.010095+00', 'Auberge Willow Place Inn', 'AUBERGE WILLOW PLACE INN', 3, 32, 9999, 1, 3, 42, 3495, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12912, '2006-10-19 22:00:00+00', '2020-04-12 21:26:51.61255+00', 'Auld Blether, The', 'AULD BLETHER', 2, 32, 9999, 1, 3, 42, 3583, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12917, '2006-10-19 22:00:00+00', '2020-04-12 21:28:43.347972+00', 'Catch that Catch Can', 'CATCH THAT CATCH CAN', 2, 32, 9999, 1, 4, NULL, 3583, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12928, '2006-10-19 22:00:00+00', '2020-04-12 21:35:26.535798+00', 'Road Not Taken, The', 'ROAD NOT TAKEN', 2, 32, 9999, 1, 3, 42, 3495, '2005-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12909, '2006-10-12 22:00:00+00', '2021-01-05 20:52:10.694412+00', 'Willie''s Little Jig', 'WILLIES LITTLE JIG', 2, 32, 9999, 1, 2, 76, 9998, NULL, '', 60, '88/80/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12934, '2006-10-19 22:00:00+00', '2020-04-12 21:41:33.250335+00', 'Stone Mountain Men', 'STONE MOUNTAIN MEN', 3, 88, 9999, 4, 4, NULL, 3495, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12922, '2006-10-19 22:00:00+00', '2020-04-12 21:31:25.431653+00', 'Haud Yer Wheesht', 'HAUD YER WHEESHT', 1, 32, 9999, 1, 3, 42, 3583, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8107, '2002-04-30 22:00:00+00', '2022-10-14 20:21:20.809292+00', 'Piper of Drummond, The', 'PIPER OF DRUMMOND', 1, 32, 9999, 1, 4, 5, 520, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12930, '2006-10-19 22:00:00+00', '2020-05-03 09:12:38.616698+00', 'Song of the Saltire', 'SONG OF THE SALTIRE', 3, 40, 9999, 1, 100, 2, 3583, '2004-01-01', '', 85, '8888/8448/8008/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12904, '2006-10-12 22:00:00+00', '2021-01-05 21:20:46.472127+00', 'Tartan Fling, The', 'TARTAN FLING', 3, 32, 9999, 2, 3, 17, 212, '2004-01-01', 'For the 10th Anniversary of the Iberian Peninsular Gathering held in Benidorm 2004.', 92, '888/888/880/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12903, '2006-10-12 22:00:00+00', '2021-01-05 21:23:08.364482+00', 'Stroll Around Nerja', 'STROLL AROUND NERJA', 3, 32, 9999, 1, 3, 42, 3717, NULL, '', 53, '624/844/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12898, '2006-10-12 22:00:00+00', '2021-01-07 11:22:36.386104+00', 'Ruby Ribbon Reel, The', 'RUBY RIBBON REEL', 1, 40, 9999, 1, 3, 42, 9998, NULL, '', 55, '888/888/844/880/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8124, '1997-10-26 23:00:00+00', '2021-03-17 05:52:38.342235+00', 'Château Claire Hornpipe, The', 'CHATEAU CLAIRE HORNPIPE', 1, 32, 9999, 1, 2, NULL, 1445, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12901, '2006-10-12 22:00:00+00', '2021-04-11 11:31:32.283741+00', 'Tapsalteerie', 'TAPSALTEERIE', 2, 32, 9999, 1, 3, 42, 3495, '2004-04-01', '"For Ann Marsh, long time member of the Richmond Scottish Country Dancers - to make a wish come true."



Bramble Tapsalteerie means “Blackberry Topsy-Turvy!”', 56, '800/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14698, '2013-01-29 14:25:38.162676+00', '2013-01-29 16:55:41.512246+00', 'Snow Angels', 'SNOW ANGELS', 3, 32, 9999, 1, 4, 11, 3610, NULL, 'This dance was written after classes were cancelled due to snow. I started thinking about snow angels and since we had been practicing the tournee, it seemed like the perfect formation to work the dance around.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8156, '1997-12-06 23:00:00+00', '2013-02-04 18:50:38.192802+00', 'Social Swing, The', 'SOCIAL SWING', 11, 16, 9999, 105, 113, 54, 2001, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8159, '1997-12-06 23:00:00+00', '2015-06-28 14:49:36.567365+00', 'Swedish Masquerade', 'SWEDISH MASQUERADE', 4, 48, 33, 5, 1, NULL, 9998, NULL, 'A traditional Danish dance', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8125, '1998-04-24 22:00:00+00', '2017-02-14 23:01:25.713183+00', 'Bielefeld Bear, The', 'BIELEFELD BEAR', 3, 32, 9999, 1, 3, 42, 1445, '1995-01-01', '', 62, '800/888/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8135, '1997-10-29 23:00:00+00', '2018-04-03 00:08:07.679685+00', 'New Red House, The', 'NEW RED HOUSE', 1, 40, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8136, '1997-10-29 23:00:00+00', '2018-04-03 00:08:09.105644+00', 'On Tour', 'ON TOUR', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12931, '2006-10-19 22:00:00+00', '2018-04-03 00:08:17.878628+00', 'Spanish Sojourn', 'SPANISH SOJOURN', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12933, '2006-10-19 22:00:00+00', '2018-04-03 00:08:18.412422+00', 'Stella by Starlight', 'STELLA BY STARLIGHT', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8163, '1998-03-31 22:00:00+00', '2012-01-20 12:57:04.161275+00', 'First Day of Spring', 'FIRST DAY OF SPRING', 2, 32, 9999, 1, 2, NULL, 2002, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8160, '2002-04-28 22:00:00+00', '2013-02-04 19:44:52.353808+00', 'Va, La', 'VA', 5, 32, 9999, 5, 1, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12937, '2006-10-22 22:00:00+00', '2018-04-29 05:45:02.316947+00', '25 Years at Westminster', '25 YEARS AT WESTMINSTER', 1, 32, 9999, 3, 5, NULL, 2793, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12938, '2006-10-22 22:00:00+00', '2018-04-29 05:45:56.019381+00', '50 and Counting', '50 AND COUNTING', 2, 32, 9999, 3, 5, NULL, 2793, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8179, '1997-12-27 23:00:00+00', '2012-01-20 12:57:04.296497+00', 'Pittaway''s Petronella', 'PITTAWAYS PETRONELLA', 4, 128, 2, 4, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8180, '1997-12-27 23:00:00+00', '2012-01-20 12:57:04.305356+00', 'Lady Catherine Kennedy', 'LADY CATHERINE KENNEDY', 2, 32, 9999, 6, 3, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8181, '1997-12-27 23:00:00+00', '2012-01-20 12:57:04.313102+00', 'Twenty-to-Six Last Thursday', 'TWENTYTOSIX LAST THURSDAY', 3, 128, 9999, 4, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12943, '2006-10-22 22:00:00+00', '2012-01-20 12:57:42.64475+00', 'It''s Dead Easy', 'ITS DEAD EASY', 2, 32, 9999, 1, 4, NULL, 2793, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12946, '2006-10-22 22:00:00+00', '2012-01-20 12:57:42.66609+00', 'Nessie Strathspey', 'NESSIE STRATHSPEY', 3, 32, 9999, 1, 4, 2, 2793, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8161, '1999-08-18 22:00:00+00', '2013-01-27 22:47:31.672466+00', 'Veleta', 'VELETA', 5, 16, 9999, 5, 1, NULL, 458, NULL, 'In the videoed demos, the couples start side by side facing in the line of the dance, swing open on bar 1 and face out, move on and face P on bar 2, then step close step.  Bars 9-10 are waltz round once.  All this differs from the Collins description.  It could be that Collins describes a SCD version that differs from the ballroom version.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14699, '2013-01-29 14:27:22.694614+00', '2013-01-29 17:20:38.260864+00', 'Visitors, The', 'VISITORS', 3, 32, NULL, 2, 3, 17, 10476, NULL, 'Written when Di Rooney, Roger Gurtner, and Maureen Haynes came to visit Salt Spring Island after attending the TAC Summer School at Shawnigan Lake in August 2007.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8153, '1997-12-06 23:00:00+00', '2013-02-04 18:18:42.576001+00', 'Palais Glide', 'PALAIS GLIDE', 50, 16, 9999, 5, 54, NULL, 2000, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8183, '1997-12-27 23:00:00+00', '2012-01-20 12:57:04.326831+00', 'Cait''s Carousel', 'CAITS CAROUSEL', 1, 40, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8184, '1997-12-27 23:00:00+00', '2012-01-20 12:57:04.333618+00', 'Catheral Ruins, The', 'CATHERAL RUINS', 4, 128, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8185, '1997-12-27 23:00:00+00', '2012-01-20 12:57:04.340385+00', 'Twenty-One Again', 'TWENTYONE AGAIN', 1, 32, 9999, 2, 3, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8186, '1997-12-27 23:00:00+00', '2012-01-20 12:57:04.347146+00', 'Dance on Fairies Hi???', 'DANCE ON FAIRIES HI', 4, 128, 2, 4, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8187, '1997-12-27 23:00:00+00', '2012-01-20 12:57:04.353881+00', 'Lochivroan', 'LOCHIVROAN', 4, 160, 34, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8192, '1997-12-27 23:00:00+00', '2012-01-20 12:57:04.39452+00', 'Insomnia', 'INSOMNIA', 2, 32, 9999, 4, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8204, '1997-12-27 23:00:00+00', '2019-03-07 00:18:58.95691+00', 'Macquarie Mixer', 'MACQUARIE MIXER', 2, 32, 9999, 1, 4, 1, 2014, '1997-01-01', '', 66, '8888/8080/8888/4000', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8164, '1997-12-11 23:00:00+00', '2019-03-07 09:18:10.182601+00', 'Donald''s Strathspey', 'DONALDS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 2011, NULL, '', 75, '888/880/844/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8193, '2002-04-30 22:00:00+00', '2019-04-25 19:16:36.306359+00', 'Crown of the Sea, The', 'CROWN OF THE SEA', 3, 48, 9999, 3, 5, 8, 520, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8189, '1997-12-27 23:00:00+00', '2020-01-11 01:59:05.47308+00', 'Pier Walk, The', 'PIER WALK', 4, 128, 2, NULL, 98, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8170, '1997-12-16 23:00:00+00', '2020-04-06 12:55:48.912658+00', 'Like the Morningstar', 'LIKE THE MORNINGSTAR', 1, 32, 9999, 4, 4, 13, 2012, NULL, '', 63, '4444/4444/4444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12936, '2006-10-20 22:00:00+00', '2020-04-12 21:39:43.666637+00', 'Thistle turns Silver, The', 'THISTLE TURNS SILVER', 1, 32, 9999, 3, 5, 16, 3583, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8141, '1998-11-01 23:00:00+00', '2020-04-05 21:29:31.403039+00', 'Merry Widow, The', 'MERRY WIDOW', 1, 32, 9999, 1, 3, 42, 2008, NULL, '', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8169, '1998-11-01 23:00:00+00', '2020-04-06 14:04:35.398298+00', 'Crickets by Moonlight', 'CRICKETS BY MOONLIGHT', 1, 32, 9999, 1, 3, 42, 2012, NULL, '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8168, '1998-11-01 23:00:00+00', '2020-04-06 15:17:15.636868+00', 'Midsummer Night', 'MIDSUMMER NIGHT', 1, 32, 9999, 1, 4, 2, 2012, NULL, '', 91, '8888/8228/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12914, '2006-10-19 22:00:00+00', '2020-04-12 21:27:41.908028+00', 'Braw Fiddler Laddie, The', 'BRAW FIDDLER LADDIE', 1, 32, 9999, 1, 3, 42, 3583, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12919, '2006-10-19 22:00:00+00', '2020-06-04 21:29:38.468021+00', 'Children of Erin & Alba', 'CHILDREN OF ERIN AND ALBA', 2, 32, 9999, 1, 3, 42, 3583, '2004-01-01', 'This dance was originally a reel.', 56, '844/866/866/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12920, '2006-10-19 22:00:00+00', '2020-05-31 22:28:42.782974+00', 'Corriejukit', 'CORRIEJUKIT', 1, 32, 9999, 1, 3, 42, 3583, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8076, '1997-09-18 22:00:00+00', '2022-10-14 21:14:08.639945+00', 'Reel of Troop 398', 'REEL OF TROOP 398', 1, 40, 9999, 1, 4, 1, 1390, NULL, 'For 3 to 6 couples in a longwise set', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8105, '1998-03-20 23:00:00+00', '2021-03-22 01:14:18.121494+00', 'Dr McDonald''s Jig', 'DR MACDONALDS JIG', 2, 32, 9999, 1, 3, 42, 1849, '1992-01-01', '', 61, '880/888/842/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12925, '2006-10-19 22:00:00+00', '2020-04-13 06:32:06.243206+00', 'Je Me Souviens', 'JE ME SOUVIENS', 3, 32, 9999, 1, 3, 42, 3439, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12921, '2006-10-19 22:00:00+00', '2020-05-10 21:14:45.68841+00', 'Dance Gypsies', 'DANCE GYPSIES', 1, 32, 9999, 1, 3, 42, 3583, '2005-08-01', '', 52, '886/833/833/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12951, '2006-10-25 22:00:00+00', '2021-01-05 15:07:44.538428+00', 'Grumpy John', 'GRUMPY JOHN', 3, 48, 9999, 1, 4, 1, 3719, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12949, '2006-10-25 22:00:00+00', '2021-01-05 15:12:12.696983+00', 'Christmas Fling, A', 'CHRISTMAS FLING', 3, 40, 9999, 3, 5, 16, 3718, '2004-01-01', '', 69, '84842/84844/80800/88888/84844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12944, '2006-10-22 22:00:00+00', '2021-01-05 20:42:03.026011+00', 'Jill''s Delight', 'JILLS DELIGHT', 3, 48, 9999, 1, 4, 1, 2793, '2003-01-01', '', 58, '8440/8440/8440/8080/8008/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12927, '2006-10-19 22:00:00+00', '2021-01-05 20:45:10.990869+00', 'My Cary Valentine', 'MY CARY VALENTINE', 3, 32, 9999, 1, 3, 42, 3583, NULL, '', 50, '880/888/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8195, '1999-12-19 23:00:00+00', '2018-04-03 00:07:39.214549+00', 'Come Kiss Me Now', 'COME KISS ME NOW', 2, 32, 9999, 1, 3, 42, 44, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8182, '1997-12-27 23:00:00+00', '2018-04-03 00:07:44.168955+00', 'Eight to be Late', 'EIGHT TO BE LATE', 1, 48, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12942, '2006-10-22 22:00:00+00', '2018-04-03 00:07:47.133278+00', 'From Loch Lomond to Pitlochry', 'FROM LOCH LOMOND TO PITLOCHRY', 1, 32, 9999, 1, 3, 42, 2793, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12945, '2006-10-22 22:00:00+00', '2018-04-03 00:07:59.398264+00', 'Let''s be Jolly', 'LETS BE JOLLY', 3, 32, 9999, 1, 3, 42, 2793, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8196, '1999-12-19 23:00:00+00', '2018-04-03 00:08:09.480956+00', 'Out Under the Stars', 'OUT UNDER THE STARS', 3, 32, 9999, 1, 3, 42, 44, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8194, '1999-12-19 23:00:00+00', '2018-04-03 00:08:13.033568+00', 'Riding the Wind', 'RIDING THE WIND', 1, 32, 9999, 1, 3, 42, 59, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8198, '1999-12-19 23:00:00+00', '2016-05-10 20:09:08.038226+00', 'Homecoming, The', 'HOMECOMING', 4, 32, 1, 1, 3, 42, 59, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8209, '1997-12-27 23:00:00+00', '2016-05-11 14:53:06.281882+00', 'Cast a Cloot', 'CAST A CLOOT', 1, 32, 9999, 1, 4, 1, 9998, NULL, 'A dance for 3, 4 or 5 couples', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8210, '1997-12-27 23:00:00+00', '2016-05-13 15:06:41.137764+00', 'Criss Cross Clapper', 'CRISS CROSS CLAPPER', 2, 32, 9999, 1, 4, 1, 2014, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8208, '1997-12-27 23:00:00+00', '2016-05-13 15:15:04.150965+00', 'Heathridge Hop, The', 'HEATHRIDGE HOP', 2, 40, 9999, 2, 3, 17, 11253, '1993-08-01', '', 47, '444/444/800/444/444', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8205, '1997-12-27 23:00:00+00', '2016-05-13 15:18:59.497194+00', 'Lambton Looper, The', 'LAMBTON LOOPER', 2, 40, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8174, '2001-11-20 23:00:00+00', '2018-04-03 00:08:25.350282+00', 'Whisky Association Reel, The', 'WHISKY ASSOCIATION REEL', 1, 32, 9999, 1, 3, 42, 388, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8188, '1997-12-27 23:00:00+00', '2018-04-03 00:08:26.726491+00', 'With Any Luck', 'WITH ANY LUCK', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12970, '2006-10-25 22:00:00+00', '2018-04-03 00:18:02.464348+00', 'Stepping out with Jenny', 'STEPPING OUT WITH JENNY', 2, 32, 9999, 2, 2, 76, 3718, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12961, '2006-10-25 22:00:00+00', '2012-01-20 12:57:42.776412+00', 'Birthday Honours', 'BIRTHDAY HONOURS', 3, 32, 9999, 1, 4, 1, 3633, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8212, '1997-12-28 23:00:00+00', '2012-01-20 12:57:04.538912+00', 'Tribute to Catherine, A', 'TRIBUTE TO CATHERINE', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8213, '1997-12-28 23:00:00+00', '2012-01-20 12:57:04.545675+00', 'In Days Gone By', 'IN DAYS GONE BY', 3, 32, 9999, 2, 3, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8216, '2003-01-30 23:00:00+00', '2012-01-20 12:57:04.56614+00', 'Irrepressible Gigglers', 'IRREPRESSIBLE GIGGLERS', 1, 32, 9999, 2, 3, NULL, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16838, '2015-12-16 10:55:47.845492+00', '2018-07-27 23:27:19.26793+00', 'Bon Viveur, The', 'BON VIVEUR', 4, 64, 10034, 4, 4, 13, 550, '2015-12-01', 'Written for Stewart Adam in recognition of his award of the RSCDS Scroll of Honour at the AGM in Perth in November 2015 and first danced at the Edinburgh Branch Christmas Party in December.



The dance was originally submitted to the RSCDS with <<ddt:Wing Commander Donald Mackenzie''s Reel>> as the suggested tune for the reel part. Since this tune was deemed too difficult and it wasn''t possible to obtain copyright clearance for reprinting it in the book, Iain MacPhail (a good friend of Stewart Adam''s) was asked to compose a reel tune for the dance. This tune – <<ddt:Stewart Adam – Bon Viveur>> – is the one that is now in the RSCDS book.', 87, '8888/8080/12 12 12 12/4444', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8234, '2002-04-19 22:00:00+00', '2018-04-03 00:07:40.590708+00', 'Dagmar''s Strathspey', 'DAGMARS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3571, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8223, '1997-12-28 23:00:00+00', '2012-01-20 12:57:04.616055+00', 'Kirkin'' o'' the Tartan', 'KIRKIN O THE TARTAN', 3, 32, 9999, 1, 4, NULL, 35, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8225, '1998-01-04 23:00:00+00', '2012-01-20 12:57:04.630231+00', 'At Canisbay', 'AT CANISBAY', 3, 40, 9999, 1, 4, NULL, 35, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8214, '1997-12-28 23:00:00+00', '2018-04-03 00:07:53.343604+00', 'In Applecross', 'IN APPLECROSS', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8265, '1998-12-02 23:00:00+00', '2012-01-20 12:57:04.909369+00', 'What If...', 'WHAT IF', 2, 64, 9999, 5, 2, NULL, 2477, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12964, '2006-10-25 22:00:00+00', '2018-07-29 14:44:34.497447+00', 'Echoes of Inverneil', 'ECHOES OF INVERNEIL', 1, 32, 9999, 1, 3, 42, 3718, '2005-01-01', 'In the Vallin Collection 2 book this is spelled "Inverneil" with one L, but the Vallin Suite 2 recording has "Inverneill" with two Ls.

', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18918, '2018-10-09 12:17:30.785511+00', '2018-10-09 12:17:30.785511+00', 'To Boldly Go…', 'TO BOLDLY GO', 2, 32, NULL, 1, 3, 42, 2766, '2016-10-01', 'Written for a Star Trek themed geek night November 30, 2016.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12966, '2006-10-25 22:00:00+00', '2012-01-20 12:57:42.811771+00', 'Farewell to Broadford', 'FAREWELL TO BROADFORD', 1, 40, 9999, 1, 4, 1, 3718, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12967, '2006-10-25 22:00:00+00', '2012-01-20 12:57:42.819352+00', 'Langley Strathspey, The', 'LANGLEY STRATHSPEY', 3, 32, 9999, 2, 3, 18, 3718, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12968, '2006-10-25 22:00:00+00', '2012-01-20 12:57:42.82692+00', 'Lucky Pieces of Eight', 'LUCKY PIECES OF EIGHT', 1, 32, 9999, 2, 3, 17, 3718, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12969, '2006-10-25 22:00:00+00', '2012-01-20 12:57:42.834571+00', 'Ribble Valley Revellers', 'RIBBLE VALLEY REVELLERS', 1, 32, 9999, 1, 4, 2, 3718, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12972, '2006-10-25 22:00:00+00', '2012-01-20 12:57:42.855905+00', 'Acklam Reelers, The', 'ACKLAM REELERS', 1, 32, 9999, 1, 4, 2, 3718, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8276, '1998-01-12 23:00:00+00', '2012-01-20 12:57:04.985377+00', 'Chain Sixsome', 'CHAIN SIXSOME', 2, 40, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12962, '2006-10-25 22:00:00+00', '2021-01-05 12:16:37.263443+00', 'Clitheroe Castle', 'CLITHEROE CASTLE', 3, 32, 9999, 1, 3, 42, 316, '2005-01-01', '', 56, '880/888/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12959, '2006-10-25 22:00:00+00', '2021-01-05 12:19:08.398254+00', 'Young Moira''s Real (& alive)', 'YOUNG MOIRAS REAL AND ALIVE', 3, 32, 9999, 1, 3, 42, 3718, '2004-01-01', '', 56, '800/888/880/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12957, '2006-10-25 22:00:00+00', '2021-01-05 12:28:23.373183+00', 'Reflections in the Lake', 'REFLECTIONS IN THE LAKE', 2, 32, 9999, 1, 3, 42, 3718, '2004-01-01', '', 69, '880/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12956, '2006-10-25 22:00:00+00', '2021-01-05 12:30:38.676099+00', 'Red House Revisited', 'RED HOUSE REVISITED', 1, 40, 9999, 2, 2, 76, 3718, '2004-01-01', '', 48, '88/80/80/84/84', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12948, '2006-10-25 22:00:00+00', '2023-02-26 17:46:58.608943+00', 'Children of the Forest', 'CHILDREN OF THE FOREST', 2, 32, 9999, 2, 3, 17, 3718, '2004-01-01', 'The very survival of Scottish country dancing lies in encouraging the children of today to learn this gentle art of keeping fit. There are a number of excellent centres of dancing for children, but all too often it is becoming more difficult to retain their interest in their teenage years. This dance is dedicated to one such children''s group based at Langley, taught by Joan Bradbury. The village lies on the fringes of the Macclesfield Forest -the dance represents the children weaving amongst the trees & occasionally coming together to play/chat.', 50, '800/888/888/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12955, '2006-10-25 22:00:00+00', '2021-01-05 12:59:15.486201+00', 'Quarry Bank Weavers, The', 'QUARRY BANK WEAVERS', 1, 40, 9999, 3, 5, 7, 3718, '2004-01-01', '', 64, '80800/80880/84884/80880/80888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12954, '2006-10-25 22:00:00+00', '2021-01-05 15:01:27.02605+00', 'Morris Dancers, The', 'MORRIS DANCERS', 2, 40, 9999, 1, 4, 1, 146, '2004-01-01', '', 57, '4444/4444/8440/8880/8444', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8200, '2003-01-30 23:00:00+00', '2021-03-20 20:03:58.306903+00', 'World Turned Upside Down, The', 'WORLD TURNED UPSIDE DOWN', 1, 32, 9999, 8, 105, 12, 44, '1995-01-01', '', 79, '888888/888888/800008/848848', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8172, '2001-11-20 23:00:00+00', '2021-03-21 19:53:19.753537+00', 'Reels, The', 'REELS', 1, 40, 9999, 1, 3, 42, 1502, NULL, '', 70, '888/888/880/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12952, '2006-10-25 22:00:00+00', '2021-03-31 22:02:21.750255+00', 'Lads and Lasses', 'LADS AND LASSES', 1, 96, 9999, 4, 4, 54, 3718, '2004-01-01', '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12973, '2006-10-25 22:00:00+00', '2012-01-20 12:57:42.863456+00', 'Carry on, Sue', 'CARRY ON SUE', 3, 32, 9999, 2, 3, 18, 3718, '2006-01-01', 'Spelling alias: Carry on Sue', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8228, '1997-12-28 23:00:00+00', '2016-05-10 19:21:24.377623+00', 'Trades Kirk, The', 'TRADES KIRK', 3, 32, 9999, 1, 3, 42, 35, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8226, '2003-01-30 23:00:00+00', '2016-05-10 19:23:01.423284+00', 'Put On Your Sunday Best', 'PUT ON YOUR SUNDAY BEST', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8219, '1997-12-28 23:00:00+00', '2016-05-10 19:23:41.579865+00', 'Kirk-going Dogs of Yarrow, The', 'KIRKGOING DOGS OF YARROW', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8220, '1997-12-28 23:00:00+00', '2016-05-10 19:25:34.986802+00', 'It Was Yerself Begun', 'IT WAS YERSELF BEGUN', 4, 32, 1, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8232, '1997-12-28 23:00:00+00', '2016-05-10 19:28:58.43521+00', 'For a Wee Chuckle', 'FOR A WEE CHUCKLE', 2, 32, 9999, 1, 3, 42, 35, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8233, '1998-01-04 23:00:00+00', '2016-05-11 13:08:37.000738+00', 'Auld Favourite, An', 'AULD FAVOURITE', 3, 32, 9999, 1, 4, 2, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8224, '1997-12-28 23:00:00+00', '2016-05-11 13:10:25.630721+00', 'Forty Winks', 'FORTY WINKS', 3, 32, 9999, 3, 5, 7, 35, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8230, '1997-12-28 23:00:00+00', '2016-05-11 13:11:28.275475+00', 'In a Lighter Vein', 'IN A LIGHTER VEIN', 2, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8229, '1997-12-28 23:00:00+00', '2016-05-11 13:12:27.536075+00', 'Near Tullibardine Castle', 'NEAR TULLIBARDINE CASTLE', 3, 40, 9999, 1, 4, 1, 35, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8231, '1998-01-04 23:00:00+00', '2016-05-11 13:15:27.955859+00', 'Unco Guid, The', 'UNCO GUID', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8215, '1997-12-28 23:00:00+00', '2016-05-11 13:16:48.062223+00', 'Yesterday''s Sabbaths', 'YESTERDAYS SABBATHS', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8237, '1998-01-05 23:00:00+00', '2016-05-11 23:36:45.437131+00', 'Haste Ye Back', 'HASTE YE BACK', 1, 40, 9999, 1, 4, 1, 3571, NULL, 'Devised in honor of Cail Koch as a parting gift when she left for Sioux City, Iowa, with her husband Dick.  February 24, 1992', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8221, '1998-01-05 23:00:00+00', '2016-09-23 22:39:35.740639+00', 'In the Town of Lanark', 'IN THE TOWN OF LANARK', 1, 32, 9999, 1, 3, 42, 35, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8268, '1998-11-15 23:00:00+00', '2018-04-29 21:56:07.419813+00', '4-Leaf Clover', '4LEAF CLOVER', 1, 32, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12985, '2006-10-29 23:00:00+00', '2018-04-03 00:07:37.637584+00', 'Celebration, The', 'CELEBRATION', 3, 32, 9999, 1, 3, 42, 3721, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10343, '2002-02-21 23:00:00+00', '2014-05-10 16:40:44.537633+00', 'Trip to Aberlemno, A', 'TRIP TO ABERLEMNO', 2, 48, 9999, 1, 4, 2, 619, '1999-01-01', 'Inscribed to Aberlemno Dance Class November 1998', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8239, '1997-12-28 23:00:00+00', '2012-01-20 12:57:04.727888+00', 'Silver Knot, The', 'SILVER KNOT', 4, 32, 1, 1, 4, NULL, 1194, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12974, '2006-10-25 22:00:00+00', '2018-04-03 00:07:37.687731+00', 'Celtic Clasp, The', 'CELTIC CLASP', 2, 40, 9999, 1, 3, 42, 3718, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18409, '2018-07-16 23:54:47.294676+00', '2018-07-16 23:54:47.294676+00', 'Ullapool Ferry, The', 'ULLAPOOL FERRY', 1, 32, NULL, 1, 4, 1, 11665, NULL, 'DEVISED: 2015', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8242, '1998-01-06 23:00:00+00', '2012-01-20 12:57:04.748675+00', 'Golden Feather, The', 'GOLDEN FEATHER', 1, 40, 9999, 1, 2, NULL, 1110, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8244, '1998-01-06 23:00:00+00', '2012-01-20 12:57:04.76248+00', 'Isomata Fog', 'ISOMATA FOG', 3, 32, 9999, 1, 4, NULL, 1110, '1972-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8245, '1998-01-06 23:00:00+00', '2012-01-20 12:57:04.769435+00', 'Argument, The', 'ARGUMENT', 1, 32, 9999, 3, 5, NULL, 2017, '1979-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8248, '1998-01-06 23:00:00+00', '2012-01-20 12:57:04.790127+00', 'Marilyn''s Medley', 'MARILYNS MEDLEY', 4, 64, 9999, 4, 4, NULL, 34, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8249, '1998-01-06 23:00:00+00', '2012-01-20 12:57:04.797095+00', 'Lindsay''s Rant', 'LINDSAYS RANT', 1, 32, 9999, 1, 4, NULL, 34, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8252, '1998-01-06 23:00:00+00', '2012-01-20 12:57:04.817784+00', 'Gib''s Special', 'GIBS SPECIAL', 2, 32, 9999, 5, 2, NULL, 1110, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8253, '1998-01-06 23:00:00+00', '2012-01-20 12:57:04.824804+00', 'Karl''s Reel', 'KARLS REEL', 1, 40, 9999, 1, 4, NULL, 1110, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8254, '1998-01-06 23:00:00+00', '2012-01-20 12:57:04.831695+00', 'Flintlock and Loom', 'FLINTLOCK AND LOOM', 3, 32, 9999, 1, 4, NULL, 34, '1989-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8255, '1998-01-06 23:00:00+00', '2012-01-20 12:57:04.838715+00', 'Martha''s Enchanted Garden', 'MARTHAS ENCHANTED GARDEN', 3, 40, 9999, 1, 4, NULL, 1110, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12975, '2006-10-25 22:00:00+00', '2018-04-03 00:07:38.522151+00', 'City of Sails', 'CITY OF SAILS', 2, 32, 9999, 1, 3, 42, 3718, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8251, '1998-01-06 23:00:00+00', '2018-04-03 00:07:40.473977+00', 'Cullison''s Jig', 'CULLISONS JIG', 2, 32, 9999, 1, 3, 42, 34, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12977, '2006-10-25 22:00:00+00', '2018-04-03 00:07:46.621467+00', 'Fountain Strathspey, The', 'FOUNTAIN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3718, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8259, '1998-12-02 23:00:00+00', '2012-01-20 12:57:04.86721+00', 'Dark-eyed Junco, The', 'DARKEYED JUNCO', 1, 88, 9999, 4, 4, NULL, 1183, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8260, '1998-12-02 23:00:00+00', '2012-01-20 12:57:04.874042+00', 'Bumbershoots of Pomeroy', 'BUMBERSHOOTS OF POMEROY', 3, 32, 9999, 1, 4, NULL, 2473, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8261, '1998-12-02 23:00:00+00', '2012-01-20 12:57:04.881144+00', 'Lady Laura Kintoul', 'LADY LAURA KINTOUL', 3, 40, 9999, 1, 4, NULL, 2474, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8262, '1998-12-02 23:00:00+00', '2012-01-20 12:57:04.888215+00', 'I.5 Bridge Portland/Vancouver', 'I5 BRIDGE PORTLAND/VANCOUVER', 3, 32, 9999, 1, 4, NULL, 1370, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8263, '1998-12-02 23:00:00+00', '2012-01-20 12:57:04.895162+00', 'Spin Dizzy', 'SPIN DIZZY', 1, 56, 9999, 4, 4, NULL, 2475, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8266, '1998-12-02 23:00:00+00', '2018-04-03 00:07:47.03833+00', 'Friendship Bridge, The', 'FRIENDSHIP BRIDGE', 3, 40, 9999, 1, 3, 42, 880, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8267, '1998-01-12 23:00:00+00', '2012-01-20 12:57:04.923429+00', 'Half Measure Reel', 'HALF MEASURE REEL', 1, 32, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12976, '2006-10-25 22:00:00+00', '2012-01-20 12:57:42.887005+00', 'Demure Annie', 'DEMURE ANNIE', 3, 32, 9999, 1, 4, 2, 21, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12978, '2006-10-25 22:00:00+00', '2012-01-20 12:57:42.901461+00', 'Katie Rules, OK!', 'KATIE RULES OK', 2, 32, 9999, 2, 3, 17, 3718, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12979, '2006-10-25 22:00:00+00', '2012-01-20 12:57:42.909076+00', 'Kinnoull Ramble', 'KINNOULL RAMBLE', 3, 40, 9999, 3, 5, 4, 3718, '2006-01-01', 'Mixer dance. I.e. partner changes.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12984, '2006-10-29 23:00:00+00', '2012-01-20 12:57:42.944723+00', 'Callejones of Toledo', 'CALLEJONES OF TOLEDO', 3, 40, 9999, 3, 5, 16, 3721, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12986, '2006-10-29 23:00:00+00', '2012-01-20 12:57:42.959457+00', 'Eternal Triangle, The', 'ETERNAL TRIANGLE', 3, 32, 9999, 6, 3, 17, 3721, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12987, '2006-10-29 23:00:00+00', '2012-01-20 12:57:42.966341+00', 'Felpham Way', 'FELPHAM WAY', 1, 32, 9999, 5, 56, NULL, 3721, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12988, '2006-10-29 23:00:00+00', '2018-04-03 00:07:50.258106+00', 'Guid Nicht to Ane & A''', 'GUID NICHT TO ANE AND A', 1, 32, 9999, 1, 3, 42, 3721, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8269, '1998-01-12 23:00:00+00', '2012-01-20 12:57:04.937065+00', 'Wee Three, The', 'WEE THREE', 3, 32, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8270, '1998-05-09 22:00:00+00', '2012-01-20 12:57:04.944208+00', '3 Reel 4', '3 REEL 4', 1, 32, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8241, '1998-01-06 23:00:00+00', '2022-10-04 19:12:29.478619+00', 'Gretchen''s Fancy', 'GRETCHENS FANCY', 2, 32, 9999, 1, 3, 42, 1110, '1984-01-01', 'Inscribed "This dance is dedicated to a young girl who loved to dance."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8272, '1998-01-12 23:00:00+00', '2012-01-20 12:57:04.957901+00', 'Perth Mirage', 'PERTH MIRAGE', 3, 32, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8273, '1998-01-12 23:00:00+00', '2012-01-20 12:57:04.964857+00', 'Right and Left', 'RIGHT AND LEFT', 2, 40, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8274, '1998-01-12 23:00:00+00', '2012-01-20 12:57:04.97162+00', 'Dangerous Curves', 'DANGEROUS CURVES', 1, 40, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8271, '1998-01-12 23:00:00+00', '2021-03-20 19:46:44.353825+00', 'Sixty-Six, The', 'SIXTYSIX', 3, 32, 9999, 5, 56, 76, 2018, NULL, 'Dance Crib compiled by the devisers', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8277, '1998-01-12 23:00:00+00', '2012-01-20 12:57:04.992194+00', 'Scotian Sixsome', 'SCOTIAN SIXSOME', 1, 32, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8278, '1998-01-12 23:00:00+00', '2012-01-20 12:57:04.999099+00', 'Gaelic Sixsome', 'GAELIC SIXSOME', 3, 32, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8279, '1998-01-12 23:00:00+00', '2012-01-20 12:57:05.005982+00', 'Tipsy', 'TIPSY', 3, 40, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8280, '1998-01-12 23:00:00+00', '2012-01-20 12:57:05.012758+00', 'Reversing Falls', 'REVERSING FALLS', 2, 32, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14715, '2013-02-21 16:27:22.845653+00', '2016-05-11 13:18:54.622862+00', 'Going Once, Going Twice', 'GOING ONCE GOING TWICE', 1, 32, NULL, 107, 1, NULL, 1394, NULL, 'Dance for one couple', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14716, '2013-02-21 16:30:25.844494+00', '2016-05-11 13:19:27.148121+00', 'Half past Two', 'HALF PAST TWO', 2, 32, NULL, 107, 1, NULL, 1394, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8257, '1998-01-06 23:00:00+00', '2016-05-11 22:53:20.720452+00', 'Mo Ghaoil', 'MO GHAOIL', 4, 96, 63, 107, 111, NULL, 1110, '1984-01-01', '48148 Medley (A Demonstration Dance)   1 Lady &4 Couples.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8256, '1998-01-06 23:00:00+00', '2016-05-11 23:00:35.931656+00', 'Scottish Wedding, A', 'SCOTTISH WEDDING', 1, 88, 9999, 1, 4, 3, 1110, '1988-01-01', '88-8ar Reel (A Demonstration Dance)   4 Couples', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8240, '1997-12-28 23:00:00+00', '2016-05-11 23:38:17.90379+00', 'Snowy Evening', 'SNOWY EVENING', 3, 32, 9999, 1, 3, 42, 1194, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12980, '2006-10-25 22:00:00+00', '2018-04-03 00:08:07.787818+00', 'Niagara Swirl', 'NIAGARA SWIRL', 1, 48, 9999, 1, 3, 42, 3718, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12981, '2006-10-25 22:00:00+00', '2018-04-03 00:08:09.914347+00', 'Party Dance Reel, The', 'PARTY DANCE REEL', 1, 32, 9999, 1, 3, 42, 3718, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8284, '1998-07-09 22:00:00+00', '2012-01-20 12:57:05.041352+00', 'Petro-Da', 'PETRODA', 3, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8285, '1998-01-13 23:00:00+00', '2012-01-20 12:57:05.049572+00', 'Ceiltich Crois', 'CEILTICH CROIS', 3, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8286, '1998-01-13 23:00:00+00', '2012-01-20 12:57:05.056643+00', 'Reel Nightmare, A', 'REEL NIGHTMARE', 3, 32, 9999, 1, 4, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8288, '1998-01-13 23:00:00+00', '2012-01-20 12:57:05.072413+00', 'Hey for the Hielan'' Body', 'HEY FOR THE HIELAN BODY', 1, 48, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8281, '1998-01-13 23:00:00+00', '2018-04-03 00:07:36.110499+00', 'Built for Two', 'BUILT FOR TWO', 3, 32, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8290, '1998-01-13 23:00:00+00', '2012-01-20 12:57:05.087458+00', 'Maggie''s Medley', 'MAGGIES MEDLEY', 4, 128, 2, 4, 4, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12997, '2006-11-01 23:00:00+00', '2018-04-03 00:07:45.420163+00', 'Fenway Jig', 'FENWAY JIG', 2, 32, 9999, 1, 3, 42, 3160, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8287, '1998-01-13 23:00:00+00', '2018-04-03 00:07:47.663674+00', 'Gallovidian, The', 'GALLOVIDIAN', 3, 32, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8293, '1998-01-12 23:00:00+00', '2012-01-20 12:57:05.108026+00', 'Granny''s Jig', 'GRANNYS JIG', 2, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8296, '1998-01-12 23:00:00+00', '2012-01-20 12:57:05.128411+00', 'Granny''s Reel', 'GRANNYS REEL', 3, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8297, '1998-07-09 22:00:00+00', '2012-01-20 12:57:05.136038+00', 'Maggie''s Mirror', 'MAGGIES MIRROR', 1, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12989, '2006-10-29 23:00:00+00', '2012-01-20 12:57:42.98+00', 'Hinton Strathspey, The', 'HINTON STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 3721, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12990, '2006-10-29 23:00:00+00', '2012-01-20 12:57:42.987578+00', 'Madeira Orchid', 'MADEIRA ORCHID', 3, 32, 9999, 1, 4, 1, 3721, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12991, '2006-10-29 23:00:00+00', '2012-01-20 12:57:42.994482+00', 'Marmian Celebration', 'MARMIAN CELEBRATION', 3, 40, 9999, 1, 4, NULL, 3721, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12992, '2006-10-29 23:00:00+00', '2012-01-20 12:57:43.001338+00', 'Members Capers', 'MEMBERS CAPERS', 2, 96, 9999, 1, 4, NULL, 3721, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12993, '2006-10-29 23:00:00+00', '2012-01-20 12:57:43.008178+00', 'Square of Tembleque, The', 'SQUARE OF TEMBLEQUE', 1, 64, 9999, 4, 4, NULL, 3721, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12994, '2006-10-29 23:00:00+00', '2012-01-20 12:57:43.015028+00', 'Tea Rose, The', 'TEA ROSE', 1, 32, 9999, 5, 1, NULL, 3721, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12995, '2006-10-29 23:00:00+00', '2012-01-20 12:57:43.022485+00', 'Way to Gibraltar, The', 'WAY TO GIBRALTAR', 3, 40, 9999, 3, 5, 7, 3721, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12392, '2005-04-28 22:00:00+00', '2019-03-09 23:36:13.428362+00', 'Spring Daffodils', 'SPRING DAFFODILS', 2, 32, 9999, 1, 3, 42, 2766, '2004-02-01', '', 47, '800/844/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8311, '1998-01-12 23:00:00+00', '2018-04-03 00:07:56.278932+00', 'John''s Jig', 'JOHNS JIG', 2, 32, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13874, '2011-08-22 22:00:00+00', '2018-04-03 00:08:19.046238+00', 'Summer Schools', 'SUMMER SCHOOLS', 1, 32, NULL, 1, 3, 42, 3350, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8298, '1998-01-12 23:00:00+00', '2012-01-20 12:57:05.142844+00', 'Red Joan of Big Harbour', 'RED JOAN OF BIG HARBOUR', 3, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8299, '1998-01-12 23:00:00+00', '2012-01-20 12:57:05.149789+00', 'For Posterity', 'FOR POSTERITY', 1, 32, 9999, 6, 3, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8300, '1998-01-12 23:00:00+00', '2012-01-20 12:57:05.156625+00', 'McPhee Reel, The', 'MACPHEE REEL', 3, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8302, '1998-01-12 23:00:00+00', '2012-01-20 12:57:05.170219+00', 'Taigh MhicLeod', 'TAIGH MHICLEOD', 3, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8303, '1998-01-12 23:00:00+00', '2012-01-20 12:57:05.176984+00', 'Head of the Pin', 'HEAD OF THE PIN', 2, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8304, '1998-01-12 23:00:00+00', '2012-01-20 12:57:05.183729+00', 'Valley Spinners', 'VALLEY SPINNERS', 1, 40, 9999, 1, 4, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8305, '1998-01-12 23:00:00+00', '2012-01-20 12:57:05.190544+00', 'Targaid Danns', 'TARGAID DANNS', 1, 32, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8306, '1998-07-09 22:00:00+00', '2012-01-20 12:57:05.197953+00', 'Tying the Knot', 'TYING THE KNOT', 3, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8307, '1998-01-12 23:00:00+00', '2012-01-20 12:57:05.204716+00', 'Dalradia', 'DALRADIA', 2, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8308, '1998-07-09 22:00:00+00', '2012-01-20 12:57:05.212367+00', 'Deanabh Seasamh', 'DEANABH SEASAMH', 3, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8316, '1998-01-12 23:00:00+00', '2012-01-20 12:57:05.267229+00', 'Donald''s Midden', 'DONALDS MIDDEN', 3, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8318, '1997-12-28 23:00:00+00', '2016-05-11 12:57:06.808794+00', 'Strathspey for Three', 'STRATHSPEY FOR THREE', 3, 32, 9999, 6, 53, NULL, 1391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8320, '1997-12-28 23:00:00+00', '2016-05-11 12:58:17.489202+00', 'Shamrock for Rhiannon, A', 'SHAMROCK FOR RHIANNON', 3, 32, 9999, 6, 53, NULL, 1391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8321, '1997-12-28 23:00:00+00', '2016-05-11 12:58:49.41878+00', 'Ripples Across the Barley', 'RIPPLES ACROSS THE BARLEY', 3, 32, 9999, 6, 53, NULL, 1391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8322, '1997-12-28 23:00:00+00', '2016-05-11 12:59:47.763596+00', 'Reeling for Fun', 'REELING FOR FUN', 2, 32, 9999, 6, 53, NULL, 1391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8323, '1997-12-28 23:00:00+00', '2016-05-11 13:00:19.432356+00', 'There Cam'' Brent', 'THERE CAM BRENT', 2, 32, 9999, 6, 53, NULL, 1391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8247, '1998-01-06 23:00:00+00', '2020-09-06 20:12:48.553662+00', 'Our Friend Bill', 'OUR FRIEND BILL', 1, 32, 9999, 1, 3, 42, 34, '1992-01-01', '', 69, '844/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8310, '1998-01-12 23:00:00+00', '2019-11-30 01:02:39.689418+00', 'Gaelic College Strathspey', 'GAELIC COLLEGE STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8295, '1998-01-12 23:00:00+00', '2021-01-10 19:05:34.981527+00', 'Jellyfish at North Gut', 'JELLYFISH AT NORTH GUT', 2, 32, 9999, 1, 4, 1, 2018, NULL, '', 44, '8000/8000/8000/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8313, '1998-01-12 23:00:00+00', '2021-03-20 19:41:25.801329+00', 'Gypsy Rover', 'GYPSY ROVER', 1, 32, 9999, 1, 3, 42, 2018, NULL, '', 50, '800/844/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8283, '1998-07-09 22:00:00+00', '2022-08-03 18:42:33.903435+00', 'Five Alive', 'FIVE ALIVE', 3, 32, 9999, 3, 5, 7, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13867, '2011-08-21 22:00:00+00', '2021-07-25 17:34:22.617121+00', 'Saint Mungo''s City', 'SAINT MUNGOS CITY', 3, 32, NULL, 1, 100, 2, 1415, NULL, '', 75, '4444/8888/0880/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8291, '1998-01-13 23:00:00+00', '2016-05-12 07:16:43.551988+00', 'Scotian Twasome, The', 'SCOTIAN TWASOME', 4, 128, 2, 107, 1, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8292, '1998-01-13 23:00:00+00', '2016-05-12 07:18:58.230346+00', 'Taigh Nan Gaidheal Srathspeidh agus Ruidhle', 'TAIGH NAN GAIDHEAL SRATHSPEIDH AGUS RUIDHLE', 4, 128, 2, 107, 2, 3, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8317, '1997-12-28 23:00:00+00', '2016-05-31 13:35:02.608067+00', 'Just Enough to Dance', 'JUST ENOUGH TO DANCE', 3, 32, 9999, 6, 53, 17, 1391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13872, '2011-08-22 22:00:00+00', '2016-09-19 12:42:13.438851+00', 'Manley Park', 'MANLEY PARK', 1, 32, NULL, 1, 3, 42, 10400, NULL, '', 56, '888/800/888/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13873, '2011-08-22 22:00:00+00', '2016-09-19 20:37:25.999466+00', 'Birthday Strathspey, A', 'BIRTHDAY STRATHSPEY', 3, 32, NULL, 5, 2, 76, 10400, '2006-10-17', 'Dance devised for the birthday celebrations at Tuesday class on 17 October 2006', 100, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13870, '2011-08-22 22:00:00+00', '2016-09-19 19:59:01.352215+00', 'A 57, The', '57', 2, 32, NULL, 1, 4, 2, 10400, NULL, '', 91, '8228/8888/8888/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8314, '1998-01-12 23:00:00+00', '2016-11-04 23:12:37.800967+00', 'Highland Gambler', 'HIGHLAND GAMBLER', 3, 32, 9999, 1, 2, 76, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8282, '1998-01-13 23:00:00+00', '2016-11-15 23:31:09.279169+00', 'Tandem Reel, The', 'TANDEM REEL', 1, 32, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8340, '1998-12-17 23:00:00+00', '2018-03-31 18:48:19.517262+00', 'Miss Judy Hodgins'' Reel', 'MISS JUDY HODGINS REEL', 1, 32, 9999, 1, 4, 1, 737, NULL, 'The original description calls this a "dance for three couples", but in fact it is a 4 couple dance, as 1c crossed to 4pl at the end and 4c steps up; it has the normal progression (2,3,4,1)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13007, '2006-11-01 23:00:00+00', '2018-04-03 00:07:39.2896+00', 'Compliments to Joyce', 'COMPLIMENTS TO JOYCE', 2, 40, 9999, 1, 3, 42, 619, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13008, '2006-11-01 23:00:00+00', '2018-04-03 00:07:41.107955+00', 'Dancing Cousins, The', 'DANCING COUSINS', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13006, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.112298+00', 'Florence''s Strathspey', 'FLORENCES STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17460, '2016-11-01 17:25:57.821531+00', '2018-07-16 23:57:50.483524+00', 'Slytherin House', 'SLYTHERIN HOUSE', 3, 32, NULL, 1, 3, 42, 2973, '2016-09-01', 'Music Any spooky strathspey. A suitable recording is ‘Midsummer Common’, RSCDS Book 49,

Jim Lindsay.



For teaching her class Sue Ronald wanted a strathspey with two snake pass chases in it and couldn''t find one, so Chris wrote this one.', 56, '880/800/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8356, '2002-06-02 22:00:00+00', '2019-09-20 19:55:21.551378+00', 'Ronda, La', 'RONDA', 1, 96, 9999, 6, 3, NULL, 108, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8350, '2002-06-02 22:00:00+00', '2018-04-03 00:07:42.434244+00', 'Donald''s Strathspey', 'DONALDS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8353, '2002-06-02 22:00:00+00', '2018-04-03 00:07:47.605333+00', 'Galapagos Gallop, The', 'GALAPAGOS GALLOP', 1, 32, 9999, 1, 3, 42, 108, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8337, '2001-05-21 22:00:00+00', '2018-04-03 00:08:01.850173+00', 'Man in Waiting, The', 'MAN IN WAITING', 3, 32, 9999, 1, 3, 42, 2677, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8358, '2002-06-02 22:00:00+00', '2018-04-03 00:08:03.659689+00', 'Mill on the Fleet, The', 'MILL ON THE FLEET', 3, 32, 9999, 1, 3, 42, 108, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8346, '2002-06-02 22:00:00+00', '2019-05-04 00:24:30.184459+00', 'Braveheart', 'BRAVEHEART', 3, 32, 9999, 1, 3, 42, 108, '1997-09-01', 'A dance to mark the passage of 700 years since the Battle of Stirling Bridge in 1297', 62, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8342, '1997-12-28 23:00:00+00', '2012-01-20 12:57:05.438792+00', 'Marie McLennan''s Fond Farewell to Lord Elgin', 'MARIE MACLENNANS FOND FAREWELL TO LORD ELGIN', 3, 40, 9999, 1, 4, NULL, 737, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8347, '2002-06-02 22:00:00+00', '2012-01-20 12:57:05.468168+00', 'Brown Willy', 'BROWN WILLY', 1, 128, 9999, 1, 4, NULL, 108, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13009, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.132716+00', 'John''s Compliments to Anne', 'JOHNS COMPLIMENTS TO ANNE', 3, 32, 9999, 3, 5, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13010, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.13949+00', 'Craigie Hill', 'CRAIGIE HILL', 2, 32, 9999, 3, 5, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13011, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.144897+00', 'Debbie''s Reel', 'DEBBIES REEL', 1, 32, 9999, NULL, NULL, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13015, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.169876+00', 'Stewart''s Hill', 'STEWARTS HILL', 3, 32, 9999, 4, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13016, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.17663+00', 'Georgina''s Jig', 'GEORGINAS JIG', 2, 40, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13017, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.183383+00', 'Graeme''s Reel', 'GRAEMES REEL', 1, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13018, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.190126+00', 'Janet''s Delight', 'JANETS DELIGHT', 3, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13022, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.214445+00', 'Disappearing Hill, The', 'DISAPPEARING HILL', 2, 32, 9999, NULL, 3, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13023, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.2219+00', 'Trip to Braco, A', 'TRIP TO BRACO', 2, 32, 9999, 1, 4, 2, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8359, '2002-02-12 23:00:00+00', '2012-01-20 12:57:05.553191+00', 'Saint Andrew''s Celebration', 'SAINT ANDREWS CELEBRATION', 1, 40, 9999, 1, 4, 1, 2926, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8362, '2002-06-03 22:00:00+00', '2012-01-20 12:57:05.574782+00', 'Red Thistle, The', 'RED THISTLE', 3, 32, 9999, 1, 4, NULL, 108, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8369, '2002-06-03 22:00:00+00', '2012-01-20 12:57:05.624947+00', 'Virgin of Terpsichore, The', 'VIRGIN OF TERPSICHORE', 3, 32, 9999, 1, 4, NULL, 108, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8335, '2001-05-21 22:00:00+00', '2015-11-09 23:10:45.242997+00', 'Kabin Fever', 'KABIN FEVER', 1, 32, 9999, 1, 3, 42, 2873, NULL, '', 56, '844/866/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8324, '1997-12-28 23:00:00+00', '2016-05-11 13:00:48.132456+00', 'Three''s ''Nuff', 'THREES NUFF', 2, 32, 9999, 6, 53, NULL, 1391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8325, '1997-12-28 23:00:00+00', '2016-05-11 13:01:11.759767+00', 'Here''s What You''re Missing', 'HERES WHAT YOURE MISSING', 2, 32, 9999, 6, 53, NULL, 1391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8333, '2001-05-21 22:00:00+00', '2016-05-11 14:39:17.889175+00', 'Gentle Annie', 'GENTLE ANNIE', 3, 32, 9999, 1, 3, 42, 2871, NULL, 'This dance is dedicated to Dr. William Gatens in honor of his long history of providing live music for our branch, including his own compositions.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8332, '2001-05-21 22:00:00+00', '2016-05-31 13:33:09.740903+00', 'Couples Meet', 'COUPLES MEET', 1, 32, 9999, 1, 3, 42, 2866, NULL, '', 56, '800/880/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8326, '1997-12-28 23:00:00+00', '2020-05-05 00:05:46.328843+00', 'Lorne Strathspey', 'LORNE STRATHSPEY', 3, 84, 9999, 107, 4, 3, 121, '1993-01-01', 'Display dance.

Starting positions: Dancers form a Cross, the M in the middle facing P outside.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8327, '1997-12-28 23:00:00+00', '2020-05-05 00:17:30.316942+00', 'Argyll Medley', 'ARGYLL MEDLEY', 4, 160, 10046, 107, 4, 3, 121, '1993-01-01', 'Display Dance.  

This dance consists of a 32 bar Strathspey followed by the full Kilmory Rant [4 x 32 bars]', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8368, '2002-06-03 22:00:00+00', '2020-05-10 18:02:01.420002+00', 'Uncle Isaac', 'UNCLE ISAAC', 1, 32, 9999, 1, 2, 76, 108, '1996-01-01', '', 60, '84/88/88/84', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8330, '2001-05-21 22:00:00+00', '2020-09-06 20:15:32.661526+00', 'Brandywine', 'BRANDYWINE', 3, 32, 9999, 1, 3, 42, 2870, NULL, '', 69, '884/884/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8339, '2001-05-21 22:00:00+00', '2020-09-06 20:18:47.231658+00', 'Raise the Roof', 'RAISE THE ROOF', 1, 32, 9999, 1, 3, 42, 2869, NULL, '', 56, '844/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8363, '2002-06-03 22:00:00+00', '2020-09-06 20:22:32.971116+00', 'Rotherham Romp, The', 'ROTHERHAM ROMP', 2, 32, 9999, 1, 4, 1, 108, '1996-01-01', '', 67, '8640/8880/8040/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8367, '2002-06-02 22:00:00+00', '2021-03-19 23:23:48.423147+00', 'Trip to Monymusk, A', 'TRIP TO MONYMUSK', 3, 32, 9999, 1, 3, 42, 108, '1996-01-01', '', 44, '800/844/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8365, '2001-05-21 22:00:00+00', '2021-03-20 10:58:29.923512+00', 'Sally Lightfoot', 'SALLY LIGHTFOOT', 2, 32, 9999, 1, 3, 42, 108, '1996-01-01', '', 50, '800/888/880/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8258, '1998-12-02 23:00:00+00', '2022-09-13 12:40:16.382501+00', 'Folksy Fivesome, The', 'FOLKSY FIVESOME', 1, 32, 9999, 4, 55, 35, 2472, '1995-01-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13004, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.099438+00', 'Lady Helen', 'LADY HELEN', 2, 32, 9999, 1, 99, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13005, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.105547+00', 'Nurses'' Reel, The', 'NURSES REEL', 2, 48, 9999, 1, 99, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13002, '2006-11-01 23:00:00+00', '2017-11-11 18:41:48.394188+00', 'Just a Lark', 'JUST A LARK', 1, 64, 9999, 104, 2, NULL, 3333, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13000, '2006-11-01 23:00:00+00', '2017-11-11 18:54:01.329635+00', 'Blaine''s Double Date', 'BLAINES DOUBLE DATE', 1, 32, 9999, 1, 4, NULL, 3724, '2005-01-01', 'Notes from Ellen: Dedicated to Blaine Peet.  We were both his "partner" for General Stuart''s reel at Capitol weekend, and later that night (read 4 a.m.) and a little wine (okay, a bottle) we had devised a real dance out of the makeshift petronella we had come up with in the dance. It actually works I think, and is fun. If you decide to try it, let me know if you have any thoughts for ways it might work better. One thing I''m going to try next time I do it, is to make the last 2 bars of the petronella skip change (when dancing couples dance to the sidelines). ', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8370, '1998-01-04 23:00:00+00', '2012-01-20 12:57:05.631968+00', 'Children of the Mist', 'CHILDREN OF THE MIST', 3, 32, 9999, 1, 4, NULL, 27, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8374, '1997-12-28 23:00:00+00', '2012-01-20 12:57:05.661478+00', 'Children''s Celebration Jig', 'CHILDRENS CELEBRATION JIG', 2, 64, 9999, 4, 4, NULL, 408, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13877, '2011-08-22 22:00:00+00', '2018-04-03 00:07:44.836209+00', 'Examiners, The', 'EXAMINERS', 1, 32, NULL, 1, 3, 42, 3349, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8377, '2002-04-30 22:00:00+00', '2012-05-07 20:35:35.813557+00', 'Elizabeth and Andrew Dorward', 'ELIZABETH AND ANDREW DORWARD', 2, 32, 9999, 1, 4, 1, 2990, '1995-03-01', 'In celebration of Elizabeth and Andrew Dorward''s Silver Wedding in march 1995', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8376, '2002-04-29 22:00:00+00', '2012-05-07 20:29:51.930914+00', 'Black Bitch Reel', 'BLACK BITCH REEL', 1, 32, 9999, 1, 4, 1, 553, '1990-01-01', 'Ladies born in Linlithgow are known as Black Bitches(!)', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8381, '2002-03-03 23:00:00+00', '2012-05-07 21:03:32.702051+00', 'Lady Ryder of Warsaw, CMG, OBE', 'LADY RYDER OF WARSAW CMG OBE', 1, 40, 9999, 1, 4, 1, 2990, '1994-11-01', 'In honour of Lady Ryder''s visit to Scotland in novembr 1994', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8382, '2002-05-14 22:00:00+00', '2012-05-07 21:15:02.713426+00', 'Stewart and Kathleen Walker', 'STEWART AND KATHLEEN WALKER', 3, 40, 9999, 1, 3, 42, 898, NULL, 'To congratulate Stewart and Kathleen Walker on 40 years of married bliss.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8383, '2002-03-03 23:00:00+00', '2012-05-07 21:21:43.428805+00', 'Medley for Kirsty, A', 'MEDLEY FOR KIRSTY', 4, 128, 13, 4, 4, 3, 2027, NULL, 'In celebration of Miss Kirsty A. Rae''s 21st birthday', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8400, '1997-12-28 23:00:00+00', '2018-04-03 00:07:46.596289+00', 'Forty Doctors Bent on Play', 'FORTY DOCTORS BENT ON PLAY', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13029, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.263042+00', 'Myra''s Return', 'MYRAS RETURN', 2, 40, 9999, 3, 5, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13030, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.269911+00', 'Scottish Visit, A', 'SCOTTISH VISIT', 2, 40, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13031, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.276685+00', 'Catherine''s Reel', 'CATHERINES REEL', 2, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8379, '1998-01-04 23:00:00+00', '2018-04-03 00:07:49.132322+00', 'Go Deasil', 'GO DEASIL', 3, 32, 9999, 1, 3, 42, 425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13033, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.289551+00', 'Goodlyburn Jig', 'GOODLYBURN JIG', 2, 32, 9999, 3, 5, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13036, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.309944+00', 'Pittencrief Park', 'PITTENCRIEF PARK', 3, 32, 9999, 4, 5, NULL, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13875, '2011-08-22 22:00:00+00', '2018-04-03 00:07:50.466574+00', 'Hallowed Halls of Learning, The', 'HALLOWED HALLS OF LEARNING', 3, 32, NULL, 1, 3, 42, 3354, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13878, '2011-08-22 22:00:00+00', '2012-01-20 12:57:49.828833+00', 'Expert, An', 'EXPERT', 1, 32, NULL, 1, 4, 2, 3357, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13881, '2011-08-22 22:00:00+00', '2012-01-20 12:57:49.848556+00', 'In the Heat of the Night', 'IN THE HEAT OF THE NIGHT', 4, 64, 5, 1, 4, 1, 3491, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8378, '2002-07-24 22:00:00+00', '2012-05-07 20:42:44.55054+00', 'Honeypot, The', 'HONEYPOT', 2, 32, 9999, 2, 3, 17, 736, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8384, '2002-05-14 22:00:00+00', '2012-05-07 21:24:18.402073+00', 'Tam''s Loup', 'TAMS LOUP', 2, 32, 9999, 1, 4, 2, 979, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8387, '1997-12-28 23:00:00+00', '2012-01-20 12:57:05.754847+00', 'Hunter Valley Rant', 'HUNTER VALLEY RANT', 1, 32, 9999, 1, 4, NULL, 109, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8390, '1997-12-28 23:00:00+00', '2012-01-20 12:57:05.775591+00', 'Windmill on the Hill, The', 'WINDMILL ON THE HILL', 3, 32, 9999, 2, 3, NULL, 2015, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8391, '1997-12-28 23:00:00+00', '2012-01-20 12:57:05.782403+00', 'Tak'' to Yoursel'' a New Partner', 'TAK TO YOURSEL A NEW PARTNER', 1, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8392, '1997-12-28 23:00:00+00', '2012-01-20 12:57:05.789247+00', 'Not What It Seems', 'NOT WHAT IT SEEMS', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8393, '1998-01-04 23:00:00+00', '2012-01-20 12:57:05.795996+00', 'Craignethan Castle', 'CRAIGNETHAN CASTLE', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13035, '2006-11-01 23:00:00+00', '2018-04-03 00:07:55.161583+00', 'Jennifer''s Delight', 'JENNIFERS DELIGHT', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8372, '1997-12-28 23:00:00+00', '2018-04-03 00:08:01.408088+00', 'MacPhee''s Hill', 'MACPHEES HILL', 3, 32, 9999, 1, 3, 42, 27, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8397, '1997-12-28 23:00:00+00', '2012-01-20 12:57:05.823294+00', 'Tillietudlem Railway Station', 'TILLIETUDLEM RAILWAY STATION', 1, 32, 9999, 2, 3, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8398, '1997-12-28 23:00:00+00', '2012-01-20 12:57:05.830178+00', 'Tilletudlem Ball, The', 'TILLETUDLEM BALL', 3, 32, 9999, 2, 3, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13880, '2011-08-22 22:00:00+00', '2018-04-03 00:08:09.16393+00', 'Open Window, The', 'OPEN WINDOW', 1, 32, NULL, 1, 3, 42, 59, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13879, '2011-08-22 22:00:00+00', '2018-04-03 00:08:10.973817+00', 'Pleasures of the Night, The', 'PLEASURES OF THE NIGHT', 2, 32, NULL, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8395, '1997-12-28 23:00:00+00', '2016-05-10 19:35:28.737139+00', 'Illusive Name, The', 'ILLUSIVE NAME', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8396, '1997-12-28 23:00:00+00', '2016-05-10 19:37:19.322411+00', 'Headless Ghost, The', 'HEADLESS GHOST', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8399, '1997-12-28 23:00:00+00', '2016-05-10 20:27:52.893361+00', 'Well Known Love Song, A', 'WELL KNOWN LOVE SONG', 2, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8401, '1997-12-28 23:00:00+00', '2016-05-10 20:29:32.493846+00', 'Haunted Stones, The', 'HAUNTED STONES', 1, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13876, '2011-08-22 22:00:00+00', '2016-07-10 12:25:11.923846+00', 'Mildred Clancey''s Strathspey', 'MILDRED CLANCEYS STRATHSPEY', 3, 32, NULL, 1, 4, 2, 3350, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13028, '2006-11-01 23:00:00+00', '2021-01-25 16:32:41.893967+00', 'Margaret''s Fancy', 'MARGARETS FANCY', 3, 32, 9999, 1, 4, NULL, 619, NULL, '<<scddb-not-identical:4158;10618>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8375, '2002-07-24 22:00:00+00', '2021-03-19 23:04:33.664539+00', 'Chalmers Hall', 'CHALMERS HALL', 2, 32, 9999, 1, 3, 42, 553, '2000-01-01', '', 69, '888/808/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8355, '2002-03-11 23:00:00+00', '2021-03-20 11:15:14.020314+00', 'Jim Nicholson''s Strathspey', 'JIM NICHOLSONS STRATHSPEY', 3, 32, 9999, 1, 100, 2, 108, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8345, '2002-06-02 22:00:00+00', '2021-03-20 12:58:37.956639+00', 'Blue-Footed Boobies, The', 'BLUEFOOTED BOOBIES', 3, 32, 9999, 1, 100, 11, 108, '1996-01-01', '', 75, '0880/8888/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13032, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.282772+00', 'Teacher''s Delight, A', 'TEACHERS DELIGHT', 3, 32, 9999, 1, 99, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13026, '2006-11-01 23:00:00+00', '2018-04-03 00:08:14.601429+00', 'Saint Matthew''s Reel', 'SAINT MATTHEWS REEL', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13027, '2006-11-01 23:00:00+00', '2018-04-03 00:08:18.587601+00', 'Storm, The', 'STORM', 2, 32, 9999, 1, 3, 42, 619, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13034, '2006-11-01 23:00:00+00', '2018-04-03 00:08:21.789694+00', 'Tribute to Allana, A', 'TRIBUTE TO ALLANA', 3, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13024, '2006-11-01 23:00:00+00', '2018-04-03 00:08:22.412713+00', 'Trip to Auchterarder, A', 'TRIP TO AUCHTERARDER', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8373, '1997-12-28 23:00:00+00', '2018-04-03 00:08:27.068361+00', 'Yon Hill Ardmore', 'YON HILL ARDMORE', 1, 40, 9999, 1, 3, 42, 27, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8436, '1998-01-04 23:00:00+00', '2018-04-03 00:07:29.99167+00', 'Alexander Mackenzie Hay', 'ALEXANDER MACKENZIE HAY', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8427, '1998-01-05 23:00:00+00', '2018-04-03 00:07:32.397762+00', 'Barnyards of Delgaty, The', 'BARNYARDS OF DELGATY', 1, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8404, '1997-12-28 23:00:00+00', '2012-01-20 12:57:05.871861+00', 'Auld Lang Syne', 'AULD LANG SYNE', 2, 32, 9999, 5, 2, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8405, '1997-12-28 23:00:00+00', '2012-01-20 12:57:05.878792+00', 'When the Spirit Moves', 'WHEN THE SPIRIT MOVES', 2, 32, 9999, 2, 3, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8426, '1997-12-28 23:00:00+00', '2018-04-03 00:07:35.751787+00', 'Bridge to Skye', 'BRIDGE TO SKYE', 2, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8408, '1997-12-28 23:00:00+00', '2012-01-20 12:57:05.899303+00', 'Courageous Piper, The', 'COURAGEOUS PIPER', 1, 32, 9999, 2, 3, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8409, '1997-12-28 23:00:00+00', '2012-01-20 12:57:05.906107+00', 'Trusty Claymore, The', 'TRUSTY CLAYMORE', 2, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8419, '1998-01-05 23:00:00+00', '2018-04-03 00:07:35.760207+00', 'Brigadoon', 'BRIGADOON', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8428, '1997-12-28 23:00:00+00', '2018-04-03 00:07:36.102278+00', 'Bugle Horn Jig, The', 'BUGLE HORN JIG', 2, 40, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13037, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.317409+00', 'Mr & Mrs Panton''s Golden Wedding', 'MR AND MRS PANTONS GOLDEN WEDDING', 2, 32, 9999, 3, 5, 7, 619, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18722, '2018-10-04 04:55:25.848025+00', '2018-10-04 05:08:02.764968+00', 'Curly Cat', 'CURLY CAT', 3, 32, NULL, 1, 3, 42, 2766, '2013-08-01', 'Our cat, Edwin, is very thin and often sleeps curled up in a tight circle', 44, '800/844/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13039, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.383042+00', 'Four Generations, The', 'FOUR GENERATIONS', 4, 256, 10000, 4, 4, NULL, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13040, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.390519+00', 'Fortieth Birthday Jig, A', 'FORTIETH BIRTHDAY JIG', 2, 32, 9999, 3, 5, 7, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13041, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.397324+00', 'Louise''s Wedding', 'LOUISES WEDDING', 3, 32, 9999, 1, 4, NULL, 619, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13044, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.417732+00', 'John''s Friends', 'JOHNS FRIENDS', 3, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13038, '2006-11-01 23:00:00+00', '2018-04-03 00:07:37.387254+00', 'Catherine''s Jig', 'CATHERINES JIG', 2, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13048, '2006-11-02 23:00:00+00', '2012-01-20 12:57:43.444193+00', 'Tickety-Boo', 'TICKETYBOO', 2, 32, 9999, 1, 4, 2, 352, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8435, '1998-01-04 23:00:00+00', '2018-04-03 00:07:38.563847+00', 'Clachnacuddin', 'CLACHNACUDDIN', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8385, '2002-07-24 22:00:00+00', '2012-05-07 21:36:00.017604+00', 'Welcome Home - King''s Own Scottish Borderers', 'WELCOME HOME  KINGS OWN SCOTTISH BORDERERS', 3, 32, 9999, 1, 4, 1, 3178, '1991-04-01', 'To mark the return of the KOSB regiment from the Gulf conflict in 1991', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8386, '2002-04-29 22:00:00+00', '2012-05-07 21:43:09.006617+00', 'Bert''s Reel', 'BERTS REEL', 1, 96, 9999, 4, 4, 3, 3112, '1995-01-01', 'Devised for his friend Bart Rae, 1995', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8413, '1998-10-18 22:00:00+00', '2012-01-20 12:57:05.933896+00', 'Brig o'' Balgownie', 'BRIG O BALGOWNIE', 1, 24, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8415, '1997-12-28 23:00:00+00', '2012-01-20 12:57:05.947581+00', 'Twix Hill and Glen', 'TWIX HILL AND GLEN', 1, 48, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13047, '2006-11-02 23:00:00+00', '2018-04-03 00:07:41.416454+00', 'Dare to Dance', 'DARE TO DANCE', 1, 32, 9999, 1, 3, 42, 352, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8433, '1997-12-28 23:00:00+00', '2018-04-03 00:07:47.989282+00', 'Geordie Hunter', 'GEORDIE HUNTER', 1, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13043, '2006-11-01 23:00:00+00', '2018-04-03 00:07:52.32622+00', 'Hillyland Highlander, The', 'HILLYLAND HIGHLANDER', 2, 48, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8424, '1997-12-28 23:00:00+00', '2012-01-20 12:57:06.009034+00', 'O! Flower of Scotland', 'O FLOWER OF SCOTLAND', 3, 40, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8414, '1997-12-28 23:00:00+00', '2018-04-03 00:07:53.410496+00', 'In Duthie Park', 'IN DUTHIE PARK', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13042, '2006-11-01 23:00:00+00', '2018-04-03 00:07:56.245702+00', 'John''s Comps to a Young Accordianist', 'JOHNS COMPS TO A YOUNG ACCORDIANIST', 2, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13053, '2006-11-02 23:00:00+00', '2018-04-03 00:07:56.629203+00', 'Julia''s Dance', 'JULIAS DANCE', 3, 32, 9999, 1, 3, 42, 352, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8429, '1997-12-28 23:00:00+00', '2018-04-03 00:08:03.701457+00', 'Mima Clanachan', 'MIMA CLANACHAN', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8437, '1998-01-05 23:00:00+00', '2018-04-03 00:08:05.686253+00', 'Mr Ian McLean''s Reel', 'MR IAN MACLEANS REEL', 1, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8420, '1997-12-28 23:00:00+00', '2018-04-03 00:08:06.820521+00', 'Muckle Mirth and Glee', 'MUCKLE MIRTH AND GLEE', 3, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8441, '1997-12-28 23:00:00+00', '2012-01-20 12:57:06.126764+00', 'Little Roe Deer, The', 'LITTLE ROE DEER', 3, 40, 9999, 1, 4, NULL, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13051, '2006-11-02 23:00:00+00', '2012-01-20 12:57:43.46615+00', 'Betwixt and Between', 'BETWIXT AND BETWEEN', 1, 64, 9999, 1, 4, 13, 352, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8412, '1997-12-28 23:00:00+00', '2016-05-10 19:33:37.366455+00', 'My Guid Auld Cronie', 'MY GUID AULD CRONIE', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8402, '1997-12-28 23:00:00+00', '2016-05-10 19:34:21.580121+00', 'Joy of Living, The', 'JOY OF LIVING', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8406, '1997-12-28 23:00:00+00', '2016-05-10 19:37:58.810703+00', 'Galloway Shepherd, The', 'GALLOWAY SHEPHERD', 2, 40, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8432, '1997-12-28 23:00:00+00', '2016-05-10 19:45:23.257328+00', 'Kinpurnie Castle', 'KINPURNIE CASTLE', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8434, '1997-12-28 23:00:00+00', '2016-05-10 19:46:24.926952+00', 'Farewell to Glenorchy', 'FAREWELL TO GLENORCHY', 3, 32, 9999, 1, 4, 1, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8440, '1997-12-28 23:00:00+00', '2016-05-10 19:47:03.611955+00', 'Mary Hutcheson', 'MARY HUTCHESON', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8439, '1997-12-28 23:00:00+00', '2016-05-10 19:58:34.789849+00', 'Four Leaf Clover, The', 'FOUR LEAF CLOVER', 3, 24, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8411, '1997-12-28 23:00:00+00', '2016-05-10 20:28:57.49174+00', 'Puckle B''Guess, A', 'PUCKLE BGUESS', 2, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8421, '1997-12-28 23:00:00+00', '2016-05-19 13:53:57.056616+00', 'Fronds in the Mist', 'FRONDS IN THE MIST', 3, 32, 9999, 1, 4, 1, 352, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8425, '1997-12-28 23:00:00+00', '2016-05-19 13:56:24.432407+00', 'Ta Think A''gen', 'TA THINK AGEN', 1, 24, 9999, 1, 4, 1, 352, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8423, '1997-12-28 23:00:00+00', '2016-05-19 13:57:31.355046+00', 'Touch of Scotland, A', 'TOUCH OF SCOTLAND', 1, 40, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8417, '1997-12-28 23:00:00+00', '2016-05-19 14:03:05.137544+00', 'Whom He ''Luffet'' Best', 'WHOM HE LUFFET BEST', 1, 32, 9999, 1, 4, 2, 352, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13046, '2006-11-02 23:00:00+00', '2016-05-21 15:01:27.326725+00', 'Pool of Reflections', 'POOL OF REFLECTIONS', 1, 64, 9999, 1, 4, 1, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13050, '2006-11-02 23:00:00+00', '2018-04-03 00:08:07.779507+00', 'New Zealand Reel, The', 'NEW ZEALAND REEL', 3, 32, 9999, 1, 3, 42, 352, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8416, '1997-12-28 23:00:00+00', '2018-04-03 00:08:10.306381+00', 'Penny Wedding, A', 'PENNY WEDDING', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13045, '2006-11-01 23:00:00+00', '2018-04-03 00:08:10.415068+00', 'Perth Scottish Country Dance Club', 'PERTH SCOTTISH COUNTRY DANCE CLUB', 3, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8418, '1998-01-05 23:00:00+00', '2022-09-13 12:45:56.795128+00', 'Brave Heart', 'BRAVE HEART', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8438, '1997-12-28 23:00:00+00', '2018-04-03 00:08:10.623473+00', 'Pilmuir Jig, The', 'PILMUIR JIG', 2, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8422, '1997-12-28 23:00:00+00', '2018-04-03 00:08:15.251741+00', 'Scots Awa', 'SCOTS AWA', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13055, '2006-11-02 23:00:00+00', '2012-01-20 12:57:43.493711+00', 'Dance for Kosti, A', 'DANCE FOR KOSTI', 1, 32, 9999, 1, 4, 1, 352, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13057, '2006-11-08 23:00:00+00', '2012-01-20 12:57:43.508102+00', 'Lady Cornwallis', 'LADY CORNWALLIS', 2, 32, 9999, 1, 4, 1, 352, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18717, '2018-10-03 10:08:01.596536+00', '2018-10-03 10:08:01.596536+00', 'Cross and Twist', 'CROSS AND TWIST', 2, 32, NULL, 1, 3, 42, 2766, '2016-02-01', 'I’ve recently taken up bobbin lace and all bobbin lace is made with two movements: cross and twist.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13059, '2006-11-08 23:00:00+00', '2012-01-20 12:57:43.522938+00', 'Laird of Langholm, The', 'LAIRD OF LANGHOLM', 3, 32, 9999, 1, 4, 2, 352, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13061, '2006-11-09 23:00:00+00', '2012-01-20 12:57:43.537378+00', 'King of Royal Road', 'KING OF ROYAL ROAD', 2, 32, 9999, 1, 4, 11, 352, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13062, '2006-11-09 23:00:00+00', '2012-01-20 12:57:43.544254+00', 'North of Meola', 'NORTH OF MEOLA', 3, 32, 9999, 1, 4, NULL, 352, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8445, '1997-12-28 23:00:00+00', '2012-01-20 12:57:06.154278+00', 'MacDonald Strathspey', 'MACDONALD STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13069, '2006-11-10 23:00:00+00', '2018-04-03 00:07:31.771499+00', 'Awa'' W'' My Heart', 'AWA W MY HEART', 1, 32, 9999, 1, 3, 42, 2680, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8456, '1997-12-28 23:00:00+00', '2012-01-20 12:57:06.229425+00', 'Where Twines the Path', 'WHERE TWINES THE PATH', 3, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8455, '1998-01-04 23:00:00+00', '2018-04-03 00:07:35.801806+00', 'Brig O'' Turk', 'BRIG O TURK', 3, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13058, '2006-11-08 23:00:00+00', '2018-04-03 00:07:36.294099+00', 'Butterworth Beauty', 'BUTTERWORTH BEAUTY', 1, 32, 9999, 1, 3, 42, 352, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13065, '2006-11-09 23:00:00+00', '2012-01-20 12:57:43.56482+00', 'Hidden in Milan', 'HIDDEN IN MILAN', 1, 32, 9999, 1, 4, NULL, 352, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13066, '2006-11-10 23:00:00+00', '2012-01-20 12:57:43.571678+00', 'In Celebration of Friends', 'IN CELEBRATION OF FRIENDS', 3, 32, 9999, 2, 3, NULL, 1381, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13072, '2006-11-10 23:00:00+00', '2012-01-20 12:57:43.613655+00', 'Echo Lake', 'ECHO LAKE', 1, 32, 9999, 1, 2, NULL, 3730, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8443, '1998-01-04 23:00:00+00', '2018-04-03 00:07:38.347036+00', 'Chrissie Michie''s Strathspey', 'CHRISSIE MICHIES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13074, '2006-11-10 23:00:00+00', '2018-04-03 00:07:40.982811+00', 'Dancers'' Circle, The', 'DANCERS CIRCLE', 2, 32, 9999, 1, 3, 42, 2680, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8442, '1997-12-28 23:00:00+00', '2016-05-10 20:32:22.681608+00', 'Ferntosh Strathspey, The', 'FERNTOSH STRATHSPEY', 3, 48, 9999, 1, 4, 1, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8454, '1998-01-04 23:00:00+00', '2016-05-12 07:32:57.431845+00', 'Cambuskenneth Abbey', 'CAMBUSKENNETH ABBEY', 3, 24, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8479, '1998-01-05 23:00:00+00', '2017-06-15 08:15:06.502048+00', 'Bees in the Heather', 'BEES IN THE HEATHER', 1, 32, 9999, 1, 3, 42, 872, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13063, '2006-11-09 23:00:00+00', '2017-02-15 14:19:31.035845+00', 'Barry of Glen Dean', 'BARRY OF GLEN DEAN', 1, 32, 9999, 1, 4, 13, 352, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8472, '1997-12-28 23:00:00+00', '2017-03-04 13:31:23.36532+00', 'Morning Mist', 'MORNING MIST', 3, 32, 9999, 1, 2, NULL, 872, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13064, '2006-11-09 23:00:00+00', '2018-04-03 00:08:09.805988+00', 'Panic Attack', 'PANIC ATTACK', 2, 32, 9999, 1, 3, 42, 352, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8468, '1998-01-04 23:00:00+00', '2017-03-05 03:38:42.438062+00', 'Autumn Gathering, An', 'AUTUMN GATHERING', 1, 32, 9999, 1, 3, 42, 872, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8459, '1997-12-28 23:00:00+00', '2018-04-03 00:07:44.377458+00', 'Ellen''s Isle', 'ELLENS ISLE', 3, 24, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13054, '2006-11-02 23:00:00+00', '2018-04-03 00:07:53.502027+00', 'Interlocking Reel, The', 'INTERLOCKING REEL', 1, 32, 9999, 1, 3, 42, 352, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8483, '1997-12-28 23:00:00+00', '2018-04-03 00:07:54.644565+00', 'It''s Spring Again', 'ITS SPRING AGAIN', 1, 32, 9999, 1, 3, 42, 872, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8457, '1997-12-28 23:00:00+00', '2018-04-03 00:07:59.923736+00', 'Loch Achray', 'LOCH ACHRAY', 3, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8444, '1997-12-28 23:00:00+00', '2018-04-03 00:08:00.065506+00', 'Lochee Jig', 'LOCHEE JIG', 2, 32, 9999, 1, 3, 42, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8458, '1997-12-28 23:00:00+00', '2018-04-03 00:08:00.123868+00', 'Loch Katrine', 'LOCH KATRINE', 3, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13067, '2006-11-10 23:00:00+00', '2018-04-03 00:08:00.907695+00', 'Lucky for Me', 'LUCKY FOR ME', 3, 32, 9999, 1, 3, 42, 3728, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13060, '2006-11-09 23:00:00+00', '2018-04-03 00:08:01.549865+00', 'Maid of Kaitia, The', 'MAID OF KAITIA', 1, 32, 9999, 1, 3, 42, 352, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8467, '1997-12-28 23:00:00+00', '2020-06-06 12:28:43.740386+00', 'Welcome', 'WELCOME', 1, 32, 9999, 7, 1, NULL, 872, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13073, '2006-11-10 23:00:00+00', '2021-01-04 17:12:17.866062+00', 'Dance With Your Heart', 'DANCE WITH YOUR HEART', 2, 32, 9999, 1, 3, 42, 1381, '2003-01-01', '', 66, '804/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8486, '1997-12-28 23:00:00+00', '2021-03-19 10:45:29.777738+00', 'Shiel Bridge', 'SHIEL BRIDGE', 2, 32, 9999, 1, 3, 42, 872, NULL, '', 56, '888/888/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8471, '1997-12-28 23:00:00+00', '2021-03-19 11:00:24.957123+00', 'Loch Quaich', 'LOCH QUAICH', 3, 32, 9999, 2, 3, 17, 872, NULL, '', 50, '880/800/844/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8469, '1997-12-28 23:00:00+00', '2021-03-19 11:02:12.730603+00', 'Helene''s Ramble', 'HELENES RAMBLE', 2, 32, 9999, 2, 3, 17, 872, NULL, '', 44, '888/800/822/804', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8465, '1997-12-28 23:00:00+00', '2021-03-19 11:24:55.195798+00', 'Scottish Jaunt, A', 'SCOTTISH JAUNT', 2, 32, 9999, 1, 4, 1, 872, NULL, '', 59, '8400/8400/8444/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8447, '1998-01-04 23:00:00+00', '2021-05-30 16:32:50.083652+00', 'Cherry Bloom', 'CHERRY BLOOM', 3, 32, 9999, 1, 3, 42, 352, '1996-04-29', '', 48, '800/860/808/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8448, '1998-01-04 23:00:00+00', '2021-06-01 00:46:10.88171+00', 'Callander Bridge', 'CALLANDER BRIDGE', 3, 32, 9999, 1, 3, 42, 352, '1996-04-30', '', 38, '880/800/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8478, '1997-12-28 23:00:00+00', '2021-07-14 11:56:48.590174+00', 'Summer Meeting, A', 'SUMMER MEETING', 1, 32, 9999, 1, 2, 76, 872, NULL, '', 52, '88/80/88/80', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8450, '1997-12-28 23:00:00+00', '2021-06-02 10:26:00.416493+00', 'Doune Castle', 'DOUNE CASTLE', 3, 32, 9999, 1, 3, 42, 352, '1996-04-30', '', 44, '880/880/800/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8460, '1998-01-04 23:00:00+00', '2021-06-03 07:39:43.401608+00', 'Borestone Reel', 'BORESTONE REEL', 3, 24, 9999, 1, 3, 42, 352, '1996-04-30', '', 58, '800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8451, '1998-01-04 23:00:00+00', '2021-06-03 08:03:29.948074+00', 'Cocksburnpath Glen', 'COCKSBURNPATH GLEN', 3, 32, 9999, 1, 3, 42, 352, '1996-01-01', '', 56, '800/866/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13056, '2006-11-08 23:00:00+00', '2021-10-09 06:31:17.235811+00', 'Kindergarten Reel', 'KINDERGARTEN REEL', 1, 32, 9999, 1, 3, 42, 352, '2003-01-01', '', 55, '800/866/855/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8452, '1998-01-04 23:00:00+00', '2021-07-20 22:47:43.379571+00', 'Aithrey Castle Reel', 'AITHREY CASTLE REEL', 3, 32, 9999, 1, 3, 42, 352, '1996-04-30', '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8491, '2001-06-12 22:00:00+00', '2012-01-20 12:57:06.494836+00', 'Maggie and Jock', 'MAGGIE AND JOCK', 3, 32, 9999, 1, 4, NULL, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18737, '2018-10-04 08:58:22.038827+00', '2018-10-04 08:58:22.038827+00', 'Double Ferris Wheel', 'DOUBLE FERRIS WHEEL', 1, 32, NULL, 1, 3, 42, 2766, '2012-09-01', 'The figures in this dance remind me of a double Ferris wheel.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8495, '2001-06-12 22:00:00+00', '2012-01-20 12:57:06.523283+00', 'Steel City Strathspey', 'STEEL CITY STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 2900, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8497, '2001-06-12 22:00:00+00', '2012-01-20 12:57:06.536895+00', 'Totley Tunnel Centenary', 'TOTLEY TUNNEL CENTENARY', 3, 32, 9999, 3, 5, NULL, 2901, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19030, '2018-10-20 23:57:42.369095+00', '2018-10-21 00:01:33.448648+00', 'Anne''s Jig', 'ANNES JIG', 2, 32, NULL, 1, 3, 42, 11181, '2018-10-21', '', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8484, '1997-12-28 23:00:00+00', '2022-10-04 19:01:31.653246+00', 'Jig for Laura (Jig 24 version), A', 'JIG FOR LAURA JIG 24 VERSION', 2, 24, 9999, 1, 4, 1, 872, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13084, '2006-11-10 23:00:00+00', '2012-01-20 12:57:43.698709+00', 'Strathspey for Julie, A', 'STRATHSPEY FOR JULIE', 3, 40, 9999, 2, 3, 17, 2862, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8528, '1998-02-08 23:00:00+00', '2019-03-06 18:09:52.378934+00', 'Anniversary Caper', 'ANNIVERSARY CAPER', 1, 32, 9999, 1, 4, 1, 787, NULL, '', 61, '8220/8440/8880/8666', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13086, '2006-11-10 23:00:00+00', '2012-01-20 12:57:43.713361+00', 'Dancing on Mount Tamalpais', 'DANCING ON MOUNT TAMALPAIS', 3, 32, 9999, 4, 4, 1, 2862, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8518, '2002-03-11 23:00:00+00', '2019-03-06 18:16:23.613892+00', 'Lewis and Colin''s Rant', 'LEWIS AND COLINS RANT', 1, 32, 9999, 4, 4, 13, 2075, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8509, '2002-04-08 22:00:00+00', '2019-03-06 18:24:43.653706+00', 'Reel Challenge, A', 'REEL CHALLENGE', 1, 32, 9999, 1, 4, 2, 13, NULL, '', 75, '0880/8888/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13076, '2006-11-10 23:00:00+00', '2014-04-27 15:03:55.186701+00', 'Reeling Roy', 'REELING ROY', 1, 48, 9999, 1, 100, 2, 884, '1998-01-01', 'A dance presented to Roy Batchelor by members of the RSCDS Western Australia Branch demonstration team on the occasion of his 60th birthday', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8504, '2002-03-11 23:00:00+00', '2019-03-06 18:26:12.417804+00', 'Happy Ferryman, The', 'HAPPY FERRYMAN', 1, 32, 9999, 1, 4, 1, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8517, '2002-03-11 23:00:00+00', '2019-06-15 10:27:31.214674+00', 'Greetings from Victoria', 'GREETINGS FROM VICTORIA', 1, 32, 9999, 1, 4, 11, 653, NULL, '', 88, '8448/8888/8888/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8531, '1998-02-08 23:00:00+00', '2018-04-03 00:07:39.612907+00', 'Cotton Mill, The', 'COTTON MILL', 1, 32, 9999, 1, 3, 42, 2080, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8489, '2001-06-12 22:00:00+00', '2019-07-15 04:08:49.010835+00', 'Barbara''s Jig', 'BARBARAS JIG', 2, 32, 9999, 1, 2, 76, 2899, NULL, '', 38, '44/88/80/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8530, '1998-02-08 23:00:00+00', '2012-01-20 12:57:06.821691+00', 'Celebration Reel', 'CELEBRATION REEL', 1, 32, 9999, 1, 2, NULL, 347, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8537, '1998-02-08 23:00:00+00', '2012-01-20 12:57:06.870316+00', 'Ray''s Water Bed', 'RAYS WATER BED', 1, 32, 9999, 1, 4, NULL, 2084, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13087, '2006-11-12 23:00:00+00', '2018-04-03 00:07:55.378348+00', 'Jig for Angelika, A', 'JIG FOR ANGELIKA', 2, 32, 9999, 1, 3, 42, 558, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8492, '2001-06-12 22:00:00+00', '2016-02-10 23:46:18.372915+00', 'Kissing Gates, The', 'KISSING GATES', 3, 32, 9999, 2, 3, 17, 2789, NULL, '', 75, '880/844/808/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13091, '2006-11-14 23:00:00+00', '2016-05-11 13:56:38.138072+00', 'Tea for Two', 'TEA FOR TWO', 1, 32, 9999, 107, 1, NULL, 1394, '2005-08-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8534, '1998-02-08 23:00:00+00', '2018-04-03 00:08:06.59549+00', 'Mrs Oliphant''s Reel', 'MRS OLIPHANTS REEL', 1, 32, 9999, 1, 3, 42, 2080, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8536, '1998-02-08 23:00:00+00', '2018-04-03 00:08:08.282455+00', 'Now We Are Six', 'NOW WE ARE SIX', 1, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8538, '1998-02-08 23:00:00+00', '2018-04-03 00:08:13.750867+00', 'Rounding the Buoy', 'ROUNDING THE BUOY', 1, 32, 9999, 1, 3, 42, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8540, '1998-02-08 23:00:00+00', '2018-04-03 00:08:16.169011+00', 'Shenandoah River Reel, The', 'SHENANDOAH RIVER REEL', 1, 32, 9999, 1, 3, 42, 2080, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8541, '1998-02-08 23:00:00+00', '2018-04-03 00:08:16.218921+00', 'Shetland Bus, The', 'SHETLAND BUS', 1, 32, 9999, 1, 3, 42, 2081, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13089, '2006-11-12 23:00:00+00', '2020-05-24 09:09:29.411622+00', 'Plain and Purl', 'PLAIN AND PURL', 2, 32, 9999, 1, 3, 42, 558, '2006-04-29', 'Dedicated to Andrea Kaufmann for her 50th birthday

', 44, '800/844/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8494, '2001-06-12 22:00:00+00', '2020-09-06 20:24:58.544392+00', 'Saint John''s of Abbeydale', 'SAINT JOHNS OF ABBEYDALE', 1, 32, 9999, 1, 3, 42, 2789, NULL, '', 44, '840/804/844/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13079, '2006-11-10 23:00:00+00', '2021-01-04 17:09:34.788469+00', 'Anne and Five Partners', 'ANNE AND FIVE PARTNERS', 2, 48, 9999, 3, 5, 4, 884, '2005-01-01', 'Presented to Anne Walker, RSCDS Western Australia Branch, on the occasion of a significant birthday.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13068, '2006-11-10 23:00:00+00', '2021-01-04 17:14:42.103591+00', 'When Hearts Meet', 'WHEN HEARTS MEET', 1, 32, 9999, 1, 3, 42, 3729, '2003-01-01', '', 59, '888/800/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8533, '2002-03-11 23:00:00+00', '2021-03-17 10:21:01.312317+00', 'Lakeside Kelpie Hornpipe, The', 'LAKESIDE KELPIE HORNPIPE', 1, 32, 9999, 1, 3, 42, 127, NULL, '', 63, '888/888/822/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8527, '2002-04-15 22:00:00+00', '2021-03-17 18:44:48.069159+00', 'Tides of Solva, The', 'TIDES OF SOLVA', 1, 32, 9999, 1, 4, 1, 2074, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8516, '2002-03-11 23:00:00+00', '2021-04-05 21:41:27.233285+00', 'Gathering of the Clan, A', 'GATHERING OF THE CLAN', 1, 32, 9999, 4, 4, 13, 2078, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8520, '2002-04-08 22:00:00+00', '2021-03-17 18:53:04.115023+00', 'Ness House, The', 'NESS HOUSE', 1, 32, 9999, 1, 3, 42, 1582, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8519, '2002-03-11 23:00:00+00', '2021-03-17 18:58:15.475828+00', 'Lewisian Reel, The', 'LEWISIAN REEL', 1, 32, 9999, 1, 3, 42, 99, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8535, '1998-02-08 23:00:00+00', '2021-09-19 22:51:54.654278+00', 'Ness House Reel, The', 'NESS HOUSE REEL', 1, 32, 9999, 1, 3, 42, 347, NULL, '', 38, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8513, '2002-03-02 23:00:00+00', '2021-03-17 19:38:21.320807+00', 'Capercaillie', 'CAPERCAILLIE', 1, 32, 9999, 3, 5, 7, 2076, NULL, '', 57, '08480/48084/08080/84884', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8510, '2002-04-08 22:00:00+00', '2021-03-17 19:57:55.897233+00', 'Rob Roy Rant, The', 'ROB ROY RANT', 1, 32, 9999, 1, 3, 42, 35, NULL, '', 63, '888/888/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8508, '2002-04-08 22:00:00+00', '2021-03-17 20:00:04.827299+00', 'Pretty Peggy', 'PRETTY PEGGY', 1, 32, 9999, 1, 2, 76, 28, NULL, '', 52, '44/44/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8506, '2002-04-08 22:00:00+00', '2021-03-18 12:33:51.688507+00', 'Many Happy Returns', 'MANY HAPPY RETURNS', 1, 32, 9999, 1, 4, 2, 2052, NULL, '"Dedicated to Nora Hunter on the occasion of her 80th Birthday. Nora, still actively dancing, was a founder member of Camberley Reel Club in 1960, and was the secretary for the first 16 years."', 88, '8448/8888/8888/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8503, '2002-04-10 22:00:00+00', '2021-03-18 12:36:37.733701+00', 'Farnham Maltings, The', 'FARNHAM MALTINGS', 1, 32, 9999, 5, 56, NULL, 27, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8502, '2002-04-24 22:00:00+00', '2021-03-18 12:39:49.605441+00', 'Clavers', 'CLAVERS', 1, 32, 9999, 1, 3, 42, 27, NULL, '', 53, '464/464/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8501, '2002-03-02 23:00:00+00', '2021-03-18 12:41:52.289547+00', 'Brightlingsea Belles', 'BRIGHTLINGSEA BELLES', 1, 32, 9999, 1, 3, 42, 2073, NULL, '', 63, '880/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8499, '2002-02-26 23:00:00+00', '2021-03-18 12:59:08.343365+00', 'All For Twelve Pounds', 'ALL FOR TWELVE POUNDS', 1, 32, 9999, 1, 3, 42, 27, NULL, '', 56, '800/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8485, '1997-12-28 23:00:00+00', '2021-03-19 10:48:33.493886+00', 'Return to Saint Swithuns', 'RETURN TO SAINT SWITHUNS', 1, 32, 9999, 1, 3, 42, 872, NULL, '', 47, '880/888/800/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8476, '1997-12-28 23:00:00+00', '2021-03-19 10:55:28.73365+00', 'Road to Moniefieth, The', 'ROAD TO MONIEFIETH', 1, 32, 9999, 1, 3, 42, 872, NULL, '', 50, '800/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8473, '1997-12-28 23:00:00+00', '2021-03-19 10:58:33.034415+00', 'Off to Tunbridge', 'OFF TO TUNBRIDGE', 1, 32, 9999, 1, 3, 42, 872, NULL, '', 56, '840/888/840/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8543, '2000-04-25 22:00:00+00', '2012-01-20 12:57:06.911515+00', 'Beauly Priory', 'BEAULY PRIORY', 1, 32, 9999, 1, 4, NULL, 2754, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8545, '2000-04-25 22:00:00+00', '2012-01-20 12:57:06.925384+00', 'Celtic Cross', 'CELTIC CROSS', 1, 32, 9999, 1, 4, NULL, 965, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8580, '1998-01-04 23:00:00+00', '2018-04-03 00:07:32.923282+00', 'Bells of Morningside, The', 'BELLS OF MORNINGSIDE', 3, 32, 9999, 1, 3, 42, 827, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8550, '2000-04-25 22:00:00+00', '2012-01-20 12:57:06.959619+00', 'Glencoe Loch', 'GLENCOE LOCH', 1, 64, 9999, 1, 4, NULL, 2761, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8584, '1998-01-13 23:00:00+00', '2018-04-29 12:47:10.491165+00', 'Passing in the Night', 'PASSING IN THE NIGHT', 2, 32, 9999, 1, 3, 42, 2018, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8553, '2000-04-25 22:00:00+00', '2012-01-20 12:57:06.981039+00', 'Over the Forth to Scone', 'OVER THE FORTH TO SCONE', 3, 32, 9999, 1, 4, NULL, 1252, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8601, '1998-07-09 22:00:00+00', '2012-01-20 12:57:07.320721+00', 'Sonas le Sith', 'SONAS LE SITH', 3, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8602, '1998-07-09 22:00:00+00', '2012-01-20 12:57:07.328224+00', 'Nellie''s Rights and Wrongs', 'NELLIES RIGHTS AND WRONGS', 3, 40, 9999, 3, 5, 16, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8521, '2002-04-08 22:00:00+00', '2022-10-04 18:59:27.128643+00', 'Parliamentary Reel, The', 'PARLIAMENTARY REEL', 1, 32, 9999, 1, 4, 1, 2074, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18272, '2018-04-02 20:21:43.597652+00', '2018-07-17 00:10:24.097254+00', 'Farewell to Balfour Road', 'FAREWELL TO BALFOUR ROAD', 2, 32, NULL, 3, 5, 8, 11623, NULL, '“Written for the Brighton and Hove SCD Club when they moved from Balfour School on Balfour Road to Moulsecoomb Hall.”



Note that being a canon, this dance only requires 96 bars of music rather than 160.



DEVISED:2015-12', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8552, '2000-04-25 22:00:00+00', '2019-02-21 02:03:07.794153+00', 'Nessie''s Real', 'NESSIES REAL', 1, 40, 9999, 1, 4, 1, 2757, '1997-03-01', '', 55, '8880/8800/8444/8444/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8560, '1998-01-05 23:00:00+00', '2012-01-20 12:57:07.030091+00', 'Cairnsmill', 'CAIRNSMILL', 1, 32, 9999, 1, 4, NULL, 2024, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8561, '1997-12-28 23:00:00+00', '2012-01-20 12:57:07.037013+00', 'Circassian Square Dance', 'CIRCASSIAN SQUARE DANCE', 2, 32, 9999, 4, 4, NULL, 2022, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13105, '2006-11-19 23:00:00+00', '2012-01-20 12:57:43.871869+00', 'Courtship, The', 'COURTSHIP', 3, 32, 9999, 2, 3, NULL, 324, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13109, '2006-11-19 23:00:00+00', '2012-01-20 12:57:43.909555+00', 'One Mother Warned You About, The', 'ONE MOTHER WARNED YOU ABOUT', 2, 32, 9999, 1, 4, 1, 324, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13110, '2006-11-19 23:00:00+00', '2012-01-20 12:57:43.919295+00', 'Party Night', 'PARTY NIGHT', 1, 32, 9999, 1, 4, 2, 324, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13111, '2006-11-19 23:00:00+00', '2012-01-20 12:57:43.929077+00', 'Round About the Place', 'ROUND ABOUT THE PLACE', 2, 32, 9999, 1, 4, 1, 324, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13112, '2006-11-19 23:00:00+00', '2012-01-20 12:57:43.937775+00', 'Summer Sun, The', 'SUMMER SUN', 1, 32, 9999, 4, 4, NULL, 324, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13092, '2006-11-14 23:00:00+00', '2013-05-31 15:50:22.715452+00', 'Blame it on Jane', 'BLAME IT ON JANE', 1, 32, 9999, 6, 53, 18, 3733, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13108, '2006-11-19 23:00:00+00', '2018-04-03 00:07:41.875448+00', 'Denver Triagonal', 'DENVER TRIAGONAL', 1, 32, 9999, 1, 3, 42, 324, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13095, '2006-11-14 23:00:00+00', '2013-05-31 20:11:16.492267+00', 'No Rest for the Wicked', 'NO REST FOR THE WICKED', 3, 32, 9999, 6, 53, 17, 3733, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13096, '2006-11-14 23:00:00+00', '2013-05-31 20:14:01.412572+00', 'Bonnie Cockade, The', 'BONNIE COCKADE', 3, 32, 9999, 4, 54, 13, 3734, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13097, '2006-11-14 23:00:00+00', '2013-05-31 20:17:26.101147+00', 'Cast of Four', 'CAST OF FOUR', 1, 32, 9999, 4, 54, 13, 3734, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13098, '2006-11-14 23:00:00+00', '2013-05-31 20:25:11.130599+00', 'More for Four', 'MORE FOR FOUR', 1, 32, 9999, 4, 54, 15, 1394, '2004-06-18', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8551, '2000-04-25 22:00:00+00', '2018-04-03 00:07:49.582557+00', 'Grannie''s Caper', 'GRANNIES CAPER', 3, 32, 9999, 1, 3, 42, 2755, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13107, '2006-11-19 23:00:00+00', '2018-04-03 00:08:00.440765+00', 'Loopy Loops', 'LOOPY LOOPS', 1, 32, 9999, 1, 3, 42, 324, '2000-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8549, '2000-04-25 22:00:00+00', '2019-02-21 01:08:13.883064+00', 'Footdee Slider, The', 'FOOTDEE SLIDER', 1, 32, 9999, 1, 4, 2, 2762, '1997-02-01', '', 91, '8888/8448/8888/8668', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8563, '1998-01-01 23:00:00+00', '2012-01-20 12:57:07.05078+00', 'Hector Macnab', 'HECTOR MACNAB', 2, 32, 9999, 1, 4, NULL, 2022, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8570, '1998-10-20 22:00:00+00', '2012-01-20 12:57:07.104095+00', 'Fizzbin - The Next Generation', 'FIZZBIN  THE NEXT GENERATION', 1, 48, 9999, 1, 4, NULL, 2360, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8572, '1998-01-04 23:00:00+00', '2012-01-20 12:57:07.117932+00', 'Leaving Harbour', 'LEAVING HARBOUR', 2, 48, 9999, 4, 4, NULL, 425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8547, '2000-04-25 22:00:00+00', '2019-02-21 03:12:20.3239+00', 'Don''s Dance', 'DONS DANCE', 2, 40, 9999, 1, 4, 1, 2758, '1997-02-01', '', 48, '8000/8000/8000/8444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13101, '2006-11-14 23:00:00+00', '2019-06-10 15:50:26.416292+00', 'Mousetrap', 'MOUSETRAP', 1, 32, 9999, 4, 55, 58, 1394, NULL, 'Suggested music: Any frantic 5x32 reel', 50, '84448/44848/00008/42442', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8581, '1997-12-28 23:00:00+00', '2012-01-20 12:57:07.179932+00', 'Karakusa Strathspey, The', 'KARAKUSA STRATHSPEY', 3, 64, 9999, 4, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8582, '1998-01-04 23:00:00+00', '2018-04-03 00:08:27.193431+00', 'Yuletide', 'YULETIDE', 1, 32, 9999, 1, 3, 42, 425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8542, '2002-11-14 23:00:00+00', '2016-08-04 16:09:17.976395+00', '25th Celebration Reel, The', '25TH CELEBRATION REEL', 1, 32, 9999, 1, 4, NULL, 347, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8586, '1998-07-09 22:00:00+00', '2016-11-15 23:37:25.993132+00', 'Sheltie Reel, The', 'SHELTIE REEL', 1, 32, 9999, 2, 3, 17, 2018, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13115, '2006-11-21 23:00:00+00', '2017-11-11 23:52:53.627798+00', 'Saunter in Savoy', 'SAUNTER IN SAVOY', 3, 32, 9999, 2, 3, NULL, 17, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8579, '1998-03-25 23:00:00+00', '2017-06-18 16:39:45.999416+00', 'Thistle Dancers'' Waltz', 'THISTLE DANCERS WALTZ', 5, 136, 9999, 4, 98, NULL, 425, NULL, '4 trios in square formation', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13114, '2006-11-19 23:00:00+00', '2018-04-03 00:08:02.008505+00', 'Margaret Brown''s Strathspey', 'MARGARET BROWNS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3183, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8565, '1998-01-01 23:00:00+00', '2018-04-03 00:08:13.700751+00', 'Rotherham Rant', 'ROTHERHAM RANT', 1, 48, 9999, 1, 3, 42, 2025, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8585, '1998-01-13 23:00:00+00', '2018-04-03 00:08:22.965344+00', 'Twa in Clover', 'TWA IN CLOVER', 3, 32, 9999, 1, 3, 42, 2018, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8578, '1998-10-20 22:00:00+00', '2020-03-05 14:22:22.903855+00', 'Tiraluin', 'TIRALUIN', 2, 32, 9999, 1, 3, 42, 600, '1986-01-01', '', 56, '880/880/880/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8498, '2001-06-12 22:00:00+00', '2020-08-24 22:44:34.588699+00', 'Woodland Reel, The', 'WOODLAND REEL', 1, 40, 9999, 1, 3, 42, 2899, NULL, '', 60, '888/800/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8564, '2002-02-26 23:00:00+00', '2021-03-16 16:43:02.264239+00', 'Jennifer''s Fancy', 'JENNIFERS FANCY', 1, 32, 9999, 3, 5, 7, 2026, NULL, '', 80, '80800/88888/84884/88888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8557, '2002-03-11 23:00:00+00', '2021-03-16 18:35:59.789945+00', 'Kirkgate Reel, The', 'KIRKGATE REEL', 1, 88, 9999, 4, 4, 3, 692, '1995-01-01', 'For the Derwent Scottish Country Dance Club, Cockermouth, who meet in All Saints Church Hall in Kirkgate.', 75, '8888/8888/5555/8080/8080/8888/0808/0808/5555/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8544, '2000-04-25 22:00:00+00', '2021-06-06 13:25:50.755629+00', 'Carousel, The', 'CAROUSEL', 1, 32, 9999, 1, 2, 76, 2760, '1997-01-01', '', 64, '84/88/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8567, '2001-05-03 22:00:00+00', '2021-08-05 22:16:52.795761+00', 'Iona', 'IONA', 3, 32, 9999, 1, 2, NULL, 425, '1997-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8591, '1998-07-09 22:00:00+00', '2012-01-20 12:57:07.250409+00', 'Really!!', 'REALLY', 3, 32, 9999, 2, 3, 17, 2018, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8595, '1998-01-13 23:00:00+00', '2018-04-03 00:07:34.725271+00', 'Bonnie Jean of Aberdeen', 'BONNIE JEAN OF ABERDEEN', 1, 32, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8622, '1998-01-14 23:00:00+00', '2018-04-03 00:07:43.983467+00', 'Edinburgh Decision, The', 'EDINBURGH DECISION', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8606, '1998-01-13 23:00:00+00', '2018-04-03 00:07:46.28775+00', 'Flower''s Favourite', 'FLOWERS FAVOURITE', 2, 32, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8589, '1998-01-13 23:00:00+00', '2018-04-03 00:08:10.248014+00', 'Pei Link', 'PEI LINK', 1, 32, 9999, 1, 3, 42, 2018, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8625, '1998-01-18 23:00:00+00', '2018-04-03 00:08:14.793225+00', 'Salute to John Linscott, A', 'SALUTE TO JOHN LINSCOTT', 4, 32, 1, 1, 3, 42, 244, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8596, '1998-01-13 23:00:00+00', '2012-01-20 12:57:07.285183+00', 'Briar Bush', 'BRIAR BUSH', 1, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8598, '1998-07-09 22:00:00+00', '2012-01-20 12:57:07.299484+00', 'Mareid''s Strathspey', 'MAREIDS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8599, '1998-01-13 23:00:00+00', '2012-01-20 12:57:07.306297+00', 'Wee Mousie, The', 'WEE MOUSIE', 1, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13116, '2006-11-21 23:00:00+00', '2022-08-20 19:57:43.475285+00', 'Wee Bit o'' Fun, A', 'WEE BIT O FUN', 2, 32, 9999, 1, 3, 42, 17, '2006-01-01', '', 55, '880/844/844/868', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13106, '2006-11-19 23:00:00+00', '2022-08-13 16:56:33.963869+00', 'Dancing on the Green', 'DANCING ON THE GREEN', 2, 32, 9999, 1, 4, 1, 324, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7605, '2002-11-18 23:00:00+00', '2022-10-23 19:38:11.192304+00', 'Banks of the Limmat, The', 'BANKS OF THE LIMMAT', 3, 32, 9999, 1, 3, 42, 671, NULL, 'Inscribed to Prue Brunner, who was president of the Zurich Scottish Country Dancing Club for 20 years.', 43, '804/840/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13142, '2006-12-06 23:00:00+00', '2022-11-13 17:36:39.397539+00', 'Bessborough Castle, The', 'BESSBOROUGH CASTLE', 3, 32, 9999, 1, 3, 42, 3746, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8592, '1998-01-13 23:00:00+00', '2018-04-03 00:08:25.066785+00', 'Wheelie Reel', 'WHEELIE REEL', 1, 32, 9999, 1, 3, 42, 2018, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8604, '1998-01-13 23:00:00+00', '2012-01-20 12:57:07.342654+00', 'Summer Gathering, A', 'SUMMER GATHERING', 2, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8605, '1998-01-13 23:00:00+00', '2012-01-20 12:57:07.34954+00', 'Saint Ann''s Fair', 'SAINT ANNS FAIR', 1, 40, 9999, 1, 4, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13120, '2006-11-28 23:00:00+00', '2019-02-12 21:55:44.922006+00', 'Alice the Camel', 'ALICE THE CAMEL', 1, 48, 9999, 1, 4, 1, 10457, '2003-02-01', '', 73, '8660/8888/8888/8800/8000/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8631, '1998-11-01 23:00:00+00', '2019-02-16 11:19:45.195147+00', 'Lindberg Lilt, The', 'LINDBERG LILT', 2, 32, 9999, 1, 3, 42, 2071, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8632, '1998-11-02 23:00:00+00', '2019-02-16 11:23:59.592218+00', 'Truly Yours', 'TRULY YOURS', 2, 32, 9999, 1, 4, NULL, 2071, '1981-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13126, '2006-11-28 23:00:00+00', '2019-02-28 21:08:26.848616+00', 'Ten o'' Clock Reel', 'TEN O CLOCK REEL', 1, 40, 9999, 4, 5, 35, 10718, NULL, 'Rosemary Crabb-Wyke', 56, '08088/88888/22228/84004/04840', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8621, '1998-01-14 23:00:00+00', '2012-01-20 12:57:07.458928+00', 'Slainte Mhath', 'SLAINTE MHATH', 4, 128, 2, 4, 4, NULL, 9998, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8623, '1998-01-18 23:00:00+00', '2012-01-20 12:57:07.472834+00', 'Sidcup Ruby, The', 'SIDCUP RUBY', 1, 48, 9999, 2, 3, NULL, 244, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8626, '2000-03-13 23:00:00+00', '2012-01-20 12:57:07.493425+00', 'Dance for the Bride, A', 'DANCE FOR THE BRIDE', 4, 120, 35, 4, 4, NULL, 244, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8594, '1998-01-13 23:00:00+00', '2016-05-11 14:46:06.022217+00', 'Gaelic College Twasome', 'GAELIC COLLEGE TWASOME', 3, 64, 9999, 107, 1, NULL, 2018, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8610, '1998-01-13 23:00:00+00', '2016-05-19 22:51:12.345679+00', 'All Mixed Up', 'ALL MIXED UP', 1, 32, 9999, 7, 113, 4, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8613, '1998-01-13 23:00:00+00', '2016-05-19 22:52:26.576879+00', 'Chain Around', 'CHAIN AROUND', 2, 40, 9999, 7, 113, 4, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8609, '1998-01-13 23:00:00+00', '2016-05-19 22:56:03.787215+00', 'Allemande Round', 'ALLEMANDE ROUND', 1, 32, 9999, 7, 113, 4, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8611, '1998-01-13 23:00:00+00', '2016-05-19 22:57:02.793647+00', 'P''s and C''s', 'PS AND CS', 2, 32, 9999, 7, 113, 4, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8612, '1998-01-13 23:00:00+00', '2016-05-19 22:57:46.180605+00', 'Eights all Round', 'EIGHTS ALL ROUND', 1, 40, 9999, 7, 113, 4, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8614, '1998-01-13 23:00:00+00', '2016-05-19 22:59:09.066019+00', 'Hourglass, The', 'HOURGLASS', 3, 32, 9999, 7, 113, 4, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8615, '1998-01-13 23:00:00+00', '2016-05-19 22:59:43.263679+00', 'Linked Circle', 'LINKED CIRCLE', 3, 32, 9999, 7, 113, 4, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8616, '1998-01-13 23:00:00+00', '2016-05-19 23:00:38.520076+00', 'Suas E!', 'SUAS E', 3, 32, 9999, 7, 113, 4, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8617, '1998-01-13 23:00:00+00', '2016-05-19 23:01:16.944287+00', 'Round Churn, The', 'ROUND CHURN', 3, 32, 9999, 7, 113, 4, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8618, '1998-01-13 23:00:00+00', '2016-05-19 23:04:12.12318+00', 'Scots Circle, The', 'SCOTS CIRCLE', 3, 32, 9999, 7, 113, 4, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8587, '1998-01-13 23:00:00+00', '2016-11-15 23:25:44.929991+00', 'Tensome Reel, The', 'TENSOME REEL', 1, 32, 9999, 4, 5, NULL, 2018, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8588, '1998-01-13 23:00:00+00', '2016-11-15 23:34:50.026336+00', 'Rosette Stone', 'ROSETTE STONE', 3, 32, 9999, 1, 3, 42, 2018, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8638, '1998-02-08 23:00:00+00', '2012-01-20 12:57:07.585243+00', 'Edy Steuri''s Reel', 'EDY STEURIS REEL', 1, 96, 9999, 4, 4, NULL, 2072, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8639, '2002-01-08 23:00:00+00', '2012-01-20 12:57:07.592144+00', 'Welcome to Grenoble', 'WELCOME TO GRENOBLE', 2, 32, 9999, 1, 4, NULL, 17, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13151, '2006-12-11 23:00:00+00', '2018-10-02 11:29:54.850238+00', 'Bubba-Que', 'BUBBAQUE', 2, 32, 9999, 1, 3, 42, 2766, '2006-01-01', 'The title of this dance comes from a friend’s young son’s mis-reading of the name of the town of Dubuque, Iowa on a roadmap.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8641, '1998-02-24 23:00:00+00', '2012-01-20 12:57:07.607992+00', 'Dragon and the Serpent, The', 'DRAGON AND THE SERPENT', 3, 32, 9999, 1, 4, NULL, 17, '1966-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8624, '1998-06-21 22:00:00+00', '2020-03-24 22:22:55.991732+00', 'Bouquet for Margaret Tate, A', 'BOUQUET FOR MARGARET TATE', 3, 32, 9999, 1, 3, 42, 244, '1991-01-01', '', 69, '888/880/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8607, '1998-01-13 23:00:00+00', '2020-09-07 08:53:03.674437+00', 'Tulloch Circle', 'TULLOCH CIRCLE', 1, 32, 9999, 7, 113, 4, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13123, '2006-11-28 23:00:00+00', '2020-09-15 21:23:50.08518+00', 'Judith''s Wedding', 'JUDITHS WEDDING', 1, 48, 9999, 2, 3, 17, 10495, '2001-08-01', '', 58, '888/800/888/888/484/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13124, '2006-11-28 23:00:00+00', '2020-09-15 21:26:55.967102+00', 'Pas de Basque It', 'PAS DE BASQUE IT', 2, 32, 9999, 1, 3, 42, 1849, '2000-10-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13125, '2006-11-28 23:00:00+00', '2020-09-15 21:32:31.426754+00', 'Picardy Jig', 'PICARDY JIG', 2, 40, 9999, 1, 4, 2, 3286, '2005-04-01', '', 85, '0880/8888/8888/4884/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13152, '2006-12-11 23:00:00+00', '2020-09-17 00:41:11.983798+00', 'Anna''s Heading West', 'ANNAS HEADING WEST', 1, 32, 9999, 1, 3, 42, 2766, '2006-01-01', 'This dance is written for Anna Jean, who is leaving our group and moving back to California.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13128, '2006-12-05 23:00:00+00', '2021-01-04 16:17:11.404689+00', 'Crawfords of Kerrera, The', 'CRAWFORDS OF KERRERA', 2, 32, 9999, 1, 3, 42, 104, '2003-01-01', '', 56, '800/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8620, '1998-01-13 23:00:00+00', '2021-03-16 10:14:26.717393+00', 'Twirling Circle', 'TWIRLING CIRCLE', 3, 32, 9999, 7, 98, 4, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8597, '1998-01-13 23:00:00+00', '2021-03-16 16:35:47.084969+00', 'Gone Fishing', 'GONE FISHING', 3, 32, 9999, 1, 2, 76, 2018, NULL, '', 60, '88/88/88/80', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13156, '2006-12-11 23:00:00+00', '2018-10-02 22:34:34.088688+00', 'Catch Me If You Can', 'CATCH ME IF YOU CAN', 2, 32, 9999, 1, 3, 42, 2766, '2006-02-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13162, '2006-12-11 23:00:00+00', '2018-10-03 01:19:24.382985+00', 'Circle of Friends', 'CIRCLE OF FRIENDS', 1, 32, 9999, 4, 4, 4, 2766, '2006-02-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13160, '2006-12-11 23:00:00+00', '2018-10-04 23:33:07.802126+00', 'Fashion Designer', 'FASHION DESIGNER', 1, 32, 9999, 2, 3, NULL, 2766, '2006-01-01', 'This dance is written for my sister Roberta, who is a talented needleworker and designs clothing.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13155, '2006-12-11 23:00:00+00', '2018-10-05 14:35:59.890275+00', 'Ice Dancing', 'ICE DANCING', 1, 32, 9999, 1, 3, 42, 2766, '2006-02-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8655, '1998-03-31 22:00:00+00', '2018-04-03 00:07:30.76923+00', 'Anne''s Dance', 'ANNES DANCE', 3, 32, 9999, 1, 3, 42, 659, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8649, '1998-03-16 23:00:00+00', '2012-01-20 12:57:07.666125+00', 'Stafford Ruby Reel, The', 'STAFFORD RUBY REEL', 1, 40, 9999, 1, 4, NULL, 2091, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13154, '2006-12-11 23:00:00+00', '2018-10-06 13:49:12.420923+00', 'Pepper Mill, The', 'PEPPER MILL', 3, 32, 9999, 1, 3, 42, 2766, '2006-06-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13161, '2006-12-11 23:00:00+00', '2018-10-07 11:46:15.066706+00', 'Roping the Wind', 'ROPING THE WIND', 1, 32, 9999, 3, 5, 41, 2766, '2006-02-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8633, '1998-11-01 23:00:00+00', '2019-06-15 12:56:03.427353+00', 'Gabriel''s Trumpet', 'GABRIELS TRUMPET', 2, 32, 9999, 1, 3, 42, 2071, '1987-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8634, '1998-11-01 23:00:00+00', '2019-02-16 11:23:02.300475+00', 'Sweet Sixteen', 'SWEET SIXTEEN', 3, 32, 9999, 1, 2, NULL, 2071, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8636, '1998-11-01 23:00:00+00', '2019-02-16 11:26:13.997131+00', 'Where the Grass is Greener', 'WHERE THE GRASS IS GREENER', 3, 32, 9999, 1, 3, 42, 2071, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8651, '1998-03-20 23:00:00+00', '2012-01-20 12:57:07.680285+00', 'Christophe''s Farewell', 'CHRISTOPHES FAREWELL', 1, 32, 9999, 1, 2, NULL, 1849, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13145, '2006-12-06 23:00:00+00', '2022-11-13 17:12:52.908419+00', 'Jig for Yorkton, A', 'JIG FOR YORKTON', 2, 32, 9999, 6, 3, 4, 2998, '2004-02-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13144, '2006-12-06 23:00:00+00', '2022-11-13 17:33:11.119295+00', 'Wascana Reel, The', 'WASCANA REEL', 1, 32, 9999, 6, 3, 4, 2998, '2004-02-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13140, '2006-12-06 23:00:00+00', '2022-11-13 17:36:08.123623+00', 'Saskatchewan Centennial Reel, The', 'SASKATCHEWAN CENTENNIAL REEL', 1, 48, 9999, 4, 4, NULL, 3745, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13141, '2006-12-06 23:00:00+00', '2022-11-13 17:38:32.285339+00', 'Saskatchewan Dancers', 'SASKATCHEWAN DANCERS', 2, 32, 9999, 1, 3, 42, 3643, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8608, '1998-01-13 23:00:00+00', '2022-11-21 13:44:01.184713+00', 'Walk Round', 'WALK ROUND', 1, 32, 9999, 7, 113, 4, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8637, '1998-11-01 23:00:00+00', '2019-06-15 08:01:55.069824+00', 'Lindberg Strathspey, The', 'LINDBERG STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2071, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8657, '1998-05-08 22:00:00+00', '2012-01-20 12:57:07.72273+00', 'Black Rose, The', 'BLACK ROSE', 3, 40, 9999, 4, 4, NULL, 2100, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8659, '1998-03-31 22:00:00+00', '2012-01-20 12:57:07.736562+00', 'Breuberg Castle Reel, The', 'BREUBERG CASTLE REEL', 1, 32, 9999, 1, 4, NULL, 2102, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8661, '1998-04-24 22:00:00+00', '2012-01-20 12:57:07.750433+00', 'Ceilidh Jubilee', 'CEILIDH JUBILEE', 2, 32, 9999, 1, 4, NULL, 2103, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8664, '1998-03-31 22:00:00+00', '2012-01-20 12:57:07.771032+00', 'Dortmund 09-some', 'DORTMUND 09SOME', 1, 208, 9999, 4, 98, NULL, 2105, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8678, '1998-03-31 22:00:00+00', '2012-01-20 12:57:07.870836+00', 'Irish Stew, The', 'IRISH STEW', 1, 40, 9999, 3, 5, NULL, 2110, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8640, '2006-03-23 23:00:00+00', '2018-04-03 00:07:45.386882+00', 'Feathered Pheasant, The', 'FEATHERED PHEASANT', 1, 32, 9999, 1, 3, 42, 2115, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8662, '1998-03-31 22:00:00+00', '2018-04-03 00:07:38.388592+00', 'Christine''s Frolic', 'CHRISTINES FROLIC', 2, 40, 9999, 1, 3, 42, 2104, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8671, '2002-04-24 22:00:00+00', '2017-09-15 23:31:41.374025+00', 'St Martin''s Cross', 'SAINT MARTINS CROSS', 1, 32, 9999, 1, 4, 11, 17, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8663, '1998-03-31 22:00:00+00', '2018-04-03 00:07:42.726133+00', 'Dortmund Furnaces', 'DORTMUND FURNACES', 2, 32, 9999, 1, 3, 42, 2100, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8667, '1998-04-01 22:00:00+00', '2018-04-03 00:07:43.885357+00', 'Eden Reel, The', 'EDEN REEL', 1, 32, 9999, 1, 3, 42, 1386, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8642, '2006-03-23 23:00:00+00', '2018-04-03 00:07:45.903944+00', 'Fiona Left Home', 'FIONA LEFT HOME', 1, 32, 9999, 1, 3, 42, 3666, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8652, '1998-03-21 23:00:00+00', '2018-04-03 00:07:46.229277+00', 'Florentine''s Fancy', 'FLORENTINES FANCY', 1, 32, 9999, 1, 3, 42, 1849, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8673, '1998-04-01 22:00:00+00', '2018-04-03 00:07:48.089379+00', 'Georg''s no Name', 'GEORGS NO NAME', 1, 32, 9999, 1, 3, 42, 2109, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8675, '1998-04-01 22:00:00+00', '2018-04-03 00:07:49.199015+00', 'Golden Autumn', 'GOLDEN AUTUMN', 1, 32, 9999, 1, 3, 42, 2002, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8643, '1998-02-24 23:00:00+00', '2018-04-03 00:07:52.076002+00', 'High in the Sky', 'HIGH IN THE SKY', 2, 40, 9999, 1, 3, 42, 17, '1979-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8677, '2002-04-19 22:00:00+00', '2018-04-03 00:07:53.510468+00', 'Internet Assembly, The', 'INTERNET ASSEMBLY', 3, 32, 9999, 1, 3, 42, 361, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8645, '2002-01-08 23:00:00+00', '2018-04-03 00:07:59.523421+00', 'Like a Fire to Heather Set', 'LIKE A FIRE TO HEATHER SET', 1, 32, 9999, 1, 3, 42, 17, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8646, '2002-01-08 23:00:00+00', '2018-04-03 00:08:21.639606+00', 'Tour in Turin', 'TOUR IN TURIN', 1, 40, 9999, 1, 3, 42, 17, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13165, '2006-12-11 23:00:00+00', '2018-10-03 01:28:19.476083+00', 'Clara''s Reel', 'CLARAS REEL', 1, 32, 9999, 1, 3, 42, 2766, '2006-03-01', 'This dance is written for Clara Geiger, a lovely woman treated me like a daughter.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13166, '2006-12-11 23:00:00+00', '2018-10-03 09:51:30.958578+00', 'Coin Collector, The', 'COIN COLLECTOR', 3, 32, 9999, 3, 5, 35, 2766, '2006-04-01', 'This dance honors my father who loves to collect coins.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8680, '1998-03-31 22:00:00+00', '2012-01-20 12:57:07.884667+00', 'Jig for Will, A', 'JIG FOR WILL', 2, 32, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8681, '1998-03-31 22:00:00+00', '2012-01-20 12:57:07.891948+00', 'Katja and Hans-Peter''s Farewell to Hoevels', 'KATJA AND HANSPETERS FAREWELL TO HOEVELS', 3, 32, 9999, 1, 2, NULL, 2111, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13164, '2006-12-11 23:00:00+00', '2019-11-27 11:33:45.414965+00', 'Snake Bit', 'SNAKE BIT', 2, 32, 9999, 1, 3, 42, 2766, '2006-03-01', '', 63, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8644, '2006-03-23 23:00:00+00', '2020-02-11 21:48:10.880975+00', 'Fire and Ice', 'FIRE AND ICE', 2, 32, 9999, 1, 2, 76, 3667, NULL, '', 60, '48/48/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13137, '2006-12-05 23:00:00+00', '2020-09-16 22:18:36.179234+00', 'Tammie Norie Jig', 'TAMMIE NORIE JIG', 2, 32, 9999, 1, 4, 1, 104, NULL, '', 56, '8080/4444/4444/8484', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13158, '2006-12-11 23:00:00+00', '2021-01-17 17:16:29.193152+00', 'Black Powder Rifle', 'BLACK POWDER RIFLE', 1, 32, 9999, 3, 5, 41, 2766, '2006-02-01', 'This dance is written for my sister Becky, who likes to go to rendezvous and owns and can shoot a black powder rifle.', 63, '80008/80008/88888/84646', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8653, '1998-03-20 23:00:00+00', '2021-03-15 22:56:19.774609+00', 'Clumsy Lover, The', 'CLUMSY LOVER', 1, 32, 9999, 1, 3, 42, 1849, '1997-01-01', '', 56, '866/888/822/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8707, '1998-03-31 22:00:00+00', '2021-06-06 13:22:50.94398+00', 'Shower Reel, The', 'SHOWER REEL', 1, 32, 9999, 1, 3, 42, 2119, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8656, '1998-03-31 22:00:00+00', '2021-06-13 09:38:45.65752+00', 'Another Good Turn', 'ANOTHER GOOD TURN', 2, 32, 9999, 1, 3, 42, 2099, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13167, '2006-12-11 23:00:00+00', '2018-10-04 05:36:01.284919+00', 'Dan''s Reel', 'DANS REEL', 1, 32, 9999, 1, 3, 42, 2766, '2006-04-01', 'This reel is for Dan, my life partner.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8687, '1998-03-31 22:00:00+00', '2012-01-20 12:57:07.93375+00', 'Loch Ness Monsters'' Delight, The', 'LOCH NESS MONSTERS DELIGHT', 2, 32, 9999, 7, 98, NULL, 2111, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13171, '2006-12-11 23:00:00+00', '2018-10-06 10:38:01.416106+00', 'Mirror, Mirror', 'MIRROR MIRROR', 1, 32, 9999, 3, 5, 16, 2766, '2006-05-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13186, '2006-12-11 23:00:00+00', '2018-10-06 13:45:43.657248+00', 'Paul Likes Tournées', 'PAUL LIKES TOURNEES', 3, 32, 9999, 1, 3, 42, 2766, '2006-11-01', 'This dance was written for Paul Gunderson, whose favorite figure is the tournée.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8694, '2002-04-19 22:00:00+00', '2012-01-20 12:57:07.983753+00', 'Only With You', 'ONLY WITH YOU', 3, 40, 9999, 1, 2, NULL, 2116, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13176, '2006-12-11 23:00:00+00', '2018-10-09 06:50:48.475365+00', 'Teaching Dance #3', 'TEACHING DANCE 3', 1, 32, 9999, 1, 4, 1, 2766, '2006-06-01', 'This dance is one of four that were written for a teaching session at the Chicago Highland Games. Since the people who participate in this are usually totally unfamiliar with Scottish Country Dancing, I needed simple dances with easy figures and an easy progression.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13178, '2006-12-11 23:00:00+00', '2018-10-09 12:35:53.911795+00', 'Trip to Ohio', 'TRIP TO OHIO', 1, 32, 9999, 1, 3, 42, 2766, '2006-07-01', 'I wrote this dance on a trip to visit my family, who all live in Ohio.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8698, '1998-03-31 22:00:00+00', '2012-01-20 12:57:08.011183+00', 'Pianist''s Windmill, The', 'PIANISTS WINDMILL', 2, 32, 9999, 5, 4, NULL, 10478, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8701, '2001-06-10 22:00:00+00', '2012-01-20 12:57:08.031844+00', 'Reel for Rechberg, A', 'REEL FOR RECHBERG', 1, 32, 9999, 5, 2, NULL, 181, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13168, '2006-12-11 23:00:00+00', '2018-10-09 14:26:49.044793+00', 'Wandering Gypsy', 'WANDERING GYPSY', 3, 32, 9999, 1, 3, 42, 2766, '2006-04-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8648, '1998-03-16 23:00:00+00', '2022-01-11 11:36:39.435683+00', 'Stafford Knot, The', 'STAFFORD KNOT', 3, 32, 9999, 1, 3, 42, 2091, '1994-01-01', '', 50, '880/880/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8650, '1998-03-16 23:00:00+00', '2022-01-11 11:39:48.628593+00', 'Wigglety-Wagglety', 'WIGGLETYWAGGLETY', 1, 32, 9999, 1, 4, 1, 2091, '1994-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13182, '2006-12-11 23:00:00+00', '2022-04-26 20:41:34.18472+00', 'Silk and Satin', 'SILK AND SATIN', 3, 32, 9999, 1, 3, 42, 2766, '2006-09-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13187, '2006-12-11 23:00:00+00', '2022-08-17 18:42:20.296072+00', 'Biloxi', 'BILOXI', 3, 32, 9999, 1, 3, 42, 2766, '2006-11-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8647, '1998-11-01 23:00:00+00', '2022-10-04 18:56:00.559004+00', 'Sleepless Nights', 'SLEEPLESS NIGHTS', 2, 32, 9999, 1, 3, 42, 17, '1998-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13146, '2006-12-06 23:00:00+00', '2022-11-13 17:10:30.320789+00', 'Around and About', 'AROUND AND ABOUT', 3, 32, 9999, 1, 3, 42, 3643, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13148, '2006-12-06 23:00:00+00', '2022-11-13 17:35:26.346077+00', 'Farewell to the Prairies', 'FAREWELL TO THE PRAIRIES', 1, 32, 9999, 1, 3, 42, 3746, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13147, '2006-12-06 23:00:00+00', '2022-11-13 17:37:59.746783+00', 'Saskatoon''s Jubilee', 'SASKATOONS JUBILEE', 4, 80, 9999, 4, 4, NULL, 3746, '2004-01-01', 'The instructions have in bars 37-40 "Eight hands round to the left and back to original places". Possibly the intention is ""Eight hands round to the left, back to original places" (3/4 round to left only)?', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8718, '2002-04-23 22:00:00+00', '2019-06-07 12:10:56.883141+00', 'Trip to Gomadingen', 'TRIP TO GOMADINGEN', 3, 32, 9999, 2, 3, NULL, 558, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8711, '2001-06-12 22:00:00+00', '2012-01-20 12:57:08.102469+00', 'Strathallan Jig, The', 'STRATHALLAN JIG', 2, 32, 9999, 1, 4, NULL, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8712, '1998-11-01 23:00:00+00', '2012-01-20 12:57:08.109339+00', 'Strathspey Reel, The', 'STRATHSPEY REEL', 2, 64, 9999, 1, 4, NULL, 2122, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8713, '2002-04-19 22:00:00+00', '2012-01-20 12:57:08.118439+00', 'Summer Strathspey', 'SUMMER STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 2002, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8704, '1999-10-18 22:00:00+00', '2013-05-30 22:38:09.659878+00', 'Scottish Witch', 'SCOTTISH WITCH', 2, 32, 9999, 1, 4, NULL, 1394, '1997-10-28', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8679, '2002-05-06 22:00:00+00', '2018-04-03 00:07:55.03644+00', 'Jean Armour''s Reel', 'JEAN ARMOURS REEL', 1, 32, 9999, 1, 3, 42, 200, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8685, '1998-03-31 22:00:00+00', '2018-04-03 00:07:59.573455+00', 'Limerick Writer, The', 'LIMERICK WRITER', 2, 32, 9999, 1, 3, 42, 1988, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8686, '1998-03-31 22:00:00+00', '2018-04-03 00:08:00.157173+00', 'Loch Lomond', 'LOCH LOMOND', 3, 32, 9999, 1, 3, 42, 2114, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8690, '1998-03-31 22:00:00+00', '2018-04-03 00:08:02.275488+00', 'Marlis'' Wedding', 'MARLIS WEDDING', 1, 40, 9999, 1, 3, 42, 2120, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8691, '2002-05-06 22:00:00+00', '2018-04-03 00:08:02.642421+00', 'Master of Devorgilla, The', 'MASTER OF DEVORGILLA', 1, 32, 9999, 1, 3, 42, 200, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8695, '1998-03-31 22:00:00+00', '2018-04-03 00:08:09.271756+00', 'Orcas Rambles', 'ORCAS RAMBLES', 1, 40, 9999, 1, 3, 42, 775, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8696, '1998-03-31 22:00:00+00', '2018-04-03 00:08:09.455632+00', 'Out of the Borders', 'OUT OF THE BORDERS', 3, 32, 9999, 1, 3, 42, 2102, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8716, '2002-04-19 22:00:00+00', '2018-04-03 00:08:21.514515+00', 'Tom''s Tears', 'TOMS TEARS', 3, 32, 9999, 1, 3, 42, 588, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8717, '1998-04-24 22:00:00+00', '2018-04-03 00:08:21.664718+00', 'Traveling Salesman, The', 'TRAVELING SALESMAN', 3, 32, 9999, 1, 3, 42, 895, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8721, '1998-04-01 22:00:00+00', '2018-04-03 00:08:26.268081+00', 'Winterize', 'WINTERIZE', 1, 32, 9999, 1, 3, 42, 2002, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8733, '1998-08-02 22:00:00+00', '2012-01-20 12:57:08.268156+00', 'Robert Society of Annapolis March, The', 'ROBERT SOCIETY OF ANNAPOLIS MARCH', 2, 32, 9999, 1, 4, NULL, 2235, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8760, '1998-10-19 22:00:00+00', '2018-07-22 16:48:19.845541+00', 'Jumping Geordie', 'JUMPING GEORDIE', 1, 32, 9999, 1, 3, 42, 173, '1985-02-24', '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13190, '2006-12-11 23:00:00+00', '2018-10-03 10:00:56.991555+00', 'Cotton Candy', 'COTTON CANDY', 1, 32, 9999, 4, 5, 21, 2766, '2005-12-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18697, '2018-10-02 20:59:57.369853+00', '2018-10-03 10:27:07.982148+00', 'Wee Anna''s Reel', 'WEE ANNAS REEL', 1, 32, NULL, 1, 3, 42, 10959, '2018-07-01', 'Remembering Anna Rielly: Scottish Country Dancer: Runner: Boot Camp addict, Hospital volunteer & friend to us all.', 43, '800/833/855/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13198, '2006-12-11 23:00:00+00', '2018-10-05 13:39:25.476605+00', 'Highland Gypsy', 'HIGHLAND GYPSY', 1, 32, 9999, 1, 3, 42, 2766, '2005-10-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8761, '1998-10-19 22:00:00+00', '2018-04-03 00:07:29.681872+00', 'Adie Morrison', 'ADIE MORRISON', 2, 32, 9999, 1, 3, 42, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13196, '2006-12-11 23:00:00+00', '2018-10-06 05:09:53.80865+00', 'Leading Lady', 'LEADING LADY', 2, 32, 9999, 1, 3, 42, 2766, '2005-11-01', 'This dance was written for Mady Newfield on her very special birthday this year. She is the leading lady of our Scottish dance class.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13188, '2006-12-11 23:00:00+00', '2018-10-06 10:48:05.969118+00', 'Monty''s Lady', 'MONTYS LADY', 1, 32, 9999, 1, 3, 42, 2766, '2006-12-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8731, '1998-07-22 22:00:00+00', '2020-01-11 01:58:28.410849+00', 'Mull Rant, The', 'MULL RANT', 3, 0, 9999, NULL, 98, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8688, '1998-03-31 22:00:00+00', '2020-09-07 08:58:22.353975+00', 'Manchester Medley, A', 'MANCHESTER MEDLEY', 4, 128, 2, 4, 4, 4, 9998, NULL, '', 75, '8888/4444/4444/4444/6666/8888/6666/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13209, '2006-12-12 23:00:00+00', '2021-01-04 16:07:07.70799+00', 'Five Years On', 'FIVE YEARS ON', 3, 32, 9999, 3, 5, 16, 1582, '2006-01-01', '', 75, '80008/88888/88888/44448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8700, '1998-04-01 22:00:00+00', '2021-03-14 23:40:22.074608+00', 'Puddocks, The', 'PUDDOCKS', 1, 112, 9999, 4, 4, 3, 416, '1988-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8697, '1998-04-24 22:00:00+00', '2021-06-13 09:37:05.101055+00', 'Patallan', 'PATALLAN', 2, 40, 9999, 1, 3, 42, 479, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8682, '1998-03-31 22:00:00+00', '2021-06-13 09:37:57.159248+00', 'Katja''s Wedding', 'KATJAS WEDDING', 1, 32, 9999, 1, 3, 42, 2112, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13192, '2006-12-11 23:00:00+00', '2018-10-30 12:13:26.592822+00', 'No Ghosts a Roamin''', 'NO GHOSTS A ROAMIN', 2, 32, 9999, 1, 4, NULL, 2766, '2005-11-01', '', 59, '8008/8338/8338/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13194, '2006-12-11 23:00:00+00', '2018-10-07 10:07:50.49686+00', 'Quirin''s Reel', 'QUIRINS REEL', 1, 32, 9999, 1, 3, 42, 2766, '2005-11-01', 'This dance celebrates Mary Helen Polensky’s favorite grandchild, born this year on June 1st.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8767, '1998-10-19 22:00:00+00', '2018-04-03 00:07:34.750276+00', 'Bonnie Kirriemuir', 'BONNIE KIRRIEMUIR', 3, 32, 9999, 1, 3, 42, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8742, '1998-11-22 23:00:00+00', '2012-01-20 12:57:08.340549+00', 'Australian Walkabout', 'AUSTRALIAN WALKABOUT', 3, 32, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13208, '2006-12-12 23:00:00+00', '2018-04-03 00:07:49.55759+00', 'Grandpa''s Wife', 'GRANDPAS WIFE', 3, 32, 9999, 1, 3, 42, 204, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13191, '2006-12-11 23:00:00+00', '2018-10-07 11:59:04.880509+00', 'Round and Round', 'ROUND AND ROUND', 1, 32, 9999, 1, 3, 42, 2766, '2005-12-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8763, '1998-10-19 22:00:00+00', '2018-04-03 00:07:55.720223+00', 'Jimmy Shearer', 'JIMMY SHEARER', 2, 32, 9999, 1, 3, 42, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8751, '1998-10-15 22:00:00+00', '2012-01-20 12:57:08.406671+00', 'Flora MacDonald', 'FLORA MACDONALD', 7, 0, 9999, 99, 51, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8752, '1998-10-15 22:00:00+00', '2012-01-20 12:57:08.413441+00', 'Highland Laddie', 'HIGHLAND LADDIE', 7, 32, 9999, 99, 51, NULL, 9998, NULL, '<<scddb:not-identical:14305>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8753, '1998-10-15 22:00:00+00', '2012-01-20 12:57:08.42023+00', 'Blue Bonnets', 'BLUE BONNETS', 7, 0, 9999, 99, 99, NULL, 9998, NULL, '<<scddb:not-identical:588>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8754, '1998-10-19 22:00:00+00', '2012-01-20 12:57:08.427106+00', 'Petriona', 'PETRIONA', 1, 32, 9999, 1, 4, NULL, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13195, '2006-12-11 23:00:00+00', '2018-10-07 12:01:16.456281+00', 'Rovin'' Willie', 'ROVIN WILLIE', 2, 32, 9999, 1, 3, 42, 2766, '2005-11-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8756, '1998-10-19 22:00:00+00', '2012-01-20 12:57:08.441108+00', 'Findochty Reel, The', 'FINDOCHTY REEL', 3, 32, 9999, 1, 4, NULL, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8757, '1998-10-19 22:00:00+00', '2012-01-20 12:57:08.448072+00', 'Donald''s Awa Tae the War', 'DONALDS AWA TAE THE WAR', 2, 32, 9999, 1, 4, NULL, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8758, '1998-10-19 22:00:00+00', '2012-01-20 12:57:08.455051+00', 'Jean MacKinnon''s Strathspey', 'JEAN MACKINNONS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8759, '1998-10-19 22:00:00+00', '2012-01-20 12:57:08.461913+00', 'Wee Bella Brough', 'WEE BELLA BROUGH', 3, 32, 9999, 1, 4, NULL, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13201, '2006-12-11 23:00:00+00', '2018-10-07 12:18:10.771557+00', 'Sand Sculptures', 'SAND SCULPTURES', 3, 32, 9999, 1, 3, 42, 2766, '2006-09-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13214, '2007-01-04 23:00:00+00', '2019-06-05 22:25:17.827691+00', 'Ms Katy B.', 'MS KATY B', 1, 32, 9999, 1, 4, 1, 3753, NULL, '', 81, '8888/8888/8440/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13202, '2006-12-11 23:00:00+00', '2018-10-07 12:41:07.63817+00', 'Shadows on the Moon', 'SHADOWS ON THE MOON', 3, 32, 9999, 1, 3, 42, 2766, '2005-09-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8787, '1998-10-20 22:00:00+00', '2018-04-03 00:07:52.334533+00', 'Himalayas, The', 'HIMALAYAS', 1, 32, 9999, 1, 3, 42, 595, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8689, '2002-05-06 22:00:00+00', '2022-12-02 11:48:37.774207+00', 'Margaret Holmes'' Strathspey', 'MARGARET HOLMES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 200, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18679, '2018-10-01 14:54:39.313597+00', '2019-05-14 04:31:23.626907+00', 'Arboreal Lace', 'ARBOREAL LACE', 2, 32, NULL, 1, 3, 42, 2766, '2015-02-01', 'This dance was inspired by heavy wet snow that fell and coated the trees in white making them look like lace drawings.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13207, '2006-12-12 23:00:00+00', '2012-01-20 12:57:44.915319+00', 'Jim Johnstone''s Strathspey', 'JIM JOHNSTONES STRATHSPEY', 3, 32, 9999, 1, 4, 1, 146, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8766, '1998-10-19 22:00:00+00', '2012-01-20 12:57:08.51114+00', 'Willbert, The', 'WILLBERT', 3, 32, 9999, 1, 4, NULL, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8738, '1998-12-19 23:00:00+00', '2016-05-10 22:29:29.238611+00', 'Highland Fling', 'HIGHLAND FLING', 7, 8, 9999, 107, 51, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8748, '1998-10-15 22:00:00+00', '2016-05-10 22:29:57.289667+00', 'Irish Jig', 'IRISH JIG', 7, 32, 9999, 107, 51, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8744, '1998-10-15 22:00:00+00', '2016-05-10 22:39:59.457986+00', 'Sword Dance', 'SWORD DANCE', 7, 32, 9999, 107, 51, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8762, '1998-10-19 22:00:00+00', '2018-04-03 00:08:24.883341+00', 'Wesley''s Jig', 'WESLEYS JIG', 2, 32, 9999, 1, 3, 42, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8723, '1998-05-06 22:00:00+00', '2018-04-03 00:08:01.182967+00', 'MacLaren''s Return to Balquhidder', 'MACLARENS RETURN TO BALQUHIDDER', 2, 32, 9999, 1, 3, 42, 586, NULL, 'See <<ddd:Balquidder Strathspey>> for information about Balquhidder.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8755, '1998-10-19 22:00:00+00', '2018-04-03 00:08:04.685426+00', 'Miss Margaret Wright', 'MISS MARGARET WRIGHT', 3, 32, 9999, 1, 3, 42, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13213, '2007-01-02 23:00:00+00', '2018-04-03 00:08:08.104786+00', 'Noss Head Jig, The', 'NOSS HEAD JIG', 2, 32, 9999, 1, 3, 42, 1024, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8764, '1998-10-19 22:00:00+00', '2018-04-03 00:08:08.505278+00', 'Old But and Ben, The', 'OLD BUT AND BEN', 2, 32, 9999, 1, 3, 42, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8746, '1998-10-19 22:00:00+00', '2018-04-03 00:08:25.83427+00', 'Willie Dawson', 'WILLIE DAWSON', 3, 32, 9999, 1, 3, 42, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8765, '1998-10-19 22:00:00+00', '2018-04-03 00:08:25.842683+00', 'Willie Laidlaw', 'WILLIE LAIDLAW', 3, 32, 9999, 1, 3, 42, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8769, '1998-10-19 22:00:00+00', '2012-01-20 12:57:08.531847+00', 'Linden Anniversary Strathspey', 'LINDEN ANNIVERSARY STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 349, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8771, '1998-10-19 22:00:00+00', '2012-01-20 12:57:08.545658+00', 'Frae Caledonia''s Shores', 'FRAE CALEDONIAS SHORES', 2, 40, 9999, 1, 4, NULL, 349, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8773, '1998-10-20 22:00:00+00', '2012-01-20 12:57:08.559467+00', 'City of Angels', 'CITY OF ANGELS', 3, 48, 9999, 1, 4, NULL, 50, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8774, '1998-10-20 22:00:00+00', '2012-01-20 12:57:08.566326+00', 'Angel''s Flight', 'ANGELS FLIGHT', 2, 48, 9999, 3, 5, NULL, 50, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13221, '2007-01-06 23:00:00+00', '2018-04-03 00:07:30.994825+00', 'Aquarius', 'AQUARIUS', 1, 32, 9999, 1, 3, 42, 416, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8776, '1998-10-20 22:00:00+00', '2012-01-20 12:57:08.580229+00', 'Chrissiejean', 'CHRISSIEJEAN', 2, 40, 9999, 1, 4, NULL, 50, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8801, '1998-10-22 22:00:00+00', '2018-04-03 00:07:33.457647+00', 'Birthday Jig', 'BIRTHDAY JIG', 2, 32, 9999, 1, 3, 42, 1193, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8790, '1998-10-20 22:00:00+00', '2018-04-03 00:07:37.086862+00', 'Carnoustie', 'CARNOUSTIE', 3, 32, 9999, 1, 3, 42, 595, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8779, '1998-10-20 22:00:00+00', '2012-01-20 12:57:08.601629+00', 'Over the Garden Wall', 'OVER THE GARDEN WALL', 1, 48, 9999, 1, 4, NULL, 50, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8780, '2001-01-18 23:00:00+00', '2012-01-20 12:57:08.608682+00', 'Jacqueline''s Jig', 'JACQUELINES JIG', 2, 32, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13215, '2007-01-02 23:00:00+00', '2020-09-16 22:38:54.248392+00', 'Voyageurs, Les', 'VOYAGEURS', 3, 32, 9999, 1, 4, 1, 80, '2006-01-01', '', 67, '8008/8448/8222/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13310, '2007-07-26 22:00:00+00', '2021-01-03 12:47:23.834804+00', 'Kay''s Jig', 'KAYS JIG', 2, 32, 9999, 1, 4, 1, 3775, '2005-12-01', '', 69, '6666/6666/4444/8088', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5437, '2002-04-08 22:00:00+00', '2020-10-10 00:59:13.195784+00', 'Quern, The', 'QUERN', 3, 32, 9999, 2, 3, 17, 101, '1993-01-01', 'Dedicated to Wallace Lockhart and his wife, founder members of the Linlithgow Scottish Country Dance Club on its 10th Anniversary in 1990



', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8747, '1998-10-15 22:00:00+00', '2021-02-19 19:05:25.878808+00', 'Sailor''s Hornpipe', 'SAILORS HORNPIPE', 7, 32, 9999, 107, 51, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8739, '2001-11-20 23:00:00+00', '2021-03-14 22:54:19.028504+00', 'Gairloch Hornpipe, The', 'GAIRLOCH HORNPIPE', 1, 48, 9999, 3, 5, 19, 550, '1995-01-01', '', 70, '88888/80008/88888/80008/86468/82428', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8737, '2002-02-12 23:00:00+00', '2021-03-14 22:58:49.343548+00', 'Saint Margaret''s Inch', 'SAINT MARGARETS INCH', 3, 32, 9999, 3, 5, 7, 21, '1998-01-01', 'In Highlander Collection, vol 1, the name of the dance is spelt with "St."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8781, '1998-10-20 22:00:00+00', '2012-01-20 12:57:08.615513+00', 'Circassian Quadrille', 'CIRCASSIAN QUADRILLE', 1, 192, 9999, 4, 4, NULL, 50, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8784, '1998-10-20 22:00:00+00', '2012-01-20 12:57:08.636594+00', 'Swilken Burn', 'SWILKEN BURN', 4, 64, 5, 1, 4, NULL, 595, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8786, '1998-10-20 22:00:00+00', '2012-01-20 12:57:08.651426+00', 'Turnberry Variations', 'TURNBERRY VARIATIONS', 3, 48, 9999, 1, 4, NULL, 595, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8788, '1998-10-20 22:00:00+00', '2012-01-20 12:57:08.665344+00', 'Postage Stamp, The', 'POSTAGE STAMP', 2, 48, 9999, 1, 4, NULL, 595, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13220, '2007-01-06 23:00:00+00', '2012-01-20 12:57:45.011795+00', 'Morningside Welcome', 'MORNINGSIDE WELCOME', 3, 40, 9999, 1, 4, 1, 3755, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8735, '1998-09-01 22:00:00+00', '2014-11-10 23:19:26.824307+00', 'Castor''s Jig', 'CASTORS JIG', 2, 32, 9999, 1, 2, NULL, 2240, '1998-01-01', '', 52, '80/84/84/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13222, '2007-01-07 23:00:00+00', '2012-01-20 12:57:45.025587+00', 'Black Watch, The', 'BLACK WATCH', 2, 40, 9999, 1, 2, NULL, 9998, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13224, '2007-01-11 23:00:00+00', '2012-01-20 12:57:45.040781+00', 'Tying the Knot', 'TYING THE KNOT', 2, 32, 9999, 1, 4, 1, 3756, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13217, '2007-01-02 23:00:00+00', '2018-04-03 00:07:37.562479+00', 'Cecilia''s Celtic Roots', 'CECILIAS CELTIC ROOTS', 3, 32, 9999, 1, 3, 42, 2525, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8785, '1998-10-20 22:00:00+00', '2018-04-03 00:07:42.767736+00', 'Double Loops of Muirfield, The', 'DOUBLE LOOPS OF MUIRFIELD', 1, 32, 9999, 1, 3, 42, 595, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8815, '1998-11-02 23:00:00+00', '2018-04-03 00:07:43.752068+00', 'Early Morning Light', 'EARLY MORNING LIGHT', 3, 32, 9999, 1, 3, 42, 324, '1989-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8793, '1998-10-22 22:00:00+00', '2012-01-20 12:57:08.701289+00', 'Nora Kindness, Her Highness', 'NORA KINDNESS HER HIGHNESS', 3, 32, 9999, 1, 4, NULL, 2367, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8795, '1998-10-22 22:00:00+00', '2012-01-20 12:57:08.715176+00', 'Lanchester Jig', 'LANCHESTER JIG', 2, 32, 9999, 1, 4, NULL, 1193, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8797, '1998-10-22 22:00:00+00', '2012-01-20 12:57:08.729003+00', 'Burnhope Mast', 'BURNHOPE MAST', 3, 32, 9999, 3, 5, NULL, 1193, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8800, '1998-10-22 22:00:00+00', '2012-01-20 12:57:08.749649+00', 'Ladies of Lanchester', 'LADIES OF LANCHESTER', 3, 32, 9999, 2, 3, NULL, 1193, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8803, '1998-10-22 22:00:00+00', '2012-01-20 12:57:08.771249+00', 'Lanchester Strathspey, The', 'LANCHESTER STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 1193, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8805, '1998-10-22 22:00:00+00', '2012-01-20 12:57:08.785117+00', 'Lanchester Reel', 'LANCHESTER REEL', 1, 32, 9999, 3, 5, NULL, 1193, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8806, '1998-10-22 22:00:00+00', '2012-01-20 12:57:08.792331+00', 'Cadger Bank', 'CADGER BANK', 3, 32, 9999, 1, 4, NULL, 1193, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8807, '1998-10-22 22:00:00+00', '2012-01-20 12:57:08.799561+00', 'Bramble Jig, The', 'BRAMBLE JIG', 2, 32, 9999, 1, 4, NULL, 1764, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8808, '1998-10-22 22:00:00+00', '2012-01-20 12:57:08.806514+00', 'Stromness Strathspey, The', 'STROMNESS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 2369, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8813, '2001-11-20 23:00:00+00', '2012-01-20 12:57:08.846851+00', 'Xakanaxa', 'XAKANAXA', 3, 40, 9999, 1, 4, 2, 550, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13218, '2007-04-10 22:00:00+00', '2017-11-12 00:25:56.128788+00', 'Timbit for George, A', 'TIMBIT FOR GEORGE', 3, 32, 9999, 1, 4, 11, 2983, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8783, '2002-11-26 23:00:00+00', '2018-04-03 00:07:48.198517+00', 'Gift for Mamie, A', 'GIFT FOR MAMIE', 2, 32, 9999, 1, 3, 42, 598, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8791, '1998-10-20 22:00:00+00', '2018-04-03 00:07:49.590931+00', 'Granny Clark''s Wynd', 'GRANNY CLARKS WYND', 2, 32, 9999, 1, 3, 42, 595, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8804, '1998-10-22 22:00:00+00', '2018-04-03 00:08:01.541464+00', 'Maiden Law', 'MAIDEN LAW', 2, 32, 9999, 1, 3, 42, 1193, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8810, '1998-10-24 22:00:00+00', '2018-04-03 00:08:06.403142+00', 'Mrs Joyce MacArthur', 'MRS JOYCE MACARTHUR', 3, 32, 9999, 1, 3, 42, 463, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8796, '1998-10-22 22:00:00+00', '2018-04-03 00:08:12.149618+00', 'Ray''s Reel', 'RAYS REEL', 1, 32, 9999, 1, 3, 42, 1193, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8789, '1998-10-20 22:00:00+00', '2018-04-03 00:08:13.900793+00', 'Royal Dornoch', 'ROYAL DORNOCH', 4, 32, 1, 1, 3, 42, 595, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8802, '1998-10-22 22:00:00+00', '2018-04-03 00:08:18.345589+00', 'Star Reel', 'STAR REEL', 1, 32, 9999, 1, 3, 42, 1193, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8798, '1998-10-22 22:00:00+00', '2018-04-03 00:08:22.523445+00', 'Trip to Lanchester', 'TRIP TO LANCHESTER', 2, 32, 9999, 1, 3, 42, 1193, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8768, '1998-10-19 22:00:00+00', '2018-04-03 00:08:24.666628+00', 'Welcome Hame', 'WELCOME HAME', 3, 32, 9999, 1, 3, 42, 173, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8772, '1998-10-19 22:00:00+00', '2018-04-03 00:08:27.076727+00', 'Yon Wild Mossy Mountains', 'YON WILD MOSSY MOUNTAINS', 1, 32, 9999, 1, 3, 42, 349, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8831, '2001-07-30 22:00:00+00', '2018-07-24 17:18:09.167905+00', 'Road to Proitze, The', 'ROAD TO PROITZE', 1, 32, 9999, 1, 4, 1, 228, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8819, '1998-11-02 23:00:00+00', '2012-01-20 12:57:08.899591+00', 'Peaceful', 'PEACEFUL', 3, 32, 9999, 1, 4, 15, 324, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8820, '1998-11-02 23:00:00+00', '2012-01-20 12:57:08.907212+00', 'Silver Circle', 'SILVER CIRCLE', 3, 32, 9999, 2, 3, 18, 324, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13234, '2007-02-01 23:00:00+00', '2012-01-20 12:57:45.129381+00', 'Teacher''s Choice, The', 'TEACHERS CHOICE', 2, 32, 9999, 1, 4, NULL, 3187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13236, '2007-02-01 23:00:00+00', '2012-01-20 12:57:45.143231+00', 'Flowers for Maureen', 'FLOWERS FOR MAUREEN', 3, 32, 9999, 1, 4, NULL, 3187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13237, '2007-02-01 23:00:00+00', '2012-01-20 12:57:45.150014+00', 'Going Home by Coach', 'GOING HOME BY COACH', 1, 32, 9999, 1, 4, NULL, 3187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13231, '2007-01-25 23:00:00+00', '2018-07-28 23:24:07.087081+00', 'Graduation Strathspey, The', 'GRADUATION STRATHSPEY', 3, 32, 9999, 1, 4, 1, 3758, '2006-01-01', '', 56, '4646/8800/0088/6662', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13239, '2007-02-01 23:00:00+00', '2012-01-20 12:57:45.163654+00', 'Let''s Shake Hands to Say Good-Bye', 'LETS SHAKE HANDS TO SAY GOODBYE', 1, 32, 9999, 1, 4, NULL, 3187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13240, '2007-02-01 23:00:00+00', '2012-01-20 12:57:45.171886+00', 'Sailing Across the Sea to St Andrews', 'SAILING ACROSS THE SEA TO ST ANDREWS', 1, 32, 9999, 1, 4, NULL, 3187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13241, '2007-02-01 23:00:00+00', '2012-01-20 12:57:45.178744+00', 'Spirit of St Andrews, The', 'SPIRIT OF ST ANDREWS', 2, 32, 9999, 1, 4, NULL, 3187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13242, '2007-02-01 23:00:00+00', '2012-01-20 12:57:45.185642+00', 'Summer Night Ball at St Andrews', 'SUMMER NIGHT BALL AT ST ANDREWS', 3, 32, 9999, 1, 4, NULL, 3187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8821, '1998-11-02 23:00:00+00', '2012-01-20 12:57:08.914343+00', 'Scotch Blend', 'SCOTCH BLEND', 1, 32, 9999, 5, 2, NULL, 324, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8822, '1998-11-02 23:00:00+00', '2012-01-20 12:57:08.922004+00', 'Thistledown', 'THISTLEDOWN', 3, 32, 9999, 2, 3, 17, 324, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8823, '1998-11-02 23:00:00+00', '2012-01-20 12:57:08.929017+00', 'Dancer''s Carol, A', 'DANCERS CAROL', 99, 0, 9999, 99, 99, NULL, 2410, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8824, '1998-11-02 23:00:00+00', '2012-01-20 12:57:08.935847+00', 'Farewell to Randy, A', 'FAREWELL TO RANDY', 99, 0, 9999, 99, 99, NULL, 2410, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8825, '1998-11-02 23:00:00+00', '2012-01-20 12:57:08.943265+00', 'Honeysuckle Rose', 'HONEYSUCKLE ROSE', 99, 0, 9999, 99, 99, NULL, 2410, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13219, '2007-01-05 23:00:00+00', '2020-06-12 16:03:34.286965+00', 'Scotland''s Thistle', 'SCOTLANDS THISTLE', 3, 32, 9999, 1, 4, 1, 269, '1963-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8817, '2002-04-18 22:00:00+00', '2020-08-09 13:41:17.006436+00', 'Fiddler''s Fancy', 'FIDDLERS FANCY', 1, 48, 9999, 1, 4, NULL, 324, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8816, '2002-04-19 22:00:00+00', '2020-08-09 13:52:21.610406+00', '''Til A'' the Seas Gang Dry', 'TIL A THE SEAS GANG DRY', 3, 32, 9999, 2, 3, 18, 324, '1990-01-01', '', 42, '800/800/886/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8853, '2001-11-16 23:00:00+00', '2021-03-13 10:37:33.710005+00', 'Thorncliffe', 'THORNCLIFFE', 3, 32, 9999, 1, 3, 42, 2409, '2001-01-01', '', 65, '822/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8794, '1998-10-22 22:00:00+00', '2021-06-06 13:21:41.839765+00', 'Lady Kindness'' Reel', 'LADY KINDNESS REEL', 1, 32, 9999, 1, 3, 42, 2368, '1966-01-01', 'Written for Nora Kindness of the Cincinnati Branch.', 56, '880/880/888/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8826, '1998-11-02 23:00:00+00', '2012-01-20 12:57:08.950178+00', 'It Started Simple', 'IT STARTED SIMPLE', 99, 0, 9999, 99, 99, NULL, 2410, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8827, '1998-11-02 23:00:00+00', '2012-01-20 12:57:08.956952+00', 'Red Herring', 'RED HERRING', 99, 0, 9999, 99, 99, NULL, 2410, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8828, '1998-11-02 23:00:00+00', '2012-01-20 12:57:08.963782+00', 'Stool of Repentance', 'STOOL OF REPENTANCE', 99, 0, 9999, 99, 99, NULL, 2410, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13232, '2007-01-25 23:00:00+00', '2018-07-28 23:29:32.840276+00', 'Kennedy Castle', 'KENNEDY CASTLE', 2, 96, 9999, 4, 4, NULL, 3759, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8841, '1998-11-16 23:00:00+00', '2012-01-20 12:57:09.062293+00', 'Isle of Bute', 'ISLE OF BUTE', 3, 32, 9999, 1, 4, 1, 87, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13243, '2007-02-01 23:00:00+00', '2012-01-20 12:57:45.192589+00', 'Through the West Port of St Andrews', 'THROUGH THE WEST PORT OF ST ANDREWS', 1, 32, 9999, 1, 4, NULL, 3187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13244, '2007-02-18 23:00:00+00', '2012-01-20 12:57:45.200083+00', 'Committee, The', 'COMMITTEE', 1, 32, 9999, 1, 4, 2, 3762, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13245, '2007-02-18 23:00:00+00', '2012-01-20 12:57:45.207758+00', 'Floating Swans of Milford, The', 'FLOATING SWANS OF MILFORD', 1, 32, 9999, 1, 4, 1, 3763, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13247, '2007-02-18 23:00:00+00', '2012-01-20 12:57:45.222085+00', 'Malmerrin', 'MALMERRIN', 1, 128, 9999, 4, 4, NULL, 3765, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8843, '1998-12-08 23:00:00+00', '2018-04-03 00:07:32.14749+00', 'Banks o'' Dee', 'BANKS O DEE', 2, 32, 9999, 1, 3, 42, 121, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13251, '2007-02-20 23:00:00+00', '2012-01-20 12:57:45.257493+00', 'Muddled Up Cars', 'MUDDLED UP CARS', 2, 40, 9999, 1, 4, 1, 3767, '2002-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13253, '2007-02-20 23:00:00+00', '2012-01-20 12:57:45.272906+00', 'Campbells of Milford, The', 'CAMPBELLS OF MILFORD', 3, 32, 9999, 1, 4, 13, 3763, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13254, '2007-02-20 23:00:00+00', '2012-01-20 12:57:45.280648+00', 'Dance for Noeline, A', 'DANCE FOR NOELINE', 3, 40, 9999, 1, 4, 4, 3762, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8844, '1998-12-01 23:00:00+00', '2018-04-03 00:07:33.190508+00', 'Betty''s Keys', 'BETTYS KEYS', 2, 32, 9999, 1, 3, 42, 663, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8846, '2002-04-29 22:00:00+00', '2018-04-03 00:07:36.135567+00', 'Burn by the Hillock, The', 'BURN BY THE HILLOCK', 1, 32, 9999, 1, 3, 42, 146, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8860, '1998-12-01 23:00:00+00', '2012-01-20 12:57:09.208418+00', 'Ruidhleadh nan Coileach Dubh', 'RUIDHLEADH NAN COILEACH DUBH', 1, 32, 9999, 99, 99, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13250, '2007-02-20 23:00:00+00', '2012-01-20 12:57:45.24997+00', 'Milford Welcome, A', 'MILFORD WELCOME', 2, 32, 9999, 5, 99, NULL, 3763, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8849, '1998-12-16 23:00:00+00', '2016-11-15 23:43:52.814768+00', 'Todlin'' Athegither', 'TODLIN ATHEGITHER', 1, 32, 9999, 2, 3, 17, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13235, '2007-02-01 23:00:00+00', '2018-04-03 00:07:38.413766+00', 'Christmas Bells of St Andrews', 'CHRISTMAS BELLS OF ST ANDREWS', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8848, '1998-12-01 23:00:00+00', '2018-04-03 00:07:39.539841+00', 'Corn Exchange, The', 'CORN EXCHANGE', 2, 32, 9999, 1, 3, 42, 341, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13238, '2007-02-01 23:00:00+00', '2018-04-03 00:07:52.000962+00', 'He Takes her Home after the Ball', 'HE TAKES HER HOME AFTER THE BALL', 2, 32, 9999, 1, 3, 42, 3187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8818, '1998-11-02 23:00:00+00', '2018-04-03 00:07:53.535726+00', 'In the Company of Friends', 'IN THE COMPANY OF FRIENDS', 3, 32, 9999, 1, 3, 42, 324, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13246, '2007-02-18 23:00:00+00', '2018-04-03 00:07:58.003628+00', 'Ladies of Milford Reel, The', 'LADIES OF MILFORD REEL', 1, 32, 9999, 1, 3, 42, 3764, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13248, '2007-02-18 23:00:00+00', '2018-04-03 00:08:09.055477+00', 'On the Edge of the Sand', 'ON THE EDGE OF THE SAND', 1, 32, 9999, 1, 3, 42, 44, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8854, '1998-12-08 23:00:00+00', '2018-04-03 00:08:09.972846+00', 'Pat o'' Bon Accord', 'PAT O BON ACCORD', 2, 40, 9999, 1, 3, 42, 121, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13255, '2007-02-20 23:00:00+00', '2018-04-03 00:08:10.123012+00', 'Pearls and Lace', 'PEARLS AND LACE', 3, 32, 9999, 1, 3, 42, 3762, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13249, '2007-02-18 23:00:00+00', '2018-04-03 00:08:16.235708+00', 'Shiels of Birkdale, The', 'SHIELS OF BIRKDALE', 1, 32, 9999, 1, 3, 42, 3762, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8834, '2000-06-04 22:00:00+00', '2018-04-03 00:08:18.720936+00', 'Strathnairn', 'STRATHNAIRN', 3, 32, 9999, 1, 3, 42, 2419, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8845, '1998-12-08 23:00:00+00', '2018-04-03 00:08:25.041851+00', 'What Say They?', 'WHAT SAY THEY', 1, 32, 9999, 1, 3, 42, 121, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8862, '1998-12-13 23:00:00+00', '2012-01-20 12:57:09.222242+00', 'Margaret''s Waltz', 'MARGARETS WALTZ', 5, 32, 9999, 5, 2, NULL, 2487, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8867, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.262947+00', 'Gie''s a hand o'' thine', 'GIES A HAND O THINE', 1, 32, 9999, 1, 4, 2, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8868, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.269857+00', 'Lands of Kippo', 'LANDS OF KIPPO', 3, 32, 9999, 5, 3, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8870, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.283652+00', 'Tarry Woo''', 'TARRY WOO', 3, 32, 9999, 6, 3, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8871, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.290512+00', 'Card it Weil', 'CARD IT WEIL', 2, 32, 9999, 6, 3, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8873, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.305052+00', 'Tune the Fiddles', 'TUNE THE FIDDLES', 2, 32, 9999, 2, 3, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8874, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.31262+00', 'Spindles and Whorles', 'SPINDLES AND WHORLES', 3, 32, 9999, 1, 4, 2, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8875, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.320228+00', 'Temper Pin, The', 'TEMPER PIN', 2, 40, 9999, 1, 4, 2, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8876, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.327438+00', 'E''eens ye like', 'EEENS YE LIKE', 3, 64, 9999, 4, 4, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8877, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.334395+00', 'Fidging-Fain', 'FIDGINGFAIN', 4, 128, 2, 4, 4, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13256, '2007-02-20 23:00:00+00', '2012-01-20 12:57:45.295031+00', 'Raurimu Spiral', 'RAURIMU SPIRAL', 3, 32, 9999, 1, 4, 1, 3769, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13258, '2007-02-20 23:00:00+00', '2012-01-20 12:57:45.308845+00', 'Sunrise Strathspey', 'SUNRISE STRATHSPEY', 3, 64, 9999, 4, 4, NULL, 3770, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8897, '1998-12-16 23:00:00+00', '2018-04-03 00:07:32.485876+00', 'Baronet of Nova Scotia', 'BARONET OF NOVA SCOTIA', 1, 32, 9999, 1, 3, 42, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8880, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.355398+00', 'Dance o'' Lav''rocks', 'DANCE O LAVROCKS', 3, 32, 9999, 4, 4, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8881, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.362329+00', 'Broose Reel, The', 'BROOSE REEL', 1, 32, 9999, 4, 4, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8882, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.369925+00', 'Tirl the sneck', 'TIRL THE SNECK', 3, 48, 9999, 4, 5, 16, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13233, '2007-01-26 23:00:00+00', '2021-01-03 14:01:07.402328+00', 'Tribute to Bunty', 'TRIBUTE TO BUNTY', 2, 96, 9999, 4, 4, 3, 851, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8892, '1998-12-16 23:00:00+00', '2021-01-04 15:52:27.028729+00', 'Ancient Gordon, The', 'ANCIENT GORDON', 3, 32, 9999, 1, 3, 42, 2018, '1998-01-01', '', 38, '800/844/844/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13252, '2007-02-20 23:00:00+00', '2021-01-09 22:46:21.237179+00', 'Ripples on the Lagoon', 'RIPPLES ON THE LAGOON', 2, 32, 9999, 2, 3, 17, 3768, '2002-01-01', '', 53, '840/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8866, '1998-12-16 23:00:00+00', '2021-03-13 09:51:16.427033+00', 'Here''s a hand, my trusty fiere', 'HERES A HAND MY TRUSTY FIERE', 3, 32, 9999, 1, 4, 2, 2018, '1998-01-01', '', 69, '8448/8448/8448/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8836, '2000-06-04 22:00:00+00', '2021-03-14 20:10:10.857189+00', 'Silver Knot Reel', 'SILVER KNOT REEL', 1, 40, 9999, 1, 3, 42, 2419, NULL, '1st couple second time through lead down and back casting to 4th position.', 55, '808/888/808/888/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8833, '2000-06-04 22:00:00+00', '2021-03-14 20:14:59.93313+00', 'Highland Ladies', 'HIGHLAND LADIES', 3, 32, 9999, 1, 3, 42, 2419, NULL, '"Dedicated to all my friends who have given me so much pleasure on the floor!"', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8832, '2000-06-04 22:00:00+00', '2021-03-14 20:17:07.240921+00', 'Balnain House', 'BALNAIN HOUSE', 3, 40, 9999, 1, 4, 1, 2419, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8883, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.376804+00', 'Haliburton Tensome', 'HALIBURTON TENSOME', 1, 32, 9999, 4, 5, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8884, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.383806+00', 'Sorbie Tensome Reel', 'SORBIE TENSOME REEL', 1, 40, 9999, 4, 5, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8885, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.390691+00', 'Galloway Tensome', 'GALLOWAY TENSOME', 1, 32, 9999, 4, 5, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8886, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.39823+00', 'Bydand', 'BYDAND', 3, 40, 9999, 2, 3, 17, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8887, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.405833+00', 'By Courage not Craft', 'BY COURAGE NOT CRAFT', 2, 32, 9999, 2, 3, 17, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8888, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.413035+00', 'Border Gordons, The', 'BORDER GORDONS', 3, 24, 9999, 1, 2, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8889, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.419897+00', 'Gordons of Kirkcudbright', 'GORDONS OF KIRKCUDBRIGHT', 2, 24, 9999, 1, 2, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8890, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.426859+00', 'Gordon of Methlic', 'GORDON OF METHLIC', 3, 32, 9999, 5, 2, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8891, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.433793+00', 'Ivy', 'IVY', 2, 32, 9999, 5, 2, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8896, '1998-12-16 23:00:00+00', '2012-01-20 12:57:09.468299+00', 'Lands of Haddo', 'LANDS OF HADDO', 3, 32, 9999, 2, 3, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8901, '1998-12-17 23:00:00+00', '2012-01-20 12:57:09.502839+00', 'Thistle Dubh Medley, The', 'THISTLE DUBH MEDLEY', 4, 64, 9999, 1, 4, NULL, 273, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8902, '1998-12-17 23:00:00+00', '2012-01-20 12:57:09.509746+00', 'Mr Carder''s Caper', 'MR CARDERS CAPER', 1, 32, 9999, 1, 4, NULL, 273, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8904, '1998-12-17 23:00:00+00', '2012-01-20 12:57:09.523324+00', 'Dinna'' Fash Yersel''', 'DINNA FASH YERSEL', 2, 40, 9999, 1, 4, NULL, 273, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8906, '1998-12-17 23:00:00+00', '2012-01-20 12:57:09.537031+00', 'My Braw Lad', 'MY BRAW LAD', 4, 128, 9999, 1, 4, NULL, 965, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13271, '2007-03-15 23:00:00+00', '2012-01-20 12:57:45.408395+00', 'Union Jack, The', 'UNION JACK', 99, 0, 9999, 4, 4, NULL, 3, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13266, '2007-02-27 23:00:00+00', '2013-09-17 11:53:16.974941+00', 'Craggie Hornpipe, The', 'CRAGGIE HORNPIPE', 6, 32, 9999, 1, 4, 1, 2419, NULL, '»This is the third dance in the Shetland trilogy – ›The Leaving‹.«



HORNPIPE

DEVISED:2006-01', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8869, '1998-12-16 23:00:00+00', '2016-07-29 20:29:58.447388+00', 'Keppock of Loch Duich', 'KEPPOCK OF LOCH DUICH', 2, 32, 9999, 5, 3, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8898, '1998-12-17 23:00:00+00', '2018-04-03 00:07:34.925475+00', 'Bonnie Mary', 'BONNIE MARY', 1, 32, 9999, 1, 3, 42, 273, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8907, '1998-12-17 23:00:00+00', '2018-04-03 00:07:39.856868+00', 'Crannog, The', 'CRANNOG', 1, 32, 9999, 1, 3, 42, 965, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8894, '1998-12-16 23:00:00+00', '2018-04-03 00:07:49.415952+00', 'Gordon Highlanders', 'GORDON HIGHLANDERS', 3, 32, 9999, 1, 3, 42, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8893, '1998-12-16 23:00:00+00', '2018-04-03 00:07:53.076818+00', 'Hunting Gordon, The', 'HUNTING GORDON', 1, 32, 9999, 1, 3, 42, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8899, '1998-12-17 23:00:00+00', '2018-04-03 00:07:54.886308+00', 'Jamie''s Seat', 'JAMIES SEAT', 1, 32, 9999, 1, 3, 42, 273, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13262, '2007-02-27 23:00:00+00', '2018-04-03 00:08:06.369835+00', 'Mrs Jay Robertson''s Hornpipe', 'MRS JAY ROBERTSONS HORNPIPE', 6, 32, 9999, 1, 3, 42, 2419, NULL, 'HORNPIPE



»Her love for music, rhythm and dance says it all in this hornpipe.«



DEVISED:2006-04', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8905, '1998-12-17 23:00:00+00', '2018-04-03 00:08:09.687755+00', 'Paddle Steamer, The', 'PADDLE STEAMER', 1, 32, 9999, 1, 3, 42, 273, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8895, '1998-12-16 23:00:00+00', '2018-04-03 00:08:13.917391+00', 'Royal Gordon, The', 'ROYAL GORDON', 1, 32, 9999, 1, 3, 42, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13257, '2007-02-20 23:00:00+00', '2018-04-03 00:08:14.643103+00', 'Saint Pat''s Day', 'SAINT PATS DAY', 3, 32, 9999, 1, 3, 42, 3762, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8903, '1998-12-17 23:00:00+00', '2018-04-03 00:08:17.728526+00', 'Sound of Barra, The', 'SOUND OF BARRA', 3, 32, 9999, 1, 3, 42, 273, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8909, '1998-12-17 23:00:00+00', '2012-01-20 12:57:09.558096+00', 'Gala Day, The', 'GALA DAY', 1, 40, 9999, 1, 4, NULL, 273, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8921, '2001-05-03 22:00:00+00', '2012-01-20 12:57:09.634332+00', 'Dance on the Sands', 'DANCE ON THE SANDS', 3, 40, 9999, 2, 3, NULL, 425, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8961, '1999-03-01 23:00:00+00', '2018-04-03 00:07:35.55139+00', 'Breath of Air', 'BREATH OF AIR', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8928, '2002-04-30 22:00:00+00', '2012-01-20 12:57:09.700015+00', 'Donside Reel, The', 'DONSIDE REEL', 1, 32, 9999, 1, 4, 1, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8935, '1999-02-14 23:00:00+00', '2012-01-20 12:57:09.75357+00', 'Jig for Two Roses, A', 'JIG FOR TWO ROSES', 2, 32, 9999, 99, 99, NULL, 101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8958, '2001-05-03 22:00:00+00', '2018-04-03 00:07:38.480456+00', 'Ciorsdan Mhor', 'CIORSDAN MHOR', 3, 32, 9999, 1, 3, 42, 108, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13279, '2007-05-13 22:00:00+00', '2012-01-20 12:57:45.470816+00', 'Saturn', 'SATURN', 3, 32, 9999, 3, 5, NULL, 17, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8908, '1998-12-17 23:00:00+00', '2018-04-03 00:07:38.663922+00', 'Cleish Hills, The', 'CLEISH HILLS', 1, 32, 9999, 1, 3, 42, 273, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8982, '1999-04-05 22:00:00+00', '2012-01-20 12:57:10.087186+00', 'Brioch, The', 'BRIOCH', 3, 32, 9999, 1, 4, 11, 2588, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8900, '1998-12-17 23:00:00+00', '2020-06-03 22:12:10.030361+00', 'Helen''s Reel', 'HELENS REEL', 1, 40, 9999, 1, 4, NULL, 273, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13260, '2007-02-27 23:00:00+00', '2020-09-16 22:47:15.85658+00', 'Tullich Hornpipe, The', 'TULLICH HORNPIPE', 6, 32, 9999, 1, 4, 1, 2419, NULL, 'HORNPIPE



DEVISED:2005-08', 50, '8000/8800/8080/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13284, '2007-06-20 22:00:00+00', '2020-09-30 11:34:59.477614+00', 'Austin Celebration, An', 'AUSTIN CELEBRATION', 1, 40, 9999, NULL, NULL, NULL, 2924, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13285, '2007-06-20 22:00:00+00', '2020-09-30 11:36:30.463678+00', 'Crofter, The', 'CROFTER', 3, 32, 9999, NULL, NULL, NULL, 2924, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8878, '1998-12-16 23:00:00+00', '2021-01-04 15:56:34.731769+00', 'Keekit Ben', 'KEEKIT BEN', 3, 72, 9999, 4, 4, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8913, '1999-01-05 23:00:00+00', '2021-02-21 23:57:19.199119+00', 'Rhonda''s Baby', 'RHONDAS BABY', 1, 32, 9999, 2, 2, 76, 440, '1992-11-08', 'Devised on November 8, 1992, in honour of Rhonda Duma, a member of the St. Andrew''s group, and her baby.', -1, '80/84/88/84', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8916, '1999-01-05 23:00:00+00', '2021-02-24 00:32:00.667711+00', 'Jess Bryden''s Jig', 'JESS BRYDENS JIG', 2, 32, 9999, 1, 4, 2, 440, '1995-01-01', 'Devised in honour of Jess Bryden, who, on April 25, 1995, retired from teaching the Bloorlea Scottish Country Dance group.', 72, '8228/8888/8008/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8937, '2002-04-30 22:00:00+00', '2021-03-12 20:20:00.38328+00', 'Little Cascade, The', 'LITTLE CASCADE', 1, 32, 9999, 1, 4, 2, 520, NULL, '', 53, '8000/8088/8440/8228', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8946, '2002-04-29 22:00:00+00', '2021-03-08 21:52:12.900526+00', 'Frae Near and Far', 'FRAE NEAR AND FAR', 1, 32, 9999, 1, 3, 42, 692, '1997-01-01', '', 56, '800/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8929, '2002-04-30 22:00:00+00', '2021-03-13 09:25:14.231298+00', 'Dophei Strathspey, The', 'DOPHEI STRATHSPEY', 3, 32, 9999, 2, 3, 17, 520, NULL, '', 60, '800/844/888/802', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8850, '2001-06-05 22:00:00+00', '2021-09-17 23:01:22.814998+00', 'Highland Midge, The', 'HIGHLAND MIDGE', 2, 32, 9999, 1, 100, 11, 101, '1995-01-01', '', 81, '8008/8448/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13267, '2007-02-27 23:00:00+00', '2019-02-24 10:38:38.758287+00', 'Dancers Fae Auchleven, The', 'DANCERS FAE AUCHLEVEN', 4, 128, 13, 4, 4, 3, 2419, NULL, '»This dance was devised for friends who were married on 12th August 2006. Their love for dance in most forms makes them a popular couple wherever they are.«', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8944, '1999-02-21 23:00:00+00', '2012-01-20 12:57:09.816702+00', 'Crosshills Jig', 'CROSSHILLS JIG', 2, 32, 9999, 1, 4, 2, 692, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8934, '1999-02-14 23:00:00+00', '2019-03-06 10:46:06.060815+00', 'Irwin Reel', 'IRWIN REEL', 1, 32, 9999, 2, 3, 17, 9998, NULL, '', 100, '888/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8948, '1999-02-21 23:00:00+00', '2012-01-20 12:57:09.843719+00', 'Kirkbrae Jig', 'KIRKBRAE JIG', 2, 32, 9999, 1, 99, NULL, 692, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8949, '1999-02-21 23:00:00+00', '2012-01-20 12:57:09.850445+00', 'Tigh Mor', 'TIGH MOR', 1, 40, 9999, 3, 5, NULL, 692, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8950, '1999-02-21 23:00:00+00', '2012-01-20 12:57:09.857227+00', 'Langholm Braes', 'LANGHOLM BRAES', 1, 32, 9999, 1, 99, NULL, 692, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8952, '1999-02-21 23:00:00+00', '2012-01-20 12:57:09.871037+00', 'O''er the Esk', 'OER THE ESK', 2, 32, 9999, 1, 99, NULL, 692, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9063, '1999-07-24 22:00:00+00', '2012-01-20 12:57:10.726971+00', 'McCabe Medley', 'MACCABE MEDLEY', 4, 64, 5, 99, 99, NULL, 2627, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13280, '2007-05-13 22:00:00+00', '2018-04-03 00:08:23.640066+00', 'Venus', 'VENUS', 1, 32, 9999, 1, 3, 42, 17, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8957, '2001-05-03 22:00:00+00', '2012-01-20 12:57:09.906425+00', 'Ackerleys of Ravenhill, The', 'ACKERLEYS OF RAVENHILL', 1, 64, 9999, 4, 4, NULL, 2574, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8959, '2000-11-14 23:00:00+00', '2012-01-20 12:57:09.921113+00', 'Downderry Jig', 'DOWNDERRY JIG', 2, 32, 9999, 3, 5, 7, 2575, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8962, '2001-05-03 22:00:00+00', '2012-01-20 12:57:09.942957+00', 'Flirtation, La', 'FLIRTATION', 3, 32, 9999, 1, 4, 1, 2817, '1978-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8942, '1999-02-21 23:00:00+00', '2016-05-25 14:38:45.042346+00', 'Across the Border', 'ACROSS THE BORDER', 1, 48, 9999, 1, 4, 1, 692, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8945, '1999-02-21 23:00:00+00', '2016-05-25 14:39:59.02307+00', 'Donald''s Fancy', 'DONALDS FANCY', 1, 88, 9999, 4, 4, 3, 692, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8943, '1999-02-21 23:00:00+00', '2016-05-25 14:40:58.404359+00', 'Ardchoille Park', 'ARDCHOILLE PARK', 3, 32, 9999, 1, 4, 1, 692, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8939, '1999-02-14 23:00:00+00', '2017-02-23 13:35:32.914881+00', 'Saint Giles', 'SAINT GILES', 2, 40, 9999, 4, 4, 4, 2564, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8947, '2002-03-11 23:00:00+00', '2017-10-16 23:51:14.610904+00', 'Heather Dewar', 'HEATHER DEWAR', 3, 32, 9999, 1, 4, 1, 692, '1997-01-01', 'There are several inconsistencies in the original description.', 50, '8800/8484/8484/8044', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13277, '2007-04-10 22:00:00+00', '2017-11-12 00:16:41.560538+00', 'Miss Anne Aldred''s Strathspey', 'MISS ANNE ALDREDS STRATHSPEY', 3, 32, 9999, 6, 3, NULL, 3754, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13276, '2007-04-10 22:00:00+00', '2017-11-12 00:51:14.363548+00', 'Timbit for Janis, A', 'TIMBIT FOR JANIS', 3, 32, 9999, 1, 4, 2, 2983, '2007-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8963, '2001-05-03 22:00:00+00', '2012-01-20 12:57:09.950611+00', 'Harrison''s Rant', 'HARRISONS RANT', 2, 40, 9999, 1, 4, 11, 2578, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8964, '1999-03-01 23:00:00+00', '2012-01-20 12:57:09.958137+00', 'Kay Gibson''s Reel', 'KAY GIBSONS REEL', 1, 32, 9999, 1, 4, 1, 2579, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13293, '2007-06-20 22:00:00+00', '2012-01-20 12:57:45.557806+00', 'Second of June, The', 'SECOND OF JUNE', 3, 32, 9999, NULL, NULL, NULL, 2924, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13294, '2007-06-20 22:00:00+00', '2012-01-20 12:57:45.563259+00', 'Sit This One Out', 'SIT THIS ONE OUT', 1, 32, 9999, NULL, NULL, NULL, 2924, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8966, '1999-03-01 23:00:00+00', '2012-01-20 12:57:09.971841+00', 'Many Happy Returns', 'MANY HAPPY RETURNS', 1, 32, 9999, 5, 56, NULL, 683, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8980, '1999-04-05 22:00:00+00', '2018-04-26 00:25:12.361838+00', 'Chain Walk, The', 'CHAIN WALK', 1, 32, 9999, 1, 4, 2, 2197, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8971, '1999-12-16 23:00:00+00', '2012-01-20 12:57:10.009945+00', 'Sgurr Nan Gillean', 'SGURR NAN GILLEAN', 1, 32, 9999, 1, 4, 2, 2578, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17508, '2016-12-31 15:23:58.159021+00', '2018-08-28 13:38:16.731705+00', 'Confluence', 'CONFLUENCE', 5, 64, NULL, 1, 102, NULL, 10934, NULL, 'I admit I couldn''t help sticking in a waltz-time English-style dance, given the wealth of dancing opportunities and the closeness of the dance communities.  In this case, the two rivers are the Delaware and Schuylkill, which line downtown Philadelphia. This dance is written for Joanna Reiner and Jenny Beer who introduced me to English Dancing at Swarthmore College, and for the Germantown Country Dancers', -1, '', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (8974, '1999-03-02 23:00:00+00', '2012-01-20 12:57:10.030303+00', 'Tinker''s Wedding', 'TINKERS WEDDING', 2, 48, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8976, '1999-03-02 23:00:00+00', '2012-01-20 12:57:10.044266+00', 'Twa Ronnies'' Reel', 'TWA RONNIES REEL', 1, 32, 9999, 1, 4, NULL, 9998, '1987-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8933, '1999-02-14 23:00:00+00', '2022-10-04 18:07:53.171824+00', 'Inglesmaldie Strathspey', 'INGLESMALDIE STRATHSPEY', 3, 48, 9999, 1, 4, 1, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8926, '1999-02-14 23:00:00+00', '2023-01-18 16:41:09.484979+00', 'Cherry Blossom', 'CHERRY BLOSSOM', 3, 32, 9999, 1, 3, 42, 550, '1992-01-01', '', 59, '844/888/855/855', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8936, '2001-06-05 22:00:00+00', '2020-09-07 09:17:19.118161+00', 'Katie''s Ceilidh', 'KATIES CEILIDH', 1, 32, 9999, 1, 3, 42, 101, NULL, 'For Katie Fallas''s 21st birthday.', 53, '800/888/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13281, '2007-05-13 22:00:00+00', '2020-06-27 21:07:32.572723+00', 'Mercury', 'MERCURY', 2, 32, 9999, 1, 3, 42, 17, '2007-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8938, '1999-02-14 23:00:00+00', '2020-09-07 09:20:05.392263+00', 'Ruislip Reel', 'RUISLIP REEL', 1, 32, 9999, 1, 3, 42, 2563, NULL, '', 53, '800/822/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8940, '1999-02-14 23:00:00+00', '2020-09-07 09:23:28.238958+00', 'Stanhope Park', 'STANHOPE PARK', 1, 32, 9999, 1, 3, 42, 49, NULL, '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8955, '1999-02-21 23:00:00+00', '2020-09-07 09:25:44.096973+00', 'Upper Tarr', 'UPPER TARR', 2, 32, 9999, 1, 3, 42, 692, NULL, '', 59, '840/880/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13287, '2007-06-20 22:00:00+00', '2020-09-30 11:38:53.425292+00', 'Ginger Reel', 'GINGER REEL', 1, 32, 9999, NULL, NULL, NULL, 2924, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13289, '2007-06-20 22:00:00+00', '2020-09-30 05:00:06.326604+00', 'Leaves of Autumn', 'LEAVES OF AUTUMN', 1, 32, 9999, 1, 3, 42, 2924, '2003-01-01', '', 53, '840/822/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13288, '2007-06-20 22:00:00+00', '2020-09-30 11:39:37.917346+00', 'Gyre and Reel', 'GYRE AND REEL', 1, 32, 9999, NULL, NULL, NULL, 2924, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13290, '2007-06-20 22:00:00+00', '2020-09-30 11:40:24.493923+00', 'Midsummer Reel, A', 'MIDSUMMER REEL', 1, 32, 9999, NULL, NULL, NULL, 2924, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13291, '2007-06-20 22:00:00+00', '2020-09-30 11:41:02.927547+00', 'Midsummer Strathspey, A', 'MIDSUMMER STRATHSPEY', 3, 32, 9999, NULL, NULL, NULL, 2924, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13296, '2007-06-20 22:00:00+00', '2020-09-30 11:42:53.788242+00', 'Torf''s Delight', 'TORFS DELIGHT', 3, 32, 9999, 1, 3, 42, 2924, '2004-01-01', '', 37, '800/808/800/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13295, '2007-06-20 22:00:00+00', '2020-09-30 11:44:27.539153+00', 'Tough Row to Hoe, A', 'TOUGH ROW TO HOE', 3, 32, 9999, NULL, NULL, NULL, 2924, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8911, '1999-01-05 23:00:00+00', '2021-02-21 23:29:23.796708+00', 'Miss Mollie Eileen', 'MISS MOLLIE EILEEN', 2, 32, 9999, 1, 3, 42, 440, '1993-07-02', 'This dance was devised on July 2, 1993, and named for Mollie Eileen Cronin, first grandchild of Paul Maloney, teacher of the St. Andrew''s group.', 56, '800/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8960, '2000-11-13 23:00:00+00', '2021-03-07 23:38:21.125305+00', 'Miss Erica Jane Scott', 'MISS ERICA JANE SCOTT', 2, 32, 9999, 2, 3, 17, 2577, '1977-01-01', '', 56, '808/888/848/840', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8968, '2002-04-19 22:00:00+00', '2021-03-07 23:40:39.950508+00', 'Michelle''s Strathspey', 'MICHELLES STRATHSPEY', 3, 32, 9999, 2, 3, 17, 1309, '1997-01-01', '', 47, '880/800/844/848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8941, '2002-04-30 22:00:00+00', '2021-03-08 21:54:59.693553+00', 'Strachan Rant', 'STRACHAN RANT', 1, 40, 9999, 1, 3, 42, 9998, NULL, '', 50, '880/888/800/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8951, '2002-03-11 23:00:00+00', '2021-03-08 21:44:57.350222+00', 'Longtown Rant', 'LONGTOWN RANT', 1, 32, 9999, 1, 3, 42, 692, '1997-01-01', '', 56, '800/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8983, '1999-04-05 22:00:00+00', '2012-01-20 12:57:10.094078+00', 'Fiona Grant', 'FIONA GRANT', 2, 64, 9999, 4, 4, NULL, 479, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8984, '1999-04-14 22:00:00+00', '2012-01-20 12:57:10.100934+00', 'Julie''s Rant', 'JULIES RANT', 3, 32, 9999, 99, 99, NULL, 2107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13305, '2007-07-26 22:00:00+00', '2019-01-21 02:29:29.008693+00', 'And Again', 'AND AGAIN', 3, 32, 9999, 1, 3, 42, 3775, '2007-01-01', '', 56, '844/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8988, '1999-04-15 22:00:00+00', '2012-01-20 12:57:10.12893+00', 'Fort, The', 'FORT', 99, 0, 9999, 4, 55, NULL, 238, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8989, '1999-04-15 22:00:00+00', '2012-01-20 12:57:10.136433+00', 'Scottish Poetry Library Reel, The', 'SCOTTISH POETRY LIBRARY REEL', 2, 48, 9999, 1, 4, 1, 2590, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8990, '1999-04-19 22:00:00+00', '2012-01-20 12:57:10.143311+00', 'Forever Youngs', 'FOREVER YOUNGS', 99, 0, 9999, 99, 99, NULL, 2107, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8979, '2001-05-03 22:00:00+00', '2018-04-03 00:07:38.7725+00', 'Cluny Capers', 'CLUNY CAPERS', 2, 32, 9999, 1, 3, 42, 2587, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8972, '2001-05-03 22:00:00+00', '2018-04-03 00:07:40.198768+00', 'Crossing the Snizort', 'CROSSING THE SNIZORT', 3, 32, 9999, 1, 3, 42, 371, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13308, '2007-07-26 22:00:00+00', '2018-04-03 00:07:46.396287+00', 'Foggy Night, The', 'FOGGY NIGHT', 2, 32, 9999, 1, 3, 42, 3777, '1999-05-02', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8993, '1999-04-19 22:00:00+00', '2018-04-03 00:07:51.925775+00', 'Here''s a Health to Him That''s Awa', 'HERES A HEALTH TO HIM THATS AWA', 2, 32, 9999, 1, 3, 42, 3185, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8994, '1999-04-19 22:00:00+00', '2012-01-20 12:57:10.17188+00', 'O Wert Thou in the Cauld Blast', 'O WERT THOU IN THE CAULD BLAST', 3, 32, 9999, 2, 3, NULL, 3185, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8995, '1999-04-19 22:00:00+00', '2012-01-20 12:57:10.178691+00', 'Royal Dumfries Volunteers', 'ROYAL DUMFRIES VOLUNTEERS', 1, 32, 9999, 1, 4, NULL, 3185, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13304, '2007-07-22 22:00:00+00', '2016-06-03 13:38:14.530166+00', 'Delmenhorst Dancie, The', 'DELMENHORST DANCIE', 1, 32, 9999, 1, 3, 42, 228, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8967, '1999-03-02 23:00:00+00', '2018-04-03 00:08:03.109246+00', 'Merle''s Medley', 'MERLES MEDLEY', 4, 32, 1, 1, 3, 42, 2580, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8969, '1999-03-02 23:00:00+00', '2018-04-03 00:08:06.770642+00', 'Mrs Wiltshire''s Dance', 'MRS WILTSHIRES DANCE', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8997, '2002-08-29 22:00:00+00', '2012-01-20 12:57:10.195137+00', 'Cotton Reel, The', 'COTTON REEL', 1, 40, 9999, 1, 4, 1, 550, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8999, '2001-11-20 23:00:00+00', '2012-01-20 12:57:10.21367+00', 'Broderer, The', 'BRODERER', 3, 40, 9999, 1, 4, 1, 550, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19039, '2018-10-25 01:19:11.126933+00', '2018-10-25 01:19:11.126933+00', 'Hoop Eht Einniw', 'HOOP EHT EINNIW', 3, 64, NULL, 4, 4, 3, 11269, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19038, '2018-10-24 23:21:53.888693+00', '2018-10-24 23:33:17.725076+00', 'Welcome Reel, The', 'WELCOME REEL', 2, 32, NULL, 1, 2, 76, 10607, NULL, '', 60, '88/88/80/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13319, '2007-09-03 22:00:00+00', '2018-12-10 19:35:25.165866+00', 'Annick Water', 'ANNICK WATER', 1, 32, 9999, 1, 3, 42, 640, '2007-01-01', '', 53, '880/822/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13321, '2007-09-03 22:00:00+00', '2018-12-19 10:53:05.58243+00', 'Bonnet Toun, The', 'BONNET TOUN', 2, 32, 9999, 1, 3, 42, 640, '2007-01-01', 'The Bonnet Toun is Stewarton (Ayrshire).', 69, '888/888/880/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9028, '1999-04-24 22:00:00+00', '2012-01-20 12:57:10.472675+00', 'Star of Dallas, The', 'STAR OF DALLAS', 2, 40, 9999, 4, 4, NULL, 2600, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13324, '2007-09-03 22:00:00+00', '2018-12-27 21:36:36.030759+00', 'Kingsford', 'KINGSFORD', 3, 32, 9999, 1, 4, 2, 640, '2007-01-01', '', 69, '8448/8448/8448/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9030, '1999-05-09 22:00:00+00', '2018-04-03 00:07:30.125307+00', 'Allemande Joy', 'ALLEMANDE JOY', 2, 32, 9999, 1, 3, 42, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13327, '2007-09-03 22:00:00+00', '2019-09-11 11:05:02.095995+00', 'Town and Gown', 'TOWN AND GOWN', 1, 32, 9999, 1, 102, 2, 640, '2007-01-01', 'Dedicated to the residents of St. Andrews and to the staff and students of its University', 94, '8888/8888/8448/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9034, '2001-05-21 22:00:00+00', '2012-01-20 12:57:10.517172+00', 'Mirrored Hearts Strathspey', 'MIRRORED HEARTS STRATHSPEY', 3, 32, 9999, 1, 4, 2, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9035, '1999-05-09 22:00:00+00', '2012-01-20 12:57:10.524707+00', 'Emma''s Challenge', 'EMMAS CHALLENGE', 1, 32, 9999, 1, 4, 1, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9036, '1999-05-09 22:00:00+00', '2012-01-20 12:57:10.532183+00', 'Humuhumunukunukuapua''a', 'HUMUHUMUNUKUNUKUAPUAA', 1, 32, 9999, 1, 4, 1, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9038, '1999-05-09 22:00:00+00', '2012-01-20 12:57:10.547137+00', 'Weather ... or Not', 'WEATHER  OR NOT', 1, 32, 9999, 1, 4, 1, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9039, '1999-05-09 22:00:00+00', '2012-01-20 12:57:10.554649+00', 'Gábor''s Strathspey', 'GABORS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9044, '1999-06-13 22:00:00+00', '2012-01-20 12:57:10.590083+00', 'Northern Beaches, The', 'NORTHERN BEACHES', 3, 48, 9999, 1, 4, NULL, 2610, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9045, '1999-06-13 22:00:00+00', '2012-01-20 12:57:10.596953+00', 'Lass from Whangarei, The', 'LASS FROM WHANGAREI', 1, 48, 9999, 4, 4, NULL, 325, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13320, '2007-09-03 22:00:00+00', '2020-01-16 16:23:30.489058+00', 'Arran View', 'ARRAN VIEW', 1, 32, 9999, 1, 3, 42, 640, '2007-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9048, '2001-10-21 22:00:00+00', '2020-04-09 20:44:01.750152+00', 'Belle Marguerite, La', 'BELLE MARGUERITE', 3, 40, 9999, 4, 4, 13, 2605, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13317, '2007-08-28 22:00:00+00', '2020-09-17 08:26:25.141167+00', 'Jig for the Sally Lightfoot Crab, A', 'JIG FOR THE SALLY LIGHTFOOT CRAB', 2, 32, 9999, 1, 3, 42, 96, '1995-01-01', '', 56, '888/800/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13297, '2007-06-20 22:00:00+00', '2020-09-30 11:45:05.555907+00', 'Waterloo Silver', 'WATERLOO SILVER', 3, 40, 9999, 3, 5, 7, 2924, '2001-01-01', '', 64, '80800/88888/80800/88888/80800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13298, '2007-06-20 22:00:00+00', '2020-09-30 11:45:44.908792+00', 'Waterloo Strathspey', 'WATERLOO STRATHSPEY', 3, 32, 9999, NULL, NULL, NULL, 2924, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13322, '2007-09-03 22:00:00+00', '2021-01-03 12:42:45.303418+00', 'Grand Hall, The', 'GRAND HALL', 3, 32, 9999, 1, 4, 2, 640, '2006-01-01', '', 94, '8888/8888/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13307, '2007-07-26 22:00:00+00', '2021-01-03 12:50:43.481209+00', 'Favourite Partners', 'FAVOURITE PARTNERS', 3, 32, 9999, 1, 4, 2, 3775, NULL, '', 84, '4884/8888/8228/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13303, '2007-07-22 22:00:00+00', '2021-01-03 12:52:57.132579+00', 'Antje Erben''s Reel', 'ANTJE ERBENS REEL', 2, 32, 9999, 1, 3, 42, 228, NULL, 'Devised: 2000-05', 50, '880/800/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9020, '1999-04-24 22:00:00+00', '2021-01-10 09:52:51.695827+00', 'Follow Your Love', 'FOLLOW YOUR LOVE', 3, 32, 9999, 2, 3, 17, 2599, '1998-01-01', 'Dedicated to all dance lovers everywhere.', 58, '844/844/800/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9043, '2002-12-16 23:00:00+00', '2021-03-06 12:27:32.402458+00', 'Hawkesbury Rant, The', 'HAWKESBURY RANT', 1, 32, 9999, 1, 4, 1, 15, '1995-01-01', '', 75, '8000/8888/8088/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9000, '2002-08-29 22:00:00+00', '2021-03-06 22:30:41.865984+00', 'Packhorse Rant, The', 'PACKHORSE RANT', 1, 32, 9999, 5, 2, 76, 550, '1998-01-01', '', 88, '88/44/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8985, '1999-04-14 22:00:00+00', '2021-03-07 19:13:29.301404+00', 'Mists of Thistledoon, The', 'MISTS OF THISTLEDOON', 3, 32, 9999, 1, 3, 42, 2107, NULL, '', 61, '822/888/866/688', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8975, '2002-03-07 23:00:00+00', '2021-03-07 19:25:09.905327+00', 'Tutor, The', 'TUTOR', 2, 32, 9999, 1, 3, 42, 792, NULL, '', 66, '866/888/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8996, '2002-06-19 22:00:00+00', '2021-06-13 09:35:19.133255+00', 'Upstairs Downstairs', 'UPSTAIRS DOWNSTAIRS', 1, 32, 9999, 1, 100, 2, 550, '1998-05-01', '', 50, '4004/4004/8448/8448', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9019, '1999-04-24 22:00:00+00', '2021-04-07 07:06:58.390166+00', 'Luck to You', 'LUCK TO YOU', 1, 48, 9999, 2, 104, 17, 2599, '1998-01-01', '', 67, '880/880/844/844/808/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8973, '1999-03-02 23:00:00+00', '2021-06-13 09:36:13.232613+00', 'Stuart Robinson''s Reel', 'STUART ROBINSONS REEL', 1, 40, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9047, '2002-11-19 23:00:00+00', '2021-08-02 04:13:20.083235+00', 'Bervie Braes, The', 'BERVIE BRAES', 1, 40, 9999, 4, 4, 1, 452, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9057, '1999-07-23 22:00:00+00', '2012-01-20 12:57:10.684482+00', 'Bonnie Brenda''s Jig', 'BONNIE BRENDAS JIG', 2, 32, 9999, 99, 99, NULL, 2621, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13329, '2007-09-03 22:00:00+00', '2012-01-20 12:57:45.836701+00', 'Lord Scott of Buccleuch', 'LORD SCOTT OF BUCCLEUCH', 1, 32, 9999, 1, 4, NULL, 1089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13333, '2007-09-05 22:00:00+00', '2012-01-20 12:57:45.864619+00', 'Folklore Jig, The', 'FOLKLORE JIG', 2, 32, 9999, 2, 3, 17, 118, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13332, '2007-09-03 22:00:00+00', '2016-02-06 00:31:49.52466+00', 'Bonnie Heir of Buccleuch', 'BONNIE HEIR OF BUCCLEUCH', 4, 64, 5, 4, 4, NULL, 1089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13331, '2007-09-03 22:00:00+00', '2018-04-03 00:07:43.268266+00', 'Duke and Duchess of Buccleuch', 'DUKE AND DUCHESS OF BUCCLEUCH', 2, 32, 9999, 1, 3, 42, 1089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13330, '2007-09-03 22:00:00+00', '2018-04-03 00:07:43.726897+00', 'Earl of Buccleuch', 'EARL OF BUCCLEUCH', 1, 32, 9999, 1, 3, 42, 1089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9031, '1999-05-09 22:00:00+00', '2018-04-03 00:07:44.477493+00', 'Emma & Kendal''s Jig', 'EMMA AND KENDALS JIG', 2, 32, 9999, 1, 3, 42, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9053, '2000-01-16 23:00:00+00', '2018-04-03 00:07:50.408171+00', 'Hale-Bopp', 'HALEBOPP', 1, 32, 9999, 1, 3, 42, 108, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9027, '1999-04-24 22:00:00+00', '2018-04-03 00:07:57.571777+00', 'Kirk on the Terrace, The', 'KIRK ON THE TERRACE', 1, 32, 9999, 1, 3, 42, 2600, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9209, '2000-01-16 23:00:00+00', '2018-04-03 00:07:59.131417+00', 'Lava Tree Reel, The', 'LAVA TREE REEL', 1, 32, 9999, 1, 3, 42, 108, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9032, '1999-05-09 22:00:00+00', '2018-04-03 00:07:59.389863+00', 'Let It Be a Dance', 'LET IT BE A DANCE', 4, 64, 5, 1, 3, 42, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9033, '1999-05-09 22:00:00+00', '2018-04-03 00:08:08.763673+00', 'One Hundred Six Butterflies', 'ONE HUNDRED SIX BUTTERFLIES', 2, 32, 9999, 1, 3, 42, 1309, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13312, '2007-07-26 22:00:00+00', '2018-04-03 00:08:15.552011+00', 'Secret Wedding, A', 'SECRET WEDDING', 3, 32, 9999, 1, 3, 42, 3775, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13328, '2007-09-03 22:00:00+00', '2012-02-25 23:17:08.671598+00', 'Faculty of Actuaries, The', 'FACULTY OF ACTUARIES', 2, 32, 9999, 1, 4, 11, 3779, '2006-12-02', 'Created to celebrate the 150th anniversary of this Scottish professional body in 2008.  The movements of this dance portray the main emblems in the Faculty''s Arms.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9060, '1999-07-24 22:00:00+00', '2012-01-20 12:57:10.705663+00', 'Clark''s Reel', 'CLARKS REEL', 1, 88, 9999, 99, 99, NULL, 2621, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9065, '1999-07-24 22:00:00+00', '2012-01-20 12:57:10.740625+00', 'Monday Morning', 'MONDAY MORNING', 2, 16, 9999, 99, 99, NULL, 2627, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9066, '1999-07-24 22:00:00+00', '2012-01-20 12:57:10.747389+00', 'Northallerton Caledonian Society', 'NORTHALLERTON CALEDONIAN SOCIETY', 1, 40, 9999, 99, 99, NULL, 2621, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9067, '2003-02-20 23:00:00+00', '2012-01-20 12:57:10.75502+00', 'Bon Voyage, Bennett', 'BON VOYAGE BENNETT', 4, 32, 1, 1, 4, 1, 1113, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9068, '1999-07-24 22:00:00+00', '2012-01-20 12:57:10.761941+00', 'Farewell to St George''s', 'FAREWELL TO ST GEORGES', 2, 32, 9999, 99, 99, NULL, 2628, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13356, '2009-08-02 22:00:00+00', '2018-04-03 00:07:34.341633+00', 'Blue Moon Rendezvous', 'BLUE MOON RENDEZVOUS', 2, 32, 9999, 1, 3, 42, 10574, '2007-06-30', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9072, '1999-07-24 22:00:00+00', '2012-01-20 12:57:10.78904+00', 'Bonnie Uyea', 'BONNIE UYEA', 3, 32, 9999, 99, 99, NULL, 815, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13342, '2007-09-11 22:00:00+00', '2018-04-03 00:18:02.238512+00', 'Kings Town Whirligig', 'KINGS TOWN WHIRLIGIG', 3, 32, 9999, 2, 2, 76, 118, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13340, '2007-09-11 22:00:00+00', '2018-04-03 00:18:02.558283+00', 'Turntable', 'TURNTABLE', 3, 32, 9999, 2, 2, 76, 118, '2007-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12762, '2006-05-21 22:00:00+00', '2018-08-21 22:41:16.959789+00', 'Cold Hands, Warm Heart', 'COLD HANDS WARM HEART', 3, 32, 9999, 1, 4, 11, 3682, NULL, 'Andrea Re is well known for using the phrase ·"cold hands, warm heart.''" Every time we dance together his hands are always freezing, and his reply is always that he has a warm heart - we have not seen any evidence of this yet! ', 88, '0880/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9081, '1999-07-25 22:00:00+00', '2012-01-20 12:57:10.850796+00', 'Peggy''s Waltz', 'PEGGYS WALTZ', 5, 32, 9999, 5, 1, NULL, 2626, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13334, '2007-09-05 22:00:00+00', '2012-01-20 12:57:45.87216+00', 'Parade Strathspey, The', 'PARADE STRATHSPEY', 3, 32, 9999, 2, 3, 17, 118, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13335, '2007-09-09 22:00:00+00', '2012-01-20 12:57:45.879058+00', 'Pavilion Reel, The', 'PAVILION REEL', 1, 32, 9999, 2, 3, NULL, 118, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13336, '2007-09-11 22:00:00+00', '2012-01-20 12:57:45.886503+00', 'Balderson House', 'BALDERSON HOUSE', 2, 40, 9999, 1, 4, 1, 118, '2006-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13337, '2007-09-11 22:00:00+00', '2012-01-20 12:57:45.893419+00', 'Black and White', 'BLACK AND WHITE', 1, 32, 9999, 1, 4, NULL, 118, '2007-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13341, '2007-09-11 22:00:00+00', '2012-01-20 12:57:45.921668+00', 'Village Stroll', 'VILLAGE STROLL', 3, 40, 9999, 1, 4, 1, 3606, '2007-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13343, '2007-09-11 22:00:00+00', '2012-01-20 12:57:45.93606+00', 'Drummer''s Companion', 'DRUMMERS COMPANION', 2, 32, 9999, 3, 5, 7, 118, '2007-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13345, '2007-09-11 22:00:00+00', '2012-01-20 12:57:45.95047+00', 'Lune Valley Scamper', 'LUNE VALLEY SCAMPER', 1, 32, 9999, 1, 4, 1, 118, '2007-01-01', '4th couple does not dance.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9097, '2002-12-31 23:00:00+00', '2019-03-05 20:33:09.481006+00', 'Take Care', 'TAKE CARE', 3, 32, 9999, 1, 3, 42, 727, NULL, '', 50, '844/800/866/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9095, '1999-08-05 22:00:00+00', '2019-03-05 20:47:43.919235+00', 'Bryony', 'BRYONY', 3, 32, 9999, 1, 4, 1, 234, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13348, '2007-09-11 22:00:00+00', '2019-05-27 10:48:50.352028+00', 'Ecossaise for Evalyn', 'ECOSSAISE FOR EVALYN', 2, 32, 9999, 1, 3, 42, 118, '2007-01-01', '', 56, '800/888/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9086, '1999-07-25 22:00:00+00', '2020-07-30 20:09:47.165824+00', 'Hidden Valley, The', 'HIDDEN VALLEY', 3, 32, 9999, 1, 2, 76, 175, NULL, '', 52, '88/80/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9101, '2001-11-22 23:00:00+00', '2022-10-02 12:42:07.579+00', 'ABC Jig, The', 'ABC JIG', 2, 32, 9999, 1, 3, 42, 727, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9024, '1999-04-24 22:00:00+00', '2020-09-07 22:42:11.705036+00', 'Maister''s Kilt, The', 'MAISTERS KILT', 1, 32, 9999, 1, 3, 42, 2600, NULL, '', 44, '800/888/800/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9023, '1999-04-24 22:00:00+00', '2020-09-07 22:39:06.485251+00', 'Road to Tigh-na-Dal', 'ROAD TO TIGHNADAL', 2, 32, 9999, 1, 3, 42, 2600, NULL, '', 56, '800/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9098, '2002-03-03 23:00:00+00', '2021-03-01 20:21:17.256285+00', 'Damaris Reel, The', 'DAMARIS REEL', 1, 48, 9999, 1, 4, 22, 2643, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9094, '1999-08-05 22:00:00+00', '2021-03-01 20:24:21.371196+00', 'James''s Jig', 'JAMESS JIG', 2, 40, 9999, 1, 3, 42, 2641, NULL, '', 60, '880/888/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9080, '2000-09-07 22:00:00+00', '2021-03-02 22:36:18.809615+00', 'North Ayrshire Welcome, A', 'NORTH AYRSHIRE WELCOME', 2, 32, 9999, 5, 2, NULL, 2626, NULL, '', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9079, '1999-07-25 22:00:00+00', '2021-03-02 22:41:50.227917+00', 'Half Century Jig, The', 'HALF CENTURY JIG', 2, 32, 9999, 3, 5, 7, 2626, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9054, '1999-08-05 22:00:00+00', '2021-03-06 12:15:02.364237+00', 'Corryvreckan', 'CORRYVRECKAN', 2, 32, 9999, 1, 3, 42, 2625, NULL, '', 53, '880/808/844/884', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9046, '2002-04-30 22:00:00+00', '2021-08-02 08:34:51.002706+00', 'Trip to the Trossachs, A', 'TRIP TO THE TROSSACHS', 1, 32, 9999, 1, 3, 42, 452, '1998-01-01', '', 53, '880/800/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9112, '1999-08-06 22:00:00+00', '2012-01-20 12:57:11.068837+00', 'Clynnog Thistle', 'CLYNNOG THISTLE', 4, 64, 5, 2, 3, NULL, 479, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13349, '2007-09-11 22:00:00+00', '2012-01-20 12:57:45.979304+00', 'Sprig of Heather', 'SPRIG OF HEATHER', 3, 72, 9999, 4, 4, NULL, 118, '2007-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13344, '2007-09-11 22:00:00+00', '2018-04-03 00:08:01.474874+00', 'Madoma Silver', 'MADOMA SILVER', 2, 32, 9999, 1, 3, 42, 118, '2007-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13346, '2007-09-11 22:00:00+00', '2018-04-03 00:08:03.409416+00', 'Midway Reel, The', 'MIDWAY REEL', 1, 40, 9999, 1, 3, 42, 118, '2007-01-01', 'set/turn corners with right hand.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9073, '2005-12-21 23:00:00+00', '2018-04-03 00:08:06.862326+00', 'Muir''s Medley', 'MUIRS MEDLEY', 4, 64, 5, 1, 3, 42, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13339, '2007-09-11 22:00:00+00', '2018-04-03 00:08:10.156387+00', 'Peekaboo', 'PEEKABOO', 2, 32, 9999, 1, 3, 42, 3782, '2007-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9116, '2002-08-29 22:00:00+00', '2012-01-20 12:57:11.103634+00', 'Reel of the Noble Society of Celts, The', 'REEL OF THE NOBLE SOCIETY OF CELTS', 1, 32, 9999, 1, 4, 1, 2670, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9118, '1999-08-12 22:00:00+00', '2012-01-20 12:57:11.1176+00', 'Wild Geese Fly South, The', 'WILD GEESE FLY SOUTH', 2, 32, 9999, 4, 4, NULL, 2670, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13359, '2009-08-02 22:00:00+00', '2018-08-09 00:43:38.04514+00', 'Charlie''s Birthday', 'CHARLIES BIRTHDAY', 2, 32, NULL, 1, 3, 42, 10564, NULL, 'Written for Charlie Stevens'' 80th birthday.', 64, '882/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9129, '2001-05-03 22:00:00+00', '2012-01-20 12:57:11.211858+00', 'Mason''s Fancy', 'MASONS FANCY', 2, 32, 9999, 4, 4, NULL, 448, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9130, '2001-05-03 22:00:00+00', '2012-01-20 12:57:11.218693+00', 'Mrs F S MacKenzie', 'MRS F S MACKENZIE', 3, 64, 9999, 4, 4, NULL, 448, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9131, '2000-03-15 23:00:00+00', '2012-01-20 12:57:11.225454+00', 'Robertson''s Hornpipe', 'ROBERTSONS HORNPIPE', 1, 32, 9999, 1, 4, NULL, 448, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9132, '2001-05-03 22:00:00+00', '2012-01-20 12:57:11.232287+00', 'Ian''s Fancy', 'IANS FANCY', 1, 32, 9999, 1, 4, NULL, 448, '1984-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9134, '2000-03-15 23:00:00+00', '2012-01-20 12:57:11.246628+00', 'Trip Homeward', 'TRIP HOMEWARD', 3, 32, 9999, 1, 2, NULL, 448, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9135, '2000-03-15 23:00:00+00', '2012-01-20 12:57:11.253462+00', 'Tribute to a Tailoress', 'TRIBUTE TO A TAILORESS', 4, 128, 51, 1, 4, NULL, 448, '1987-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13366, '2009-08-02 22:00:00+00', '2018-08-09 17:09:43.971778+00', 'Lydia''s Dance', 'LYDIAS DANCE', 1, 40, NULL, 1, 3, 42, 10567, '2003-03-01', 'Written for Lydia Rice.

', 63, '800/880/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9139, '1999-10-24 22:00:00+00', '2012-01-20 12:57:11.282453+00', 'Trip to the Dauphiné', 'TRIP TO THE DAUPHINE', 1, 32, 9999, 1, 4, NULL, 17, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9140, '1999-10-24 22:00:00+00', '2012-01-20 12:57:11.289347+00', 'Wedding in Dauphiné, A', 'WEDDING IN DAUPHINE', 1, 32, 9999, 1, 4, NULL, 17, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13368, '2009-10-18 22:00:00+00', '2012-01-20 12:57:46.118635+00', 'Stuck in the Snow', 'STUCK IN THE SNOW', 1, 32, NULL, 3, 5, 7, 2806, '2006-04-01', 'Devised for Deirdre Adamson and her band after they got stuck in the snow returning home after playing for a Newcastle branch dance in March 2006', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13800, '2011-07-24 22:00:00+00', '2012-01-20 12:57:49.224237+00', 'Denise Cunningham', 'DENISE CUNNINGHAM', 1, 32, NULL, 1, 4, 5, 2682, '2009-11-02', 'Modified 23 February 2010. Denise is a friend from Vancouver met through Scottish Country Dancing at various TAC Summer Schools and AGM''s.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13801, '2011-07-24 22:00:00+00', '2012-01-20 12:57:49.235617+00', 'Lady Mary Hay''s Reel', 'LADY MARY HAYS REEL', 1, 32, NULL, 1, 4, 2, 2682, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13802, '2011-07-24 22:00:00+00', '2012-01-20 12:57:49.246877+00', 'Lady Mary Hay''s Scot''s Measure', 'LADY MARY HAYS SCOTS MEASURE', 1, 32, NULL, 1, 4, 2, 2682, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6659, '1997-04-03 22:00:00+00', '2018-08-23 18:48:54.174657+00', 'Torwood', 'TORWOOD', 1, 40, 9999, 1, 4, 2, 28, NULL, 'To Rita Porter, our Bristol Branch pianist who played for the demonstration group classes at Torwood House.', 80, '8008/8888/8008/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9137, '1999-10-19 22:00:00+00', '2019-03-04 19:50:15.995538+00', 'Look Aboot Ye''', 'LOOK ABOOT YE', 2, 32, 9999, 1, 4, 2, 1084, NULL, '', 88, '8888/8228/8888/6886', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9149, '1999-11-07 23:00:00+00', '2018-04-03 00:07:37.178575+00', 'Castle by the Water, The', 'CASTLE BY THE WATER', 3, 32, 9999, 1, 3, 42, 2675, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9168, '2001-12-04 23:00:00+00', '2019-03-05 20:22:00.043937+00', 'Cauld Comfort', 'CAULD COMFORT', 1, 40, 9999, 1, 4, 1, 401, '1998-01-01', '', 45, '8000/8220/8000/8022/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9150, '1999-11-07 23:00:00+00', '2012-01-20 12:57:11.363852+00', 'Devil on Paws, The', 'DEVIL ON PAWS', 1, 40, 9999, 1, 4, 1, 2675, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9159, '1999-11-04 23:00:00+00', '2019-03-05 20:26:59.451545+00', 'Tying the Knot', 'TYING THE KNOT', 3, 40, 9999, 1, 4, 11, 2169, NULL, '', 68, '8888/8448/8008/8228/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9163, '1999-11-04 23:00:00+00', '2019-04-02 20:21:27.972514+00', 'Hot Links', 'HOT LINKS', 1, 40, 9999, 1, 3, 42, 2677, NULL, '', 58, '800/880/884/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9164, '1999-11-04 23:00:00+00', '2019-04-02 20:25:06.311061+00', 'Richard the Third', 'RICHARD THE THIRD', 3, 32, 9999, 1, 3, 42, 2677, NULL, '', 53, '800/888/677/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13353, '2007-10-28 23:00:00+00', '2020-03-27 19:36:14.512518+00', 'Branches Together', 'BRANCHES TOGETHER', 3, 96, 9999, 4, 4, 3, 146, NULL, 'For the Leeds and York & North Humberside Branches who organized an Autumn Ball - November 2007', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9143, '1999-10-24 22:00:00+00', '2020-04-02 10:23:25.177591+00', 'Falls of Fyers', 'FALLS OF FYERS', 1, 32, 9999, 1, 4, 2, 17, '1997-01-01', '', 75, '8008/4884/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9075, '1999-07-25 22:00:00+00', '2020-05-25 18:11:34.659684+00', 'Old Bailey Bridge, The', 'OLD BAILEY BRIDGE', 1, 40, 9999, 1, 3, 42, 2626, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9069, '1999-07-24 22:00:00+00', '2020-09-07 22:46:26.181088+00', 'Enid''s Welcome', 'ENIDS WELCOME', 3, 32, 9999, 4, 4, 1, 2627, NULL, '', 75, '4444/8888/8888/4444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9071, '1999-07-24 22:00:00+00', '2020-09-07 22:57:50.455154+00', 'Canterbury Cross', 'CANTERBURY CROSS', 2, 48, 9999, 1, 4, 1, 815, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13350, '2007-09-11 22:00:00+00', '2022-04-28 09:11:13.404695+00', 'Rideau Street Rant', 'RIDEAU STREET RANT', 1, 32, 9999, 2, 3, 17, 118, '2007-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9018, '1999-04-24 22:00:00+00', '2022-08-07 11:01:11.48169+00', 'Strathspey for Eric, A', 'STRATHSPEY FOR ERIC', 3, 32, 9999, 1, 3, 42, 2599, '1998-01-01', 'To Eric Wallace on his 60th birthday, January 1998', 59, '880/822/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9058, '2002-03-02 23:00:00+00', '2022-08-13 17:21:34.270105+00', 'Captain Donald Johnstone', 'CAPTAIN DONALD JOHNSTONE', 3, 32, 9999, 1, 3, 42, 2621, NULL, '', 38, '800/800/880/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13352, '2007-10-10 22:00:00+00', '2022-09-19 09:36:42.76272+00', 'Shoplifting Seagulls', 'SHOPLIFTING SEAGULLS', 4, 32, 1, 1, 3, 42, 1113, '2007-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9099, '1999-08-05 22:00:00+00', '2022-10-03 08:44:08.896464+00', 'Spring Chicken', 'SPRING CHICKEN', 2, 40, 9999, 1, 3, 42, 234, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13746, '2011-07-11 22:00:00+00', '2020-09-20 08:39:16.568359+00', 'Perez Hospitality', 'PEREZ HOSPITALITY', 1, 32, NULL, 1, 4, 1, 2973, '2006-09-01', 'Devised in September 2006 and tested at Teresa and Louis'' home.', 72, '8888/8008/8008/4888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13363, '2009-08-02 22:00:00+00', '2020-12-29 11:23:43.440258+00', 'Happy To Meet You Charlie', 'HAPPY TO MEET YOU CHARLIE', 3, 32, NULL, 1, 100, 2, 10563, '2005-01-30', 'Written for Charlie Stevens for his 80th birthday.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9128, '1999-10-24 22:00:00+00', '2021-03-01 11:06:35.062187+00', 'To Karin', 'TO KARIN', 1, 32, 9999, 1, 4, 2, 448, '1999-01-01', '', 68, '8008/8448/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9092, '1999-08-05 22:00:00+00', '2021-03-02 14:15:32.077937+00', 'Ladykirk Bridge', 'LADYKIRK BRIDGE', 3, 32, 9999, 1, 3, 42, 2639, NULL, '', 56, '800/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9127, '1999-10-10 22:00:00+00', '2021-03-01 11:11:22.670257+00', 'Jack''s the Lad', 'JACKS THE LAD', 3, 32, 9999, 2, 3, 17, 146, '1998-01-01', 'For Jack Brown''s ninetieth birthday.', 69, '844/844/822/868', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9089, '1999-07-26 22:00:00+00', '2021-03-02 14:20:32.506021+00', 'Three and One', 'THREE AND ONE', 2, 32, 9999, 8, 105, 12, 175, NULL, '', 65, '448844/448844/864468/048840', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9085, '1999-07-25 22:00:00+00', '2021-03-02 22:26:24.847673+00', 'Famous Grouse, The', 'FAMOUS GROUSE', 2, 32, 9999, 1, 3, 42, 175, NULL, '', 47, '800/844/844/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9078, '1999-07-25 22:00:00+00', '2021-03-02 22:46:19.863103+00', 'Visit to Kelburn, A', 'VISIT TO KELBURN', 1, 32, 9999, 1, 3, 42, 2626, NULL, '', 69, '888/888/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9155, '1999-11-07 23:00:00+00', '2012-01-20 12:57:11.399421+00', 'President''s Jig, The', 'PRESIDENTS JIG', 2, 32, 9999, 1, 4, 1, 2675, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13354, '2007-10-29 23:00:00+00', '2019-06-09 17:24:12.785001+00', 'Irish Bride, The', 'IRISH BRIDE', 3, 32, 9999, 1, 3, 42, 3784, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9152, '1999-11-07 23:00:00+00', '2018-04-03 00:07:42.117292+00', 'Diamond Reel, The', 'DIAMOND REEL', 1, 32, 9999, 1, 3, 42, 2675, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9119, '1999-08-16 22:00:00+00', '2018-04-03 00:07:43.293216+00', 'Duke of Rothesay, The', 'DUKE OF ROTHESAY', 3, 32, 9999, 1, 3, 42, 326, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9142, '1999-10-24 22:00:00+00', '2018-04-03 00:07:59.681834+00', 'Lindsey''s Return', 'LINDSEYS RETURN', 1, 32, 9999, 1, 3, 42, 17, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9171, '1999-12-06 23:00:00+00', '2018-04-03 00:07:50.491564+00', 'Halsway Lasses', 'HALSWAY LASSES', 1, 32, 9999, 1, 3, 42, 304, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9126, '2000-07-26 22:00:00+00', '2018-04-03 00:08:07.270882+00', 'Naughty Nancy', 'NAUGHTY NANCY', 2, 32, 9999, 1, 3, 42, 1331, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9154, '1999-11-07 23:00:00+00', '2018-04-03 00:08:09.772686+00', 'Pamela of Plimmerton', 'PAMELA OF PLIMMERTON', 1, 32, 9999, 1, 3, 42, 2675, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9146, '1999-10-24 22:00:00+00', '2018-04-03 00:08:11.974452+00', 'Rain in the Spring', 'RAIN IN THE SPRING', 3, 32, 9999, 1, 3, 42, 17, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9145, '1999-10-24 22:00:00+00', '2018-04-03 00:08:18.103986+00', 'Spracklin up the Braes', 'SPRACKLIN UP THE BRAES', 1, 40, 9999, 1, 3, 42, 17, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9174, '1999-12-06 23:00:00+00', '2018-04-03 00:18:02.288117+00', 'Midsummer Jig, The', 'MIDSUMMER JIG', 2, 48, 9999, 2, 2, 76, 304, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9191, '2001-12-16 23:00:00+00', '2018-04-29 06:15:05.091096+00', 'Briarcliff Manor', 'BRIARCLIFF MANOR', 1, 32, 9999, 102, 5, NULL, 108, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5752, '1997-04-03 22:00:00+00', '2018-04-02 23:56:37.439065+00', 'Royal Town, The', 'ROYAL TOWN', 2, 32, 9999, 1, 3, 42, 313, NULL, 'The Royal Town of Sutton Coldfield was granted its Charter by King Henry VIII in 1529.', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (9201, '2001-12-16 23:00:00+00', '2018-04-03 00:07:35.025618+00', 'Bonsai Tree, The', 'BONSAI TREE', 2, 32, 9999, 1, 3, 42, 108, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13372, '2009-11-05 23:00:00+00', '2012-01-20 12:57:46.137972+00', 'Silver Spire, The', 'SILVER SPIRE', 1, 40, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9172, '1999-12-06 23:00:00+00', '2012-01-20 12:57:11.522376+00', 'West Coast Line, The', 'WEST COAST LINE', 1, 32, 9999, 1, 4, NULL, 304, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9173, '1999-12-06 23:00:00+00', '2012-01-20 12:57:11.529261+00', 'Mrs Brown''s Reel', 'MRS BROWNS REEL', 1, 144, 9999, 4, 4, NULL, 304, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9175, '1999-12-06 23:00:00+00', '2012-01-20 12:57:11.542835+00', 'After Harris', 'AFTER HARRIS', 2, 48, 9999, 1, 4, NULL, 304, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9176, '1999-12-06 23:00:00+00', '2012-01-20 12:57:11.549608+00', 'Spring and Summer', 'SPRING AND SUMMER', 3, 32, 9999, 1, 4, NULL, 304, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9178, '2000-02-13 23:00:00+00', '2012-01-20 12:57:11.563827+00', 'Carfraemill', 'CARFRAEMILL', 3, 32, 9999, 2, 3, 17, 2683, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13361, '2009-08-02 22:00:00+00', '2018-08-17 03:05:17.881328+00', 'Mòran Taing', 'MORAN TAING', 3, 32, NULL, 1, 3, 42, 10565, '2007-01-01', 'Written as a big "thank-you" to the Montréal Branch for many years of great dancing and camaraderie.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9182, '1999-12-16 23:00:00+00', '2012-01-20 12:57:11.591505+00', 'Moira''s Medley for a Tenth Anniversary', 'MOIRAS MEDLEY FOR A TENTH ANNIVERSARY', 4, 64, 9999, 3, 5, NULL, 2578, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9183, '1999-12-16 23:00:00+00', '2012-01-20 12:57:11.59839+00', 'Loch Torridon', 'LOCH TORRIDON', 3, 96, 9999, 4, 4, NULL, 2578, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9160, '2002-03-11 23:00:00+00', '2018-10-13 12:36:02.462167+00', 'Knights'' Heys', 'KNIGHTS HEYS', 1, 32, 9999, 1, 3, 42, 2677, '1995-01-01', '', 54, '811/888/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18680, '2018-10-01 15:07:20.616896+00', '2018-10-01 15:07:20.616896+00', 'A-Synchronicity', 'ASYNCHRONICITY', 6, 32, NULL, 1, 3, NULL, 2766, '2012-06-01', 'In this dance 1C are dancing different tracks in bars 1-8 and 25-28 to end in similar places; thus the name of the dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13373, '2009-11-05 23:00:00+00', '2018-04-03 00:07:37.612487+00', 'Celebration Reel', 'CELEBRATION REEL', 1, 32, NULL, 1, 3, 42, 1836, '2006-10-01', 'Devised: 2006-10', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9198, '2002-10-28 23:00:00+00', '2012-01-20 12:57:11.70191+00', 'Micklegate Run, The', 'MICKLEGATE RUN', 2, 96, 9999, 4, 4, NULL, 854, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13382, '2009-11-05 23:00:00+00', '2012-01-20 12:57:46.202043+00', 'Beside the Seaside', 'BESIDE THE SEASIDE', 2, 32, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13885, '2011-08-22 22:00:00+00', '2012-01-20 12:57:49.874689+00', 'Geordie Diamond, The', 'GEORDIE DIAMOND', 3, 40, NULL, 2, 3, 17, 2788, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9185, '2000-01-10 23:00:00+00', '2018-04-03 00:07:39.323076+00', 'Constabulary of Kent', 'CONSTABULARY OF KENT', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13888, '2011-08-22 22:00:00+00', '2012-01-20 12:57:49.894962+00', 'Maureen''s Medley', 'MAUREENS MEDLEY', 4, 128, 2, 4, 4, 30, 2788, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9202, '2000-01-16 23:00:00+00', '2012-01-20 12:57:11.730122+00', 'Breezbay', 'BREEZBAY', 2, 32, 9999, 1, 2, NULL, 108, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9206, '2000-01-16 23:00:00+00', '2012-01-20 12:57:11.758526+00', 'Dream Maker', 'DREAM MAKER', 3, 32, 9999, 1, 2, NULL, 108, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13371, '2009-11-04 23:00:00+00', '2016-06-24 21:19:04.169428+00', 'George Scroggie''s Strathspey', 'GEORGE SCROGGIES STRATHSPEY', 3, 32, NULL, NULL, NULL, NULL, 3682, NULL, 'The dance was devised in memory of Luke Brady''s grandfather who died in August 2007.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13381, '2009-11-05 23:00:00+00', '2017-02-14 21:10:27.940988+00', 'To Be a Wind', 'TO BE A WIND', 2, 32, NULL, 3, 5, 7, 10356, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9141, '1999-10-24 22:00:00+00', '2020-09-07 23:07:09.942293+00', 'Tartan Shawl', 'TARTAN SHAWL', 2, 32, 9999, 1, 3, 42, 17, '1999-01-01', '', 50, '800/888/866/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13377, '2009-11-05 23:00:00+00', '2021-04-03 11:13:23.941092+00', 'Highland Games', 'HIGHLAND GAMES', 4, 96, 42, 1, 107, 3, 10357, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9196, '2002-10-28 23:00:00+00', '2021-02-26 22:17:51.812926+00', 'Al''s Fiddle', 'ALS FIDDLE', 1, 32, 9999, 1, 3, 42, 1415, NULL, '', 44, '800/822/888/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9259, '2000-01-16 23:00:00+00', '2018-04-03 00:08:23.415675+00', 'Unusual Wedding, An', 'UNUSUAL WEDDING', 3, 32, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9270, '2000-01-16 23:00:00+00', '2018-04-03 00:08:26.751583+00', 'With Vim and Vigour', 'WITH VIM AND VIGOUR', 1, 32, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9156, '1999-11-07 23:00:00+00', '2022-04-29 08:12:03.533907+00', 'Road Goes Ever On, The', 'ROAD GOES EVER ON', 3, 32, 9999, 1, 2, 76, 2675, '1993-01-01', 'Revised in August 1996 and presented to John Bailey, the deviser''s husband, on the occasion of his retirement in September 1996.', 60, '80/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13378, '2009-11-05 23:00:00+00', '2022-09-19 08:46:34.082169+00', 'Jig for Yukio, A', 'JIG FOR YUKIO', 2, 40, NULL, 2, 3, 17, 50, '2005-04-01', 'Devised: 2005-04', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9161, '1999-11-04 23:00:00+00', '2021-03-01 11:02:08.412107+00', 'Smoke Rings in the Night', 'SMOKE RINGS IN THE NIGHT', 3, 32, 9999, 1, 2, 76, 2677, NULL, '', 60, '66/88/66/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13379, '2009-11-05 23:00:00+00', '2021-03-03 22:36:44.968809+00', 'Lady of Tokai', 'LADY OF TOKAI', 3, 32, NULL, 1, 102, 2, 1089, NULL, '', 84, '8888/8668/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13376, '2009-11-05 23:00:00+00', '2021-03-03 22:52:11.174985+00', 'Canberra Bluebell, The', 'CANBERRA BLUEBELL', 3, 80, NULL, 4, 4, 3, 93, '1988-01-01', 'Devised: 1988', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13374, '2009-11-05 23:00:00+00', '2021-03-03 22:55:38.829596+00', 'Bluebell Flowers', 'BLUEBELL FLOWERS', 4, 128, 2, 1, 4, 3, 10356, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9200, '2002-04-29 22:00:00+00', '2021-03-13 19:09:59.791027+00', 'Celtic Gold', 'CELTIC GOLD', 2, 32, 9999, 2, 3, 18, 2635, '2001-01-01', 'Devised to celebrate Thornton Cleveleys 50th Anniversary.', 79, '282/484/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9180, '1999-12-16 23:00:00+00', '2021-06-06 13:14:38.592452+00', 'Sweets of May', 'SWEETS OF MAY', 2, 48, 9999, 2, 3, NULL, 2578, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9179, '1999-12-16 23:00:00+00', '2021-06-06 13:15:48.241803+00', 'Bishops of Tweedie, The', 'BISHOPS OF TWEEDIE', 2, 32, 9999, 1, 4, NULL, 2578, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13882, '2011-08-22 22:00:00+00', '2018-04-03 00:07:50.566687+00', 'Hamilton''s Versatile Virtuosos', 'HAMILTONS VERSATILE VIRTUOSOS', 2, 40, NULL, 1, 3, 42, 3490, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9208, '2000-01-16 23:00:00+00', '2018-04-03 00:07:52.042622+00', 'Hibiscus Waltz, The', 'HIBISCUS WALTZ', 5, 32, 9999, 1, 3, 42, 108, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9195, '2000-01-12 23:00:00+00', '2018-04-03 00:07:53.310222+00', 'Ilona''s Reel', 'ILONAS REEL', 1, 32, 9999, 1, 3, 42, 854, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9186, '2000-01-11 23:00:00+00', '2018-04-03 00:08:03.501238+00', 'Millennium', 'MILLENNIUM', 3, 32, 9999, 1, 3, 42, 785, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13883, '2011-08-22 22:00:00+00', '2018-04-03 00:08:05.419302+00', 'Mo''s Musicians', 'MOS MUSICIANS', 3, 32, NULL, 1, 3, 42, 3490, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9188, '2000-01-10 23:00:00+00', '2018-04-03 00:08:15.735532+00', 'Seventy Years Young', 'SEVENTY YEARS YOUNG', 1, 32, 9999, 1, 3, 42, 1314, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9225, '2000-01-16 23:00:00+00', '2018-04-03 00:07:31.278771+00', 'Askival', 'ASKIVAL', 2, 32, 9999, 1, 3, 42, 108, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9211, '2000-01-16 23:00:00+00', '2012-01-20 12:57:11.792963+00', 'Matsu Shima', 'MATSU SHIMA', 3, 64, 9999, 2, 3, NULL, 108, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9212, '2000-01-16 23:00:00+00', '2012-01-20 12:57:11.799839+00', 'Miss Ogilvie''s Jig', 'MISS OGILVIES JIG', 2, 32, 9999, 1, 4, NULL, 108, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13805, '2011-08-04 22:00:00+00', '2018-04-26 21:22:48.871775+00', 'Burnham Reel', 'BURNHAM REEL', 1, 32, NULL, 2, 3, 17, 10378, NULL, 'Devised by Janet while vacationing in Burnham, Maine.', 71, '820/888/802/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9218, '2000-01-16 23:00:00+00', '2012-01-20 12:57:11.841076+00', 'Sayonara', 'SAYONARA', 2, 40, 9999, 1, 2, NULL, 108, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9228, '2000-01-16 23:00:00+00', '2012-01-20 12:57:11.910437+00', 'Cairn of Sorrow, The', 'CAIRN OF SORROW', 3, 32, 9999, 5, 99, NULL, 108, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9226, '2002-02-27 23:00:00+00', '2019-02-08 17:35:58.421187+00', 'Big Bang, The', 'BIG BANG', 1, 40, 9999, 1, 100, 2, 108, '1998-01-01', '', 95, '8888/8888/8888/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9230, '2000-01-16 23:00:00+00', '2012-01-20 12:57:11.924436+00', 'Chinook, The', 'CHINOOK', 2, 48, 9999, 1, 4, NULL, 108, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13388, '2009-11-08 23:00:00+00', '2012-01-20 12:57:46.230922+00', 'Thistle and the Maple Leaf, The', 'THISTLE AND THE MAPLE LEAF', 2, 128, NULL, 4, 4, 30, 370, NULL, '»Devised by Moira Stacey of Kirkcudbright, Scotland, and dedicated to friends made at the RSCDS Summer School in St Andrews: Mary Murray (Vancouver), Cherlye Macdonald (Stave Falls) and Sandra Crosby (Abbotsford).«', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9207, '2000-01-16 23:00:00+00', '2019-03-05 20:13:34.913193+00', 'Have a Bashie', 'HAVE A BASHIE', 2, 32, 9999, 1, 100, 2, 108, '1998-01-01', '', 84, '8228/8448/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13384, '2009-11-06 23:00:00+00', '2014-06-19 18:52:57.870412+00', 'Dainty Dave', 'DAINTY DAVE', 3, 16, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13392, '2009-11-08 23:00:00+00', '2012-01-20 12:57:46.258024+00', 'Stooges Salute', 'STOOGES SALUTE', 4, 128, 2, 4, 4, 3, 10373, NULL, 'Devised by Chris and Sue Ronald of Edgewater, New Jersey, to honour the stooges at TAC Summer School, and especially Joan and John Reeves who''ve marshalled the stooges over many years.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13803, '2011-07-24 22:00:00+00', '2012-01-20 12:57:49.255554+00', 'End of the Great Bridge, The', 'END OF THE GREAT BRIDGE', 2, 48, NULL, 1, 4, 1, 2682, '2010-03-24', 'Inspired by the challenge of Hugh Foss''s Waverley Fugues. And, as the alias name suggests, modelled around Maxwell''s Rant.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9246, '2000-01-16 23:00:00+00', '2018-04-03 00:07:41.124488+00', 'Dancing Driscolls', 'DANCING DRISCOLLS', 2, 32, 9999, 1, 3, 42, 3586, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9233, '2002-03-11 23:00:00+00', '2019-05-01 09:28:33.604497+00', 'Harold''s Strathspey', 'HAROLDS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9232, '2000-01-16 23:00:00+00', '2018-04-03 00:07:46.070785+00', 'Fixed Link, The', 'FIXED LINK', 2, 40, 9999, 1, 3, 42, 108, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9237, '2002-02-27 23:00:00+00', '2012-01-20 12:57:11.972605+00', 'Riva-Dance', 'RIVADANCE', 1, 96, 9999, 4, 4, NULL, 108, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9238, '2000-01-16 23:00:00+00', '2012-01-20 12:57:11.979686+00', 'Saint Boniface', 'SAINT BONIFACE', 3, 32, 9999, 1, 4, NULL, 108, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9241, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.000395+00', 'That Sinking Feeling', 'THAT SINKING FEELING', 1, 32, 9999, 1, 4, NULL, 108, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9243, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.014076+00', 'Arthritis', 'ARTHRITIS', 1, 32, 9999, 1, 2, NULL, 3590, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9244, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.020925+00', 'Betty Fold', 'BETTY FOLD', 1, 32, 9999, 4, 5, NULL, 3591, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9247, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.041515+00', 'Isn''t He a Lovely Man?', 'ISNT HE A LOVELY MAN', 1, 32, 9999, 1, 2, NULL, 3586, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9248, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.048416+00', 'Knights of the Green Garter', 'KNIGHTS OF THE GREEN GARTER', 3, 96, 9999, 4, 4, NULL, 3586, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9251, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.069081+00', 'Penultimate Banana, The', 'PENULTIMATE BANANA', 4, 96, 11, 4, 4, NULL, 3591, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9249, '2000-01-16 23:00:00+00', '2016-11-15 23:47:39.140684+00', 'One Dwarf Short of a Set', 'ONE DWARF SHORT OF A SET', 3, 32, 9999, 1, 4, NULL, 3591, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9221, '2000-01-16 23:00:00+00', '2020-09-08 08:51:30.682787+00', 'Wellbrae', 'WELLBRAE', 3, 32, 9999, 1, 100, 2, 108, '1998-01-01', '', 88, '8888/8888/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9229, '2000-01-16 23:00:00+00', '2020-09-08 16:42:25.000067+00', 'Capon Tree, The', 'CAPON TREE', 2, 32, 9999, 1, 3, 42, 108, '1997-01-01', '', 83, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9214, '2002-04-08 22:00:00+00', '2021-01-03 16:23:32.359162+00', 'Mount Fuji', 'MOUNT FUJI', 3, 32, 9999, 1, 3, 42, 108, '1997-08-01', 'For the dancers in Mr Miyakawa''s group in Japan who invited the deviser to visit them in 1998.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9236, '2000-01-16 23:00:00+00', '2021-01-10 17:48:12.56202+00', 'Reel of the Badcocks', 'REEL OF THE BADCOCKS', 2, 32, 9999, 1, 3, 42, 108, '1998-01-01', '', 69, '888/888/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9234, '2002-03-11 23:00:00+00', '2021-02-26 14:03:08.357494+00', 'Honeycomb, The', 'HONEYCOMB', 1, 40, 9999, 1, 4, 1, 108, '1997-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9205, '2002-01-06 23:00:00+00', '2021-02-26 21:33:18.813399+00', 'Georgian Strathspey, The', 'GEORGIAN STRATHSPEY', 3, 32, 9999, 1, 100, 2, 108, '1998-01-01', '', 75, '8888/8888/8008/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9181, '1999-12-16 23:00:00+00', '2021-02-27 09:35:23.853742+00', 'Toast to the Stewarts, A', 'TOAST TO THE STEWARTS', 2, 40, 9999, 1, 3, 18, 2578, '1999-01-01', '', 63, '888/888/888/840/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9192, '2002-07-04 22:00:00+00', '2021-05-25 09:48:43.194516+00', 'Diana''s Reel', 'DIANAS REEL', 1, 32, 9999, 1, 3, 42, 854, '1998-01-01', '', 53, '800/888/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9245, '2000-01-16 23:00:00+00', '2022-08-13 11:10:15.249598+00', 'Clash of the Tartans', 'CLASH OF THE TARTANS', 2, 48, 9999, 1, 100, 22, 3585, '1999-01-01', 'Danced twice.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9210, '2000-01-16 23:00:00+00', '2023-01-12 22:29:50.421996+00', 'Lei Waltz, The', 'LEI WALTZ', 5, 32, 9999, 5, 1, 4, 108, '1998-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9184, '2000-01-12 23:00:00+00', '2021-02-27 18:38:24.778504+00', 'Renaissance Man, The', 'RENAISSANCE MAN', 3, 40, 9999, 1, 3, 42, 2684, '1997-11-01', 'Dedicated to Milton Levy who devised the figures (set and "Link for Three" and Strathspey Balance in Line) used in this dance.', 58, '800/822/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9197, '2002-10-28 23:00:00+00', '2021-03-13 11:48:00.969427+00', 'Vicky''s Jig', 'VICKYS JIG', 2, 32, 9999, 1, 3, 42, 854, NULL, 'This dance was devised for Vicky Bacon of Doncaster.', 56, '800/888/888/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9213, '2000-01-16 23:00:00+00', '2021-07-02 20:51:42.980138+00', 'Moonlight', 'MOONLIGHT', 3, 32, 9999, 1, 100, 2, 108, '1998-06-01', '', 81, '8888/8448/8888/0880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13390, '2009-11-08 23:00:00+00', '2018-04-03 00:08:19.396419+00', 'Sutherland Salute', 'SUTHERLAND SALUTE', 2, 32, NULL, 1, 3, 42, 2961, NULL, '»Devised by Bob McMurtry, Felton, California.



Dedication: To Nora Sutherland for her dedication handling the many needs of TACBooks.«

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9252, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.075969+00', 'Piping Draughtsman', 'PIPING DRAUGHTSMAN', 2, 32, 9999, 1, 2, NULL, 3586, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9253, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.082814+00', 'Scoone Circular', 'SCOONE CIRCULAR', 3, 32, 9999, 5, 2, NULL, 3585, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9256, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.103413+00', 'RSCDS 75th Anniversary 1998, The', 'RSCDS 75TH ANNIVERSARY 1998', 3, 32, 9999, 1, 4, NULL, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13826, '2011-08-05 22:00:00+00', '2018-04-24 04:14:05.235564+00', 'Grange Hall, The', 'GRANGE HALL', 2, 32, NULL, 1, 4, 1, 1113, NULL, 'This dance was devised as a simple teaching dance for reels of four to use in the Flying Ghillies

introductory classes.', 69, '8888/8000/8224/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18919, '2018-10-09 12:20:43.007526+00', '2018-10-09 12:20:43.007526+00', 'Top Cat', 'TOP CAT', 3, 32, NULL, 1, 3, NULL, 2766, '2010-05-01', 'This dance is for our cat, Harrington, who is definitely our top cat.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18982, '2018-10-17 12:27:27.972137+00', '2018-10-17 12:27:27.972137+00', 'Bill and Marjorie Hancock - in tandem', 'BILL AND MARJORIE HANCOCK  IN TANDEM', 3, 32, NULL, 1, 100, NULL, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9262, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.144833+00', 'Profound Statement, A', 'PROFOUND STATEMENT', 3, 32, 9999, 1, 4, NULL, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9263, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.15173+00', 'Poor Measure, A', 'POOR MEASURE', 2, 32, 9999, 1, 4, NULL, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19017, '2018-10-19 20:13:11.873711+00', '2018-10-20 17:30:09.850878+00', 'Leominster Medley, The', 'LEOMINSTER MEDLEY', 4, 64, 5, 1, 4, 22, 11737, NULL, '', 75, '8888/8080/0808/8888/8888/8080/0808/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18973, '2018-10-15 17:42:57.402633+00', '2018-10-25 21:51:06.982438+00', 'Reelsome, The', 'REELSOME', 1, 40, NULL, 1, 4, 1, 9998, NULL, '', -1, '8000/0800/0080/8880/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9269, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.193294+00', 'Champion Ringer, The', 'CHAMPION RINGER', 3, 40, 9999, 1, 4, NULL, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9284, '2000-01-16 23:00:00+00', '2019-01-20 07:27:30.296366+00', 'Orkney Islands, The', 'ORKNEY ISLANDS', 1, 40, 9999, 1, 3, 42, 684, '1999-01-01', '', 72, '888/080/444/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9272, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.214277+00', 'Let Me Have My Dreams', 'LET ME HAVE MY DREAMS', 3, 40, 9999, 1, 4, NULL, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15520, '2014-06-27 21:18:19.289605+00', '2019-01-23 18:22:26.635847+00', 'Reel for Emily, A', 'REEL FOR EMILY', 1, 32, NULL, 1, 4, 1, 10971, NULL, 'To celebrate the birthday of the deviser''s granddaughter, Emily Dugan.', 81, '8888/8888/8440/8448', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9275, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.234954+00', 'Old Blacksmith''s Shop, The', 'OLD BLACKSMITHS SHOP', 2, 32, 9999, 1, 4, NULL, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15493, '2014-06-27 21:01:43.169008+00', '2019-01-22 23:25:25.534825+00', 'Home from Japan', 'HOME FROM JAPAN', 3, 32, NULL, 2, 3, 17, 10971, NULL, 'Devised on a long flight home from Japan.', 67, '844/844/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9278, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.25557+00', 'Step into Summer, A', 'STEP INTO SUMMER', 4, 128, 2, 3, 5, NULL, 684, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9283, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.289851+00', 'Stepping Stones', 'STEPPING STONES', 1, 64, 9999, 4, 4, NULL, 684, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8583, '1998-01-13 23:00:00+00', '2019-02-25 17:10:31.409721+00', 'Twirl of the Kilt', 'TWIRL OF THE KILT', 3, 32, 9999, 1, 2, 76, 2018, '1997-01-01', '', 60, '88/88/44/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9285, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.303605+00', 'Triple Trouble', 'TRIPLE TROUBLE', 2, 32, 9999, 5, 56, NULL, 684, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9281, '2000-01-16 23:00:00+00', '2016-08-02 20:07:57.369985+00', 'Nicki''s Dance', 'NICKIS DANCE', 2, 32, 9999, 1, 4, NULL, 684, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9279, '2000-01-16 23:00:00+00', '2018-04-03 00:07:32.286773+00', 'Barbara''s Reel', 'BARBARAS REEL', 1, 40, 9999, 1, 3, 42, 684, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9267, '2000-01-16 23:00:00+00', '2018-04-03 00:07:35.768388+00', 'Brighten the Corner Where You Are', 'BRIGHTEN THE CORNER WHERE YOU ARE', 2, 32, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9264, '2000-01-16 23:00:00+00', '2018-04-03 00:07:39.748354+00', 'Craigdarroch Castle', 'CRAIGDARROCH CASTLE', 1, 40, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9271, '2000-01-16 23:00:00+00', '2018-04-03 00:07:40.515763+00', 'Curious Family Recipe, A', 'CURIOUS FAMILY RECIPE', 1, 32, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9266, '2000-01-16 23:00:00+00', '2018-04-03 00:07:44.894622+00', 'Extraordinary Project, An', 'EXTRAORDINARY PROJECT', 2, 32, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9255, '2000-01-16 23:00:00+00', '2018-04-03 00:07:45.244976+00', 'Farewell to the Forest', 'FAREWELL TO THE FOREST', 1, 32, 9999, 1, 3, 42, 3592, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9260, '2000-01-16 23:00:00+00', '2018-04-03 00:07:50.816938+00', 'Happy Social Event, A', 'HAPPY SOCIAL EVENT', 2, 32, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9257, '2000-01-16 23:00:00+00', '2018-04-03 00:07:52.259336+00', 'High Steppers', 'HIGH STEPPERS', 2, 32, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9258, '2000-01-16 23:00:00+00', '2018-04-03 00:07:53.608686+00', 'In the Melting Pot', 'IN THE MELTING POT', 1, 40, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9273, '2000-01-16 23:00:00+00', '2018-04-03 00:08:00.382277+00', 'Long and the Short of It, The', 'LONG AND THE SHORT OF IT', 2, 32, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9276, '2000-01-16 23:00:00+00', '2018-04-03 00:08:01.524779+00', 'Magic of the Clouds, The', 'MAGIC OF THE CLOUDS', 2, 32, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9268, '2000-01-16 23:00:00+00', '2018-04-03 00:08:07.120922+00', 'My Secret Drawer', 'MY SECRET DRAWER', 1, 32, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9274, '2000-01-16 23:00:00+00', '2018-04-03 00:08:08.48014+00', 'Old Autograph Book, An', 'OLD AUTOGRAPH BOOK', 2, 32, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9277, '2000-01-16 23:00:00+00', '2018-04-03 00:08:08.713573+00', 'On a Shaded Bench', 'ON A SHADED BENCH', 1, 32, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13395, '2009-11-08 23:00:00+00', '2018-04-03 00:08:17.761898+00', 'Source, The', 'SOURCE', 3, 32, NULL, 1, 3, 42, 361, NULL, '»Dedication::

  For years, Scottish country dancers in North America have relied upon TACSound and TACBooks

  as ›The Source‹ of recorded music, dance books, and dance leaflets. We are all indebted to the

  dedicated and hard-working TAC members who have run TACSound and TACBooks over the years

  as a service to us all.«

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9265, '2000-01-16 23:00:00+00', '2018-04-03 00:08:18.353932+00', 'Starry-Eyed', 'STARRYEYED', 3, 32, 9999, 1, 3, 42, 35, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9216, '2000-01-16 23:00:00+00', '2020-08-29 15:57:51.513553+00', 'Pink Panda, The', 'PINK PANDA', 1, 32, 9999, 1, 3, 42, 108, '1999-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9217, '2000-01-16 23:00:00+00', '2020-09-08 08:48:39.689537+00', 'Rising Sun, The', 'RISING SUN', 2, 40, 9999, 1, 3, 42, 108, '1998-01-01', '', 45, '800/844/844/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9240, '2000-01-16 23:00:00+00', '2020-09-08 16:45:22.162289+00', 'Swirling Waters', 'SWIRLING WATERS', 3, 32, 9999, 1, 3, 42, 108, '1997-01-01', '', 56, '844/844/880/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15553, '2014-07-27 13:41:15.115292+00', '2021-02-19 01:16:24.221904+00', 'Guid New Year, A', 'GUID NEW YEAR', 3, 32, NULL, 2, 3, 17, 2018, NULL, '', 71, '800/888/866/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13825, '2011-08-05 22:00:00+00', '2021-06-06 11:57:01.249771+00', 'Corn Chowder', 'CORN CHOWDER', 1, 32, NULL, 1, 3, 42, 1113, NULL, 'This dance was devised as a teaching dance for mirror reels of three.', 44, '800/888/800/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9254, '2000-01-16 23:00:00+00', '2018-04-03 00:08:26.918261+00', 'Worm Charmers', 'WORM CHARMERS', 1, 32, 9999, 1, 3, 42, 3590, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9280, '2000-01-16 23:00:00+00', '2019-03-05 20:08:00.658079+00', 'Darby''s Corner', 'DARBYS CORNER', 4, 64, 5, 1, 4, 1, 684, '1999-01-01', '', 86, '8282/0808/8888/8888/8888/8888/8484/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9305, '2000-01-16 23:00:00+00', '2018-04-03 00:07:29.983229+00', 'Alexander Graham Bell', 'ALEXANDER GRAHAM BELL', 1, 40, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9314, '2000-01-16 23:00:00+00', '2018-04-03 00:07:30.217275+00', 'All Scots, Ilka Ane O'' Them', 'ALL SCOTS ILKA ANE O THEM', 1, 40, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13404, '2009-11-10 23:00:00+00', '2012-01-20 12:57:46.307977+00', 'Jock''s Hill', 'JOCKS HILL', 2, 48, NULL, 4, 4, NULL, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13407, '2009-11-10 23:00:00+00', '2012-01-20 12:57:46.326127+00', 'Incey Wincey Dance, The', 'INCEY WINCEY DANCE', 2, 32, NULL, 6, 3, NULL, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13411, '2009-11-10 23:00:00+00', '2012-01-20 12:57:46.350416+00', 'Strathspey Shuffle, The', 'STRATHSPEY SHUFFLE', 3, 32, NULL, 1, 4, NULL, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13406, '2009-11-10 23:00:00+00', '2013-02-15 23:32:43.027717+00', 'Atlantic - Pacific Link, The', 'ATLANTIC  PACIFIC LINK', 1, 32, NULL, 1, 4, NULL, 3718, NULL, 'Iain Boyd writes in Strathspey message 63756, on 15 Feb 2013:  "The Vallin collections are not RSCDS publications so I would tend NOT to use RSCDS-speak, and assume that the reels of three are just what they are described as - ''tandem reels'' without the leading dancers swapping over. Unfortunately, John Morris died last year (I think) so there is no way that we can ask him."

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13425, '2009-11-10 23:00:00+00', '2018-04-03 00:07:31.679831+00', 'Autumn Gold', 'AUTUMN GOLD', 2, 32, NULL, 1, 3, 42, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9299, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.399892+00', 'Soft as Silk', 'SOFT AS SILK', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18923, '2018-10-09 13:32:57.204355+00', '2018-10-09 13:32:57.204355+00', 'Tunnel of Light', 'TUNNEL OF LIGHT', 3, 32, NULL, 1, 3, 42, 2766, '2011-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9301, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.413511+00', 'John Baird of Kirkintilloch', 'JOHN BAIRD OF KIRKINTILLOCH', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9302, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.420273+00', 'Daft Pate', 'DAFT PATE', 2, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18897, '2018-10-09 05:49:34.903068+00', '2018-10-09 13:43:39.829988+00', 'Square Knot, The', 'SQUARE KNOT', 3, 32, NULL, 4, 4, 1, 2766, '2008-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9304, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.433907+00', 'Who Has Had the Honour', 'WHO HAS HAD THE HONOUR', 2, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11448, '2003-09-22 22:00:00+00', '2018-10-09 13:56:10.656629+00', 'Twists and Turns', 'TWISTS AND TURNS', 1, 32, 9999, 1, 3, 42, 2766, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9309, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.467835+00', '10th Earl of Dundonald, The', '10TH EARL OF DUNDONALD', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9311, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.481405+00', 'Old Starry', 'OLD STARRY', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13413, '2009-11-10 23:00:00+00', '2012-01-20 12:57:46.362547+00', 'Keep those Feet Dancing', 'KEEP THOSE FEET DANCING', 2, 40, NULL, 3, 5, NULL, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13414, '2009-11-10 23:00:00+00', '2012-01-20 12:57:46.368631+00', 'Can You Repeat That', 'CAN YOU REPEAT THAT', 3, 40, NULL, 2, 3, NULL, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13415, '2009-11-10 23:00:00+00', '2012-01-20 12:57:46.37536+00', 'Grundy''s Delight', 'GRUNDYS DELIGHT', 1, 40, NULL, 1, 4, 2, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13416, '2009-11-10 23:00:00+00', '2012-01-20 12:57:46.381551+00', 'Happy Feet', 'HAPPY FEET', 2, 32, NULL, 1, 4, NULL, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13417, '2009-11-10 23:00:00+00', '2012-01-20 12:57:46.387581+00', 'East of York', 'EAST OF YORK', 3, 40, NULL, 3, 5, NULL, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13418, '2009-11-10 23:00:00+00', '2012-01-20 12:57:46.393623+00', 'Another Anniversary Reel', 'ANOTHER ANNIVERSARY REEL', 1, 32, NULL, 3, 5, NULL, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13423, '2009-11-10 23:00:00+00', '2012-01-20 12:57:46.423937+00', 'Monster in the Lake', 'MONSTER IN THE LAKE', 3, 40, NULL, 3, 5, NULL, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13426, '2009-11-10 23:00:00+00', '2012-01-20 12:57:46.443646+00', 'Stepping Hill', 'STEPPING HILL', 4, 160, 10, 4, 4, NULL, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9316, '2000-01-16 23:00:00+00', '2018-04-03 00:07:33.607747+00', 'Black Friars'' Bridge, The', 'BLACK FRIARS BRIDGE', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9318, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.529367+00', 'James Bowman Lindsay', 'JAMES BOWMAN LINDSAY', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9319, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.536875+00', 'Noble Progression', 'NOBLE PROGRESSION', 4, 64, 22, 1, 4, 1, 3590, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13421, '2009-11-10 23:00:00+00', '2018-04-03 00:07:39.373038+00', 'Copacabana Caper', 'COPACABANA CAPER', 1, 32, NULL, 1, 3, 42, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13408, '2009-11-10 23:00:00+00', '2017-02-08 13:55:19.240881+00', 'If at First ... Strathspey', 'IF AT FIRST  STRATHSPEY', 3, 32, NULL, 4, 4, NULL, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9310, '2000-01-16 23:00:00+00', '2018-04-03 00:07:40.532311+00', 'Curling Stones', 'CURLING STONES', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9303, '2000-01-16 23:00:00+00', '2018-04-03 00:07:41.925493+00', 'Devil on Wheels, The', 'DEVIL ON WHEELS', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9312, '2000-01-16 23:00:00+00', '2018-04-03 00:07:42.542711+00', 'Doodle-Sack, The', 'DOODLESACK', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9300, '2000-01-16 23:00:00+00', '2018-04-03 00:07:48.41463+00', 'Glasgow Weavers, The', 'GLASGOW WEAVERS', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13420, '2009-11-10 23:00:00+00', '2018-04-03 00:07:53.743977+00', 'In Yonder Glen', 'IN YONDER GLEN', 3, 32, NULL, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13422, '2009-11-10 23:00:00+00', '2018-04-03 00:07:53.819022+00', 'Irish Influence, The', 'IRISH INFLUENCE', 2, 40, NULL, 1, 3, 42, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9315, '2000-01-16 23:00:00+00', '2018-04-03 00:07:54.869726+00', 'James Watt of Greenock', 'JAMES WATT OF GREENOCK', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9308, '2000-01-16 23:00:00+00', '2018-04-03 00:07:55.019747+00', 'J. B. Dunlop', 'J B DUNLOP', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13410, '2009-11-10 23:00:00+00', '2018-04-03 00:08:04.702074+00', 'Miss Marshall of Melbourne', 'MISS MARSHALL OF MELBOURNE', 2, 32, NULL, 1, 3, 42, 3698, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9306, '2000-01-16 23:00:00+00', '2018-04-03 00:08:10.298055+00', 'Penny Black Stamp, The', 'PENNY BLACK STAMP', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13412, '2009-11-10 23:00:00+00', '2018-04-03 00:08:10.539983+00', 'Philip Islanders'' Dash, The', 'PHILIP ISLANDERS DASH', 1, 32, NULL, 1, 3, 42, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13409, '2009-11-10 23:00:00+00', '2018-04-03 00:08:10.890388+00', 'Pittsburgh Twister, The', 'PITTSBURGH TWISTER', 1, 40, NULL, 1, 3, 42, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13456, '2009-11-17 23:00:00+00', '2020-09-17 22:25:48.999588+00', 'Silver Walk, The', 'SILVER WALK', 3, 64, NULL, 4, 4, 30, 10408, NULL, '', 80, '6666/6666/4444/4444/7777/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9313, '2000-01-16 23:00:00+00', '2018-04-03 00:08:15.243431+00', 'Scot Named MacAdam, A', 'SCOT NAMED MACADAM', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9556, '2000-07-26 22:00:00+00', '2012-01-20 12:57:14.426526+00', 'Tenaby', 'TENABY', 2, 32, 9999, 1, 2, NULL, 214, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9307, '2000-01-16 23:00:00+00', '2018-04-03 00:08:18.237355+00', 'Squiggly Dance, The', 'SQUIGGLY DANCE', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9298, '2000-01-16 23:00:00+00', '2018-04-03 00:08:23.465618+00', 'Ups and Downs', 'UPS AND DOWNS', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9321, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.551345+00', 'Claire''s Carousel', 'CLAIRES CAROUSEL', 1, 32, 9999, 7, 3, NULL, 3586, '1997-01-01', 'For sets of 3, 4 or 5 couples', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9324, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.572693+00', 'Land of the Long White Cloud', 'LAND OF THE LONG WHITE CLOUD', 1, 48, 9999, 3, 5, 16, 3586, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9327, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.593404+00', 'Scottish Widdows', 'SCOTTISH WIDDOWS', 3, 32, 9999, 1, 2, NULL, 3590, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9328, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.600187+00', 'Skate in Black Butter', 'SKATE IN BLACK BUTTER', 4, 64, 5, 4, 4, NULL, 3590, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9329, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.607043+00', 'Wind a Bonnie Pirn', 'WIND A BONNIE PIRN', 1, 40, 9999, 1, 4, NULL, 3591, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9330, '2000-01-16 23:00:00+00', '2012-01-20 12:57:12.613955+00', 'Wedding Ring', 'WEDDING RING', 1, 32, 9999, 4, 5, NULL, 3591, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12142, '2005-04-11 22:00:00+00', '2018-10-01 17:00:44.126895+00', 'Back to the Barn', 'BACK TO THE BARN', 1, 32, 9999, 3, 5, 40, 2766, '2005-02-01', 'This dance celebrates the return of the Silk & Thistle class to dancing at the Fermilab Barn.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11827, '2004-10-31 23:00:00+00', '2019-06-09 18:48:36.766232+00', 'Silver Link, The', 'SILVER LINK', 3, 32, 9999, 3, 5, 33, 2677, '2004-01-01', '2018-08-14:  The former link http://home.roadrunner.com/~glasshall/SilverLink.html appears to be dead.', 60, '88888/80008/84848/00800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9335, '2001-05-03 22:00:00+00', '2012-01-20 12:57:12.64945+00', 'To Louise', 'TO LOUISE', 3, 40, 9999, 1, 2, NULL, 2688, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9342, '2000-02-25 23:00:00+00', '2012-01-20 12:57:12.695565+00', 'Tantallon Castle', 'TANTALLON CASTLE', 4, 80, 50, 4, 4, NULL, 563, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9322, '2000-01-16 23:00:00+00', '2018-04-03 00:07:39.030868+00', 'Cod Piece', 'COD PIECE', 1, 32, 9999, 1, 3, 42, 3590, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13431, '2009-11-15 23:00:00+00', '2012-01-20 12:57:46.466415+00', 'Inverness Highland Ball', 'INVERNESS HIGHLAND BALL', 4, 64, 5, 1, 3, 42, 2419, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9323, '2000-01-16 23:00:00+00', '2018-04-03 00:07:54.5945+00', 'It''s Fun to be Fifty', 'ITS FUN TO BE FIFTY', 2, 40, 9999, 1, 3, 42, 3586, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13438, '2009-11-16 23:00:00+00', '2012-10-02 22:34:15.835211+00', 'Fireworks', 'FIREWORKS', 2, 40, NULL, 1, 3, 42, 10326, NULL, 'Published in the Diamond Jubilee Collection of the RSCDS Inverness and District Branch: http://my.strathspey.org/dd/publ/1027/', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9344, '2000-02-26 23:00:00+00', '2012-01-20 12:57:12.712306+00', 'Welcome to Pawling', 'WELCOME TO PAWLING', 1, 32, 9999, 1, 4, NULL, 101, '1970-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9346, '2000-02-26 23:00:00+00', '2012-01-20 12:57:12.719326+00', 'Andover Lass and Her Lad, The', 'ANDOVER LASS AND HER LAD', 1, 32, 9999, 1, 4, NULL, 101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9347, '2000-02-26 23:00:00+00', '2012-01-20 12:57:12.726123+00', 'Milton''s Jig', 'MILTONS JIG', 2, 48, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9348, '2000-02-26 23:00:00+00', '2012-01-20 12:57:12.732897+00', 'Ann Elizabeth''s Strathspey', 'ANN ELIZABETHS STRATHSPEY', 3, 40, 9999, 99, 3, NULL, 657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9349, '2000-02-26 23:00:00+00', '2012-01-20 12:57:12.73969+00', 'Tay Bridge, The', 'TAY BRIDGE', 1, 48, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9356, '2001-05-03 22:00:00+00', '2012-01-20 12:57:12.789081+00', 'Brisbane Flourish', 'BRISBANE FLOURISH', 3, 48, 9999, 1, 4, NULL, 448, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9357, '2000-03-15 23:00:00+00', '2012-01-20 12:57:12.795936+00', 'Clan MacKenzie', 'CLAN MACKENZIE', 3, 48, 9999, 1, 4, NULL, 448, '1985-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9359, '2000-03-15 23:00:00+00', '2012-01-20 12:57:12.809724+00', 'Examination, The', 'EXAMINATION', 3, 96, 9999, 1, 4, NULL, 448, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9360, '2000-03-15 23:00:00+00', '2012-01-20 12:57:12.816586+00', 'Dancing Pump, The', 'DANCING PUMP', 1, 32, 9999, 1, 4, NULL, 448, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9361, '2000-03-15 23:00:00+00', '2012-01-20 12:57:12.823451+00', 'Weave, The', 'WEAVE', 1, 48, 9999, 8, 6, NULL, 448, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9362, '2000-03-15 23:00:00+00', '2012-01-20 12:57:12.830294+00', 'Plain and Simple', 'PLAIN AND SIMPLE', 1, 24, 9999, 1, 4, NULL, 448, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9364, '2001-05-03 22:00:00+00', '2012-01-20 12:57:12.844072+00', 'From Me to You', 'FROM ME TO YOU', 2, 40, 9999, 4, 4, NULL, 448, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9370, '2000-04-03 22:00:00+00', '2012-01-20 12:57:12.888436+00', 'Crazy Crossing', 'CRAZY CROSSING', 2, 32, 9999, 1, 4, 1, 2709, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13435, '2009-11-15 23:00:00+00', '2015-01-07 13:40:57.545621+00', 'Helen & Barclay Walker''s Reel', 'HELEN AND BARCLAY WALKERS REEL', 1, 40, 9999, 1, 4, 1, 2419, '2008-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13434, '2009-11-15 23:00:00+00', '2015-01-07 13:47:18.52526+00', 'Reel for Anne Chesterman of Cambuskenneth, A', 'REEL FOR ANNE CHESTERMAN OF CAMBUSKENNETH', 1, 40, 9999, 1, 4, 1, 2419, '2008-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13432, '2009-11-15 23:00:00+00', '2016-07-15 14:31:47.629698+00', 'Up the Ben wi'' Eddie', 'UP THE BEN WI EDDIE', 2, 32, NULL, 1, 4, 1, 2419, '2005-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9297, '2000-01-16 23:00:00+00', '2020-09-08 17:10:33.590359+00', 'Tin Woodman, The', 'TIN WOODMAN', 3, 32, 9999, 1, 3, 42, 501, '1982-01-01', '', 50, '800/866/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9353, '2000-03-12 23:00:00+00', '2020-12-05 20:39:31.874868+00', 'Charlie''s Silver Jubilee', 'CHARLIES SILVER JUBILEE', 3, 32, 9999, 1, 4, 1, 2703, NULL, '', 81, '8044/8888/8888/4488', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13439, '2009-11-16 23:00:00+00', '2021-01-02 13:42:35.542712+00', 'Royal Scot, Northward Bound, The', 'ROYAL SCOT NORTHWARD BOUND', 1, 48, 9999, 1, 4, 1, 2419, '2008-05-01', '', 62, '8888/8220/8220/8080/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9326, '2000-01-16 23:00:00+00', '2021-01-05 19:06:09.782797+00', 'Miss Amy Louise', 'MISS AMY LOUISE', 3, 32, 9999, 1, 3, 42, 3586, '1997-05-13', 'Written for the birth of Pam Perkins'' first grandaughter on 13th May 1997.', 66, '880/866/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9371, '2000-04-03 22:00:00+00', '2021-02-25 16:07:06.479603+00', 'Detasseling the Riggs of Corn', 'DETASSELING THE RIGGS OF CORN', 1, 32, 9999, 1, 2, 76, 2710, '1997-01-01', '', 56, '80/84/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9367, '2000-04-03 22:00:00+00', '2021-02-25 16:09:30.701302+00', 'Beyond Ambivalence', 'BEYOND AMBIVALENCE', 1, 40, 9999, 1, 3, 42, 2707, '1999-01-01', '', 52, '808/800/888/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9365, '2000-03-18 23:00:00+00', '2021-02-25 18:53:14.466713+00', 'Kirrie Lads, The', 'KIRRIE LADS', 2, 32, 9999, 1, 4, 1, 2705, '1998-01-01', '', 81, '8484/8888/8808/4848', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9331, '2002-10-15 22:00:00+00', '2021-02-26 13:32:26.980619+00', 'Reel for George, A', 'REEL FOR GEORGE', 1, 32, 9999, 1, 3, 42, 197, NULL, '', 63, '880/888/808/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9325, '2000-01-16 23:00:00+00', '2021-06-06 13:12:14.127618+00', 'New Forest Show', 'NEW FOREST SHOW', 1, 64, 9999, 107, 6, NULL, 3586, '1994-01-01', 'Written for The New Forest Show 1994. Danced in two parallel three couple sets which intermingle.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13428, '2009-11-15 23:00:00+00', '2018-04-03 00:08:26.70037+00', 'Wishworthy', 'WISHWORTHY', 3, 32, NULL, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13445, '2009-11-16 23:00:00+00', '2013-01-20 14:39:50.98221+00', 'Up and Down Ben Nevis', 'UP AND DOWN BEN NEVIS', 3, 32, 9999, 2, 3, 17, 10328, NULL, 'Published in the Diamond Jubilee Collection of the RSCDS Inverness and District Branch: http://my.strathspey.org/dd/publ/1027/', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9374, '2000-04-03 22:00:00+00', '2012-01-20 12:57:12.918462+00', 'McClure Family Burns Supper, The', 'MACCLURE FAMILY BURNS SUPPER', 1, 32, 9999, 1, 2, NULL, 1268, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9375, '2000-04-03 22:00:00+00', '2012-01-20 12:57:12.926131+00', 'McIntosh Legs, The', 'MACINTOSH LEGS', 1, 40, 9999, 1, 4, 1, 2713, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9363, '2000-03-15 23:00:00+00', '2022-06-01 16:27:48.490988+00', 'Trip to South Australia', 'TRIP TO SOUTH AUSTRALIA', 2, 40, 9999, 3, 5, 16, 448, '1987-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9368, '2000-04-03 22:00:00+00', '2022-08-13 17:25:35.322068+00', 'Chang O''Hara''s Reel', 'CHANG OHARAS REEL', 1, 32, 9999, 1, 4, 11, 2408, '1999-01-01', 'Devised while sitting in Chang O''Hara''s restaurant in St. Paul after dance class.', 81, '8008/8888/8888/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9369, '2002-03-02 23:00:00+00', '2022-08-20 19:47:03.084514+00', 'Child''s Play', 'CHILDS PLAY', 2, 40, 9999, 2, 3, 18, 2708, '1999-01-01', '', 80, '800/880/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9358, '2000-03-15 23:00:00+00', '2022-09-13 13:04:27.996003+00', 'Cleveland Country Dance', 'CLEVELAND COUNTRY DANCE', 3, 48, 9999, 1, 4, 1, 448, '1984-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9377, '2000-04-03 22:00:00+00', '2012-01-20 12:57:12.943218+00', 'Serendipity', 'SERENDIPITY', 3, 32, 9999, 1, 2, NULL, 2408, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9378, '2000-04-03 22:00:00+00', '2012-01-20 12:57:12.950836+00', 'Tapestry, The', 'TAPESTRY', 4, 96, 9999, 1, 4, 11, 2408, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9379, '2000-04-03 22:00:00+00', '2012-01-20 12:57:12.957719+00', 'Untitled #109', 'UNTITLED 109', 3, 32, 9999, 1, 4, NULL, 2714, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9383, '2000-04-22 22:00:00+00', '2012-01-20 12:57:12.985109+00', 'Wollondilly White Waratah', 'WOLLONDILLY WHITE WARATAH', 2, 32, 9999, 1, 4, NULL, 2752, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18681, '2018-10-01 17:05:38.713105+00', '2018-10-01 17:05:38.713105+00', 'Backtrack', 'BACKTRACK', 1, 32, NULL, 1, 3, 42, 2766, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9405, '2000-04-18 22:00:00+00', '2019-02-22 18:29:29.909177+00', 'Simmer Dim, The', 'SIMMER DIM', 2, 32, 9999, 1, 4, 1, 276, '2000-01-01', '', 56, '4444/4444/8888/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13451, '2009-11-17 23:00:00+00', '2012-01-20 12:57:46.601644+00', 'Okinawa Reunion', 'OKINAWA REUNION', 5, 0, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (41, '1997-08-31 22:00:00+00', '2014-04-30 23:23:37.194458+00', 'Adieu, The', 'ADIEU', 1, 32, 9999, 1, 3, 42, 466, NULL, 'Note in the Whetherly Book 24:  From Thompson''s Compleat Collection Vol. 4.  Originally the first couple danced down the mlddle and back to second place. On the last eight bars the first couple danced a right hand

allemande (i.e. they made a complete turn after which the lady turned under their raised right arms) followed by a left hand allemande. The instructions have been adapted to modern technique', 56, '888  800  888  880', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (9409, '2000-04-22 22:00:00+00', '2012-01-20 12:57:13.169213+00', 'Caprice, The', 'CAPRICE', 2, 32, 9999, 1, 4, 4, 2746, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9410, '2000-04-22 22:00:00+00', '2012-01-20 12:57:13.176699+00', 'Coss Keys, The', 'COSS KEYS', 2, 32, 9999, 1, 4, 2, 2747, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9411, '2000-04-22 22:00:00+00', '2012-01-20 12:57:13.183508+00', 'Dersingham Bog', 'DERSINGHAM BOG', 2, 48, 9999, 4, 4, NULL, 2746, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9412, '2000-04-22 22:00:00+00', '2012-01-20 12:57:13.190504+00', 'Galloping Granny, The', 'GALLOPING GRANNY', 1, 32, 9999, 1, 4, NULL, 2748, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9414, '2001-05-21 22:00:00+00', '2012-01-20 12:57:13.205081+00', 'Peterborough Ten, The', 'PETERBOROUGH TEN', 1, 48, 9999, 3, 5, 21, 2749, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9415, '2000-04-22 22:00:00+00', '2012-01-20 12:57:13.211909+00', 'Snow on Snow', 'SNOW ON SNOW', 3, 32, 9999, 1, 4, NULL, 2750, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9416, '2000-04-22 22:00:00+00', '2012-01-20 12:57:13.218705+00', 'Ladies of Wroxham, The', 'LADIES OF WROXHAM', 1, 32, 9999, 1, 2, NULL, 2751, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9429, '2000-05-17 22:00:00+00', '2012-01-20 12:57:13.326658+00', 'Evenstar', 'EVENSTAR', 4, 128, 2, 4, 4, NULL, 2203, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9430, '2002-04-25 22:00:00+00', '2012-01-20 12:57:13.333542+00', 'Galadriel''s Mirror', 'GALADRIELS MIRROR', 3, 128, 9999, 4, 4, NULL, 2203, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9392, '2000-04-18 22:00:00+00', '2016-06-13 14:01:16.107111+00', 'Alve Silver Glen', 'ALVE SILVER GLEN', 3, 32, 9999, 6, 3, 18, 2739, '2000-01-01', 'Special triangular set, the W stand BtotB in the centre, facing their partner.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9394, '2000-04-18 22:00:00+00', '2016-06-13 14:16:29.652159+00', 'Crofthead', 'CROFTHEAD', 2, 32, 9999, 1, 4, 1, 2739, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9395, '2000-04-18 22:00:00+00', '2016-06-13 14:17:03.310236+00', 'Cruachan', 'CRUACHAN', 3, 32, 9999, 1, 4, 1, 2739, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9396, '2000-04-18 22:00:00+00', '2016-06-13 14:19:06.775526+00', 'Dollar Glen', 'DOLLAR GLEN', 3, 32, 9999, 4, 5, 48, 2739, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9393, '2000-04-18 22:00:00+00', '2016-06-13 14:20:16.328288+00', 'Castle Campbell', 'CASTLE CAMPBELL', 2, 64, 9999, 4, 4, 1, 2739, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9397, '2000-04-18 22:00:00+00', '2016-06-13 14:21:16.576871+00', 'Moffat Strathspey', 'MOFFAT STRATHSPEY', 3, 32, 9999, 1, 4, 1, 2739, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9398, '2000-04-18 22:00:00+00', '2016-06-13 14:22:56.996757+00', 'Ochil Chase', 'OCHIL CHASE', 1, 40, 9999, 2, 3, 17, 2739, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9399, '2000-04-18 22:00:00+00', '2016-06-13 14:23:27.014184+00', 'Penycae Strathspey', 'PENYCAE STRATHSPEY', 3, 32, 9999, 2, 3, 18, 2739, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9400, '2000-04-18 22:00:00+00', '2016-06-13 14:34:23.501629+00', 'Tillicoultry Burn', 'TILLICOULTRY BURN', 1, 32, 9999, 1, 3, 42, 2739, '2000-01-01', 'The original description says this is a 8 x 32 reel for 4 couples in a longwise set, but omits to mention that (as is evident from "8x") only 3 couples are actually dancing.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9402, '2000-04-18 22:00:00+00', '2016-06-13 14:35:25.931653+00', 'Swansea Jubilee', 'SWANSEA JUBILEE', 2, 40, 9999, 3, 5, 41, 2740, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9413, '2000-04-22 22:00:00+00', '2016-09-17 21:44:32.039471+00', 'New Town, The', 'NEW TOWN', 3, 32, 9999, 1, 3, 42, 108, '1968-01-01', '', 55, '880/808/806/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13478, '2009-11-20 23:00:00+00', '2018-04-02 23:56:36.545856+00', 'Mrs Takano''s Spirits', 'MRS TAKANOS SPIRITS', 1, 32, 9999, 1, 3, 42, 3783, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13444, '2009-11-16 23:00:00+00', '2020-09-17 08:39:27.834503+00', 'Mrs Lilian Meiklejohn', 'MRS LILIAN MEIKLEJOHN', 1, 32, 9999, 1, 3, 42, 2893, NULL, 'Published in the Diamond Jubilee Collection of the RSCDS Inverness and District Branch: http://my.strathspey.org/dd/publ/1027/', 47, '800/822/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13453, '2009-11-17 23:00:00+00', '2020-09-17 22:05:56.88049+00', 'Stanley Mill, The', 'STANLEY MILL', 1, 40, NULL, 1, 4, 1, 10406, NULL, '', 85, '8888/8888/8888/8888/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13455, '2009-11-17 23:00:00+00', '2020-09-17 22:20:49.996674+00', 'Two Inch Race, The', 'TWO INCH RACE', 1, 32, NULL, 3, 5, 16, 146, NULL, '', 45, '84000/84444/84444/80004', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13443, '2009-11-16 23:00:00+00', '2021-01-02 13:22:05.465196+00', 'Diamond Anniversary, The', 'DIAMOND ANNIVERSARY', 2, 32, 9999, 1, 3, 42, 10323, NULL, 'Published in the Diamond Jubilee Collection of the RSCDS Inverness and District Branch: http://my.strathspey.org/dd/publ/1027/', 47, '800/822/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9404, '2000-04-18 22:00:00+00', '2021-02-24 19:44:26.303766+00', 'Dervaig Ladies Jig, The', 'DERVAIG LADIES JIG', 2, 32, 9999, 1, 3, 42, 276, '2000-01-01', '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9384, '2000-04-09 22:00:00+00', '2021-02-25 16:04:01.052158+00', 'Stoner House', 'STONER HOUSE', 2, 32, 9999, 1, 4, 2, 2718, '1997-01-01', '', 88, '8448/8888/8888/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9422, '2002-09-22 22:00:00+00', '2021-07-30 06:10:26.625903+00', 'Barton Barbecue', 'BARTON BARBECUE', 1, 32, 9999, 1, 4, 1, 308, '1994-07-01', 'Note that the turn [13-16] is RH 1 1/2; some erroneous cribs circulate that specify LH.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13832, '2011-08-05 22:00:00+00', '2018-04-26 22:49:04.490763+00', 'Reel To Hopalots, A', 'REEL TO HOPALOTS', 1, 40, NULL, 3, 5, NULL, 10293, '2011-02-14', 'The dance can be danced with five couples or with three couples in a three- or four-couple longwise set.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9433, '2000-05-17 22:00:00+00', '2012-01-20 12:57:13.354228+00', 'River Woman''s Daughter, The', 'RIVER WOMANS DAUGHTER', 3, 32, 9999, 1, 4, NULL, 2203, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9434, '2000-05-17 22:00:00+00', '2012-01-20 12:57:13.361141+00', 'Rosie Cotton', 'ROSIE COTTON', 1, 32, 9999, 3, 5, NULL, 2203, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13462, '2009-11-17 23:00:00+00', '2014-11-09 00:44:49.619635+00', 'Time to Meet', 'TIME TO MEET', 1, 32, NULL, 1, 4, 1, 146, NULL, '', 56, '8080/0808/8000/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18536, '2018-08-27 20:21:41.467761+00', '2018-08-30 11:28:11.210089+00', 'Golden Castle Of Gifu, The', 'GOLDEN CASTLE OF GIFU', 1, 32, NULL, 2, 3, 18, 2887, '2017-09-01', 'Deviser''s note:  Although written and demonstrated as a 3x 32 Reel, it could be danced 8 times

through in a 4 couple set, the progression may seem strange but it works fine. ', 71, '800/888/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13464, '2009-11-17 23:00:00+00', '2019-01-31 21:31:09.865384+00', 'Mountain Stream, The', 'MOUNTAIN STREAM', 1, 32, NULL, 1, 2, NULL, 146, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9428, '2000-05-17 22:00:00+00', '2022-04-28 09:09:49.65998+00', 'Entwives, The', 'ENTWIVES', 3, 32, 9999, 3, 5, NULL, 2203, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9426, '2000-05-17 22:00:00+00', '2023-02-18 12:08:21.203715+00', 'Around the Party Tree', 'AROUND THE PARTY TREE', 2, 40, 9999, 7, 1, 4, 2203, '1999-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9440, '2002-08-29 22:00:00+00', '2022-08-01 21:13:07.055061+00', 'Chase 1', 'CHASE 1', 1, 32, 9999, 1, 2, 76, 558, '1994-01-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9431, '2000-05-17 22:00:00+00', '2019-04-22 11:25:56.281396+00', 'Green Dragon, The', 'GREEN DRAGON', 1, 32, 9999, 1, 3, 42, 2203, '1999-01-01', '', 56, '880/888/880/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9437, '2002-04-23 22:00:00+00', '2019-06-07 12:12:59.095527+00', 'Rudi''s Fault', 'RUDIS FAULT', 2, 24, 9999, 1, 2, NULL, 558, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9457, '2001-11-25 23:00:00+00', '2018-04-03 00:07:35.926918+00', 'Broomhill', 'BROOMHILL', 1, 32, 9999, 1, 3, 42, 108, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9445, '2002-07-21 22:00:00+00', '2018-04-03 00:07:38.054727+00', 'Charly''s Run', 'CHARLYS RUN', 3, 32, 9999, 1, 3, 42, 558, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9436, '2002-04-23 22:00:00+00', '2019-06-07 12:13:34.4972+00', 'Weeping Willow, The', 'WEEPING WILLOW', 2, 32, 9999, 1, 3, 42, 558, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9439, '2002-08-29 22:00:00+00', '2019-06-07 12:14:16.410681+00', 'Twinkling Star, The', 'TWINKLING STAR', 1, 24, 9999, 1, 3, 42, 558, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13482, '2009-11-20 23:00:00+00', '2012-01-20 12:57:46.766771+00', 'Breeze Bay', 'BREEZE BAY', 2, 32, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9464, '2000-05-21 22:00:00+00', '2012-01-20 12:57:13.601205+00', 'Four Million', 'FOUR MILLION', 3, 144, 9999, 4, 4, NULL, 108, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9471, '2000-05-21 22:00:00+00', '2012-01-20 12:57:13.65051+00', 'Dreams of the Orient', 'DREAMS OF THE ORIENT', 3, 32, 9999, 1, 4, NULL, 108, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13480, '2009-11-20 23:00:00+00', '2015-02-13 15:38:07.925012+00', 'Dashing Wild Hatchan, The', 'DASHING WILD HATCHAN', 1, 32, 9999, 5, 56, 30, 3783, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13481, '2009-11-20 23:00:00+00', '2015-02-13 16:17:27.184572+00', 'Great Little Lady, The', 'GREAT LITTLE LADY', 3, 40, 9999, 2, 3, 18, 3783, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13475, '2009-11-20 23:00:00+00', '2015-02-14 13:14:41.405483+00', 'Northern Connections', 'NORTHERN CONNECTIONS', 3, 32, 9999, 1, 4, 1, 3783, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9465, '2002-01-06 23:00:00+00', '2015-08-31 22:42:59.450554+00', 'Gibson''s Gallop', 'GIBSONS GALLOP', 1, 32, 9999, 5, 1, 4, 108, '1999-01-01', '', 75, '88/08/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13831, '2011-08-05 22:00:00+00', '2015-09-18 20:07:31.599925+00', 'Wright Reel, The', 'WRIGHT REEL', 1, 32, NULL, 1, 2, NULL, 3371, '2011-09-01', 'A 32 Bar Reel or Strathspey for 2 couples in a four-couple longwise set.



This dance was devised for the Wright State University Rec-Fit Scottish Country Dance class,

September 2010.', 52, '88/80/80/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9450, '2002-07-21 22:00:00+00', '2017-06-07 00:06:48.487909+00', 'Charlie''s Welcome', 'CHARLIES WELCOME', 3, 32, 9999, 2, 3, 17, 2765, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9449, '2002-07-21 22:00:00+00', '2017-09-25 23:45:42.786903+00', 'None So Tricky', 'NONE SO TRICKY', 3, 32, 9999, 1, 2, NULL, 2765, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9452, '2002-07-21 22:00:00+00', '2017-09-25 23:48:54.345909+00', 'Thursday Afternoon', 'THURSDAY AFTERNOON', 2, 32, 9999, 2, 3, 17, 2765, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9448, '2002-07-21 22:00:00+00', '2017-09-26 00:21:44.305309+00', 'Crans and Huckles', 'CRANS AND HUCKLES', 3, 32, 9999, 1, 4, 2, 2765, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9432, '2000-05-17 22:00:00+00', '2018-04-03 00:07:58.405637+00', 'Lady of Lothlorien, The', 'LADY OF LOTHLORIEN', 1, 40, 9999, 1, 3, 42, 2203, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9444, '2002-04-23 22:00:00+00', '2018-04-03 00:08:19.571698+00', 'Swirling Waters', 'SWIRLING WATERS', 2, 32, 9999, 1, 3, 42, 558, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9485, '2000-09-04 22:00:00+00', '2018-10-06 10:15:00.304079+00', 'Mary Helen''s Big Day', 'MARY HELENS BIG DAY', 1, 32, 9999, 1, 3, 42, 2766, '1999-08-01', 'This dance is a celebration of Mary Helen''s special birthday 8/30/99.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9491, '2000-09-04 22:00:00+00', '2018-10-01 16:56:49.205406+00', 'Wee Dif-fugue-ilty, A', 'WEE DIFFUGUEILTY', 1, 32, 9999, 1, 4, 8, 2766, '1999-11-01', 'This dance was written in an attempt to write a fugue-al dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9458, '2001-11-25 23:00:00+00', '2020-09-08 22:44:34.251338+00', 'Browned Off', 'BROWNED OFF', 1, 32, 9999, 5, 2, 76, 108, '1998-01-01', '', 75, '88/44/44/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9460, '2001-11-25 23:00:00+00', '2020-09-08 22:51:04.173232+00', 'Copycat Suite - Fantasia', 'COPYCAT SUITE  FANTASIA', 3, 32, 9999, 1, 3, 42, 108, '2000-01-01', '', 58, '864/888/880/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9461, '2002-04-28 22:00:00+00', '2020-09-08 22:54:30.951912+00', 'Copycat Suite - Fugue', 'COPYCAT SUITE  FUGUE', 2, 32, 9999, 1, 3, 42, 108, '2000-01-01', '', 64, '864/888/882/886', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9446, '2002-05-03 22:00:00+00', '2021-01-05 15:46:56.296429+00', 'Tribute to John Drewry', 'TRIBUTE TO JOHN DREWRY', 2, 32, 9999, 1, 3, 42, 558, NULL, '', 47, '800/844/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9783, '2001-03-13 23:00:00+00', '2021-02-20 20:20:51.58359+00', 'Redwood Empire Strathspey', 'REDWOOD EMPIRE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 401, '1999-01-01', '', 56, '880/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9467, '2002-03-11 23:00:00+00', '2021-02-23 20:50:52.324313+00', 'Jag''s Jig', 'JAGS JIG', 2, 32, 9999, 1, 3, 42, 108, '1999-01-01', '', 50, '808/808/880/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9466, '2002-01-06 23:00:00+00', '2021-02-24 09:23:46.340206+00', 'Haggis Thrash, The', 'HAGGIS THRASH', 1, 32, 9999, 1, 2, 76, 108, '1998-01-01', '', 60, '80/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9456, '2002-03-02 23:00:00+00', '2021-02-24 10:06:12.763532+00', 'Breathalyser, The', 'BREATHALYSER', 2, 32, 9999, 1, 3, 42, 108, '1999-01-01', '', 56, '844/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9453, '2001-11-25 23:00:00+00', '2021-02-24 17:17:30.183706+00', 'As the Crow Flies', 'AS THE CROW FLIES', 1, 32, 9999, 1, 3, 42, 108, '1998-09-01', 'For Ken Crowe of Yarrow B.C.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9454, '2002-02-28 23:00:00+00', '2021-02-24 11:20:19.836997+00', 'Bound and Gagged', 'BOUND AND GAGGED', 1, 32, 9999, 1, 3, 42, 108, '1998-10-01', 'Described as a "dance which is bound to leave you speechless."', 50, '844/888/822/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9451, '2002-07-21 22:00:00+00', '2021-02-24 17:20:48.102843+00', '27th of December', '27TH OF DECEMBER', 3, 32, 9999, 1, 3, 42, 2765, '1998-01-01', '', 59, '844/888/844/884', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9447, '2002-07-21 22:00:00+00', '2021-02-24 17:59:31.631195+00', 'After Hours', 'AFTER HOURS', 1, 32, 9999, 1, 2, 76, 2765, '1998-01-01', '', 64, '88/84/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9403, '2002-02-12 23:00:00+00', '2021-02-24 19:47:53.679455+00', 'Shetland Welcome, A', 'SHETLAND WELCOME', 2, 32, 9999, 1, 100, 2, 276, '2000-01-01', '"Devised for the Voe class in Shetland where I was invited to take week-end classes in 1996 & 1997."', 81, '8008/8888/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9435, '2000-05-17 22:00:00+00', '2021-06-08 21:04:08.5759+00', 'Shieldmaiden of the Rohirrim, A', 'SHIELDMAIDEN OF THE ROHIRRIM', 2, 32, 9999, 1, 3, 42, 2203, '1999-01-01', '', 63, '866/844/888/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9421, '2002-09-22 22:00:00+00', '2021-07-30 06:17:43.504525+00', 'Ashby Petronella', 'ASHBY PETRONELLA', 1, 32, 9999, 1, 3, 42, 308, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9492, '2000-09-04 22:00:00+00', '2018-10-03 00:36:40.994596+00', 'Celtic Knot, A', 'CELTIC KNOT', 1, 48, 9999, 4, 4, NULL, 2766, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9480, '2000-06-28 22:00:00+00', '2012-01-20 12:57:13.71404+00', 'Woodmere Wedding', 'WOODMERE WEDDING', 3, 48, 9999, 4, 4, NULL, 108, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9481, '2000-05-21 22:00:00+00', '2012-01-20 12:57:13.72091+00', 'Y2K', 'Y2K', 2, 32, 9999, 1, 4, NULL, 108, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9488, '2000-09-04 22:00:00+00', '2018-10-04 10:16:03.878677+00', 'Doug''s Strathspey', 'DOUGS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2766, '1999-10-01', 'This dance was written to showcase the strathspey setting in the 4th figure that Doug Jensen used in a class demonstration.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9790, '2001-03-13 23:00:00+00', '2018-04-03 00:07:40.21531+00', 'Crosslinks', 'CROSSLINKS', 3, 32, 9999, 1, 3, 42, 3549, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9495, '2000-09-04 22:00:00+00', '2018-10-07 11:03:15.554212+00', 'It''s a Reel Thing', 'ITS A REEL THING', 1, 32, 9999, 1, 3, 42, 2766, '2000-04-01', 'This dance was inspired by my love for dolphin reels and reels in general.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13486, '2009-11-20 23:00:00+00', '2018-03-02 22:03:37.973265+00', 'Lady from the West, A', 'LADY FROM THE WEST', 3, 32, 9999, 4, 4, 13, 3783, NULL, 'Noriko Shigeta comes from Ohsaka and speaks with a strong Kansai accent, which often gives wrong

ideas to people from Tokyo.



In Tokyo, KA-ki means an oyster and ka-KI means a persimmon while, in Ohsaka, the opposite is the

case.



However, I can assure you that there is no language barrier to dancing and that she is a very good

dancer.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9490, '2000-09-04 22:00:00+00', '2018-10-09 05:58:00.269518+00', 'To Honor St. Andrew', 'TO HONOR ST ANDREW', 1, 32, 9999, 1, 3, 42, 2766, '1999-11-01', 'This dance was written in honor of St. Andrews Day 11/30/99.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9442, '2002-04-23 22:00:00+00', '2022-08-01 18:01:57.916023+00', 'Temptation', 'TEMPTATION', 3, 32, 9999, 1, 3, 42, 558, '1996-01-01', 'Devised by Rudolf Spägele for Sybille Föhrenbach', 63, '844/888/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9438, '2002-08-29 22:00:00+00', '2022-08-02 07:56:27.828047+00', 'Noname', 'NONAME', 1, 32, 9999, 1, 3, 42, 558, '1992-01-01', '', 63, '844/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9782, '2001-03-13 23:00:00+00', '2012-01-20 12:57:16.03135+00', 'Rascal Fair', 'RASCAL FAIR', 3, 32, 9999, 1, 2, NULL, 389, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18920, '2018-10-09 12:22:31.50568+00', '2018-10-09 12:22:31.50568+00', 'Topspin', 'TOPSPIN', 1, 32, NULL, 1, 3, 42, 2766, '2013-01-01', 'As I wrote this dance I thought of a spinning top. Topspin sounded better.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9784, '2001-03-13 23:00:00+00', '2012-01-20 12:57:16.045125+00', 'Saint Ola', 'SAINT OLA', 1, 32, 9999, 1, 4, NULL, 389, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9786, '2001-03-13 23:00:00+00', '2012-01-20 12:57:16.058826+00', 'Uhlingers, The', 'UHLINGERS', 2, 40, 9999, 4, 4, NULL, 390, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9518, '2000-06-12 22:00:00+00', '2018-04-03 00:07:41.750233+00', 'Delight of Donegal, The', 'DELIGHT OF DONEGAL', 3, 32, 9999, 1, 3, 42, 2773, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9789, '2001-03-13 23:00:00+00', '2012-01-20 12:57:16.079249+00', 'Colonel H.A. (Pop) Gunn', 'COLONEL HA POP GUNN', 3, 32, 9999, 1, 4, NULL, 3549, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18927, '2018-10-09 14:14:01.77999+00', '2018-10-09 14:14:01.77999+00', 'Uncle Isaac', 'UNCLE ISAAC', 3, 32, NULL, 1, 3, 42, 2766, '2013-08-01', 'Not sure where I got the name of this dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9791, '2001-03-13 23:00:00+00', '2012-01-20 12:57:16.092771+00', 'Escort to Sir Winston', 'ESCORT TO SIR WINSTON', 2, 32, 9999, 1, 2, NULL, 3549, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9792, '2001-03-13 23:00:00+00', '2012-01-20 12:57:16.099523+00', 'Follow Your Partner', 'FOLLOW YOUR PARTNER', 2, 40, 9999, 1, 4, NULL, 952, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9793, '2001-03-13 23:00:00+00', '2012-01-20 12:57:16.107318+00', 'Marquis de Lafayette, Le', 'MARQUIS DE LAFAYETTE', 3, 32, 9999, 1, 4, 14, 3549, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9795, '2001-03-13 23:00:00+00', '2012-01-20 12:57:16.121646+00', 'Merlin''s Cross', 'MERLINS CROSS', 1, 32, 9999, 1, 4, 14, 3549, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9794, '2001-03-13 23:00:00+00', '2018-04-03 00:08:00.023735+00', 'Loch Awe', 'LOCH AWE', 3, 32, 9999, 1, 3, 42, 3549, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9476, '2002-02-12 23:00:00+00', '2019-01-01 09:34:33.5515+00', 'Stonehaven Lassies', 'STONEHAVEN LASSIES', 2, 32, 9999, 1, 3, 42, 108, '1998-01-01', '', 50, '800/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9498, '2001-07-30 22:00:00+00', '2012-01-20 12:57:13.872007+00', 'Millwater, The', 'MILLWATER', 3, 32, 9999, 1, 4, 2, 228, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9502, '2001-07-30 22:00:00+00', '2012-01-20 12:57:13.899358+00', 'Mill-Ennium Welcome, The', 'MILLENNIUM WELCOME', 2, 32, 9999, 5, 2, NULL, 228, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9506, '2000-06-07 22:00:00+00', '2012-01-20 12:57:13.928382+00', 'Cathy''s Jig', 'CATHYS JIG', 2, 40, 9999, 1, 4, 11, 952, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9510, '2000-06-07 22:00:00+00', '2012-01-20 12:57:13.956634+00', 'Ninety in the Shade', 'NINETY IN THE SHADE', 3, 40, 9999, 1, 4, 14, 952, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9511, '2000-06-07 22:00:00+00', '2012-01-20 12:57:13.963523+00', 'Thistledown Reel, The', 'THISTLEDOWN REEL', 1, 32, 9999, 1, 2, NULL, 952, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9477, '2001-11-25 23:00:00+00', '2018-04-03 00:08:21.214294+00', 'Tipsy Laird, The', 'TIPSY LAIRD', 3, 32, 9999, 1, 3, 42, 108, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9514, '2000-06-12 22:00:00+00', '2012-01-20 12:57:13.984848+00', 'Teasing the Tide', 'TEASING THE TIDE', 3, 32, 9999, 1, 4, 1, 2772, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9516, '2000-06-12 22:00:00+00', '2012-01-20 12:57:14.064004+00', 'Blonay-Chamby Line, The', 'BLONAYCHAMBY LINE', 1, 40, 9999, 1, 4, 1, 2773, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9517, '2000-06-12 22:00:00+00', '2012-01-20 12:57:14.07159+00', 'Kindred Celts', 'KINDRED CELTS', 2, 32, 9999, 1, 4, 2, 2773, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13483, '2009-11-20 23:00:00+00', '2015-02-13 15:47:45.000835+00', 'East Meets West', 'EAST MEETS WEST', 3, 72, 9999, 4, 4, 3, 3783, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9479, '2001-11-25 23:00:00+00', '2018-04-03 00:08:21.950736+00', 'Triplicity', 'TRIPLICITY', 3, 32, 9999, 1, 3, 42, 108, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9509, '2000-06-07 22:00:00+00', '2016-05-13 14:45:59.548206+00', 'Nine Ladies Dancing', 'NINE LADIES DANCING', 3, 48, 9999, 4, 111, NULL, 952, '1985-01-01', 'for nine ladies, arranged at start in three lines of three, one behind the other, facing the audience.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9788, '2001-03-13 23:00:00+00', '2016-05-19 14:21:03.480023+00', 'New Foursome Reel, A', 'NEW FOURSOME REEL', 4, 80, 4, 104, 2, 3, 3549, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9507, '2000-06-07 22:00:00+00', '2016-05-19 14:42:41.467578+00', 'Dancing Couple, The', 'DANCING COUPLE', 4, 80, 4, 1, 4, 2, 952, '1993-01-01', 'The original instruction mention a progression 2431; that is impossible, as 3 does not move.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9512, '2000-06-07 22:00:00+00', '2016-05-19 14:47:36.86671+00', 'Western Stars', 'WESTERN STARS', 3, 64, 9999, 107, 5, 3, 952, '1980-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9519, '2000-06-12 22:00:00+00', '2012-01-20 12:57:14.085358+00', 'Carrickmacross Lace', 'CARRICKMACROSS LACE', 1, 32, 9999, 4, 4, NULL, 2773, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9520, '2000-06-12 22:00:00+00', '2012-01-20 12:57:14.092903+00', 'Leprechaun, The', 'LEPRECHAUN', 2, 32, 9999, 1, 4, 5, 2773, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9521, '2000-06-12 22:00:00+00', '2012-01-20 12:57:14.099782+00', 'Claddagh Ring, The', 'CLADDAGH RING', 3, 64, 9999, 4, 4, NULL, 2773, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9522, '2000-06-12 22:00:00+00', '2012-01-20 12:57:14.10732+00', 'Craic, The', 'CRAIC', 1, 32, 9999, 1, 4, 1, 2773, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9525, '2000-06-12 22:00:00+00', '2012-01-20 12:57:14.128195+00', 'Shamrock, The', 'SHAMROCK', 2, 32, 9999, 6, 3, NULL, 2773, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13717, '2011-07-08 22:00:00+00', '2012-01-20 12:57:48.443765+00', 'Pleasure', 'PLEASURE', 2, 40, NULL, 1, 4, 1, 10354, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9508, '2000-06-07 22:00:00+00', '2020-04-24 00:59:03.673199+00', 'Doubly Triumphant', 'DOUBLY TRIUMPHANT', 1, 32, 9999, 1, 3, 42, 2099, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9472, '2000-09-20 22:00:00+00', '2021-04-18 18:31:00.716357+00', 'Drumheller', 'DRUMHELLER', 3, 32, 9999, 1, 100, 2, 108, '2000-01-01', '', 75, '8888/8888/8008/8008', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11475, '2003-09-22 22:00:00+00', '2021-01-24 12:28:49.886174+00', 'World Turned Upside Down, The', 'WORLD TURNED UPSIDE DOWN', 3, 32, 9999, 1, 3, 42, 2766, '2002-08-01', '', 34, '800/880/800/804', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9582, '2000-09-06 22:00:00+00', '2021-02-21 18:29:16.756993+00', 'Fiddler''s Delight', 'FIDDLERS DELIGHT', 1, 32, 9999, 2, 2, 76, 394, '1999-01-01', '', 58, '88/88/80/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9475, '2002-04-08 22:00:00+00', '2021-02-23 20:29:07.773607+00', 'Over the Moon', 'OVER THE MOON', 3, 32, 9999, 1, 100, 2, 108, '1998-01-01', '', 75, '8008/8888/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9463, '2001-12-19 23:00:00+00', '2021-02-24 09:28:57.486289+00', 'Flora Inglis'' Strathspey', 'FLORA INGLIS STRATHSPEY', 3, 32, 9999, 1, 100, 2, 108, '2000-01-01', '', 88, '8888/8888/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9526, '2000-06-12 22:00:00+00', '2012-01-20 12:57:14.135808+00', 'Connemara Capers', 'CONNEMARA CAPERS', 1, 32, 9999, 3, 5, 16, 2773, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13498, '2009-11-21 23:00:00+00', '2012-01-20 12:57:46.81467+00', 'Port-No-Quay Jig', 'PORTNOQUAY JIG', 2, 40, 9999, 1, 4, 2, 1269, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13501, '2009-11-21 23:00:00+00', '2012-01-20 12:57:46.837381+00', 'Port Hill Medley, The', 'PORT HILL MEDLEY', 4, 96, 11, 4, 4, 3, 1269, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13503, '2009-11-21 23:00:00+00', '2012-01-20 12:57:46.851253+00', 'Cadger''s Roadie, The', 'CADGERS ROADIE', 2, 32, 9999, 1, 2, NULL, 1269, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13504, '2009-11-21 23:00:00+00', '2012-01-20 12:57:46.85878+00', 'Flagstaff and Cairn, The', 'FLAGSTAFF AND CAIRN', 3, 40, 9999, 1, 4, 1, 1269, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9554, '2000-07-26 22:00:00+00', '2018-04-29 21:25:51.420963+00', 'Scotland the Brave', 'SCOTLAND THE BRAVE', 1, 32, 9999, 1, 3, 42, 2784, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9538, '2000-07-01 22:00:00+00', '2012-01-20 12:57:14.260854+00', 'Franco-Scottish Society Reel, The', 'FRANCOSCOTTISH SOCIETY REEL', 1, 32, 9999, 2, 3, 17, 888, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9544, '2002-03-07 23:00:00+00', '2012-01-20 12:57:14.318493+00', 'Clear Mountain Ceilidh', 'CLEAR MOUNTAIN CEILIDH', 1, 64, 9999, 1, 4, NULL, 2774, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9569, '2000-09-05 22:00:00+00', '2018-10-16 06:55:17.534386+00', 'Bow Tie Reel, The', 'BOW TIE REEL', 1, 32, 9999, 1, 4, 11, 2766, '2000-08-01', 'This dance happened when I wondered how I could write a dance with a figure flowing into a poussette.', 75, '0880/0880/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18723, '2018-10-04 05:18:15.432456+00', '2018-10-04 05:18:15.432456+00', 'Dancing in My Head', 'DANCING IN MY HEAD', 3, 32, NULL, 1, 3, 42, 2766, '2016-05-01', 'My way of falling asleep is to compose dances in my head and dance them in my head repeatedly to refine them.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13506, '2009-11-21 23:00:00+00', '2012-01-20 12:57:46.873264+00', 'Bow Fiddle Shore, The', 'BOW FIDDLE SHORE', 4, 96, 10007, 1, 4, 3, 1269, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9577, '2000-09-06 22:00:00+00', '2019-02-22 18:05:41.581221+00', 'Jingling Geordie''s Jig', 'JINGLING GEORDIES JIG', 2, 40, 9999, 1, 4, 1, 394, '1992-01-01', '', 85, '8000/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13509, '2009-11-22 23:00:00+00', '2012-01-20 12:57:46.892168+00', 'Trumpet Polka, The', 'TRUMPET POLKA', 13, 8, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13514, '2009-11-29 23:00:00+00', '2012-01-20 12:57:46.923881+00', 'Letty Moodie', 'LETTY MOODIE', 3, 32, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13515, '2009-11-29 23:00:00+00', '2012-01-20 12:57:46.92998+00', 'Fergus Gathering, The', 'FERGUS GATHERING', 1, 40, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13518, '2009-12-01 23:00:00+00', '2012-01-20 12:57:46.951778+00', 'Leck, The', 'LECK', 3, 32, NULL, 1, 3, 42, 2419, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13521, '2009-12-01 23:00:00+00', '2012-01-20 12:57:46.960474+00', 'Mr McColl''s Hornpipe', 'MR MACCOLLS HORNPIPE', 6, 48, NULL, 4, 4, 13, 2419, NULL, 'HORNPIPE', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9575, '2000-09-06 22:00:00+00', '2019-02-22 18:18:00.378854+00', 'Miss Lesley Taylor', 'MISS LESLEY TAYLOR', 1, 32, 9999, 1, 4, 1, 2793, '1992-01-01', '', 44, '8000/8880/8000/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9572, '2000-09-06 22:00:00+00', '2019-02-22 18:25:14.836448+00', 'Ruth Jappy''s Delight', 'RUTH JAPPYS DELIGHT', 1, 32, 9999, 3, 5, 35, 118, '1998-01-01', '', 60, '80008/80808/84048/88808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9553, '2000-07-26 22:00:00+00', '2018-04-03 00:08:12.241332+00', 'Redwood Burl', 'REDWOOD BURL', 2, 32, 9999, 1, 3, 42, 798, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9524, '2000-06-12 22:00:00+00', '2018-04-03 00:08:17.628395+00', 'Soft Day, A', 'SOFT DAY', 3, 32, 9999, 1, 3, 42, 2773, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9555, '2000-07-26 22:00:00+00', '2018-04-03 00:08:19.204689+00', 'Sun Dance', 'SUN DANCE', 1, 32, 9999, 1, 3, 42, 214, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13522, '2009-12-01 23:00:00+00', '2012-01-20 12:57:46.969958+00', 'Tribute to the Black Watch 2004', 'TRIBUTE TO THE BLACK WATCH 2004', 1, 32, 9999, 1, 4, 2, 2419, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13524, '2009-12-02 23:00:00+00', '2012-01-20 12:57:46.987249+00', 'Bannercross', 'BANNERCROSS', 4, 64, 5, 1, 4, 1, 2900, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13525, '2009-12-02 23:00:00+00', '2012-01-20 12:57:46.996724+00', 'Dance for Dulcie, A', 'DANCE FOR DULCIE', 3, 32, 9999, 1, 4, 14, 10121, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13526, '2009-12-02 23:00:00+00', '2012-01-20 12:57:47.006242+00', 'Darwin Lane', 'DARWIN LANE', 1, 32, 9999, 1, 4, 2, 2024, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13532, '2009-12-02 23:00:00+00', '2012-01-20 12:57:47.059212+00', 'Lullaby for a Baby', 'LULLABY FOR A BABY', 4, 192, 10009, 2, 3, 17, 10122, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13533, '2009-12-02 23:00:00+00', '2012-01-20 12:57:47.068711+00', 'Mix ''n'' Match', 'MIX N MATCH', 3, 32, 9999, 1, 4, 2, 2789, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13523, '2009-12-01 23:00:00+00', '2020-09-18 16:18:56.004166+00', 'Calum''s Road', 'CALUMS ROAD', 3, 32, NULL, 1, 4, 1, 2419, NULL, 'Official alias: Rathad Chalum', 75, '8800/8888/8044/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9566, '2000-09-04 22:00:00+00', '2021-01-04 13:13:58.131918+00', 'Silken Knot, The', 'SILKEN KNOT', 3, 32, 9999, 4, 4, 1, 2766, '2000-03-01', '', 88, '8080/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9552, '2000-07-26 22:00:00+00', '2021-01-27 04:25:27.622823+00', 'Printing Master, The', 'PRINTING MASTER', 3, 32, 9999, 1, 3, 42, 214, '1994-01-01', 'This dance was written in memory of Carl Mueller, who was Miriam''s husband', 62, '800/888/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9584, '2002-03-03 23:00:00+00', '2021-02-21 18:26:06.057402+00', 'Trew Fidelity', 'TREW FIDELITY', 2, 32, 9999, 1, 114, 1, 118, '1997-01-01', '', 78, '0880/8888/8444/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9574, '2000-09-06 22:00:00+00', '2021-02-21 19:43:15.306478+00', 'Jill Wings It', 'JILL WINGS IT', 2, 32, 9999, 1, 3, 42, 394, '1995-01-01', '', 53, '840/888/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9571, '2002-03-03 23:00:00+00', '2021-02-22 11:24:45.742561+00', 'Vagabond Jig', 'VAGABOND JIG', 2, 32, 9999, 1, 4, 1, 118, '1998-01-01', '', 81, '8888/8888/8440/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9570, '2000-09-05 22:00:00+00', '2021-02-22 11:29:17.585875+00', 'Reel Roundup', 'REEL ROUNDUP', 1, 32, 9999, 1, 4, 2, 2792, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9550, '2000-07-26 22:00:00+00', '2021-02-22 11:40:59.163515+00', 'Mickey''s Jig', 'MICKEYS JIG', 2, 32, 9999, 1, 3, 42, 2783, '1998-01-01', 'This dance is named for Tom''s wife Michele who is known by many as Mickey.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9549, '2000-07-26 22:00:00+00', '2021-02-22 16:32:25.384507+00', 'Home for the Holidays', 'HOME FOR THE HOLIDAYS', 1, 32, 9999, 1, 3, 42, 798, '1995-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9547, '2001-04-25 22:00:00+00', '2021-02-22 16:37:38.1848+00', 'Hamish McIntosh', 'HAMISH MACINTOSH', 2, 32, 9999, 1, 102, 11, 165, NULL, '', 75, '8000/4884/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9539, '2002-05-12 22:00:00+00', '2021-02-22 17:01:41.135555+00', 'Normandy Jig, The', 'NORMANDY JIG', 2, 48, 9999, 1, 4, 1, 3106, NULL, '', 70, '8080/8888/8080/8080/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9523, '2000-06-12 22:00:00+00', '2021-02-22 20:11:26.096668+00', 'Linen Looms, The', 'LINEN LOOMS', 2, 40, 9999, 1, 3, 42, 2773, '2000-01-01', '', 58, '666/666/888/888/404', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13513, '2009-11-29 23:00:00+00', '2021-03-03 22:27:33.741517+00', 'Yukio''s Reel', 'YUKIOS REEL', 1, 32, NULL, 1, 4, 1, 1836, NULL, '', 50, '4884/8000/4884/4004', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13512, '2009-11-29 23:00:00+00', '2021-03-03 22:32:29.163654+00', 'Masako', 'MASAKO', 1, 40, NULL, 1, 4, 1, 1836, '2006-01-01', 'Devised: 2006', 54, '8000/8220/8440/8880/8666', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9530, '2000-06-13 22:00:00+00', '2021-07-30 08:26:11.765391+00', 'Millennium Bug, The', 'MILLENNIUM BUG', 3, 32, 9999, 1, 3, 42, 308, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9533, '2002-09-22 22:00:00+00', '2021-07-30 08:33:06.182735+00', 'Two Furlongs', 'TWO FURLONGS', 3, 32, 9999, 2, 3, NULL, 308, '2001-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9548, '2000-07-26 22:00:00+00', '2021-10-08 10:44:12.071238+00', 'Clockwork', 'CLOCKWORK', 2, 32, 9999, 1, 2, 76, 214, '1997-01-01', '', 60, '44/88/88/88', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9527, '2002-09-22 22:00:00+00', '2021-08-02 09:43:34.475766+00', 'Caledonian Caper', 'CALEDONIAN CAPER', 1, 40, 9999, 1, 3, 42, 308, '1999-04-01', '', 70, '848/888/866/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13534, '2009-12-02 23:00:00+00', '2012-01-20 12:57:47.077345+00', 'Ringinglow Jig, The', 'RINGINGLOW JIG', 2, 32, 9999, 1, 4, NULL, 10123, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13535, '2009-12-02 23:00:00+00', '2012-01-20 12:57:47.086894+00', 'Sheaf Strathspey, The', 'SHEAF STRATHSPEY', 3, 32, 9999, 1, 4, 2, 2024, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9587, '2000-09-04 22:00:00+00', '2012-01-20 12:57:14.658923+00', 'Charm City Strathspey', 'CHARM CITY STRATHSPEY', 3, 32, 9999, 2, 3, NULL, 2796, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9588, '2000-09-04 22:00:00+00', '2012-01-20 12:57:14.665854+00', 'Colonel MacLeod''s Rant', 'COLONEL MACLEODS RANT', 3, 40, 9999, 1, 4, NULL, 2796, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9590, '2000-09-04 22:00:00+00', '2012-01-20 12:57:14.679655+00', 'Fifty Years and A''', 'FIFTY YEARS AND A', 3, 32, 9999, 1, 4, NULL, 2796, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9596, '2000-09-04 22:00:00+00', '2012-01-20 12:57:14.721738+00', 'Robert Burns Society of Annapolis', 'ROBERT BURNS SOCIETY OF ANNAPOLIS', 2, 128, 9999, 4, 4, NULL, 2796, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9598, '2000-09-04 22:00:00+00', '2012-01-20 12:57:14.735446+00', 'Shirley''s Strathspey', 'SHIRLEYS STRATHSPEY', 3, 32, 9999, 5, 56, NULL, 2796, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9599, '2000-09-04 22:00:00+00', '2012-01-20 12:57:14.742207+00', 'Gie Us A Hand', 'GIE US A HAND', 1, 32, 9999, 5, 2, NULL, 693, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9601, '2000-09-04 22:00:00+00', '2012-01-20 12:57:14.755922+00', 'Diamond Circlet, The', 'DIAMOND CIRCLET', 3, 32, 9999, 1, 2, NULL, 693, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9603, '2000-09-04 22:00:00+00', '2012-01-20 12:57:14.769696+00', 'Red Sash, The', 'RED SASH', 4, 32, 9999, 1, 4, NULL, 693, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9604, '2000-09-04 22:00:00+00', '2012-01-20 12:57:14.776579+00', 'Celtic Braid, The', 'CELTIC BRAID', 1, 32, 9999, 1, 4, NULL, 693, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9605, '2000-09-04 22:00:00+00', '2012-01-20 12:57:14.783429+00', 'Left-Handed Queen, The', 'LEFTHANDED QUEEN', 2, 32, 9999, 1, 2, NULL, 693, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9606, '2000-09-04 22:00:00+00', '2012-01-20 12:57:14.790267+00', 'Spirit of the Brachan', 'SPIRIT OF THE BRACHAN', 3, 32, 9999, 1, 4, NULL, 693, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9545, '2000-07-26 22:00:00+00', '2018-04-02 10:27:53.775484+00', 'Anderson Kilt, The', 'ANDERSON KILT', 1, 32, 9999, 1, 3, 42, 214, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9546, '2000-07-26 22:00:00+00', '2018-04-02 23:56:33.322065+00', 'Captain, The', 'CAPTAIN', 1, 32, 9999, 1, 3, 42, 214, '1996-01-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9610, '2000-09-05 22:00:00+00', '2012-01-20 12:57:14.819767+00', 'Two of a Kind', 'TWO OF A KIND', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13536, '2009-12-02 23:00:00+00', '2012-01-20 12:57:47.09643+00', 'Sheffield Secretary, The', 'SHEFFIELD SECRETARY', 3, 32, 9999, 2, 3, 17, 10123, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13537, '2009-12-02 23:00:00+00', '2012-01-20 12:57:47.105996+00', 'Strathaird', 'STRATHAIRD', 3, 32, 9999, 1, 4, 1, 2022, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13541, '2009-12-02 23:00:00+00', '2012-01-20 12:57:47.132734+00', 'Conor''s Ceilidh', 'CONORS CEILIDH', 1, 32, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9578, '2000-09-06 22:00:00+00', '2022-10-21 13:43:58.327818+00', 'An Tigh Mor', 'TIGH MOR', 1, 32, 9999, 1, 3, 42, 394, '1992-06-01', '', 44, '800/880/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9612, '2000-09-05 22:00:00+00', '2018-04-03 00:07:31.362447+00', 'At Last We Are Going to Dance Again', 'AT LAST WE ARE GOING TO DANCE AGAIN', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9608, '2000-09-04 22:00:00+00', '2016-05-11 14:29:48.995055+00', 'Circles on the Moor', 'CIRCLES ON THE MOOR', 1, 88, 9999, 4, 4, NULL, 693, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9586, '2000-09-04 22:00:00+00', '2018-04-03 00:07:33.290623+00', 'Big and Little Sandy', 'BIG AND LITTLE SANDY', 1, 40, 9999, 1, 3, 42, 2796, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13527, '2009-12-02 23:00:00+00', '2018-04-03 00:07:42.525989+00', 'Don Valley Reel, The', 'DON VALLEY REEL', 1, 32, 9999, 1, 3, 42, 2900, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13529, '2009-12-02 23:00:00+00', '2018-04-03 00:07:53.90252+00', 'Island Strathspey, The', 'ISLAND STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2899, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13530, '2009-12-02 23:00:00+00', '2018-04-03 00:07:56.07048+00', 'John Barleycorn', 'JOHN BARLEYCORN', 2, 32, 9999, 1, 3, 42, 2024, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13531, '2009-12-02 23:00:00+00', '2018-04-03 00:08:00.2572+00', 'Logan Braes', 'LOGAN BRAES', 3, 32, 9999, 1, 3, 42, 2024, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9592, '2000-09-04 22:00:00+00', '2018-04-03 00:08:02.225335+00', 'Marjorie Franklin''s Strathspey', 'MARJORIE FRANKLINS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2796, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9600, '2000-09-06 22:00:00+00', '2018-04-03 00:08:03.292789+00', 'Mews, The', 'MEWS', 2, 32, 9999, 1, 3, 42, 693, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9589, '2000-09-04 22:00:00+00', '2018-04-03 00:08:03.768132+00', 'Mirrie Boys o'' Greenland, Da', 'MIRRIE BOYS O GREENLAND', 1, 32, 9999, 1, 3, 42, 2796, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9585, '2001-07-18 22:00:00+00', '2018-04-03 00:08:04.00991+00', 'Miss Cynthia Mackay', 'MISS CYNTHIA MACKAY', 2, 32, 9999, 1, 3, 42, 2795, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9593, '2000-09-04 22:00:00+00', '2018-04-03 00:08:08.463727+00', 'Oh Gin I Were Where Gadie Rins', 'OH GIN I WERE WHERE GADIE RINS', 1, 32, 9999, 1, 3, 42, 2796, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9594, '2000-09-04 22:00:00+00', '2018-04-03 00:08:10.21476+00', 'Peggy''s Farewell', 'PEGGYS FAREWELL', 1, 32, 9999, 1, 3, 42, 2796, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9595, '2000-09-04 22:00:00+00', '2018-04-03 00:08:11.032182+00', 'Pontius Pilate''s Bodyguard', 'PONTIUS PILATES BODYGUARD', 1, 32, 9999, 1, 3, 42, 2796, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9597, '2000-09-04 22:00:00+00', '2018-04-03 00:08:13.375493+00', 'Robert Callander', 'ROBERT CALLANDER', 4, 32, 1, 1, 3, 42, 2796, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9611, '2000-09-05 22:00:00+00', '2018-04-03 00:08:15.32699+00', 'Scottish Country Dance Society, The', 'SCOTTISH COUNTRY DANCE SOCIETY', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9613, '2000-09-05 22:00:00+00', '2018-04-03 00:08:24.866537+00', 'We''re in the Army Now', 'WERE IN THE ARMY NOW', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9602, '2000-09-04 22:00:00+00', '2018-04-03 00:08:25.625249+00', 'White Water Reel', 'WHITE WATER REEL', 1, 32, 9999, 1, 3, 42, 693, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9627, '2000-09-05 22:00:00+00', '2018-04-03 00:07:30.518646+00', 'And That Did It!', 'AND THAT DID IT', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9646, '2000-09-06 22:00:00+00', '2018-04-29 10:23:28.041588+00', 'East of Yeadon', 'EAST OF YEADON', 2, 32, 9999, 1, 3, 42, 146, '1992-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9614, '2000-09-05 22:00:00+00', '2018-04-03 00:07:34.666794+00', 'Bonnie, Bonnie Lassies, The', 'BONNIE BONNIE LASSIES', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9618, '2001-03-21 23:00:00+00', '2012-01-20 12:57:14.874757+00', 'Royal Scottish Country Dance Society, The', 'ROYAL SCOTTISH COUNTRY DANCE SOCIETY', 2, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13528, '2009-12-02 23:00:00+00', '2020-09-18 16:27:12.490625+00', 'Inversnaid Reel', 'INVERSNAID REEL', 1, 32, 9999, 1, 3, 42, 2899, NULL, '', 56, '888/800/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13538, '2009-12-02 23:00:00+00', '2020-09-18 16:30:34.170119+00', 'Wheel Done', 'WHEEL DONE', 2, 32, 9999, 1, 2, 76, 2789, NULL, '', 69, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9662, '2000-09-18 22:00:00+00', '2021-02-21 11:20:34.951869+00', 'Bonny Blue Bride', 'BONNY BLUE BRIDE', 2, 32, 9999, 1, 3, 42, 2488, '1981-01-01', '', 50, '800/888/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9591, '2000-09-04 22:00:00+00', '2021-06-08 10:36:55.614911+00', 'Lassie with the Dancing Eyes', 'LASSIE WITH THE DANCING EYES', 1, 32, 9999, 1, 3, 42, 2796, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9619, '2000-09-05 22:00:00+00', '2012-01-20 12:57:14.881573+00', 'We are the Best Peacemakers in the World', 'WE ARE THE BEST PEACEMAKERS IN THE WORLD', 3, 48, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9669, '2000-09-18 22:00:00+00', '2019-03-03 14:47:01.738313+00', 'Mardi Gras Minnesota', 'MARDI GRAS MINNESOTA', 1, 32, 9999, 1, 2, NULL, 1268, '1993-01-01', '', 52, '44/44/88/88', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9621, '2000-09-05 22:00:00+00', '2012-01-20 12:57:14.895123+00', 'By Word of Mouth', 'BY WORD OF MOUTH', 3, 40, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9623, '2000-09-05 22:00:00+00', '2012-01-20 12:57:14.901922+00', 'Sporran Legion, The', 'SPORRAN LEGION', 2, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9626, '2000-09-05 22:00:00+00', '2012-01-20 12:57:14.922437+00', 'Give Your Whole Heart to Dancing', 'GIVE YOUR WHOLE HEART TO DANCING', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9629, '2000-09-05 22:00:00+00', '2012-01-20 12:57:14.943669+00', 'In My Heart I''m Full of Dancing', 'IN MY HEART IM FULL OF DANCING', 3, 32, 9999, 1, 4, NULL, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9616, '2000-09-05 22:00:00+00', '2018-04-03 00:07:48.106015+00', 'Get Her Feet aff the Grun''', 'GET HER FEET AFF THE GRUN', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13568, '2010-04-14 22:00:00+00', '2012-01-20 12:57:47.324362+00', 'Danderin''', 'DANDERIN', 2, 32, NULL, 5, 56, 30, 10384, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13570, '2010-04-14 22:00:00+00', '2012-01-20 12:57:47.340805+00', '8000 Miles from Home', '8000 MILES FROM HOME', 4, 64, 5, 1, 4, 1, 856, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13571, '2010-04-14 22:00:00+00', '2012-01-20 12:57:47.347653+00', 'McMillan Strathspey, The', 'MACMILLAN STRATHSPEY', 3, 32, NULL, 4, 4, 30, 3523, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13569, '2010-04-14 22:00:00+00', '2018-04-03 00:07:49.157333+00', 'Gold and Silver Strathspey, The', 'GOLD AND SILVER STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10382, NULL, '<<scddb:not-identical:12083>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9644, '2002-08-29 22:00:00+00', '2012-01-20 12:57:15.050971+00', 'Iona Wedding Rings', 'IONA WEDDING RINGS', 1, 32, 9999, 1, 4, 1, 2797, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9665, '2000-09-18 22:00:00+00', '2012-01-20 12:57:15.196953+00', 'Fugal Farkle', 'FUGAL FARKLE', 1, 32, 9999, 1, 4, NULL, 2488, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9666, '2000-09-18 22:00:00+00', '2012-01-20 12:57:15.204131+00', 'Ginger''s Frolic', 'GINGERS FROLIC', 1, 32, 9999, 1, 2, NULL, 2488, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9645, '2000-09-05 22:00:00+00', '2018-04-03 00:08:06.78715+00', 'Mr Yasumuro''s Strathspey', 'MR YASUMUROS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2798, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9664, '2000-09-18 22:00:00+00', '2016-05-12 09:44:06.336533+00', 'Gentle Jude, The', 'GENTLE JUDE', 3, 32, 9999, 4, 2, NULL, 2488, '1991-01-01', 'Start in diamond shape, W on midline, M on sides', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13558, '2010-01-19 23:00:00+00', '2017-05-28 18:17:47.59307+00', 'King Edward''s Jig', 'KING EDWARDS JIG', 2, 32, NULL, 1, 4, 2, 347, NULL, 'King Edward''s Hall in Lindfield is another venue that I [*Mervyn Short*] used for my class.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9628, '2000-09-05 22:00:00+00', '2018-04-03 00:08:12.975142+00', 'Rich Heritage, A', 'RICH HERITAGE', 2, 40, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13573, '2010-05-29 22:00:00+00', '2017-12-13 15:25:13.864559+00', 'Eriskay Jig, The', 'ERISKAY JIG', 2, 32, NULL, 4, 4, NULL, 550, '2005-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9624, '2000-09-05 22:00:00+00', '2018-04-03 00:08:17.553397+00', 'Society Disciple, A', 'SOCIETY DISCIPLE', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13555, '2010-01-19 23:00:00+00', '2022-10-22 02:19:14.509826+00', 'Sidney''s Reel', 'SIDNEYS REEL', 2, 32, NULL, 2, 3, 17, 347, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9670, '2002-02-27 23:00:00+00', '2022-11-15 22:44:28.039502+00', 'McClellan Knot, The', 'MACCLELLAN KNOT', 3, 32, 9999, 1, 3, 42, 2488, '1992-01-01', 'Theis dance was "presented to Anita and Michael McClellan upon the occasion of their marriage on September 26, 1992."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9668, '2000-09-18 22:00:00+00', '2022-12-19 14:42:34.878445+00', 'Madison Square', 'MADISON SQUARE', 10, 64, 9999, 4, 4, NULL, 2488, '1982-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13547, '2009-12-19 23:00:00+00', '2023-01-18 08:18:41.380654+00', 'Triskelion', 'TRISKELION', 4, 192, 3, 6, 3, 17, 550, '2002-02-01', 'This is really a 32-bar dance which is danced three times through in strathspey time and then three times through in reel time.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9625, '2000-09-05 22:00:00+00', '2018-04-03 00:08:20.380439+00', 'Terribly Natural', 'TERRIBLY NATURAL', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9620, '2000-09-05 22:00:00+00', '2018-04-03 00:08:24.309934+00', 'We are Saving a Tradition', 'WE ARE SAVING A TRADITION', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9673, '2000-09-18 22:00:00+00', '2012-01-20 12:57:15.255643+00', 'Resident Fiddler Marries, The', 'RESIDENT FIDDLER MARRIES', 2, 32, 9999, 1, 4, NULL, 1268, '1985-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9677, '2000-09-19 22:00:00+00', '2012-01-20 12:57:15.285167+00', 'Hasty Pudding', 'HASTY PUDDING', 1, 32, 9999, 1, 99, NULL, 480, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9678, '2000-09-20 22:00:00+00', '2012-01-20 12:57:15.292619+00', 'Hector Strathspey, The', 'HECTOR STRATHSPEY', 3, 40, 9999, 1, 4, 22, 2810, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9690, '2002-02-26 23:00:00+00', '2012-01-20 12:57:15.377744+00', 'James Duff, M.P.', 'JAMES DUFF MP', 1, 32, 9999, 1, 4, NULL, 2811, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17663, '2017-03-19 16:02:21.544948+00', '2018-08-17 12:28:44.073459+00', 'Trail to Tucson', 'TRAIL TO TUCSON', 2, 32, NULL, 1, 3, 42, 11322, '2017-03-01', 'Conceived at the request of Anne Dempsey and Rochelle Mullis as a gift for Georgene Porter when she and her husband Steve moved from Northern Virginia to Tucson, Arizona.', 59, '844/844/866/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9692, '2002-02-26 23:00:00+00', '2012-01-20 12:57:15.391275+00', 'Wemyss Castle', 'WEMYSS CASTLE', 1, 32, 9999, 1, 4, NULL, 2811, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9694, '2002-08-29 22:00:00+00', '2012-01-20 12:57:15.404915+00', 'MacDuff''s Petronella', 'MACDUFFS PETRONELLA', 1, 96, 9999, 4, 4, NULL, 2811, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9671, '2000-09-18 22:00:00+00', '2020-07-24 16:06:27.257246+00', 'McDonald of the Arches', 'MACDONALD OF THE ARCHES', 3, 32, 9999, 2, 3, 17, 1268, '1990-01-01', 'Dance written by Doug Schneider in 1990 and dedicated to Clay Gagnon, who jokingly traces his Scottish ancestry back to Clan McDonald of the Arches.', 60, '888/800/800/882', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9650, '2001-06-12 22:00:00+00', '2020-09-09 09:55:57.141215+00', 'Jig for Helen, A', 'JIG FOR HELEN', 2, 40, 9999, 1, 4, 1, 2788, '1997-01-01', '', 75, '8888/8008/0880/8888/0888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9651, '2001-06-12 22:00:00+00', '2020-09-09 11:03:10.488487+00', 'Mrs Mary Cooper', 'MRS MARY COOPER', 3, 32, 9999, 1, 3, 42, 523, '1993-01-01', '', 44, '800/888/448/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9652, '2001-06-12 22:00:00+00', '2020-09-09 11:08:14.684971+00', 'Birthday Cake, The', 'BIRTHDAY CAKE', 1, 32, 9999, 1, 4, 1, 2803, '1992-01-01', '', 84, '8888/8448/4884/4888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9657, '2001-06-12 22:00:00+00', '2020-09-09 11:11:43.760597+00', 'Leaving of The Rise, The', 'LEAVING OF THE RISE', 1, 32, 9999, 1, 4, 1, 2788, '1998-01-01', '', 75, '6666/8888/8888/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9659, '2001-06-12 22:00:00+00', '2020-09-09 11:15:56.311709+00', 'Silver Wedding Medley, The', 'SILVER WEDDING MEDLEY', 4, 96, 11, 4, 4, 3, 2805, '1995-01-01', '', 79, '4444/4444/8686/6868/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9680, '2001-10-23 22:00:00+00', '2020-09-09 12:11:39.921678+00', 'Dancing Chef, The', 'DANCING CHEF', 1, 96, 9999, 4, 4, 3, 2892, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9653, '2001-06-12 22:00:00+00', '2020-09-09 12:51:06.155926+00', 'Lilburn Tower', 'LILBURN TOWER', 3, 32, 9999, 1, 3, 42, 2788, '1998-01-01', '', 53, '840/804/888/848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9655, '2000-09-14 22:00:00+00', '2020-09-09 12:57:41.846574+00', 'Tribute to Mrs McAulay, A', 'TRIBUTE TO MRS MACAULAY', 3, 32, 9999, 2, 3, 17, 525, NULL, '', 83, '888/808/808/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9688, '2002-08-29 22:00:00+00', '2021-02-21 10:56:41.069204+00', 'Captain MacDuff''s Delight', 'CAPTAIN MACDUFFS DELIGHT', 1, 32, 9999, 1, 2, 76, 2811, NULL, '', 60, '88/80/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13556, '2010-01-19 23:00:00+00', '2020-09-18 16:35:48.84327+00', 'Naishcombe Hill', 'NAISHCOMBE HILL', 3, 32, NULL, 1, 3, 42, 347, NULL, '', 53, '800/888/844/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9684, '2002-04-08 22:00:00+00', '2021-02-21 11:16:15.767583+00', 'Ord Arms Medley', 'ORD ARMS MEDLEY', 4, 128, 13, 1, 4, 2, 2892, NULL, 'This is the hotel where the Glen Orrin Dancers originally met for an afternoon of dance followed by a meal and a good ''blether''. Danced twice in strathspey and twice in jig time.', 69, '8008/0880/8888/4884', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9702, '2000-11-12 23:00:00+00', '2021-01-23 23:28:04.556671+00', 'Welcome to the Dance', 'WELCOME TO THE DANCE', 2, 32, 9999, 5, 56, 76, 447, '1990-01-01', '<<scddb-not-identical:7035>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9695, '2000-10-13 22:00:00+00', '2012-01-20 12:57:15.411789+00', 'Falkland Castle', 'FALKLAND CASTLE', 3, 32, 9999, 2, 3, NULL, 2811, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18984, '2018-10-17 12:31:12.421361+00', '2019-01-29 00:19:43.518928+00', 'Carol''s Chain Reaction', 'CAROLS CHAIN REACTION', 2, 32, NULL, 1, 2, 76, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9697, '2000-10-14 22:00:00+00', '2012-01-20 12:57:15.426162+00', 'Lion Rampant Reel', 'LION RAMPANT REEL', 1, 40, 9999, 1, 4, 2, 2811, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13599, '2010-09-20 22:00:00+00', '2012-01-20 12:57:47.525337+00', 'Ken and Lavinia''s Ruby', 'KEN AND LAVINIAS RUBY', 3, 40, 9999, 1, 4, 2, 10244, '2006-01-01', 'Devised: 2006-01', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9698, '2001-12-16 23:00:00+00', '2012-01-20 12:57:15.433072+00', 'Balmullo Trumpeter, The', 'BALMULLO TRUMPETER', 2, 40, 9999, 1, 99, NULL, 1272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9700, '2000-11-09 23:00:00+00', '2012-01-20 12:57:15.446712+00', 'Boston Tea Party, The', 'BOSTON TEA PARTY', 99, 0, 9999, 99, 99, NULL, 9998, NULL, 'This dance doesn''t yet exist. It''s just that it''s a great name with all the hint''s of action and rebellion. If YOU can devise one and want the name, then let me know', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9703, '2000-11-12 23:00:00+00', '2012-01-20 12:57:15.469357+00', 'Royal Gold', 'ROYAL GOLD', 3, 80, 9999, 4, 4, NULL, 2815, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9704, '2000-11-12 23:00:00+00', '2012-01-20 12:57:15.476236+00', 'Catri''s Delight', 'CATRIS DELIGHT', 1, 32, 9999, 1, 4, NULL, 2580, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9705, '2000-11-12 23:00:00+00', '2012-01-20 12:57:15.483105+00', 'Lord Charles Somerset', 'LORD CHARLES SOMERSET', 3, 80, 9999, 4, 4, NULL, 447, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9706, '2000-11-12 23:00:00+00', '2012-01-20 12:57:15.490537+00', 'Jig for Jaqui, A', 'JIG FOR JAQUI', 2, 32, 9999, 1, 4, 1, 2817, '1980-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9707, '2001-03-17 23:00:00+00', '2012-01-20 12:57:15.497538+00', 'Birkland Burn, The', 'BIRKLAND BURN', 2, 32, 9999, 1, 4, NULL, 2829, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9681, '2001-10-23 22:00:00+00', '2019-03-05 11:10:15.332964+00', 'Glen Orrin Strathspey', 'GLEN ORRIN STRATHSPEY', 3, 32, 9999, 4, 4, 1, 2892, NULL, '', 88, '8888/8888/8888/4444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9712, '2000-11-13 23:00:00+00', '2012-01-20 12:57:15.532254+00', 'Jimmy''s Lilt', 'JIMMYS LILT', 2, 32, 9999, 4, 4, NULL, 447, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9713, '2000-11-13 23:00:00+00', '2012-01-20 12:57:15.539098+00', 'Spring Strathspey', 'SPRING STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 2822, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9714, '2000-11-14 23:00:00+00', '2012-01-20 12:57:15.54594+00', 'Spinney, The', 'SPINNEY', 3, 32, 9999, 1, 2, NULL, 447, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9715, '2000-11-14 23:00:00+00', '2012-01-20 12:57:15.553474+00', 'Laidlaw Laid Low', 'LAIDLAW LAID LOW', 1, 32, 9999, 1, 4, 1, 2817, '1980-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9716, '2000-11-14 23:00:00+00', '2012-01-20 12:57:15.560334+00', 'Somerset Strathspey', 'SOMERSET STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 2824, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9718, '2000-11-17 23:00:00+00', '2012-01-20 12:57:15.573936+00', 'Scottish Highlanders, The', 'SCOTTISH HIGHLANDERS', 3, 32, 9999, 1, 4, NULL, 447, '1989-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9719, '2000-11-17 23:00:00+00', '2012-01-20 12:57:15.581497+00', 'Saxon''s Strathspey', 'SAXONS STRATHSPEY', 3, 48, 9999, 1, 4, 2, 2825, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9720, '2000-11-17 23:00:00+00', '2012-01-20 12:57:15.588388+00', 'Tangle, The', 'TANGLE', 3, 32, 9999, 1, 4, NULL, 2580, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9723, '2000-11-17 23:00:00+00', '2012-01-20 12:57:15.60881+00', 'Out of Africa', 'OUT OF AFRICA', 4, 64, 17, 4, 4, NULL, 2826, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9693, '2000-10-13 22:00:00+00', '2018-04-03 00:07:57.271555+00', 'Kilgour''s Jig', 'KILGOURS JIG', 2, 32, 9999, 1, 3, 42, 2811, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9696, '2000-10-14 22:00:00+00', '2018-04-03 00:07:58.781024+00', 'Lands of Kilgour', 'LANDS OF KILGOUR', 2, 40, 9999, 1, 3, 42, 2811, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9691, '2002-08-29 22:00:00+00', '2018-04-03 00:08:05.586128+00', 'Mr Aldridge''s Favorite Hornpipe', 'MR ALDRIDGES FAVORITE HORNPIPE', 1, 32, 9999, 1, 3, 42, 2811, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9679, '2001-05-03 22:00:00+00', '2022-10-02 11:58:06.099362+00', 'Greetings from Lipica', 'GREETINGS FROM LIPICA', 1, 40, 9999, 1, 3, 18, 2533, '2000-03-29', 'Lipica is a little village in Slovenia’s karst region close to the Italian border.', 47, '804/888/800/888/800', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9689, '2002-08-29 22:00:00+00', '2018-04-03 00:08:06.028055+00', 'Mrs Duff''s Reel', 'MRS DUFFS REEL', 1, 32, 9999, 1, 3, 42, 2811, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9717, '2000-11-16 23:00:00+00', '2018-04-03 00:08:15.727175+00', 'Settlers, The', 'SETTLERS', 2, 32, 9999, 1, 3, 42, 447, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9721, '2000-11-17 23:00:00+00', '2018-04-03 00:08:18.645934+00', 'Straitgate', 'STRAITGATE', 2, 32, 9999, 1, 3, 42, 2817, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13605, '2010-09-20 22:00:00+00', '2012-01-20 12:57:47.570216+00', 'Golden Birthday Strathspey, The', 'GOLDEN BIRTHDAY STRATHSPEY', 3, 32, 9999, 1, 4, 2, 10242, '2000-01-01', 'Devised: 2000', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9756, '2000-12-17 23:00:00+00', '2018-04-29 13:12:05.857492+00', '19th Hole, The', '19TH HOLE', 2, 32, 9999, 1, 3, 42, 394, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9728, '2000-11-17 23:00:00+00', '2018-04-29 21:26:49.643335+00', 'Cavern Rant, The', 'CAVERN RANT', 1, 32, 9999, 5, 56, NULL, 2828, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9738, '2000-12-12 23:00:00+00', '2018-04-29 13:13:46.029033+00', 'Pride of Scotland', 'PRIDE OF SCOTLAND', 1, 40, 9999, 1, 3, 42, 394, '1980-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13612, '2010-09-21 22:00:00+00', '2012-01-20 12:57:47.612986+00', 'Loopylu', 'LOOPYLU', 1, 40, 9999, 1, 4, 2, 3125, '2008-10-25', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13890, '2011-08-22 22:00:00+00', '2012-01-20 12:57:49.908354+00', 'Double Score', 'DOUBLE SCORE', 3, 40, NULL, 1, 4, 1, 2788, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9727, '2000-11-17 23:00:00+00', '2012-01-20 12:57:15.637953+00', 'Tribute to Nancy, A', 'TRIBUTE TO NANCY', 2, 48, 9999, 3, 5, NULL, 447, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9741, '2001-07-31 22:00:00+00', '2018-10-01 09:26:44.067566+00', 'Silk and Thistle', 'SILK AND THISTLE', 4, 32, 1, 1, 3, 42, 1346, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9732, '2000-11-17 23:00:00+00', '2012-01-20 12:57:15.672856+00', 'John''s Jig', 'JOHNS JIG', 2, 32, 9999, 7, 4, NULL, 2815, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9734, '2000-11-17 23:00:00+00', '2012-01-20 12:57:15.687968+00', 'First to Third', 'FIRST TO THIRD', 3, 32, 9999, 2, 3, 17, 2580, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9699, '2001-12-16 23:00:00+00', '2020-08-31 16:38:57.227745+00', 'Blooms of Perth', 'BLOOMS OF PERTH', 4, 128, 2, 4, 4, 3, 205, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9779, '2001-03-13 23:00:00+00', '2020-09-09 13:06:59.987835+00', 'King''s Highway, The', 'KINGS HIGHWAY', 3, 32, 9999, 2, 3, 17, 3469, '2000-01-01', '', 75, '800/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13600, '2010-09-20 22:00:00+00', '2020-10-13 19:44:49.999288+00', 'Carleton Jig, The', 'CARLETON JIG', 2, 32, 9999, 1, 100, 2, 316, '2009-01-01', 'Devised: 2009', 72, '8008/8228/4884/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13603, '2010-09-20 22:00:00+00', '2021-01-01 19:07:04.756851+00', 'Far Distant Land, A', 'FAR DISTANT LAND', 1, 48, 9999, 1, 3, 42, 505, '1999-07-01', 'Devised: 1999-07', 58, '888/888/800/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13601, '2010-09-20 22:00:00+00', '2021-01-01 19:16:46.315229+00', 'JillwithaJ', 'JILLWITHAJ', 1, 48, 9999, 2, 3, 18, 3462, '2008-12-01', 'Devised: 2008-12', 72, '880/880/844/808/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13602, '2010-09-20 22:00:00+00', '2021-01-01 19:13:18.577854+00', 'Berry Brow', 'BERRY BROW', 3, 32, 9999, 4, 4, 13, 3125, '2009-01-01', 'Devised: 2009', 88, '8080/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13598, '2010-09-20 22:00:00+00', '2021-01-01 19:19:46.400403+00', 'By Invitation', 'BY INVITATION', 1, 32, 9999, 1, 4, 2, 10240, '2009-04-01', 'Devised: 2009-04', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13596, '2010-09-20 22:00:00+00', '2021-01-01 19:26:38.478556+00', 'Kathy Campbell''s Reel', 'KATHY CAMPBELLS REEL', 1, 32, NULL, 1, 3, 42, 316, '2007-01-01', 'Devised: 2007', 47, '844/844/844/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9740, '2002-08-29 22:00:00+00', '2021-02-21 10:44:34.610902+00', 'Lucy''s Fancy', 'LUCYS FANCY', 1, 32, 9999, 1, 3, 42, 1346, '1988-09-01', '', 53, '800/888/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9687, '2001-10-23 22:00:00+00', '2021-02-21 11:05:40.902015+00', 'Tribute to Euan', 'TRIBUTE TO EUAN', 2, 40, 9999, 1, 102, 2, 2892, NULL, '', 90, '8888/8888/8888/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9685, '2002-03-03 23:00:00+00', '2021-02-21 11:11:55.337211+00', 'Ormonde Castle', 'ORMONDE CASTLE', 3, 32, 9999, 1, 100, 11, 2892, NULL, '', 84, '8008/8668/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (40, '1998-09-29 22:00:00+00', '2018-10-08 20:35:13.872029+00', 'Adieu Mon Ami', 'ADIEU MON AMI', 3, 32, 9999, 1, 3, 42, 9998, '1814-01-01', '', 53, '880 880 822 888', 0, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (18985, '2018-10-17 12:32:23.194066+00', '2018-10-17 12:32:23.194066+00', 'Charlotte''s Double Knot', 'CHARLOTTES DOUBLE KNOT', 2, 32, NULL, 2, 3, 17, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9743, '2001-07-31 22:00:00+00', '2019-02-07 23:47:44.327065+00', 'Drunkards Path, The', 'DRUNKARDS PATH', 4, 32, 1, 1, 3, 42, 1346, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9739, '2000-12-12 23:00:00+00', '2012-01-20 12:57:15.723242+00', 'Tribute to Jill', 'TRIBUTE TO JILL', 2, 32, 9999, 1, 4, NULL, 2814, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9735, '2000-11-17 23:00:00+00', '2019-03-05 11:06:57.250849+00', 'Birthday Dance, A', 'BIRTHDAY DANCE', 2, 32, 9999, 1, 100, 2, 2817, '1988-01-01', '', 81, '8008/4884/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13609, '2010-09-20 22:00:00+00', '2019-04-03 21:52:30.631343+00', 'Restless Ghost, The', 'RESTLESS GHOST', 1, 32, 9999, 1, 3, 42, 3462, '1997-01-01', 'Devised: 1997', 56, '804/866/488/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9744, '2000-12-14 23:00:00+00', '2012-01-20 12:57:15.757686+00', 'Essex Scottish, The', 'ESSEX SCOTTISH', 2, 32, 9999, 1, 4, NULL, 394, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9745, '2000-12-14 23:00:00+00', '2012-01-20 12:57:15.765204+00', 'Veronica', 'VERONICA', 1, 32, 9999, 1, 4, 1, 118, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9746, '2000-12-14 23:00:00+00', '2012-01-20 12:57:15.772752+00', 'Diamond for Rose and Tom, A', 'DIAMOND FOR ROSE AND TOM', 3, 32, 9999, 2, 3, 18, 2793, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9747, '2000-12-14 23:00:00+00', '2012-01-20 12:57:15.780307+00', 'Jill''s Hogmanay', 'JILLS HOGMANAY', 3, 32, 9999, 1, 4, 2, 118, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9748, '2000-12-14 23:00:00+00', '2012-01-20 12:57:15.78783+00', 'Hand in Glove', 'HAND IN GLOVE', 1, 32, 9999, 1, 4, 1, 2793, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9749, '2000-12-14 23:00:00+00', '2012-01-20 12:57:15.794691+00', 'Jig for Lillie, A', 'JIG FOR LILLIE', 2, 40, 9999, 1, 4, NULL, 2793, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9750, '2000-12-14 23:00:00+00', '2012-01-20 12:57:15.802239+00', 'Heritage Medley, The', 'HERITAGE MEDLEY', 4, 64, 5, 2, 3, 3, 118, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9751, '2000-12-14 23:00:00+00', '2012-01-20 12:57:15.809786+00', 'Ceilidh Caper', 'CEILIDH CAPER', 2, 32, 9999, 2, 3, 18, 2793, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9754, '2000-12-14 23:00:00+00', '2018-04-03 00:07:31.93864+00', 'Bajan Reel', 'BAJAN REEL', 1, 32, 9999, 1, 3, 42, 394, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9771, '2001-01-18 23:00:00+00', '2018-04-03 00:07:33.424161+00', 'Birkhall', 'BIRKHALL', 1, 40, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9778, '2001-03-13 23:00:00+00', '2019-08-29 17:12:38.142904+00', 'Jitka''s Dance', 'JITKAS DANCE', 1, 32, 9999, 5, 2, NULL, 401, '1998-01-01', 'This dance was written the first week of August, 1998, at the Prague Scottish Dance Week by Ron Wallace and Muriel Johnstone dedicated to the organizer and miracle worker Jitka Bonusova.  The tune, "Dvorana", was written by Muriel Johnstone and takes its name from the Dance Company that organizes dance weeks in Prague.  Thank you Jitka!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9763, '2001-01-18 23:00:00+00', '2012-01-20 12:57:15.894975+00', 'Crosshill Capers', 'CROSSHILL CAPERS', 99, 0, 9999, 5, 99, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9729, '2000-11-17 23:00:00+00', '2018-04-03 00:07:51.707133+00', 'Helderberg Reel, The', 'HELDERBERG REEL', 1, 32, 9999, 1, 3, 42, 447, '1989-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9777, '2001-05-03 22:00:00+00', '2018-04-03 00:08:14.809857+00', 'Salute to South Simcoe', 'SALUTE TO SOUTH SIMCOE', 3, 32, 9999, 1, 3, 42, 2833, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13628, '2010-11-07 23:00:00+00', '2016-05-15 21:30:56.388037+00', 'Triple Treat', 'TRIPLE TREAT', 4, 128, 2, 107, 53, 3, 228, '2005-07-01', 'A 64-bar strathspey/64-bar reel demonstration medley for three dancers in a line', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13626, '2010-11-07 23:00:00+00', '2016-06-03 13:34:52.536752+00', '(Other) Hungarian Bride, The', 'OTHER HUNGARIAN BRIDE', 2, 32, NULL, 1, 3, 42, 228, '2010-10-04', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13608, '2010-09-20 22:00:00+00', '2017-02-07 20:00:24.773792+00', 'Ken and Lavinia Morris', 'KEN AND LAVINIA MORRIS', 3, 32, 9999, 1, 4, 2, 505, '2003-01-01', 'Devised: 2003', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9730, '2000-11-17 23:00:00+00', '2018-04-03 00:08:06.603825+00', 'Mrs Robertson''s Reel', 'MRS ROBERTSONS REEL', 1, 40, 9999, 1, 3, 42, 2830, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13606, '2010-09-20 22:00:00+00', '2017-02-11 23:52:50.351267+00', 'Red Rum', 'RED RUM', 2, 32, 9999, 1, 3, 42, 505, '2000-05-01', 'Devised: 2000-05', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9731, '2000-11-17 23:00:00+00', '2018-04-03 00:08:13.509015+00', 'Rondebosch Reel, The', 'RONDEBOSCH REEL', 1, 32, 9999, 1, 3, 42, 2819, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9780, '2001-03-13 23:00:00+00', '2023-02-06 10:35:43.779904+00', 'Laura''s Ceilidh', 'LAURAS CEILIDH', 2, 32, 9999, 1, 3, 42, 401, '1998-10-15', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9737, '2000-11-17 23:00:00+00', '2018-04-03 00:08:15.318534+00', 'Scottish Country Dancer''s Pleasure, A', 'SCOTTISH COUNTRY DANCERS PLEASURE', 3, 32, 9999, 1, 3, 42, 447, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9736, '2000-11-17 23:00:00+00', '2018-04-03 00:08:21.798022+00', 'Tribute to Archie', 'TRIBUTE TO ARCHIE', 3, 32, 9999, 1, 3, 42, 2832, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13652, '2011-03-21 23:00:00+00', '2018-04-03 00:18:02.179063+00', 'G/J Strathspey, The', 'G/J STRATHSPEY', 3, 32, 9999, 2, 2, 76, 23, '2005-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9806, '2001-03-26 22:00:00+00', '2018-04-03 00:07:30.944667+00', 'Anstruther Lassies', 'ANSTRUTHER LASSIES', 1, 40, 9999, 1, 3, 42, 50, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9841, '2005-12-21 23:00:00+00', '2018-04-03 00:18:02.363828+00', 'Pippa''s Jig', 'PIPPAS JIG', 2, 32, 9999, 2, 2, 76, 3412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9796, '2001-03-13 23:00:00+00', '2012-01-20 12:57:16.129468+00', 'Petaluma Queen, The', 'PETALUMA QUEEN', 3, 40, 9999, 2, 3, 30, 3549, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9797, '2001-03-13 23:00:00+00', '2012-01-20 12:57:16.136365+00', 'Quicksilver Jig, The', 'QUICKSILVER JIG', 2, 32, 9999, 5, 56, NULL, 952, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9781, '2001-03-13 23:00:00+00', '2018-04-29 21:16:50.502705+00', 'Marghie''s Wedding', 'MARGHIES WEDDING', 1, 32, 9999, 1, 3, 42, 401, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14355, '2011-12-14 23:00:00+00', '2018-08-17 12:27:54.700797+00', 'Old Ba'' Game, The', 'OLD BA GAME', 1, 32, NULL, 1, 4, 1, 2932, '2008-01-01', 'Good music: Duke of Perth encore, Terpsichore, Caledonian Muse,  or any good pipe tune.



Devised after reading a wonderful feature in the Washington Post about the Christmas Ba'' game on Kirkwall, Orkney (see http://www.bagame.com/main.html), to evoke the up and down energy of the event. I called it Uppies and Doonies until I found out there was already a dance by that name. So I stole the Post headline, The Old Ba'' Game.', 81, '8080  8888  8484  8888', 0, 0, 0, 0, 81);
INSERT INTO 'dance' VALUES (9801, '2001-03-13 23:00:00+00', '2012-01-20 12:57:16.163414+00', 'Seton Links', 'SETON LINKS', 2, 24, 9999, 1, 2, NULL, 3549, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9805, '2001-03-26 22:00:00+00', '2012-01-20 12:57:16.193455+00', 'Willie''s Girl', 'WILLIES GIRL', 1, 48, 9999, 1, 4, NULL, 50, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15484, '2014-06-27 20:56:08.949743+00', '2019-01-22 22:48:09.189067+00', 'Ben''s Jig', 'BENS JIG', 2, 32, NULL, 1, 3, 42, 10971, NULL, 'The dance is inscribed as "a small memento for my grandson".', 69, '888/888/888/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10221, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.404174+00', 'Mike''s Magic', 'MIKES MAGIC', 2, 40, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9828, '2001-04-25 22:00:00+00', '2021-06-08 10:35:34.988156+00', 'Westhill Reel', 'WESTHILL REEL', 1, 64, 9999, 2, 3, 17, 165, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13610, '2010-09-21 22:00:00+00', '2021-01-01 18:56:20.548852+00', 'Fulwood Favourite, A', 'FULWOOD FAVOURITE', 2, 32, 9999, 1, 3, 42, 10241, '2008-01-01', 'Devised: 2008', 56, '800/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9844, '2002-04-11 22:00:00+00', '2021-02-18 11:23:48.577831+00', 'Cheshire Cat, The', 'CHESHIRE CAT', 2, 32, 9999, 1, 3, 42, 2863, NULL, '', 53, '800/888/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9837, '2001-07-25 22:00:00+00', '2021-02-18 15:25:23.350108+00', 'Angela''s Jig', 'ANGELAS JIG', 2, 32, 9999, 1, 3, 42, 372, '1998-01-01', '', 63, '880/808/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9774, '2002-06-04 22:00:00+00', '2021-02-20 20:26:20.736135+00', 'Alex T Queen', 'ALEX T QUEEN', 1, 48, 9999, 1, 4, 2, 316, NULL, '', 79, '8008/8448/8888/8888/8448/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9766, '2002-04-03 22:00:00+00', '2021-02-20 20:49:19.630326+00', 'Muirs of Greywell, The', 'MUIRS OF GREYWELL', 2, 32, 9999, 1, 3, 42, 104, '1994-08-01', 'Devised for Ian & Liz Muir who live in the village of Greywell.', 63, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9753, '2002-03-03 23:00:00+00', '2021-05-09 10:02:53.732346+00', 'MacLachlan Jig, The', 'MACLACHLAN JIG', 2, 32, 9999, 1, 4, 2, 1024, '1996-06-01', 'Devised for a weekend party at the summer residence of Elma and Duncan MacLachlan at Lake Kashwakamak.', 88, '8080/8888/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9807, '2001-12-02 23:00:00+00', '2012-01-20 12:57:16.206971+00', 'Happy 75th', 'HAPPY 75TH', 4, 196, 53, 1, 4, NULL, 50, '1998-01-01', 'Composed from: Deil Amang the Tailors, Petronella, Glasgow Highlanders, Circassian Circle, Mairi''s Wedding', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9821, '2001-04-25 22:00:00+00', '2012-01-20 12:57:16.310087+00', 'Westhill Strathspey', 'WESTHILL STRATHSPEY', 3, 32, 9999, 2, 3, 17, 165, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9823, '2001-04-25 22:00:00+00', '2012-01-20 12:57:16.324317+00', 'Shush!', 'SHUSH', 1, 32, 9999, 1, 4, 5, 165, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9773, '2001-01-31 23:00:00+00', '2013-11-27 01:45:40.675093+00', 'Millennium Welcome, A', 'MILLENNIUM WELCOME', 4, 128, 2, 4, 4, NULL, 872, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13649, '2011-03-09 23:00:00+00', '2012-01-20 12:57:47.868506+00', 'Three And Three', 'THREE AND THREE', 1, 32, NULL, 2, 3, 18, 10309, '2010-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13651, '2011-03-21 23:00:00+00', '2012-01-20 12:57:47.883964+00', 'Washington Barnes'' Dance, The', 'WASHINGTON BARNES DANCE', 1, 32, 9999, 5, 2, 30, 2782, '1986-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9798, '2001-03-13 23:00:00+00', '2018-04-03 00:08:12.525045+00', 'Reflections in Loch Awe', 'REFLECTIONS IN LOCH AWE', 3, 24, 9999, 1, 3, 42, 3549, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13653, '2011-03-21 23:00:00+00', '2012-01-20 12:57:47.898436+00', 'Jack''s Farewell To The Ladies', 'JACKS FAREWELL TO THE LADIES', 3, 32, 9999, 1, 2, NULL, 2684, '1988-10-24', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9825, '2001-04-25 22:00:00+00', '2012-01-20 12:57:16.33862+00', 'Kilrenny Jig', 'KILRENNY JIG', 2, 40, 9999, 3, 5, 6, 165, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9826, '2001-04-25 22:00:00+00', '2012-01-20 12:57:16.346126+00', 'Rambling Rose', 'RAMBLING ROSE', 2, 48, 9999, 1, 4, 1, 165, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9827, '2001-04-25 22:00:00+00', '2012-01-20 12:57:16.353611+00', 'Bonaly Burn', 'BONALY BURN', 2, 32, 9999, 3, 5, 6, 165, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9799, '2001-03-13 23:00:00+00', '2018-04-03 00:08:13.342153+00', 'Road to Zamora, The', 'ROAD TO ZAMORA', 2, 24, 9999, 1, 3, 42, 3549, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13655, '2011-03-21 23:00:00+00', '2012-01-20 12:57:47.917911+00', 'Maggie''s Compact', 'MAGGIES COMPACT', 2, 32, 9999, 2, 3, 17, 10311, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13630, '2010-11-10 23:00:00+00', '2017-10-22 20:24:17.324405+00', 'Apple for Ann Murray, An', 'APPLE FOR ANN MURRAY', 2, 32, 9999, 1, 4, 2, 10287, '1996-08-01', 'A Note from "The Vienna Book":  

When pupils in Austria do their exercises extraordinarily well the teacher will reward them not only with the best mark “1” but with an “I” (Roman One), which is represented by bars 9–24. The title of this dance originates from the tradition of giving an apple to a teacher.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9822, '2001-04-25 22:00:00+00', '2016-07-21 23:14:52.7435+00', 'Knockando', 'KNOCKANDO', 1, 96, 9999, 4, 4, NULL, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13650, '2011-03-21 23:00:00+00', '2016-05-15 22:27:18.339902+00', 'Culloden Jig', 'CULLODEN JIG', 2, 32, 9999, 6, 53, 17, 10322, '2000-04-09', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9808, '2001-03-27 22:00:00+00', '2017-02-25 03:55:48.454584+00', 'Where No One Has Gone Before', 'WHERE NO ONE HAS GONE BEFORE', 2, 40, 9999, 1, 4, 2, 2203, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13632, '2010-11-10 23:00:00+00', '2017-10-22 20:26:30.61519+00', 'Heiko''s, actually', 'HEIKOS ACTUALLY', 2, 40, 9999, 1, 4, 5, 10290, '2009-02-14', 'A Note from "The Vienna Book":  

Devised by Beate Seybold for Heiko Schmidt to mark the occasion of his 40th birthday.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13633, '2010-11-10 23:00:00+00', '2017-10-22 20:29:23.419947+00', 'Manhattan is a Beach', 'MANHATTAN IS A BEACH', 1, 32, 9999, 1, 4, 2, 589, '2000-01-01', 'Dedicated to Fred DeMarse.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13634, '2010-11-10 23:00:00+00', '2017-10-22 20:30:00.577888+00', '39th Step, The', '39TH STEP', 1, 32, 9999, 1, 4, 2, 589, '2000-01-01', 'Dedicated to Fred DeMarse.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13641, '2010-11-10 23:00:00+00', '2017-10-22 20:56:05.939257+00', 'With Compliments (to Susi Mayr)', 'WITH COMPLIMENTS TO SUSI MAYR', 3, 32, 9999, 1, 4, 1, 10288, '2001-01-01', 'A Note from "The Vienna Book":  

Devised by Beatrix Wepner for Susi Mayr to thank her for the brilliant organisation of the Vienna Workshop 2001.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18986, '2018-10-17 12:33:14.650445+00', '2018-10-17 12:33:14.650445+00', 'Charlotte''s Knot', 'CHARLOTTES KNOT', 3, 32, NULL, 2, 3, 17, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18987, '2018-10-17 12:34:42.758879+00', '2018-10-17 12:34:42.758879+00', 'Dancing Dunelmians, The', 'DANCING DUNELMIANS', 1, 32, NULL, 1, 100, 2, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18988, '2018-10-17 12:35:58.990875+00', '2019-01-29 00:19:23.861488+00', 'Dashing Douglas, The', 'DASHING DOUGLAS', 2, 32, NULL, 1, 3, 42, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10002, '2001-07-19 22:00:00+00', '2012-01-20 12:57:17.711101+00', 'Jarig Jetje', 'JARIG JETJE', 1, 32, 9999, 1, 2, NULL, 1049, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9831, '2002-08-29 22:00:00+00', '2022-12-19 14:31:57.895938+00', 'Janus', 'JANUS', 1, 64, 9999, 8, 6, 25, 2861, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13667, '2011-03-22 23:00:00+00', '2012-01-20 12:57:48.015036+00', 'Do We Hear The Music, Pony?', 'DO WE HEAR THE MUSIC PONY', 1, 32, 9999, 1, 4, 1, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9879, '2001-06-04 22:00:00+00', '2019-03-04 13:41:29.992651+00', 'Pearl & Jack Sinclair', 'PEARL AND JACK SINCLAIR', 3, 32, 9999, 1, 4, 1, 2892, NULL, '', 78, '4884/8448/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13657, '2011-03-21 23:00:00+00', '2018-04-03 00:07:37.378869+00', 'Catherine''s Engagement', 'CATHERINES ENGAGEMENT', 3, 32, 9999, 1, 3, 42, 10312, '1998-07-05', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9867, '2001-07-25 22:00:00+00', '2019-03-05 00:28:05.121183+00', 'Joe''s Reel', 'JOES REEL', 1, 32, 9999, 3, 5, 7, 692, '1998-01-01', '', 60, '80800/63663/63663/80888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9887, '2001-05-30 22:00:00+00', '2021-02-15 12:02:08.919531+00', 'Road to Alhambra', 'ROAD TO ALHAMBRA', 2, 40, 9999, 1, 4, 1, 2705, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9873, '2001-05-30 22:00:00+00', '2021-02-16 12:02:59.784267+00', 'Memories of Arran', 'MEMORIES OF ARRAN', 3, 96, 9999, 4, 4, 3, 2886, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9870, '2001-06-04 22:00:00+00', '2021-02-17 11:51:54.494839+00', 'Ken Mill''s Reel', 'KEN MILLS REEL', 1, 48, 9999, 1, 4, 2, 2891, NULL, '', 88, '8888/8888/8888/8448/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9868, '2002-03-11 23:00:00+00', '2021-02-17 14:03:44.133707+00', 'Kirrie Boys, The', 'KIRRIE BOYS', 2, 32, 9999, 1, 4, 13, 2705, NULL, '', 94, '8888/8888/8880/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9866, '2002-03-11 23:00:00+00', '2021-02-17 14:06:55.508261+00', 'Jimmy Shore''s Fancy', 'JIMMY SHORES FANCY', 1, 32, 9999, 1, 4, 2, 9998, NULL, '', 88, '8880/8884/8888/6688', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9863, '2001-05-20 22:00:00+00', '2021-02-17 14:14:48.229441+00', 'Hairste''en Jig', 'HAIRSTEEN JIG', 2, 32, 9999, 5, 56, NULL, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9857, '2001-10-25 22:00:00+00', '2021-02-17 19:52:36.402436+00', 'Fig Tree Bay', 'FIG TREE BAY', 2, 32, 9999, 1, 4, 1, 2705, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9856, '2002-12-17 23:00:00+00', '2021-02-17 19:55:50.614743+00', 'Farm House Jig', 'FARM HOUSE JIG', 2, 32, 9999, 1, 4, 2, 2673, NULL, '', 62, '8888/8008/8008/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9852, '2002-03-03 23:00:00+00', '2021-02-18 11:00:40.109205+00', 'Easter Reel', 'EASTER REEL', 1, 32, 9999, 1, 4, 2, 575, NULL, '', 88, '8888/8888/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9845, '2001-06-28 22:00:00+00', '2021-02-18 11:19:26.964704+00', 'Chimney Sweep', 'CHIMNEY SWEEP', 1, 32, 9999, 1, 3, 42, 21, NULL, 'Bars 9-16: Muirland Willie upside down', 63, '880/888/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9847, '2002-11-12 23:00:00+00', '2021-02-18 11:09:26.019367+00', 'Crown House', 'CROWN HOUSE', 1, 32, 9999, 1, 3, 42, 2673, NULL, '', 56, '800/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9834, '2002-03-12 23:00:00+00', '2021-02-18 15:28:03.010245+00', 'Marmalade Sandwich, The', 'MARMALADE SANDWICH', 1, 48, 9999, 1, 4, 1, 550, '2001-01-01', '', 71, '4444/4444/8888/8000/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9814, '2001-10-22 22:00:00+00', '2021-02-19 15:00:04.734663+00', 'Mrs Ernest Allan''s Strathspey', 'MRS ERNEST ALLANS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 2851, NULL, '<<ddp:Main, Nan#1607>>, a well known Scottish Country Dance composer and pianist, *was* Mrs Ernest Allan.



A "wee bourachie" is a tight group or cluster. (Mrs Cramb''s words.)', 75, '8448/8008/8888/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9883, '2002-08-06 22:00:00+00', '2021-04-05 20:26:17.76708+00', 'Red Rose of Lancaster, The', 'RED ROSE OF LANCASTER', 1, 128, 9999, 7, 5, 3, 534, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9848, '2001-10-25 22:00:00+00', '2021-04-05 20:30:15.509091+00', 'Deeside Banner', 'DEESIDE BANNER', 3, 32, 9999, 2, 3, NULL, 1324, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13658, '2011-03-21 23:00:00+00', '2018-04-03 00:07:39.968196+00', 'Crazy Cake Mix', 'CRAZY CAKE MIX', 1, 32, 9999, 1, 3, 42, 10313, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13668, '2011-03-22 23:00:00+00', '2012-01-20 12:57:48.024544+00', 'Double Delight', 'DOUBLE DELIGHT', 3, 32, 9999, 1, 4, 2, 10319, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13669, '2011-03-22 23:00:00+00', '2012-01-20 12:57:48.034113+00', 'Elk River Strathspey', 'ELK RIVER STRATHSPEY', 3, 40, 9999, 1, 4, 1, 10318, '2010-04-01', 'Published in "Thistle XXX - We Dance Therefore We Dine": http://my.strathspey.org/dd/publ/1026/', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13670, '2011-03-22 23:00:00+00', '2012-01-20 12:57:48.043822+00', 'Let Me Show You My Kilt', 'LET ME SHOW YOU MY KILT', 3, 32, 9999, 1, 4, 2, 10310, '1998-01-14', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13671, '2011-03-22 23:00:00+00', '2012-01-20 12:57:48.053552+00', 'Pirate King''s Rant, The', 'PIRATE KINGS RANT', 1, 32, 9999, 1, 4, 1, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13672, '2011-03-22 23:00:00+00', '2012-01-20 12:57:48.063075+00', 'Robin''s Nest', 'ROBINS NEST', 1, 32, 9999, 1, 4, 1, 10320, '2001-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13673, '2011-03-22 23:00:00+00', '2012-01-20 12:57:48.072693+00', 'Flight of the Robins, The', 'FLIGHT OF THE ROBINS', 1, 32, 9999, 2, 3, 17, 10320, '2001-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13674, '2011-03-22 23:00:00+00', '2012-01-20 12:57:48.082305+00', 'Score and Five at Thistle, A', 'SCORE AND FIVE AT THISTLE', 1, 32, 9999, 1, 4, 1, 10321, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13678, '2011-04-25 22:00:00+00', '2012-01-20 12:57:48.116452+00', 'Never Again!!!', 'NEVER AGAIN', 1, 48, 9999, NULL, NULL, NULL, 2419, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9854, '2002-10-13 22:00:00+00', '2019-03-05 00:37:55.644559+00', 'Falkirk Millennium Wheel', 'FALKIRK MILLENNIUM WHEEL', 1, 96, 9999, 4, 4, 3, 2694, NULL, '', 67, '8888/8888/8080/0808/8080/0808/4444/4444/8080/0808/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13675, '2011-03-22 23:00:00+00', '2016-10-29 11:37:56.473834+00', 'XXX Dance, The', 'XXX DANCE', 3, 32, 9999, 1, 4, 1, 2107, '2010-01-01', '', 81, '8888/8440/8448/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13660, '2011-03-21 23:00:00+00', '2018-04-03 00:07:51.575708+00', 'Heavenly Dancers, The', 'HEAVENLY DANCERS', 3, 32, 9999, 1, 3, 42, 10314, '2009-07-01', 'Published in "Thistle XXX - We Dance Therefore We Dine": http://my.strathspey.org/dd/publ/1026/', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13659, '2011-03-21 23:00:00+00', '2018-04-03 00:07:54.978181+00', 'JanieLuv', 'JANIELUV', 1, 32, 9999, 1, 3, 42, 23, '1996-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13661, '2011-03-21 23:00:00+00', '2018-04-03 00:07:55.461745+00', 'Jig for Janie, A', 'JIG FOR JANIE', 2, 40, 9999, 1, 3, 42, 10317, '1997-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13663, '2011-03-21 23:00:00+00', '2018-04-03 00:08:14.843224+00', 'Samhain Magic', 'SAMHAIN MAGIC', 1, 32, 9999, 1, 3, 42, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13664, '2011-03-21 23:00:00+00', '2018-04-03 00:08:20.705619+00', 'Thistle Progression a.k.a. Coming Along Nicely', 'THISTLE PROGRESSION AKA COMING ALONG NICELY', 1, 32, 9999, 1, 3, 42, 10310, '1997-07-06', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13665, '2011-03-22 23:00:00+00', '2018-04-03 00:08:21.506148+00', 'Tom''s Rant', 'TOMS RANT', 1, 32, 9999, 1, 3, 42, 23, '2006-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13666, '2011-03-22 23:00:00+00', '2018-04-03 00:08:21.56464+00', 'Torf''s Seventy-Fifth', 'TORFS SEVENTYFIFTH', 3, 32, 9999, 1, 3, 42, 23, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9931, '2001-06-05 22:00:00+00', '2018-04-02 23:56:33.062376+00', 'Blainslie Fancy, The', 'BLAINSLIE FANCY', 1, 32, 9999, 1, 3, 42, 101, NULL, 'For Robert and Marjorie Hamilton from Blainslie in the Scottish Borders.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9924, '2001-05-24 22:00:00+00', '2018-04-03 00:07:37.762726+00', 'Celtic Mystery', 'CELTIC MYSTERY', 1, 32, 9999, 1, 3, 42, 352, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9927, '2001-06-05 22:00:00+00', '2018-07-17 08:59:39.081152+00', 'Chris in the Kitchen', 'CHRIS IN THE KITCHEN', 1, 32, 9999, 1, 3, 42, 101, NULL, 'For Chris Adam who has spent much time in charge of catering for several international festivals run by Dunedin Dancers.', 53, '844/844/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9898, '2003-02-23 23:00:00+00', '2018-07-29 22:46:45.463833+00', 'Silver Hamer, The', 'SILVER HAMER', 3, 32, 9999, 2, 3, 17, 1760, '2003-01-01', '', 62, '808/008/228/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13682, '2011-06-13 22:00:00+00', '2012-02-25 21:23:09.490932+00', 'Reels of Dunans, The', 'REELS OF DUNANS', 1, 32, NULL, 1, 3, 42, 10333, NULL, 'Dunans in Glendaruel, Cowal, Argyllshire.  



The first 16 bars have been dubbed "Dunans Reels".  These are modified Mirror Reels of three on the sides, 2nd cpl starting in and up.  All couples follow the same track: as each couple arrives from above in 2nd place they cross down to 3rd place on the other side.  After 8 bars all are on opposite side (1x,2x,3x).  Back home after 16 bars.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13683, '2011-06-13 22:00:00+00', '2012-02-25 21:36:19.124446+00', 'Birthday Present, The', 'BIRTHDAY PRESENT', 3, 32, NULL, 1, 3, 42, 10333, NULL, 'The figures evoke the wrapping of a birthday present.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13684, '2011-06-14 22:00:00+00', '2012-02-25 23:21:56.114116+00', 'Montgomeri Strathspey, The', 'MONTGOMERI STRATHSPEY', 3, 32, NULL, 2, 3, 17, 347, NULL, 'Named after the drive in which I live; I cannot explain the unusual spelling!', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9920, '2001-05-24 22:00:00+00', '2018-04-03 00:07:40.23212+00', 'Cross Stitch', 'CROSS STITCH', 1, 40, 9999, 1, 3, 42, 352, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10005, '2001-08-19 22:00:00+00', '2012-01-20 12:57:17.737524+00', 'Our Kitty', 'OUR KITTY', 2, 32, 9999, 1, 4, NULL, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13692, '2011-06-27 22:00:00+00', '2012-01-20 12:57:48.240083+00', 'Vollmerz Square Eight, The', 'VOLLMERZ SQUARE EIGHT', 2, 128, NULL, 4, 4, 3, 228, NULL, 'Devised: 2002-08', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9912, '2001-05-24 22:00:00+00', '2012-01-20 12:57:16.966675+00', 'Koru', 'KORU', 2, 32, 9999, 1, 4, 1, 352, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13677, '2011-04-25 22:00:00+00', '2021-01-01 18:42:15.718502+00', 'Gus''s Reel', 'GUSS REEL', 1, 40, 9999, 3, 5, 16, 2419, '2010-03-01', '', 58, '80800/80800/80066/88888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9858, '2002-11-12 23:00:00+00', '2021-01-01 19:47:54.968939+00', 'Ford Strathspey, The', 'FORD STRATHSPEY', 3, 32, 9999, 2, 3, 17, 2673, NULL, '', 83, '888/888/484/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9894, '2001-05-20 22:00:00+00', '2021-02-15 10:58:34.460264+00', 'Stirling Millennium Reel', 'STIRLING MILLENNIUM REEL', 1, 40, 9999, 1, 100, 2, 246, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9893, '2001-05-30 22:00:00+00', '2021-02-15 11:01:18.266327+00', 'Snowdonia Reel, The', 'SNOWDONIA REEL', 1, 32, 9999, 1, 4, 2, 2886, '1991-01-01', '', 75, '8008/8888/8008/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9891, '2001-10-23 22:00:00+00', '2021-02-15 11:07:08.801489+00', 'Sandwood Bay', 'SANDWOOD BAY', 3, 32, 9999, 1, 4, 1, 2892, NULL, '', 72, '8888/4004/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9886, '2001-06-04 22:00:00+00', '2021-02-15 12:09:24.986849+00', 'Renali Strathspey, The', 'RENALI STRATHSPEY', 3, 32, 9999, 2, 3, 4, 2892, NULL, '', 96, '888/888/888/686', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9885, '2002-03-03 23:00:00+00', '2021-02-15 18:12:05.094898+00', 'Reel of Four Diamonds', 'REEL OF FOUR DIAMONDS', 1, 32, 9999, 1, 4, 2, 9998, NULL, '', 88, '8448/8448/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9884, '2001-06-04 22:00:00+00', '2021-02-15 18:20:37.223468+00', 'Redundancy Dance', 'REDUNDANCY DANCE', 1, 88, 9999, 4, 4, 3, 3312, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9877, '2001-05-30 22:00:00+00', '2021-02-15 21:31:17.878527+00', 'New Alliance', 'NEW ALLIANCE', 3, 32, 9999, 1, 3, 42, 2887, NULL, '', 53, '804/808/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9872, '2001-07-25 22:00:00+00', '2021-02-16 12:43:02.427895+00', 'Longhandled Broom, The', 'LONGHANDLED BROOM', 3, 32, 9999, 1, 3, 42, 21, NULL, '', 69, '888/888/880/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9865, '2001-06-04 22:00:00+00', '2021-02-17 14:10:07.234107+00', 'Jig for Jane', 'JIG FOR JANE', 2, 32, 9999, 1, 3, 42, 3312, NULL, '', 44, '880/800/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9859, '2001-05-20 22:00:00+00', '2021-02-17 19:46:46.235971+00', 'Furthermore', 'FURTHERMORE', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13644, '2011-01-14 23:00:00+00', '2021-04-04 10:59:38.501831+00', 'Jet Set Hornpipe, The', 'JET SET HORNPIPE', 1, 32, NULL, 1, 3, 42, 228, '2010-07-07', '', 50, '880/844/844/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9913, '2001-05-24 22:00:00+00', '2012-01-20 12:57:16.974217+00', 'Snowball Twister', 'SNOWBALL TWISTER', 2, 32, 9999, 1, 4, 2, 352, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9914, '2001-05-24 22:00:00+00', '2012-01-20 12:57:16.981771+00', 'Dawning, The', 'DAWNING', 2, 32, 9999, 1, 4, 11, 352, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9915, '2001-05-24 22:00:00+00', '2012-01-20 12:57:16.989383+00', 'Travelling On', 'TRAVELLING ON', 3, 32, 9999, 1, 4, 5, 352, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9916, '2001-05-24 22:00:00+00', '2012-01-20 12:57:16.997351+00', 'Band of Gold', 'BAND OF GOLD', 3, 32, 9999, 1, 4, 13, 352, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9917, '2001-05-24 22:00:00+00', '2012-01-20 12:57:17.004965+00', 'Caroline''s Wedding', 'CAROLINES WEDDING', 3, 32, 9999, 1, 4, 15, 352, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9918, '2001-05-24 22:00:00+00', '2012-01-20 12:57:17.012538+00', 'Feet on Fire', 'FEET ON FIRE', 1, 32, 9999, 1, 4, 1, 352, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9919, '2001-05-24 22:00:00+00', '2012-01-20 12:57:17.020112+00', 'Stone of Scone', 'STONE OF SCONE', 1, 32, 9999, 1, 4, 1, 352, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9907, '2002-08-06 22:00:00+00', '2019-03-04 13:13:07.448544+00', 'Wirral in Gladenbach', 'WIRRAL IN GLADENBACH', 1, 32, 9999, 4, 4, 13, 2919, NULL, '', 88, '4444/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9928, '2001-06-05 22:00:00+00', '2019-10-04 01:43:51.342097+00', 'Janeil Strathspey, The', 'JANEIL STRATHSPEY', 3, 32, 9999, 2, 3, 18, 101, '1995-01-01', 'For the wedding of Jane and Neil Duncan from Caribou, BC, in March 1995.', 75, '888/800/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9925, '2001-05-24 22:00:00+00', '2018-04-03 00:07:50.708424+00', 'Happiness Is', 'HAPPINESS IS', 1, 32, 9999, 1, 3, 42, 352, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9923, '2001-05-24 22:00:00+00', '2018-04-03 00:08:13.142006+00', 'River Dance Reel', 'RIVER DANCE REEL', 1, 32, 9999, 1, 3, 42, 352, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9910, '2002-11-14 23:00:00+00', '2018-04-03 00:08:15.53532+00', 'Second-Hand Rose', 'SECONDHAND ROSE', 2, 32, 9999, 1, 3, 42, 2488, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13694, '2011-06-27 22:00:00+00', '2012-01-20 12:57:48.260146+00', 'Station Street Strathspey, The', 'STATION STREET STRATHSPEY', 3, 32, NULL, 2, 3, 17, 228, NULL, 'Devised: 2006-05', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13695, '2011-06-28 22:00:00+00', '2012-01-20 12:57:48.268946+00', 'Chemistry', 'CHEMISTRY', 3, 40, NULL, 1, 4, 1, 10343, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13688, '2011-06-14 22:00:00+00', '2015-02-15 10:17:22.522342+00', 'Three Shires, The', 'THREE SHIRES', 1, 32, NULL, 1, 3, 42, 104, NULL, 'Devised for the RSCDS Border Branch', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9921, '2001-05-24 22:00:00+00', '2018-04-03 00:08:19.905228+00', 'Tap Your Feet', 'TAP YOUR FEET', 1, 32, 9999, 1, 3, 42, 352, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13691, '2011-06-27 22:00:00+00', '2016-06-03 13:53:14.463506+00', 'Twists and Turns', 'TWISTS AND TURNS', 3, 32, NULL, 1, 3, 42, 228, NULL, 'Devised: 2002-05', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13687, '2011-06-14 22:00:00+00', '2017-01-05 23:56:51.050756+00', 'Gin and Tonic, A', 'GIN AND TONIC', 4, 192, 3, 2, 3, 17, 10336, NULL, 'This dance consists of 32 bars of strathspey, danced three times through, and 32 bars of reel, danced three times through.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9932, '2001-06-05 22:00:00+00', '2017-02-23 19:54:59.920437+00', 'Perfect Blend, The', 'PERFECT BLEND', 1, 32, 9999, 4, 4, 4, 101, '1996-01-01', 'For the wedding of Rosalie Wilkie and Jan Van outrive in April 1996.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9938, '2001-06-05 22:00:00+00', '2018-08-13 22:34:41.413127+00', 'Auld Acquaintance', 'AULD ACQUAINTANCE', 1, 32, 9999, 1, 3, 42, 101, NULL, '', 50, '800/880/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9935, '2001-06-05 22:00:00+00', '2012-01-20 12:57:17.136648+00', 'Edinburgh''s Welcome', 'EDINBURGHS WELCOME', 1, 32, 9999, 4, 4, NULL, 101, '1997-01-01', 'For demonstration with the groups visiting the international festival run by Dunedin Dancers in 1997.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9982, '2001-06-17 22:00:00+00', '2018-04-03 00:07:35.968616+00', 'Broughty Flittin'', The', 'BROUGHTY FLITTIN', 2, 32, 9999, 1, 3, 42, 2913, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9949, '2001-06-12 22:00:00+00', '2012-01-20 12:57:17.237779+00', 'Bonnie Buchanhaven', 'BONNIE BUCHANHAVEN', 3, 32, 9999, 1, 4, NULL, 514, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9950, '2001-06-12 22:00:00+00', '2012-01-20 12:57:17.246272+00', 'Avis''s Fancy', 'AVISS FANCY', 2, 32, 9999, 2, 3, 17, 1, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9951, '2001-06-12 22:00:00+00', '2012-01-20 12:57:17.255684+00', 'Dunblane Capers', 'DUNBLANE CAPERS', 2, 48, 9999, 7, 98, NULL, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9953, '2001-06-12 22:00:00+00', '2012-01-20 12:57:17.276406+00', 'Ramble with Ruby, A', 'RAMBLE WITH RUBY', 3, 32, 9999, 4, 4, NULL, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9954, '2001-06-12 22:00:00+00', '2012-01-20 12:57:17.283755+00', 'Ochlochy Park', 'OCHLOCHY PARK', 2, 32, 9999, 5, 2, NULL, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9955, '2001-06-12 22:00:00+00', '2012-01-20 12:57:17.291004+00', 'Bridge of Allan Jig', 'BRIDGE OF ALLAN JIG', 2, 32, 9999, 1, 2, NULL, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9956, '2001-06-12 22:00:00+00', '2012-01-20 12:57:17.298568+00', 'Gathering Stone, The', 'GATHERING STONE', 1, 32, 9999, 5, 56, NULL, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9939, '2001-06-05 22:00:00+00', '2018-07-17 06:42:27.208321+00', 'Buchan Lass, The', 'BUCHAN LASS', 2, 32, 9999, 1, 100, 2, 101, '1978-01-01', 'For the wedding of Lori and Jay Conant from New Hampshire, in 1978.', 81, '8008/8888/8888/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9958, '2001-06-12 22:00:00+00', '2012-01-20 12:57:17.31602+00', 'Fourways Roundabout', 'FOURWAYS ROUNDABOUT', 3, 32, 9999, 4, 4, NULL, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13710, '2011-07-04 22:00:00+00', '2012-01-20 12:57:48.386234+00', 'Buckle O'' Me Belt, The', 'BUCKLE O ME BELT', 1, 32, NULL, 1, 4, NULL, 3095, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13689, '2011-06-14 22:00:00+00', '2022-09-30 19:45:58.04948+00', 'Salute to the Borders', 'SALUTE TO THE BORDERS', 3, 32, NULL, 1, 3, 42, 104, NULL, 'Devised for the RSCDS Border Branch', 50, '800/844/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9901, '2001-06-04 22:00:00+00', '2022-09-30 20:22:22.3652+00', 'Wee Millie', 'WEE MILLIE', 3, 24, 9999, 1, 3, 42, 2895, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9895, '2002-04-14 22:00:00+00', '2022-12-05 10:50:33.172162+00', 'Swans on the Tweed', 'SWANS ON THE TWEED', 3, 40, 9999, 4, 4, 54, 3579, NULL, '', 80, '6666/6666/6666/6666/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13712, '2011-07-08 22:00:00+00', '2012-01-20 12:57:48.402713+00', 'Dance for Joyce', 'DANCE FOR JOYCE', 3, 40, NULL, 1, 4, 1, 10346, '2007-01-01', 'Devised for the pleasure of dancing, but especially for my granddaughter Joyce.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9976, '2002-04-30 22:00:00+00', '2018-04-03 00:07:41.625055+00', 'Dear Little Angels, The', 'DEAR LITTLE ANGELS', 3, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18509, '2018-08-18 10:14:16.979418+00', '2020-11-16 21:34:19.023792+00', 'Until We Meet Again', 'UNTIL WE MEET AGAIN', 1, 32, NULL, 5, 56, NULL, 2886, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9974, '2002-01-06 23:00:00+00', '2021-02-14 12:33:46.809084+00', 'Andrew Carnegie', 'ANDREW CARNEGIE', 3, 32, 9999, 1, 3, 42, 1500, '1984-01-01', '', 59, '886/868/844/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9947, '2001-06-12 22:00:00+00', '2021-02-14 12:37:30.891733+00', 'Jovial Gentleman, The', 'JOVIAL GENTLEMAN', 2, 48, 9999, 3, 5, 16, 335, NULL, '', 75, '08080/88888/44444/88888/80808/88888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9941, '2001-06-05 22:00:00+00', '2021-02-14 20:30:48.630022+00', 'Kestrel, The', 'KESTREL', 3, 32, 9999, 2, 3, 18, 101, NULL, 'For Stewart Adam''s 50th birthday.', 83, '888/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9937, '2002-02-12 23:00:00+00', '2021-02-14 20:33:19.842546+00', 'Stephen''s Strathspey', 'STEPHENS STRATHSPEY', 3, 32, 9999, 3, 5, 7, 101, NULL, 'For Stephen Gibson.', 70, '80800/88888/80800/88888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9902, '2001-06-04 22:00:00+00', '2021-02-14 20:43:30.869318+00', 'Welcome to Kilmorack', 'WELCOME TO KILMORACK', 1, 32, 9999, 1, 3, 42, 2893, NULL, '', 69, '880/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13704, '2011-07-04 22:00:00+00', '2021-03-03 14:27:19.699919+00', 'Tornado', 'TORNADO', 2, 32, NULL, 1, 4, 1, 10356, NULL, '', 69, '8888/4884/0844/0088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13703, '2011-07-04 22:00:00+00', '2021-03-03 14:44:34.435195+00', 'Sunplaza', 'SUNPLAZA', 3, 32, NULL, 1, 3, 42, 10357, NULL, '', 63, '888/880/880/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13702, '2011-07-04 22:00:00+00', '2021-03-03 22:10:32.225239+00', 'Masako Okada Naitoh', 'MASAKO OKADA NAITOH', 3, 32, NULL, 1, 4, 1, 1836, '2007-05-01', 'Devised: 2007-05', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13700, '2011-07-04 22:00:00+00', '2021-03-03 22:22:57.365503+00', 'Fun For The Young', 'FUN FOR THE YOUNG', 1, 32, NULL, 3, 5, 7, 10357, NULL, '', 68, '86806/82842/86846/82842', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9922, '2001-05-24 22:00:00+00', '2021-03-22 16:53:07.234149+00', 'Southern Aurora', 'SOUTHERN AURORA', 1, 32, 9999, 1, 3, 42, 352, '1998-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9945, '2001-06-17 22:00:00+00', '2019-02-08 17:53:36.809364+00', 'Daunder in the Glen', 'DAUNDER IN THE GLEN', 3, 32, 9999, 1, 4, 1, 511, NULL, '', 94, '8888/8888/8888/0888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9946, '2001-06-12 22:00:00+00', '2012-01-27 11:30:06.240984+00', 'Jaunty Jack', 'JAUNTY JACK', 1, 32, 9999, 1, 3, 42, 88, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9960, '2001-06-12 22:00:00+00', '2012-01-20 12:57:17.334047+00', 'Billy Thom''s Reel', 'BILLY THOMS REEL', 1, 32, 9999, 6, 3, NULL, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9961, '2001-06-12 22:00:00+00', '2012-01-20 12:57:17.34278+00', 'Cath Petrie''s Lilt', 'CATH PETRIES LILT', 3, 40, 9999, 1, 4, NULL, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9964, '2001-06-12 22:00:00+00', '2012-01-20 12:57:17.368786+00', 'Fraser''s Fling', 'FRASERS FLING', 3, 48, 9999, 5, 2, NULL, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9965, '2001-06-12 22:00:00+00', '2012-01-20 12:57:17.377482+00', 'Allanside Amble, The', 'ALLANSIDE AMBLE', 2, 32, 9999, 6, 3, NULL, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9966, '2001-06-12 22:00:00+00', '2012-01-20 12:57:17.386158+00', 'Bonfire Reel, The', 'BONFIRE REEL', 1, 0, 9999, 99, 99, NULL, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9971, '2001-06-28 22:00:00+00', '2012-01-20 12:57:17.430359+00', 'Red Biretta Reel, The', 'RED BIRETTA REEL', 1, 32, 9999, 1, 4, NULL, 2907, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9973, '2001-06-17 22:00:00+00', '2012-01-20 12:57:17.447784+00', 'Bill Forrester''s Jig', 'BILL FORRESTERS JIG', 2, 32, 9999, 1, 4, NULL, 2910, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9975, '2002-04-30 22:00:00+00', '2012-01-20 12:57:17.466277+00', 'Craigie''s Welcome', 'CRAIGIES WELCOME', 3, 32, 9999, 4, 4, 1, 2911, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9977, '2001-06-28 22:00:00+00', '2012-01-20 12:57:17.483605+00', 'Greetings from Dundee', 'GREETINGS FROM DUNDEE', 2, 32, 9999, 1, 4, NULL, 1038, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9978, '2002-12-08 23:00:00+00', '2012-01-20 12:57:17.492272+00', 'Diana, Queen of Our Hearts', 'DIANA QUEEN OF OUR HEARTS', 3, 32, 9999, 1, 4, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9979, '2001-06-17 22:00:00+00', '2012-01-20 12:57:17.50096+00', 'Bob Duff Strathspey, The', 'BOB DUFF STRATHSPEY', 3, 40, 9999, 4, 4, NULL, 2913, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9981, '2002-02-27 23:00:00+00', '2012-01-20 12:57:17.518417+00', 'Bonnie Lass o'' Fyvie', 'BONNIE LASS O FYVIE', 3, 32, 9999, 1, 4, NULL, 2913, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13711, '2011-07-04 22:00:00+00', '2015-03-03 22:41:04.366058+00', 'Washing-Go-Round', 'WASHINGGOROUND', 2, 32, NULL, 1, 4, NULL, 3095, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13714, '2011-07-08 22:00:00+00', '2018-04-03 00:07:45.97902+00', 'First result', 'FIRST RESULT', 2, 32, NULL, 1, 3, 42, 10350, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9934, '2001-06-05 22:00:00+00', '2016-05-29 05:56:31.944783+00', 'Dunedin Quadrille', 'DUNEDIN QUADRILLE', 10, 32, 9999, 7, 4, 4, 101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9962, '2001-06-12 22:00:00+00', '2018-04-03 00:07:57.555116+00', 'Kippendavie Rant', 'KIPPENDAVIE RANT', 2, 48, 9999, 1, 3, 42, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9952, '2001-06-12 22:00:00+00', '2018-04-03 00:08:01.750074+00', 'Malcolm Wilson''s Reel', 'MALCOLM WILSONS REEL', 1, 32, 9999, 1, 3, 42, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9957, '2001-06-12 22:00:00+00', '2018-04-03 00:08:03.684831+00', 'Milton Brae Twostep', 'MILTON BRAE TWOSTEP', 2, 32, 9999, 1, 3, 42, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13708, '2011-07-04 22:00:00+00', '2018-04-03 00:08:13.150365+00', 'River of Coke', 'RIVER OF COKE', 3, 32, NULL, 1, 3, 42, 3095, '1998-08-01', 'Devised: 1998-08', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13707, '2011-07-04 22:00:00+00', '2018-04-03 00:08:18.429119+00', 'Steller''s Jay Jig', 'STELLERS JAY JIG', 2, 32, NULL, 1, 3, 42, 3095, '2001-01-01', 'Devised: 2001', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13718, '2011-07-08 22:00:00+00', '2018-04-03 00:08:21.556197+00', 'Topsy-Turvy', 'TOPSYTURVY', 1, 32, NULL, 1, 3, 42, 10355, '2007-01-01', '"Topsy-Turvy = upside down, chaos"', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9963, '2001-06-12 22:00:00+00', '2018-04-03 00:08:21.839752+00', 'Tribute to Nanette, A', 'TRIBUTE TO NANETTE', 1, 32, 9999, 1, 3, 42, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9959, '2001-06-12 22:00:00+00', '2018-04-03 00:08:22.448317+00', 'Trip to Braco, A', 'TRIP TO BRACO', 2, 32, 9999, 1, 3, 42, 991, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9968, '2001-06-13 22:00:00+00', '2012-02-09 00:30:10.618162+00', 'Lodge Gardens, The', 'LODGE GARDENS', 3, 32, 9999, 1, 4, 1, 2889, '1998-01-01', 'The prize winning entry of the competition.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10004, '2001-07-19 22:00:00+00', '2018-04-29 22:21:20.18297+00', 'Bell-Founders, The', 'BELLFOUNDERS', 1, 32, 9999, 1, 3, 42, 2917, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9970, '2001-06-13 22:00:00+00', '2012-02-22 22:36:56.127433+00', 'Stone of Destiny, The', 'STONE OF DESTINY', 2, 40, 9999, 1, 4, NULL, 2889, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9988, '2001-06-21 22:00:00+00', '2012-01-20 12:57:17.581057+00', 'Circle of Friendship, The', 'CIRCLE OF FRIENDSHIP', 2, 32, 9999, 5, 2, NULL, 2913, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9991, '2001-07-19 22:00:00+00', '2012-01-20 12:57:17.609055+00', 'Halfway to Silver', 'HALFWAY TO SILVER', 4, 32, 1, 1, 4, 1, 2118, '1988-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10017, '2001-08-19 22:00:00+00', '2019-03-03 20:19:47.661359+00', 'Farewell to the OTC', 'FAREWELL TO THE OTC', 1, 32, 9999, 1, 4, 1, 2922, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9994, '2001-07-19 22:00:00+00', '2012-01-20 12:57:17.63703+00', 'Strathspey for Kieran, A', 'STRATHSPEY FOR KIERAN', 3, 32, 9999, 1, 4, 2, 2795, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9996, '2001-07-18 22:00:00+00', '2012-01-20 12:57:17.655224+00', 'Lilian''s Wedding', 'LILIANS WEDDING', 2, 96, 9999, 3, 5, NULL, 1049, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9997, '2001-07-19 22:00:00+00', '2012-01-20 12:57:17.664899+00', 'Long John''s Birthday', 'LONG JOHNS BIRTHDAY', 1, 32, 9999, 1, 4, 1, 1049, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13735, '2011-07-10 22:00:00+00', '2019-05-29 21:58:37.55748+00', 'Roundabout Reel', 'ROUNDABOUT REEL', 1, 40, 9999, 4, 4, NULL, 10366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9908, '2001-05-20 22:00:00+00', '2022-09-09 20:30:48.312309+00', 'Wrexham Ladies', 'WREXHAM LADIES', 2, 32, 9999, 1, 102, 1, 1019, NULL, 'Devised by Betty Smart, the Teacher at Wrexham and District Caledonian Association, in the late 1980’s when the group had no male members.', 59, '4444/8888/8400/8044', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13891, '2011-08-22 22:00:00+00', '2023-02-09 21:46:59.782308+00', 'Tyneside Ceilidh', 'TYNESIDE CEILIDH', 1, 32, NULL, 7, 98, 30, 2788, '2000-03-01', 'The notes say this "was written to finish a medley of dances performed on stage in March 2000 by the demonstration team of the Newcastle and District Branch of the RSCDS in a concert jointly given with the Glasgow Phoenix choir."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10020, '2001-08-19 22:00:00+00', '2018-04-03 00:07:33.674559+00', 'Blainslie Reel', 'BLAINSLIE REEL', 1, 32, 9999, 1, 3, 42, 617, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13731, '2011-07-10 22:00:00+00', '2012-01-20 12:57:48.551402+00', 'St Ninian''s Strathspey', 'SAINT NINIANS STRATHSPEY', 3, 32, NULL, 1, 4, 1, 10360, NULL, 'Devised: 2005



St Ninian''s is the name of the school where the Monday Branch class is held and Teresa has taught there since 2001.  Pianist, Beryl Livingston played for the class for many years and composed the music in 2005 when the dance was devised', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13738, '2011-07-10 22:00:00+00', '2019-05-29 22:00:24.943171+00', 'Birthday Medley, The', 'BIRTHDAY MEDLEY', 4, 128, 2, 4, 4, NULL, 10367, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9943, '2001-06-05 22:00:00+00', '2020-09-09 13:16:10.493183+00', 'Two Roses', 'TWO ROSES', 3, 32, 9999, 1, 3, 42, 101, '1994-01-01', 'For the wedding of Cathy Clowes and Donald Harley in September 1994.', 56, '800/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13725, '2011-07-09 22:00:00+00', '2020-09-19 21:06:08.787003+00', 'Just Around the Corner', 'JUST AROUND THE CORNER', 3, 32, NULL, 1, 3, 42, 175, NULL, '', 47, '800/844/844/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13737, '2011-07-10 22:00:00+00', '2020-12-31 12:02:57.984182+00', 'Normal for Norfolk', 'NORMAL FOR NORFOLK', 3, 32, 9999, 1, 3, 42, 10362, NULL, '', 61, '806/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13736, '2011-07-10 22:00:00+00', '2020-12-31 12:25:21.880444+00', 'Golden Moments', 'GOLDEN MOMENTS', 1, 32, NULL, 3, 5, 7, 10365, NULL, '', 71, '86886/08800/88800/68888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13734, '2011-07-10 22:00:00+00', '2020-12-31 12:30:51.102625+00', 'Norwich Assembly', 'NORWICH ASSEMBLY', 3, 32, NULL, 2, 3, 17, 10364, NULL, '', 67, '800/888/844/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10015, '2001-08-19 22:00:00+00', '2021-02-13 15:34:39.512636+00', 'Doobri, The', 'DOOBRI', 3, 32, 9999, 3, 5, 7, 21, NULL, '', 55, '80800/84884/80800/80844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10022, '2002-08-29 22:00:00+00', '2021-07-29 17:18:57.945682+00', 'Autumn Sky, The', 'AUTUMN SKY', 3, 32, 9999, 1, 3, 42, 2923, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13741, '2011-07-10 22:00:00+00', '2019-05-29 22:04:07.056512+00', 'Embroidery Strathspey', 'EMBROIDERY STRATHSPEY', 3, 32, 9999, 1, 4, 1, 10369, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9987, '2001-06-21 22:00:00+00', '2018-04-03 00:07:39.281313+00', 'Compliments to a Nurse', 'COMPLIMENTS TO A NURSE', 3, 32, 9999, 1, 3, 42, 619, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10027, '2001-09-02 22:00:00+00', '2012-01-20 12:57:17.997875+00', 'Applegreene', 'APPLEGREENE', 1, 32, 9999, 1, 4, NULL, 9, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10029, '2001-09-02 22:00:00+00', '2012-01-20 12:57:18.015465+00', 'Brig o'' Balkerach, The', 'BRIG O BALKERACH', 3, 32, 9999, 1, 4, NULL, 9, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10021, '2001-08-19 22:00:00+00', '2018-04-03 00:07:40.840874+00', 'Dance for Lisbeth, A', 'DANCE FOR LISBETH', 1, 32, 9999, 1, 3, 42, 617, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9995, '2001-07-18 22:00:00+00', '2018-04-03 00:07:51.527025+00', 'Heather Ross MacDonald', 'HEATHER ROSS MACDONALD', 3, 32, 9999, 1, 3, 42, 2795, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9990, '2001-07-18 22:00:00+00', '2018-04-03 00:07:52.467992+00', 'Holiday Reel, A', 'HOLIDAY REEL', 1, 32, 9999, 1, 3, 42, 2918, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10018, '2001-08-19 22:00:00+00', '2018-04-03 00:07:52.659804+00', 'Hornet''s Nest, The', 'HORNETS NEST', 1, 32, 9999, 1, 3, 42, 108, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10026, '2001-09-02 22:00:00+00', '2015-09-19 21:59:21.180592+00', 'Aloha Lui Noa', 'ALOHA LUI NOA', 1, 32, 9999, 1, 3, 42, 9, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10030, '2001-09-02 22:00:00+00', '2015-09-19 22:02:23.226782+00', 'Calziebohalzie', 'CALZIEBOHALZIE', 2, 32, 9999, 1, 2, NULL, 9, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10032, '2001-09-02 22:00:00+00', '2015-09-19 22:03:06.243708+00', 'Comet, The', 'COMET', 1, 32, 9999, 1, 3, 42, 9, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10033, '2001-09-02 22:00:00+00', '2015-09-19 22:03:57.823236+00', 'Fairbridge Boy, The', 'FAIRBRIDGE BOY', 1, 32, 9999, 1, 3, 42, 9, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10034, '2001-09-02 22:00:00+00', '2015-09-19 22:21:55.947392+00', 'Geordie Hinny', 'GEORDIE HINNY', 1, 32, 9999, 2, 3, 17, 9, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10028, '2001-09-02 22:00:00+00', '2015-11-09 20:23:30.870258+00', 'Bankhead Boy, The', 'BANKHEAD BOY', 2, 32, 9999, 1, 3, 42, 9, '1995-03-01', '', 44, '800/844/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9972, '2001-06-28 22:00:00+00', '2016-10-02 18:48:32.980597+00', 'Barr''s Wedding Birl', 'BARRS WEDDING BIRL', 1, 32, 9999, 1, 3, 42, 11249, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9969, '2001-06-13 22:00:00+00', '2018-04-03 00:07:59.164887+00', 'Lazy Daisy, The', 'LAZY DAISY', 3, 32, 9999, 1, 3, 42, 2905, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13715, '2011-07-08 22:00:00+00', '2018-04-03 00:07:59.715189+00', 'Linge River Dance, The', 'LINGE RIVER DANCE', 1, 32, NULL, 1, 3, 42, 10351, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13716, '2011-07-08 22:00:00+00', '2018-04-03 00:08:03.059207+00', 'Memory, The', 'MEMORY', 3, 32, NULL, 1, 3, 42, 10352, '2007-01-01', 'Dedicated to the memory of Jan Helmig.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9992, '2001-07-18 22:00:00+00', '2018-04-03 00:08:10.039619+00', 'Pauline Cathcart''s Strathspey', 'PAULINE CATHCARTS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1049, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10025, '2002-08-29 22:00:00+00', '2018-04-03 00:08:12.508306+00', 'Reely Quick Across', 'REELY QUICK ACROSS', 1, 16, 9999, 1, 3, 42, 2924, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10024, '2002-08-29 22:00:00+00', '2018-04-03 00:08:12.516836+00', 'Reely Quick On the Sides', 'REELY QUICK ON THE SIDES', 1, 16, 9999, 1, 3, 42, 2924, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10001, '2001-07-19 22:00:00+00', '2018-04-03 00:08:23.60758+00', 'Van Riel''s Reel', 'VAN RIELS REEL', 1, 40, 9999, 1, 3, 42, 1049, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9993, '2001-07-18 22:00:00+00', '2018-04-03 00:08:26.809964+00', 'Wonderful Time in the Warenar', 'WONDERFUL TIME IN THE WARENAR', 1, 32, 9999, 1, 3, 42, 1049, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10101, '2005-03-03 23:00:00+00', '2018-04-03 00:07:31.462519+00', 'Audrey''s Awa''', 'AUDREYS AWA', 3, 32, 9999, 1, 3, 42, 9, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10037, '2001-09-02 22:00:00+00', '2012-01-20 12:57:18.085876+00', 'Miss Nora Kearsley', 'MISS NORA KEARSLEY', 3, 32, 9999, 1, 4, NULL, 9, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10042, '2001-09-02 22:00:00+00', '2012-01-20 12:57:18.125852+00', 'Welcoming Frog, The', 'WELCOMING FROG', 3, 32, 9999, 1, 4, NULL, 9, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10064, '2001-09-10 22:00:00+00', '2018-04-26 16:34:49.346873+00', 'Reel Millennium Bug, The', 'REEL MILLENNIUM BUG', 1, 120, 9999, 4, 119, 3, 127, '1999-11-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10044, '2001-09-02 22:00:00+00', '2012-01-20 12:57:18.140124+00', 'Westbury Gardens', 'WESTBURY GARDENS', 2, 32, 9999, 1, 4, 1, 2925, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10045, '2001-09-02 22:00:00+00', '2012-01-20 12:57:18.147568+00', 'Level Crossing', 'LEVEL CROSSING', 3, 32, 9999, 1, 4, 1, 2925, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10043, '2001-09-02 22:00:00+00', '2018-04-03 00:07:56.262396+00', 'John''s Domesday Book', 'JOHNS DOMESDAY BOOK', 1, 48, 9999, 1, 3, 42, 2925, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10091, '2001-09-20 22:00:00+00', '2018-04-03 00:07:56.579108+00', 'Jubilee Strathspey', 'JUBILEE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 619, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10050, '2001-09-02 22:00:00+00', '2018-10-01 08:44:17.160428+00', 'Quark''s Jig', 'QUARKS JIG', 2, 128, 9999, 1, 4, NULL, 2928, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10047, '2001-09-02 22:00:00+00', '2018-04-03 00:08:03.376031+00', 'Midnight Madness', 'MIDNIGHT MADNESS', 1, 40, 9999, 1, 3, 42, 2926, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10222, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.410946+00', 'Swirling Spey', 'SWIRLING SPEY', 3, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10103, '2001-10-04 22:00:00+00', '2021-02-12 11:13:27.11306+00', 'Airs & Graces', 'AIRS AND GRACES', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10062, '2001-09-09 22:00:00+00', '2021-01-08 19:59:07.792286+00', 'Lindisfarne Reel, The', 'LINDISFARNE REEL', 1, 32, 9999, 3, 5, 7, 2563, NULL, '', 72, '82848/80800/84884/86888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10095, '2002-10-20 22:00:00+00', '2021-02-12 13:03:00.628863+00', 'Never Look Back', 'NEVER LOOK BACK', 1, 40, 9999, 1, 3, 42, 108, '2000-01-01', '', 60, '848/888/848/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10065, '2001-09-09 22:00:00+00', '2021-02-12 18:53:44.583355+00', 'On Suilven in Summer', 'ON SUILVEN IN SUMMER', 2, 32, 9999, 1, 3, 42, 127, NULL, '', 47, '880/880/808/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10063, '2001-09-09 22:00:00+00', '2021-02-12 19:02:35.35644+00', 'Maidenhead Golden Medley', 'MAIDENHEAD GOLDEN MEDLEY', 4, 128, 2, 4, 4, 3, 127, '2001-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14845, '2013-05-18 21:45:20.289501+00', '2018-04-03 00:07:53.368722+00', 'Inca Springs, The', 'INCA SPRINGS', 1, 40, 9999, 1, 3, 42, 17, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10061, '2001-09-10 22:00:00+00', '2021-02-12 19:05:06.122912+00', 'Home Farm Trust Reel, The', 'HOME FARM TRUST REEL', 1, 32, 9999, 1, 3, 42, 127, '1988-01-01', '', 50, '800/880/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10060, '2001-09-10 22:00:00+00', '2021-02-12 19:57:37.162475+00', 'Hobson''s Choice', 'HOBSONS CHOICE', 4, 128, 2, 1, 3, 42, 127, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10059, '2001-09-10 22:00:00+00', '2021-02-13 12:31:25.992572+00', 'Green Isle Bridge, The', 'GREEN ISLE BRIDGE', 2, 32, 9999, 1, 3, 42, 127, NULL, '', 56, '888/800/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10058, '2001-09-10 22:00:00+00', '2021-02-13 12:40:08.251835+00', 'Golden Anniversary Strathspey', 'GOLDEN ANNIVERSARY STRATHSPEY', 3, 32, 9999, 1, 4, 11, 127, '2000-01-01', 'Devised for Stan and Jeanette Ward on the occasion of their Golden Wedding (March 2000).', 88, '4884/8888/4884/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10023, '2002-08-29 22:00:00+00', '2021-02-13 15:28:18.203404+00', 'Quicksilver Reel, The', 'QUICKSILVER REEL', 2, 40, 9999, 1, 3, 42, 2924, '2000-01-01', '', 35, '800/008/080/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10046, '2001-09-02 22:00:00+00', '2021-04-08 12:50:22.058337+00', 'Royal Stirling Square', 'ROYAL STIRLING SQUARE', 3, 32, 9999, 4, 4, 13, 515, '1996-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10051, '2002-09-22 22:00:00+00', '2021-07-30 07:40:27.252493+00', 'Dancer''s Web, The', 'DANCERS WEB', 1, 32, 9999, 1, 3, 42, 308, NULL, '', 53, '840/880/866/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10098, '2001-09-20 22:00:00+00', '2012-01-20 12:57:18.537514+00', 'Kerry''s Jig', 'KERRYS JIG', 1, 32, 9999, 1, 4, 1, 2934, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10099, '2001-09-20 22:00:00+00', '2012-01-20 12:57:18.54505+00', 'Kilchurn Romance', 'KILCHURN ROMANCE', 3, 32, 9999, 1, 4, 2, 108, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10100, '2001-09-20 22:00:00+00', '2012-01-20 12:57:18.551902+00', 'Langtoun Medley, The', 'LANGTOUN MEDLEY', 4, 64, 5, 4, 4, NULL, 2935, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10104, '2001-10-04 22:00:00+00', '2015-01-30 13:24:53.713616+00', 'Border Jig', 'BORDER JIG', 2, 32, 9999, 1, 2, NULL, 9998, NULL, '', 52, '80/80/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10035, '2001-09-02 22:00:00+00', '2015-09-19 22:04:47.519228+00', 'J & A Jig, The', 'J AND A JIG', 2, 32, 9999, 1, 3, 42, 9, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10041, '2001-09-02 22:00:00+00', '2015-09-19 22:06:42.502515+00', 'Sweetie Sandy', 'SWEETIE SANDY', 3, 32, 9999, 2, 3, 17, 9, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10039, '2001-09-02 22:00:00+00', '2015-09-19 22:14:07.979171+00', 'Saint Edmond''s Reel', 'SAINT EDMONDS REEL', 1, 32, 9999, 1, 3, 42, 9, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10036, '2001-09-02 22:00:00+00', '2015-09-19 22:18:18.037276+00', 'Mrs Mary Dopson', 'MRS MARY DOPSON', 3, 32, 9999, 1, 3, 42, 9, NULL, 'TO CELEBRATE MARY''S 80TH BIRTHDAY.   THE FIRST 16 BARS OUTLINE THE NUMBER 80', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10053, '2001-09-03 22:00:00+00', '2017-01-30 22:45:22.919359+00', 'Andrew''s Shield', 'ANDREWS SHIELD', 2, 32, 9999, 1, 3, 42, 2931, '1997-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10055, '2001-09-03 22:00:00+00', '2017-01-30 23:02:17.464466+00', 'Commencement 2000', 'COMMENCEMENT 2000', 3, 32, 9999, 1, 2, NULL, 2932, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10054, '2001-09-03 22:00:00+00', '2017-01-30 23:07:00.784672+00', 'Dream Angus', 'DREAM ANGUS', 3, 32, 9999, 1, 3, 42, 2931, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10094, '2001-09-20 22:00:00+00', '2017-05-27 23:33:26.84788+00', 'Out of This World', 'OUT OF THIS WORLD', 2, 32, 9999, 1, 4, 2, 108, '2000-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10121, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.710303+00', 'Brisbane River Reel', 'BRISBANE RIVER REEL', 1, 40, 9999, 3, 4, NULL, 2605, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10122, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.717108+00', 'Banana Benders, The', 'BANANA BENDERS', 2, 32, 9999, 1, 2, NULL, 2949, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10123, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.724001+00', 'Tribute to Miss Milligan, A', 'TRIBUTE TO MISS MILLIGAN', 3, 32, 9999, 1, 4, NULL, 2951, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18989, '2018-10-17 12:38:28.725519+00', '2018-10-17 12:38:28.725519+00', 'Dorothy Dickson', 'DOROTHY DICKSON', 3, 32, NULL, 2, 3, 17, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10125, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.7376+00', 'Karen & Ian''s Wedding', 'KAREN AND IANS WEDDING', 2, 32, 9999, 99, 3, NULL, 2953, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10127, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.751268+00', 'Caledonian Capers', 'CALEDONIAN CAPERS', 2, 32, 9999, 99, 3, NULL, 2950, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10128, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.759814+00', 'Carol''s Way', 'CAROLS WAY', 2, 40, 9999, 99, 3, NULL, 2954, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10130, '2002-04-19 22:00:00+00', '2012-01-20 12:57:18.773529+00', 'Maryborough Heritage City', 'MARYBOROUGH HERITAGE CITY', 3, 32, 9999, 99, 3, NULL, 2951, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10131, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.780309+00', 'Circle of Friends', 'CIRCLE OF FRIENDS', 3, 96, 9999, 4, 4, NULL, 2955, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10132, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.787121+00', 'Cameron Reel, The', 'CAMERON REEL', 1, 32, 9999, 99, 3, NULL, 2951, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10133, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.793978+00', 'Birkdale Strathspey', 'BIRKDALE STRATHSPEY', 3, 32, 9999, 99, 3, NULL, 2950, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10134, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.801431+00', 'Fast & Furious', 'FAST AND FURIOUS', 1, 32, 9999, 1, 4, 2, 2956, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10135, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.808221+00', 'Reel Fun', 'REEL FUN', 1, 64, 9999, 99, 4, NULL, 2957, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10137, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.821745+00', 'Man Called Peter, A', 'MAN CALLED PETER', 1, 32, 9999, 99, 4, NULL, 2951, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10138, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.828548+00', 'Kirsten''s Welcome', 'KIRSTENS WELCOME', 3, 32, 9999, 1, 4, NULL, 2949, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10139, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.835285+00', 'Our Missing Friend', 'OUR MISSING FRIEND', 1, 32, 9999, 1, 98, NULL, 2959, NULL, 'One man missing!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10140, '2001-10-30 23:00:00+00', '2012-01-20 12:57:18.842037+00', 'Spider', 'SPIDER', 3, 32, 9999, 99, 4, NULL, 2960, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10146, '2001-10-25 22:00:00+00', '2012-01-20 12:57:18.883036+00', 'Reel Fridays', 'REEL FRIDAYS', 2, 96, 9999, 4, 4, NULL, 2942, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10157, '2001-12-03 23:00:00+00', '2019-01-27 20:24:11.551116+00', 'Census Day in Turkey', 'CENSUS DAY IN TURKEY', 1, 32, 9999, 1, 4, 1, 108, '2000-01-01', '', 63, '4884/4884/8000/0888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10159, '2001-10-23 22:00:00+00', '2019-02-08 18:00:08.551289+00', 'Crescent Moon, The', 'CRESCENT MOON', 1, 32, 9999, 1, 4, 2, 108, '2000-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10160, '2001-10-23 22:00:00+00', '2019-02-08 18:03:30.644454+00', 'Eternal Flame, The', 'ETERNAL FLAME', 1, 32, 9999, 1, 4, 11, 108, '2000-01-01', '', 100, '8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10152, '2005-01-19 23:00:00+00', '2021-02-11 10:19:42.039458+00', 'Heartbeat', 'HEARTBEAT', 3, 32, 9999, 2, 3, 17, 9998, NULL, '', 83, '880/888/808/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10108, '2001-10-04 22:00:00+00', '2021-02-12 11:05:57.068264+00', 'Provost''s Chain', 'PROVOSTS CHAIN', 3, 32, 9999, 4, 4, 13, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14221, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.822231+00', 'Forty''s Delight', 'FORTYS DELIGHT', 2, 32, NULL, 1, 4, 1, 10469, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10107, '2001-10-04 22:00:00+00', '2021-02-12 11:09:32.38507+00', 'Greengates of Fortrose', 'GREENGATES OF FORTROSE', 3, 48, 9999, 1, 4, 1, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10172, '2001-10-23 22:00:00+00', '2022-06-26 22:30:13.882281+00', 'Bow Belle, The', 'BOW BELLE', 2, 40, 9999, 1, 3, 42, 272, '1998-03-01', 'Devised for Vera Mitchell.', 60, '800/888/888/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10092, '2001-09-20 22:00:00+00', '2022-09-30 20:04:05.922565+00', '''Appy Dance, An', 'APPY DANCE', 1, 32, 9999, 1, 4, 2, 108, '2001-06-01', 'Inscribed "for Alice Mclean".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10106, '2001-10-04 22:00:00+00', '2021-02-12 11:11:20.598838+00', 'Lansdown Mirth', 'LANSDOWN MIRTH', 2, 32, 9999, 1, 4, 1, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10097, '2001-09-20 22:00:00+00', '2021-02-12 11:18:03.68045+00', 'Strathcarron', 'STRATHCARRON', 2, 32, 9999, 1, 4, 2, 108, '2000-01-01', '', 75, '6886/6886/8448/0088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10068, '2001-09-10 22:00:00+00', '2021-02-12 18:40:11.142682+00', 'Trip to Windsor, A', 'TRIP TO WINDSOR', 1, 48, 9999, 1, 100, 2, 127, '1997-01-01', 'Dance devised for Ann Baker and Alan Pfeiffer on the occasion of their marriage on 26th July 1997.', 81, '8448/8888/8888/8448/8448/2882', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10119, '2001-10-30 23:00:00+00', '2021-07-03 08:46:51.894056+00', 'Grace and Cromwell', 'GRACE AND CROMWELL', 3, 48, 9999, 1, 4, NULL, 2605, NULL, 'Devised for the 26th Australian Winter School held in Grace and Cromwell Colleges at the University of Queensland, St. Lucia, Brisbane, 2001.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10126, '2001-10-30 23:00:00+00', '2017-11-03 22:00:44.198993+00', 'Leeze Me10126', 'LEEZE ME10126', 3, 32, 9999, 99, 4, NULL, 363, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10124, '2001-10-30 23:00:00+00', '2018-04-03 00:08:16.852833+00', 'Silver Wedding Jig', 'SILVER WEDDING JIG', 2, 32, 9999, 1, 3, 42, 2952, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10141, '2001-10-22 22:00:00+00', '2019-02-22 12:12:34.775692+00', 'Alba Antics', 'ALBA ANTICS', 2, 32, 9999, 1, 4, 1, 2941, NULL, '', 81, '8888/6666/4642/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10164, '2001-10-23 22:00:00+00', '2019-02-22 12:16:06.904335+00', 'Peerie Towers, The', 'PEERIE TOWERS', 3, 32, 9999, 2, 3, 17, 108, '2000-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10161, '2001-10-23 22:00:00+00', '2019-03-03 19:55:38.344875+00', 'Follow Baha!', 'FOLLOW BAHA', 1, 32, 9999, 1, 4, 1, 108, '2000-01-01', '', 69, '8444/4444/8444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10147, '2002-04-30 22:00:00+00', '2019-03-03 20:09:39.04534+00', 'Rose of Saint Andrews, The', 'ROSE OF SAINT ANDREWS', 2, 40, 9999, 1, 4, 1, 520, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10142, '2001-10-25 22:00:00+00', '2019-05-26 16:18:27.863867+00', 'Dance for Grandma???, A', 'DANCE FOR GRANDMA', 2, 40, 9999, 1, 3, 42, 2942, NULL, '', 48, '800/866/800/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10149, '2003-01-09 23:00:00+00', '2019-05-26 23:04:34.44706+00', 'Ynyslas', 'YNYSLAS', 3, 32, 9999, 2, 3, 18, 2943, NULL, '', 92, '844/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10143, '2001-10-22 22:00:00+00', '2019-05-26 16:36:46.564127+00', 'Etta''s Walkabout', 'ETTAS WALKABOUT', 3, 32, 9999, 1, 3, 42, 2941, '1999-01-01', '', 58, '800/822/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10148, '2002-10-31 23:00:00+00', '2019-05-31 00:11:41.770382+00', 'Spot of Bother, A', 'SPOT OF BOTHER', 1, 32, 9999, 1, 3, 42, 1084, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10186, '2001-10-25 22:00:00+00', '2012-01-20 12:57:19.162185+00', 'Mr Alan Morrison', 'MR ALAN MORRISON', 4, 32, 9999, 1, 4, 2, 2913, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10187, '2001-10-25 22:00:00+00', '2012-01-20 12:57:19.169792+00', 'Netta''s Reel', 'NETTAS REEL', 3, 40, 9999, 2, 3, 17, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10189, '2001-10-27 22:00:00+00', '2012-01-20 12:57:19.184129+00', 'Karin''s Ceilidh', 'KARINS CEILIDH', 3, 32, 9999, 1, 4, 2, 479, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10181, '2001-10-23 22:00:00+00', '2019-02-22 12:40:15.331919+00', 'Haste to Hillockhead', 'HASTE TO HILLOCKHEAD', 2, 32, 9999, 1, 4, 1, 272, NULL, '', 84, '8008/8888/8888/4888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10190, '2001-10-27 22:00:00+00', '2018-04-03 00:07:33.265514+00', 'Beyond our Ken', 'BEYOND OUR KEN', 2, 32, 9999, 1, 3, 42, 479, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10182, '2001-10-23 22:00:00+00', '2019-02-22 12:44:49.103618+00', 'Prince O''er the Water', 'PRINCE OER THE WATER', 3, 32, 9999, 1, 4, 1, 965, NULL, '', 91, '8888/8888/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10156, '2001-10-23 22:00:00+00', '2019-03-03 20:02:26.658342+00', 'Cat-Walk, The', 'CATWALK', 2, 32, 9999, 1, 4, 2, 108, '2000-01-01', '', 75, '8008/8888/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10196, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.232509+00', 'Dubh Gall', 'DUBH GALL', 3, 32, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10197, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.239315+00', 'Finn Gall', 'FINN GALL', 1, 32, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10200, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.261699+00', 'Hereawa, Thereawa', 'HEREAWA THEREAWA', 3, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10204, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.288737+00', 'Gudeman of Day', 'GUDEMAN OF DAY', 3, 32, 9999, 4, 4, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10205, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.295501+00', 'Fa'' This', 'FA THIS', 2, 128, 9999, 4, 4, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10206, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.302282+00', 'Tap Ta Tae', 'TAP TA TAE', 3, 40, 9999, 4, 5, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10207, '2002-11-26 23:00:00+00', '2012-01-20 12:57:19.309033+00', 'Chappit Ten', 'CHAPPIT TEN', 1, 40, 9999, 4, 5, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10192, '2001-10-28 23:00:00+00', '2018-04-03 00:07:49.424322+00', 'Gordon''s Jig', 'GORDONS JIG', 2, 32, 9999, 1, 3, 42, 479, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10212, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.342983+00', 'Gaelic College Pipe Band''s Welcome Home', 'GAELIC COLLEGE PIPE BANDS WELCOME HOME', 4, 128, 2, 4, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10214, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.356631+00', 'Reeling On', 'REELING ON', 3, 32, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10215, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.363402+00', 'Link Aroon', 'LINK AROON', 11, 32, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10216, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.370171+00', 'Bobbit Reel', 'BOBBIT REEL', 3, 32, 9999, 1, 2, NULL, 2018, NULL, 'Music should be 6/8 time.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10217, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.376965+00', 'Linkin'' Ower the Lea', 'LINKIN OWER THE LEA', 2, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10218, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.383809+00', 'M and M''s Fancy', 'M AND MS FANCY', 3, 32, 9999, 2, 3, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10220, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.397403+00', 'Mary''s Delight', 'MARYS DELIGHT', 3, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10158, '2001-10-23 22:00:00+00', '2020-08-30 10:49:02.925427+00', 'Cocks of Denizli, The', 'COCKS OF DENIZLI', 1, 32, 9999, 1, 4, 2, 108, '2000-01-01', '', 69, '4884/4884/4884/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10162, '2001-10-23 22:00:00+00', '2020-09-10 10:59:09.846335+00', 'Lamartine', 'LAMARTINE', 4, 96, 42, 1, 100, 3, 108, '2000-01-01', '', 81, '8888/4884/8888/8888/8080/0808/8888/8888/4444/4444/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10165, '2001-10-23 22:00:00+00', '2020-09-10 18:14:01.826014+00', 'Raki Mountain Trail, The', 'RAKI MOUNTAIN TRAIL', 1, 32, 9999, 1, 3, 42, 108, '2000-01-01', '', 69, '888/888/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10175, '2001-10-23 22:00:00+00', '2020-09-10 18:33:56.942906+00', 'Dance for Denny', 'DANCE FOR DENNY', 2, 32, 9999, 2, 3, 17, 965, NULL, '', 63, '888/888/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10179, '2001-10-23 22:00:00+00', '2020-09-10 18:47:47.382561+00', 'Cromarty''s Sundance', 'CROMARTYS SUNDANCE', 1, 48, 9999, 1, 3, 42, 272, NULL, '', 42, '444/444/880/800/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10184, '2001-10-23 22:00:00+00', '2020-09-10 19:01:42.448957+00', 'Celtic Rose, The', 'CELTIC ROSE', 3, 64, 9999, 4, 4, 3, 273, NULL, '', 88, '8888/8888/4444/4444/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10185, '2001-10-23 22:00:00+00', '2020-09-10 19:05:47.758965+00', 'Cat''s Cradle', 'CATS CRADLE', 1, 32, 9999, 1, 3, 42, 272, NULL, '', 64, '888/888/820/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10180, '2001-10-23 22:00:00+00', '2021-02-10 14:54:09.637033+00', 'Groam House', 'GROAM HOUSE', 1, 40, 9999, 1, 4, 1, 272, '2000-05-01', '', 60, '4440/4440/8484/8888/8080', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10177, '2001-10-23 22:00:00+00', '2021-02-10 14:58:11.524355+00', 'Happy Couple, The', 'HAPPY COUPLE', 2, 40, 9999, 1, 4, 1, 2757, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10176, '2001-10-23 22:00:00+00', '2021-02-10 15:06:48.48717+00', 'Heston Jig, The', 'HESTON JIG', 2, 32, 9999, 4, 4, 1, 272, '1999-01-01', '', 69, '8686/8686/4444/0808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10173, '2001-10-23 22:00:00+00', '2021-02-10 17:42:26.528206+00', 'Lily Amangst the Heather', 'LILY AMANGST THE HEATHER', 3, 64, 9999, 4, 4, 3, 272, NULL, '', 91, '8888/8888/5555/8888/5555/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10163, '2002-01-08 23:00:00+00', '2021-02-11 09:44:02.945287+00', 'Magic Carpet, The', 'MAGIC CARPET', 2, 32, 9999, 1, 100, 2, 108, '2000-01-01', '', 88, '8008/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10086, '2001-09-12 22:00:00+00', '2022-07-21 16:55:20.332047+00', 'Susan', 'SUSAN', 3, 32, 9999, 2, 3, 17, 108, '2000-06-01', 'In memory of Susan Nedderman of Cambridge.', 50, '808/808/888/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10168, '2001-10-23 22:00:00+00', '2023-01-21 20:38:25.144645+00', 'Trip to Aphrodisia, A', 'TRIP TO APHRODISIA', 1, 32, 9999, 2, 3, 17, 108, '2000-01-01', '', 88, '888/848/888/088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10188, '2002-04-11 22:00:00+00', '2023-02-17 16:53:55.943112+00', 'Our Friend Bob', 'OUR FRIEND BOB', 2, 80, 9999, 1, 4, NULL, 2863, '1995-01-01', 'Bob was Alison''s husband; they met on the dance floor.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10154, '2001-11-07 23:00:00+00', '2021-02-11 09:46:41.32662+00', 'City of the Clyde', 'CITY OF THE CLYDE', 2, 32, 9999, 1, 3, 42, 1415, NULL, '', 50, '844/844/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10136, '2001-10-30 23:00:00+00', '2021-02-11 10:26:49.218914+00', 'Celtic Ribbons', 'CELTIC RIBBONS', 2, 40, 9999, 1, 3, 42, 2958, NULL, '', 60, '800/888/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10115, '2002-05-11 22:00:00+00', '2021-02-11 15:01:10.584406+00', 'Bishop of Columbus, The', 'BISHOP OF COLUMBUS', 1, 32, 9999, 1, 100, 2, 2677, NULL, '', 61, '7007/8008/8008/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10112, '2001-10-04 22:00:00+00', '2021-02-12 10:57:46.885692+00', 'Opo''s Frolics', 'OPOS FROLICS', 1, 32, 9999, 1, 3, 42, 2705, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10109, '2002-04-08 22:00:00+00', '2021-02-12 11:03:00.578835+00', 'Malcolm Strathspey, The', 'MALCOLM STRATHSPEY', 3, 32, 9999, 1, 4, 1, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10223, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.41784+00', 'Weel''s Me On the Birl', 'WEELS ME ON THE BIRL', 1, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10226, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.439565+00', 'Lemniscate', 'LEMNISCATE', 3, 32, 9999, 2, 3, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10227, '2001-11-06 23:00:00+00', '2012-01-20 12:57:19.446361+00', 'Highways and Byways', 'HIGHWAYS AND BYWAYS', 3, 32, 9999, 2, 3, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10230, '2001-11-07 23:00:00+00', '2012-01-20 12:57:19.466692+00', 'Light and Shade', 'LIGHT AND SHADE', 3, 32, 9999, 1, 4, NULL, 2962, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10225, '2001-11-06 23:00:00+00', '2015-04-05 10:32:02.807811+00', 'Spey in Spate', 'SPEY IN SPATE', 1, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10209, '2001-11-06 23:00:00+00', '2016-05-11 13:43:08.184401+00', 'Twasome Reel', 'TWASOME REEL', 4, 128, 2, 107, 1, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10210, '2001-11-06 23:00:00+00', '2016-05-11 13:43:52.171681+00', 'Scotia Threesome', 'SCOTIA THREESOME', 4, 128, 2, 6, 53, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10211, '2001-11-06 23:00:00+00', '2016-05-11 13:44:15.108357+00', 'Medley for Three', 'MEDLEY FOR THREE', 4, 96, 21, 105, 53, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10213, '2001-11-06 23:00:00+00', '2016-11-15 23:39:13.281886+00', 'Fivesome Reel', 'FIVESOME REEL', 4, 128, 2, 105, 55, NULL, 2018, NULL, 'Set: 5 dancers in a line facing the audience', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10203, '2001-11-06 23:00:00+00', '2017-02-15 13:53:46.730473+00', 'Reel Pets', 'REEL PETS', 1, 32, 9999, 2, 3, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10202, '2001-11-06 23:00:00+00', '2018-04-03 00:08:08.44674+00', 'O! For an Eagle', 'O FOR AN EAGLE', 3, 32, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10219, '2001-11-06 23:00:00+00', '2018-04-03 00:08:20.338707+00', 'Ted''s Flying Shuttle', 'TEDS FLYING SHUTTLE', 1, 32, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10201, '2001-11-06 23:00:00+00', '2018-04-03 00:08:24.566448+00', 'Weel Met', 'WEEL MET', 2, 32, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10234, '2001-11-25 23:00:00+00', '2012-01-20 12:57:19.494091+00', 'Marilynn Knight''s Delight', 'MARILYNN KNIGHTS DELIGHT', 3, 0, 9999, 99, 99, NULL, 1829, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10235, '2001-11-25 23:00:00+00', '2012-01-20 12:57:19.501872+00', 'Mingle, The', 'MINGLE', 4, 128, 2, 4, 4, 1, 1829, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10252, '2001-11-25 23:00:00+00', '2018-10-01 14:59:43.972336+00', 'Arches and Angles', 'ARCHES AND ANGLES', 1, 32, 9999, 1, 3, 42, 2766, '2001-04-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10237, '2001-11-25 23:00:00+00', '2018-10-05 07:32:07.705947+00', 'Fox River, The', 'FOX RIVER', 3, 32, 9999, 4, 4, 1, 2766, '2000-07-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10257, '2001-11-25 23:00:00+00', '2018-10-05 08:29:06.830181+00', 'Fun at Fermi', 'FUN AT FERMI', 2, 32, 9999, 1, 3, 42, 2766, '2001-04-01', 'Scottish dancing at Fermilab is always such fun, I thought it deserved a dance named after it.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10251, '2001-11-25 23:00:00+00', '2018-10-05 11:46:25.984092+00', 'Glen Cairn', 'GLEN CAIRN', 3, 32, 9999, 1, 3, 42, 2766, '2001-03-01', 'This dance was written because I wanted a 3 couple dance with a strathspey poussette and all the dances I found were 2 couple dances.  



Family folklore says the ancestral home was named Glen Cairn, so I named the dance for it.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10249, '2001-11-25 23:00:00+00', '2018-10-05 13:44:15.823721+00', 'Holly''s Joy', 'HOLLYS JOY', 2, 32, 9999, 1, 3, 42, 2766, '2001-02-01', 'This dance celebrates Holly Mocko’s return to health and dancing at Fermi.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10246, '2001-11-25 23:00:00+00', '2018-10-06 09:50:48.577155+00', 'Great Mandala, The', 'GREAT MANDALA', 2, 32, 9999, 1, 3, 42, 2766, '2000-12-01', 'Timing is everything in this dance as the figures are not symmetric.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10259, '2001-11-25 23:00:00+00', '2018-10-06 13:48:15.040626+00', 'Peony Flower, The', 'PEONY FLOWER', 3, 32, 9999, 1, 3, 42, 2766, '2001-07-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10248, '2001-11-25 23:00:00+00', '2018-10-07 11:14:56.941903+00', 'Reversal of Fortune', 'REVERSAL OF FORTUNE', 2, 32, 9999, 1, 3, 42, 2766, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10258, '2001-11-25 23:00:00+00', '2018-10-07 06:55:37.838705+00', 'Perpetual Motion', 'PERPETUAL MOTION', 3, 32, 9999, 1, 3, 42, 2766, '2001-05-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10266, '2001-11-25 23:00:00+00', '2018-10-08 18:17:04.305248+00', 'Memories of Skye', 'MEMORIES OF SKYE', 3, 32, 9999, 1, 3, 42, 2766, '2001-08-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10240, '2001-11-25 23:00:00+00', '2018-10-09 06:43:19.841375+00', 'T for Two', 'T FOR TWO', 3, 32, 9999, 107, 7, NULL, 2766, '2000-09-01', 'This dance is an attempt to create a 7-couple dance in T formation.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10260, '2001-11-25 23:00:00+00', '2018-10-09 10:16:13.202125+00', 'Tease, The', 'TEASE', 1, 32, 9999, 1, 3, 42, 2766, '2001-07-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10244, '2001-11-25 23:00:00+00', '2018-10-09 14:29:56.957029+00', 'Old Waterwheel, The', 'OLD WATERWHEEL', 1, 32, 9999, 1, 3, 42, 2766, '2000-11-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18992, '2018-10-17 12:42:12.274802+00', '2018-10-17 12:42:12.274802+00', 'G. W.', 'G W', 3, 32, NULL, 1, 4, NULL, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10276, '2001-11-29 23:00:00+00', '2012-01-20 12:57:19.878226+00', 'Shelly''s Wedding', 'SHELLYS WEDDING', 2, 48, 9999, 4, 4, NULL, 2968, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10277, '2001-11-29 23:00:00+00', '2012-01-20 12:57:19.8871+00', 'Mullen Compromise, The', 'MULLEN COMPROMISE', 4, 32, 1, 1, 4, NULL, 2968, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18993, '2018-10-17 12:43:40.435674+00', '2018-10-17 12:43:40.435674+00', 'Irene''s Second Wee Dance', 'IRENES SECOND WEE DANCE', 3, 32, NULL, 2, 3, 18, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10228, '2001-11-06 23:00:00+00', '2019-12-03 08:18:23.454706+00', 'Black Chanter of the MacPhersons', 'BLACK CHANTER OF THE MACPHERSONS', 3, 32, 9999, 1, 2, 76, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10250, '2001-11-25 23:00:00+00', '2019-12-07 17:43:24.370998+00', 'Waves on the Sea, The', 'WAVES ON THE SEA', 1, 32, 9999, 1, 4, 2, 2766, '2001-02-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10255, '2001-11-25 23:00:00+00', '2020-06-14 00:41:36.130928+00', 'Weaving the Plaid', 'WEAVING THE PLAID', 1, 32, 9999, 4, 4, 1, 2766, '2001-04-01', '', 81, '8888/8080/8888/6666', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10194, '2002-07-21 22:00:00+00', '2020-09-10 19:09:02.443514+00', 'Fiddle Sound, The', 'FIDDLE SOUND', 3, 32, 9999, 1, 3, 42, 2961, NULL, '', 53, '844/844/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10253, '2001-11-25 23:00:00+00', '2020-12-31 14:01:17.136168+00', 'Bend in the River, A', 'BEND IN THE RIVER', 3, 32, 9999, 1, 3, 42, 2766, '2001-04-01', '', 50, '800/844/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10262, '2001-11-25 23:00:00+00', '2021-02-10 13:33:23.283133+00', 'XYZZY', 'XYZZY', 1, 32, 9999, 1, 3, 42, 2766, '2001-07-01', 'The figures of this dance reminded me of a phrase from the original Adventure game ("You are in a maze of twisty little passages all alike").', 53, '800/866/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10243, '2001-11-25 23:00:00+00', '2021-01-20 01:38:37.161024+00', 'Xs and Os', 'XS AND OS', 2, 32, 9999, 4, 4, 13, 2766, '2000-10-01', '', 66, '8080/8080/4646/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10242, '2001-11-25 23:00:00+00', '2021-02-10 13:36:06.94204+00', 'Witching Hour, The', 'WITCHING HOUR', 3, 32, 9999, 1, 3, 42, 2766, '2000-10-01', 'I like the figure in bars 9-16 which I saw in John Drewry''s dance Midnight Oil, so I decided to try it in a strathspey.', 47, '800/822/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10275, '2001-11-29 23:00:00+00', '2021-03-01 19:41:19.357993+00', 'Johnya Wedding, The', 'JOHNYA WEDDING', 3, 64, 9999, 1, 4, NULL, 2968, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14846, '2013-05-18 21:48:27.038005+00', '2018-04-03 00:07:54.994728+00', 'January Jig', 'JANUARY JIG', 2, 32, 9999, 1, 3, 42, 17, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10178, '2001-10-23 22:00:00+00', '2022-06-17 20:13:09.838596+00', 'Waves of Moray, The', 'WAVES OF MORAY', 3, 32, 9999, 2, 3, 17, 272, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10271, '2001-11-25 23:00:00+00', '2022-09-30 12:44:09.477496+00', 'Sweet Potatoes', 'SWEET POTATOES', 2, 32, 9999, 1, 3, 42, 2766, '2001-11-01', 'This dance is named for the season in which it was written (Thanksgiving in the US).', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10199, '2001-11-06 23:00:00+00', '2022-09-30 12:47:50.62862+00', 'As the Moon Turns', 'AS THE MOON TURNS', 1, 32, 9999, 9, 7, 36, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10274, '2001-11-29 23:00:00+00', '2021-03-02 00:47:22.664811+00', 'Hoedown for Halloween', 'HOEDOWN FOR HALLOWEEN', 1, 32, 9999, 1, 4, NULL, 2970, '2000-01-01', 'To be danced 5 times through.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10193, '2001-10-31 23:00:00+00', '2021-06-08 09:53:59.517122+00', 'Thank You, Mr. Twhigg', 'THANK YOU MR TWHIGG', 1, 32, 9999, 1, 3, 42, 2961, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10263, '2001-11-25 23:00:00+00', '2021-06-15 08:57:04.498923+00', 'Counterpoint', 'COUNTERPOINT', 3, 32, 9999, 1, 3, 42, 2766, '2001-07-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18991, '2018-10-17 12:41:01.644522+00', '2019-01-29 00:18:56.044344+00', 'For Joan', 'FOR JOAN', 1, 32, NULL, 1, 3, 42, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18990, '2018-10-17 12:39:35.397224+00', '2019-01-29 00:19:12.310248+00', 'Flying Lady, The', 'FLYING LADY', 1, 32, NULL, 1, 3, 42, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14974, '2013-07-03 22:13:27.946068+00', '2014-04-30 23:23:37.250756+00', 'Aging Gracefully', 'AGING GRACEFULLY', 3, 32, NULL, 1, 3, 42, 10806, NULL, '', 50, '888  440  440  888', 0, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (10314, '2002-01-08 23:00:00+00', '2018-04-03 00:07:56.929504+00', 'Katherine''s Jig', 'KATHERINES JIG', 2, 40, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10280, '2001-11-29 23:00:00+00', '2018-04-03 00:08:02.583966+00', 'Masquerade, The', 'MASQUERADE', 1, 32, 9999, 1, 3, 42, 2972, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10233, '2002-07-21 22:00:00+00', '2018-04-03 00:08:13.08374+00', 'Rising Phoenix', 'RISING PHOENIX', 1, 32, 9999, 1, 3, 42, 2961, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10296, '2002-01-06 23:00:00+00', '2018-04-03 00:18:02.204461+00', 'Isabella Williamson', 'ISABELLA WILLIAMSON', 2, 32, 9999, 2, 2, 76, 9998, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10289, '2001-12-16 23:00:00+00', '2012-01-20 12:57:19.998001+00', 'Broun''s Reel', 'BROUNS REEL', 1, 32, 9999, 3, 5, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13754, '2011-07-11 22:00:00+00', '2018-04-17 09:02:27.749735+00', 'Delivery Round', 'DELIVERY ROUND', 2, 32, NULL, 1, 3, 42, 10370, NULL, 'This is a placeholder for a dance in Minicribs, added here to avoid a mismatch. The source given there is »Pensioner''s Coll.«', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10293, '2001-12-19 23:00:00+00', '2012-01-20 12:57:20.036365+00', 'Friends of the Hospice', 'FRIENDS OF THE HOSPICE', 1, 32, 9999, 1, 4, 2, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10284, '2001-12-02 23:00:00+00', '2018-07-28 18:06:51.989809+00', 'Down the Primrose Path', 'DOWN THE PRIMROSE PATH', 2, 40, 9999, 2, 3, 17, 2974, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10287, '2001-12-16 23:00:00+00', '2018-04-03 00:07:34.541714+00', 'Boddam Pier', 'BODDAM PIER', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10297, '2002-01-07 23:00:00+00', '2012-01-20 12:57:20.072976+00', 'Saint Andrew''s Hornpipe', 'SAINT ANDREWS HORNPIPE', 1, 32, 9999, 5, 2, NULL, 2982, '2001-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (51, '2000-02-13 23:00:00+00', '2019-04-18 17:32:05.372292+00', 'Ailsa Craig', 'AILSA CRAIG', 3, 32, 9999, 2, 3, 17, 128, '1973-01-01', '', 75, '888  840  804  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (10318, '2002-01-08 23:00:00+00', '2012-01-20 12:57:20.263378+00', 'Maple Leaf''s Compliments to RNLI', 'MAPLE LEAFS COMPLIMENTS TO RNLI', 1, 32, 9999, 1, 4, 2, 851, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10319, '2002-01-08 23:00:00+00', '2012-01-20 12:57:20.272184+00', 'Margaret Morrison', 'MARGARET MORRISON', 4, 256, 55, 1, 4, NULL, 2913, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10321, '2002-01-08 23:00:00+00', '2012-01-20 12:57:20.290485+00', 'Millennium Clock, The', 'MILLENNIUM CLOCK', 2, 40, 9999, 4, 4, 1, 123, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10292, '2001-12-19 23:00:00+00', '2018-04-03 00:07:45.995696+00', 'Fisherman of Oyne', 'FISHERMAN OF OYNE', 1, 48, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10294, '2002-01-06 23:00:00+00', '2018-04-03 00:07:47.5719+00', 'Gagiebank', 'GAGIEBANK', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9631, '2001-12-16 23:00:00+00', '2014-04-30 23:23:37.281648+00', 'Aileen''s Reel', 'AILEENS REEL', 1, 32, 9999, 1, 3, 42, 146, '2000-01-01', '', 52, '820  888  800  888', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (10305, '2002-04-24 22:00:00+00', '2020-01-22 18:42:09.155897+00', 'Come What May', 'COME WHAT MAY', 3, 32, 9999, 1, 4, 1, 2984, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10299, '2002-05-11 22:00:00+00', '2020-01-23 10:34:24.734366+00', 'Jig for Ann, A', 'JIG FOR ANN', 2, 32, 9999, 4, 4, 1, 222, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13749, '2011-07-11 22:00:00+00', '2020-09-20 08:47:41.504466+00', 'Orion''s Dance', 'ORIONS DANCE', 1, 32, NULL, 1, 4, 2, 2973, '2008-12-01', 'Devised in December 2008, for Kachina Allen and Alex Rafalovitch‟s son, Orion, on his first birthday. Several of the formations in this dance resemble stars.



Music:  Any lively reel, such as Shuter''s Hornpipe.', 88, '8008/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13753, '2011-07-11 22:00:00+00', '2020-09-20 09:16:07.082804+00', 'Shaws of Cambridge, The', 'SHAWS OF CAMBRIDGE', 3, 32, NULL, 1, 4, 2, 2973, NULL, 'Devised May 2008.



Dedicated to Judy Reynolds-Shaw and Roger Shaw of Cambridge, Massachusetts, who were the first to help me, along with my wife Sue, test the Celtic Cross progression.



The Celtic Cross Progression is described separately on page 27 of this publication.', 75, '4444/8888/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13761, '2011-07-12 22:00:00+00', '2020-09-21 10:33:16.568161+00', 'Blinkbonny', 'BLINKBONNY', 1, 32, NULL, 1, 2, 76, 246, NULL, 'This entry is a placeholder for a dance in Minicrib, to avoid a mismatch.', 60, '88/88/88/80', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13763, '2011-07-12 22:00:00+00', '2020-09-21 10:48:38.724215+00', 'Jean''s Delight', 'JEANS DELIGHT', 3, 32, NULL, 1, 4, 1, 9998, NULL, 'This entry is a placeholder for a dance in Minicrib, to avoid a mismatch. Minicrib says »A Taylor«.', 86, '8888/8888/8888/2822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10307, '2002-01-08 23:00:00+00', '2021-02-10 11:07:16.54304+00', 'Diamond Wedding', 'DIAMOND WEDDING', 1, 32, 9999, 1, 3, 42, 2984, NULL, '', 63, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10304, '2002-01-08 23:00:00+00', '2021-02-10 11:12:18.321935+00', 'Weaving Dreams', 'WEAVING DREAMS', 3, 32, 9999, 1, 4, 2, 3312, NULL, '', 94, '8888/8888/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10300, '2002-04-24 22:00:00+00', '2021-02-10 11:24:13.951341+00', 'Upside Down', 'UPSIDE DOWN', 1, 40, 9999, 6, 3, 18, 9998, NULL, '', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10279, '2001-11-29 23:00:00+00', '2021-02-28 08:30:23.751818+00', 'Karen''s Wedding', 'KARENS WEDDING', 1, 40, 9999, 1, 4, 1, 2968, '1998-01-01', 'Devised on the occasion of Karen Boyle and Jim Kraner, December 19, 1998', 80, '8860/8440/8800/8404/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10273, '2001-11-29 23:00:00+00', '2021-02-23 01:41:19.693247+00', 'Laura''s Wedding', 'LAURAS WEDDING', 2, 32, 9999, 1, 3, 42, 2968, '1998-01-01', '', 63, '888/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10315, '2002-01-08 23:00:00+00', '2021-06-06 12:13:08.007043+00', 'McKinnon River Dance', 'MACKINNON RIVER DANCE', 1, 40, 9999, 1, 4, 1, 205, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10278, '2001-11-29 23:00:00+00', '2021-02-28 14:07:25.689126+00', 'Salute to Sister Dorcas', 'SALUTE TO SISTER DORCAS', 1, 32, 9999, 1, 3, 42, 2969, NULL, 'Devised by Ron Hankes to honor our teacher and founder, Sister Dorcas Baker.', 58, '888/888/820/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10282, '2001-11-29 23:00:00+00', '2021-03-01 22:40:31.915011+00', 'Owen''s First Birthday', 'OWENS FIRST BIRTHDAY', 1, 32, 9999, 1, 3, 42, 2969, '2000-01-01', '', 50, '888/880/800/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10310, '2002-04-24 22:00:00+00', '2021-10-17 09:45:35.288443+00', '1-2-5', '125', 1, 32, 9999, 1, 3, 42, 2084, '2001-01-01', 'October 2021.  Robert Rushton has confirmed that the Minicrib instructions were incorrect. 

The final 8 bars are:

25-28 1s, turn LH 1½ times

29-32 1W, RH across with 2s. while 1M, RH across with 3s.



This dance was put together for Robert & Eileen''s Birthday Dance in 2001, By Robert.

125 was the combined age, of Robert & Eileen.', 44, '800/880/880/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10313, '2002-01-08 23:00:00+00', '2018-04-03 00:07:55.52017+00', 'Jig for John, A', 'JIG FOR JOHN', 2, 40, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10268, '2001-11-25 23:00:00+00', '2022-09-30 12:45:51.870404+00', 'Copy Cat', 'COPY CAT', 2, 32, 9999, 1, 3, 42, 2766, '2001-08-01', '', 50, '804/880/804/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10291, '2001-12-19 23:00:00+00', '2016-12-01 10:00:53.226955+00', 'Edzell Arch, The', 'EDZELL ARCH', 1, 32, 9999, 1, 2, 76, 108, '2001-01-01', 'A note from John Drewry says the dance is very energetic and should probably danced in a 3C set.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10320, '2002-01-08 23:00:00+00', '2018-04-03 00:08:02.192181+00', 'Marion''s Jig', 'MARIONS JIG', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12764, '2006-05-21 22:00:00+00', '2018-08-21 21:21:16.638143+00', 'Jim Healy Jig, The', 'JIM HEALY JIG', 2, 48, 9999, 1, 4, 2, 3682, NULL, 'Jim taught the technique class for four years and this dance and tune were presented to him on leaving the class. Celtic reels were included to prove that we could all do them. Although, I don·t think he believes us yet. (Fiona Mackie)  

Jim was the first teacher I played for in the Branch and he taught me a lot. for which I am grateful. By the way still looking for Book 3002! (Luke Brady)', 73, '8228/8888/8888/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13770, '2011-07-13 22:00:00+00', '2012-01-20 12:57:48.912322+00', 'Times Square', 'TIMES SQUARE', 4, 128, 2, 4, 4, 3, 2973, '2001-01-01', 'Music Any 64-bar strathspey / 64-bar reel medley. A suitable recording is ‗Stooges Salute‘,

TAC 50th Anniversary Collection, Bobby Brown and The Scottish Accent, track 9.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13762, '2011-07-12 22:00:00+00', '2018-04-02 23:56:38.27854+00', 'Tying Ribbons', 'TYING RIBBONS', 1, 32, 9999, 1, 3, 42, 3610, NULL, 'We had been working on reels of three in class so I wanted to incorporate two types in one dance. The movement of the dancers suggested the tying of ribbons.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13855, '2011-08-21 22:00:00+00', '2018-04-03 00:08:07.812881+00', 'Nieve-Nieve Nick-Nack', 'NIEVENIEVE NICKNACK', 2, 32, NULL, 1, 3, 42, 93, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13764, '2011-07-12 22:00:00+00', '2020-09-21 10:55:30.830296+00', 'Chase Court', 'CHASE COURT', 1, 32, NULL, 1, 2, 76, 2973, '2009-11-01', 'Devised in November 2009. Chase Court is our home in the US (in Independence Harbor, Edge-water, New Jersey) and seemed a good name for a dance with chases. Our building is actually named after Samuel Chase of Maryland, one of the original signatories of the Declaration of Independence in 1776.



Music

Any good reel (Inspired by Red House Reel). A suitable recording is ''Catch the Wind'', Catch the Wind, The Music Makars, track 1. (This is not the tune used by the RSCDS in book 45.)', 52, '80/08/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13765, '2011-07-12 22:00:00+00', '2020-09-21 10:59:48.893458+00', 'Juliana''s Jig', 'JULIANAS JIG', 2, 32, NULL, 3, 5, 7, 2980, NULL, 'This entry is a placeholder for a dance in Minicrib, to avoid a mismatch. ', 79, '86866/86846/86846/84844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13866, '2011-08-21 22:00:00+00', '2020-09-24 12:35:27.126545+00', 'Mrs Muriel More', 'MRS MURIEL MORE', 1, 32, NULL, 1, 3, 42, 640, NULL, '', 53, '880/866/866/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10302, '2002-01-08 23:00:00+00', '2021-02-10 11:19:07.856338+00', 'Way Ahead, The', 'WAY AHEAD', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 63, '888/888/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18572, '2018-09-10 14:50:37.420379+00', '2020-11-17 19:54:59.752941+00', 'Millennium Wedding', 'MILLENNIUM WEDDING', 1, 32, NULL, 1, 3, 42, 12004, '2000-06-01', 'The dance was written by Alan Cottle and Lesley McKenna to celebrate their wedding on 24 June 2000.', 50, '800/888/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10301, '2002-04-24 22:00:00+00', '2021-02-10 11:21:15.230781+00', 'Lubina Sol', 'LUBINA SOL', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 63, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13775, '2011-07-23 22:00:00+00', '2021-07-25 16:48:11.802985+00', 'None So F-Hugh-gal', 'NONE SO FHUGHGAL', 1, 40, NULL, 1, 4, NULL, 1276, NULL, 'Adrian writes:  None So F-Hugh-gal (pronounced "None So Fugal"): 4x40 R for 4 couples in a longwise

set, danced to the music for None So Pretty. Dedicated to the memory of Hugh Foss, with a

canon for 4 voices in bars 1-24. Dance intensity 81%. Standard - advanced/ demonstration.

Numerous diagrams provided - mostly for the fugal section.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13776, '2011-07-23 22:00:00+00', '2021-05-25 21:15:08.179171+00', 'Heights of Rechberg, The', 'HEIGHTS OF RECHBERG', 1, 32, NULL, 1, 4, 11, 1276, '1975-01-01', 'Adrian writes: The Heights of Rechberg (aka Hohenrechberg Castle) is a 4x32 R for 4 couples in a longwise

set, danced to the music of The Corn Rigs. Dance intensity 100%. Standard - good intermediate, stamina also essential. Best treated as a romp, the odds are against most sets completing all four repeats without the dance falling apart.



Dedicated to the memory of Hans and Karin Willberg.

', 100, '8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13769, '2011-07-13 22:00:00+00', '2021-10-03 17:52:58.313454+00', 'New Amsterdam', 'NEW AMSTERDAM', 1, 32, NULL, 1, 3, 42, 2973, '2010-04-01', 'Devised in April 2010. 



The first permanent European settlement in Manhattan was named Nieuw-Amsterdam by the Dutch in 1625. The name was changed to New York in 1664, after the Duke of York.



Music

Any good reel. A suitable recording is ‗On the Morning Tide‘, Many Happy Returns, Hanneke Cassel and Dave Wiesler, track 1.



The Celtic Cross progression is a new figure of progression introduced in my book 12 Scottish Country Dances (2009).



See Annex 1 for a note on the ''Swing Corners'' figure. The original Swing Corners figure appears in Scotia Swing. I have modified the figure to fit this dance.', 56, '880/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13824, '2011-08-05 22:00:00+00', '2018-04-24 03:41:57.295281+00', 'Barnyard Geese', 'BARNYARD GEESE', 1, 32, NULL, 1, 3, 42, 3371, NULL, 'Music: Reel with clear 4 beats suitable for learning pas de basque.  



This dance was adapted from The Wild Geese as a dance for learning advancing pas de basque and balance-in-line.', 44, '808/808/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4042, '1997-11-25 23:00:00+00', '2020-09-01 10:54:48.585645+00', 'MacLauchlane', 'MACLAUCHLANE', 1, 128, 9999, 4, 4, 3, 129, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13817, '2011-08-04 22:00:00+00', '2022-04-26 20:17:15.797853+00', 'Patty''s Strathspey', 'PATTYS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 1113, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13818, '2011-08-04 22:00:00+00', '2022-08-14 08:22:01.042862+00', 'Quaternary Knot', 'QUATERNARY KNOT', 2, 32, NULL, 1, 3, 42, 3369, NULL, 'From the dance notes: "Bars 9 – 16 Quaternary Knot. Basically a crossover mirrored reel of three with 1st couple

crossing at the top and bottom. From their starting position, they are dancing a diagonal oval around the couple above then the couple below while 2nd and 3rd couples dance a mirror reel on the side."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13777, '2011-07-23 22:00:00+00', '2022-09-13 15:45:48.689886+00', 'Tour of the Backs, A', 'TOUR OF THE BACKS', 1, 48, NULL, 3, 5, 16, 1276, NULL, 'Adrian writes:  A Tour of the Backs: 5x48 R for 5 couples in a longwise set. Dance intensity 82%.

Standard - good intermediate. The dance has some parallels with the ISTD dance Jack O''

Carron and the well-known RSCDS Anniversary Reel (originally the 35th Anniversary Reel to

commemorate a club near Croydon).



Dedicated to the Cambridge University (UK) Strathspey and Reel Club.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13783, '2011-07-24 22:00:00+00', '2012-01-20 12:57:49.031168+00', 'Charlotte''s Web', 'CHARLOTTES WEB', 1, 32, NULL, 3, 5, 40, 2682, '2010-07-19', 'For Charlotte Williams (nee Dunn), local dancer of great passion.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13795, '2011-07-24 22:00:00+00', '2012-01-20 12:57:49.169781+00', 'Phina''s Fling', 'PHINAS FLING', 2, 40, NULL, 1, 3, 42, 2682, '2006-07-01', 'Revised November 2007. Phina is our youngest dancer, and is only 10.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13809, '2011-08-04 22:00:00+00', '2018-04-27 10:09:56.306564+00', 'Falkirk Wheel', 'FALKIRK WHEEL', 3, 32, NULL, 1, 4, 2, 3369, '2011-01-01', 'This dance commemorates my trip to Falkirk in 2010.', 75, '8448/8008/8888/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13808, '2011-08-04 22:00:00+00', '2018-04-27 09:50:03.580294+00', 'Couldn''t Sleep', 'COULDNT SLEEP', 4, 64, 22, 1, 4, 1, 3369, NULL, 'As the title implies, this dance was devised one night when I just couldn’t get to sleep.', 58, '822/808/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18739, '2018-10-04 10:01:19.769699+00', '2018-10-04 10:01:19.769699+00', 'Double Knitting', 'DOUBLE KNITTING', 2, 32, NULL, 1, 4, NULL, 2766, '2015-02-01', 'My latest experiment is double knitting and the figures in this dance remind me of that.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13816, '2011-08-04 22:00:00+00', '2012-01-20 12:57:49.36979+00', 'My Heart''s In The Highlands', 'MY HEARTS IN THE HIGHLANDS', 3, 32, NULL, 1, 2, NULL, 1113, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13812, '2011-08-04 22:00:00+00', '2018-12-15 03:01:33.694332+00', 'Here Comes Santa Claus', 'HERE COMES SANTA CLAUS', 1, 32, NULL, 1, 3, 42, 10380, NULL, '', 61, '800/888/886/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13788, '2011-07-24 22:00:00+00', '2017-03-29 11:10:25.853222+00', 'Twisted Wizard of Binghamton, The', 'TWISTED WIZARD OF BINGHAMTON', 3, 40, NULL, 1, 4, 30, 2682, '2010-08-10', 'This is a twisted version of The Wizard of Binghamton, for those who love a challenge.



Dedicated to Terry Glasspool, "The Wizard of Binghamton", a wonderful deviser of Scottish Country Dances. Inspired by the overlink idea of Terry Glasspool from his regrettably unpublished "Four on the Floor" Collection.



', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13815, '2011-08-04 22:00:00+00', '2017-11-13 14:07:39.069808+00', 'Molly MacLay Of Kilfinnan', 'MOLLY MACLAY OF KILFINNAN', 3, 32, NULL, 2, 3, NULL, 1113, NULL, 'Molly MacLay of Kilfinnan is the full name of the devisor’s black Labrador retriever, who while in her sixties in human years personifies Miss Milligan’s philosophy of controlled abandon – well, almost controlled…You can see pictures of Molly and her adopted pack mate Jasmine at http://picasaweb.google.com/Lee.Fuell/Dogs.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13786, '2011-07-24 22:00:00+00', '2017-03-29 11:13:09.140765+00', 'Wizard of Binghamton, The', 'WIZARD OF BINGHAMTON', 3, 40, NULL, 1, 4, 30, 2682, '2010-08-11', 'Dedicated to Terry Glasspool, "The Wizard of Binghamton", a wonderful deviser of Scottish Country Dances.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13811, '2011-08-04 22:00:00+00', '2018-04-03 00:07:50.174648+00', 'Gude Ale Keeps The Heart Aboon', 'GUDE ALE KEEPS THE HEART ABOON', 1, 32, NULL, 1, 3, 42, 1113, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13814, '2011-08-04 22:00:00+00', '2018-04-03 00:08:01.766699+00', 'Mally''s Meek, Mally''s Sweet', 'MALLYS MEEK MALLYS SWEET', 3, 32, NULL, 1, 3, 42, 1113, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13819, '2011-08-04 22:00:00+00', '2018-12-16 01:40:13.397389+00', 'Slipstop Jig', 'SLIPSTOP JIG', 2, 32, NULL, 1, 3, 42, 3368, NULL, '', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13790, '2011-07-24 22:00:00+00', '2018-12-25 18:47:54.827047+00', 'Corner Meeting', 'CORNER MEETING', 2, 32, NULL, 1, 3, 42, 2682, '2007-03-01', 'Devised as a teaching dance for corners, the first time that they are introduced.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13789, '2011-07-24 22:00:00+00', '2018-12-25 09:54:28.322126+00', 'Eighty Eight', 'EIGHTY EIGHT', 3, 32, NULL, 1, 2, 76, 2682, '2006-02-01', 'Devised as a teaching dance to teach figures of eight.', -1, '80/08/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13793, '2011-07-24 22:00:00+00', '2018-12-26 12:50:21.134073+00', 'Adelle''s Jig', 'ADELLES JIG', 2, 32, NULL, 1, 3, 42, 2682, '2009-03-30', 'Devised in Wellington as teaching dance for grand chain. Adelle is one of Johnsonville''s young club members.



ADELLE''S JIG (INTERMEDIATE VERSION) is the same except that bars 1-6 have the first couple set (1-2) cross RH and cast into second place on opposite sides. And on bars 21-24 rst couple turn RH one and a half times.', 50, '800/888/844/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13857, '2011-08-21 22:00:00+00', '2018-04-03 00:08:18.595944+00', 'Storrie Ba'', Hinnie Ba''', 'STORRIE BA HINNIE BA', 3, 32, NULL, 1, 3, 42, 93, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13781, '2011-07-24 22:00:00+00', '2020-09-21 19:05:30.537991+00', 'Monica', 'MONICA', 1, 48, NULL, 2, 3, 17, 2682, '2010-07-27', 'For the very energetic, the dance could finish with no extra in the reel, ending in places 2,1,3, and then could be danced as an 8 x 48 R.



Given to Monica (Juping) Zhou, a dancing friend on the occasion of her 50th birthday.', 62, '800/805/805/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18573, '2018-09-10 14:54:50.486078+00', '2020-08-07 19:01:38.611084+00', 'Jiggles', 'JIGGLES', 2, 32, NULL, 1, 3, 42, 11233, '2013-06-01', '', 69, '844/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13785, '2011-07-24 22:00:00+00', '2020-09-21 19:11:57.539431+00', 'Malcolm Brown', 'MALCOLM BROWN', 3, 40, NULL, 1, 4, 2, 2682, '2011-06-25', 'The isobirl formation is due to Terry Glasspool.  I learned of this formation from my correspondences with Malcolm Brown.', 98, '8888/8888/8888/8888/8668', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13823, '2011-08-05 22:00:00+00', '2020-09-22 08:36:26.827678+00', '200 King Street North', '200 KING STREET NORTH', 2, 32, NULL, 1, 2, 76, 2245, NULL, 'This dance was devised for teaching reels of four in a beginner class.', 56, '82/88/82/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (55, '1998-09-27 22:00:00+00', '2020-12-27 12:36:01.599978+00', 'Airdrie Lassies', 'AIRDRIE LASSIES', 2, 48, 9999, 1, 4, 1, 9998, NULL, '', 75, '8888  8888  8008  8008  8888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (13807, '2011-08-04 22:00:00+00', '2020-12-31 11:56:38.25373+00', 'Coire Lagan', 'COIRE LAGAN', 1, 32, NULL, 1, 3, 42, 1113, NULL, '', 50, '800/888/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13797, '2011-07-24 22:00:00+00', '2021-07-15 08:21:56.175402+00', 'Stargazers', 'STARGAZERS', 3, 32, NULL, 1, 4, 2, 2682, '2007-05-01', 'Given to Aline and John Holmes, long time Johnsonville members and "stargazers" on clear nights.

', 88, '8448/8888/8888/8448', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13796, '2011-07-24 22:00:00+00', '2021-10-26 15:03:49.895657+00', 'Lass and the Laird, The', 'LASS AND THE LAIRD', 2, 32, NULL, 1, 3, 42, 2682, '2009-06-03', 'I have taught exactly this dance many times as my misreading of Jack McConachie''s dance "The Laird and the Lass". The first 16 bars are quite different than Jack''s and rather easier.', 50, '888/888/800/800', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13787, '2011-07-24 22:00:00+00', '2019-05-22 16:32:27.724324+00', 'Apprentice, The', 'APPRENTICE', 3, 40, NULL, 1, 4, 30, 2682, '2010-08-11', 'Dedicated to Terry Glasspool, "The Wizard of Binghamton", a wonderful deviser of Scottish Country Dances.



This is a simplified version (for bars 1-8 only) of "The Wizard of Binghamton".  The simplified version was suggested by Charlotte Williams and I am recording it here.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13794, '2011-07-24 22:00:00+00', '2018-12-26 13:09:47.480675+00', 'First Foot and Friend', 'FIRST FOOT AND FRIEND', 3, 32, NULL, 1, 3, 42, 2682, '2007-03-01', 'Devised in as a teaching dance for half figure of eight and to have similar simple corner movements to "Delvine Side". Given to Joanne Ang and Selwyn Ng, the latter being the "First Foot" at Hogmannay in the beginning of 2007.', 53, '888/800/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13820, '2011-08-04 22:00:00+00', '2019-10-12 13:53:50.625397+00', 'Thistle School Jig', 'THISTLE SCHOOL JIG', 2, 32, NULL, 1, 3, 42, 3369, '2011-01-01', 'Devised: 2011', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13858, '2011-08-21 22:00:00+00', '2018-04-03 00:07:31.830123+00', 'Babbity Bowster', 'BABBITY BOWSTER', 3, 32, NULL, 1, 3, 42, 93, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13853, '2011-08-21 22:00:00+00', '2012-01-20 12:57:49.665728+00', 'Mrs Watson''s Fancy', 'MRS WATSONS FANCY', 3, 64, NULL, 1, 4, 1, 93, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13854, '2011-08-21 22:00:00+00', '2012-01-20 12:57:49.674403+00', 'Mitcham Society, The', 'MITCHAM SOCIETY', 3, 64, NULL, 1, 4, 1, 93, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13856, '2011-08-21 22:00:00+00', '2012-01-20 12:57:49.693325+00', 'Mary MacKenzie Strathspey, The', 'MARY MACKENZIE STRATHSPEY', 3, 32, NULL, 1, 4, 1, 93, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13952, '2011-08-22 22:00:00+00', '2012-01-20 12:57:50.314305+00', 'Flute of Mad Wine, A', 'FLUTE OF MAD WINE', 2, 32, NULL, 2, 3, 17, 10300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13938, '2011-08-22 22:00:00+00', '2019-10-05 10:59:08.478411+00', 'Cafe Noir, Le', 'CAFE NOIR', 2, 32, NULL, 1, 2, 76, 2203, NULL, '', 60, '88/88/44/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13954, '2011-08-22 22:00:00+00', '2012-01-20 12:57:50.327466+00', 'Riddler, The', 'RIDDLER', 3, 40, NULL, 1, 4, 2, 10300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13955, '2011-08-22 22:00:00+00', '2012-01-20 12:57:50.334904+00', 'Chocolate and Roses', 'CHOCOLATE AND ROSES', 3, 32, NULL, 2, 3, 17, 2203, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13921, '2011-08-22 22:00:00+00', '2018-04-17 15:59:05.721724+00', 'Mosi oa Tunya', 'MOSI OA TUNYA', 1, 32, NULL, 1, 3, 42, 3254, '2006-06-01', 'Devised by Terry Lynne Harris, Pretoria, August 2006.  

Written for Ken Martlew. in celebration of the Martlews'' visit to our beautiful shores, 25 August - 10 September 2006.  



Notes:  

Mosi oa Tunya. meaning "The Smoke that Thunders". and pronounced: Mawsi wa Toonyah. was the local name used for the falls when David Livingstone first saw them in November 1855. Livingstone called the falls ''''Victoria Falls". after Britain''s Queen Victoria. ', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13912, '2011-08-22 22:00:00+00', '2018-04-19 08:35:37.662284+00', 'Grenoble Gem', 'GRENOBLE GEM', 3, 32, NULL, 6, 3, 18, 3254, '2004-04-01', 'Devised by Terry Lynne Harris, Pretoria, April 2004.  



Written for Geneviève Sheffield, an absolute gem, with thanks and appreciation for her part in making my time at Martin Sheffield''s first SCD Holiday near Grenoble, France (16-23 June 2003) so enjoyable.  



Bars 13-16 of La Baratte, as described above, is a slight variation on the original instructions for the sake of the flow of this dance description.', 100, '888/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13895, '2011-08-22 22:00:00+00', '2012-01-20 12:57:49.942814+00', 'Blagdon Hall', 'BLAGDON HALL', 1, 48, NULL, 1, 4, 1, 2788, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13903, '2011-08-22 22:00:00+00', '2018-04-08 08:22:17.428241+00', 'Echoes of Strathglass', 'ECHOES OF STRATHGLASS', 3, 32, NULL, 2, 3, 17, 635, NULL, 'Devised by Malcolm Brown, Dunnington, UK.



The Iso-Birl was devised by Terry Glasspool.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13917, '2011-08-22 22:00:00+00', '2018-04-19 02:16:26.580891+00', 'Love and Sunbeams', 'LOVE AND SUNBEAMS', 2, 40, NULL, 1, 3, 42, 64, '2005-02-01', 'Devised by Irene van Maarseveen. Pretoria, February 2005.  



For Adrienne and Jason Blignaut, whose lives became inextricably intertwined on 19 March 2005 and who radiate love and sunbeams. ', 73, '860/880/880/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13843, '2011-08-21 22:00:00+00', '2018-07-07 06:01:31.051529+00', 'Auchendinny Strathspey', 'AUCHENDINNY STRATHSPEY', 3, 48, NULL, 2, 3, 17, 872, NULL, '', 61, '880/800/844/800/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13844, '2011-08-21 22:00:00+00', '2013-11-27 02:33:19.405103+00', 'Robsons'' Ruby Wedding, The', 'ROBSONS RUBY WEDDING', 3, 80, NULL, 4, 4, 30, 872, '2003-02-02', 'Devised for Margaret Robson (Secretary of the Bournemouth Branch) and husband, Lelie on the occasion of their Ruby Wedding Anniversary, 2nd February 2003', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13927, '2011-08-22 22:00:00+00', '2018-04-12 11:31:18.040827+00', 'Soaring Dragon, The', 'SOARING DRAGON', 1, 32, NULL, 1, 3, 42, 3254, '2004-01-01', '', 60, '800/888/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13846, '2011-08-21 22:00:00+00', '2013-11-27 02:56:26.164885+00', 'Madras College Medley', 'MADRAS COLLEGE MEDLEY', 4, 128, 10020, 1, 4, 1, 872, '2001-01-01', 'Devised in 2001 for the many young Branch Members who attended classes in Madras College at Summer School in St Andrews', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13896, '2011-08-22 22:00:00+00', '2018-04-07 07:00:23.510715+00', '35 Years and Counting', '35 YEARS AND COUNTING', 2, 32, NULL, 1, 3, 42, 3254, '2007-01-01', 'Devised by Terry Lynne Harris, Pretoria 2007.



Written for the 35th anniversary of the Pretoria Branch of the RSCDS', 53, '800/844/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13902, '2011-08-22 22:00:00+00', '2018-04-07 23:52:49.713758+00', 'East to the Escarpment', 'EAST TO THE ESCARPMENT', 2, 32, NULL, 1, 3, 42, 3254, '2005-08-01', 'Devised by Teny Lynne Harris, Pretoria, August 2005.



Written for Helen Brown, to commemorate our trip eastwards to the Escarpment (Drakensberg) with the Browns.



The Snake Pass was devised by Norman Churnside.', 53, '840/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13845, '2011-08-21 22:00:00+00', '2018-07-07 08:04:28.622007+00', 'Frank''s Reel', 'FRANKS REEL', 1, 32, NULL, 1, 3, 42, 872, '1999-01-01', 'Devised in memory of Frank Oliver who died 10th April 1999. He was Treasurer of Bournemouth Branch for 5 years - a great character and loved by all.', 50, '800/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18724, '2018-10-04 05:24:50.802407+00', '2018-10-04 05:31:33.396902+00', 'Dan''s Jig', 'DANS JIG', 2, 32, NULL, 1, 3, 42, 2766, '2014-12-01', 'For my husband whose birthday is in December.', 50, '800/880/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13919, '2011-08-22 22:00:00+00', '2018-04-11 12:12:04.622481+00', 'Margo''s Knot', 'MARGOS KNOT', 3, 32, NULL, 1, 3, 42, 3179, '2003-08-01', 'Devised by Wouter Joubert, Pretoria, August 2003.



In honour of Margo Monteith of the 51st Club. Johannesburg. it was presented to Margo by the Pretoria Branch in 2004 as a tribute to her enormous contribution to SCD in South Africa.', 59, '880/855/855/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18725, '2018-10-04 05:38:19.050763+00', '2018-10-04 05:38:19.050763+00', 'Dark Is Rising, The', 'DARK IS RISING', 1, 32, NULL, 1, 3, 42, 2766, '2014-11-01', 'About the days getting shorter and honoring a favorite fantasy series by Susan Cooper.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13893, '2011-08-22 22:00:00+00', '2020-06-03 22:22:56.164289+00', 'Keys, The', 'KEYS', 2, 32, NULL, 1, 4, 1, 2788, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13863, '2011-08-21 22:00:00+00', '2020-08-31 16:05:18.99751+00', 'GG''s Manor', 'GGS MANOR', 3, 32, NULL, 1, 3, 42, 1415, NULL, '', 59, '800/888/866/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13849, '2011-08-21 22:00:00+00', '2020-09-22 08:45:09.181349+00', 'Belfast City Hall', 'BELFAST CITY HALL', 3, 40, NULL, 4, 4, 13, 28, NULL, '', 80, '8888/8888/8080/0808/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13861, '2011-08-21 22:00:00+00', '2020-09-24 12:23:50.1383+00', 'clydebuilt 85', 'CLYDEBUILT 85', 1, 32, NULL, 1, 4, 1, 1415, NULL, '', 81, '8080/8888/8484/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13864, '2011-08-21 22:00:00+00', '2020-09-24 12:27:59.011298+00', 'Milngavie Strathspey', 'MILNGAVIE STRATHSPEY', 3, 32, NULL, 2, 3, 17, 3699, NULL, '', 79, '686/888/080/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13924, '2011-08-22 22:00:00+00', '2020-09-24 13:08:49.78812+00', 'Reel for St Columba''s Church', 'REEL FOR ST COLUMBAS CHURCH', 1, 32, NULL, 1, 3, 42, 3179, NULL, '', 50, '800 844 844 888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13926, '2011-08-22 22:00:00+00', '2021-01-01 20:04:00.275995+00', 'Simple Delights', 'SIMPLE DELIGHTS', 1, 32, NULL, 1, 3, 42, 3179, '2004-02-29', '', 41, '880/822/822/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13865, '2011-08-21 22:00:00+00', '2019-01-06 20:47:47.8442+00', 'Mr Duncan MacLean', 'MR DUNCAN MACLEAN', 2, 32, NULL, 1, 3, 42, 640, NULL, '', 50, '800/888/844/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13960, '2011-08-24 22:00:00+00', '2018-04-03 00:07:29.757371+00', 'Age of Aquarius', 'AGE OF AQUARIUS', 3, 32, NULL, 1, 3, 42, 1331, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13993, '2011-08-24 22:00:00+00', '2018-04-03 00:07:37.420625+00', 'Cat in the Basket, The', 'CAT IN THE BASKET', 1, 40, NULL, 1, 3, 42, 10424, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13937, '2011-08-22 22:00:00+00', '2012-01-20 12:57:50.216253+00', 'Bruce''s Bubbly', 'BRUCES BUBBLY', 3, 32, NULL, 4, 4, 30, 10300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13939, '2011-08-22 22:00:00+00', '2012-01-20 12:57:50.229809+00', 'Milk Chocolate with Allemandes', 'MILK CHOCOLATE WITH ALLEMANDES', 2, 32, NULL, 1, 4, 1, 2203, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13940, '2011-08-22 22:00:00+00', '2012-01-20 12:57:50.236645+00', 'Evelyn''s Gift', 'EVELYNS GIFT', 1, 40, NULL, 4, 4, 30, 10410, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13941, '2011-08-22 22:00:00+00', '2012-01-20 12:57:50.243472+00', 'Yvonne''s Treat', 'YVONNES TREAT', 2, 32, NULL, 1, 4, 1, 10300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13943, '2011-08-22 22:00:00+00', '2012-01-20 12:57:50.256395+00', 'Spinning Bobbins', 'SPINNING BOBBINS', 1, 32, NULL, 2, 3, 17, 10412, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13944, '2011-08-22 22:00:00+00', '2012-01-20 12:57:50.26316+00', 'Chocolate Stars', 'CHOCOLATE STARS', 3, 32, NULL, 1, 4, 2, 2203, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13946, '2011-08-22 22:00:00+00', '2012-01-20 12:57:50.276179+00', 'Hot Butterbeer', 'HOT BUTTERBEER', 3, 32, NULL, 2, 3, 17, 10299, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13949, '2011-08-22 22:00:00+00', '2012-01-20 12:57:50.294658+00', 'Chocolate Swirl', 'CHOCOLATE SWIRL', 3, 32, NULL, 1, 2, NULL, 10413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13950, '2011-08-22 22:00:00+00', '2012-01-20 12:57:50.301061+00', 'Chocolate Frogs and Peppermint Toads', 'CHOCOLATE FROGS AND PEPPERMINT TOADS', 2, 32, NULL, 1, 2, NULL, 10299, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13951, '2011-08-22 22:00:00+00', '2012-01-20 12:57:50.307136+00', 'French Silk', 'FRENCH SILK', 1, 32, NULL, 2, 3, NULL, 10298, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14071, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.881438+00', 'Ross''s Reel', 'ROSSS REEL', 1, 32, NULL, 1, 2, NULL, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13859, '2011-08-21 22:00:00+00', '2022-08-14 19:48:08.179585+00', 'Bearsden Jig', 'BEARSDEN JIG', 2, 32, NULL, 1, 3, 42, 3699, NULL, '', 63, '844/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13956, '2011-08-22 22:00:00+00', '2012-01-20 12:57:50.341888+00', 'Death by Chocolate', 'DEATH BY CHOCOLATE', 1, 48, NULL, 3, 5, 7, 2203, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13973, '2011-08-24 22:00:00+00', '2012-01-20 12:57:50.398256+00', 'Gyromancy', 'GYROMANCY', 1, 40, NULL, 2, 3, 18, 10417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13978, '2011-08-24 22:00:00+00', '2012-01-20 12:57:50.416534+00', 'Mistress McKelvy', 'MISTRESS MACKELVY', 3, 32, NULL, 1, 2, NULL, 1331, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13979, '2011-08-24 22:00:00+00', '2012-01-20 12:57:50.42356+00', 'Mr Murphy''s Bicycle', 'MR MURPHYS BICYCLE', 3, 32, NULL, 1, 4, 2, 10419, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13948, '2011-08-22 22:00:00+00', '2018-04-03 00:07:38.305207+00', 'Chocolate Fountain', 'CHOCOLATE FOUNTAIN', 1, 32, NULL, 1, 3, 42, 10410, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13989, '2011-08-24 22:00:00+00', '2012-01-20 12:57:50.480999+00', 'Sylvain''s Hornpipe', 'SYLVAINS HORNPIPE', 1, 32, NULL, 1, 4, 15, 10422, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13992, '2011-08-24 22:00:00+00', '2012-01-20 12:57:50.493826+00', 'Chocolate Teapots, The', 'CHOCOLATE TEAPOTS', 2, 32, NULL, 2, 3, 18, 10423, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13964, '2011-08-24 22:00:00+00', '2013-01-09 00:01:10.357092+00', 'Dance Lieber', 'DANCE LIEBER', 2, 32, NULL, 1, 4, 2, 2701, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13994, '2011-08-24 22:00:00+00', '2012-01-20 12:57:50.506878+00', 'Ladies & Gentlemen', 'LADIES AND GENTLEMEN', 3, 32, NULL, 1, 4, 2, 10425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13958, '2011-08-22 22:00:00+00', '2018-04-03 00:07:38.313589+00', 'Chocolate Ganache', 'CHOCOLATE GANACHE', 2, 32, NULL, 1, 3, 42, 2203, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13999, '2011-08-24 22:00:00+00', '2012-01-20 12:57:50.521574+00', 'Platypus Reel, The', 'PLATYPUS REEL', 1, 64, NULL, 4, 4, 30, 10424, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13963, '2011-08-24 22:00:00+00', '2018-04-03 00:07:39.264623+00', 'Comings & Goings', 'COMINGS AND GOINGS', 1, 40, NULL, 1, 3, 42, 10417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14007, '2011-08-24 22:00:00+00', '2012-01-20 12:57:50.560938+00', 'Geraldine''s Fancy', 'GERALDINES FANCY', 2, 48, NULL, 1, 4, 1, 10427, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14011, '2011-08-24 22:00:00+00', '2012-01-20 12:57:50.579958+00', 'Wantonness', 'WANTONNESS', 1, 32, NULL, 2, 3, NULL, 2408, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13998, '2011-08-24 22:00:00+00', '2016-04-18 23:00:20.35855+00', 'Meadows'' Medley, The', 'MEADOWS MEDLEY', 4, 192, 10009, 2, 3, NULL, 3753, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14005, '2011-08-24 22:00:00+00', '2016-05-19 14:30:17.592002+00', 'Little Red Devil, The', 'LITTLE RED DEVIL', 2, 32, NULL, 4, 111, 4, 3631, NULL, 'Jig for four couples and a m ale spectator in a square set', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13936, '2011-08-22 22:00:00+00', '2016-07-10 12:17:03.354724+00', 'St Vincent''s Reel', 'SAINT VINCENTS REEL', 2, 40, NULL, 7, 99, 30, 10300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13966, '2011-08-24 22:00:00+00', '2018-04-03 00:07:42.459303+00', 'Donna''s Delight', 'DONNAS DELIGHT', 3, 32, NULL, 1, 3, 42, 10418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13945, '2011-08-22 22:00:00+00', '2018-04-03 00:07:42.776111+00', 'Double Mocha', 'DOUBLE MOCHA', 1, 40, NULL, 1, 3, 42, 2203, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14003, '2011-08-24 22:00:00+00', '2018-04-03 00:07:53.952535+00', 'Isle of Ornsay Jig, The', 'ISLE OF ORNSAY JIG', 2, 40, NULL, 1, 3, 42, 10424, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13957, '2011-08-22 22:00:00+00', '2018-04-03 00:07:56.862698+00', 'Kaffee Klatch', 'KAFFEE KLATCH', 2, 32, NULL, 1, 3, 42, 10298, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13977, '2011-08-24 22:00:00+00', '2018-04-03 00:08:03.401153+00', 'Midsummer Night''s Dream, A', 'MIDSUMMER NIGHTS DREAM', 3, 32, NULL, 1, 3, 42, 10417, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13980, '2011-08-24 22:00:00+00', '2018-04-03 00:08:08.096446+00', 'North of Corcoran', 'NORTH OF CORCORAN', 3, 32, NULL, 1, 3, 42, 214, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13947, '2011-08-22 22:00:00+00', '2018-04-03 00:08:11.549165+00', 'Quad Latte', 'QUAD LATTE', 1, 32, NULL, 1, 3, 42, 10300, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14000, '2011-08-24 22:00:00+00', '2018-04-03 00:08:18.962641+00', 'Suilven', 'SUILVEN', 2, 32, NULL, 1, 3, 42, 10424, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13986, '2011-08-24 22:00:00+00', '2018-04-03 00:08:19.021119+00', 'Summer in London', 'SUMMER IN LONDON', 3, 32, NULL, 1, 3, 42, 10420, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13988, '2011-08-24 22:00:00+00', '2018-04-03 00:08:19.463125+00', 'Sweet Friends of Mine', 'SWEET FRIENDS OF MINE', 2, 32, NULL, 1, 3, 42, 10421, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13990, '2011-08-24 22:00:00+00', '2018-04-03 00:08:21.531122+00', 'Topgallant', 'TOPGALLANT', 2, 40, NULL, 1, 3, 42, 1331, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13953, '2011-08-22 22:00:00+00', '2018-04-03 00:08:22.698522+00', 'Truffle, The', 'TRUFFLE', 1, 32, NULL, 1, 3, 42, 10414, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14018, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.623511+00', 'Cross Links', 'CROSS LINKS', 2, 32, NULL, 1, 4, 2, 389, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14019, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.630517+00', 'Fort Worden''s Pearl', 'FORT WORDENS PEARL', 4, 144, 10022, 4, 4, NULL, 401, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13930, '2011-08-22 22:00:00+00', '2020-09-24 13:11:18.565711+00', 'Voortrekker Monument, The', 'VOORTREKKER MONUMENT', 3, 32, NULL, 1, 3, 42, 854, NULL, '', 58, '802/888/888/844 ', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13942, '2011-08-22 22:00:00+00', '2020-09-24 13:21:46.642001+00', 'Grinding Coffee', 'GRINDING COFFEE', 2, 40, NULL, 1, 2, 76, 10411, NULL, '', 69, '88/88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14001, '2011-08-24 22:00:00+00', '2020-09-24 20:00:48.78249+00', 'Elderflower Champagne', 'ELDERFLOWER CHAMPAGNE', 1, 40, NULL, 1, 3, 42, 10426, NULL, '', 58, '800/866/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14009, '2011-08-24 22:00:00+00', '2020-09-24 20:08:37.400665+00', 'Nethy Bridge', 'NETHY BRIDGE', 2, 32, NULL, 1, 4, 2, 3631, NULL, '', 84, '8888/8448/8448/8668', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14023, '2011-08-25 22:00:00+00', '2020-09-25 21:05:05.222288+00', 'Old and Dangerous', 'OLD AND DANGEROUS', 3, 32, NULL, 1, 2, 76, 389, NULL, '', 69, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13932, '2011-08-22 22:00:00+00', '2021-01-01 20:07:37.387608+00', 'Ilkley Gift, An', 'ILKLEY GIFT', 3, 32, NULL, 1, 3, 42, 146, '2007-01-01', '', 63, '848/808/884/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14084, '2011-08-25 22:00:00+00', '2018-04-03 00:07:30.208952+00', 'All Right on the Night', 'ALL RIGHT ON THE NIGHT', 2, 32, NULL, 1, 3, 42, 2804, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14026, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.676008+00', 'Through the Streets of Prague', 'THROUGH THE STREETS OF PRAGUE', 3, 32, NULL, 1, 4, 2, 389, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14039, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.703467+00', 'Edinburgh''s Gain', 'EDINBURGHS GAIN', 3, 40, NULL, 1, 4, 1, 347, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14081, '2011-08-25 22:00:00+00', '2018-04-03 00:07:30.477027+00', 'And One', 'AND ONE', 3, 32, NULL, 1, 3, 42, 10438, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14041, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.716392+00', 'Bridget''s Farewell', 'BRIDGETS FAREWELL', 1, 32, NULL, 1, 2, NULL, 10430, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14044, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.728567+00', 'Heather on the Loch', 'HEATHER ON THE LOCH', 3, 32, NULL, 1, 2, NULL, 348, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14045, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.735311+00', '(K)night in the Box, A', 'KNIGHT IN THE BOX', 1, 32, NULL, 4, 4, 13, 10430, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14046, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.741396+00', 'Mr Steve Wyrick''s Reel', 'MR STEVE WYRICKS REEL', 1, 32, NULL, 1, 2, NULL, 348, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14047, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.747585+00', 'Mr Steve Wyrick''s Strathspey', 'MR STEVE WYRICKS STRATHSPEY', 3, 32, NULL, 1, 2, NULL, 348, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14048, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.753637+00', 'My Lady Hamilton', 'MY LADY HAMILTON', 3, 32, NULL, 1, 2, NULL, 348, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14049, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.759682+00', 'New World Strathspey, The', 'NEW WORLD STRATHSPEY', 3, 32, NULL, 1, 2, NULL, 10431, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14050, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.766682+00', 'Night Owl and Sandpiper', 'NIGHT OWL AND SANDPIPER', 3, 32, NULL, 1, 4, 1, 10430, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2701, '1997-04-03 22:00:00+00', '2019-08-16 19:46:03.662782+00', 'Guinea Pigs Jig, The', 'GUINEA PIGS JIG', 2, 48, 9999, 1, 3, 42, 270, NULL, '', 56, '844/844/866/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14059, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.803485+00', 'Tulla Tussle', 'TULLA TUSSLE', 2, 32, NULL, 3, 5, NULL, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14060, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.810359+00', 'And the Little One Said', 'AND THE LITTLE ONE SAID', 2, 32, NULL, 1, 4, 1, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14064, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.837038+00', 'Gay Gordon River Dance, The', 'GAY GORDON RIVER DANCE', 1, 32, NULL, 7, 98, 4, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14065, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.843286+00', 'Hobart Hornpipe', 'HOBART HORNPIPE', 1, 32, NULL, 3, 5, NULL, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14069, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.869164+00', 'Trip to Tassie', 'TRIP TO TASSIE', 2, 40, NULL, 4, 5, 30, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14027, '2011-08-25 22:00:00+00', '2022-07-31 19:01:49.343983+00', 'Whimsy', 'WHIMSY', 2, 88, NULL, 6, 3, 3, 389, '2006-01-01', 'This is a performance dance with elements of old time ballroom.', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14094, '2011-08-25 22:00:00+00', '2018-04-03 00:07:33.632835+00', 'Black Swan, The', 'BLACK SWAN', 3, 32, NULL, 1, 3, 42, 10440, NULL, '<<scddb:not-identical:554>>

<<scddb:not-identical:555>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14070, '2011-08-25 22:00:00+00', '2018-04-03 00:07:36.093829+00', 'Budelah', 'BUDELAH', 2, 32, NULL, 1, 3, 42, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14016, '2011-08-25 22:00:00+00', '2018-04-03 00:07:37.954665+00', 'Changeling, The', 'CHANGELING', 2, 48, NULL, 1, 3, 42, 389, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14083, '2011-08-25 22:00:00+00', '2012-01-20 12:57:50.972922+00', 'Mary McDonald', 'MARY MACDONALD', 1, 48, NULL, 1, 4, 1, 10436, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14088, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.016184+00', 'My Friend Margaret', 'MY FRIEND MARGARET', 3, 32, NULL, 1, 4, 1, 10436, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14091, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.042671+00', 'Bill & Mary Moore', 'BILL AND MARY MOORE', 3, 32, NULL, 2, 3, NULL, 10439, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14095, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.072182+00', 'Jaunty Jan', 'JAUNTY JAN', 1, 32, NULL, 2, 3, NULL, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14073, '2011-08-25 22:00:00+00', '2017-05-14 01:47:32.918397+00', 'Pauline''s Promenade', 'PAULINES PROMENADE', 3, 32, NULL, 1, 3, 42, 10435, NULL, 'A dance devised by Ian Dickson for Pauline Kerby, Sunderland, a member of our dancing group.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14087, '2011-08-25 22:00:00+00', '2018-04-03 00:07:43.61852+00', 'Durham Argus, The', 'DURHAM ARGUS', 2, 40, NULL, 1, 3, 42, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14074, '2011-08-25 22:00:00+00', '2017-07-13 07:34:25.502263+00', 'It Flows Nicely', 'IT FLOWS NICELY', 1, 32, NULL, 1, 3, 42, 10436, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14079, '2011-08-25 22:00:00+00', '2018-04-03 00:07:46.529642+00', 'For Marion', 'FOR MARION', 1, 48, NULL, 1, 3, 42, 10436, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14090, '2011-08-25 22:00:00+00', '2018-04-03 00:07:47.21348+00', 'Fulwell Mill', 'FULWELL MILL', 1, 40, NULL, 1, 3, 42, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14092, '2011-08-25 22:00:00+00', '2018-04-03 00:07:54.62792+00', 'It''s My Dance', 'ITS MY DANCE', 1, 32, NULL, 1, 3, 42, 10440, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14012, '2011-08-24 22:00:00+00', '2018-04-03 00:08:02.842396+00', 'McEwan Hall', 'MACEWAN HALL', 3, 32, NULL, 1, 3, 42, 2788, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14082, '2011-08-25 22:00:00+00', '2018-04-03 00:08:05.494248+00', 'Moth Ball, The', 'MOTH BALL', 2, 32, NULL, 1, 3, 42, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14085, '2011-08-25 22:00:00+00', '2018-04-03 00:08:06.660812+00', 'Mrs Rose Ann Robertson', 'MRS ROSE ANN ROBERTSON', 3, 32, NULL, 1, 3, 42, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14096, '2011-08-25 22:00:00+00', '2018-04-03 00:08:07.529477+00', 'Nell''s Strathspey', 'NELLS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 2804, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14068, '2011-08-25 22:00:00+00', '2018-04-03 00:08:09.113891+00', 'On Yer Bike!', 'ON YER BIKE', 3, 32, NULL, 1, 3, 42, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14089, '2011-08-25 22:00:00+00', '2018-04-03 00:08:09.414039+00', 'Our Golden Year', 'OUR GOLDEN YEAR', 2, 40, NULL, 1, 3, 42, 2804, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14051, '2011-08-25 22:00:00+00', '2018-04-03 00:08:11.432524+00', 'Protector of High Places', 'PROTECTOR OF HIGH PLACES', 1, 32, NULL, 1, 3, 42, 348, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14066, '2011-08-25 22:00:00+00', '2018-04-03 00:08:14.676487+00', 'Salamanca Markey', 'SALAMANCA MARKEY', 3, 32, NULL, 1, 3, 42, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14062, '2011-08-25 22:00:00+00', '2018-04-03 00:08:15.076626+00', 'Say Cheese', 'SAY CHEESE', 1, 32, NULL, 1, 3, 42, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14063, '2011-08-25 22:00:00+00', '2018-04-03 00:08:18.637686+00', 'Strahan Strathspey', 'STRAHAN STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14055, '2011-08-25 22:00:00+00', '2018-04-03 00:08:18.771001+00', 'Strathspey for Lori & Michael', 'STRATHSPEY FOR LORI AND MICHAEL', 3, 32, NULL, 1, 3, 42, 2701, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14061, '2011-08-25 22:00:00+00', '2018-04-03 00:08:19.946931+00', 'Tartan Kiwis, The', 'TARTAN KIWIS', 3, 32, NULL, 1, 3, 42, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14057, '2011-08-25 22:00:00+00', '2018-04-03 00:08:20.063615+00', 'Taskmaster, The', 'TASKMASTER', 1, 32, NULL, 1, 3, 42, 10430, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14058, '2011-08-25 22:00:00+00', '2018-04-03 00:08:23.81601+00', 'Visit with Claudette, A', 'VISIT WITH CLAUDETTE', 2, 32, NULL, 1, 3, 42, 10431, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14132, '2011-08-25 22:00:00+00', '2018-09-03 06:08:26.054646+00', 'P-Platers'' Jig, The', 'PPLATERS JIG', 2, 32, NULL, 1, 4, 1, 10433, NULL, 'This dance is dedicated to Scottish Country Dancers everywhere. It''s a great moment when you progress from being a bewildered beginner and give up your ''L'' plates for ''P'' plates.', 47, '8000/8448/8000/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14099, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.096575+00', 'Belles of St Chad''s, The', 'BELLES OF ST CHADS', 3, 32, NULL, 1, 4, NULL, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14100, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.103306+00', 'Twenty Five Years On', 'TWENTY FIVE YEARS ON', 2, 64, NULL, 1, 4, 1, 217, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14101, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.110024+00', '1948', '1948', 1, 32, NULL, 1, 4, 1, 10443, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14121, '2011-08-25 22:00:00+00', '2018-09-01 23:33:16.472477+00', 'Spilt Milk', 'SPILT MILK', 2, 32, NULL, 1, 3, 42, 10433, NULL, '600 mls of milk goes a long way when it is not going into cups of tea! ', 59, '888/844/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14043, '2011-08-25 22:00:00+00', '2020-09-25 21:20:17.326624+00', 'Griffin''s Flight, The', 'GRIFFINS FLIGHT', 2, 32, NULL, 1, 3, 42, 348, NULL, '', 63, '888/880/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14117, '2011-08-25 22:00:00+00', '2020-09-26 08:22:09.380026+00', 'Mixer Box, The', 'MIXER BOX', 1, 32, NULL, 1, 3, 42, 10433, NULL, '', 52, '800/677/855/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14104, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.128633+00', 'Iain Stuart''s Strathspey', 'IAIN STUARTS STRATHSPEY', 3, 48, NULL, 4, 4, NULL, 10444, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14105, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.135481+00', 'Jig for John and Joan, A', 'JIG FOR JOHN AND JOAN', 2, 32, NULL, 1, 4, 2, 217, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14106, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.142242+00', 'Dance for a Young Couple, A', 'DANCE FOR A YOUNG COUPLE', 2, 32, NULL, 1, 4, 2, 217, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14107, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.194811+00', 'Reverend David Hamilton, The', 'REVEREND DAVID HAMILTON', 1, 48, NULL, 4, 4, NULL, 217, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14108, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.203751+00', 'Christopher and Margaret Sanders', 'CHRISTOPHER AND MARGARET SANDERS', 2, 32, NULL, 1, 4, 2, 217, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14110, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.218156+00', 'Dorothy''s Departure', 'DOROTHYS DEPARTURE', 2, 32, NULL, 1, 4, NULL, 217, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14111, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.225946+00', 'Manse Burn, The', 'MANSE BURN', 4, 128, 2, 4, 4, 4, 10443, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14112, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.232078+00', 'Save the Children', 'SAVE THE CHILDREN', 1, 48, NULL, 4, 4, NULL, 217, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14131, '2011-08-25 22:00:00+00', '2018-09-03 09:25:35.885704+00', 'Muddle in the Middle', 'MUDDLE IN THE MIDDLE', 1, 32, NULL, 1, 3, 42, 10433, NULL, '', 47, '844/844/822/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14114, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.244337+00', 'Waverley Welcome', 'WAVERLEY WELCOME', 1, 32, NULL, 5, 56, NULL, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14123, '2011-08-25 22:00:00+00', '2018-09-06 22:26:23.110522+00', 'Virginia Street Reel, The', 'VIRGINIA STREET REEL', 1, 32, NULL, 1, 2, 76, 10433, NULL, 'Waverley Scottish Society meets in a hall in Virginia Street, Mount Waverley.  



Note: I derived bars 1 - 8 from Martin Mulligan''s ''solo rights and lefts'' in his dance ''On the Wallaby Track''. I am indebted to John van der Touw, a member of the Waverley Scottish Society, for giving my derivation a name.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14124, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.306504+00', 'Wee Geordie', 'WEE GEORDIE', 2, 32, NULL, 6, 3, NULL, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14125, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.313913+00', 'Clayton Road', 'CLAYTON ROAD', 4, 64, 5, 1, 4, 1, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14126, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.320748+00', 'Crosses and Noughts', 'CROSSES AND NOUGHTS', 2, 64, NULL, 2, 3, 30, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14133, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.363591+00', 'Kennedy Strathspey, The', 'KENNEDY STRATHSPEY', 3, 32, NULL, 1, 4, NULL, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14217, '2011-08-26 22:00:00+00', '2018-04-03 00:08:14.000941+00', 'Ruby Lips', 'RUBY LIPS', 3, 32, NULL, 1, 3, 42, 1089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14180, '2011-08-26 22:00:00+00', '2018-04-03 00:08:19.471533+00', 'Sweetheart Abbey Jig', 'SWEETHEART ABBEY JIG', 2, 32, NULL, 1, 3, 42, 127, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14211, '2011-08-26 22:00:00+00', '2018-04-03 00:08:24.849923+00', 'Wendy of Appin', 'WENDY OF APPIN', 1, 32, NULL, 1, 3, 42, 1089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14168, '2011-08-26 22:00:00+00', '2018-04-03 00:08:26.993391+00', 'Ye''ll Aye Be Welcome', 'YELL AYE BE WELCOME', 1, 32, NULL, 1, 3, 42, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14134, '2011-08-25 22:00:00+00', '2012-01-20 12:57:51.370443+00', 'Shetland Quadrilles', 'SHETLAND QUADRILLES', 1, 180, NULL, 4, 4, 3, 9999, NULL, 'The Highlander Coll. vol 1 booklet says "Music for this dance can be found on "A Shetland Dance" by Da Fustra  (HRMCD008)"



The description has no explicit barring, and says "the figures are not strictly tied to the music, ...., so some sets may take longer to finish than the others ..." .  



There are 6 figures.  On the the CD there is one track for each figure, each with from 2 to 4 tunes.  No tune or track lengths are indicated.  The whole dance must far exceed 180 bars.  I do not see where that number came from; perhaps it is 180 per figure?  But are the six figures equally long?



This entry must be revised by someone who knows the dance and the music.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14097, '2011-08-25 22:00:00+00', '2018-04-03 00:07:35.87689+00', 'Broken Arm Reel, The', 'BROKEN ARM REEL', 1, 32, NULL, 1, 3, 42, 2804, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14127, '2011-08-25 22:00:00+00', '2018-04-03 00:07:56.16214+00', 'John Marriot Hall, The', 'JOHN MARRIOT HALL', 3, 40, NULL, 1, 3, 42, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14109, '2011-08-25 22:00:00+00', '2018-04-03 00:08:02.283732+00', 'Mar Lodge', 'MAR LODGE', 3, 32, NULL, 1, 3, 42, 10446, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14128, '2011-08-25 22:00:00+00', '2018-04-03 00:08:10.815272+00', 'Piper''s Rest, The', 'PIPERS REST', 1, 32, NULL, 1, 3, 42, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14113, '2011-08-25 22:00:00+00', '2018-04-03 00:08:22.431735+00', 'Trip to Bath, A', 'TRIP TO BATH', 1, 32, NULL, 1, 3, 42, 217, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14142, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.423077+00', 'Start as you Finish', 'START AS YOU FINISH', 1, 32, NULL, 2, 3, 17, 3718, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14143, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.429243+00', 'Worth Celebrating', 'WORTH CELEBRATING', 1, 96, NULL, 4, 4, NULL, 10453, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14144, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.435302+00', 'Keighley Five O', 'KEIGHLEY FIVE O', 1, 32, NULL, 3, 5, NULL, 10454, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14145, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.442143+00', 'Gentle Strathspey, The', 'GENTLE STRATHSPEY', 3, 32, NULL, 2, 3, 17, 10454, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14146, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.449255+00', 'Royal Charter, The', 'ROYAL CHARTER', 1, 32, NULL, 1, 4, 2, 10454, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14147, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.455364+00', 'At the End of the Pier', 'AT THE END OF THE PIER', 1, 32, NULL, 3, 5, NULL, 10455, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14148, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.462103+00', 'Aida', 'AIDA', 3, 32, NULL, 1, 4, 1, 948, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14103, '2011-08-25 22:00:00+00', '2020-09-26 08:05:56.66904+00', 'Sandra''s 60th', 'SANDRAS 60TH', 1, 32, NULL, 1, 3, 42, 217, NULL, '', 50, '800/844/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14136, '2011-08-26 22:00:00+00', '2020-09-26 09:00:45.417841+00', 'Celtic Capers', 'CELTIC CAPERS', 1, 32, NULL, 1, 2, 76, 74, NULL, '', 60, '84/88/88/84', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14137, '2011-08-26 22:00:00+00', '2020-09-26 09:41:46.82368+00', 'Fitzroy Fancy', 'FITZROY FANCY', 4, 64, 5, 4, 4, 13, 74, NULL, '', 100, '8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14139, '2011-08-26 22:00:00+00', '2020-09-26 09:49:53.309891+00', 'Up the Downs', 'UP THE DOWNS', 1, 32, NULL, 1, 4, 1, 74, NULL, '', 62, '8000/8440/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14141, '2011-08-26 22:00:00+00', '2020-09-26 09:58:14.42016+00', 'Pearces'' Gold', 'PEARCES GOLD', 3, 32, NULL, 2, 3, 17, 74, NULL, '', 71, '484/888/880/804', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9001, '1999-07-27 22:00:00+00', '2021-03-06 22:28:01.864026+00', 'Alastair Hunter''s Reel', 'ALASTAIR HUNTERS REEL', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 50, '844 844 844 844', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (14149, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.469139+00', 'Ardmair Bay', 'ARDMAIR BAY', 1, 32, NULL, 1, 4, 1, 650, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18643, '2018-09-18 22:31:49.852112+00', '2018-09-19 07:56:47.357775+00', 'Owl''s Wynd', 'OWLS WYND', 2, 32, NULL, 1, 3, 42, 3617, '2013-10-01', '', 49, '888/800/880/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14151, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.482133+00', 'Honeysuckle Cottage', 'HONEYSUCKLE COTTAGE', 3, 32, NULL, 1, 4, 1, 948, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14152, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.489015+00', 'Michael''s Rock', 'MICHAELS ROCK', 2, 32, NULL, 1, 4, 1, 948, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14153, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.495922+00', 'Sally Gap', 'SALLY GAP', 1, 32, NULL, 1, 4, 1, 948, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14154, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.50205+00', 'Sixty Years Come September', 'SIXTY YEARS COME SEPTEMBER', 3, 32, NULL, 3, 5, NULL, 650, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14187, '2011-08-26 22:00:00+00', '2019-01-14 02:32:47.975925+00', 'Wheel of Fortune', 'WHEEL OF FORTUNE', 2, 40, NULL, 1, 3, 42, 10459, '1990-01-01', '', 55, '800/888/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14163, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.53523+00', 'Mrs Staniland''s Strathspey', 'MRS STANILANDS STRATHSPEY', 3, 32, NULL, 4, 4, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14171, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.559944+00', 'Miss Wilson''s Strathspey', 'MISS WILSONS STRATHSPEY', 3, 72, NULL, 2, 3, NULL, 304, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14178, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.599564+00', 'Farmers Boy', 'FARMERS BOY', 1, 32, NULL, 1, 4, 2, 127, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14179, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.606349+00', 'Henley Regatta Medley', 'HENLEY REGATTA MEDLEY', 4, 192, 3, 4, 4, NULL, 127, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14174, '2011-08-26 22:00:00+00', '2019-07-30 15:07:01.987286+00', 'Bow Fiddle Strathspey', 'BOW FIDDLE STRATHSPEY', 3, 32, NULL, 1, 4, 2, 127, NULL, 'The Bow-Fiddle is a famous Rock at Portknockie in the Moray Firth. It appears as if someone is playing a fiddle. So with the reel of four up and down, and the reel of three across, I have tried to reproduce the fiddle and bow.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14193, '2011-08-26 22:00:00+00', '2019-10-28 18:44:55.26447+00', 'Don''s Party', 'DONS PARTY', 1, 32, NULL, 1, 3, 42, 10459, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14186, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.650495+00', 'Let''s Get Together', 'LETS GET TOGETHER', 1, 32, NULL, 5, 2, NULL, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14188, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.662625+00', 'Honey For Jan', 'HONEY FOR JAN', 3, 32, NULL, 1, 2, NULL, 10460, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14189, '2011-08-26 22:00:00+00', '2018-04-03 00:07:31.003216+00', 'Arasaid, The', 'ARASAID', 1, 32, NULL, 1, 3, 42, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14197, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.721212+00', 'Day at Culzean Castle, A', 'DAY AT CULZEAN CASTLE', 3, 32, NULL, 1, 4, 1, 10459, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14199, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.733396+00', 'Brand New', 'BRAND NEW', 1, 32, NULL, 2, 3, NULL, 670, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14204, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.752304+00', 'Peggy Rose', 'PEGGY ROSE', 1, 32, NULL, 1, 4, 1, 2419, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14212, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.764487+00', 'Lady of Glen', 'LADY OF GLEN', 1, 88, NULL, 4, 4, NULL, 1089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14213, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.771111+00', 'Ruby Pride', 'RUBY PRIDE', 1, 128, NULL, 4, 4, NULL, 1089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14214, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.778563+00', 'Mount Fuji Majesty', 'MOUNT FUJI MAJESTY', 1, 32, NULL, 4, 4, NULL, 1089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14215, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.784783+00', 'Wolfman of Kamagari', 'WOLFMAN OF KAMAGARI', 1, 32, NULL, 1, 4, NULL, 1089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14219, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.809283+00', 'Lady Hamilton''s Lace', 'LADY HAMILTONS LACE', 3, 32, NULL, 1, 4, NULL, 1089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14201, '2011-08-26 22:00:00+00', '2016-07-15 14:26:28.321802+00', 'Tribute to the Black Watch', 'TRIBUTE TO THE BLACK WATCH', 1, 32, NULL, 1, 4, 2, 2419, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14150, '2011-08-26 22:00:00+00', '2018-04-03 00:07:33.315822+00', 'Big Donald', 'BIG DONALD', 2, 32, NULL, 1, 3, 42, 948, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14198, '2011-08-26 22:00:00+00', '2018-04-03 00:07:35.225932+00', 'Bottle of the Best, A', 'BOTTLE OF THE BEST', 2, 32, NULL, 1, 3, 42, 10467, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14177, '2011-08-26 22:00:00+00', '2018-04-03 00:07:39.815177+00', 'Craigievar Reel', 'CRAIGIEVAR REEL', 1, 40, NULL, 1, 3, 42, 127, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14190, '2011-08-26 22:00:00+00', '2018-04-03 00:07:42.909654+00', 'Down the Murray', 'DOWN THE MURRAY', 1, 32, NULL, 1, 3, 42, 10461, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14192, '2011-08-26 22:00:00+00', '2018-04-03 00:07:44.177263+00', 'Eighty Candles for Cath', 'EIGHTY CANDLES FOR CATH', 1, 40, NULL, 1, 3, 42, 10463, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14196, '2011-08-26 22:00:00+00', '2018-04-03 00:08:06.845463+00', 'Muffin Lady, The', 'MUFFIN LADY', 1, 32, NULL, 1, 3, 42, 10466, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14195, '2011-08-26 22:00:00+00', '2012-09-07 10:14:08.820088+00', 'Betty''s Birthday Bash', 'BETTYS BIRTHDAY BASH', 1, 48, NULL, 1, 4, 1, 3520, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14252, '2011-09-02 22:00:00+00', '2018-09-08 20:44:47.246863+00', 'Fairly Risky', 'FAIRLY RISKY', 2, 32, NULL, 1, 4, 30, 10478, NULL, 'This dance is a variation on “The Frisky”', -1, '8008/8888/8448/7887', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14256, '2011-09-02 22:00:00+00', '2018-09-07 22:26:37.855031+00', 'Royal Message, The', 'ROYAL MESSAGE', 1, 32, NULL, 1, 3, 42, 10478, NULL, 'The author, Wil van den Berg, has withdrawn this dance; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14251, '2011-09-02 22:00:00+00', '2018-09-08 14:21:50.163675+00', 'More Elusive Muses', 'MORE ELUSIVE MUSES', 2, 32, NULL, 8, 105, 47, 10478, NULL, 'The author, Wil van den Berg, has withdrawn this dance from the database; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14229, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.873335+00', 'Twilight Cruise, A', 'TWILIGHT CRUISE', 2, 32, NULL, 1, 2, NULL, 843, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14230, '2011-08-26 22:00:00+00', '2012-01-20 12:57:51.879458+00', 'Quayside Strathspey, The', 'QUAYSIDE STRATHSPEY', 3, 32, NULL, 2, 3, NULL, 827, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14169, '2011-08-26 22:00:00+00', '2020-01-11 01:56:15.615182+00', 'Fergusons Jig, The', 'FERGUSONS JIG', 2, 120, NULL, NULL, 98, NULL, 304, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14172, '2011-08-26 22:00:00+00', '2020-01-11 02:00:59.265663+00', 'Twelvesome Reel, The', 'TWELVESOME REEL', 1, 176, NULL, NULL, 98, NULL, 304, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14185, '2011-08-26 22:00:00+00', '2020-01-19 22:31:09.827941+00', 'Witch''s Stone, The', 'WITCHS STONE', 2, 32, NULL, 1, 3, 42, 127, NULL, '', 59, '804/888/880/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14231, '2011-08-27 22:00:00+00', '2020-01-23 10:05:07.856786+00', 'Double Thirty Five', 'DOUBLE THIRTY FIVE', 1, 88, NULL, 4, 4, 3, 3729, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14162, '2011-08-26 22:00:00+00', '2020-08-25 19:15:32.948405+00', 'Aldessan', 'ALDESSAN', 2, 32, NULL, 1, 4, 1, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14234, '2011-08-27 22:00:00+00', '2020-09-26 21:28:32.600338+00', 'Ma''s Medley', 'MAS MEDLEY', 4, 128, 10020, 4, 4, 13, 2980, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14238, '2011-08-27 22:00:00+00', '2020-09-26 21:39:55.582565+00', 'Beekeeper From Skye, The', 'BEEKEEPER FROM SKYE', 2, 32, NULL, 1, 4, 1, 10473, NULL, '', 33, '4024/4000/8800/8004', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14181, '2011-08-26 22:00:00+00', '2021-02-04 18:48:35.816985+00', 'Barmaid, The', 'BARMAID', 1, 32, NULL, 1, 3, 42, 127, NULL, 'Devised for "Martina Gogolova" from Slovakia, University Student and part time Barmaid.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14272, '2011-10-15 22:00:00+00', '2012-01-20 12:57:52.153177+00', 'Caribbean Caledonian, The', 'CARIBBEAN CALEDONIAN', 3, 32, NULL, 2, 3, 18, 1445, NULL, 'For our friends Ruud and Ellen Douglas on their 40th wedding anniversary.  Ruud was born on the island of Aruba, and their 40th wedding party turned into a real Caribbean Ceilidh!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14273, '2011-10-15 22:00:00+00', '2012-01-20 12:57:52.159967+00', 'Summer day''s Fancy, A', 'SUMMER DAYS FANCY', 1, 32, NULL, 1, 3, 42, 1445, NULL, 'For our pianist friend Edwin Werner, and a tune to go with it.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14245, '2011-09-02 22:00:00+00', '2012-01-20 12:57:51.968692+00', 'Across the Sea', 'ACROSS THE SEA', 1, 32, NULL, 1, 2, NULL, 10478, NULL, 'The author, Wil van den Berg, has withdrawn this dance; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14248, '2011-09-02 22:00:00+00', '2012-01-20 12:57:51.989362+00', 'Dear Riet', 'DEAR RIET', 3, 32, NULL, 8, 6, 9, 10478, NULL, 'The author, Wil van den Berg, has withdrawn this dance; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14250, '2011-09-02 22:00:00+00', '2012-01-20 12:57:52.002297+00', 'Dutch Princess Royal, The', 'DUTCH PRINCESS ROYAL', 1, 28, NULL, 5, 56, NULL, 10478, NULL, 'The author, Wil van den Berg, has withdrawn this dance; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14220, '2011-08-26 22:00:00+00', '2018-04-03 00:07:41.366454+00', 'Danse de Chez Nous', 'DANSE DE CHEZ NOUS', 2, 32, NULL, 1, 3, 42, 651, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14254, '2011-09-02 22:00:00+00', '2012-01-20 12:57:52.029626+00', 'Red and Blue Doublet', 'RED AND BLUE DOUBLET', 3, 40, NULL, 1, 3, 42, 10478, NULL, 'The author, Wil van den Berg, has withdrawn this dance; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14255, '2011-09-02 22:00:00+00', '2012-01-20 12:57:52.035771+00', 'River Allan, The', 'RIVER ALLAN', 2, 32, NULL, 1, 2, NULL, 10478, NULL, 'The author, Wil van den Berg, has withdrawn this dance; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14236, '2011-08-27 22:00:00+00', '2019-02-26 17:22:08.985985+00', 'Mary Come of Age', 'MARY COME OF AGE', 3, 32, NULL, 2, 3, 17, 2980, NULL, '', 59, '484/888/484/488', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14253, '2011-09-02 22:00:00+00', '2014-10-28 14:22:52.085967+00', 'Invitation, The', 'INVITATION', 2, 32, NULL, 1, 3, 42, 10478, NULL, 'The author, Wil van den Berg, has withdrawn this dance; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14258, '2011-09-02 22:00:00+00', '2012-01-20 12:57:52.05683+00', 'Simple Airie', 'SIMPLE AIRIE', 2, 32, NULL, 3, 5, 7, 10478, NULL, 'The author, Wil van den Berg, has withdrawn this dance; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14261, '2011-09-09 22:00:00+00', '2012-01-20 12:57:52.077574+00', 'Rambling Rose', 'RAMBLING ROSE', 3, 40, NULL, 4, 4, 13, 1228, '2008-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14263, '2011-09-10 22:00:00+00', '2012-01-20 12:57:52.090662+00', 'Sophisticated Ladies', 'SOPHISTICATED LADIES', 3, 40, NULL, 1, 4, 1, 1228, '2008-01-21', '2nd and 4th couples begin on the opposite side.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14265, '2011-09-10 22:00:00+00', '2012-01-20 12:57:52.1052+00', 'Twirling Shirley''s, The', 'TWIRLING SHIRLEYS', 2, 32, NULL, 2, 3, 4, 1228, '2010-10-29', 'Dedicated to our two Shirley''s.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14266, '2011-09-10 22:00:00+00', '2012-01-20 12:57:52.112575+00', 'Trip to New Zealand', 'TRIP TO NEW ZEALAND', 3, 32, NULL, 8, 6, 12, 1228, '2010-04-18', '4th,5th and 6th couples begin on the opposite side.

Can be danced as a 3 couple dance, with progression (2,3,1)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14267, '2011-09-10 22:00:00+00', '2012-01-20 12:57:52.11945+00', '40 Not Out', '40 NOT OUT', 3, 48, NULL, 1, 4, 11, 1228, '2008-11-01', 'To celebrate our Ruby Wedding Anniversary

This is a Reel or Strathspey;  Best danced as a Strathspey.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14268, '2011-09-10 22:00:00+00', '2012-01-20 12:57:52.126409+00', '50th Anniversary Reel', '50TH ANNIVERSARY REEL', 1, 32, NULL, 3, 5, 48, 1228, '2009-10-15', 'Devised for the Crawley Scottish Country Dancing Club on the occasion of their 50th Anniversary Dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14275, '2011-10-15 22:00:00+00', '2012-01-20 12:57:52.17366+00', 'Tribute to Jean McKirdy', 'TRIBUTE TO JEAN MACKIRDY', 2, 32, NULL, 1, 3, 42, 1445, NULL, 'For Jean McKirdy and her Edinburgh highland dancers who helped us so much in getting our shows on th road!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14277, '2011-10-15 22:00:00+00', '2012-01-20 12:57:52.187277+00', 'Hop, Skip and Dance!', 'HOP SKIP AND DANCE', 2, 32, NULL, 1, 3, 42, 1445, NULL, 'To allthose very young dancers ho always enjoy the dancing so much', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14257, '2011-09-02 22:00:00+00', '2015-09-05 21:20:07.062045+00', 'Ruud''s Reel', 'RUUDS REEL', 1, 40, NULL, 1, 3, 42, 10478, NULL, 'The author, Wil van den Berg, has withdrawn this dance; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14233, '2011-08-27 22:00:00+00', '2019-02-26 21:28:46.745718+00', 'Saga Strathspey, The', 'SAGA STRATHSPEY', 3, 32, NULL, 2, 3, 17, 2980, NULL, '', 92, '888/484/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14226, '2011-08-26 22:00:00+00', '2018-04-03 00:08:06.41999+00', 'Mrs Kondo''s Strathspey', 'MRS KONDOS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 843, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14227, '2011-08-26 22:00:00+00', '2018-04-03 00:08:06.528758+00', 'Mrs Matuhasi', 'MRS MATUHASI', 3, 32, NULL, 1, 3, 42, 843, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14228, '2011-08-26 22:00:00+00', '2018-04-03 00:08:12.408106+00', 'Reel of Kem', 'REEL OF KEM', 1, 32, NULL, 1, 3, 42, 843, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14237, '2011-08-27 22:00:00+00', '2019-06-18 09:15:27.849003+00', 'Senior Citizen''s Reel', 'SENIOR CITIZENS REEL', 1, 32, NULL, 4, 5, 35, 2980, NULL, '', 61, '88888/20208/84848/20228', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14279, '2011-10-15 22:00:00+00', '2012-01-20 12:57:52.200833+00', 'Firefly Jig, The', 'FIREFLY JIG', 2, 40, NULL, 1, 4, 1, 1445, NULL, 'For John and Margaret Lambourne on their silver wedding.  John and Margaret live in a street called Firefly Meadow.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14334, '2011-12-08 23:00:00+00', '2018-04-03 00:07:41.241336+00', 'Dancing Q-Tip, The', 'DANCING QTIP', 1, 32, 9999, 1, 3, 42, 10575, '2007-01-01', 'Devised: 2007', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14333, '2011-12-08 23:00:00+00', '2018-04-03 00:08:12.708376+00', 'Retiring Lass, The', 'RETIRING LASS', 1, 32, 9999, 1, 3, 42, 2701, '2009-01-01', 'Devised: 2009', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14297, '2011-11-04 23:00:00+00', '2012-01-20 12:57:52.332273+00', 'Auld Reekie', 'AULD REEKIE', 7, 0, NULL, 99, 99, NULL, 10513, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14298, '2011-11-04 23:00:00+00', '2012-01-20 12:57:52.338476+00', 'Dusty Miller, The', 'DUSTY MILLER', 7, 0, NULL, 99, 99, NULL, 9999, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14299, '2011-11-04 23:00:00+00', '2012-01-20 12:57:52.344549+00', 'Bonnie Briest Knot, The', 'BONNIE BRIEST KNOT', 7, 0, NULL, 99, 99, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14300, '2011-11-04 23:00:00+00', '2012-01-20 12:57:52.349321+00', 'Blue Bonnets (4/4 version)', 'BLUE BONNETS 4/4 VERSION', 7, 0, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14302, '2011-11-04 23:00:00+00', '2012-01-20 12:57:52.358691+00', 'Deeside Lilt (6/8 version), The', 'DEESIDE LILT 6/8 VERSION', 7, 0, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14232, '2011-08-27 22:00:00+00', '2020-09-26 21:18:41.460993+00', 'Ann MacDonald of Drumuie', 'ANN MACDONALD OF DRUMUIE', 2, 32, NULL, 1, 3, 42, 2980, NULL, '', 63, '888/888/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14235, '2011-08-27 22:00:00+00', '2020-09-26 21:35:18.724236+00', 'Jess''s Jig', 'JESSS JIG', 2, 40, NULL, 1, 3, 42, 10472, NULL, '', 49, '420/888/866/840/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14293, '2011-11-01 23:00:00+00', '2020-09-27 09:08:31.551147+00', 'Mr Pixton of Brookline', 'MR PIXTON OF BROOKLINE', 1, 32, 9999, 1, 4, 11, 608, NULL, '', 84, '2882/4884/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14296, '2011-11-04 23:00:00+00', '2021-01-23 23:34:06.557894+00', 'Rowan Tree, The', 'ROWAN TREE', 7, 0, NULL, 99, 99, NULL, 10512, NULL, '<<scddb-not-identical:5726;5727;5728>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14305, '2011-11-04 23:00:00+00', '2012-01-20 12:57:52.368004+00', 'Highland Laddie (4/4 version)', 'HIGHLAND LADDIE 4/4 VERSION', 7, 0, NULL, NULL, NULL, NULL, 9998, NULL, '<<scddb:not-identical:8752>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14309, '2011-11-04 23:00:00+00', '2012-01-20 12:57:52.382242+00', 'Old Scottish Lilt, The', 'OLD SCOTTISH LILT', 7, 0, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14311, '2011-11-04 23:00:00+00', '2012-01-20 12:57:52.391725+00', 'Pas de Deux for the Misses Grant of Monymusk', 'PAS DE DEUX FOR THE MISSES GRANT OF MONYMUSK', 7, 0, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14312, '2011-11-04 23:00:00+00', '2012-01-20 12:57:52.396424+00', 'Pas de Trois for the Misses Glennie', 'PAS DE TROIS FOR THE MISSES GLENNIE', 7, 0, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14314, '2011-11-04 23:00:00+00', '2012-01-20 12:57:52.40571+00', 'Village Maid, The', 'VILLAGE MAID', 7, 0, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14315, '2011-11-04 23:00:00+00', '2012-01-20 12:57:52.410444+00', 'Way tae Fife, The', 'WAY TAE FIFE', 7, 0, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14316, '2011-11-04 23:00:00+00', '2012-01-20 12:57:52.415145+00', 'Welcome to Galloway', 'WELCOME TO GALLOWAY', 7, 0, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14317, '2011-11-10 23:00:00+00', '2012-01-20 12:57:52.422553+00', 'Oliver''s Dance', 'OLIVERS DANCE', 4, 32, 2, 1, 4, 3, 3775, '2008-11-01', 'Danced twice as Strathspey, then twice as reel.  

Suitable recording: Leslie House (Medley) from "Memories of Fife".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14321, '2011-12-01 23:00:00+00', '2012-01-20 12:57:52.457141+00', 'Mr John Duckett', 'MR JOHN DUCKETT', 2, 32, NULL, 1, 4, 2, 3694, NULL, 'Source: "Pilling", Supplement to 8th Ed.  

The cover of the "Green Book Set of SCD" names the deviser.  

On the TACbooks page the dance is named "Mr. John Duckett''s Jig"; that has therefore been entered as an alias.  ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14328, '2011-12-07 23:00:00+00', '2012-01-20 12:57:52.516255+00', 'Occidental Ceilidh, The', 'OCCIDENTAL CEILIDH', 50, 32, 9999, 1, 4, 1, 2701, '2007-08-11', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14751, '2013-04-01 10:30:39.78901+00', '2013-04-01 10:30:39.789016+00', 'Accolade to Elspeth', 'ACCOLADE TO ELSPETH', 3, 40, NULL, 2, 3, NULL, 10765, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14742, '2013-03-23 08:38:29.490295+00', '2013-03-26 22:09:16.602191+00', 'Deerness Reel, The', 'DEERNESS REEL', 1, 32, NULL, 4, 4, NULL, 3165, '1988-01-01', 'The dance consists of four 16-bar movements each followed by the 16-bar chorus.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14307, '2011-11-04 23:00:00+00', '2015-02-05 13:46:48.34737+00', 'Hirondelle, L''', 'HIRONDELLE', 7, 0, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14281, '2011-10-26 22:00:00+00', '2015-05-29 15:55:40.319355+00', 'O''er the Hills', 'OER THE HILLS', 2, 96, 9999, 4, 4, 3, 10490, '2008-01-01', 'As music the author suggests "any uplifting jig".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14290, '2011-10-26 22:00:00+00', '2015-05-29 15:55:56.086876+00', 'Wavre Adieu a La Saltarelle', 'WAVRE ADIEU A LA SALTARELLE', 2, 48, 9999, 1, 4, 1, 10497, '2006-07-01', 'As music the authors suggest "any cordial jig".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14283, '2011-10-26 22:00:00+00', '2015-05-29 15:54:56.532812+00', 'Bermuda Triangle, The', 'BERMUDA TRIANGLE', 3, 32, 9999, 6, 3, 17, 10492, '2008-01-01', 'As music the author suggests "any languid Strathspey".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14284, '2011-10-26 22:00:00+00', '2015-05-29 15:54:14.524396+00', 'Aroon Aboot Midnight', 'AROON ABOOT MIDNIGHT', 4, 128, 2, 4, 4, 1, 10493, '2008-01-01', 'As music the author suggests "any suitable Strathspey/Reel medley".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14286, '2011-10-26 22:00:00+00', '2015-05-29 15:52:32.945489+00', 'First Try, The', 'FIRST TRY', 3, 32, 9999, 2, 3, 17, 10494, '2008-01-01', 'As music the author suggests "Neidpath Castle" or "any suitable Strathspey".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14292, '2011-10-26 22:00:00+00', '2015-05-29 15:49:10.331441+00', 'Top Gear Reel', 'TOP GEAR REEL', 1, 48, 9999, 1, 4, 1, 10499, '2008-01-01', 'As music the author suggests "any racy reel".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14291, '2011-10-26 22:00:00+00', '2015-05-29 15:49:44.04923+00', 'United in Harmony', 'UNITED IN HARMONY', 3, 32, 9999, 1, 4, 1, 10498, '2008-03-01', 'As music the author suggests "any harmonious Strathspey".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14289, '2011-10-26 22:00:00+00', '2015-05-29 15:50:30.703091+00', 'Well Mixed', 'WELL MIXED', 1, 88, 9999, 4, 4, 3, 3066, '2008-01-01', 'As music the author suggests "any stirring reel".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8197, '1999-12-19 23:00:00+00', '2013-03-25 00:05:55.373719+00', 'Silkie, The', 'SILKIE', 2, 40, 9999, 1, 4, 2, 2682, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14366, '2011-12-16 23:00:00+00', '2018-04-10 11:50:56.622875+00', 'Ke Nako - It is Time', 'KE NAKO  IT IS TIME', 3, 32, 9999, 2, 3, 17, 3179, '2010-07-01', 'The Tswana expression "Ke nako" which can be translated with "It is time" was widely used during the 2010 Soccer World Cup in South Africa.', 75, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14752, '2013-04-01 10:34:27.076593+00', '2018-04-03 00:07:33.340604+00', 'Bill and Sheena''s 50th Anniversary Jig', 'BILL AND SHEENAS 50TH ANNIVERSARY JIG', 2, 32, NULL, 1, 3, 42, 10766, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14325, '2011-12-07 23:00:00+00', '2018-08-09 01:27:57.556516+00', 'Clive''s Riddle', 'CLIVES RIDDLE', 2, 32, NULL, 1, 3, 42, 10563, NULL, 'Written by Dagmar Koeppler for Clive Griffiths and Sylvia Riddell upon their departure for the »sunnier« West Coast.



The description suggests *Icebreaker* from the White Cockade album, Tartan Capers.', 47, '840/880/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14753, '2013-04-01 10:37:52.696768+00', '2013-04-01 10:37:52.696774+00', 'Broken River Flood', 'BROKEN RIVER FLOOD', 1, 40, NULL, 3, 5, NULL, 3757, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14760, '2013-04-02 10:55:19.696163+00', '2018-04-03 00:07:41.09962+00', 'Dancing Chains', 'DANCING CHAINS', 2, 32, NULL, 1, 3, 42, 10767, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15040, '2013-08-02 19:24:06.742196+00', '2020-01-15 18:22:53.42108+00', 'Nifty Ninety', 'NIFTY NINETY', 1, 32, NULL, 107, 111, 30, 727, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14336, '2011-12-08 23:00:00+00', '2020-07-14 20:56:59.746125+00', 'Homecoming Reel, The', 'HOMECOMING REEL', 1, 32, 9999, 5, 2, 30, 1331, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14341, '2011-12-10 23:00:00+00', '2020-12-31 11:45:46.932769+00', 'Lightnin'' Bug, The', 'LIGHTNIN BUG', 2, 32, NULL, 2, 3, 18, 2701, '2009-05-10', 'For Paula Jacobson who is a bright spot on the dance floor. Her patient, skillful teaching and excellent dance briefings provide illumination for many dancers in the area.', 59, '770/770/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14763, '2013-04-02 19:14:42.61445+00', '2018-04-03 00:07:42.475916+00', 'Don''s Birthday Frolics', 'DONS BIRTHDAY FROLICS', 1, 32, NULL, 1, 3, 42, 1418, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14376, '2011-12-16 23:00:00+00', '2020-09-27 20:14:27.267684+00', 'Mint Truffles', 'MINT TRUFFLES', 3, 32, NULL, 1, 3, 42, 2476, '2007-05-01', '"Top Rated Strathspey"



Suggested Music: "The Sheltered Cove" on the CD Aye Afloat, track #06, or "Monadh

Liath" on the CD Kardinia Capers, track #10', 63, '844/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14303, '2011-11-04 23:00:00+00', '2023-01-12 15:15:32.977732+00', 'Flowers of Edinburgh, The', 'FLOWERS OF EDINBURGH', 7, 0, NULL, 107, 51, NULL, 9998, NULL, '6 steps', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14340, '2011-12-10 23:00:00+00', '2020-12-31 11:48:45.876901+00', 'Merry Lad''s Affair, The', 'MERRY LADS AFFAIR', 1, 32, NULL, 1, 3, 42, 2701, '2010-01-01', 'For Frank Simeone and Victoria Lewis of the Noe Valley class. I taught The Merry Lads of Ayr prior to an upcoming party and apparently I didn’t enunciate clearly enough. I found Frank chuckling when he saw the dance name printed on the program because he realized that the name was different from what he had thought it was.



Music:	A rakish reel.

', 56, '844/844/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14313, '2011-11-04 23:00:00+00', '2021-05-01 22:56:08.043771+00', 'Rose of Benbecula, The', 'ROSE OF BENBECULA', 7, 0, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14308, '2011-11-04 23:00:00+00', '2021-07-04 12:24:59.229966+00', 'Maid of Islay, The', 'MAID OF ISLAY', 7, 80, NULL, NULL, NULL, NULL, 242, '1950-01-01', 'Devised circa 1950 and gifted to Mrs Tihi West for her daughter Wendy West by Mrs MacNab, believed on a visit to St Andrews Summer School. It was revised in 1976 by Mrs Tihi West, for teaching. The bars are 8+8+8+8+32+16=80. Information from <<https://my.strathspey.org/dd/issue/2443/|issue 2443>>.', -1, '', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (14329, '2011-12-07 23:00:00+00', '2021-09-23 20:42:05.379624+00', 'Basic Knitting', 'BASIC KNITTING', 2, 32, 9999, 1, 3, 42, 10573, '2007-10-01', 'Traditionally, every San Francisco Class Solstice Party program includes a dance devised by or for a class member.

Michael Iachini started dancing last year (2006-2007).', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14326, '2011-12-07 23:00:00+00', '2018-08-09 10:21:07.342812+00', 'Diamond for Don, A', 'DIAMOND FOR DON', 3, 40, NULL, 1, 3, 42, 10565, '2005-05-01', 'Written for Don Nemiroff on the occasion of his 60th birthday. In the six bars 27-32, the 1st couple are tracing the shape of mirrored 6''s, while in bars 33-40, the six dancers inscribe the shape »0«. The two figures together honour Don''s big day.



The description suggests »Snow in Summer« from the Berkeley Scottish Players album, »A Camp of Pleasure«.', 66, '800/888/844/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14754, '2013-04-01 10:40:39.183271+00', '2018-04-03 00:07:37.095175+00', 'Carnoustie Lass, The', 'CARNOUSTIE LASS', 2, 40, NULL, 1, 3, 42, 10466, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14324, '2011-12-07 23:00:00+00', '2018-08-09 01:05:05.491891+00', 'Caloundra Capers', 'CALOUNDRA CAPERS', 3, 32, NULL, 2, 3, 17, 1322, NULL, 'The dance was written by Alex Small from figures devised by Bob Campbell of Oakville, Ontario, for the Caloundra Scottish Dancers of Queensland, Australia.



The description suggests »any good recording for Neidpath Castle«.', 53, '880/844/866/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14348, '2011-12-13 23:00:00+00', '2017-11-11 19:36:45.227897+00', 'Auchindrain', 'AUCHINDRAIN', 1, 32, NULL, 1, 3, 42, 1167, '2007-11-28', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14344, '2011-12-12 23:00:00+00', '2017-11-12 04:05:43.536153+00', 'Jean', 'JEAN', 2, 32, NULL, 1, 3, 42, 1167, '2008-04-01', 'Dance devised in honor of Jean Attwood, author of ''The Falls of Rogie'' and many other good dances. This dance is drawn, shamelessly, from her dance ''Glen Falloch'' in Alexander Dances #2.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14360, '2011-12-15 23:00:00+00', '2017-11-12 04:10:57.401553+00', 'Gordon of Straloch', 'GORDON OF STRALOCH', 3, 32, NULL, 1, 3, 42, 1167, '2009-11-01', 'Recommended recorded music: Set of Strathspey Airs (track 5) on Waverley Station''s CD First Stop.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14345, '2011-12-12 23:00:00+00', '2017-11-13 08:37:15.350473+00', 'Miss Ilona Brown', 'MISS ILONA BROWN', 3, 32, NULL, 3, 5, NULL, 635, NULL, 'Devised by Malcolm Brown.  Miss Ilona Brown is one of his grand-daughters. This dance was the result of having five couples in the class when wanting to teach a three couple dance (in a four couple set).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14359, '2011-12-14 23:00:00+00', '2017-11-14 00:58:13.451828+00', 'Triangle Reel', 'TRIANGLE REEL', 2, 32, NULL, 1, 3, 42, 10581, NULL, 'Music: Tilliedudlem on Music Makars: Sing, Dance and Rejoice', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14361, '2011-12-15 23:00:00+00', '2017-11-14 01:07:06.50609+00', 'Miss McBurnie''s Wedding', 'MISS MACBURNIES WEDDING', 3, 32, NULL, 2, 3, 17, 10582, '2009-10-10', 'Devised by Andrew Hodgson in celebration of his marriage to Miss Heather McBurnie on 10th October 2009 in Cape Town. 



Recommended recorded music: "The Partnership" from "Vintage Goldring" by Muriel Johnstone & Keith Smith 



', 54, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14362, '2011-12-15 23:00:00+00', '2017-11-14 01:08:36.944578+00', 'Laird Jim''s 60th', 'LAIRD JIMS 60TH', 1, 60, NULL, 4, 4, 3, 10583, '2009-08-01', 'Devised by the Unit 3 class of week 2 at the 2009 Summer School, to celebrate the 60th birthday of Jim Laird who was their pianist. Contact: Gabrielle Funhoff, parbleuoui@aol.com', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14327, '2011-12-07 23:00:00+00', '2018-04-03 00:07:45.411829+00', 'Fenton''s Fancy', 'FENTONS FANCY', 2, 32, NULL, 1, 3, 42, 10566, NULL, 'Dedicated to Helen Fenton on her move from Montréal to Victoria, British Columbia.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18579, '2018-09-11 08:58:11.129048+00', '2018-09-11 22:44:32.413812+00', 'Rambling Round the Raith', 'RAMBLING ROUND THE RAITH', 3, 32, NULL, 1, 3, 42, 2863, '2017-05-01', 'Story: upgraded Interchange at Junction 5, M74  

Set - new traffic lights  

Bourrel - double roundabout  

Arches - new underpass and bridges overhead  

Reels - dual carriageway linking everything up', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18647, '2018-09-18 22:52:31.807772+00', '2018-09-23 22:47:41.166723+00', 'Skunk in Spate, The', 'SKUNK IN SPATE', 2, 40, NULL, 1, 3, 42, 11710, NULL, 'Note:  1 – 24 Same as Skunk River Reel', 65, '800/888/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18585, '2018-09-12 20:09:11.282489+00', '2018-10-09 14:53:32.684777+00', 'We Stand With France', 'WE STAND WITH FRANCE', 4, 64, 5, 1, 3, 42, 2766, '2015-11-01', 'Written after the terror attacks on Paris November 13, 2015.', 53, '855/855/888/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18581, '2018-09-12 00:07:49.662783+00', '2018-09-22 20:45:14.115983+00', 'Alcanede Strathspey', 'ALCANEDE STRATHSPEY', 3, 32, NULL, 1, 4, 1, 11225, NULL, '', 78, '8888/8888/8640/8046', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14349, '2011-12-13 23:00:00+00', '2019-02-15 17:19:59.463022+00', 'Mary Stewart Ashworth', 'MARY STEWART ASHWORTH', 1, 32, NULL, 1, 3, 42, 10578, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18582, '2018-09-12 19:53:19.323449+00', '2018-10-10 04:15:19.391473+00', 'Matrix Medley', 'MATRIX MEDLEY', 4, 64, 5, 105, 111, NULL, 2766, '2009-11-01', 'We often have many more women than men for demos.  This dance was written as a possible demo dance for one of those occasions.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12164, '2005-04-13 22:00:00+00', '2018-04-03 00:07:36.654577+00', 'Cambridge Hornpipe, The', 'CAMBRIDGE HORNPIPE', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14369, '2011-12-16 23:00:00+00', '2012-09-16 21:07:05.754504+00', 'Admirable Fred', 'ADMIRABLE FRED', 2, 64, NULL, 1, 100, 13, 10593, '2004-01-01', 'For Fred van Nus, who worked tirelessly to promote Scottish Country Dancing especially in

Clark County, WA (there''s a ballad that goes with the music available via vancouverusascd@comcast.net). [written when he was alive to hear the song; ed]', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14378, '2011-12-16 23:00:00+00', '2012-01-20 12:57:53.037978+00', 'Ships in the Night', 'SHIPS IN THE NIGHT', 3, 32, NULL, 1, 3, 42, 10594, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (74, '1998-07-09 22:00:00+00', '2014-04-30 23:23:37.535951+00', 'Alec Hay''s Delight', 'ALEC HAYS DELIGHT', 3, 32, 9999, 2, 3, 17, 108, '1992-02-01', 'This 2C dance needs to be danced in a 3C set, to give room for the reel of 4 on the midline.  3C stands still but steps up at the end for the progression.  It is therefore classified as a 3C dance in a 3C set.', 62, '84  88  88  88', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (2037, '1997-09-29 22:00:00+00', '2013-03-02 08:46:42.756991+00', 'Fair Rosamund', 'FAIR ROSAMUND', 3, 32, 9999, 2, 3, 18, 13, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4680, '1997-11-18 23:00:00+00', '2021-05-01 20:29:11.491447+00', 'Moulin Dhu', 'MOULIN DHU', 3, 120, 9999, 4, 4, 3, 9998, NULL, '##RSCDS-DI:omit-type



From the original description: "This is a working dance and shows the movements of the mill wheel. Collected in North Uist."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14749, '2013-03-26 21:16:24.02364+00', '2013-03-26 21:20:33.082444+00', 'Cambridge Hornpipe, The', 'CAMBRIDGE HORNPIPE', 1, 128, NULL, 4, 4, 3, 129, NULL, 'This "''The Cambridge Hornpipe'', an unlisted dance of Hugh Foss given as a leaflet to the Cambridge group." was sent to SCDDB by Rod Downey of New Zealand in march 2013.  It is composed of four related figures, each 32-bars, danced in succession.  



In the dance text Hugh Foss writes "There may already be a dance with this title, in which case a new title is to be found."', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14373, '2011-12-16 23:00:00+00', '2016-05-11 23:12:59.974376+00', 'Eleventh & Main', 'ELEVENTH AND MAIN', 3, 32, NULL, 107, 1, NULL, 10589, '2008-06-01', 'The idea for this dance began as a couple of dancers and a piper were waiting on a downtown

street comer for the rest of the performance team to arrive for a demo. The piper began to warm

up with a beautiful strathspey tune, and the two dancers mused, "If only we knew a strathspey

for one couple!"', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14375, '2011-12-16 23:00:00+00', '2018-08-05 18:11:58.830829+00', 'MAB of McLeod', 'MAB OF MACLEOD', 1, 32, NULL, 1, 3, 42, 10590, '1998-01-01', 'In memory of my mother, Marion Anna Beishlag, a professional pianist with a special spot in

her heart for The Dance. Her initials spelled MAB (the literary Queen of the Fairies). My father, 

Donald McLeod, oft'' times used the nickname, MAB.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14372, '2011-12-16 23:00:00+00', '2019-02-04 10:56:34.401961+00', 'Duncan Burn', 'DUNCAN BURN', 1, 32, NULL, 1, 3, 42, 2474, '2008-10-06', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14382, '2011-12-17 23:00:00+00', '2017-11-14 06:26:57.851393+00', 'Just a Dozen', 'JUST A DOZEN', 1, 40, NULL, 107, 6, 67, 156, '2011-10-13', '40-bar reel for two 3-couple sets, side by side.



Special progression.  After 40 bars, each set has progressed from (123) to (312), and the sets have swapped places.  All return home after 6 times through.



Suggested recording: ''Red House Revisited'', Vallin Suite 1, Track 1. (Neil Barron)', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14379, '2011-12-17 23:00:00+00', '2017-11-14 06:31:01.134774+00', 'Redfoot''s Ramble', 'REDFOOTS RAMBLE', 3, 32, NULL, 1, 4, 1, 3617, NULL, 'Devised by Linda Lieberman (lindasuzan [at] aol.com) assisted by the Monday night Scottish dancers at St. Luke''s church, Des Moines, Iowa.This dance is dedicated to Paige Morlan and Jonathan Rothfus on the occasion of their marriage, Saturday, July 23, 2011. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15293, '2013-12-10 19:16:21.296753+00', '2018-08-15 10:06:21.330426+00', 'Time Machine, The', 'TIME MACHINE', 2, 32, NULL, 1, 4, NULL, 10903, NULL, 'The dance was inspired by an event in Dance Scottish week in Bristol. Whilst dancing at a shopping mall, the Bristol RSCDS team saw people dressed up in Dr Who outfits. The dance shows: the arrival of the time machine/TARDIS (bars 1-8), the interaction of people after it has landed (9-24) and the chase back to original partners ready for another adventure (25-32). The Time Machine is written to encapsulate the adventures of the last 50 years.  

Since the dance is mainly danced with a partner it symbolises the inclusive nature of Bristol RSCDS.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18453, '2018-07-19 15:59:34.796236+00', '2018-09-19 09:42:42.559496+00', 'Amberley''s Labyrinth', 'AMBERLEYS LABYRINTH', 1, 48, 9999, 4, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18650, '2018-09-18 23:09:48.503261+00', '2018-09-19 09:03:46.946523+00', 'Sweet Tea Pie', 'SWEET TEA PIE', 3, 32, NULL, 1, 3, 42, 11716, '2014-12-01', '', 43, '800/844/880/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14737, '2013-03-14 15:52:30.342469+00', '2018-04-03 00:07:33.040246+00', 'Bennybeg, The', 'BENNYBEG', 1, 32, NULL, 1, 3, 42, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14731, '2013-03-14 15:40:28.303673+00', '2013-03-14 15:40:28.303678+00', 'Abigail''s Reel', 'ABIGAILS REEL', 1, 48, NULL, 4, 4, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14732, '2013-03-14 15:42:27.275957+00', '2013-03-14 15:42:27.275963+00', 'Tanglewood', 'TANGLEWOOD', 3, 32, NULL, 4, 4, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14733, '2013-03-14 15:44:47.213585+00', '2013-03-14 15:44:47.213591+00', 'Maurward Medley', 'MAURWARD MEDLEY', 4, 128, 2, 4, 4, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14735, '2013-03-14 15:49:12.676573+00', '2013-03-14 15:49:12.676578+00', 'Illy''s Jig', 'ILLYS JIG', 2, 128, NULL, 4, 4, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14736, '2013-03-14 15:51:02.774338+00', '2013-03-14 15:51:02.774344+00', 'You Will Pass Left', 'YOU WILL PASS LEFT', 3, 32, NULL, 2, 3, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14765, '2013-04-02 19:17:29.872386+00', '2018-08-28 09:42:28.840527+00', 'Double Forty', 'DOUBLE FORTY', 2, 40, NULL, 1, 3, 42, 10767, '2008-03-01', '', 58, '888/444/880/828/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14745, '2013-03-23 08:45:06.015537+00', '2013-03-23 08:45:06.015543+00', 'Dounby Jig, The', 'DOUNBY JIG', 2, 32, NULL, 3, 5, NULL, 3165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14757, '2013-04-02 10:47:10.903063+00', '2018-04-03 00:07:40.690913+00', 'Dance at Dookie 1 10th Australian Winter School 1985', 'DANCE AT DOOKIE 1 10TH AUSTRALIAN WINTER SCHOOL 1985', 2, 32, NULL, 1, 3, 42, 670, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14758, '2013-04-02 10:48:37.363911+00', '2018-04-03 00:07:40.699111+00', 'Dance at Dookie 2 16th Australian Winter School 1991', 'DANCE AT DOOKIE 2 16TH AUSTRALIAN WINTER SCHOOL 1991', 2, 32, NULL, 1, 3, 42, 670, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14734, '2013-03-14 15:47:29.391238+00', '2013-08-19 11:46:00.373033+00', 'Tandem, The', 'TANDEM', 3, 32, NULL, 1, 4, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14730, '2013-03-14 15:37:58.787384+00', '2013-08-19 11:45:58.427801+00', 'Four J''s Strathspey, The', 'FOUR JS STRATHSPEY', 3, 96, NULL, 4, 4, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14755, '2013-04-02 10:43:41.178138+00', '2018-04-03 00:07:40.707505+00', 'Dance at Dookie 3 30th Australian Winter School 2005', 'DANCE AT DOOKIE 3 30TH AUSTRALIAN WINTER SCHOOL 2005', 1, 32, NULL, 1, 3, 42, 670, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14759, '2013-04-02 10:52:18.019043+00', '2018-04-03 00:07:40.763697+00', 'Dance at Dookie 4 37th Australian Winter School 2012', 'DANCE AT DOOKIE 4 37TH AUSTRALIAN WINTER SCHOOL 2012', 1, 32, NULL, 1, 3, 42, 670, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14578, '2012-10-02 09:21:29.916877+00', '2020-09-01 08:39:02.658635+00', 'Lx', 'LX', 1, 32, NULL, 1, 3, 42, 1415, NULL, 'This dance was written for Lindsay Martin. Lx is how she always signs off her texts which has in the past

caused some amusement. Lindsay may come across as shy, but there is a mischievous streak in her which comes out in her dancing.', 56, '800/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14377, '2011-12-16 23:00:00+00', '2021-01-30 13:53:24.288575+00', 'Red Wine & Truffles', 'RED WINE AND TRUFFLES', 2, 32, NULL, 1, 3, 42, 2476, '2007-05-01', '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (77, '2002-12-05 23:00:00+00', '2021-04-17 21:30:51.532029+00', 'Alex Doig''s Jig', 'ALEX DOIGS JIG', 2, 32, 9999, 1, 3, 42, 108, '1975-01-01', 'Notes from the devisor:



Alex Doig was the drummer for many years with Jim Macleod''s Band. Tommy Ford, the lead accordionist, wrote the original tune.', 56, '800  888  888  844', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14383, '2011-12-17 23:00:00+00', '2021-08-15 08:57:14.492348+00', 'Corners'' Hello', 'CORNERS HELLO', 3, 32, NULL, 1, 3, 42, 3369, '2011-09-21', 'If you feel adventurous, try this dance in Jig or Reel Time.', 59, '880/855/855/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14756, '2013-04-02 10:45:08.525999+00', '2013-04-02 10:45:08.526004+00', 'Cinq or Swim', 'CINQ OR SWIM', 2, 32, NULL, 3, 5, NULL, 3757, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14200, '2011-08-26 22:00:00+00', '2019-01-27 20:46:15.171385+00', 'Guests at Mairi''s Wedding, The', 'GUESTS AT MAIRIS WEDDING', 1, 40, NULL, 3, 5, 16, 1036, NULL, '', 70, '80800  84884  84884  84884  84844', 0, 0, 0, 0, 70);
INSERT INTO 'dance' VALUES (14727, '2013-03-14 10:12:27.190878+00', '2019-02-04 10:55:41.78593+00', 'Saltburn Lass, The', 'SALTBURN LASS', 2, 32, NULL, 1, 3, 42, 10761, NULL, 'Devised by Mick Rawlings, january 2009, to celebrate the 50th birthday of his wife, Trisha, who was born in Saltburn, Yorkshire.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14766, '2013-04-02 19:18:51.163913+00', '2019-02-11 18:32:23.298969+00', 'Ena''s Strathspey', 'ENAS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 10769, NULL, '', 83, '888/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12520, '2005-08-29 22:00:00+00', '2019-03-02 01:22:06.241961+00', 'Berstane', 'BERSTANE', 2, 32, 9999, 1, 3, 42, 3165, '1995-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14761, '2013-04-02 10:56:30.571925+00', '2013-04-02 10:56:30.571933+00', 'Dancing Clouds', 'DANCING CLOUDS', 3, 40, NULL, 4, 4, NULL, 3520, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14806, '2013-04-08 10:34:23.649633+00', '2013-08-19 11:44:32.857242+00', 'Strathspey for Liz, A', 'STRATHSPEY FOR LIZ', 3, 32, NULL, 1, 4, NULL, 10771, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14764, '2013-04-02 19:16:39.977572+00', '2013-04-02 19:16:39.977578+00', 'Dookie Farmyard Frolic', 'DOOKIE FARMYARD FROLIC', 1, 48, NULL, 6, 111, NULL, 3520, NULL, 'Dance for three men and six women', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14771, '2013-04-03 20:42:15.050961+00', '2013-04-03 20:42:15.050967+00', 'Federation Square', 'FEDERATION SQUARE', 4, 64, 2, 4, 4, NULL, 10771, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14772, '2013-04-03 20:46:20.858118+00', '2013-04-03 20:46:20.858126+00', 'Five For Flinders', 'FIVE FOR FLINDERS', 3, 32, NULL, 4, 55, NULL, 10772, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14770, '2013-04-03 20:40:33.279002+00', '2013-04-03 20:51:34.269706+00', 'Gardiner Hall', 'GARDINER HALL', 3, 32, NULL, 1, 4, NULL, 10461, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14773, '2013-04-04 16:03:53.334253+00', '2013-04-04 16:03:53.334259+00', 'Alan', 'ALAN', 3, 32, NULL, 1, 4, NULL, 10459, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14775, '2013-04-04 16:07:54.857674+00', '2013-04-04 16:07:54.85768+00', 'Gwen Beaton''s Strathspey', 'GWEN BEATONS STRATHSPEY', 3, 32, NULL, 1, 4, NULL, 10459, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14778, '2013-04-04 16:13:25.153895+00', '2013-04-04 16:13:25.1539+00', 'Inverness Rant', 'INVERNESS RANT', 3, 32, NULL, 1, 4, NULL, 10462, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14779, '2013-04-04 16:14:05.326282+00', '2013-04-04 16:14:05.326288+00', 'Kathrence Birthday Reel', 'KATHRENCE BIRTHDAY REEL', 1, 40, NULL, 1, 4, NULL, 10773, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14780, '2013-04-04 16:15:57.197411+00', '2013-04-04 16:15:57.197417+00', 'Keep Left', 'KEEP LEFT', 1, 32, NULL, 5, 113, NULL, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14783, '2013-04-05 13:33:03.823145+00', '2013-04-05 13:33:03.823151+00', 'Les Morrow of Castlemaine', 'LES MORROW OF CASTLEMAINE', 3, 80, NULL, 4, 4, NULL, 10459, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14774, '2013-04-04 16:06:51.452894+00', '2018-04-03 00:07:51.992547+00', 'Herringbone Strathspey', 'HERRINGBONE STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10773, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14776, '2013-04-04 16:11:24.616308+00', '2018-04-03 00:07:52.342915+00', 'Hip,Hip, Hooray!', 'HIPHIP HOORAY', 1, 32, NULL, 1, 3, 42, 10767, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14781, '2013-04-04 16:16:29.211219+00', '2018-04-03 00:07:57.154858+00', 'Kenneth''s Strathspey', 'KENNETHS STRATHSPEY', 7, 32, NULL, 1, 3, 42, 414, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14786, '2013-04-05 13:38:35.980129+00', '2018-04-03 00:08:07.978441+00', 'No Rest for the Wicked', 'NO REST FOR THE WICKED', 1, 32, NULL, 1, 3, 42, 3757, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14729, '2013-03-14 15:33:58.105676+00', '2018-04-03 00:08:10.865336+00', 'Pippin''s Jig', 'PIPPINS JIG', 2, 40, NULL, 1, 3, 42, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14726, '2013-03-14 10:07:25.573122+00', '2017-06-08 12:13:52.19409+00', 'Milestone Jig, The', 'MILESTONE JIG', 2, 32, NULL, 1, 3, 42, 10760, NULL, 'Devised by Trisha & Mick Rawlings, 2008, & written in honour of Dennis Tucker''s 80th "milestone" birthday, 31 st May 2008.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14762, '2013-04-02 19:13:29.227867+00', '2013-08-19 11:45:58.289639+00', 'Dog Walkers''s Strathspey, The', 'DOG WALKERSS STRATHSPEY', 3, 32, NULL, 2, 3, NULL, 10768, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14784, '2013-04-05 13:34:15.72439+00', '2013-07-13 14:38:19.167518+00', 'Maelstrom', 'MAELSTROM', 1, 32, NULL, 4, 4, NULL, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14768, '2013-04-02 19:21:38.370116+00', '2018-04-03 00:07:45.344978+00', 'Farrier and his Wife, The', 'FARRIER AND HIS WIFE', 2, 40, NULL, 1, 3, 42, 10770, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14777, '2013-04-04 16:12:13.251628+00', '2018-04-03 00:07:53.235086+00', 'Iconic Jig, The', 'ICONIC JIG', 2, 40, NULL, 1, 3, 42, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7888, '1997-12-28 23:00:00+00', '2018-09-15 09:48:14.228732+00', 'Peter McGregor''s Reel', 'PETER MACGREGORS REEL', 1, 32, 9999, 1, 3, 42, 737, NULL, 'Uke most R.S.C.D.S. classes, there are more ladies than men in the class. My class is no exception;

however, like the first seWer to London, the men in my class have stayed and this dance was written for

them.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14800, '2013-04-08 10:28:08.936701+00', '2018-04-03 00:08:09.080493+00', 'On the Road to Dookie', 'ON THE ROAD TO DOOKIE', 1, 40, NULL, 1, 3, 42, 10771, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14816, '2013-04-29 13:55:11.890753+00', '2019-01-30 23:28:37.524459+00', 'On the Toe', 'ON THE TOE', 2, 32, NULL, 1, 4, 1, 3581, NULL, '', 81, '8888/8440/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14782, '2013-04-05 13:26:16.036739+00', '2013-08-19 11:45:58.680177+00', 'Laird of Sanday Bay, The', 'LAIRD OF SANDAY BAY', 3, 32, NULL, 2, 3, NULL, 10774, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14799, '2013-04-07 21:06:01.308276+00', '2013-04-07 22:44:01.23835+00', 'Olive MacNeil of Hayes', 'OLIVE MACNEIL OF HAYES', 2, 32, NULL, 1, 4, 2, 135, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14803, '2013-04-08 10:31:41.745492+00', '2013-04-08 10:31:41.745499+00', 'Salute to Western Australia', 'SALUTE TO WESTERN AUSTRALIA', 1, 40, NULL, 1, 4, NULL, 10775, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14804, '2013-04-08 10:32:30.64679+00', '2013-04-08 10:32:30.646796+00', 'Shinty', 'SHINTY', 1, 32, NULL, 8, 6, NULL, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14807, '2013-04-08 10:35:03.667339+00', '2013-04-08 10:35:03.667345+00', 'Windy Wellington', 'WINDY WELLINGTON', 1, 40, NULL, 2, 3, NULL, 10766, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7552, '1999-12-21 23:00:00+00', '2013-04-08 18:57:03.762419+00', 'Military Two Step', 'MILITARY TWO STEP', 11, 16, 9999, 5, 1, NULL, 1998, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14915, '2013-05-28 22:05:35.707402+00', '2013-05-28 22:05:35.707408+00', 'Knit Me a Tam', 'KNIT ME A TAM', 3, 32, NULL, 4, 54, 13, 3734, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6061, '1998-09-30 22:00:00+00', '2020-04-17 15:43:38.088677+00', 'Shoulder to Shoulder', 'SHOULDER TO SHOULDER', 2, 40, 9999, 1, 2, 76, 319, NULL, '', 55, '80/80/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2245, '2000-06-12 22:00:00+00', '2021-06-07 10:18:05.732474+00', 'Flower of the Quern, The', 'FLOWER OF THE QUERN', 3, 32, 9999, 1, 3, 42, 44, '1974-01-01', 'For Glenys and Ken Mills.', 48, '886/880/800/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1367, '1998-04-08 22:00:00+00', '2021-06-19 20:04:36.58263+00', 'Countess of Lauderdale''s Reel, The', 'COUNTESS OF LAUDERDALES REEL', 1, 40, 9999, 1, 3, 42, 9998, NULL, 'This was erroneously published as a jig (see the Errata section in the October 2008 issue of *Scottish Country Dancer*).', 52, '660/660/822/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7331, '1997-08-27 22:00:00+00', '2020-12-01 04:43:15.703+00', '15th of May', '15TH OF MAY', 2, 32, 9999, 1, 3, 42, 17, '1985-01-01', '', 56, '800/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14788, '2013-04-07 19:47:15.336605+00', '2021-01-03 13:29:10.159441+00', 'Welcome to Argyll', 'WELCOME TO ARGYLL', 1, 32, NULL, 5, 2, NULL, 3183, '1995-01-01', 'Devised by Anne Thorn in 1995 for use as an audience participation dance at the Cobbler Hotel in Arrochar.', 100, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (742, '1999-08-06 22:00:00+00', '2021-05-01 20:13:06.166243+00', 'Braes of Balquhidder, The', 'BRAES OF BALQUHIDDER', 3, 128, 9999, 4, 4, 3, 9998, NULL, 'See <<ddd:Balquidder Strathspey>> for information about Balquhidder.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5620, '1997-10-26 23:00:00+00', '2013-04-10 09:02:07.597395+00', 'Road to Ben Hope (Demonstration dance), The', 'ROAD TO BEN HOPE DEMONSTRATION DANCE', 3, 48, 9999, 2, 3, 17, 227, '1992-10-01', 'This is a Demonstration Dance.  Level: Very Advanced.  When performed on stage, the top should be nearest the audience.  Two times through will be enough.



Devised "For my husband, Cor"



Suggested tune: a strathspey in Muriel Johnstone''s style



', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10586, '2002-05-26 22:00:00+00', '2013-04-10 09:02:24.011703+00', 'Salute to Jennifer, A', 'SALUTE TO JENNIFER', 2, 48, 9999, 4, 4, 1, 3140, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14538, '2012-08-15 22:54:34.582187+00', '2013-04-10 09:02:50.834403+00', 'Stranfasket Hill', 'STRANFASKET HILL', 2, 48, NULL, 1, 100, 2, 2682, '2011-11-22', 'Devised 22/11/2011. This was inspired by working through Hugh Foss''s fugues

this year, particularly the fugues in the Glendorrach leaflets. Foss''s idea of

taking a theme (here clearly back to back) and working the whole dance around

it was really interesting to our group. Thanks to the group, especially John

Homes and Tom Cole, for suggestions which made the last 4 bars reasonable.

This particular dance was inspired by Stroangassel. Stroangassel is a hill in

Scotland with a fairy ring. Stranfasket Hill is very close to Strongassel. Hence

the title. I would recommend a steady 4 by 48 jig with strong 2 bar phrases.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13987, '2011-08-24 22:00:00+00', '2013-04-10 09:03:05.531144+00', 'Susie', 'SUSIE', 2, 32, NULL, 1, 4, 1, 1331, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14805, '2013-04-08 10:33:15.000248+00', '2013-08-19 11:44:32.836361+00', 'Strathspey for Bess, A', 'STRATHSPEY FOR BESS', 3, 32, NULL, 2, 3, NULL, 10769, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14794, '2013-04-07 20:07:31.463195+00', '2022-09-05 08:35:38.565156+00', 'Gateway to the Highlands', 'GATEWAY TO THE HIGHLANDS', 4, 128, 2, 4, 4, 3, 3183, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14792, '2013-04-07 19:56:24.297883+00', '2022-09-13 16:03:30.402164+00', 'I''ll Aye Follow Ye', 'ILL AYE FOLLOW YE', 2, 32, NULL, 1, 4, 1, 3183, '2009-05-01', 'Devised by Anne Thorn in May 2009 for her parents', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8143, '1999-12-21 23:00:00+00', '2013-10-11 14:04:47.9163+00', 'Britannia Two Step', 'BRITANNIA TWO STEP', 11, 16, 9999, 5, 53, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14634, '2012-12-31 16:00:36.740013+00', '2013-04-12 11:18:22.562784+00', 'Perth 800', 'PERTH 800', 1, 32, 9999, 1, 4, 2, 463, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14808, '2013-04-13 21:45:18.675808+00', '2013-04-13 21:45:18.675812+00', 'Malcolm''s Choices', 'MALCOLMS CHOICES', 1, 32, 9999, 2, 3, 17, 10778, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14801, '2013-04-08 10:28:48.174836+00', '2018-04-03 00:08:09.397345+00', 'Our Delight', 'OUR DELIGHT', 3, 32, NULL, 1, 3, 42, 10461, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14821, '2013-05-17 22:16:21.052119+00', '2013-05-17 22:16:21.052126+00', '80 Years Young', '80 YEARS YOUNG', 1, 80, 9999, 1, 4, 1, 17, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9551, '2000-07-26 22:00:00+00', '2018-04-03 00:08:09.997905+00', 'Pat''s Strathspey', 'PATS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 214, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14812, '2013-04-17 12:51:19.897777+00', '2013-04-17 13:12:53.479022+00', 'Macdonald''s Double Diamond', 'MACDONALDS DOUBLE DIAMOND', 3, 40, NULL, 2, 3, 18, 186, NULL, 'Taken from Minicrib; Charles Upton says source unknown.  Author is given as M. Howard; could be another Howard than Mary.  Eric Ferguson, 2013-04-17.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14802, '2013-04-08 10:29:45.257641+00', '2018-04-03 00:08:12.349983+00', 'Reel for Rena, A', 'REEL FOR RENA', 2, 32, NULL, 1, 3, 42, 10466, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14809, '2013-04-13 21:52:18.706753+00', '2016-07-15 17:29:52.972691+00', 'Scotch Mixer', 'SCOTCH MIXER', 1, 32, 9999, 5, 2, 4, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14810, '2013-04-13 21:59:03.413277+00', '2017-02-13 14:55:21.539143+00', 'Snowball Reel', 'SNOWBALL REEL', 1, 40, 9999, 1, 4, 1, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14789, '2013-04-07 19:48:43.895219+00', '2017-03-29 11:07:11.133097+00', 'Topsy Turvy', 'TOPSY TURVY', 1, 32, NULL, 2, 3, 30, 3183, '2011-02-01', '', 94, '888/888/888/288', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14823, '2013-05-17 22:51:18.85255+00', '2013-05-18 10:54:41.284453+00', 'Bobbing John', 'BOBBING JOHN', 2, 32, 9999, 1, 4, 1, 17, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14819, '2013-04-29 14:03:57.77627+00', '2019-02-26 17:28:41.710392+00', 'Seniors be Full Power!', 'SENIORS BE FULL POWER', 2, 32, NULL, 2, 3, 17, 10782, NULL, '', 100, '888/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14825, '2013-05-18 11:03:04.024876+00', '2013-05-18 11:03:04.024882+00', 'Brave Lads and Bonnie Lassies', 'BRAVE LADS AND BONNIE LASSIES', 3, 32, 9999, 1, 114, NULL, 17, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14827, '2013-05-18 11:10:16.532459+00', '2013-05-18 11:10:16.532466+00', 'Brief Encounter', 'BRIEF ENCOUNTER', 3, 32, NULL, 1, 4, NULL, 17, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14829, '2013-05-18 11:33:59.438618+00', '2013-05-18 11:33:59.438625+00', 'Alpine Assembly', 'ALPINE ASSEMBLY', 1, 48, NULL, 4, 4, NULL, 17, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14836, '2013-05-18 12:30:08.919253+00', '2013-05-18 12:30:08.91926+00', 'December Delights', 'DECEMBER DELIGHTS', 1, 40, 9999, 3, 5, 7, 17, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14837, '2013-05-18 12:36:21.921803+00', '2013-05-18 12:36:21.921809+00', 'Dreams of Dundee', 'DREAMS OF DUNDEE', 3, 32, NULL, 1, 4, NULL, 17, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14838, '2013-05-18 12:42:11.338454+00', '2013-05-18 12:42:11.338461+00', 'February Fling', 'FEBRUARY FLING', 2, 32, NULL, 3, 5, NULL, 17, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14839, '2013-05-18 12:46:41.605077+00', '2013-05-18 12:46:41.605083+00', 'Fiona''s Fiddle', 'FIONAS FIDDLE', 3, 32, NULL, 1, 4, 15, 17, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14840, '2013-05-18 12:52:04.187076+00', '2013-05-18 12:52:04.187081+00', 'Flowery Mountain', 'FLOWERY MOUNTAIN', 1, 48, 9999, 1, 4, NULL, 17, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14841, '2013-05-18 12:55:50.802029+00', '2013-05-18 12:55:50.802037+00', 'French Frolics', 'FRENCH FROLICS', 2, 32, 9999, 3, 5, NULL, 17, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14831, '2013-05-18 11:40:51.99416+00', '2018-04-03 00:07:30.335788+00', 'Ambi-Dextrous Dancers', 'AMBIDEXTROUS DANCERS', 1, 32, 9999, 1, 3, 42, 17, '2006-01-01', 'Each 2nd time through the dance is ''inverted'', meaning RH, LH, clockwise etc. change to LH, RH, anti-clockwise etc.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14833, '2013-05-18 11:45:35.173187+00', '2018-04-03 00:07:31.380509+00', 'At the Eleventh Hour', 'AT THE ELEVENTH HOUR', 1, 40, NULL, 1, 3, 42, 17, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14852, '2013-05-19 10:24:09.251244+00', '2013-05-19 10:24:09.251249+00', 'Lacing the Ghillies', 'LACING THE GHILLIES', 3, 32, 9999, 3, 5, NULL, 17, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14853, '2013-05-19 10:24:52.059532+00', '2013-05-19 10:24:52.059537+00', 'Leap into the Unknown', 'LEAP INTO THE UNKNOWN', 2, 32, 9999, 3, 5, NULL, 17, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14822, '2013-05-17 22:22:05.858586+00', '2018-04-03 00:07:33.232094+00', 'Between the Snowy Peaks', 'BETWEEN THE SNOWY PEAKS', 1, 32, 9999, 1, 3, 42, 17, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14521, '2012-07-22 13:31:06.067989+00', '2013-05-19 10:38:56.364636+00', 'Linking the World', 'LINKING THE WORLD', 1, 32, NULL, 3, 5, 38, 17, NULL, '"Leap into the Unknown" above is an easier version of this dance, which was originally devised to celebrate the tenth anniversary of the Strathspey mailing list. (Note from "140 Scottish Country Dances" by Martin Sheffield)', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14824, '2013-05-18 10:57:46.124802+00', '2018-04-03 00:07:35.417922+00', 'Braes of the Rhone', 'BRAES OF THE RHONE', 3, 32, 9999, 1, 3, 42, 17, '1980-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14856, '2013-05-19 11:01:59.842825+00', '2013-05-19 11:01:59.842831+00', 'March Madness', 'MARCH MADNESS', 1, 48, 9999, 4, 4, NULL, 17, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14798, '2013-04-07 20:17:54.001861+00', '2020-10-01 18:44:52.77562+00', 'Diamond Girls, The', 'DIAMOND GIRLS', 3, 64, NULL, 4, 4, 3, 3183, '2007-03-01', 'Dance devised by Anne Thorn in March 2007 for Christine Kirkpatrick and Joan Murray to celebrate their 60th birthdays.

', 69, '4444/6666/8080/8888/0808/8888/6666/4444', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14828, '2013-05-18 11:21:51.252478+00', '2020-10-02 09:19:47.894828+00', 'Across the Firth', 'ACROSS THE FIRTH', 1, 32, 9999, 1, 3, 42, 17, '2006-01-01', '', 47, '880/844/822/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5141, '1997-11-18 23:00:00+00', '2021-01-08 00:44:47.728796+00', 'Oxton Reel', 'OXTON REEL', 3, 144, 9999, 8, 6, 3, 9998, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1179, '1997-08-31 22:00:00+00', '2021-06-21 17:33:55.506337+00', 'Chesterton', 'CHESTERTON', 3, 32, 9999, 1, 2, 76, 200, NULL, 'The instructions say this is for "3 couples (8x32)" but only 2 couple are involved. It is assumed "2 couples" was the intention.', 60, '88/88/88/80', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14857, '2013-05-19 11:14:01.882725+00', '2013-05-19 11:14:01.882731+00', 'Marrakech Reel', 'MARRAKECH REEL', 2, 256, NULL, 4, 4, 3, 17, '1970-01-01', 'The description states S8x32 as music, but lists chorus plus four figures. Thus, the description might be incomplete.



The description marks this dace as square, ''Irish style''.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14859, '2013-05-19 11:26:56.846255+00', '2013-05-19 11:26:56.846261+00', 'October Oddity', 'OCTOBER ODDITY', 1, 32, 9999, 5, 2, 30, 17, '2002-01-01', 'The description says the dance may be danced round the room, couple facing couple, or in a longway set, 1st and 3rd couples beginning on oppsite sides.



It is not stated whether it should be danced to Reel or Jig time music.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14861, '2013-05-19 11:32:44.222669+00', '2013-05-19 11:32:44.222676+00', 'Over Drumochter', 'OVER DRUMOCHTER', 3, 32, 9999, 1, 4, NULL, 17, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14863, '2013-05-19 11:37:25.750631+00', '2013-05-19 11:37:25.750638+00', 'Pent-Up Energy', 'PENTUP ENERGY', 3, 40, 9999, 3, 5, NULL, 17, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14864, '2013-05-19 11:40:53.774268+00', '2013-05-19 11:40:53.774274+00', 'Pepper Tree', 'PEPPER TREE', 3, 32, 9999, 3, 5, NULL, 17, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9144, '1999-10-24 22:00:00+00', '2015-04-07 09:37:36.211824+00', 'Homage to Bach', 'HOMAGE TO BACH', 1, 40, 9999, 3, 5, 58, 17, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14843, '2013-05-18 17:11:00.982533+00', '2017-04-14 13:55:30.173682+00', 'Hadrian''s Wall', 'HADRIANS WALL', 1, 48, 9999, 1, 4, NULL, 17, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14834, '2013-05-18 11:54:41.074173+00', '2018-04-03 00:07:38.088117+00', 'Chase Your Partner', 'CHASE YOUR PARTNER', 1, 32, NULL, 1, 3, 42, 17, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14826, '2013-05-18 11:06:26.856376+00', '2018-04-03 00:07:35.518123+00', 'Break in the Clouds, A', 'BREAK IN THE CLOUDS', 3, 32, 9999, 1, 3, 42, 17, '1997-01-01', 'The title in the older 140 dances collection was missing the "A" at the beginning.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14835, '2013-05-18 11:57:49.033432+00', '2017-09-16 00:21:21.551536+00', 'Clavermaclish', 'CLAVERMACLISH', 2, 160, 9999, 4, 4, 3, 17, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14842, '2013-05-18 12:58:54.242467+00', '2018-04-03 00:07:47.163534+00', 'From the Pines to the Palms', 'FROM THE PINES TO THE PALMS', 1, 32, 9999, 1, 3, 42, 17, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14847, '2013-05-18 22:22:00.712078+00', '2018-04-03 00:07:52.284446+00', 'Hike in the Hills, A', 'HIKE IN THE HILLS', 2, 32, 9999, 1, 3, 42, 17, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14797, '2013-04-07 20:14:01.262785+00', '2022-09-09 20:31:25.892214+00', 'Dancing Through the Generations', 'DANCING THROUGH THE GENERATIONS', 1, 32, NULL, 5, 56, 76, 3183, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14848, '2013-05-18 22:57:28.581592+00', '2018-04-03 00:07:56.695985+00', 'June Holidays', 'JUNE HOLIDAYS', 50, 40, 9999, 1, 3, 42, 17, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14849, '2013-05-18 23:38:56.519073+00', '2018-04-03 00:07:56.779251+00', 'Jupiter', 'JUPITER', 1, 32, 9999, 1, 3, 42, 17, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14850, '2013-05-18 23:42:04.342273+00', '2018-04-03 00:07:57.062994+00', 'Keep Moving', 'KEEP MOVING', 3, 32, 9999, 1, 3, 42, 17, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14858, '2013-05-19 11:19:39.366248+00', '2018-04-03 00:08:08.238382+00', 'November Novelty', 'NOVEMBER NOVELTY', 2, 32, 9999, 1, 3, 42, 17, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14862, '2013-05-19 11:35:07.575597+00', '2018-04-03 00:08:09.505954+00', 'Overseas Delight', 'OVERSEAS DELIGHT', 1, 32, 9999, 1, 3, 42, 17, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14868, '2013-05-19 12:15:58.955277+00', '2018-04-03 00:08:11.257367+00', 'Prince Charlie''s Cairn', 'PRINCE CHARLIES CAIRN', 1, 40, NULL, 1, 3, 42, 17, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14927, '2013-05-30 22:10:05.961762+00', '2018-04-03 00:18:02.09549+00', 'Déjà Vu', 'DEJA VU', 3, 32, NULL, 2, 2, 76, 1394, '1999-03-29', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14865, '2013-05-19 11:42:58.030167+00', '2018-04-03 00:08:10.348172+00', 'Per Ardua Ad Astra', 'PER ARDUA AD ASTRA', 2, 32, 9999, 1, 3, 42, 17, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14867, '2013-05-19 12:10:41.16278+00', '2013-05-19 12:10:41.162787+00', 'Pretty Petronella', 'PRETTY PETRONELLA', 3, 32, 9999, 2, 3, 18, 17, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14869, '2013-05-19 13:03:37.202568+00', '2013-05-19 13:05:03.438163+00', 'Queen Victoria''s Quadrille', 'QUEEN VICTORIAS QUADRILLE', 10, 184, 9999, 4, 4, 3, 17, '1986-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14870, '2013-05-19 16:18:42.805625+00', '2013-05-19 16:18:42.805631+00', 'Quick Dip in the Cam', 'QUICK DIP IN THE CAM', 1, 48, 9999, 4, 4, 30, 17, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14871, '2013-05-19 20:41:59.029635+00', '2013-05-19 20:41:59.029641+00', 'Restful Square', 'RESTFUL SQUARE', 1, 48, 9999, 4, 4, 30, 17, '1985-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14872, '2013-05-19 20:48:25.62274+00', '2013-05-19 20:48:25.622746+00', 'Return to France', 'RETURN TO FRANCE', 3, 32, 9999, 1, 4, NULL, 17, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14873, '2013-05-19 20:55:18.892033+00', '2013-05-19 20:55:18.892039+00', 'Rings of Saturn', 'RINGS OF SATURN', 3, 32, 9999, 3, 5, NULL, 17, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14920, '2013-05-30 15:04:29.499259+00', '2018-04-26 22:10:32.404571+00', 'Gordian Knot', 'GORDIAN KNOT', 3, 32, NULL, 102, 55, 33, 1394, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14876, '2013-05-19 21:44:15.206776+00', '2013-05-19 21:44:15.206783+00', 'Saphire Square', 'SAPHIRE SQUARE', 3, 32, 9999, 3, 5, NULL, 17, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18571, '2018-09-10 14:19:23.053747+00', '2018-09-28 23:27:53.932058+00', 'Spaegeles'' Jig', 'SPAEGELES JIG', 2, 40, NULL, 1, 3, 42, 10451, NULL, '', 63, '844/888/844/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14874, '2013-05-19 20:58:51.541476+00', '2018-04-03 00:08:13.492259+00', 'Romp in the Heather', 'ROMP IN THE HEATHER', 1, 32, 9999, 1, 3, 42, 17, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14880, '2013-05-19 22:00:41.073735+00', '2013-05-19 22:00:41.073742+00', 'Songs on the Muirs', 'SONGS ON THE MUIRS', 2, 32, 9999, 1, 4, NULL, 17, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14875, '2013-05-19 21:41:47.343068+00', '2018-04-03 00:08:14.409708+00', 'Sailor''s Lassie', 'SAILORS LASSIE', 1, 48, 9999, 1, 3, 42, 17, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14881, '2013-05-19 22:11:55.826653+00', '2013-05-19 22:29:35.402839+00', 'St. Andrew and St. George', 'SAINT ANDREW AND ST GEORGE', 1, 48, 9999, 1, 4, NULL, 17, '1996-01-01', 'Description states Reel and Jig as type of the dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14884, '2013-05-19 22:44:25.119699+00', '2013-05-19 22:44:25.119706+00', 'Strolling in Savoy', 'STROLLING IN SAVOY', 3, 32, 9999, 2, 3, NULL, 17, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14917, '2013-05-28 22:22:09.718485+00', '2018-10-09 13:26:51.279178+00', 'Tumbleweeds', 'TUMBLEWEEDS', 2, 32, NULL, 4, 54, 13, 1394, '2004-06-18', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14912, '2013-05-28 21:29:53.071789+00', '2019-01-27 19:50:04.580985+00', 'Hot Chili', 'HOT CHILI', 2, 32, NULL, 105, 53, 17, 1394, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14887, '2013-05-19 23:03:00.252464+00', '2013-05-19 23:03:00.252471+00', 'Towers of Strength', 'TOWERS OF STRENGTH', 4, 64, 5, 1, 4, NULL, 17, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18994, '2018-10-17 12:44:57.391338+00', '2019-01-29 00:18:38.398976+00', 'It''s a Reel Pearl!', 'ITS A REEL PEARL', 1, 32, NULL, 1, 3, 42, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14877, '2013-05-19 21:50:14.771445+00', '2018-04-03 00:08:15.685506+00', 'September Strathspey', 'SEPTEMBER STRATHSPEY', 3, 32, 9999, 1, 3, 42, 17, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14878, '2013-05-19 21:52:25.740777+00', '2018-04-03 00:08:17.294842+00', 'Slalom', 'SLALOM', 1, 32, 9999, 1, 3, 42, 17, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14893, '2013-05-24 13:56:13.510638+00', '2013-05-24 13:56:13.510644+00', 'Walter McAdam of Kelvinside', 'WALTER MACADAM OF KELVINSIDE', 3, 40, NULL, 2, 3, NULL, 10785, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14882, '2013-05-19 22:17:45.278468+00', '2018-04-03 00:08:18.312265+00', 'St Andrew''s Feast', 'SAINT ANDREWS FEAST', 2, 32, 9999, 1, 3, 42, 17, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14891, '2013-05-22 16:31:16.535074+00', '2013-05-27 20:24:39.213524+00', 'Silver Lambourne Square, The', 'SILVER LAMBOURNE SQUARE', 1, 88, NULL, 4, 4, 3, 1049, '2007-08-14', 'Dance devised for Margaret and John Lambourne on the occasion of their 25th wedding anniversary, 

August 14, 2007, by Anne-Miek Klokgieters, The Hague. 

', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14910, '2013-05-28 20:08:44.288912+00', '2013-05-28 20:08:44.288918+00', 'Caberthrei', 'CABERTHREI', 1, 32, NULL, 6, 53, 17, 1394, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14896, '2013-05-24 14:03:09.335582+00', '2013-08-19 11:45:57.990941+00', 'Bees of Heather MacKay, The', 'BEES OF HEATHER MACKAY', 2, 32, NULL, 1, 4, NULL, 1331, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14911, '2013-05-28 20:20:06.750017+00', '2013-05-28 20:20:06.750023+00', 'Desert Sands', 'DESERT SANDS', 3, 32, NULL, 6, 53, 18, 1394, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14913, '2013-05-28 21:37:58.618156+00', '2013-05-28 21:37:58.618162+00', 'Dance of Diamond, The', 'DANCE OF DIAMOND', 1, 32, NULL, 4, 54, 13, 1394, NULL, 'For four dancers in a diamond-shaped set



Devised in honor of "The Dance of Diamonds" by Graham and Fay Cattell', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14914, '2013-05-28 21:59:50.323355+00', '2013-05-28 21:59:50.32336+00', 'Dust Devils', 'DUST DEVILS', 2, 32, NULL, 4, 54, 1, 1394, '2006-02-18', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14814, '2013-04-29 13:49:23.578962+00', '2020-10-02 09:15:36.122626+00', 'Happy Smile', 'HAPPY SMILE', 1, 32, NULL, 1, 3, 42, 10781, NULL, '', 67, '880/877/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14916, '2013-05-28 22:16:12.029335+00', '2013-05-28 22:16:12.029341+00', 'Southwest Sunset', 'SOUTHWEST SUNSET', 3, 32, NULL, 4, 54, 13, 1394, NULL, 'The "Mixed Poussette" in this dance is the normal Strathspey poussette, danced by any 4 dancers, not only two M+W couples.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14918, '2013-05-30 14:49:50.065221+00', '2013-05-30 14:49:50.065227+00', 'Cactus Flower', 'CACTUS FLOWER', 2, 32, NULL, 4, 55, 37, 1394, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14919, '2013-05-30 14:59:43.132541+00', '2013-05-30 14:59:43.132547+00', 'Fivesome, A', 'FIVESOME', 1, 48, NULL, 4, 55, 55, 3734, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14922, '2013-05-30 15:55:30.683175+00', '2013-05-30 15:55:30.68318+00', 'Painted Desert', 'PAINTED DESERT', 3, 32, NULL, 2, 3, 17, 1394, '2009-02-06', 'Revised on the given date.  Danced as 3x32 or 6x32.



An alternative for [25-28] changes the progression to (213), for use in a 4C set. ', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14923, '2013-05-30 16:03:58.995295+00', '2013-05-30 16:03:58.995301+00', 'Roman Eight', 'ROMAN EIGHT', 1, 32, NULL, 2, 3, 17, 3733, NULL, 'An alternative ending gives a progression 213, suitable for a 4C set.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14924, '2013-05-30 16:13:54.210942+00', '2013-05-30 16:13:54.210948+00', 'Sage and Salsa', 'SAGE AND SALSA', 4, 32, 1, 2, 3, 17, 1394, NULL, 'An alternative ending [25-32] gives the progression 213, suitable for a 4C set.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14866, '2013-05-19 11:45:29.290821+00', '2016-07-10 12:36:00.428571+00', 'Philabeag A-Flying', 'PHILABEAG AFLYING', 1, 32, 9999, 3, 5, 7, 17, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6267, '1997-04-03 22:00:00+00', '2017-06-19 16:27:35.51329+00', 'Squirrel, The', 'SQUIRREL', 2, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14879, '2013-05-19 21:57:00.842469+00', '2016-09-12 19:45:56.410333+00', 'Snowball', 'SNOWBALL', 2, 40, 9999, 3, 5, 16, 17, '2007-01-01', 'Description states both Jig and Reel as type of the dance.', 57, '84000/80860/80888/88888/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15000, '2013-07-30 18:27:04.337935+00', '2017-08-22 22:13:56.901018+00', 'Ye Olde Pussy Cat', 'YE OLDE PUSSY CAT', 3, 32, NULL, 1, 3, 42, 10568, NULL, '', 50, '800/844/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14883, '2013-05-19 22:27:57.043147+00', '2017-09-15 23:28:51.395785+00', 'St Andrews Square', 'SAINT ANDREWS SQUARE', 2, 64, 9999, 4, 4, 30, 17, '2003-01-01', 'Description states Jig and Reel as type of the dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14885, '2013-05-19 22:54:11.077073+00', '2018-04-03 00:08:21.389523+00', 'Toast to the Next Four Decades', 'TOAST TO THE NEXT FOUR DECADES', 1, 40, 9999, 1, 3, 42, 17, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14886, '2013-05-19 22:57:52.48838+00', '2018-04-03 00:08:21.589597+00', 'Torrents in Torre', 'TORRENTS IN TORRE', 1, 40, 9999, 1, 3, 42, 17, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14888, '2013-05-19 23:07:46.010766+00', '2018-04-03 00:08:22.19863+00', 'Trip through Tyrol', 'TRIP THROUGH TYROL', 1, 32, 9999, 1, 3, 42, 17, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14971, '2013-07-03 19:16:03.750689+00', '2018-11-26 19:03:25.90839+00', 'Welcome to Glasgow', 'WELCOME TO GLASGOW', 3, 32, NULL, 1, 3, 42, 515, '2012-10-01', '', 53, '840/844/888/808', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14900, '2013-05-27 16:37:43.380485+00', '2017-12-29 21:00:05.960725+00', 'Carol McQuilling Strathspey', 'CAROL MACQUILLING STRATHSPEY', 3, 32, NULL, 1, 4, 1, 10787, NULL, 'Carol McQuilling was active in the Santa Cruz class and the San Francisco Branch in the early 1980s.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14889, '2013-05-19 23:19:24.228391+00', '2018-04-03 00:08:22.681857+00', 'Trotternich', 'TROTTERNICH', 3, 32, 9999, 1, 3, 42, 17, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14905, '2013-05-27 16:48:04.09267+00', '2018-04-03 00:08:24.26625+00', 'Way of Life', 'WAY OF LIFE', 2, 40, NULL, 1, 3, 42, 1283, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14928, '2013-05-30 22:25:30.47846+00', '2013-05-30 22:25:30.478466+00', 'Rockhound Reel, The', 'ROCKHOUND REEL', 1, 32, NULL, 2, 3, 18, 1394, '2004-07-12', 'In the original description the couples are numbered (3,2,1) starting from the top.  1C is the dancing couple.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14929, '2013-05-30 22:30:19.174164+00', '2013-05-30 22:30:19.17417+00', 'Roundabout', 'ROUNDABOUT', 3, 32, NULL, 1, 3, 42, 1394, '2004-05-21', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14926, '2013-05-30 17:06:40.211171+00', '2018-02-20 21:30:19.785161+00', 'Autumn Leaves', 'AUTUMN LEAVES', 2, 32, NULL, 1, 3, 42, 1394, '2003-11-21', 'Can be danced in a 3C set using a different ending with progression 231 

This first video is a performance/demo and the ending is modified.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14931, '2013-05-30 22:49:33.311516+00', '2013-05-30 22:49:33.311523+00', 'Winter Wonder', 'WINTER WONDER', 1, 32, NULL, 1, 3, 42, 1394, '2002-12-27', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13093, '2006-11-14 23:00:00+00', '2013-05-31 15:53:56.293221+00', 'Bridge over Troubled Waters', 'BRIDGE OVER TROUBLED WATERS', 2, 32, 9999, 6, 53, 18, 3733, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14936, '2013-06-01 11:03:29.012396+00', '2018-04-03 00:18:02.305164+00', 'Mulled Cider', 'MULLED CIDER', 2, 32, NULL, 2, 2, 76, 1394, '2007-09-27', 'Can be danced as a Reel.  



Can be danced with 3 couples in a 3C or 4C set - instructions provided.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14902, '2013-05-27 16:42:16.355487+00', '2014-08-23 09:54:52.468714+00', 'Sterling Shores', 'STERLING SHORES', 3, 32, NULL, 1, 4, NULL, 10788, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14898, '2013-05-27 16:33:49.73699+00', '2018-04-05 12:18:46.391153+00', 'Lost and Found', 'LOST AND FOUND', 1, 32, NULL, 1, 3, 42, 10786, NULL, 'Dedicated to lost & found lovers everywhere', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14903, '2013-05-27 16:46:01.669666+00', '2018-07-17 00:28:17.429777+00', 'Trip to Timber Ridge', 'TRIP TO TIMBER RIDGE', 1, 32, NULL, 1, 3, 42, 10789, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14080, '2011-08-25 22:00:00+00', '2018-09-20 23:27:32.309205+00', 'Nessie''s jig', 'NESSIES JIG', 2, 32, NULL, 1, 4, 1, 2804, NULL, 'A dance devised by Ray Settrey for ‘Nessie’ Prideaux.', 66, '8008/0880/8888/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14932, '2013-06-01 10:40:39.163916+00', '2013-06-01 10:40:39.163922+00', 'After You', 'AFTER YOU', 1, 32, NULL, 2, 3, 17, 1394, '2007-09-07', 'Alternatives instructions included for this dance in 2C and 4C sets.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14933, '2013-06-01 10:45:49.912429+00', '2013-06-01 10:46:13.863616+00', 'Crossing the Clyde', 'CROSSING THE CLYDE', 3, 32, NULL, 1, 3, 42, 1394, '2006-02-10', 'Alternative ending supplied to create the progression 231 needed for a 3c set', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14934, '2013-06-01 10:52:09.393356+00', '2013-06-01 10:52:09.393362+00', 'Glass House, The', 'GLASS HOUSE', 1, 32, NULL, 1, 3, 42, 1394, '2007-07-01', 'Alternative [17-24] supplied for a 3C set (progression 231)



For George and Pat Glass.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14937, '2013-06-01 13:42:43.553918+00', '2013-06-01 13:42:43.553924+00', 'Strawberry Swirl', 'STRAWBERRY SWIRL', 3, 32, NULL, 1, 3, 42, 1394, '2007-10-03', 'Can be danced in a 3C set, with an alternative [31-32] giving the progression 231', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14938, '2013-06-01 13:48:09.224663+00', '2013-06-01 13:48:09.224669+00', 'Too hot to tango', 'TOO HOT TO TANGO', 2, 32, NULL, 2, 3, 17, 3732, '2009-06-29', '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14939, '2013-06-01 13:52:52.340064+00', '2013-06-01 13:52:52.34007+00', 'Watch This', 'WATCH THIS', 2, 32, NULL, 3, 5, 16, 1394, '2009-01-23', 'Can also be danced as a Reel or as a Strathspey', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8782, '1998-10-20 22:00:00+00', '2013-06-04 12:10:34.796004+00', 'Lord McDonald''s Quadrille', 'LORD MACDONALDS QUADRILLE', 1, 128, 9999, 4, 4, 3, 50, '1997-01-01', 'This demo dance has four 32-bar figures; the first has no name, the second is called "Advance and Retire", the third is called "Schiehallion", the fourth "Ladies'' Figure".



The dance was adapted from "Corsair Field" when not enough dancers were available.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19000, '2018-10-17 12:56:59.656286+00', '2018-10-17 12:56:59.656286+00', 'Marion', 'MARION', 2, 32, NULL, 1, 4, 2, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19001, '2018-10-17 12:59:09.665838+00', '2018-10-17 12:59:09.665838+00', 'Of Mice and Men', 'OF MICE AND MEN', 2, 32, NULL, 4, 4, NULL, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14940, '2013-06-04 12:19:27.264482+00', '2013-06-04 19:37:57.205079+00', 'Lea''s Rigged Petronella', 'LEAS RIGGED PETRONELLA', 4, 112, 18, 2, 3, 3, 10699, '2013-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14947, '2013-06-23 18:26:01.510642+00', '2020-10-02 10:27:59.357594+00', 'Peggy''s 100th Birthday', 'PEGGYS 100TH BIRTHDAY', 1, 40, NULL, 1, 4, 1, 10798, NULL, '', 68, '8048/8624/8888/4444/8462', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18996, '2018-10-17 12:47:13.637492+00', '2019-12-31 10:52:10.590392+00', 'Just Jean', 'JUST JEAN', 3, 32, NULL, 2, 3, 17, 10435, NULL, '', 75, '888/080/088/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14942, '2013-06-20 13:44:04.868007+00', '2020-12-31 11:42:48.889196+00', 'Take Wing', 'TAKE WING', 2, 32, NULL, 1, 4, 2, 10796, '2012-06-01', 'For Jan Jones and the Thistle Club who organise an annual musicians workshop in Wing, Buckinghamshire.



1W and 4M both need to be prepared for both the 1/2 fig 8 and the RH turn by dancing generous curls at the end of the reel and the 1/2 figs 8.', 75, '8008/8888/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13102, '2006-11-14 23:00:00+00', '2019-02-04 10:54:40.792882+00', 'Ranald''s Run', 'RANALDS RUN', 1, 32, 9999, 4, 55, 26, 3734, NULL, 'Named for Ranald MacDonald, the younger Clanranald, who defied his father and joined the Jacobite rising in 1745.  He escaped from Culloden and was hunted by government soldiers throughout the Highlands.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14957, '2013-06-25 21:20:52.546409+00', '2013-06-25 21:20:52.546415+00', 'One for the Cabarfeidh', 'ONE FOR THE CABARFEIDH', 1, 32, NULL, 1, 4, NULL, 2419, '2011-01-03', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13090, '2006-11-14 23:00:00+00', '2016-05-11 13:55:40.508189+00', 'Peas in a Pod', 'PEAS IN A POD', 2, 32, 9999, 107, 1, NULL, 1394, '2005-09-30', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13099, '2006-11-14 23:00:00+00', '2016-05-11 13:57:29.234996+00', 'Santa Fe Summer', 'SANTA FE SUMMER', 2, 32, 9999, 107, 54, 13, 1394, '2004-06-11', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14897, '2013-05-27 16:31:26.574263+00', '2017-12-26 22:02:24.79965+00', 'Lady of Spain', 'LADY OF SPAIN', 3, 32, NULL, 1, 3, 42, 3549, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14908, '2013-05-27 16:54:03.320057+00', '2017-12-28 21:39:10.421995+00', 'Golden Ribbons', 'GOLDEN RIBBONS', 3, 32, NULL, 1, 3, 42, 10792, NULL, 'For Janis and Ned Dairiki in honor of their 50th wedding anniversary.



Suggested music: "The Banks of Banna" and "Margaret''s Ghost"', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14907, '2013-05-27 16:52:14.822365+00', '2017-12-28 22:32:06.639879+00', 'Lake of the Sky', 'LAKE OF THE SKY', 1, 32, NULL, 1, 3, 42, 10791, NULL, 'Dedicated to the beauty of Lake Tahoe



Suggested music: "The Silver Fern Reel" ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14951, '2013-06-23 18:42:34.983446+00', '2019-02-22 12:58:29.115309+00', 'Rod and Julia', 'ROD AND JULIA', 1, 40, NULL, 1, 4, 4, 3358, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14953, '2013-06-23 18:54:29.718539+00', '2019-02-22 13:01:21.89765+00', 'Priorsford Bridge', 'PRIORSFORD BRIDGE', 3, 32, NULL, 1, 4, 1, 3358, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14943, '2013-06-20 18:04:20.40703+00', '2019-02-27 22:34:20.035971+00', 'Magic Circle', 'MAGIC CIRCLE', 3, 48, NULL, 1, 4, 1, 10798, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14945, '2013-06-20 19:44:39.390062+00', '2019-04-25 09:00:42.88239+00', 'St Ronan''s Strathspey', 'SAINT RONANS STRATHSPEY', 3, 32, NULL, 1, 4, 5, 10798, NULL, '', 80, '8244/8888/0488/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10499, '2002-04-23 22:00:00+00', '2019-06-07 12:10:17.091928+00', 'Palindrome', 'PALINDROME', 1, 24, 9999, 2, 3, 17, 558, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14944, '2013-06-20 19:39:45.605797+00', '2019-06-18 10:13:24.695925+00', 'Bruadar', 'BRUADAR', 3, 32, NULL, 4, 4, 1, 3471, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14959, '2013-06-25 21:25:00.359413+00', '2018-07-25 08:29:56.933084+00', 'Fraser Cailean Donaldson''s Reel', 'FRASER CAILEAN DONALDSONS REEL', 1, 40, NULL, 1, 4, NULL, 2419, '2012-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14960, '2013-06-25 21:27:20.005405+00', '2013-08-19 11:46:00.206333+00', 'Spirit of Mortlach, The', 'SPIRIT OF MORTLACH', 2, 48, NULL, 1, 4, NULL, 2419, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14958, '2013-06-25 21:22:59.359567+00', '2013-08-19 11:46:00.494409+00', 'Turtle and the Cranes, The', 'TURTLE AND THE CRANES', 4, 128, 13, 1, 4, NULL, 2419, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7395, '1997-04-04 22:00:00+00', '2018-04-03 00:07:46.145888+00', 'Flirt, The', 'FLIRT', 3, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8336, '2002-03-11 23:00:00+00', '2014-09-17 15:49:56.030652+00', 'Kumite', 'KUMITE', 1, 32, 9999, 1, 2, NULL, 2867, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14575, '2012-09-13 16:07:50.496127+00', '2013-07-13 14:38:18.941653+00', 'Alexander''s Castle', 'ALEXANDERS CASTLE', 2, 32, NULL, 1, 3, 42, 10593, '2009-07-07', 'Alexander’s Castle is the oldest building within the Fort Worden compound.  John B. Alexander served as rector at St. Paul’s Episcopal Church in Port Townsend (WA, USA) from 1882-1886. In 1883 he acquired 10 acres of land near Point Wilson and constructed the building known as Alexander’s Castle. Alexander intended the building to serve as a home for himself and his bride. Traveling to Scotland, Alexander found that his bride-to-be had married another. He returned to Port Townsend alone…', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14574, '2012-09-13 16:06:55.829108+00', '2013-07-13 14:38:19.036707+00', 'Emerald Hills of Home', 'EMERALD HILLS OF HOME', 3, 32, NULL, 2, 3, 17, 10593, '2005-01-01', 'Inscribed to Fred and Marge van Nus on the occasion of their 55th wedding anniversary.  The dance tells their story, and their active participation in Scottish Country Dance. In the first eight bars they meet, marry, and begin dancing. They include other dancers who in turn include more dancers, and they travel round the world Scottish Country Dancing. Still dancing, they eventually end up here in Southwest Washington among the fir-covered, emerald hills that we call home.



', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15116, '2013-09-13 13:04:08.700836+00', '2018-10-31 12:17:14.842084+00', 'Mauve Mist, Purple Haze', 'MAUVE MIST PURPLE HAZE', 1, 32, 9999, 1, 4, 1, 3254, '2012-04-01', 'Devised by Terry Lynne Harris, April 2012.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13104, '2006-11-15 23:00:00+00', '2018-04-03 00:08:16.794558+00', 'Silver Nutmeg, The', 'SILVER NUTMEG', 2, 40, 9999, 1, 3, 42, 1167, '2003-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13791, '2011-07-24 22:00:00+00', '2018-12-26 12:15:38.745226+00', 'Meet the Corners', 'MEET THE CORNERS', 1, 32, NULL, 1, 3, 42, 2682, '2006-03-01', 'Devised as a teaching dance for corners. The reason that the man goes to the corners first (rather than the more traditional lady) is that in our club the person dancing as the lady is more often than not the newer dancer.', 38, '800/444/444/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15053, '2013-08-06 13:16:41.461003+00', '2013-08-06 13:16:41.461003+00', 'Inveresk House', 'INVERESK HOUSE', 2, 32, 9999, 1, 100, 2, 154, NULL, 'Devised: 2011



On the 2nd chord 3rd and 4th couples cross to the opposite sides.



This dance can be danced as a ceilidh style dance where the 3rd and 4th couples start on opposite sides.





Tune Inveresk House (played as a jig) by Nathaniel Gow', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15096, '2013-08-24 13:41:26.47402+00', '2013-08-24 13:55:49.965586+00', 'Royal Scottish Country Dance Society Toronto Association Fiftieth Celebration', 'ROYAL SCOTTISH COUNTRY DANCE SOCIETY TORONTO ASSOCIATION FIFTIETH CELEBRATION', 4, 96, 10028, 1, 4, NULL, 10847, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15168, '2013-09-28 19:27:55.02526+00', '2013-09-28 19:27:55.02526+00', 'Hitching Rail, The', 'HITCHING RAIL', 2, 32, NULL, 2, 3, 17, 3101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14815, '2013-04-29 13:52:49.260821+00', '2019-01-30 23:34:37.281057+00', 'Matsuri Strathspey, The', 'MATSURI STRATHSPEY', 3, 32, NULL, 1, 4, 1, 2781, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14946, '2013-06-23 18:24:04.620653+00', '2020-10-02 09:50:51.789261+00', 'Peggy''s Eightieth Birthday', 'PEGGYS EIGHTIETH BIRTHDAY', 3, 80, NULL, 4, 4, 3, 3358, NULL, '', 78, '8888/8888/8080/8888/0808/8282/2828/4444/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14948, '2013-06-23 18:29:28.85881+00', '2020-10-03 09:27:40.96713+00', 'Farewell to Peebles', 'FAREWELL TO PEEBLES', 2, 48, NULL, 1, 4, 1, 10798, NULL, '', 54, '8000/4444/8800/0088/8888/4444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14965, '2013-07-03 18:47:26.789532+00', '2020-10-03 18:15:45.198182+00', 'Moulin Brae', 'MOULIN BRAE', 3, 32, NULL, 2, 3, 17, 10802, '2010-01-01', '', 96, '888/488/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14968, '2013-07-03 19:09:48.896889+00', '2020-10-03 18:20:44.823825+00', 'Speirs Wharf Hornpipe', 'SPEIRS WHARF HORNPIPE', 1, 32, NULL, 1, 3, 42, 2718, NULL, '', 55, '800/886/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14950, '2013-06-23 18:40:55.425232+00', '2020-10-05 09:51:40.084888+00', 'Set, Cross and Cast', 'SET CROSS AND CAST', 1, 48, NULL, 1, 4, 1, 10798, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14979, '2013-07-17 08:17:54.583615+00', '2020-11-28 10:52:48.882107+00', 'Clockwork Comic, The', 'CLOCKWORK COMIC', 2, 32, 9999, 1, 3, 42, 3342, '2012-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14963, '2013-07-03 18:41:28.749097+00', '2019-02-05 16:59:03.056638+00', 'Fingask Castle', 'FINGASK CASTLE', 2, 32, NULL, 3, 5, 7, 10801, NULL, '', 78, '88880/82842/84844/88888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14961, '2013-07-03 18:33:55.032761+00', '2019-02-09 18:30:30.622935+00', 'Autumn Beginnings', 'AUTUMN BEGINNINGS', 3, 32, NULL, 1, 4, 2, 1415, NULL, '', 78, '8008/8448/6886/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14966, '2013-07-03 18:50:41.084164+00', '2019-03-07 19:54:50.420007+00', 'Scotch Broth', 'SCOTCH BROTH', 1, 32, NULL, 1, 3, 42, 10803, NULL, '', 56, '800/888/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14385, '2011-12-19 23:00:00+00', '2017-11-14 06:25:17.037158+00', 'Graduation Reel, The', 'GRADUATION REEL', 1, 40, NULL, 1, 3, 42, 2932, NULL, 'Suitable music: Waverley Station, First Stop, 8x40 reels



In celebration of the first graduating seniors of RSCDS@UMD, University of Maryland, especially Chris Tabisz and Gabi Kocerha, who got this awesome group started with their imagination, dedication, and unbeatable Terp spirit. Fear the Kilt!', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15013, '2013-07-31 19:53:32.812351+00', '2018-04-02 23:56:32.622815+00', 'Alan''s Flypers', 'ALANS FLYPERS', 2, 32, NULL, 1, 3, 42, 10568, '2012-07-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15012, '2013-07-31 19:51:50.5252+00', '2018-04-02 23:56:33.782337+00', 'Dancing with Swans', 'DANCING WITH SWANS', 3, 32, NULL, 1, 3, 42, 10568, '2012-05-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15017, '2013-07-31 20:08:26.367028+00', '2018-04-02 23:56:33.978605+00', 'Dog''s Tale, A', 'DOGS TALE', 2, 32, NULL, 1, 3, 42, 10568, '2012-01-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15016, '2013-07-31 19:59:48.931204+00', '2018-04-02 23:56:34.984482+00', 'Good Mind, A', 'GOOD MIND', 1, 32, NULL, 1, 3, 42, 10568, '2012-08-15', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15007, '2013-07-31 19:42:58.47171+00', '2018-04-02 23:56:38.123824+00', 'Trip to Algeria', 'TRIP TO ALGERIA', 1, 40, NULL, 1, 3, 42, 10568, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15009, '2013-07-31 19:47:02.176785+00', '2018-04-02 23:56:38.132089+00', 'Trip to Egypt, A', 'TRIP TO EGYPT', 2, 32, NULL, 1, 3, 42, 10568, '2012-03-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15006, '2013-07-31 19:41:23.275582+00', '2018-04-02 23:56:38.532624+00', 'What Don Wants', 'WHAT DON WANTS', 1, 32, NULL, 1, 3, 42, 10568, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14998, '2013-07-30 18:24:05.276371+00', '2014-04-03 00:44:46.259088+00', 'Polly''s Big Day', 'POLLYS BIG DAY', 1, 32, NULL, 2, 3, 17, 10568, '2011-05-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15019, '2013-07-31 20:22:07.139891+00', '2013-07-31 20:22:07.139891+00', 'Forty Below', 'FORTY BELOW', 1, 40, NULL, 1, 4, NULL, 10813, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15003, '2013-07-31 15:07:28.111851+00', '2013-08-19 15:59:44.599914+00', 'Mr David W Mitchell', 'MR DAVID W MITCHELL', 2, 32, NULL, 2, 3, 18, 10812, NULL, 'Information source: Minicrib', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15001, '2013-07-30 18:28:36.306691+00', '2014-04-03 01:16:45.571126+00', 'When the Wind Blows', 'WHEN THE WIND BLOWS', 50, 32, NULL, 7, 113, 4, 10568, '2011-08-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15062, '2013-08-10 15:32:18.808843+00', '2019-02-27 22:06:18.996916+00', 'Reel for Lyn, A', 'REEL FOR LYN', 1, 40, NULL, 1, 3, 42, 10830, '2009-12-01', 'Devised for the occasion of Lyn Picone''s 60th birthday.', 73, '844/888/822/822/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15110, '2013-09-13 10:17:45.065394+00', '2018-04-09 09:39:51.566616+00', 'Helen and Jean''s Welcome to Gauteng', 'HELEN AND JEANS WELCOME TO GAUTENG', 2, 32, 9999, 1, 3, 42, 10856, '2010-09-01', 'Devised by Norma Craven of the 51st Club, Johannesburg, September 2010, in honour of Helen Frame and Jean Martin''s visit to Gauteng', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14970, '2013-07-03 19:14:30.70431+00', '2022-08-19 09:26:07.573038+00', 'Tribute to Glasgow', 'TRIBUTE TO GLASGOW', 2, 32, NULL, 1, 4, 2, 640, NULL, '', 97, '8888/7777/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15120, '2013-09-13 13:09:03.050954+00', '2022-09-09 08:52:29.847831+00', 'Send Her Victorious', 'SEND HER VICTORIOUS', 3, 32, 9999, 2, 3, 17, 3179, '2012-07-01', 'Devised by Wouter Joubert, July 2012, in honour of Queen Elizabeth II''s Diamond Jubilee Celebration', 67, '800/844/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14967, '2013-07-03 18:54:53.550897+00', '2022-10-28 10:24:53.180112+00', 'Snowdrops in the Glen', 'SNOWDROPS IN THE GLEN', 1, 32, NULL, 1, 3, 42, 10804, NULL, '', 50, '800/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14996, '2013-07-30 17:07:38.272764+00', '2014-04-03 00:27:57.947124+00', 'Dance for Bobby Brown, A', 'DANCE FOR BOBBY BROWN', 1, 32, NULL, 1, 4, 1, 10568, NULL, 'Written to the music for "Bobby Brown''s Canadian Breakdown"

Music has 2 chords & the dance has 2 honors at the beginning.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15115, '2013-09-13 11:46:17.12394+00', '2018-04-10 09:16:20.460004+00', 'Master Duncan Nelson', 'MASTER DUNCAN NELSON', 2, 32, 9999, 1, 3, 42, 3179, '2011-06-23', 'Duncan Nelson, born 13 July 2009, is the son of Ryan Nelson, the current Pretoria Branch Chairman. The tune was composed in anticipation of Duncan''s birth, the dance took a while longer.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14999, '2013-07-30 18:25:49.649723+00', '2014-04-03 01:00:33.440677+00', 'Bewitched in Salem', 'BEWITCHED IN SALEM', 3, 32, NULL, 2, 3, 17, 10568, '2011-06-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15002, '2013-07-30 18:29:25.196105+00', '2014-04-03 13:33:46.100523+00', 'Puppy Love', 'PUPPY LOVE', 2, 32, NULL, 1, 4, 1, 10568, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15118, '2013-09-13 13:07:00.872366+00', '2018-04-10 11:56:04.325071+00', 'Of Butterflies and Rainbows', 'OF BUTTERFLIES AND RAINBOWS', 2, 32, 9999, 2, 3, 17, 3179, '2012-01-29', 'Devised by Wouter Joubert, 9 August 2011 and revised on 29 January 2012. For Urisa Reungsuwan who, with her charming and colourful presence, enhances our dancing in Pretoria.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18524, '2018-08-25 08:24:05.641363+00', '2018-08-25 08:24:05.641363+00', 'Stonehaven''s Welcome', 'STONEHAVENS WELCOME', 1, 32, NULL, 5, 125, NULL, 11680, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18525, '2018-08-25 08:25:25.569892+00', '2018-08-25 08:25:25.569892+00', 'Dancer all her Days, A', 'DANCER ALL HER DAYS', 3, 40, NULL, 1, 4, NULL, 11681, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18526, '2018-08-25 08:26:45.754691+00', '2018-08-25 08:26:45.754691+00', 'Gourdon Girls'' Dance, The', 'GOURDON GIRLS DANCE', 1, 32, NULL, 2, 3, NULL, 11682, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14986, '2013-07-24 14:19:11.572611+00', '2018-10-09 23:40:02.843761+00', 'Who Am I?', 'WHO AM I', 1, 40, NULL, 1, 3, 42, 3309, '2013-05-05', 'Bob Davidson (piobbeag [at] aol.com) says, "Having recently done a dance which had the ladies dancing the men''s role in a Men''s Chain, I thought it only fair that the men would have their turn."', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10919, '2002-11-12 23:00:00+00', '2019-01-27 20:27:17.407737+00', 'Laurieston Jig', 'LAURIESTON JIG', 2, 32, 9999, 1, 102, 2, 2673, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1323, '1999-03-01 23:00:00+00', '2019-02-04 18:21:37.092593+00', 'Conundrum, The', 'CONUNDRUM', 3, 32, 9999, 1, 4, 2, 727, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15005, '2013-07-31 19:39:09.484653+00', '2019-03-23 14:09:02.423012+00', 'Portsmouth Intersection', 'PORTSMOUTH INTERSECTION', 1, 88, NULL, 4, 4, 3, 10568, '2011-11-01', '', 89, '8888/8888/8282/8888/8888/6666/6666/8888/2828/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15004, '2013-07-31 19:37:46.81625+00', '2016-04-18 23:11:33.33202+00', 'Dancing Dogs', 'DANCING DOGS', 3, 32, NULL, 1, 2, NULL, 10568, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15008, '2013-07-31 19:45:17.508032+00', '2019-06-11 21:23:07.181911+00', 'By Paddlewheel Steamer Down the Nile', 'BY PADDLEWHEEL STEAMER DOWN THE NILE', 3, 40, NULL, 2, 3, 17, 10568, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14997, '2013-07-30 18:22:39.167233+00', '2016-04-18 23:12:14.465256+00', 'Easy Does it', 'EASY DOES IT', 2, 32, NULL, 1, 2, NULL, 10568, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15011, '2013-07-31 19:50:02.22603+00', '2016-04-18 23:12:48.778879+00', 'Fore Tom', 'FORE TOM', 3, 32, NULL, 1, 2, NULL, 10568, '2012-05-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15010, '2013-07-31 19:48:36.618661+00', '2016-04-18 23:25:13.313081+00', 'S.S. Karim, The', 'SS KARIM', 3, 32, NULL, 1, 2, NULL, 10568, '2012-03-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15015, '2013-07-31 19:57:45.20535+00', '2016-04-18 23:27:24.572462+00', 'Well Oiled Machine, A', 'WELL OILED MACHINE', 4, 32, 1, 1, 2, NULL, 10568, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14954, '2013-06-23 18:56:49.749372+00', '2020-10-03 18:12:57.93102+00', 'Watchmaker, The', 'WATCHMAKER', 3, 40, NULL, 1, 4, 1, 10798, NULL, '', 100, '8888/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14969, '2013-07-03 19:12:16.864999+00', '2020-10-03 18:28:40.549087+00', 'Squinty Bridge, The', 'SQUINTY BRIDGE', 2, 32, NULL, 3, 5, 16, 10443, NULL, '', 50, '80000/84480/82284/82284', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15123, '2013-09-13 13:14:25.388378+00', '2020-11-28 11:26:47.36664+00', 'Walking on Clouds', 'WALKING ON CLOUDS', 4, 128, 13, 1, 100, 2, 64, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15052, '2013-08-06 13:00:47.965208+00', '2020-12-06 10:26:04.974481+00', 'Machine Without Wheels', 'MACHINE WITHOUT WHEELS', 2, 32, 9999, 1, 3, 42, 154, NULL, 'Devised: 2010 at the TAC Summer School to mark the hired car having its wheels stolen.', 56, '800/888/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15022, '2013-08-01 19:54:42.670991+00', '2016-12-23 01:18:06.698142+00', 'Bees They are A''Drummin'', The', 'BEES THEY ARE ADRUMMIN', 1, 32, NULL, 1, 3, 42, 10648, '2013-01-01', 'This  dance is for  Chris  Rea  to  mark  his 10  years’ service as Secretary, Treasurer  and  committee  member  of Peterborough & District RSCDS Branch. Chris is a keen beekeeper and one-time drummer with the Peterborough Pipe Band. 



Recommended recordings: Mr Watson’s Favourite (RSCDS Book of Graded SCDs  - David Cunningham & his Band) or The Mason’s Apron (Scottish Dance Vol.12 - Marian Anderson’s Scottish Dance Band)', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14989, '2013-07-24 14:47:14.455763+00', '2019-08-07 17:29:40.007184+00', 'Groundhog Day', 'GROUNDHOG DAY', 3, 32, NULL, 1, 2, 76, 10810, '2012-03-09', '', 69, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (874, '1997-04-03 22:00:00+00', '2013-08-01 11:19:44.988299+00', 'Burning Sands', 'BURNING SANDS', 3, 48, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15020, '2013-07-31 22:58:41.786512+00', '2013-08-03 20:54:45.381351+00', 'Tiaras and Teapots', 'TIARAS AND TEAPOTS', 2, 40, NULL, 1, 3, 42, 10648, '2013-05-12', 'The recommended recording for this dance is The Rakish Highlandman, which is a good steady pace. 



The inspiration for this dance came whilst dancing Roselath Cross (two half Crown Triangles) at an Afternoon Tea   Dance in the summer of 2012 amidst the Queen’s Diamond Jubilee celebrations, when the question was asked,   “What’s half a Crown?”.   Of course the other answer is 2 shillings and sixpence and so, if the 6 bar movement in bars 27-32 (and again in bars 33-38) is given the name ‘a Shilling’, the alternative name for this dance is “2 Half Crowns and a Florin”!', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15075, '2013-08-15 18:57:43.816353+00', '2018-04-02 23:56:34.992854+00', 'Good Times', 'GOOD TIMES', 3, 32, NULL, 1, 3, 42, 3775, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15028, '2013-08-02 15:54:54.077597+00', '2013-08-02 15:54:54.077597+00', 'Cathryn''s Reel', 'CATHRYNS REEL', 1, 88, NULL, 6, 3, NULL, 10815, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18527, '2018-08-25 08:28:31.705132+00', '2018-08-25 08:28:31.705132+00', 'Extending of Findon Court, The', 'EXTENDING OF FINDON COURT', 3, 32, NULL, 1, 4, NULL, 11683, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18580, '2018-09-11 09:05:10.31795+00', '2018-09-13 14:58:29.098332+00', 'Iain Campbell''s Jig', 'IAIN CAMPBELLS JIG', 2, 32, NULL, 4, 4, 4, 2863, '2017-08-01', 'This dance was written to fit the music arranged by George Stirrat for Iain Campbell.', 75, '8484/4848/4444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18995, '2018-10-17 12:45:58.878895+00', '2018-10-17 12:45:58.878895+00', 'Joan Lampton''s Return', 'JOAN LAMPTONS RETURN', 3, 32, NULL, 2, 3, NULL, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18998, '2018-10-17 12:50:30.928546+00', '2018-10-17 12:50:30.928546+00', 'Lass o'' Peggy''s Mill, The', 'LASS O PEGGYS MILL', 1, 32, NULL, 1, 100, 2, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18999, '2018-10-17 12:51:31.991514+00', '2018-10-17 12:51:31.991514+00', 'Let''s Cosy Down wi'' Nessie', 'LETS COSY DOWN WI NESSIE', 3, 32, NULL, 2, 3, 17, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15026, '2013-08-02 10:24:07.129479+00', '2013-08-19 11:45:58.567126+00', 'Kelvin Strathspey, The', 'KELVIN STRATHSPEY', 3, 32, NULL, 2, 3, NULL, 2983, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15029, '2013-08-02 15:57:21.976719+00', '2013-08-19 11:45:58.698098+00', 'Laird''s Diamond, The', 'LAIRDS DIAMOND', 3, 32, NULL, 1, 2, NULL, 2983, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15042, '2013-08-02 19:30:28.489261+00', '2019-02-22 13:13:26.755196+00', 'Candyfloss', 'CANDYFLOSS', 3, 32, NULL, 2, 3, 17, 234, NULL, '', 83, '808/484/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15072, '2013-08-10 15:46:41.597945+00', '2019-02-27 22:53:15.983886+00', 'Liverpool Lass', 'LIVERPOOL LASS', 2, 32, NULL, 1, 4, 2, 2980, NULL, '', 56, '2442/2442/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14502, '2012-07-03 18:33:16.656766+00', '2019-03-26 21:23:52.046307+00', 'Christmas Tree Jig, The', 'CHRISTMAS TREE JIG', 2, 48, NULL, 6, 3, 17, 2434, NULL, '', 100, '888/888/888/888/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15074, '2013-08-11 09:49:20.402758+00', '2017-04-30 12:22:33.827685+00', 'Loom, The', 'LOOM', 2, 32, NULL, 1, 3, 42, 3323, '2007-12-31', 'A dance of weaving between each other. The transitions between the formations should be danced at speed.', 62, '800  888  888  888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15095, '2013-08-24 13:27:02.932962+00', '2019-03-31 22:02:57.526779+00', 'Swansea Strathspey', 'SWANSEA STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10846, NULL, '', 44, '800/880/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11170, '2003-02-24 23:00:00+00', '2022-09-30 11:25:10.448038+00', 'Trip to Austin, A', 'TRIP TO AUSTIN', 3, 32, 9999, 1, 100, 11, 2677, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15094, '2013-08-24 13:22:53.246762+00', '2013-08-24 13:22:53.246762+00', 'Salute to Dr. Donald Fraser', 'SALUTE TO DR DONALD FRASER', 3, 32, NULL, 1, 4, 1, 10845, NULL, 'The title refers to Dr. Donald Fraser, the first chairman of the Toronto Branch (Association). 



More details in the publication, describing each figure.



Bars 21-32: Progressive half rights and lefts with each couple in turn, giving right hand on the side, then both couples cross over giving left hand, 1st couple finishing in fourth place, all ather couples having progressed one place on own side. Note the split phrasing for this figure.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15048, '2013-08-06 12:18:00.12183+00', '2019-03-16 11:35:25.757452+00', 'Black Squirrel, The', 'BLACK SQUIRREL', 3, 32, 9999, 1, 3, 42, 154, '2005-05-01', 'Devised: 2005-05 at the Colorado Springs weekend.', 47, '800/808/844/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (50, '1998-07-08 22:00:00+00', '2013-08-08 10:20:05.657441+00', 'Aiken Tree, The', 'AIKEN TREE', 2, 32, 9999, 1, 4, 2, 13, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (118, '1997-08-27 22:00:00+00', '2013-08-08 10:39:10.708658+00', 'Among The Farthest Hebrides', 'AMONG THE FARTHEST HEBRIDES', 3, 32, 9999, 1, 3, 42, 108, '1964-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15038, '2013-08-02 19:20:09.389083+00', '2016-02-08 15:03:49.572306+00', 'All the Eights', 'ALL THE EIGHTS', 2, 32, NULL, 1, 3, 42, 727, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15045, '2013-08-06 11:54:32.283135+00', '2018-04-03 00:08:04.401888+00', 'Mississauga Starter', 'MISSISSAUGA STARTER', 1, 32, 9999, 1, 3, 42, 154, '2006-03-19', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15031, '2013-08-02 16:07:15.952335+00', '2018-04-03 00:08:12.716792+00', 'Return of the Loons', 'RETURN OF THE LOONS', 2, 32, NULL, 1, 3, 42, 2983, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14505, '2012-07-04 12:53:24.454349+00', '2018-04-03 00:18:02.129002+00', 'Doe at Dawn, The', 'DOE AT DAWN', 2, 32, NULL, 2, 2, 76, 3101, NULL, 'May be danced in a 4 couple set', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (801, '1998-10-18 22:00:00+00', '2014-05-30 13:22:34.37762+00', 'Brig o'' Aboyne', 'BRIG O ABOYNE', 3, 32, 9999, 1, 4, 2, 108, '1978-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14503, '2012-07-04 07:44:46.250879+00', '2018-04-03 00:07:31.044983+00', 'Arches of MacGregor, The', 'ARCHES OF MACGREGOR', 2, 32, NULL, 1, 3, 42, 3101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15059, '2013-08-10 15:10:16.065994+00', '2019-11-28 10:44:06.210151+00', 'Road to Bluff Hill, The', 'ROAD TO BLUFF HILL', 1, 32, NULL, 1, 3, 42, 10831, NULL, '', 50, '800/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15070, '2013-08-10 15:44:44.805141+00', '2019-11-28 17:38:15.766302+00', 'Social Butterfly, The', 'SOCIAL BUTTERFLY', 3, 48, NULL, 1, 4, 1, 10833, NULL, '', 38, '8000/8080/8000/8800/8000/8224', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15065, '2013-08-10 15:37:05.255222+00', '2019-11-28 17:51:57.853132+00', 'Iron Pot, The', 'IRON POT', 6, 32, NULL, 1, 3, 42, 10831, NULL, '', 50, '880/888/633/633', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15061, '2013-08-10 15:31:23.081516+00', '2019-11-28 18:03:31.5387+00', 'Go with the Flow', 'GO WITH THE FLOW', 2, 32, NULL, 1, 3, 42, 2980, NULL, '', 56, '880/888/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15069, '2013-08-10 15:42:46.170386+00', '2019-11-28 18:06:58.422549+00', 'Drew''s Delight', 'DREWS DELIGHT', 2, 40, NULL, 1, 3, 42, 10830, NULL, '', 50, '800/888/844/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15049, '2013-08-06 12:40:20.320782+00', '2020-04-06 22:21:16.734144+00', 'Carlin''s Loup', 'CARLINS LOUP', 1, 32, 9999, 1, 100, 2, 154, NULL, 'Devised: 2008



On 2nd chord, couples 3 and 4 cross to opposite side', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (249, '1997-08-28 22:00:00+00', '2020-08-29 11:53:12.138604+00', 'Ashbourne Gingerbread', 'ASHBOURNE GINGERBREAD', 2, 32, 9999, 1, 3, 42, 234, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15033, '2013-08-02 19:07:41.726632+00', '2020-10-05 18:52:06.561023+00', 'Charles Ogden''s Jig', 'CHARLES OGDENS JIG', 2, 32, NULL, 1, 3, 42, 727, NULL, '', 44, '800/844/866/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15034, '2013-08-02 19:10:20.147086+00', '2020-10-05 18:57:30.538345+00', 'Golden Arc', 'GOLDEN ARC', 1, 32, NULL, 1, 3, 42, 3177, NULL, '', 47, '800/855/855/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15036, '2013-08-02 19:15:36.31405+00', '2020-10-05 19:02:18.050008+00', 'Leccamore Jig, The', 'LECCAMORE JIG', 2, 32, NULL, 1, 3, 42, 10819, NULL, '', 34, '800/840/840/804', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15043, '2013-08-02 19:31:37.806311+00', '2020-10-05 19:05:54.839666+00', 'Jovial Jack', 'JOVIAL JACK', 1, 32, NULL, 1, 3, 42, 727, NULL, '', 58, '888 800 846 888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15058, '2013-08-10 15:08:23.370601+00', '2020-10-05 19:08:18.904519+00', 'Diamond for Napier, A', 'DIAMOND FOR NAPIER', 2, 40, NULL, 1, 3, 42, 10830, NULL, '', 60, '888/800/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15068, '2013-08-10 15:41:27.135628+00', '2020-10-05 19:14:58.523273+00', 'Pines on Parade', 'PINES ON PARADE', 1, 32, NULL, 1, 3, 42, 10830, NULL, '', 56, '880/888/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15060, '2013-08-10 15:30:17.066561+00', '2021-01-03 12:58:20.960365+00', 'Tyrella Homestead', 'TYRELLA HOMESTEAD', 3, 32, NULL, 1, 3, 42, 2980, NULL, '', 50, '800/888/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15085, '2013-08-23 17:30:13.799856+00', '2018-04-03 00:07:46.154141+00', 'Flitting Across Toronto', 'FLITTING ACROSS TORONTO', 1, 32, NULL, 1, 3, 42, 10840, NULL, 'The reason for the dance title is that dancers move all over the city to attend dances. The dance movements represent individuals travelling around the city to meer for the dance.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15082, '2013-08-21 13:18:45.454358+00', '2018-04-03 00:07:49.357502+00', 'Go Like 50', 'GO LIKE 50', 1, 32, NULL, 1, 3, 42, 1582, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15079, '2013-08-20 22:31:19.100717+00', '2018-04-03 00:07:50.858639+00', 'Harcourt Cross Roads', 'HARCOURT CROSS ROADS', 1, 32, NULL, 1, 3, 42, 10837, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15143, '2013-09-20 17:15:55.564264+00', '2018-04-03 00:18:02.137341+00', 'Elgin Wedding Reel', 'ELGIN WEDDING REEL', 1, 32, 9999, 2, 2, 76, 10863, '2005-09-29', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15078, '2013-08-20 14:12:38.084171+00', '2018-04-03 00:07:55.561882+00', 'Jig for the 50th, A', 'JIG FOR THE 50TH', 2, 32, NULL, 1, 3, 42, 839, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15081, '2013-08-20 22:58:25.992261+00', '2018-04-03 00:07:57.796714+00', 'Knot Work for the 50th', 'KNOT WORK FOR THE 50TH', 3, 32, NULL, 1, 3, 42, 10839, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13713, '2011-07-08 22:00:00+00', '2013-08-19 11:45:58.380829+00', 'Fickleness, The', 'FICKLENESS', 2, 32, NULL, 4, 5, 35, 10349, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15112, '2013-09-13 10:21:08.785293+00', '2018-04-10 08:42:07.218136+00', 'Jay Birds, The', 'JAY BIRDS', 2, 32, 9999, 1, 4, 2, 64, '2008-02-29', 'Devised by Irene van Maarseveen on 29 February 2008 (leap year). "Blame" Jill for her observation during class the previous Thursday that the name of everyone in her set began with "J".', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18528, '2018-08-25 08:29:56.861888+00', '2019-02-23 18:58:24.351279+00', 'Skatie Shore', 'SKATIE SHORE', 3, 32, NULL, 1, 4, 1, 11684, NULL, 'Has sheet music', 86, '8888/8448/8688/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18529, '2018-08-25 08:31:57.444264+00', '2018-08-25 08:31:57.444264+00', 'Stonehaven Market Square', 'STONEHAVEN MARKET SQUARE', 3, 128, 2, 4, 4, NULL, 11685, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15080, '2013-08-20 22:53:06.359529+00', '2013-08-20 22:53:06.359529+00', 'Swiftly Flow The Years (50 years of dance)', 'SWIFTLY FLOW THE YEARS 50 YEARS OF DANCE', 3, 40, NULL, 3, 5, 19, 10838, NULL, 'Dedicated to my mother, Jean', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18530, '2018-08-25 08:34:08.521829+00', '2018-08-25 08:34:08.521829+00', 'Dunnottar Hi-Jinks', 'DUNNOTTAR HIJINKS', 2, 40, NULL, 4, 4, NULL, 11686, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15084, '2013-08-21 13:32:34.720976+00', '2013-08-21 13:32:34.720976+00', 'Anniversary Salute, The', 'ANNIVERSARY SALUTE', 3, 32, NULL, 1, 4, NULL, 3533, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18532, '2018-08-25 08:41:06.047691+00', '2018-08-25 08:41:06.047691+00', 'Stoney Fireballs, The', 'STONEY FIREBALLS', 1, 48, NULL, 1, 4, NULL, 11688, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15086, '2013-08-23 18:14:35.464404+00', '2013-08-23 18:14:35.464404+00', '50 Glorious Years', '50 GLORIOUS YEARS', 3, 32, NULL, 1, 4, 1, 10841, NULL, 'Dedicated to the RSCDS Toronto Association in celebration of its 50th Anniversary and to two of its affiliated groups - Calvin and Petronella - also celebrating their 50th Anniversaries.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15088, '2013-08-24 12:22:14.087588+00', '2013-08-24 12:22:14.087588+00', 'Five Decades', 'FIVE DECADES', 3, 32, NULL, 3, 5, 7, 10595, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15089, '2013-08-24 12:26:14.097091+00', '2013-08-24 12:26:14.097091+00', 'Kathleen of Aberdeen', 'KATHLEEN OF ABERDEEN', 2, 40, NULL, 1, 4, NULL, 10842, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15091, '2013-08-24 12:41:47.794151+00', '2013-08-24 12:41:47.794151+00', 'Tour of Toronto', 'TOUR OF TORONTO', 3, 32, NULL, 1, 4, 15, 10843, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14725, '2013-03-14 10:04:59.035054+00', '2019-02-12 23:37:16.126033+00', 'Little Treasure, The', 'LITTLE TREASURE', 3, 32, NULL, 2, 3, 17, 771, '2000-01-01', 'Dance devised by Dennis Tucker, December, 2000, to celebrate the birthday of his wife, Diana, who likes to dance with her partner.', 69, '822/888/860/808', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15144, '2013-09-20 17:26:52.83218+00', '2013-09-20 17:26:52.83218+00', 'Duke and Duchess of Marmalade, The', 'DUKE AND DUCHESS OF MARMALADE', 3, 32, 9999, 1, 4, 2, 10863, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15146, '2013-09-20 17:47:46.874584+00', '2018-04-03 00:08:14.076014+00', 'Rumbling Bridge Reel', 'RUMBLING BRIDGE REEL', 1, 32, 9999, 1, 3, 42, 10863, NULL, 'Tune: "Arthur''s Seat", from Many Happy Returns by Hanneke Cassel and Dave Wiesler', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15092, '2013-08-24 13:05:27.944173+00', '2018-04-03 00:08:18.128897+00', 'Spring Bay Strathspey', 'SPRING BAY STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10844, NULL, 'Spring Bay: A beautiful Bay on the island of Bequia, British Windward Islands. A place in paradise where time spent with dear friends will always be remembered.



Bars 27-28: 1st couple require strong travelling steps to reach third place.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14494, '2012-07-03 17:49:16.84283+00', '2018-04-03 00:08:21.848053+00', 'Tribute to Norman Bett, A', 'TRIBUTE TO NORMAN BETT', 4, 32, 1, 1, 3, 42, 2434, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14175, '2011-08-26 22:00:00+00', '2019-09-13 23:22:56.494831+00', 'The Sandwich Man TRANSFER LINKS TO Bob Wilson''s Jig 14173', 'SANDWICH MAN TRANSFER LINKS TO BOB WILSONS JIG 14173', 2, 32, NULL, 1, 4, NULL, 127, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15142, '2013-09-20 17:07:46.027471+00', '2018-04-03 00:18:02.279802+00', 'Meyer Lemon Strathspey', 'MEYER LEMON STRATHSPEY', 3, 32, 9999, 2, 2, 76, 10863, NULL, 'Devised: 2006-05', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15077, '2013-08-20 12:20:21.768946+00', '2013-09-09 06:50:50.198403+00', 'Mrs Hamilton of Eaglemount', 'MRS HAMILTON OF EAGLEMOUNT', 3, 40, NULL, 2, 3, 17, 10836, NULL, 'To Jean Hamilton - one of Toronto''s dedicated teachers. Reaching our 50th Anniversary is in no small part due to the calibre of teachers we are fortunate to have in Toronto. This dance is dedicated to one such person.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14517, '2012-07-06 08:25:14.679019+00', '2020-01-05 07:54:45.000217+00', 'Priestly Jig, The', 'PRIESTLY JIG', 2, 32, NULL, 1, 3, 42, 3101, NULL, '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15242, '2013-11-12 19:25:47.72091+00', '2020-02-29 23:51:39.898132+00', 'Culduthel Rant', 'CULDUTHEL RANT', 3, 32, NULL, 1, 3, 42, 3213, NULL, 'Dance devised by Helen Murray for her grandson Douglas Hector Murray MacDonald, born on 3rd July 2009. Douglas and his parents, Lorna and Kenneth, live on Culduthel Road, lnverness.', 56, '880/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18531, '2018-08-25 08:39:17.134941+00', '2020-04-13 08:45:01.728758+00', 'Stonehaven Strathspey', 'STONEHAVEN STRATHSPEY', 3, 32, NULL, 2, 3, 17, 11687, NULL, '', 79, '822/888/888/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15119, '2013-09-13 13:08:08.55497+00', '2021-06-10 21:55:33.879495+00', 'Reel to the Future', 'REEL TO THE FUTURE', 1, 32, 9999, 2, 3, 17, 3254, '2008-05-01', 'Devised by Terry Lynne Harris for Irene van Maarseveen, May 2008.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15030, '2013-08-02 16:00:17.428141+00', '2020-10-05 18:10:27.247305+00', 'Prairie Crocus, A', 'PRAIRIE CROCUS', 3, 32, NULL, 2, 3, 18, 2983, NULL, '', 83, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8354, '1997-12-28 23:00:00+00', '2021-03-20 12:48:12.418374+00', 'Fiona''s Strathspey', 'FIONAS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 872, NULL, '', 41, '880/800/800/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15076, '2013-08-20 08:24:58.395407+00', '2021-06-10 09:14:07.64569+00', 'Caught By The Wind', 'CAUGHT BY THE WIND', 1, 40, 9999, 1, 3, 42, 44, '2004-06-01', '', 55, '888/800/888/800/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15124, '2013-09-13 13:15:57.120111+00', '2021-07-03 16:28:32.527525+00', '7th Wonder', '7TH WONDER', 1, 32, 9999, 2, 3, 17, 10582, NULL, '', 67, '800/844/888/484', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14323, '2011-12-07 23:00:00+00', '2018-04-03 00:07:31.320642+00', 'As the Worm Turns', 'AS THE WORM TURNS', 2, 32, NULL, 1, 3, 42, 480, '1998-05-28', 'Dedicated to Sally Dee (Boston) and Jodie Hebert (Montréal) after a worm tossing incident.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15100, '2013-09-12 11:18:25.330031+00', '2018-04-08 10:19:02.163974+00', 'Dancing Delight', 'DANCING DELIGHT', 2, 32, 9999, 1, 3, 42, 3254, NULL, '', 42, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15137, '2013-09-20 16:32:46.690825+00', '2018-04-03 00:07:50.875271+00', 'Hare Reel, The', 'HARE REEL', 1, 32, 9999, 1, 3, 42, 3453, NULL, 'Devised: 2008', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15107, '2013-09-13 10:12:34.10636+00', '2018-04-08 10:29:54.851599+00', 'Going Home', 'GOING HOME', 2, 32, NULL, 1, 3, 42, 3254, NULL, '', 48, '440/440/886/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13268, '2007-02-27 23:00:00+00', '2013-09-17 08:58:08.773192+00', 'Callum Dewar''s Reel', 'CALLUM DEWARS REEL', 1, 40, 9999, 1, 4, 1, 2419, NULL, '»To celebrate the birth of Callum Dewar 6th November 2006 and with congratulations to Veda and Colin Dewar.«



DEVISED:2006', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15099, '2013-09-12 11:17:08.034137+00', '2018-04-08 08:53:39.031864+00', 'Cooks'' Strathspey', 'COOKS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 10853, NULL, '', 81, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13264, '2007-02-27 23:00:00+00', '2013-09-17 11:53:57.262982+00', 'Shetland Gathering, The', 'SHETLAND GATHERING', 6, 48, 9999, 3, 5, 16, 2419, NULL, '»First dance in the Shetland trilogy – ›Arriving‹. Bars 1-8 depict the waves made by the boat. Bars 9-16 the rope in the water for tying up. Bars 17-24 the rope round the capstan. Bars 25-32 the rope around the bollards. Bars 33-48 disembarking.«



HORNPIPE

DEVISED:2006-01', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9709, '2000-11-13 23:00:00+00', '2013-09-17 20:16:21.933527+00', 'McCagie''s Rest', 'MACCAGIES REST', 3, 32, 9999, 1, 4, NULL, 2819, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15102, '2013-09-12 15:25:40.211773+00', '2018-04-06 09:19:51.386623+00', 'Forty Years On', 'FORTY YEARS ON', 3, 32, NULL, 2, 3, 17, 3179, NULL, '', 66, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15108, '2013-09-13 10:13:24.041529+00', '2018-04-10 12:23:47.687522+00', 'Going in Circles', 'GOING IN CIRCLES', 3, 32, NULL, 1, 4, 1, 3254, '2004-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15133, '2013-09-20 15:26:57.566823+00', '2013-09-20 15:26:57.566823+00', 'Remember the Allemande', 'REMEMBER THE ALLEMANDE', 1, 32, 9999, 1, 100, 2, 3453, NULL, 'Devised: 2006', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15134, '2013-09-20 15:35:25.265236+00', '2013-09-20 15:35:25.265236+00', 'Flood of ''98', 'FLOOD OF 98', 3, 32, 9999, 1, 4, 1, 3453, '1998-11-17', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15135, '2013-09-20 16:19:26.340528+00', '2013-09-20 16:19:26.340528+00', 'Thistles and Bluebonnets', 'THISTLES AND BLUEBONNETS', 3, 40, 9999, 1, 4, 11, 10862, NULL, 'Devised: 2009-09', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15131, '2013-09-20 15:03:08.198127+00', '2018-04-03 00:08:09.839309+00', 'Parking Lot, The', 'PARKING LOT', 1, 32, 9999, 1, 3, 42, 10861, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15105, '2013-09-12 15:30:48.421183+00', '2018-04-10 09:07:08.086553+00', 'Floral Bouquet', 'FLORAL BOUQUET', 3, 32, 9999, 2, 3, 17, 3254, '2012-01-01', 'In memory of SCD teachers Donoveen Meijer and Margo Monteith.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15132, '2013-09-20 15:16:10.047291+00', '2018-04-03 00:08:11.982826+00', 'Rainy Day, A', 'RAINY DAY', 3, 32, 9999, 1, 3, 42, 10861, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11611, '2003-12-04 23:00:00+00', '2018-04-03 00:08:25.566952+00', 'White Rock', 'WHITE ROCK', 1, 32, 9999, 1, 3, 42, 2682, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15136, '2013-09-20 16:26:12.766671+00', '2016-09-11 23:25:41.583731+00', 'Elinor of Briar Lea', 'ELINOR OF BRIAR LEA', 2, 32, 9999, 1, 2, 76, 3453, '2004-01-01', '', 69, '88/88/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17248, '2016-09-04 10:44:40.631653+00', '2018-08-25 09:30:43.362815+00', 'Intruders, The', 'INTRUDERS', 2, 32, NULL, 1, 4, 30, 10598, NULL, 'Many dancers like to insert themselves into dances when they are standing out. Some teachers/dancers object to this “over–exuberance.” I wrote this dance for those of you who, like me, love to move to the music even when you should be standing out.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9676, '2000-09-19 22:00:00+00', '2018-08-09 15:13:24.33937+00', 'Farewell to the Dicksons', 'FAREWELL TO THE DICKSONS', 2, 32, 9999, 1, 3, 42, 371, '1981-04-01', 'Dedicated to Chris and John Bowie Dickson on the occasion of their return to Scotland and presented to them at the RSCDS Montréal Branch 1981 Weekend at Ste. Agathe, QC.', 66, '880/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11029, '2002-11-24 23:00:00+00', '2017-12-04 10:50:26.438685+00', 'Donoveen''s Dance', 'DONOVEENS DANCE', 4, 96, 11, 4, 4, 14, 3250, '2000-01-01', 'Recommended music: The Nor'' Loch (HRMCD 503)



Devised by Jean Fryer, Pretoria, South Africa; 2002



In memory of Donoveen Meijer (31 March 1948 - 23 August 2000), a dear friend and active Scottish Country Dancer.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9340, '2000-02-25 23:00:00+00', '2013-09-20 23:29:27.418912+00', 'Birks of Lafayette, The', 'BIRKS OF LAFAYETTE', 2, 32, 9999, 1, 3, 42, 348, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6, '1997-06-29 22:00:00+00', '2018-04-02 10:26:58.880599+00', 'A M Shinnie', 'M SHINNIE', 2, 32, 9999, 1, 3, 42, 129, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9056, '2002-03-04 23:00:00+00', '2022-10-04 14:35:39.663889+00', 'Cross and Cast Off', 'CROSS AND CAST OFF', 2, 32, 9999, 1, 4, 1, 815, '1993-03-01', 'Devised for the occasion of Bill Bishop’s seventieth birthday party in York.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15139, '2013-09-20 16:47:25.579785+00', '2022-10-25 16:14:19.04325+00', 'Oasis', 'OASIS', 1, 32, 9999, 2, 3, 17, 3453, '2006-01-01', 'For the three couples in the Oasis Foundation activities program SCD class', 58, '800/888/800/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16234, '2015-05-01 11:36:05.95+00', '2018-08-26 10:30:38.614206+00', 'Joan Evans Strathspey', 'JOAN EVANS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 84, '2008-01-01', 'Gill Loubser (Cape Town Branch) writes"  When our club (Bergvliet Scottish Country Dance Club) celebrated its 50th anniversary in 2008, we dedicated a strathspey to Joan in recognition of her sterling work in founding the club and keeping it going for 50 years. Tom Kerr (of Cape Town Wedding fame!) devised a dance called the Bergvliet Strathspey for our 50th anniversary ball held at Cape Town''s iconic Kelvin Grove Club, and, once we had danced it, I announced a name change (with Tom''s permission) to the Joan Evans'' Strathspey.', 56, '888/808/844/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15101, '2013-09-12 15:23:58.093587+00', '2020-10-06 14:56:03.281374+00', 'Dancing Gorse', 'DANCING GORSE', 4, 32, 1, 1, 3, 42, 10853, NULL, '', 56, '800/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15103, '2013-09-12 15:28:12.70766+00', '2020-10-06 15:16:47.822917+00', 'Dolphin Frolic', 'DOLPHIN FROLIC', 1, 32, 9999, 1, 3, 42, 3254, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15111, '2013-09-13 10:18:37.3865+00', '2020-10-06 15:18:42.927798+00', 'Highveld Wedding, A', 'HIGHVELD WEDDING', 2, 32, 9999, 1, 3, 42, 3179, NULL, '', 56, '800/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12726, '2006-04-26 22:00:00+00', '2021-01-10 20:58:38.483511+00', 'Isle of Man Strathspey', 'ISLE OF MAN STRATHSPEY', 3, 32, 9999, 6, 3, 17, 2886, '2006-01-01', '', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11695, '2004-02-18 23:00:00+00', '2021-01-29 06:37:31.765754+00', 'Silvery Tay, The', 'SILVERY TAY', 3, 32, 9999, 2, 3, 17, 3427, '2000-01-01', '', 75, '888/888/800/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8669, '2002-05-06 22:00:00+00', '2021-03-15 22:15:21.317157+00', 'Ellisland', 'ELLISLAND', 3, 32, 9999, 4, 4, 4, 200, '1996-01-01', '', 84, '4444/8888/7777/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11808, '2004-09-16 22:00:00+00', '2021-06-21 20:26:12.654326+00', 'September 1st', 'SEPTEMBER 1ST', 1, 32, 9999, 1, 3, 42, 2680, NULL, '<<scddb:not-identical:1533>>



Originally entered in SCDDB with unknown deviser and name "First of September" this dance was later identified as "September 1st" by Fiona Miller.



The notes say it was "devised in honour of the 40th wedding anniversary of my parents, Netta and Alan Brown, September 1, 1991."', 50, '844/633/633/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15158, '2013-09-28 01:10:09.762514+00', '2019-07-05 18:44:48.209726+00', 'Epsilon', 'EPSILON', 3, 32, NULL, 1, 3, 42, 3101, NULL, '', 50, '888/880/800/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15149, '2013-09-25 16:03:23.923253+00', '2019-10-05 19:05:28.254702+00', 'FSCDC 50th Anniversary Reel', 'FSCDC 50TH ANNIVERSARY REEL', 1, 32, NULL, 3, 5, NULL, 10864, NULL, 'description:

 1-2	All cross over with right hands.  

 3-4	Persons in 1st ladies’ and 5th men’s places set while all others change places on the sidelines with left hands.



	S   P XL P   P XL P   



	P XL P   P XL P   S



 5-8	Repeat bars 1 - 4  

 9-16	Ten hands round and back.  

17-20	Persons in 2nd and 4th places dance half figure of eight round the persons standing in 1st and 5th places start by crossing up or down, finish facing 3rd corner.  

21-24	They dance half reels of four with 3rd corners, finish facing 4th corners.  

25-28	They dance half reels of four with 4th corners, finish in the sidelines in 2nd or 4th places.  

29-32	All turn opposite person with right hands.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15161, '2013-09-28 01:28:34.635221+00', '2013-11-26 17:25:51.848288+00', 'Counterflow', 'COUNTERFLOW', 1, 40, NULL, 1, 4, 1, 3101, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15162, '2013-09-28 01:32:22.62499+00', '2013-11-26 17:41:53.439137+00', 'I Dream of Jeannie', 'I DREAM OF JEANNIE', 3, 32, NULL, 1, 4, 1, 3101, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15169, '2013-09-28 19:32:57.655111+00', '2013-09-28 19:32:57.655111+00', 'Country Turnstiles', 'COUNTRY TURNSTILES', 1, 32, NULL, 2, 3, 17, 3101, NULL, '', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15170, '2013-09-28 19:36:44.268877+00', '2013-09-28 19:36:44.268877+00', 'Teapots and Turnstiles', 'TEAPOTS AND TURNSTILES', 1, 32, NULL, 2, 3, 17, 3101, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15171, '2013-09-28 19:42:03.569872+00', '2013-09-28 19:42:03.569872+00', 'Big Cloverleaf Fountain', 'BIG CLOVERLEAF FOUNTAIN', 1, 40, NULL, 2, 3, 18, 3101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15173, '2013-09-28 19:48:43.414286+00', '2013-09-28 19:48:43.414286+00', 'Smoke on the Hills', 'SMOKE ON THE HILLS', 3, 32, NULL, 2, 3, 18, 3101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15174, '2013-09-28 19:52:51.180869+00', '2013-09-28 19:52:51.180869+00', 'Bittersweet', 'BITTERSWEET', 3, 32, NULL, 2, 3, 17, 3101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15175, '2013-09-28 19:58:33.680194+00', '2013-09-28 19:58:33.680194+00', 'Fountain Strathspey, The', 'FOUNTAIN STRATHSPEY', 3, 32, NULL, 2, 3, 18, 3101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15047, '2013-08-06 12:10:22.116206+00', '2018-03-06 23:36:42.093493+00', 'Budapest Birl', 'BUDAPEST BIRL', 2, 32, 9999, 1, 3, 42, 154, '2006-06-09', 'Extra info - from the original dance instruction :-)   "dance devised by Alex Gray with assistance from Gabor Turi to thank the Budapest Scottish Dancers for inviting him to teach at a weekend of dance. 10th June 2006"

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3654, '1999-08-06 22:00:00+00', '2013-10-02 12:41:21.294672+00', 'Laird of Achamore''s Strathspey, The', 'LAIRD OF ACHAMORES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 370, NULL, 'for Keith, our "Laird of Achamore"', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14482, '2012-06-15 05:15:58.731541+00', '2017-03-09 16:13:07.843038+00', 'SOAP', 'SOAP', 3, 32, NULL, 2, 3, 17, 10632, '2010-01-01', 'The Pilling code for the dance is SOAP



The progression is in error. As a Strathspey Poussette is not progressive, the finishing positions are (3,2,1) not the intended (2,3,1).  The dance will work in quicktime.



Original description



1-8 All three couples dance four setting steps (any Highland or Strathspey setting steps)



9-16 Six hands round and back for all the three couples



17-24 All dance a three couples Allemande



25-32 3C and 2C dance a diamond Poussette.



Repeat the dance two more times from the new positions



Tune: any 3x32 bar Strathspey



Devised by Zsolt Molnár in 2010 as a result of playing with the letters of the pilling type

description of Scottish dances. The outcome is a dance, which is really easy to remember: if

you know the title of the dance, you know the order of the figures in the dance.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15156, '2013-09-28 00:57:59.667684+00', '2018-04-02 23:56:33.94516+00', 'Delta Force', 'DELTA FORCE', 1, 32, NULL, 1, 3, 42, 3101, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15155, '2013-09-28 00:52:25.904703+00', '2018-04-02 23:56:34.813861+00', 'Gamma Three', 'GAMMA THREE', 2, 32, NULL, 1, 3, 42, 3101, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3550, '2000-07-02 22:00:00+00', '2018-04-02 23:56:35.744169+00', 'Kla-How-Ya Tillicum', 'KLAHOWYA TILLICUM', 3, 32, 9999, 1, 3, 42, 108, '1980-01-01', 'According to the leaflet, »Ka-How-Ya Tillicum« means »Welcome Friend«.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15153, '2013-09-28 00:45:28.930461+00', '2018-04-02 23:56:35.835961+00', 'Last Man Standing', 'LAST MAN STANDING', 2, 32, NULL, 1, 3, 42, 3101, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15160, '2013-09-28 01:20:05.93152+00', '2018-04-02 23:56:36.320263+00', 'Middlesex Militia, The', 'MIDDLESEX MILITIA', 3, 32, NULL, 1, 3, 42, 3101, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10649, '2002-07-21 22:00:00+00', '2018-04-03 00:07:45.912273+00', 'Firecracker Reel', 'FIRECRACKER REEL', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', 50, '844  844  888  800', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (15147, '2013-09-20 18:00:56.260541+00', '2018-04-03 00:07:46.841437+00', 'Fraser''s Fiftieth', 'FRASERS FIFTIETH', 1, 32, 9999, 1, 3, 42, 10863, '2004-02-18', 'Tune: "Fiddlin'' Round", from Devil''s Quandary, CD by Debbie Benton Grosjean and Andy Imbrie', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4814, '1997-09-10 22:00:00+00', '2013-10-02 12:34:52.916156+00', 'Mrs Warrack''s Strathspey', 'MRS WARRACKS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 370, NULL, 'Dedicated to Mrs I Warrack of Retford in appreciation of all her years of teaching the Retford and District SCD class.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15163, '2013-09-28 19:20:28.145986+00', '2018-04-03 00:18:02.028202+00', 'Chase George Thomson', 'CHASE GEORGE THOMSON', 2, 40, NULL, 2, 2, 76, 3101, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1704, '1998-07-08 22:00:00+00', '2013-10-02 17:08:26.307468+00', 'Double Celebration', 'DOUBLE CELEBRATION', 2, 40, 9999, 1, 4, 11, 313, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15214, '2013-10-14 22:53:56.641063+00', '2018-04-03 00:18:02.397438+00', 'Reel of Troqueer, The', 'REEL OF TROQUEER', 1, 48, NULL, 2, 2, 76, 10886, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15179, '2013-09-28 22:26:35.268221+00', '2022-10-24 11:08:00.789901+00', 'Pig Farmer''s Wife, The', 'PIG FARMERS WIFE', 1, 40, 9999, 1, 3, 42, 10568, '2007-03-01', 'The deviser writes that "all the ''twirls'' in the dance are piglet tails. Some people have since added ''tails'' for the first couple as they wait on the sides during the chain (as in Hooper''s Jig). This adds to the enjoyment."



The dance is inscribed "for Dagmar who, with her husband Hermann, runs a pig farm."

', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15180, '2013-09-28 22:33:44.888349+00', '2018-04-02 23:56:34.533389+00', 'Fiona''s Flock', 'FIONAS FLOCK', 1, 40, 9999, 1, 3, 42, 10568, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18249, '2018-03-07 23:19:25.243467+00', '2018-04-02 23:56:36.529135+00', 'Mrs Henderson of Blair Castle', 'MRS HENDERSON OF BLAIR CASTLE', 3, 32, NULL, 1, 3, 42, 703, '2014-10-01', '“Devised for Linda Henderson of San Francisco Area in October, 2014 by Sandy Gallamore. While teaching at Scottish Weekend, the guest teachers stay in the cabin named ‘Blair Castle’. After being guest teacher in 2010, Linda would sign her e-mails ‘Mrs Henderson of Blair Castle.’ Such a great title for a dance.’



DEVISED:2014-10', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10232, '2003-02-12 23:00:00+00', '2018-04-03 00:07:48.439756+00', 'Glastonbury Tor', 'GLASTONBURY TOR', 1, 32, 9999, 1, 3, 42, 854, '2001-01-01', 'Originally published as a Jig.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15154, '2013-09-28 00:48:35.345495+00', '2020-12-30 21:53:09.334141+00', 'Ann Arbor', 'ANN ARBOR', 2, 32, NULL, 1, 3, 42, 3101, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12897, '2006-10-12 22:00:00+00', '2021-01-07 11:30:39.158106+00', 'Warden''s Wife, The', 'WARDENS WIFE', 1, 32, 9999, 1, 3, 42, 558, '2004-01-01', '', 63, '800/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19002, '2018-10-17 13:00:15.862588+00', '2018-10-17 13:00:15.862588+00', 'Pearlescent (at 80)', 'PEARLESCENT AT 80', 3, 32, NULL, 1, 4, 1, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15208, '2013-10-14 22:05:50.062739+00', '2013-10-14 22:05:55.47949+00', 'Scotland in Trust', 'SCOTLAND IN TRUST', 1, 32, NULL, 1, 3, 42, 10882, '2006-01-01', 'Written to celebrate the 75th anniversary of the National Trust for Scotland in 2006. The figures in the dance represent the NTS logo (see publication for details)', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15209, '2013-10-14 22:09:32.757969+00', '2013-10-14 22:11:42.07493+00', 'Criss Cross', 'CRISS CROSS', 2, 32, NULL, 1, 4, 1, 2806, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15213, '2013-10-14 22:43:35.584526+00', '2013-10-14 22:47:15.201592+00', 'Half Way There', 'HALF WAY THERE', 2, 64, NULL, 4, 4, NULL, 10885, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15197, '2013-10-14 11:56:34.919626+00', '2013-10-14 11:57:14.442348+00', 'John our Kind Friend', 'JOHN OUR KIND FRIEND', 1, 32, NULL, 1, 2, NULL, 10877, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15184, '2013-10-14 08:09:41.197166+00', '2013-10-14 08:19:20.164981+00', 'Hot Summer''s Day, A', 'HOT SUMMERS DAY', 2, 32, NULL, 1, 4, 1, 10868, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15188, '2013-10-14 09:04:42.640633+00', '2013-10-14 09:04:59.052333+00', 'Douglas Jig, The', 'DOUGLAS JIG', 2, 32, NULL, 1, 4, 1, 10871, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15190, '2013-10-14 09:43:33.029536+00', '2013-10-14 09:43:37.658916+00', 'Hope Mountain Reel', 'HOPE MOUNTAIN REEL', 1, 32, NULL, 4, 4, 13, 10872, NULL, 'Written for Giles Bayliss', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15192, '2013-10-14 09:55:06.378011+00', '2013-10-14 09:55:09.722822+00', 'Reel for Cherry, A', 'REEL FOR CHERRY', 1, 32, NULL, 2, 3, 17, 10872, NULL, 'Written for Cherry Connolly', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15194, '2013-10-14 10:15:17.764146+00', '2013-10-14 10:16:21.467415+00', 'Alison''s Reel', 'ALISONS REEL', 1, 40, NULL, 1, 3, 42, 10874, NULL, 'Written for Alice''s mum who brings her sister and her to class every Friday and sometimes gets to dance herself!', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15200, '2013-10-14 13:26:03.997653+00', '2013-10-14 22:48:00.226014+00', 'Stuart''s Troqueer School Jig', 'STUARTS TROQUEER SCHOOL JIG', 2, 32, NULL, 1, 3, 42, 10879, NULL, 'Stuart wrote this dance on his way home from school dance class in June 2006.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15183, '2013-10-14 08:04:19.881378+00', '2019-01-28 22:44:58.652023+00', 'Spinning Dee, The', 'SPINNING DEE', 2, 32, NULL, 1, 4, 1, 10867, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15207, '2013-10-14 21:57:59.048128+00', '2015-03-02 00:38:55.646616+00', 'Jamaican Jig, The', 'JAMAICAN JIG', 2, 32, NULL, 1, 4, 1, 10872, NULL, 'Written for Roy Whitehead', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15210, '2013-10-14 22:20:06.431641+00', '2015-03-02 00:42:24.148245+00', 'Road to Penrith, The', 'ROAD TO PENRITH', 2, 32, NULL, 1, 4, 1, 10883, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12699, '2006-03-23 23:00:00+00', '2015-03-03 22:11:17.840314+00', 'Hamilton Ceilidh, A', 'HAMILTON CEILIDH', 1, 40, 9999, 4, 4, 13, 2115, NULL, '', 80, '8080/0808/4444/12,12,12,12/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1743, '1997-04-03 22:00:00+00', '2015-12-26 23:49:51.137089+00', 'Dr. Robertson', 'DR ROBERTSON', 1, 32, 9999, 1, 3, 42, 129, NULL, '', 50, '840/804/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13118, '2006-11-22 23:00:00+00', '2015-11-14 16:36:49.440839+00', 'Otterburn Tower', 'OTTERBURN TOWER', 1, 32, 9999, 5, 2, NULL, 3736, '2006-01-01', 'Written for Elaine Robertson and David Bolam’s wedding on 18 November 2006 at Otterburn Tower, Northumberland.', 69, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1277, '1997-04-03 22:00:00+00', '2016-04-18 23:09:47.70761+00', 'Coldside Jig', 'COLDSIDE JIG', 2, 32, 9999, 1, 2, NULL, 129, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15181, '2013-10-14 07:53:44.49681+00', '2016-06-03 15:52:35.605198+00', 'It''s not Leap Year', 'ITS NOT LEAP YEAR', 2, 32, NULL, 1, 4, 1, 2806, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15191, '2013-10-14 09:51:03.859722+00', '2016-10-21 07:33:11.138726+00', 'Jungle Jig, The', 'JUNGLE JIG', 2, 32, NULL, 1, 4, 1, 10873, NULL, '1-8 Monkeys collecting Bananas



9-16  Weaving snakes



17-20  Charging tigers



21-24  Monkeys in the trees



25-32  Tigers chasing prey', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6609, '1997-04-03 22:00:00+00', '2019-08-03 00:02:07.368651+00', 'Tillietudlem', 'TILLIETUDLEM', 2, 32, 9999, 1, 3, 42, 129, NULL, '', 58, '840/248/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2493, '1997-09-03 22:00:00+00', '2019-08-03 22:20:07.923029+00', 'Glasgow Caledonian Strathspey and Reel Society', 'GLASGOW CALEDONIAN STRATHSPEY AND REEL SOCIETY', 4, 32, 1, 1, 2, 76, 129, NULL, '', 62, '73/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15189, '2013-10-14 09:10:58.136371+00', '2017-12-19 19:34:15.249874+00', 'Celebrations', 'CELEBRATIONS', 1, 32, NULL, 1, 4, 1, 10474, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15203, '2013-10-14 15:52:38.360987+00', '2013-10-14 15:53:58.025313+00', 'Robot Reel, The', 'ROBOT REEL', 1, 48, NULL, 1, 4, 1, 10881, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15254, '2013-11-16 14:48:53.891648+00', '2013-11-16 14:48:53.891648+00', 'Schnickerdoodles', 'SCHNICKERDOODLES', 1, 32, NULL, 7, 113, NULL, 10657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15258, '2013-11-16 14:59:29.33938+00', '2013-11-16 14:59:29.33938+00', 'Moxie', 'MOXIE', 1, 32, NULL, 104, 2, NULL, 10657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15247, '2013-11-12 19:33:55.507781+00', '2019-09-05 09:57:37.829644+00', 'Three Score by Four', 'THREE SCORE BY FOUR', 3, 32, NULL, 1, 4, 1, 518, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15382, '2014-03-20 13:30:14.578669+00', '2014-03-20 13:30:14.578669+00', 'William the 50th', 'WILLIAM THE 50TH', 1, 40, NULL, 1, 4, NULL, 10933, NULL, '', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15216, '2013-10-14 23:05:51.055341+00', '2013-10-14 23:05:57.146529+00', 'Raw Pea Eater, The', 'RAW PEA EATER', 2, 40, NULL, 4, 4, NULL, 10872, NULL, 'Written for Beth Thomas', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15218, '2013-10-15 16:20:06.2587+00', '2013-10-15 16:20:06.2587+00', 'Crazy Aunt Wendy', 'CRAZY AUNT WENDY', 2, 32, NULL, 1, 4, 1, 2973, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15255, '2013-11-16 14:54:18.397857+00', '2013-11-16 14:54:18.397857+00', 'Double Fudge', 'DOUBLE FUDGE', 1, 32, NULL, 4, 4, NULL, 10657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15259, '2013-11-16 15:00:42.550112+00', '2013-11-16 15:00:42.550112+00', 'Drewry Lane', 'DREWRY LANE', 3, 32, NULL, 2, 3, NULL, 10657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11338, '2003-06-03 22:00:00+00', '2018-04-03 00:08:03.492879+00', 'Millenium Rigged Ship', 'MILLENIUM RIGGED SHIP', 1, 32, 9999, 1, 3, 42, 352, NULL, 'The name "Millennium Rigged Ship" has been added as a spelling alias, to facilitate searches, as "Millenium" is a spelling error.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15224, '2013-10-29 00:35:34.718857+00', '2019-03-27 10:26:33.53005+00', 'Leaving Lunga', 'LEAVING LUNGA', 3, 32, 9999, 4, 4, 13, 10890, '2013-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15296, '2013-12-10 19:20:11.537614+00', '2013-12-10 19:20:11.537614+00', 'Fifty Dancing Years', 'FIFTY DANCING YEARS', 1, 48, NULL, 4, 5, NULL, 10904, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8724, '2002-04-23 22:00:00+00', '2020-01-15 08:10:10.339417+00', 'Teapots', 'TEAPOTS', 1, 32, 9999, 1, 3, 42, 558, NULL, '', 44, '800/844/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15336, '2014-02-14 13:25:31.20881+00', '2016-06-03 14:06:56.273589+00', 'Tuesday Corners', 'TUESDAY CORNERS', 1, 32, NULL, 1, 3, 42, 228, '2014-02-11', 'A practice dance for »Dance to each corner and set«.', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15202, '2013-10-14 15:42:02.889442+00', '2022-08-14 10:47:21.714751+00', 'Square Tangle, The', 'SQUARE TANGLE', 1, 48, NULL, 4, 4, 1, 10880, NULL, 'Deviser aged 12 (Darlington Juniors).', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15206, '2013-10-14 21:50:56.903633+00', '2022-08-14 10:50:26.236051+00', 'Merci à Lyon', 'MERCI A LYON', 1, 32, NULL, 4, 4, 28, 10872, NULL, '', 88, '8888/8888/0808/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15215, '2013-10-14 22:56:54.98388+00', '2022-08-14 10:54:12.568889+00', 'Hayley''s Reel', 'HAYLEYS REEL', 1, 32, NULL, 1, 3, 42, 10887, NULL, 'Deviser aged 14 (Thistle Scottish Country Dance Club, Dumfries).', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15196, '2013-10-14 11:51:07.109204+00', '2022-08-20 08:23:42.37028+00', 'Junior Twelvesome', 'JUNIOR TWELVESOME', 1, 32, NULL, 4, 115, NULL, 10876, NULL, 'Square set, 3 persons on each side', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2294, '2001-11-22 23:00:00+00', '2023-01-27 19:55:35.758005+00', 'Forteviot Jig', 'FORTEVIOT JIG', 2, 32, 9999, 1, 3, 42, 129, NULL, '', 59, '840/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15376, '2014-03-18 10:47:51.48977+00', '2020-03-09 15:35:54.756589+00', 'Marlin Spike', 'MARLIN SPIKE', 1, 32, NULL, 1, 3, 42, 10584, NULL, 'The web page that provided the description in the past (http://reels-on-the-rhine.de) does unfortunately not exist anymore.', 66, '866/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1946, '1997-04-03 22:00:00+00', '2020-02-21 07:27:32.414017+00', 'Elizabeth Adair', 'ELIZABETH ADAIR', 2, 32, 9999, 1, 2, 76, 129, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15304, '2013-12-19 10:36:29.79307+00', '2020-10-07 14:15:15.047608+00', 'Lion Gate, The', 'LION GATE', 1, 32, 9999, 5, 2, 76, 10688, '2010-01-01', 'The dance commemorates the granting of the Charter confirming Perth as a Royal Burgh by William the Lion in 1210.', 100, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9478, '2002-04-15 22:00:00+00', '2021-02-23 20:27:08.38271+00', 'There Be Dragons', 'THERE BE DRAGONS', 2, 32, 9999, 1, 3, 42, 108, '1999-01-01', '', 69, '880/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12892, '2006-10-12 22:00:00+00', '2013-12-17 20:33:13.293463+00', 'Pawling Porch, The', 'PAWLING PORCH', 1, 32, 9999, 1, 3, 42, 1760, NULL, 'Devised by Elaine Brunken,  May 2005, at the Pawling Weekend in New York State.  Elaine writes: "Muriel (Johnstone) and I  had a small porch off our cabin, which seemed to become the place everyone stopped for a drink after classes, before lunch, after lunch, before dinner……..  (now there’s a surprise!).  Pawling (run by the New York Branch) is a brilliant weekend, the NY branch are one of the friendliest, most welcoming groups I have met in my many travels."   

', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15251, '2013-11-16 14:44:30.933913+00', '2018-04-03 00:08:09.221747+00', 'Oranges and Lemons', 'ORANGES AND LEMONS', 2, 32, NULL, 1, 3, 42, 10657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15383, '2014-03-20 13:34:28.347685+00', '2014-03-20 13:34:28.347685+00', 'Two can Play', 'TWO CAN PLAY', 1, 32, NULL, 1, 98, 30, 10933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15249, '2013-11-16 14:38:52.164902+00', '2013-11-16 14:38:52.164902+00', 'Ditto Ditto', 'DITTO DITTO', 3, 32, NULL, 1, 4, NULL, 10657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15252, '2013-11-16 14:45:41.43572+00', '2013-11-16 14:45:41.43572+00', 'T.G.I.F.', 'TGIF', 1, 32, NULL, 3, 5, NULL, 10657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15256, '2013-11-16 14:55:26.974453+00', '2013-11-16 14:55:26.974453+00', 'Jiggity Jig', 'JIGGITY JIG', 2, 32, NULL, 1, 2, NULL, 10657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15260, '2013-11-16 15:02:12.182919+00', '2013-11-16 15:02:12.182919+00', 'Pocket Full of Posies', 'POCKET FULL OF POSIES', 2, 32, NULL, 2, 3, NULL, 10657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15262, '2013-11-16 15:18:49.265205+00', '2013-11-16 15:18:49.265205+00', 'Road Between', 'ROAD BETWEEN', 1, 32, NULL, 2, 3, NULL, 10657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14707, '2013-02-01 10:44:21.621673+00', '2013-11-18 22:37:38.227143+00', 'Powder Monkey, The', 'POWDER MONKEY', 4, 128, 2, 4, 4, 3, 10735, NULL, 'Devised to commemorate »Sea Britain« in 2005, 200 years after the battle of Trafalgar.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15264, '2013-11-20 11:29:37.86028+00', '2013-11-20 11:29:37.86028+00', 'Chas Reel, The', 'CHAS REEL', 1, 32, NULL, 1, 3, 42, 2694, NULL, 'The CD "Reels and Wheels says "Chas Reel.  Dance instructions available by request. Contact mr. C Hunter, +44-1324 553 601"', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15243, '2013-11-12 19:26:50.536915+00', '2019-10-26 08:47:45.021348+00', 'Vallay Sound', 'VALLAY SOUND', 2, 32, NULL, 1, 4, 2, 517, NULL, '', 69, '8448/8448/8008/8448', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15324, '2013-12-22 23:30:27.42646+00', '2016-10-16 23:19:09.320006+00', 'King in Patagonia, A', 'KING IN PATAGONIA', 1, 32, NULL, 1, 3, 42, 10910, '2012-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15315, '2013-12-22 23:07:07.323229+00', '2019-06-16 08:48:55.879161+00', 'Farm Boy', 'FARM BOY', 3, 32, NULL, 1, 4, 1, 10910, '2013-03-01', '', 94, '8888/8888/8484/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15312, '2013-12-19 10:53:30.743636+00', '2019-06-17 11:48:21.482621+00', 'Highlander in Glasgow, A', 'HIGHLANDER IN GLASGOW', 3, 32, NULL, 1, 102, 2, 884, '2013-05-01', 'In memory of David Gordon, fiddle player, composer and member of the RSCDS Western Australia branch. David was born a highlander near Inverness but before immigrating to Australia, spent most of his early working life in Glasgow.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15377, '2014-03-18 10:54:14.990555+00', '2017-09-22 02:50:23.101674+00', 'Tempus Fugit', 'TEMPUS FUGIT', 1, 48, NULL, 4, 4, NULL, 10584, NULL, 'The web page that provided the description in the past (http://reels-on-the-rhine.de) does unfortunately not exist anymore.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15321, '2013-12-22 23:19:14.091922+00', '2018-03-16 08:40:29.785228+00', 'Impressive Clergyman, The', 'IMPRESSIVE CLERGYMAN', 3, 32, NULL, 1, 3, 42, 10910, '2012-12-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15257, '2013-11-16 14:57:52.406283+00', '2018-04-03 00:18:02.37217+00', 'Purdy Pink Band Shoes', 'PURDY PINK BAND SHOES', 2, 32, NULL, 2, 2, 76, 10657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15250, '2013-11-16 14:41:45.670636+00', '2013-11-16 14:41:45.670636+00', 'George Street Jig', 'GEORGE STREET JIG', 2, 32, NULL, 1, 4, NULL, 10657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15261, '2013-11-16 15:08:14.323842+00', '2013-11-16 15:08:14.323842+00', 'Dance for Charlie', 'DANCE FOR CHARLIE', 1, 32, NULL, 7, 113, NULL, 10657, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15159, '2013-09-28 01:16:09.840725+00', '2018-04-02 23:56:34.755229+00', 'Frugal Farmer, The', 'FRUGAL FARMER', 3, 32, NULL, 1, 3, 42, 3101, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15220, '2013-10-28 23:43:14.102853+00', '2013-10-28 23:43:14.102853+00', '… And the Ladies Wore Red', ' AND THE LADIES WORE RED', 1, 32, 9999, 1, 4, 1, 10648, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15221, '2013-10-29 00:04:31.828076+00', '2013-10-29 00:04:31.828076+00', 'Barry & Doreen''s Continental Capers', 'BARRY AND DOREENS CONTINENTAL CAPERS', 1, 32, 9999, 1, 100, 2, 10888, '2013-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15225, '2013-10-29 00:40:31.77104+00', '2013-10-29 00:40:31.77104+00', 'Mrs Millar''s Strathspey', 'MRS MILLARS STRATHSPEY', 3, 32, 9999, 1, 4, 2, 10889, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15318, '2013-12-22 23:13:11.52759+00', '2018-04-03 00:07:38.680583+00', 'Cliffs of Insanity, The', 'CLIFFS OF INSANITY', 2, 32, NULL, 1, 3, 42, 10593, '2012-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15227, '2013-10-29 00:56:18.316464+00', '2014-02-01 16:59:28.342283+00', 'Twins'' Delight, The', 'TWINS DELIGHT', 2, 32, 9999, 2, 3, 17, 10648, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15291, '2013-12-10 19:12:37.183464+00', '2018-08-15 07:08:22.161548+00', 'Fitness Fun', 'FITNESS FUN', 1, 32, NULL, 1, 4, 1, 10902, NULL, '', 84, '6666/6666/4888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15240, '2013-11-12 19:21:49.47862+00', '2019-11-18 23:31:53.649113+00', 'Badgers Dance, The', 'BADGERS DANCE', 1, 48, NULL, 4, 5, 38, 10424, '2005-05-01', 'Dance devised by Rachel Robson In May 2005 for Yoshimi Kuroda, with many thanks for piping at Rachel''s and Neil Wignall''s wedding. The dance is named for the badgers that Yoshimi was studying at the time.

', 80, '44448/88888/44448/88888/44448/88888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15239, '2013-11-12 19:20:41.457727+00', '2020-01-04 22:24:13.108433+00', 'Deb''s Christmas Cracker', 'DEBS CHRISTMAS CRACKER', 2, 32, NULL, 1, 4, 11, 11645, NULL, 'Both dance and tune were a Christmas present (from a herdp student) for hos mother, Deb Lees.', 81, '8008/8888/8888/8448', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4863, '1997-04-03 22:00:00+00', '2020-08-07 04:42:02.866916+00', 'My Mither''s Aye Glow''rin'' Owre Me', 'MY MITHERS AYE GLOWRIN OWRE ME', 2, 32, 9999, 1, 2, NULL, 129, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15306, '2013-12-19 10:39:19.168928+00', '2020-10-07 14:17:38.252498+00', 'Special Occasion, A', 'SPECIAL OCCASION', 1, 48, 9999, 2, 3, 18, 884, '2011-03-01', '', 58, '800/888/844/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15316, '2013-12-22 23:08:48.564677+00', '2020-10-07 14:20:54.112502+00', 'Screaming Eels, The', 'SCREAMING EELS', 2, 32, NULL, 1, 3, 42, 10593, '2012-12-01', '', 56, '800/888/808/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15244, '2013-11-12 19:29:52.029762+00', '2021-02-03 13:05:49.387175+00', 'Hot Cross Bun, The', 'HOT CROSS BUN', 1, 32, NULL, 2, 3, 18, 10894, NULL, 'Either a 8 x 32 Reel or a 3 x 32 Reel. ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10000, '2001-07-19 22:00:00+00', '2021-03-27 19:01:54.589969+00', 'When Dancers Meet', 'WHEN DANCERS MEET', 1, 48, 9999, 1, 4, 13, 1049, '1995-01-01', 'Devised for the wedding of Kaoru Masaki and Aad Boode  

This dance was the 10 000th dance to be included in DanceData.', 62, '0008  8888  0008  8888  0008  8888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (15403, '2014-03-27 23:48:32.501044+00', '2017-02-19 10:51:22.281434+00', 'Festival Man, The', 'FESTIVAL MAN', 2, 32, NULL, 1, 3, 42, 2806, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15198, '2013-10-14 12:04:38.033031+00', '2022-08-14 10:43:44.833598+00', 'Greyfriars Bobby', 'GREYFRIARS BOBBY', 2, 40, NULL, 2, 3, 17, 10878, NULL, 'Each dancer in the set represents one character in the story of Greyfriar''s Bobby (see publication for details) ', 57, '800/844/804/800/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19053, '2018-11-12 00:24:29.540987+00', '2022-10-01 09:01:29.696389+00', 'Swans o'' the Bay', 'SWANS O THE BAY', 3, 32, NULL, 1, 4, 2, 10582, '2018-01-01', 'Devised for Barbara Swanepoel in celebration of her 70th birthday', 62, '8888/8008/8008/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15238, '2013-11-12 19:19:28.381254+00', '2021-04-09 10:48:53.329246+00', 'Swiss Chocolate', 'SWISS CHOCOLATE', 1, 32, NULL, 1, 4, 1, 10424, '2003-08-16', 'Presented to Nicole Frey and Adrian Buchel at their wedding in lttinger Switzerland on 16th August 2003.



This is a ceilidh dance, intended for the less experienced. It can also be danced with 3 or 5 couples.', 72, '8888/8000/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3866, '2002-04-30 22:00:00+00', '2021-08-02 04:06:53.312601+00', 'Loch Michigan Rant, The', 'LOCH MICHIGAN RANT', 1, 40, 9999, 1, 3, 42, 452, '1986-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9418, '2002-09-22 22:00:00+00', '2021-08-02 10:04:27.615915+00', 'Moving South', 'MOVING SOUTH', 3, 40, 9999, 1, 3, 42, 308, '1997-03-01', 'The devisor does not consider this dance works well *(comment received from Sue Petyt by email)*.', 60, ' 844/844/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10856, '2002-11-01 23:00:00+00', '2017-01-03 15:12:39.361817+00', 'Wheels of Time, The', 'WHEELS OF TIME', 1, 32, 9999, 1, 3, 42, 3199, '2002-04-03', 'Devised to celebrate Frans Ligtmans'' 70th birthday, 3 april 2002



Music: a reel that illustrates the motion of the balance wheel an old-fashioned watch.', 62, '844  888  844  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (11949, '2004-12-13 23:00:00+00', '2016-02-15 07:55:56.898126+00', 'Celtic Wedding', 'CELTIC WEDDING', 1, 32, 9999, 1, 3, 42, 411, '2001-05-23', 'The Celtic Reels in this dance are based on those in Barry Skelton’s dance ‘The Celtic Reel’ from his ‘Celtic Book’. The structure of the dance in bars 9 - 24 is based on Ron Wallace’s dance ‘Trip to Paradise’ which contains a ‘Corners Targe’ here converted into a ‘Corner’s Celtic Reel’.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15234, '2013-11-12 18:48:22.621327+00', '2019-10-02 15:11:20.111554+00', 'Troublesome Threesomes', 'TROUBLESOME THREESOMES', 3, 48, NULL, 2, 3, 17, 10894, NULL, '', 72, '822/866/866/866/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15322, '2013-12-22 23:20:57.003858+00', '2016-10-16 23:18:29.562433+00', 'Wing, The', 'WING', 1, 40, NULL, 1, 3, 42, 10910, '2012-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15325, '2013-12-22 23:31:39.804435+00', '2016-10-16 23:19:28.433444+00', 'Four White Horses', 'FOUR WHITE HORSES', 2, 32, NULL, 1, 4, 1, 10910, '2012-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15230, '2013-11-09 22:59:36.757528+00', '2018-12-07 17:49:54.518745+00', 'It''s My Pleasure', 'ITS MY PLEASURE', 2, 32, NULL, 1, 3, 42, 3369, '2013-10-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15245, '2013-11-12 19:31:24.776611+00', '2017-02-06 23:43:48.951324+00', 'Speedy Thomas', 'SPEEDY THOMAS', 6, 32, NULL, 1, 2, 76, 10720, NULL, '', 47, '80/80/88/84', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15152, '2013-09-28 00:40:07.225793+00', '2017-05-14 00:33:52.490896+00', 'Aldebaran', 'ALDEBARAN', 2, 32, NULL, 1, 3, 42, 3101, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15228, '2013-10-29 01:16:12.539757+00', '2017-10-10 15:19:31.951643+00', 'Waltham Ladies, The', 'WALTHAM LADIES', 4, 96, 10029, 4, 4, 3, 10648, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13078, '2006-11-10 23:00:00+00', '2019-03-17 22:16:48.458046+00', 'Glengarry Homestead, The', 'GLENGARRY HOMESTEAD', 3, 32, 9999, 1, 4, 2, 884, '1995-01-01', '', 78, '8484/8888/8008/6688', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15223, '2013-10-29 00:20:57.325403+00', '2017-12-20 23:28:41.333286+00', 'History in the Making', 'HISTORY IN THE MAKING', 1, 32, 9999, 2, 110, 17, 10648, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9062, '1999-07-24 22:00:00+00', '2013-11-27 02:22:13.3875+00', 'Macdonalds'' Skye Wedding, The', 'MACDONALDS SKYE WEDDING', 2, 96, 9999, 4, 4, 3, 872, '1996-01-01', 'Devised in 1996 for Judy and Ian (llsa ans John) McDonald on the occasion of their Wedding on the Isle of Skye, 28th March 1996', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13842, '2011-08-21 22:00:00+00', '2013-11-27 02:27:22.433286+00', 'Golden Wedding Tribute, A', 'GOLDEN WEDDING TRIBUTE', 1, 88, NULL, 4, 4, 30, 872, '1995-01-01', 'Devised by Marilyn Watson in 1995 to celebrate the Golden Wedding of Margaret and Ted Sutters, who have been members of the Bournemouth Branch for over 30 years.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15274, '2013-12-07 20:35:51.388681+00', '2018-04-02 23:56:33.330445+00', 'Cardross House', 'CARDROSS HOUSE', 3, 32, NULL, 1, 3, 42, 1760, '2000-07-01', 'DATE:2000-07', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15276, '2013-12-07 20:46:24.807676+00', '2018-04-02 23:56:34.016022+00', 'Double Measure, A', 'DOUBLE MEASURE', 1, 32, NULL, 1, 3, 42, 1760, '2001-07-01', 'DATE:2001-07', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15278, '2013-12-07 21:01:02.293871+00', '2018-04-02 23:56:34.700511+00', 'Four''s A Score', 'FOURS A SCORE', 1, 32, NULL, 1, 3, 42, 1760, '2008-09-20', '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4130, '1998-07-08 22:00:00+00', '2014-01-12 01:57:46.144291+00', 'Mann And The Isles', 'MANN AND THE ISLES', 3, 40, 9999, 1, 4, 2, 377, '1982-01-01', 'The spelling alias "Millennium Rant, The" has been added to facilitate searches, as "Millenium" is a spelling error.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15384, '2014-03-20 13:38:27.172723+00', '2014-03-20 13:38:27.172723+00', 'JJH 2008', 'JJH 2008', 3, 32, NULL, 1, 4, NULL, 10933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15380, '2014-03-20 13:21:05.398662+00', '2014-03-20 13:21:05.398662+00', 'Romance of the Waimarie', 'ROMANCE OF THE WAIMARIE', 2, 40, NULL, 1, 4, 1, 10933, NULL, '', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15279, '2013-12-07 21:03:36.82247+00', '2018-04-02 23:56:35.034754+00', 'Greenbelt Jig, The', 'GREENBELT JIG', 2, 32, NULL, 1, 3, 42, 1760, '2010-03-01', 'DATE:2010-03', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15280, '2013-12-07 21:12:24.969719+00', '2018-04-02 23:56:36.462238+00', 'More Than Nothin''', 'MORE THAN NOTHIN', 2, 32, NULL, 1, 3, 42, 1760, '2002-09-01', 'DATE:2002-09', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15289, '2013-12-10 13:55:17.21206+00', '2018-08-15 00:11:08.706033+00', 'Mendip Reel, The', 'MENDIP REEL', 1, 40, NULL, 1, 3, 42, 1439, NULL, '', 81, '800/888/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15295, '2013-12-10 19:19:16.213655+00', '2018-08-14 08:40:10.890586+00', 'Highland Cathedral', 'HIGHLAND CATHEDRAL', 3, 32, NULL, 1, 3, 42, 3170, NULL, 'The dance is the same as "Lesley''s Favourites" with an alternate ending to make it a 3 couple dance in a 4

couple set "Highland Cathedral" was probably Lesley''s favourite tune.', 47, '800/844/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15283, '2013-12-07 21:25:51.404711+00', '2018-04-02 23:56:37.004858+00', 'Pinewoods Transitions', 'PINEWOODS TRANSITIONS', 1, 40, NULL, 1, 3, 42, 1760, '2001-07-01', 'DATE:2001-07', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15288, '2013-12-10 13:51:34.163543+00', '2018-08-16 23:04:21.91057+00', 'Lesley''s Favourites', 'LESLEYS FAVOURITES', 3, 32, NULL, 2, 3, 17, 3170, NULL, 'Remembering Lesley Terry - a much respected Secretary, co-founder of the Branch''s Bums Supper

celebrations and active member of the Branch for many years.', 47, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15307, '2013-12-19 10:40:58.223605+00', '2020-03-01 10:30:26.022833+00', 'Far North Queensland', 'FAR NORTH QUEENSLAND', 3, 32, 9999, 3, 5, 19, 884, '2011-06-01', '', 63, '84448/80008/86468/82428', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13082, '2006-11-10 23:00:00+00', '2020-03-20 12:50:15.27091+00', 'One of a Kind', 'ONE OF A KIND', 4, 120, 15, 1, 114, NULL, 884, '2002-01-01', 'This is a demonstration dance - presented to Ken Sumby by members of the Western Australia Branch Demonstration Team on the occasion of his 60th birthday.



The three medley sections are all different and are mostly described in four bar phrases with detailed hints on transitions between them. 



For demo dances making a crib or adding detailed formation information serves no purpose.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13835, '2011-08-21 22:00:00+00', '2020-09-22 08:39:22.662376+00', 'Seaside Ruby, A', 'SEASIDE RUBY', 2, 32, NULL, 1, 3, 42, 872, '2005-01-01', 'Devised in 2005 to celebrate the 40th Anniversary of the Bournemouth Branch', 66, '888/888/844/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7087, '1997-04-03 22:00:00+00', '2020-05-19 00:47:48.308196+00', 'Where Good Friends Meet', 'WHERE GOOD FRIENDS MEET', 1, 32, 9999, 1, 3, 42, 44, NULL, 'Presented to the 1986 Pinewoods Scottish Country Dance Camp', 56, '888/888/800/880', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (15317, '2013-12-22 23:10:49.202571+00', '2020-10-07 14:24:42.803139+00', 'Swashbuckling Dread Pirate Roberts', 'SWASHBUCKLING DREAD PIRATE ROBERTS', 1, 32, NULL, 1, 3, 42, 10910, '2012-10-01', '', 41, '800/822/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15327, '2013-12-26 15:53:32.076983+00', '2020-10-07 21:11:47.987131+00', 'Somerset Rhapsody, A', 'SOMERSET RHAPSODY', 3, 32, NULL, 2, 3, 17, 2197, '2013-01-01', 'For Maureen and Frank', 75, '800/888/888/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15362, '2014-03-17 23:00:13.979171+00', '2020-10-08 13:43:14.942793+00', 'Aspen Circle Strathspey, The', 'ASPEN CIRCLE STRATHSPEY', 3, 40, NULL, 2, 3, 17, 10930, NULL, '', 87, '880/888/888/808/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10361, '2002-02-26 23:00:00+00', '2021-02-09 12:32:51.040274+00', 'Wild Rose Strathspey, The', 'WILD ROSE STRATHSPEY', 3, 32, 9999, 2, 3, 17, 3617, '1993-03-01', 'This was first performed during interval at the Central Iowa Ball in May 1993 for Iain and Janette Crawford of Glasgow as they came back to visit.  They will always be a part of our ball!', 63, '800/888/822/808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15226, '2013-10-29 00:47:49.593468+00', '2022-08-14 11:37:02.407054+00', 'Three Squared', 'THREE SQUARED', 2, 32, 9999, 4, 111, 30, 1848, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13740, '2011-07-10 22:00:00+00', '2014-11-12 14:07:52.120863+00', 'Honeysuckle', 'HONEYSUCKLE', 1, 40, 9999, 1, 4, 1, 10366, NULL, 'The description on the website has an error, making the set move up one place each time through.  This has been corrected in my crib.  Eric', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18587, '2018-09-15 15:41:52.779773+00', '2018-09-22 14:41:53.977698+00', 'Cardigan Sunsets', 'CARDIGAN SUNSETS', 3, 32, NULL, 2, 3, 17, 729, '2018-06-01', 'Dance devised whilst staying for a dancing holiday at the Cliff Hotel in late June 2018 arranged and organised by Jean Shaw. Thank you, Jean, for a great holiday and arranging such superb weather so that we could experience glorious sunsets every evening!', 94, '888/888/882/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15319, '2013-12-22 23:14:53.688583+00', '2016-10-16 23:15:04.699301+00', 'Dizzying Intellect, A', 'DIZZYING INTELLECT', 2, 32, NULL, 1, 3, 42, 10910, '2012-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15400, '2014-03-24 01:30:29.644408+00', '2018-04-02 23:56:37.013177+00', 'Pipe Doon', 'PIPE DOON', 2, 32, NULL, 1, 3, 42, 3431, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15268, '2013-11-27 04:17:39.454619+00', '2015-10-28 15:05:48.097237+00', 'Red Rubber Ball', 'RED RUBBER BALL', 2, 40, 9999, 1, 3, 42, 10899, '2013-06-01', '', 42, '800/880/844/844/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15284, '2013-12-07 21:28:08.679091+00', '2018-04-02 23:56:37.347342+00', 'Road to the Border, The', 'ROAD TO THE BORDER', 1, 32, NULL, 1, 3, 42, 1760, '2004-07-01', 'DATE:2004-07', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15271, '2013-12-03 15:17:20.943902+00', '2016-08-23 23:09:52.227383+00', 'Just For You', 'JUST FOR YOU', 4, 128, 2, 4, 4, 54, 3355, NULL, 'Devised for Rosi Betsche', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15287, '2013-12-10 13:49:46.837723+00', '2019-02-04 15:51:57.263039+00', 'Fifty Years Young', 'FIFTY YEARS YOUNG', 1, 40, NULL, 1, 3, 42, 3482, NULL, 'This was judged by Branch members as the most popular dance in the competition to devise a dance for the Quincentenary.', 47, '800/844/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14093, '2011-08-25 22:00:00+00', '2018-04-03 00:08:10.173014+00', 'Peerless Pearl', 'PEERLESS PEARL', 2, 32, NULL, 1, 3, 42, 10435, NULL, 'Devised by Ian Dickson for Pearl Varah to celebrate a birthday.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15294, '2013-12-10 19:18:01.818156+00', '2018-04-03 00:08:15.743854+00', 'Severn Bridges', 'SEVERN BRIDGES', 1, 40, NULL, 1, 3, 42, 10904, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15286, '2013-12-07 21:42:07.897108+00', '2019-10-14 22:54:46.098116+00', 'Union Jig, The', 'UNION JIG', 2, 32, NULL, 1, 3, 42, 1760, '2005-05-07', '', 63, '880/888/880/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4112, '1997-04-03 22:00:00+00', '2019-08-02 12:24:26.611978+00', 'Malcolm Misticot', 'MALCOLM MISTICOT', 1, 32, 9999, 1, 2, 76, 129, NULL, '', 60, '84/88/88/84', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15300, '2013-12-10 19:26:15.588362+00', '2013-12-10 19:26:15.588362+00', 'Queen Square', 'QUEEN SQUARE', 3, 48, NULL, 4, 4, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1876, '1999-08-06 22:00:00+00', '2018-04-02 23:56:34.133426+00', 'Earl of Angus And Arran, The', 'EARL OF ANGUS AND ARRAN', 3, 32, 9999, 1, 3, 42, 129, '1969-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6629, '1998-07-08 22:00:00+00', '2013-12-13 16:52:42.565738+00', 'Toast to St. Andrews, A', 'TOAST TO ST ANDREWS', 1, 48, 9999, 1, 100, 2, 108, '1975-02-02', '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11850, '2004-10-31 23:00:00+00', '2014-01-22 11:39:08.451017+00', 'McConnells'' Awa''', 'MACCONNELLS AWA', 3, 32, 9999, NULL, 3, NULL, 2961, NULL, 'Devised: 2003', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15335, '2014-02-12 09:10:18.436864+00', '2014-02-12 09:10:18.436864+00', 'Hands Across the Water', 'HANDS ACROSS THE WATER', 2, 32, NULL, 1, 3, 42, 146, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15385, '2014-03-20 13:42:30.781532+00', '2014-03-20 13:42:30.781532+00', 'On Yer Bike (and over the Hill)', 'ON YER BIKE AND OVER THE HILL', 1, 32, NULL, 1, 4, NULL, 10933, NULL, 'Sub Title: Paul is 40', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15390, '2014-03-20 14:09:31.740699+00', '2014-03-20 14:09:31.740699+00', 'SSvoSS', 'SSVOSS', 2, 32, NULL, 1, 4, NULL, 10933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15392, '2014-03-20 14:16:40.636419+00', '2014-03-20 14:16:40.636419+00', 'And Then Some', 'AND THEN SOME', 3, 32, NULL, 1, 4, 1, 10933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15394, '2014-03-20 14:27:58.650969+00', '2014-03-20 14:27:58.650969+00', 'PIAB {Putting it Across (Bevin)]', 'PIAB PUTTING IT ACROSS BEVIN', 4, 64, 5, 1, 4, NULL, 10933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15396, '2014-03-20 14:48:51.683486+00', '2014-03-20 14:48:51.683486+00', 'To One Elizabeth Douglas', 'TO ONE ELIZABETH DOUGLAS', 4, 128, 2, 4, 4, 3, 10933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15332, '2014-01-22 11:46:48.969516+00', '2018-10-09 13:46:49.320746+00', 'Simple Twist of Fate, A', 'SIMPLE TWIST OF FATE', 3, 32, 9999, 1, 3, 42, 2766, '2010-08-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15299, '2013-12-10 19:24:48.962461+00', '2019-02-22 23:20:53.443708+00', 'Torphins Lassie', 'TORPHINS LASSIE', 1, 32, NULL, 1, 3, 42, 3168, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15389, '2014-03-20 13:54:52.033125+00', '2018-04-02 23:56:36.311996+00', 'Michelle, Sue and Mary Reel (MS&MR), The', 'MICHELLE SUE AND MARY REEL MSANDMR', 1, 32, NULL, 1, 3, 42, 10933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15337, '2014-02-15 07:07:55.215058+00', '2014-02-15 07:13:02.639382+00', 'DYM 180', 'DYM 180', 3, 32, NULL, 2, 3, 18, 10373, '2006-10-01', 'Devised by Chris and Sue Ronald, October 2006, for Marion and William Salmon.  The title of the dance refers to the number plate of a very special motor car. 



The movement on bars 5-8, 13-16 and 21-24 was devised by Kathy Wendell.  See bars 9-16 of The Rose Garden, San Francisco Collection, Volume 2



Original instructions:



Bars

1 – 4	1st couple cross passing by right shoulder, and cast off one place on partner''s side as 2nd couple step up.



5 – 8	1st couple set advancing, passing back to back on the second step, pull right shoulders back to face partner and turn with both hands to finish facing first corners ; on bar 8, 1st man pulls right shoulder back and 1st woman helps him round with her right hand (in his left hand).



9 - 12	1st couple set to and turn first corners with both hands. 1st woman finishes between 2nd couple at top, 1st man finishes between 3rd couple.



13 – 16	1st couple set advancing, passing back to back on the second step, pull right shoulders back to face partner and turn with both hands to finish facing 2nd corner, 1st woman helping partner as on bar 8.



 17 - 20	1st couple set to and turn second corners, finishing in 2nd place on partner''s side.



21 – 24	1st couple set advancing, passing back to back on the second step, pull right shoulders back to face partner and turn three-quarters round with both hands, to finish woman above man in the centre; at the last moment, they release both hands, and pull right shoulder back so that woman faces up and man faces down.



25 - 28 	1st woman with 2nd couple, 1st man with 3rd couple, right hands across, again finishing with woman above man in the centre (left shoulder to left shoulder).    



29 – 32	(Snake figure) 1st man, followed by 3rd man and 3rd woman, dances up the women''s side, across the top and half way down the men''s side; while 1st woman followed by 2nd woman and 2nd man, dances down the men''s side, across the bottom and half way up the women''s side. 



	Finish in order 3,1,2.  Repeat from new places.  

', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4092, '1997-08-17 22:00:00+00', '2018-11-13 01:48:18.555735+00', 'Maids of Currie, The', 'MAIDS OF CURRIE', 1, 32, 9999, 1, 3, 42, 486, '1979-01-01', '', 41, '800/880/880/822', 0, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (9380, '2000-05-11 22:00:00+00', '2018-11-26 00:13:43.185744+00', 'Auld Reekie Hornpipe', 'AULD REEKIE HORNPIPE', 1, 32, 9999, 1, 3, 42, 717, '1998-01-01', '', 61, '864/888/822/888', 0, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (14138, '2011-08-26 22:00:00+00', '2020-09-26 09:45:30.520342+00', 'Farewell to Helensburgh', 'FAREWELL TO HELENSBURGH', 3, 32, NULL, 1, 3, 42, 74, '2003-06-01', '', 63, '880/880/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18975, '2018-10-15 18:43:42.801479+00', '2020-11-22 18:57:44.490972+00', 'Midwinter Strathspey', 'MIDWINTER STRATHSPEY', 3, 32, NULL, 1, 3, 42, 9998, NULL, '', 45, '800/823/832/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15378, '2014-03-19 22:19:29.285029+00', '2020-12-30 21:51:43.609079+00', 'Twenty Candles for Iberia', 'TWENTY CANDLES FOR IBERIA', 1, 96, NULL, 4, 4, 3, 3717, '2013-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15303, '2013-12-10 19:30:46.668503+00', '2021-01-04 12:21:00.016304+00', 'Go for Gold', 'GO FOR GOLD', 3, 40, NULL, 1, 4, 1, 10905, NULL, '', 80, '8800/8888/2666/8884/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15292, '2013-12-10 19:13:59.989308+00', '2021-04-03 11:09:46.71674+00', 'St Monica''s Medley', 'SAINT MONICAS MEDLEY', 4, 128, 2, 4, 4, 1, 10902, NULL, '', 97, '8888/8888/7777/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10933, '2002-11-13 23:00:00+00', '2021-02-02 16:32:26.695594+00', 'Toast to the Millenium, A', 'TOAST TO THE MILLENIUM', 2, 40, 9999, 1, 3, 42, 9998, NULL, 'Spelling alias "Toast to the Millennium, A" added, to facilitate searches, as "Millenium" is a spelling error.', 40, '880/800/808/800/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15281, '2013-12-07 21:17:46.951841+00', '2021-03-17 23:37:18.997311+00', 'Mr. Gallamore''s Strathspey', 'MR GALLAMORES STRATHSPEY', 3, 32, NULL, 1, 4, 11, 1760, '2010-05-01', 'DATE:2010-05', 75, '4444/4444/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13729, '2011-07-10 22:00:00+00', '2021-03-27 21:55:32.768889+00', 'Whirlwind, The', 'WHIRLWIND', 1, 32, NULL, 1, 3, 42, 175, NULL, 'This dance "for energetic dancers" is identical to the strathspey "<<ddd:Windmills#10776>>" (dance 11 in the same book).



<<scddb-not-identical:12789;13179;16505;20205>>

', 50, '844  844  844  844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (3080, '1998-10-08 22:00:00+00', '2021-05-26 09:53:33.893032+00', 'In Garb of Old Gaul', 'IN GARB OF OLD GAUL', 3, 32, 9999, 1, 3, 42, 129, '1966-01-01', '', 44, '800/800/880/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15386, '2014-03-20 13:47:50.656701+00', '2018-04-02 23:56:37.948492+00', 'TaeKate', 'TAEKATE', 2, 32, NULL, 1, 3, 42, 10933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11735, '2004-07-06 22:00:00+00', '2018-04-03 00:07:59.114538+00', 'Lauren''s Reel', 'LAURENS REEL', 3, 32, 9999, 1, 3, 42, 619, '1998-01-01', 'Inscribed to the granddaughter of Mrs Anne Duffy 1998', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8734, '1998-10-22 22:00:00+00', '2018-04-02 23:56:36.40368+00', 'Miss Nora Kindness', 'MISS NORA KINDNESS', 1, 32, 9999, 1, 3, 42, 777, '1992-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7090, '1998-11-14 23:00:00+00', '2018-02-14 22:06:14.046125+00', 'Whigmaleeries', 'WHIGMALEERIES', 1, 32, 9999, 1, 3, 42, 618, '1968-01-01', '', 50, '800/844/848/848', 1, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (15345, '2014-02-20 13:45:40.106469+00', '2018-10-14 00:12:24.507722+00', 'Barcelo Breeze, The', 'BARCELO BREEZE', 2, 32, NULL, 1, 3, 42, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15342, '2014-02-20 13:37:18.504728+00', '2018-06-01 13:55:59.481655+00', 'Glasgow Smiles', 'GLASGOW SMILES', 2, 32, NULL, 1, 3, 42, 3694, NULL, 'For Alison Jackson who worked very hard to pass her Unit 5 of the Teaching Certificate with the Birmingham class of 2011', 61, '860/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15351, '2014-02-20 13:54:58.534692+00', '2014-02-20 13:54:58.534692+00', 'Januay Holiday, The', 'JANUAY HOLIDAY', 1, 40, NULL, 4, 4, NULL, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15353, '2014-02-20 13:57:02.914197+00', '2014-02-20 13:57:02.914197+00', 'Prentice''s Apprentices', 'PRENTICES APPRENTICES', 1, 32, NULL, 1, 4, NULL, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15354, '2014-02-20 13:57:54.745657+00', '2014-02-20 13:57:54.745657+00', 'Alison Close', 'ALISON CLOSE', 3, 32, NULL, 1, 4, NULL, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18550, '2018-08-30 22:48:20.678336+00', '2018-09-27 21:33:58.950351+00', 'Weekends in Oban', 'WEEKENDS IN OBAN', 2, 32, NULL, 1, 3, 42, 3522, '2011-03-01', 'Devised by Sue Porter for the R5CDS Lorn (Argyll) Branch 50th Weekend School March 2011', 56, '800/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15356, '2014-02-20 14:00:08.55049+00', '2014-02-20 14:00:08.55049+00', 'Pamlova Strathspey, The', 'PAMLOVA STRATHSPEY', 3, 32, NULL, 2, 3, NULL, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18552, '2018-08-31 10:21:44.698855+00', '2018-08-31 10:24:25.316511+00', 'Jack Gregor''s Jig', 'JACK GREGORS JIG', 2, 48, NULL, 1, 3, 42, 3211, NULL, '(source: Minicrib)', 49, '800/844/800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15387, '2014-03-20 13:52:06.477257+00', '2014-03-20 13:52:06.477257+00', 'Whitebait in Season', 'WHITEBAIT IN SEASON', 3, 32, NULL, 1, 4, NULL, 10933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15391, '2014-03-20 14:13:22.485941+00', '2014-03-20 14:13:22.485941+00', 'Up a Ladder', 'UP A LADDER', 2, 32, NULL, 1, 4, NULL, 10933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15393, '2014-03-20 14:23:09.822122+00', '2014-03-20 14:23:09.822122+00', 'Ready About (Jibe Ho)', 'READY ABOUT JIBE HO', 1, 32, NULL, 1, 4, 2, 10933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15355, '2014-02-20 13:58:32.735514+00', '2018-04-03 00:07:40.949508+00', 'Dance Romance, A', 'DANCE ROMANCE', 3, 32, NULL, 1, 3, 42, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17802, '2017-06-18 16:31:40.919657+00', '2018-09-19 09:43:32.617206+00', 'Bill And Rajeev''s Wedding Jig', 'BILL AND RAJEEVS WEDDING JIG', 2, 32, NULL, 2, 3, 17, 11503, '2014-01-01', 'Bars 25-32 with six hands round and back represent the wedding ring.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14078, '2011-08-25 22:00:00+00', '2018-09-21 12:46:30.524408+00', 'Dorothy McDonald Dickson', 'DOROTHY MACDONALD DICKSON', 3, 32, NULL, 2, 3, 17, 10435, NULL, 'A dance devised by Ian Dickson for his wife.', 69, '860/808/888/848', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15379, '2014-03-20 13:16:54.913916+00', '2016-04-18 23:14:37.444649+00', 'Jan of Bushy Park Road', 'JAN OF BUSHY PARK ROAD', 2, 32, NULL, 1, 2, NULL, 10933, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15402, '2014-03-27 23:41:34.061337+00', '2019-01-09 23:51:36.087662+00', 'Golden Years, The', 'GOLDEN YEARS', 3, 32, NULL, 1, 3, 42, 10942, NULL, '"For the Monday morning West Acres (Toronto) seniors'' class - what a great way to start the

week!"', 69, '844/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15397, '2014-03-20 14:52:06.126782+00', '2017-05-31 10:46:45.791164+00', 'Hug for Ha''ra, A', 'HUG FOR HARA', 2, 32, NULL, 1, 4, NULL, 10933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15375, '2014-03-18 10:46:30.684942+00', '2017-09-22 02:41:12.024382+00', 'Dancing in the Park', 'DANCING IN THE PARK', 3, 32, NULL, 1, 2, NULL, 10584, '2011-05-01', 'The web page that provided the description in the past (http://reels-on-the-rhine.de) does unfortunately not exist anymore.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15346, '2014-02-20 13:48:44.653881+00', '2018-04-03 00:08:09.956142+00', 'Passport and Pumps', 'PASSPORT AND PUMPS', 2, 32, NULL, 1, 3, 42, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15357, '2014-02-20 14:01:05.473738+00', '2018-04-03 00:08:14.025881+00', 'Ruby Rendezvous', 'RUBY RENDEZVOUS', 3, 32, NULL, 1, 3, 42, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18740, '2018-10-04 10:09:19.79721+00', '2018-10-04 10:09:19.79721+00', 'Doug''s 7-0 Reel', 'DOUGS 70 REEL', 1, 96, NULL, 4, 4, 3, 2766, '2008-03-01', 'This dance is written for Doug Jensen, in honor of his 70th birthday October 18, 2010.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18551, '2018-08-30 22:51:10.820922+00', '2018-09-30 22:01:36.105152+00', 'Arabesques', 'ARABESQUES', 2, 32, NULL, 3, 5, 16, 11066, '2018-01-01', '', 60, '60600/60006/04444/88888/88888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15363, '2014-03-17 23:04:09.162408+00', '2018-10-14 00:11:39.752561+00', 'Ehlana''s Strathspey', 'EHLANAS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 10930, NULL, 'Dedicated to my granddaughter Ehlana.', 67, '800/888/844/808', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12200, '2005-04-14 22:00:00+00', '2018-10-04 10:36:27.236533+00', 'Durham Bound', 'DURHAM BOUND', 1, 64, 9999, 4, 4, 28, 2766, '2005-02-01', 'This dance is written for Maureen and Andrew Pettigrew who are leaving our dance group and moving to Durham, North Carolina.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15347, '2014-02-20 13:49:43.973539+00', '2018-10-14 00:12:49.994619+00', 'Pythagoras Cup, The', 'PYTHAGORAS CUP', 2, 32, NULL, 1, 3, 42, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15348, '2014-02-20 13:50:31.660846+00', '2018-10-14 00:13:20.974171+00', 'Steele Dancers, The', 'STEELE DANCERS', 2, 32, NULL, 1, 3, 42, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12939, '2006-10-22 22:00:00+00', '2020-06-03 22:22:32.901803+00', '80 Years Young', '80 YEARS YOUNG', 3, 32, 9999, 1, 4, 2, 2793, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15407, '2014-03-29 21:09:39.81973+00', '2020-10-05 17:58:18.59171+00', 'Making Waves', 'MAKING WAVES', 1, 32, NULL, 1, 3, 42, 3626, '2000-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15340, '2014-02-15 21:18:21.075769+00', '2020-10-08 10:27:51.52004+00', 'On Our Way to Javea', 'ON OUR WAY TO JAVEA', 2, 32, NULL, 1, 4, 2, 3717, NULL, '', 56, '4334/4334/4884/8228', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15361, '2014-03-17 22:58:05.38455+00', '2020-10-08 13:32:59.718678+00', 'Alley Cat, The', 'ALLEY CAT', 2, 32, NULL, 1, 100, 1, 10898, NULL, '', 88, '8080/8888/8888/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15373, '2014-03-17 23:18:09.451032+00', '2020-10-09 08:19:21.817633+00', 'Weekender, The', 'WEEKENDER', 1, 32, NULL, 1, 3, 42, 10898, NULL, '', 63, '800/888/888/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15301, '2013-12-10 19:27:15.296945+00', '2020-10-13 19:57:45.90664+00', 'Bristol Hornpipe, The', 'BRISTOL HORNPIPE', 1, 40, NULL, 1, 100, 2, 28, NULL, 'To celebrate the 40th Anniversary of the Bristol Branch in 2002.', 90, '8888/8888/8008/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15404, '2014-03-27 23:55:41.632505+00', '2020-12-30 21:47:33.331126+00', 'MacLeod''s Wedding', 'MACLEODS WEDDING', 1, 48, NULL, 3, 5, 7, 2096, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9904, '2002-09-01 22:00:00+00', '2021-03-09 23:17:08.523625+00', 'Whistler''s Jig', 'WHISTLERS JIG', 2, 32, 9999, 2, 2, 76, 591, NULL, 'Written for 3 couple sets but can be danced in normal 4 couple sets', 54, '62  88  75  88', 1, 1, 0, 1, 81);
INSERT INTO 'dance' VALUES (7093, '1998-11-14 23:00:00+00', '2021-03-31 09:01:38.823414+00', 'Whippety Stourie', 'WHIPPETY STOURIE', 1, 32, 9999, 1, 3, 42, 313, NULL, '“Little kens my dame at hame   

That Whippety Stourie is my name.”



From a Scottish folk lore legend (see for example <<http://www.online-literature.com/anonymous/scottish-folk-lore-legends/6/>>).

', 47, '800  833  833  888', 1, 1, 0, 1, 62);
INSERT INTO 'dance' VALUES (15349, '2014-02-20 13:51:28.682528+00', '2018-10-14 00:13:49.082416+00', 'Betancuria Reel, The', 'BETANCURIA REEL', 1, 32, NULL, 1, 3, 42, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15350, '2014-02-20 13:54:15.765163+00', '2018-10-14 00:14:20.278683+00', 'Doncaster Seven, The', 'DONCASTER SEVEN', 1, 32, NULL, 9, 7, NULL, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15344, '2014-02-20 13:42:41.023463+00', '2019-09-21 20:50:56.050822+00', 'Around the Palace', 'AROUND THE PALACE', 2, 32, NULL, 5, 2, NULL, 3694, NULL, 'couple facing couple round the room.  Men begin with partners on their right.', 100, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15352, '2014-02-20 13:56:03.983222+00', '2019-09-21 20:55:44.638676+00', 'Maltese Coastline, The', 'MALTESE COASTLINE', 1, 40, NULL, 4, 119, 4, 3694, NULL, 'The title was inspired by a holiday in Malta January 2008 where we stayed at the Coastline Hotel. It was notable for the terrible wet weather.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15381, '2014-03-20 13:25:57.831563+00', '2014-03-20 13:25:57.831563+00', 'Sea Terns', 'SEA TERNS', 3, 40, NULL, 2, 3, 17, 10933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15359, '2014-03-13 15:40:34.497179+00', '2018-04-03 00:08:25.358588+00', 'Whisky Galore', 'WHISKY GALORE', 1, 32, 9999, 1, 3, 42, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18741, '2018-10-04 10:20:11.697314+00', '2022-08-17 18:44:38.331748+00', 'DuPage River Strathspey, The', 'DUPAGE RIVER STRATHSPEY', 3, 32, NULL, 2, 3, 18, 2766, '2008-02-01', '', 79, '282/888/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9242, '2002-02-27 23:00:00+00', '2022-10-02 12:37:03.217624+00', 'Touch not the Cat', 'TOUCH NOT THE CAT', 1, 32, 9999, 1, 100, 2, 108, '1996-12-01', 'Inscribed "for the Montgomery family in Edmonton, AIberta".', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15413, '2014-04-05 22:41:23.558627+00', '2014-10-19 13:10:34.104045+00', 'Trip to the Summer Isles, A', 'TRIP TO THE SUMMER ISLES', 3, 32, NULL, 4, 4, 30, 1445, '2014-04-06', '', 84, '8181/5858/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12044, '2005-02-20 23:00:00+00', '2014-04-07 18:15:05.881592+00', 'Reely', 'REELY', 1, 32, 9999, 2, 3, 17, 777, NULL, '32 Reel for a 3 or 5 couple set.

In a three couple set: second couple begins the second round.

In a five couple set: the first couple dances again with the fourth and fifth couples.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15360, '2014-03-13 17:54:46.353614+00', '2015-02-13 13:15:24.883028+00', 'Dover Ruby, The', 'DOVER RUBY', 1, 40, 9999, 1, 4, 2, 3694, '2011-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12348, '2005-04-27 22:00:00+00', '2019-06-24 10:17:17.315354+00', 'Songs without Words', 'SONGS WITHOUT WORDS', 2, 32, 9999, 1, 100, 2, 651, '2001-03-01', '', 78, '8008/8888/8228/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15365, '2014-03-17 23:07:48.490001+00', '2015-01-26 11:57:38.611916+00', 'Florida Crackers', 'FLORIDA CRACKERS', 1, 32, NULL, 1, 3, 42, 10898, NULL, '', 69, '888/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12595, '2005-11-01 23:00:00+00', '2020-03-06 21:01:02.634409+00', 'Rite of Spring', 'RITE OF SPRING', 1, 32, 9999, 1, 3, 42, 2961, NULL, '', 53, '840/880/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14563, '2012-09-04 22:14:25.44073+00', '2020-10-01 11:31:12.401114+00', 'Salute to Lark Hill', 'SALUTE TO LARK HILL', 2, 32, 9999, 1, 3, 42, 10652, NULL, 'David devised this dance in 2010 for a demonstration at Lark Hill Village, an ExtraCare Community in Clifton,  Nottingham and dedicated it to his wife, Rhona.  David recommends the music for Miss Bennett’s Jig (Robert Whitehead’s Strictly Scottish Vol. 2) but he has  written his own tune, ‘Mrs. Rhona Page’, to accompany this dance.', 58, '860/888/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15366, '2014-03-17 23:08:51.055644+00', '2020-10-08 16:24:57.25978+00', 'Flying Dutchman, The', 'FLYING DUTCHMAN', 3, 32, NULL, 1, 3, 42, 10898, '2013-01-01', '', 50, '880/800/888/844', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15367, '2014-03-17 23:11:07.603075+00', '2020-10-08 21:31:07.391091+00', 'Jig for Elizabeth Ann, A', 'JIG FOR ELIZABETH ANN', 2, 32, NULL, 1, 3, 42, 10930, NULL, '', 50, '800/888/880/880', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15368, '2014-03-17 23:12:17.46245+00', '2020-10-08 21:41:33.739516+00', 'Khaosan Reel, The', 'KHAOSAN REEL', 1, 48, NULL, 4, 4, 1, 10898, NULL, '', 100, '8888/8888/8888/8888/8888/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15370, '2014-03-17 23:14:29.669508+00', '2020-10-08 21:53:04.606765+00', 'Parasail', 'PARASAIL', 1, 40, NULL, 1, 3, 42, 10898, NULL, '', 52, '800/888/844/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15371, '2014-03-17 23:15:40.774593+00', '2020-10-09 08:09:07.103219+00', 'Reel for Maria, A', 'REEL FOR MARIA', 1, 40, NULL, 1, 3, 42, 10930, NULL, '', 55, '800/888/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15408, '2014-03-30 21:47:20.045912+00', '2020-10-09 08:22:43.419015+00', 'Day After, The', 'DAY AFTER', 2, 32, NULL, 1, 100, 2, 3699, NULL, '', 66, '0880/8668/8448/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15409, '2014-03-31 10:08:23.802996+00', '2020-10-09 08:25:12.272747+00', 'George Rennie''s Rant', 'GEORGE RENNIES RANT', 2, 32, NULL, 1, 3, 42, 3211, NULL, '(source: Minicrib)', 38, '800/880/808/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15410, '2014-03-31 14:06:07.305449+00', '2020-10-09 08:27:59.146679+00', 'Ruby Reel, The', 'RUBY REEL', 1, 32, NULL, 1, 102, 2, 3444, NULL, '', 75, '8000/8888/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3299, '1998-07-08 22:00:00+00', '2020-12-07 21:48:25.473751+00', 'Joan''s Jig', 'JOANS JIG', 2, 32, 9999, 1, 102, 11, 175, '1978-01-01', 'For Mrs. Joan Newby of Kingston, Waterhead



First published in Scottish Dance Archives   january 1978', 87, '4444  8888  8888  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (13441, '2009-11-16 23:00:00+00', '2021-01-02 13:30:34.388321+00', 'Bellfield Park', 'BELLFIELD PARK', 2, 32, 9999, 1, 100, 2, 1911, NULL, 'Published in the Diamond Jubilee Collection of the RSCDS Inverness and District Branch: http://my.strathspey.org/dd/publ/1027/', 94, '8888/4884/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7338, '1998-01-05 23:00:00+00', '2021-03-27 12:31:57.5722+00', 'Alison''s Round Reel', 'ALISONS ROUND REEL', 1, 32, 9999, 5, 53, NULL, 154, NULL, '"For Alison''s eighteenth birthday."



Trio of one man facing clockwise to two women facing anticlockwise around the room.

', 92, '888  484  888  888', 0, 1, 0, 0, 91);
INSERT INTO 'dance' VALUES (7337, '1997-04-05 22:00:00+00', '2021-03-27 12:34:31.368531+00', 'Alice''s Request', 'ALICES REQUEST', 2, 32, 9999, 1, 2, 76, 146, NULL, '', 60, '88  80  44  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (18553, '2018-08-31 13:55:46.56085+00', '2021-04-19 10:13:56.292795+00', 'Brig Amity, The', 'BRIG AMITY', 1, 40, NULL, 1, 3, 42, 884, '2016-11-01', 'In 1826, the brig Amity sailed from Sydney under the command of Major Edmund

Lockyer, who had orders to form a settlement at King George Sound, later

named Albany, in Western Australia.

Amity House, Albany Residential College was the venue for the 38th Australian

Winter School in 2013.', 45, '800/844/822/844/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4988, '2002-05-04 22:00:00+00', '2021-05-03 07:59:33.884925+00', 'North To Inverness', 'NORTH TO INVERNESS', 3, 40, 9999, 1, 100, 2, 1253, '1991-01-01', '', 95, '8448/8888/8888/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3563, '1998-11-17 23:00:00+00', '2021-05-18 11:35:28.844805+00', 'Valletta, La', 'VALLETTA', 1, 32, 9999, 1, 100, 1, 87, NULL, 'Progression involves change-of-side.', 62, '4444/6226/8888/0448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2568, '1998-07-08 22:00:00+00', '2021-06-03 10:04:23.141528+00', 'Glentruim', 'GLENTRUIM', 3, 32, 9999, 1, 100, 11, 108, '1994-01-01', 'For Andrew Gillies.



Drewry''s notes to the dance say "Glen Truim leads northwards from Drumochter Pass towards Newtonmore. Glentruim House, beside the Spey, at the mouth of the Glen, is the home of one of the Chieftains of Clan Macpherson (Andrew''s Clan). Glentromie (the name of the tune) is the glen to the east of Glen Truim."', 88, '8888/8888/8008/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (89, '1998-10-26 23:00:00+00', '2021-10-30 21:30:26.826787+00', 'Alison Rose', 'ALISON ROSE', 3, 32, 9999, 1, 4, 1, 618, '1968-01-01', 'For the deviser''s daughter.', 91, '8444  8888  8888  8888', 1, 1, 0, 0, 90);
INSERT INTO 'dance' VALUES (10948, '2002-11-14 23:00:00+00', '2019-03-02 11:17:29.599397+00', 'Newmachar Strathspey, The', 'NEWMACHAR STRATHSPEY', 3, 32, 9999, 1, 100, 2, 108, '2002-01-01', '', 78, '8668 8888 8008 8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7339, '1997-04-05 22:00:00+00', '2019-03-08 18:05:56.413342+00', 'Andrew and Gordon''s Jig', 'ANDREW AND GORDONS JIG', 2, 32, 9999, 1, 4, 1, 146, NULL, '', 38, '8400  8040  8000  8224', 1, 1, 1, 1, 37);
INSERT INTO 'dance' VALUES (223, '2003-01-30 23:00:00+00', '2014-04-30 23:23:38.421307+00', 'Argyll''s Fancy', 'ARGYLLS FANCY', 2, 48, 9999, 1, 4, 1, 9998, NULL, '', 48, '8800  8000  8000  8800  8440  8668', 1, 1, 1, 1, 47);
INSERT INTO 'dance' VALUES (522, '1998-09-29 22:00:00+00', '2018-04-03 10:28:25.180951+00', 'Birks of Invermay, The', 'BIRKS OF INVERMAY', 3, 32, 9999, 1, 3, 42, 455, '1776-01-01', 'The Society’s version of this dance can be traced back to *Skillern''s Compleat Collection of Two Hundred & four Reels and Country Dances* of about 1789 where it is given as *Birks of Endermay*. ', 52, '541  888  800  888', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (428, '1998-01-05 23:00:00+00', '2018-08-07 21:00:31.548372+00', 'Bauldy Bain''s Fiddle', 'BAULDY BAINS FIDDLE', 1, 32, 9999, 1, 3, 42, 101, '1978-06-01', 'Dedicated to John Armstrong.', 56, '800  888  844  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (20601, '2022-01-07 18:15:33.863223+00', '2022-01-07 18:15:33.863223+00', 'Calanchoe, The', 'CALANCHOE', 2, 32, NULL, 1, 4, 1, 11514, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15364, '2014-03-17 23:06:28.788748+00', '2022-04-26 10:21:33.059285+00', 'Endless Progress', 'ENDLESS PROGRESS', 3, 32, NULL, 1, 4, 1, 10898, NULL, '', 78, '8888/8448/7654/7456', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15369, '2014-03-17 23:13:36.561501+00', '2022-09-13 16:10:16.929979+00', 'Move It', 'MOVE IT', 2, 32, NULL, 4, 55, 41, 10898, '2012-09-01', '"Born of necessity in my first group of St. Pete dancers, in the fall 2012".', 75, '88888/80408/04088/88888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7353, '1998-01-04 23:00:00+00', '2022-10-23 20:17:54.073637+00', 'Border Weavers, The', 'BORDER WEAVERS', 3, 32, 9999, 2, 3, 17, 154, NULL, '', 75, '800  888  808  888', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (9333, '2002-04-11 22:00:00+00', '2023-02-18 08:23:36.220741+00', 'Alison Rants', 'ALISON RANTS', 3, 32, 9999, 2, 3, 17, 2863, '1995-01-01', 'Alison was asked how this dance got its name.  She replied "The name was given by someone in my class who said I talk a lot!!!  Only when teaching and sometimes while they’re dancing. It was a joke really but it stuck. I wasn’t impressed with the name as I also found it a bit rude but as I said it stuck!!!!  After this I named any dances I wrote with care!!! ".

', 100, '888/888/888/888', 1, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (12039, '2005-02-20 23:00:00+00', '2014-04-21 15:54:20.862522+00', 'Double Trouble', 'DOUBLE TROUBLE', 1, 32, 9999, 1, 3, 42, 777, NULL, '1-4 	Half reels of three on the sides, first couples passing second couples by right shoulders to begin. First woman finish facing out in third place. (The order is 3,2,1)



5-8 	First woman cast up, followed by her partner, dance into the center in second place and pulling back her left shoulder turns left hands with her partner half way round to finish in promenade hold facing up. Second couple step down and in on bars 7 and 8 to finish in the center in third place in promenade hold facing up. Third couple step in on bar 8 and face up in the center in first place taking promenade hold ready for:



9-16 	Third, first, and second couples allemande. All finish on own sides.



17-24 	First couple turn half way round giving left hands, man faces up woman down. First man dances up between the second couple and casts off around the second man''s place into second place while the first woman dances down between the third couple and cast up around the third woman''s place into second place. First couple turn once round giving left hands to finish back to back in the center facing own sides. Meanwhile second and third couples dance rights and lefts.



25-32 	Second, first, and third couples dance double triangles.

', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15415, '2014-04-09 19:53:31.200039+00', '2014-04-09 21:54:19.687431+00', 'Kenneth & Fiona''s Ruby Strathspey', 'KENNETH AND FIONAS RUBY STRATHSPEY', 3, 32, NULL, 2, 104, 17, 3694, '2012-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15414, '2014-04-09 19:20:12.048693+00', '2018-06-02 15:06:27.188542+00', 'Bob Shakespeare''s Jig', 'BOB SHAKESPEARES JIG', 2, 32, NULL, 1, 3, 42, 3694, '2012-09-01', 'Written to celebrate the 70th birthday of Bob Shakespeare a well known local musician and band leader in September 2012', 56, '880/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15420, '2014-04-11 20:31:14.063612+00', '2014-04-11 20:31:14.063612+00', 'Wend Her Way to Bob', 'WEND HER WAY TO BOB', 3, 32, NULL, 2, 3, 17, 10946, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18260, '2018-03-13 23:04:40.682837+00', '2018-09-19 09:43:44.097463+00', 'Bluebelle''s Jig', 'BLUEBELLES JIG', 2, 32, NULL, 1, 4, 2, 11609, '2018-01-01', 'On occasion 70th birthday of David Quarrie', 75, '8888/8008/8888/8008', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12248, '2005-04-19 22:00:00+00', '2014-04-21 22:23:50.512582+00', 'Buckinghamshire Lass, The', 'BUCKINGHAMSHIRE LASS', 1, 40, 9999, 1, 100, 2, 884, '1994-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14391, '2012-01-06 23:00:00+00', '2014-04-30 23:23:37.671206+00', 'All for Janny', 'ALL FOR JANNY', 3, 32, NULL, 2, 3, 17, 3135, '2004-07-01', 'Devised for Janny Kramer at her 60th birthday', 46, '484  444  666  888', 0, 0, 0, 0, 72);
INSERT INTO 'dance' VALUES (9762, '2002-04-03 22:00:00+00', '2018-06-08 22:24:23.756733+00', 'Allison''s Jig', 'ALLISONS JIG', 2, 32, 9999, 1, 3, 42, 104, '1993-01-01', 'Devised for Allison Butcher', 50, '800  844  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (15273, '2013-12-06 01:08:24.119023+00', '2014-04-30 23:23:37.767287+00', 'All The Young Loons', 'ALL THE YOUNG LOONS', 2, 32, NULL, 1, 3, 42, 10900, NULL, 'I was recently delighted to learn (courtesy of The Buckie Loon) that ''loon'' means ''lad'', at least if you come from near Aberdeen. This dance is inscribed to all the young loons who have recently been gracing the dance floors of Seattle, bringing with them a splendid mix of verve, gallantry and - let''s face it - lunacy.

(I leave it to others to pay suitable tribute to the lasses.)

- Rachel Pusey, Sep 2012





', 41, '800  822  800  888', 1, 1, 1, 0, 54);
INSERT INTO 'dance' VALUES (18656, '2018-09-21 13:07:24.345716+00', '2018-09-21 13:11:39.937771+00', 'Tartan Bows', 'TARTAN BOWS', 2, 32, NULL, 1, 3, 42, 11718, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18539, '2018-08-28 17:58:15.962512+00', '2018-09-23 21:22:59.678518+00', 'Little Gem, A', 'LITTLE GEM', 3, 32, NULL, 1, 4, 11, 11693, NULL, 'A dance for the Bath Branch Diamond Jubilee.', 54, '2820/8280/8880/4804', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (105, '1998-01-12 23:00:00+00', '2014-04-30 23:23:37.851327+00', 'Alloway Kirk Rant', 'ALLOWAY KIRK RANT', 1, 32, 9999, 1, 4, 1, 210, NULL, '', 72, '8888  8000  8444  8888', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (14439, '2012-05-09 14:01:24.658827+00', '2014-04-30 23:23:36.88912+00', '50th Parallel, The', '50TH PARALLEL', 1, 48, 9999, 3, 5, 16, 2672, NULL, 'The authors lived on Vancouver Island for 6 years, just south of the 50th Parallel.', 57, '80008  80008  88888  80008  80888  80008', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (116, '2001-04-03 22:00:00+00', '2014-04-30 23:23:37.896662+00', 'Alyth Burn', 'ALYTH BURN', 2, 48, 9999, 1, 3, 42, 474, NULL, '', 60, '888  880  888  833  833  888', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (12801, '2006-07-02 22:00:00+00', '2014-04-30 23:23:37.956524+00', 'And Happy Meet Again', 'AND HAPPY MEET AGAIN', 3, 32, 9999, 1, 4, 15, 610, NULL, '', 78, '8642  8888  4804  8888', 0, 1, 1, 1, 78);
INSERT INTO 'dance' VALUES (18727, '2018-10-04 07:44:56.500031+00', '2018-10-04 07:44:56.500031+00', 'Dasher, Dancer', 'DASHER DANCER', 1, 32, NULL, 1, 3, 42, 2766, '2015-12-01', 'Celebrating the holiday season.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14548, '2012-08-31 10:38:44.087698+00', '2016-03-28 06:28:39.815816+00', 'Rutland Reel, The', 'RUTLAND REEL', 1, 40, NULL, 1, 3, 42, 10645, '2010-12-07', 'Dedicated to the late Alastair, son of the deviser, who was born and brought up in Rutland.', 46, '800/880/868/808/804', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15425, '2014-04-22 21:52:46.155724+00', '2016-08-09 15:35:22.963881+00', 'Tablet Maker''s Reel, The', 'TABLET MAKERS REEL', 1, 40, NULL, 4, 4, 46, 99, NULL, '', 57, '8000/8040/8888/8080/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15417, '2014-04-11 19:27:39.216093+00', '2017-05-31 12:48:48.984917+00', 'Morecambe Strathspey, The', 'MORECAMBE STRATHSPEY', 3, 40, NULL, 1, 4, 1, 31, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (132, '1998-09-29 22:00:00+00', '2017-07-07 14:20:51.637921+00', 'An'' thou wert my only Dear', 'AN THOU WERT MY ONLY DEAR', 2, 48, 9999, 1, 2, NULL, 9998, NULL, '', 49, '84  84  80  08  84  88', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (15416, '2014-04-11 19:19:26.942334+00', '2018-04-03 00:07:30.96979+00', 'Appleby Horse Fair', 'APPLEBY HORSE FAIR', 3, 32, NULL, 1, 3, 42, 802, '2012-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10820, '2002-09-16 22:00:00+00', '2020-08-24 17:57:26.078088+00', 'Abbotsford Lassies', 'ABBOTSFORD LASSIES', 1, 32, 9999, 4, 4, 4, 555, '1988-01-01', '', 62, '8080  0808  4444  8888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (15423, '2014-04-17 09:54:46.81561+00', '2019-12-26 16:51:58.679249+00', 'Rose Garden, The', 'ROSE GARDEN', 3, 32, NULL, 2, 3, 18, 10948, '2011-07-01', '', 75, '880/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (93, '1998-01-05 23:00:00+00', '2020-12-27 16:57:59.515115+00', 'All For Mary', 'ALL FOR MARY', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 59, '822  866  888  866', 0, 1, 0, 0, 79);
INSERT INTO 'dance' VALUES (9223, '2000-02-20 23:00:00+00', '2021-02-26 14:05:17.35664+00', 'All in the Mind', 'ALL IN THE MIND', 3, 32, 9999, 1, 3, 42, 108, '1997-01-01', '', 62, '880  844  888  844', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (140, '1998-09-29 22:00:00+00', '2021-07-04 11:09:43.038062+00', 'Anderson''s Rant', 'ANDERSONS RANT', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 50, '888  888  800  800', 1, 1, 0, 1, 66);
INSERT INTO 'dance' VALUES (107, '1997-08-28 22:00:00+00', '2021-11-10 10:13:51.473082+00', 'Allt An Duin', 'ALLT AN DUIN', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 44, '800/888/800/844', 0, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (11158, '2003-01-12 23:00:00+00', '2019-04-18 21:35:52.960632+00', 'All''s Well that Ends', 'ALLS WELL THAT ENDS', 1, 40, 9999, 1, 3, 42, 2961, NULL, 'Devised: 2003

Tune: from suggested recording', 45, '884  848  800  804  804', 0, 1, 1, 0, 60);
INSERT INTO 'dance' VALUES (152, '1998-04-29 22:00:00+00', '2014-04-30 23:23:38.0225+00', 'Angus MacKinnon''s Hornpipe', 'ANGUS MACKINNONS HORNPIPE', 1, 32, 9999, 1, 3, 42, 101, '1978-01-01', '', 53, '800  888  844  866', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (246, '2001-06-13 22:00:00+00', '2019-02-15 20:17:12.652668+00', 'Arwon''s ''Matilda''', 'ARWONS MATILDA', 3, 32, 9999, 1, 4, 1, 257, NULL, '', 62, '8888  8000  8444  8444', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (9381, '2000-04-09 22:00:00+00', '2014-04-30 23:23:38.169817+00', 'Anna''s Wedding Cake', 'ANNAS WEDDING CAKE', 3, 32, 9999, 2, 3, 17, 1176, '1996-01-01', '', 67, '800  844  088  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (11184, '2003-02-16 23:00:00+00', '2014-04-30 23:23:38.260083+00', 'Antarctica Bound', 'ANTARCTICA BOUND', 2, 32, 9999, 1, 4, 1, 146, '2002-01-01', '', 59, '8800  0088  8004  8888', 1, 1, 1, 1, 59);
INSERT INTO 'dance' VALUES (328, '2002-04-25 22:00:00+00', '2019-09-13 21:45:34.63943+00', 'Ayers Rock', 'AYERS ROCK', 3, 32, 9999, 1, 100, 2, 108, '1991-01-01', '', 87, '8888  8888  8888  8008', 1, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (373, '2002-01-08 23:00:00+00', '2017-07-07 14:26:16.107157+00', 'Balmoral Strathspey', 'BALMORAL STRATHSPEY', 3, 32, NULL, 1, 4, 1, 471, NULL, 'See also the dance ''Balmoral Castle''.', 94, '8888  8888  8888  8088', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (9838, '2002-04-04 22:00:00+00', '2022-09-30 21:26:52.869987+00', 'Annan Gold', 'ANNAN GOLD', 3, 32, 9999, 2, 3, 17, 692, '1999-01-01', '', 77, '888  833  833  868', 1, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (13578, '2010-06-02 22:00:00+00', '2018-04-03 00:07:30.694272+00', 'Anna''s Homecoming', 'ANNAS HOMECOMING', 1, 32, NULL, 1, 3, 42, 2408, '2008-11-18', 'Dedicated to the memory of Anna Laino (1983-2009).



Anna Laino was a member of the RSCDS Twin Cities Branch. A gifted musician, Anna was also fiddler for Duck or Grouse Rapper Sword Dancers. In addition to fiddle, her repertoire of musical instruments included piano, accordion, organ, and trumpet, and she sang like an angel. She completed her Masters in Sacred Music in 2008 and was organist and choirmaster for St. David''s Episcopal Church in Minnetonka, Minnesota. ', 59, '888  800  884  888', 0, 1, 1, 0, 79);
INSERT INTO 'dance' VALUES (144, '1997-08-28 22:00:00+00', '2017-02-01 15:27:29.411126+00', 'Andrew''s Dance', 'ANDREWS DANCE', 1, 32, 9999, 1, 3, 42, 628, NULL, '', 44, '800/888/880/800', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (221, '1998-09-29 22:00:00+00', '2018-04-03 00:07:31.136857+00', 'Argyll Strathspey', 'ARGYLL STRATHSPEY', 3, 32, 9999, 1, 3, 42, 146, '1985-01-01', '', 62, '888  888  808  880', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (231, '1997-08-28 22:00:00+00', '2018-04-03 00:07:31.178611+00', 'Armstrongs'' Rant, The', 'ARMSTRONGS RANT', 3, 32, 9999, 1, 3, 42, 176, NULL, '', 62, '888  844  844  888', 0, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (11269, '2003-04-21 22:00:00+00', '2014-04-30 23:23:38.794755+00', 'Auld Music Maister, The', 'AULD MUSIC MAISTER', 3, 40, 9999, 1, 3, 42, 360, NULL, '', 41, '660  660  823  832  808', 0, 1, 1, 1, 55);
INSERT INTO 'dance' VALUES (123, '1997-04-03 22:00:00+00', '2018-06-25 06:32:16.290758+00', 'Amethyst', 'AMETHYST', 3, 32, 9999, 1, 4, 1, 35, NULL, 'Peter and Vivian Russell met at the K-W Branch in 1967, married and have shared many interests and hobbies. Vivian is a school teacher and at one time taught a SCD Children''s Class. In Peter''s work in Earth Sciences, he developed a hobby of collecting minerals. Another hobby is SCD. Both of these are pictured in the dance, which is named for Ontario''s mineral emblem, "Amethyst," found near Thunder Bay. The diamond poussette represents the crystal forms, and the mirror reels the "teamwork" of atoms working together to form a perfect gem. 1st couple turning represents Peter''s and Vivian''s interest in dancing. Another joint interest is camping, and a favourite spot is near Thunder Bay on the Sibley Peninsula, with views over the lake to the hills called "The Sleeping Giant." Peter was born in Leeds, England, while Vivian was Canadian Born in Strathroy, Ontario.', 100, '8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18542, '2018-08-28 18:27:26.308682+00', '2018-09-23 21:36:28.622811+00', 'Judith''s Jig', 'JUDITHS JIG', 2, 32, NULL, 2, 3, 18, 11693, NULL, 'In memory of Judith Boxall, a founder member of the Bath Branch''s Bathampton class.', 64, '080/828/888/282', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (314, '2002-03-11 23:00:00+00', '2014-04-30 23:23:38.939841+00', 'Autumn in Appin', 'AUTUMN IN APPIN', 3, 32, 9999, 1, 100, 2, 108, '1982-01-01', '', 75, '0880  8888  4444  8888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (9138, '2002-12-17 23:00:00+00', '2020-02-10 15:39:27.763835+00', 'Auchinellan Jig', 'AUCHINELLAN JIG', 2, 32, 9999, 1, 3, 42, 2673, NULL, '', 56, '880  888  844  844', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (183, '1998-09-29 22:00:00+00', '2020-05-15 11:45:44.44242+00', 'Anniversary Reel', 'ANNIVERSARY REEL', 1, 32, 9999, 1, 4, 1, 449, '1987-01-01', '', 53, '8000/8844/8444/8044', 1, 1, 1, 1, 53);
INSERT INTO 'dance' VALUES (14098, '2011-08-25 22:00:00+00', '2020-05-15 13:47:42.06597+00', 'Ardchoille Jig, The', 'ARDCHOILLE JIG', 2, 32, NULL, 2, 3, 17, 10436, NULL, '', 55, '686/686/484/077', 1, 1, 1, 0, 72);
INSERT INTO 'dance' VALUES (164, '1997-04-03 22:00:00+00', '2021-05-07 22:39:50.934844+00', 'Anne', 'ANNE', 3, 32, 9999, 1, 3, 42, 129, NULL, '', 50, '880  800  888  844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (9839, '2001-05-20 22:00:00+00', '2021-02-18 15:23:14.494445+00', 'Are You Sleeping?', 'ARE YOU SLEEPING', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 60, '66  66  80  88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (13625, '2010-10-13 22:00:00+00', '2020-09-19 11:34:27.664683+00', 'Anne Sheach''s Strathspey', 'ANNE SHEACHS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 2980, NULL, '', 92, '888  888  888  088', 0, 1, 0, 0, 91);
INSERT INTO 'dance' VALUES (240, '1998-01-05 23:00:00+00', '2020-11-15 13:10:13.433022+00', 'Arran Chase', 'ARRAN CHASE', 1, 32, 9999, 1, 3, 42, 323, NULL, '', 66, '866  866  866  888', 1, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (14393, '2012-01-06 23:00:00+00', '2020-11-15 13:13:27.295087+00', 'At the Summit', 'AT THE SUMMIT', 3, 32, NULL, 1, 3, 42, 10597, '2009-08-01', 'Devised for Bob and Barbara Anglin in appreciation of their support of our teaching in Ottawa', 50, '800  844  844  888', 0, 0, 0, 0, 66);
INSERT INTO 'dance' VALUES (17696, '2017-04-02 08:34:50.650522+00', '2021-01-19 12:07:27.884791+00', 'Devil''s Staircase, The', 'DEVILS STAIRCASE', 2, 32, NULL, 1, 3, 42, 11164, NULL, '', 38, '808/800/822/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11684, '2004-02-18 23:00:00+00', '2021-01-21 22:45:01.587036+00', 'Angus of Fife', 'ANGUS OF FIFE', 2, 32, 9999, 1, 3, 42, 3424, '2000-01-01', '', 53, '888  888  822  800', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (219, '1998-09-29 22:00:00+00', '2021-02-07 09:52:02.570879+00', 'Argyll Ludging, The', 'ARGYLL LUDGING', 3, 32, 9999, 1, 3, 42, 346, NULL, '', 66, '880  888  888  884', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (8728, '2001-11-20 23:00:00+00', '2021-03-14 23:18:36.602348+00', 'Auld Mahoun''s Revenge', 'AULD MAHOUNS REVENGE', 2, 40, 9999, 1, 3, 42, 550, '1996-01-01', '', 60, '800  888  866  888  866', 0, 1, 0, 0, 80);
INSERT INTO 'dance' VALUES (218, '1998-10-31 23:00:00+00', '2021-04-18 11:47:16.652561+00', 'Argyll is my Name', 'ARGYLL IS MY NAME', 2, 32, 9999, 1, 3, 42, 108, '1985-01-01', 'For the members of the London Argylls.', 66, '888  888  884  844', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (274, '1998-04-01 22:00:00+00', '2021-07-04 10:07:48.154263+00', 'Atsuko''s Wedding', 'ATSUKOS WEDDING', 1, 32, 9999, 1, 3, 42, 531, NULL, '', 44, '800  822  822  888', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (229, '1998-04-04 22:00:00+00', '2021-07-04 10:50:35.085603+00', 'Armadale Castle', 'ARMADALE CASTLE', 1, 32, 9999, 1, 3, 42, 227, '1987-01-01', '', 30, '422  844  800  880', 1, 1, 0, 1, 50);
INSERT INTO 'dance' VALUES (12665, '2006-01-02 23:00:00+00', '2021-07-30 06:24:25.288076+00', 'Annan Reel, The', 'ANNAN REEL', 1, 32, 9999, 2, 3, 17, 308, '2005-01-01', '', 47, '822  822  844  888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (329, '1997-08-25 22:00:00+00', '2014-04-30 23:23:39.069686+00', 'Ayr Promenade, The', 'AYR PROMENADE', 2, 32, 9999, 1, 4, 1, 146, NULL, 'Can be danced easily in a 3-couple set.', 55, '6660  6660  8880  8002', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (18543, '2018-08-28 18:43:01.82422+00', '2018-09-23 21:39:39.464894+00', 'Kessock Bridge', 'KESSOCK BRIDGE', 3, 32, NULL, 2, 3, 17, 3481, NULL, 'The Kessock Bridge spans the Moray Firth, linking Inverness with the Black Isle.', 91, '888/888/888/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11376, '2003-06-26 22:00:00+00', '2014-04-24 11:28:53.072373+00', 'Argyll Square, The', 'ARGYLL SQUARE', 2, 96, 9999, 4, 4, 3, 146, '2000-01-01', '', 60, '80  80  08  08   66  44  44  66   88  88  44  44  88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11216, '2003-02-24 23:00:00+00', '2018-04-03 00:07:31.855073+00', 'Back to Back', 'BACK TO BACK', 2, 32, 9999, 1, 3, 42, 2677, NULL, '', 42, '800  800  888  833', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (9543, '2001-12-16 23:00:00+00', '2014-04-30 23:23:39.355957+00', 'Balmullo Reel, The', 'BALMULLO REEL', 1, 88, 9999, 4, 4, 3, 146, '1997-01-01', '', 73, '8888  4444  8888  4444  8080  8080  0808  0808  8888  8888  8888', 0, 1, 1, 0, 72);
INSERT INTO 'dance' VALUES (195, '1997-08-28 22:00:00+00', '2019-04-20 08:37:40.011021+00', 'Anya''s Dance', 'ANYAS DANCE', 4, 96, 11, 4, 4, 3, 643, NULL, '', 100, '8888  8888  8888  8888  8888  8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (392, '1998-09-29 22:00:00+00', '2014-04-30 23:23:39.430616+00', 'Banks of Clyde, The', 'BANKS OF CLYDE', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 56, '888  888  800  880', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14425, '2012-05-05 08:26:48.742801+00', '2015-02-28 21:11:52.950454+00', 'Ayrshire Craig', 'AYRSHIRE CRAIG', 1, 32, 9999, 1, 3, 42, 1502, NULL, '', 58, '880  888  866  888', 0, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (8998, '2002-08-29 22:00:00+00', '2015-04-24 20:56:33.727889+00', 'BAMFAD, The', 'BAMFAD', 1, 32, 9999, 1, 3, 42, 550, '1999-01-01', '', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (353, '1998-10-15 22:00:00+00', '2016-03-06 18:57:12.348017+00', 'Baldovan Reel', 'BALDOVAN REEL', 1, 32, 9999, 1, 4, 1, 176, NULL, '', 48, '8660  8440  8440  8002', 1, 1, 1, 1, 48);
INSERT INTO 'dance' VALUES (364, '1997-08-28 22:00:00+00', '2016-12-06 20:10:37.832786+00', 'Ballater Reel, The', 'BALLATER REEL', 1, 32, 9999, 1, 2, 76, 394, NULL, 'Suited for Reel as well as Strathspey time (stated explicitly in the description of the dance).', 52, '80  88  88  80', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (11583, '2003-11-17 23:00:00+00', '2016-12-07 14:24:38.458579+00', 'Autumn Wind', 'AUTUMN WIND', 3, 32, 9999, 1, 3, 42, 2408, '2000-11-01', '', 66, '884  888  888  844', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (292, '1998-04-04 22:00:00+00', '2022-07-30 16:44:21.80263+00', 'Auld Friends Meet', 'AULD FRIENDS MEET', 3, 32, 9999, 1, 3, 42, 146, '1981-01-01', '', 43, '811  833  822  866', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (9042, '1999-06-09 22:00:00+00', '2022-10-04 14:39:40.024504+00', 'Ann Lindsey''s Strathspey', 'ANN LINDSEYS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2489, '1997-01-01', 'The notes say this was devised " by Charles Snowdon for his wife Ann Lindsey and danced for the first time at their wedding in Madison in 1997."', 44, '880  808  800  880', 1, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (433, '2002-04-29 22:00:00+00', '2014-04-30 23:23:39.705175+00', 'Beacon On The Law', 'BEACON ON THE LAW', 1, 32, 9999, 2, 3, 17, 680, NULL, 'The volcanic cone, around which our town of Dundee is built, is called the Law" which is the Gaelic term for "hill". A beacon was lit upon the Law to warn of the approach of the Spanish Armada."', 67, '888  888  800  800', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (11556, '2003-10-20 22:00:00+00', '2018-04-03 00:07:32.072637+00', 'Banchory Reel, The', 'BANCHORY REEL', 1, 32, 9999, 1, 3, 42, 394, '2003-06-01', 'Written summer 2003 by John Trew to commemorate the visit to the Kingston ON area, of the Banchory Strathspey & Reel Society.', 62, '800  888  888  888', 0, 0, 0, 0, 83);
INSERT INTO 'dance' VALUES (7387, '1997-04-04 22:00:00+00', '2019-03-08 17:12:00.956634+00', 'Dunblane Reel, The', 'DUNBLANE REEL', 1, 32, 9999, 1, 4, 11, 930, '1995-06-01', '', 72, '8008/2882/8448/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7351, '2002-04-19 22:00:00+00', '2019-03-08 18:04:01.285223+00', 'Bill Little''s Strathspey', 'BILL LITTLES STRATHSPEY', 3, 32, 9999, 1, 4, 1, 146, NULL, '', 75, '8080  8888  8080  8888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (9288, '2000-01-16 23:00:00+00', '2020-02-10 22:10:55.105693+00', 'Banjo Patterson', 'BANJO PATTERSON', 1, 32, 9999, 1, 3, 42, 501, '1991-01-01', '', 56, '880/866/866/844', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (327, '1997-11-18 23:00:00+00', '2020-03-28 10:18:04.182323+00', 'Axum Reel, The', 'AXUM REEL', 3, 32, 9999, 1, 4, 54, 9998, NULL, '', 100, '8888  8888  8888  8888', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (10546, '2002-08-05 22:00:00+00', '2021-02-07 10:49:02.475439+00', 'Beekeeper''s Medley, The', 'BEEKEEPERS MEDLEY', 4, 64, 17, 4, 4, 13, 2980, NULL, '', 100, '8888  8888  8888  8888', 0, 1, 0, 0, 43);
INSERT INTO 'dance' VALUES (289, '1998-11-07 23:00:00+00', '2020-07-17 16:04:26.604127+00', 'Auld Alliance, The', 'AULD ALLIANCE', 1, 32, 9999, 1, 4, 1, 450, NULL, '', 72, '6222  8888  8888  0088', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (13499, '2009-11-21 23:00:00+00', '2020-08-24 22:28:22.122093+00', 'Aye Afloat', 'AYE AFLOAT', 3, 48, 9999, 1, 4, 2, 1269, '2007-01-01', '', 83, '4884  4884  4884  4884  8888  8888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (13720, '2011-07-09 22:00:00+00', '2020-09-19 20:55:42.884318+00', 'Balmaha', 'BALMAHA', 3, 32, NULL, 1, 3, 42, 175, NULL, 'Balmaha is delightfully situated on the shores of Loch Lomond', 56, '880/880/844/888', 0, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (12021, '2005-02-13 23:00:00+00', '2020-09-15 20:32:55.352226+00', 'Barop Wedding', 'BAROP WEDDING', 2, 32, 9999, 2, 3, 18, 3507, '2003-01-01', 'See <<http://www.strathspey.org/lists/strathspey%40strathspey.org/m/40620/>> and <<http://www.strathspey.org/lists/strathspey%40strathspey.org/m/40623/>>.', 75, '800  888  888  880', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (13709, '2011-07-04 22:00:00+00', '2021-01-01 18:40:03.731975+00', 'Avalanche Reel, The', 'AVALANCHE REEL', 1, 32, NULL, 1, 4, 5, 3095, '1995-01-01', 'Devised: 1995', 69, '8444  6840  8888  8604', 0, 1, 0, 0, 68);
INSERT INTO 'dance' VALUES (9113, '1999-08-08 22:00:00+00', '2021-03-01 18:52:13.675218+00', 'Bayside Twenty-First', 'BAYSIDE TWENTYFIRST', 3, 40, 9999, 1, 4, 1, 2605, '1999-01-01', '', 75, '8800  8888  8888  8888  8000', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (9082, '1999-07-25 22:00:00+00', '2021-03-02 22:31:56.143777+00', 'Ayrshire Lasses', 'AYRSHIRE LASSES', 3, 32, 9999, 3, 5, 7, 175, NULL, '', 68, '80800  88888  82842  84844', 1, 1, 1, 1, 67);
INSERT INTO 'dance' VALUES (9076, '1999-07-25 22:00:00+00', '2021-03-06 12:05:19.500799+00', 'Ayrshire Wheelie Bin, The', 'AYRSHIRE WHEELIE BIN', 2, 32, 9999, 1, 3, 42, 2626, NULL, '', 53, '888  646  808  822', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (9002, '1999-07-27 22:00:00+00', '2021-03-06 22:25:55.297148+00', 'Bartons'' Reel, The', 'BARTONS REEL', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 53, '808  822  888  844', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (8111, '2001-05-03 22:00:00+00', '2021-03-22 01:01:56.521147+00', 'Autumn Posy, An', 'AUTUMN POSY', 3, 32, 9999, 1, 2, 76, 59, '1989-01-01', '', 62, '66  88  66  80', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14247, '2011-09-02 22:00:00+00', '2021-03-27 18:59:39.469074+00', 'Balmoral Castle', 'BALMORAL CASTLE', 3, 32, NULL, 1, 4, 1, 10478, '1998-01-01', 'Derived from the Balmoral Strathspey by switching [9-16] with [17-24]; this dance flows better.', 94, '8888  8888  8888  8088', 0, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (312, '1999-08-06 22:00:00+00', '2021-03-27 21:46:30.269401+00', 'Australian Ladies, The', 'AUSTRALIAN LADIES', 1, 32, 9999, 1, 3, 42, 62, '1967-05-01', 'Devised in May 1967 in New Zealand by Bob Campbell of Canada for Jean Conway, Elma See, Lorraine Dyall, and Margaret Gray of the Newcastle (Australia) Colleges Strathspey and Reel Club.', 56, '804  840  888  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (340, '1998-09-29 22:00:00+00', '2021-07-03 14:18:20.224271+00', 'Back to the Fireside', 'BACK TO THE FIRESIDE', 1, 32, 9999, 1, 3, 42, 146, NULL, 'Inscribed to lhe T.A.C.', 52, '808  864  880  844', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (335, '1998-10-31 23:00:00+00', '2021-07-03 14:21:14.887636+00', 'Back o'' Bennachie, The', 'BACK O BENNACHIE', 1, 32, 9999, 1, 2, 76, 116, NULL, '', 47, '84  84  66  80', 1, 1, 0, 0, 68);
INSERT INTO 'dance' VALUES (306, '1997-04-03 22:00:00+00', '2021-07-04 09:34:17.038422+00', 'Auld Robin Gray', 'AULD ROBIN GRAY', 3, 32, 9999, 1, 3, 42, 129, '1966-01-01', '', 47, '800  840  844  888', 1, 1, 0, 1, 62);
INSERT INTO 'dance' VALUES (7349, '2001-06-13 22:00:00+00', '2019-09-01 11:08:42.977649+00', 'Beal''s Reel', 'BEALS REEL', 1, 40, 9999, 3, 5, 16, 480, '1980-01-01', '"I wrote it in 1980 and modified it slightly in 1991. The tune is Whimsey ; and Beal enjoys Dorothy Sayers’ Peter Wimsey books, puns, and the three spellings of whimsy."', 48, '84400  88800  80440  80880  80008', 1, 1, 1, 1, 48);
INSERT INTO 'dance' VALUES (518, '1997-08-25 22:00:00+00', '2014-04-30 23:23:40.131247+00', 'Birkenside', 'BIRKENSIDE', 3, 32, 9999, 1, 2, NULL, 146, NULL, '', 52, '88  44  80  88', 0, 0, 0, 0, 75);
INSERT INTO 'dance' VALUES (8294, '1998-01-12 23:00:00+00', '2015-02-28 21:29:26.191561+00', 'Black Ewe, The', 'BLACK EWE', 3, 32, 9999, 1, 3, 42, 2018, NULL, '', 53, '440  448  888  866', 1, 1, 1, 0, 70);
INSERT INTO 'dance' VALUES (11587, '2003-11-29 23:00:00+00', '2015-10-27 19:00:55.305792+00', 'Beach Dancer', 'BEACH DANCER', 2, 32, 9999, 1, 3, 42, 411, '2003-01-01', 'For Margaret Blackhall, a teacher at Kamo Club who lives on the coast at Ngunguru.

', 50, '840  880  840  888', 1, 1, 1, 1, 64);
INSERT INTO 'dance' VALUES (8722, '2001-05-21 22:00:00+00', '2016-06-03 13:36:29.454195+00', 'Birgit Röhricht''s Strathspey', 'BIRGIT ROHRICHTS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 228, '1998-01-01', '', 57, '800  888  881 888', 0, 0, 0, 0, 76);
INSERT INTO 'dance' VALUES (13577, '2010-05-30 22:00:00+00', '2016-12-14 22:50:51.170833+00', 'Bill Clement MBE', 'BILL CLEMENT MBE', 2, 32, 9999, 1, 3, 42, 515, '2008-11-01', '', 50, '800/844/844/888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (15722, '2015-01-07 15:02:01.285638+00', '2018-04-03 00:08:10.640088+00', 'Pine Canyon', 'PINE CANYON', 3, 40, 9999, 1, 3, 42, 3549, '2005-01-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (410, '1999-01-06 23:00:00+00', '2017-07-07 13:02:11.982583+00', 'Barley Bree', 'BARLEY BREE', 2, 40, 9999, 1, 4, 1, 9998, NULL, '', 79, '8888  8888  16 2 2 2  8888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (13593, '2010-09-15 22:00:00+00', '2017-07-12 14:32:12.186307+00', 'Birls Allowed', 'BIRLS ALLOWED', 2, 32, 9999, 1, 3, 42, 10613, '2010-02-01', 'Note:- Unofficial Variation (but with the approval of the deviser Alex Taylor) for bars 17-24 :- 

AS 3s+2s Set & Rotate ALSO 1s full wide graceful RH turn + LH back OR 1s birl RH / then LH.

Source:  Dance Programme, Stirling Branch Summer Dancing, 10th June 2017.   Nicol McLaren.



"Birls Allowed" was issued as a single sheet with music and was given out at a dance run by Stirling Castle Country Dance Club in 2011.



', 56, '844  888  088  880', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (541, '1998-09-29 22:00:00+00', '2018-04-03 00:07:33.582699+00', 'Black Dance, The', 'BLACK DANCE', 1, 32, 9999, 1, 3, 42, 453, '1772-01-01', '', 31, '800  602  808  602', 0, 0, 0, 0, 41);
INSERT INTO 'dance' VALUES (564, '1997-08-24 22:00:00+00', '2014-04-30 23:23:40.591935+00', 'Blairmormond', 'BLAIRMORMOND', 3, 32, 9999, 1, 2, NULL, 108, '1994-01-01', '', 60, '80 88  88  88', 0, 0, 0, 0, 87);
INSERT INTO 'dance' VALUES (18545, '2018-08-28 20:01:02.119408+00', '2018-09-24 10:04:07.959599+00', 'Ralph Allen''s Fancy', 'RALPH ALLENS FANCY', 1, 32, NULL, 1, 3, 42, 11697, NULL, 'Ralph Allen (1693-1764) owned the stone quarries of Bath and supplied the architect John Wood with the stone that gives the city its defining character.', 50, '440/880/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (480, '1998-09-29 22:00:00+00', '2014-04-30 23:23:39.992681+00', 'Berwick Johnnie', 'BERWICK JOHNNIE', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 41, '880  800  880  822', 0, 1, 1, 0, 54);
INSERT INTO 'dance' VALUES (488, '2002-03-02 23:00:00+00', '2014-07-25 22:48:16.158901+00', 'Best Man, The', 'BEST MAN', 1, 32, 9999, 1, 3, 42, 227, '1992-10-21', 'Level: intermediate



For Tom Chisholm, with many thanks for a great time.  Tom was Chairman of The Thistle Club for a number of years.  He lived in Best, a village near Eindhoven.



When danced to recorded music: Sandy Nixon''s Repeat Prescription, The Cuckoo Clock.', 53, '822/888/888/800', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (18278, '2018-04-06 21:33:41.317037+00', '2018-04-06 21:34:19.602548+00', 'Labyrinth, The', 'LABYRINTH', 1, 32, NULL, 3, 5, 16, 2682, '2016-09-28', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18641, '2018-09-18 22:18:30.937481+00', '2018-09-24 18:56:18.430667+00', 'One Good Jig', 'ONE GOOD JIG', 2, 32, NULL, 1, 3, 42, 11712, '2014-12-01', 'Devised by a committee: David Michael, Sarah Binder, Ron Jackson, Susan Jackson, Scott Kalberer, Charlotte Baldwin, John Bonham, Linda Lieberman, Gary Lieberman,', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (610, '1998-11-11 23:00:00+00', '2014-04-30 23:23:40.921538+00', 'Bob of Fettercairn, The', 'BOB OF FETTERCAIRN', 1, 24, 9999, 1, 2, NULL, 263, '1796-01-01', '', 57, '88  80  88', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (570, '1998-11-14 23:00:00+00', '2020-08-02 23:24:46.74+00', 'Blervie Castle', 'BLERVIE CASTLE', 3, 32, 9999, 1, 4, 2, 175, '1971-01-01', '', 94, '8888  8888  8888  8448', 1, 1, 1, 0, 93);
INSERT INTO 'dance' VALUES (10689, '2002-07-21 22:00:00+00', '2020-09-11 08:51:47.446385+00', 'Bev''s Delight', 'BEVS DELIGHT', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', 44, '888  800  800  880', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (11198, '2003-02-16 23:00:00+00', '2020-09-14 15:46:13.868601+00', 'Black Bear, The', 'BLACK BEAR', 1, 32, 9999, 1, 3, 42, 3327, NULL, '', 47, '880  822  844  844', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (14270, '2011-10-15 22:00:00+00', '2020-09-27 08:19:51.390112+00', 'Bernie Hewitt''s Reel', 'BERNIE HEWITTS REEL', 1, 32, NULL, 1, 2, 76, 1445, NULL, 'For Bernie Hewitt for much needed and well appreciated musical support.', 54, '68  24  42  88  80', 0, 1, 0, 0, 78);
INSERT INTO 'dance' VALUES (583, '1998-07-08 22:00:00+00', '2020-10-13 18:18:02.536875+00', 'Blooms of Ben Lawers', 'BLOOMS OF BEN LAWERS', 3, 32, 9999, 1, 100, 11, 108, '1975-02-02', '', 81, '8888  0880  4884  8888', 0, 1, 0, 0, 81);
INSERT INTO 'dance' VALUES (18106, '2017-12-11 12:02:22.291242+00', '2020-11-13 10:02:48.597549+00', 'DG Dancers'' Celebration', 'DG DANCERS CELEBRATION', 2, 32, NULL, 5, 2, 54, 1582, '2017-01-01', 'A dance for the DG Dancers in Dumfries in the 70th Anniversary Year of the RSCDS, Dumfries Branch.', 62, '84/48/80/08', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10580, '2002-07-21 22:00:00+00', '2021-01-10 14:13:48.512674+00', 'Australian Laddie', 'AUSTRALIAN LADDIE', 4, 64, 17, 4, 4, NULL, 2961, '2002-01-01', '', 100, '8 times 8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11373, '2003-06-26 22:00:00+00', '2021-01-25 15:22:31.978093+00', 'Bea''s Delight', 'BEAS DELIGHT', 1, 32, 9999, 1, 3, 42, 2525, '2000-01-01', '', 50, '770  888  707  822', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (11109, '2002-12-16 23:00:00+00', '2021-01-30 10:53:29.489484+00', 'Blackadder House', 'BLACKADDER HOUSE', 3, 32, 9999, 1, 3, 42, 2672, NULL, '', 45, '800  832  823  888', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (11108, '2002-12-16 23:00:00+00', '2021-01-30 10:55:15.129501+00', 'Blackadder Jig, The', 'BLACKADDER JIG', 2, 32, 9999, 1, 3, 42, 1502, NULL, '', 44, '800  808  880  880', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (9022, '2001-10-22 22:00:00+00', '2021-03-06 21:50:45.131589+00', 'Beechwood Strathspey, The', 'BEECHWOOD STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2600, NULL, '', 47, '840  888  844  800', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (7350, '1998-04-24 22:00:00+00', '2021-03-27 11:20:27.362939+00', 'Beeswing', 'BEESWING', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 50, '800  888  800  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (430, '1998-09-29 22:00:00+00', '2021-06-22 19:32:39.413745+00', 'Bawk, The', 'BAWK', 2, 32, 9999, 1, 3, 42, 1977, NULL, '', 31, '620  800  844  800', 1, 1, 0, 1, 41);
INSERT INTO 'dance' VALUES (571, '1998-09-29 22:00:00+00', '2021-07-01 22:55:50.102652+00', 'Bleu Ribbon, The', 'BLEU RIBBON', 1, 40, 9999, 1, 3, 42, 339, '1749-01-01', '', 27, '400  400  800  800  866', 1, 1, 1, 1, 36);
INSERT INTO 'dance' VALUES (545, '1998-04-05 22:00:00+00', '2021-07-02 10:49:08.54137+00', 'Black House, The', 'BLACK HOUSE', 2, 32, 9999, 1, 2, 76, 227, '1991-04-03', 'Level: beginners/intermediate



Suitable recorded music:  "Edinburgh Jigs"  in "A Dancer''s Miscellany Vol I", track 7 by Muriel Johnstone''s Band.

', 52, '80  80  88  88', 1, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (497, '1998-11-16 23:00:00+00', '2021-07-02 12:19:05.147581+00', 'Betty''s Wedding', 'BETTYS WEDDING', 4, 32, 1, 1, 3, 42, 87, NULL, '', 50, '800  844  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (475, '1997-04-03 22:00:00+00', '2021-07-02 12:44:01.989193+00', 'Beneath The Pines', 'BENEATH THE PINES', 3, 32, 9999, 1, 3, 42, 351, NULL, '', 69, '888/888/888/880', 1, 1, 0, 1, 91);
INSERT INTO 'dance' VALUES (471, '2002-02-12 23:00:00+00', '2021-07-02 14:03:10.890169+00', 'Ben Macdhui', 'BEN MACDHUI', 2, 32, 9999, 1, 3, 42, 244, '1990-01-01', '', 62, '888  880  844  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (442, '1998-10-31 23:00:00+00', '2021-07-02 14:10:57.949134+00', 'Bedrule', 'BEDRULE', 3, 32, 9999, 1, 3, 42, 152, '1984-01-01', 'The slightly mystifying name of this dance comes from a village in the Scottish borders, near Hawick and Jedburgh. The late <<ddp:Grant, Betty>> of Toronto, Ontario, dedicated the dance to her great-great-grandmother Elizabeth Turnbull Dickson, who came from Bedrule and emigrated to Canada in 1834.

', 63, '881  888  844  888', 1, 1, 1, 1, 84);
INSERT INTO 'dance' VALUES (615, '1997-04-03 22:00:00+00', '2014-04-30 23:23:40.978256+00', 'Bobby Brown''s Canadian Breakdown', 'BOBBY BROWNS CANADIAN BREAKDOWN', 1, 32, 9999, 4, 4, 13, 268, NULL, 'It should really be obvious to Scottish country dancers but in order to

avoid confusion especially in the younger generation it bears repeating that

this dance gets its name from <<ddp:Brown, Bobby>>, the late Canadian

Scottish dance band leader, not from

<<http://en.wikipedia.org/wiki/Bobby_Brown|Bobby Brown>>, the R&B/soul singer

and ex-husband of the late Whitney Houston.

', 84, '8484  4848  7777  8888', 1, 1, 1, 1, 84);
INSERT INTO 'dance' VALUES (608, '1998-11-07 23:00:00+00', '2018-04-03 00:07:34.525096+00', 'Bob o'' Dowally, The', 'BOB O DOWALLY', 3, 32, 9999, 1, 3, 42, 9998, '1760-01-01', '', 44, '440  448  808  880', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (462, '1998-11-14 23:00:00+00', '2016-02-08 15:19:45.336998+00', 'Belle of Bon Accord, The', 'BELLE OF BON ACCORD', 3, 32, 9999, 1, 4, 1, 108, '1981-01-01', '', 69, '8484  8080  8888  8080', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (611, '1998-09-29 22:00:00+00', '2017-07-07 13:57:29.325118+00', 'Bob Sanders', 'BOB SANDERS', 2, 40, 9999, 1, 3, 42, 468, '1758-02-02', '', 62, '888  888  888  888  800', 1, 1, 1, 1, 86);
INSERT INTO 'dance' VALUES (18640, '2018-09-18 22:13:36.612458+00', '2018-09-24 22:02:04.479656+00', 'Mrs. Virginia Cunning''s Strathspey', 'MRS VIRGINIA CUNNINGS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 3617, '1997-07-01', 'We had been dancing "Minister on the Loch" and Virginia loved the "turn 1½" in strathspey time. This was for her birthday in 1997', 50, '888/800/844/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18657, '2018-09-24 22:08:51.718408+00', '2018-09-25 20:41:45.177081+00', 'Abel''s Welcome', 'ABELS WELCOME', 1, 32, NULL, 1, 4, 1, 1445, '2018-01-01', 'To commemorate the arrival of our grandson Abel', 53, '8400/8088/8800/8800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18546, '2018-08-28 20:08:20.486059+00', '2018-09-27 13:22:37.464691+00', 'Sulis Minerva', 'SULIS MINERVA', 3, 32, NULL, 2, 3, 18, 11698, NULL, 'Sulis Minerva was the goddess of the thermal springs in Bath. The Roman Temple beside the springs was dedicated to her. She was believed to have the power to heal, and to right wrongs.', 77, '888/404/888/828', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18682, '2018-10-02 00:43:37.367208+00', '2018-10-02 00:43:37.367208+00', 'Bizzy Bee Reel, The', 'BIZZY BEE REEL', 1, 32, NULL, 1, 3, 42, 2766, '2012-04-01', 'This dance was written for a friend of mine, Paul Grzybek, who died way too young. I first met him at his shop named Bizzy Bee where he bought and sold used CDs and repaired vacuum cleaners.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (594, '1998-11-03 23:00:00+00', '2019-02-04 17:50:03.659177+00', 'Blue Mess Jacket, The', 'BLUE MESS JACKET', 3, 32, 9999, 1, 4, 1, 176, NULL, '', 59, '8800  8440  8004  8888', 0, 1, 1, 0, 59);
INSERT INTO 'dance' VALUES (8658, '1999-07-24 22:00:00+00', '2019-03-06 11:13:19.831679+00', 'Bo-Bo''s Jig', 'BOBOS JIG', 2, 32, 9999, 1, 4, 1, 2101, '1996-01-01', '', 62, '8228  2882  8440  8448', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (754, '1998-09-29 22:00:00+00', '2018-07-21 05:52:55.608234+00', 'Braes of Tulliemet, The', 'BRAES OF TULLIEMET', 3, 32, 9999, 1, 3, 42, 9998, NULL, '"A Perthshire dance. Collected in the Borders".', 44, '800  804  844  866', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (8978, '1999-03-14 23:00:00+00', '2014-04-30 23:23:41.073911+00', 'Bonnie Bernard''s B.Day Bash', 'BONNIE BERNARDS BDAY BASH', 1, 32, 9999, 1, 4, 1, 2582, '1999-01-01', '', 44, '4440  4440  8000  8888', 1, 1, 1, 0, 43);
INSERT INTO 'dance' VALUES (15577, '2014-08-26 19:26:10.682719+00', '2018-08-31 13:49:25.384362+00', 'Bruntsfield Links, The', 'BRUNTSFIELD LINKS', 2, 32, NULL, 1, 4, 1, 550, '2002-06-01', 'Devised for Sophia Marriage and Jonathan Pryce in honour of their wedding in St Martin of Tours Episcopal Church in Edinburgh on the 6th of July, 2002 and performed at the ensuing celebrations in The Hub. With much love and best wishes for the future.



Sophi and Jonathan both lived in Bruntsfield throughout their courtship, and bought a house together in Bruntsfield as their first marital home. 





Eric''s crib was derived from the video.', 62, '8000/8800/8880/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14014, '2011-08-25 22:00:00+00', '2014-04-30 23:23:41.270932+00', 'Bonnie Lass with the Curly Hair, The', 'BONNIE LASS WITH THE CURLY HAIR', 1, 32, NULL, 1, 3, 42, 10428, '2007-06-17', '', 70, '864  888  888  888', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (679, '1998-07-08 22:00:00+00', '2014-04-30 23:23:41.391505+00', 'Bonnie Wells, The', 'BONNIE WELLS', 3, 32, 9999, 1, 100, 2, 313, '1992-01-01', '', 87, '8888  8888  8888  8008', 1, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (635, '1997-08-24 22:00:00+00', '2018-04-02 23:56:33.095995+00', 'Bonnie Banchory', 'BONNIE BANCHORY', 1, 32, 9999, 1, 3, 42, 108, '1970-01-01', '', 62, '888  888  880  880', 1, 1, 0, 1, 83);
INSERT INTO 'dance' VALUES (8142, '1998-10-04 22:00:00+00', '2014-04-30 23:23:41.659421+00', 'Boston Two Step', 'BOSTON TWO STEP', 50, 16, 9999, 5, 1, NULL, 1991, NULL, '', 100, '88 88', 0, 0, 0, 0, 100);
INSERT INTO 'dance' VALUES (773, '1998-09-29 22:00:00+00', '2015-04-15 21:28:43.877748+00', 'Braw Sir John', 'BRAW SIR JOHN', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 59, '800/888/888/866', 0, 1, 1, 0, 79);
INSERT INTO 'dance' VALUES (670, '1998-11-16 23:00:00+00', '2020-05-15 13:12:17.372886+00', 'Bonnie Shira Glen', 'BONNIE SHIRA GLEN', 4, 32, 1, 1, 4, 1, 87, NULL, '', 72, '8448/6446/4884/6486', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (721, '1997-05-17 22:00:00+00', '2020-08-29 12:41:05.306914+00', 'Bothkennar', 'BOTHKENNAR', 3, 32, 9999, 1, 4, 1, 6, NULL, '', 52, '4141  1414  8888  8222', 0, 1, 0, 0, 51);
INSERT INTO 'dance' VALUES (7105, '2000-02-20 23:00:00+00', '2021-03-30 21:15:10.160604+00', 'Whistling Wind, The', 'WHISTLING WIND', 1, 32, 9999, 1, 3, 42, 502, '1984-01-01', 'The 1990 edition of RSCDS Book 36 misspelt Elizabeth''s name with only one S.', 50, '800  844  888  844', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (950, '1997-04-03 22:00:00+00', '2020-08-02 23:44:03.440764+00', 'Caller Herrin''', 'CALLER HERRIN', 1, 40, 9999, 1, 3, 42, 129, NULL, '', 65, '880/880/888/888/888', 1, 1, 1, 1, 86);
INSERT INTO 'dance' VALUES (11091, '2002-12-05 23:00:00+00', '2020-09-14 15:41:53.451569+00', 'Bonnie Dunoon', 'BONNIE DUNOON', 2, 32, 9999, 2, 3, 17, 142, NULL, '', 56, '840  840  880  808', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (11913, '2004-11-23 23:00:00+00', '2021-01-18 11:16:20.932262+00', 'Bonny Water, The', 'BONNY WATER', 3, 48, 9999, 1, 4, 1, 2941, NULL, '', 86, '8484  8888  8888  8888  8222  8888', 1, 1, 1, 1, 86);
INSERT INTO 'dance' VALUES (547, '1997-08-28 22:00:00+00', '2021-07-02 09:23:49.030684+00', 'Black Magic', 'BLACK MAGIC', 2, 32, 9999, 1, 3, 42, 653, NULL, 'In this dance all couples start on the opposite side, and 4c is leading couple, starting from the bottom.  The final positions are 1243, the normal situation where dancing couple and their neighbours switch places.  In fact this is just a normal 3C/4L dance turned round and starting from the bottom.  That is why the progression is given here as (2,1,3).



The notes say "this dance is suitable for Occasions such as Hallowe''en or Friday 13th."', 56, '008  088  888  888', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (9562, '2001-11-21 23:00:00+00', '2021-02-22 11:31:39.937523+00', 'Blackwater Reel, The', 'BLACKWATER REEL', 1, 32, 9999, 1, 3, 42, 831, '1997-01-01', '', 75, '888  888  888  888', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (559, '1998-11-03 23:00:00+00', '2021-05-26 12:49:38.240962+00', 'Blacksmith of Elgin, The', 'BLACKSMITH OF ELGIN', 2, 48, 9999, 1, 3, 42, 698, NULL, '', 58, '888  888  864  444  468  844', 1, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (8102, '2002-12-16 23:00:00+00', '2021-03-22 01:16:07.095086+00', 'Bonnie Gallowa''', 'BONNIE GALLOWA', 3, 40, 9999, 1, 4, 1, 433, '1997-01-01', '', 79, '8080  8888  8888  8222  8888', 1, 1, 1, 1, 78);
INSERT INTO 'dance' VALUES (9455, '2002-03-02 23:00:00+00', '2021-04-05 21:32:19.831331+00', 'Bountree Reel, The', 'BOUNTREE REEL', 1, 48, 9999, 4, 4, 46, 108, '1999-01-01', '', 92, '8484  8484  8888  8888  8888  8888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (700, '2001-12-16 23:00:00+00', '2021-06-29 09:45:11.520172+00', 'Border Meeting', 'BORDER MEETING', 2, 32, 9999, 5, 2, 76, 146, NULL, '', 75, '44  44  88  88', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (650, '1998-09-30 22:00:00+00', '2021-07-01 09:08:03.375503+00', 'Bonnie Geordie''s Wig', 'BONNIE GEORDIES WIG', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 60, '88  88  80  88', 1, 1, 0, 1, 87);
INSERT INTO 'dance' VALUES (644, '2002-03-25 23:00:00+00', '2021-07-01 09:14:12.445248+00', 'Bonnie Charlie', 'BONNIE CHARLIE', 1, 32, 9999, 1, 4, 1, 705, '1985-01-01', 'Devised to teach reels of four. The title refers to Bonnie Prince Charlie.



In the notes, Ed Stern says, "The dance is a very forgiving dance for beginners, and they will get through it successfully even if they face the wrong way to begin the reel of four."', 62, '8888/8000/8888/8000', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (743, '1999-08-06 22:00:00+00', '2014-04-30 23:23:41.750121+00', 'Braes of Breadalbane, The', 'BRAES OF BREADALBANE', 3, 32, 9999, 1, 3, 42, 455, '1795-01-01', 'Breadalbane, from the Gaelic *bràghad Albainn* (»the upper part of

Alba (Scotland)«) is an area in the southern Highlands and today

mostly part of the »Loch Lomond and the Trossachs« national park.

', 50, '800  844  888  880', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (745, '1999-08-06 22:00:00+00', '2014-04-30 23:23:41.765109+00', 'Braes of Busby, The', 'BRAES OF BUSBY', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 62, '800  888  888  888', 0, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (15723, '2015-01-07 15:07:21.168648+00', '2015-01-07 15:07:21.168648+00', 'South Gate', 'SOUTH GATE', 3, 32, 9999, 1, 4, 11, 3549, '2004-06-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (640, '2001-07-19 22:00:00+00', '2016-08-28 06:54:18.117194+00', 'Bonnie Breist Knots, The', 'BONNIE BREIST KNOTS', 3, 32, 9999, 1, 3, 42, 9998, NULL, 'The original music is written as 64 bars of Strathspey in 2/4 time, with 2 bars per step.  It is more convenient to read this as a normal 32-bar Strathspey in 4/4 time.



Collected in Roxburghshire', 44, '440  840  844  866', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (14813, '2013-04-29 13:44:10.532505+00', '2015-08-18 15:06:45.965563+00', 'Braiding Reel, The', 'BRAIDING REEL', 1, 32, NULL, 1, 3, 42, 3562, NULL, '', 59, '811  411   12 12 12   888', 0, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (699, '1998-04-05 22:00:00+00', '2017-02-28 08:52:57.415367+00', 'Border Lassies', 'BORDER LASSIES', 2, 32, 9999, 1, 3, 42, 146, '1985-01-01', '', 50, '844  844  822  866', 1, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (682, '1998-09-29 22:00:00+00', '2017-07-07 13:20:01.405844+00', 'Bonniest Lass in all the World, The', 'BONNIEST LASS IN ALL THE WORLD', 3, 40, 9999, 1, 3, 42, 466, '1751-01-01', '', 42, '840  800  880  888  800', 0, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (616, '1997-04-03 22:00:00+00', '2018-04-03 00:07:34.475228+00', 'Bobby Crowe''s Reel', 'BOBBY CROWES REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 62, '840  888  848  888', 0, 0, 0, 0, 83);
INSERT INTO 'dance' VALUES (816, '1998-11-12 23:00:00+00', '2018-04-26 22:43:56.46814+00', 'Brisk Young Lad, The', 'BRISK YOUNG LAD', 2, 48, 9999, 3, 5, 16, 108, '1984-01-01', '', 84, '16,16,4,16,16  44844  44844  88888  88888', 0, 1, 1, 0, 68);
INSERT INTO 'dance' VALUES (13355, '2009-08-02 22:00:00+00', '2018-03-10 18:34:43.814409+00', 'Kathleen McAdam''s Scroll', 'KATHLEEN MACADAMS SCROLL', 2, 32, 9999, 1, 3, 42, 2701, '2007-01-01', 'Written to celebrate Kathleen McAdam who received the Scroll of Honour from the Royal Scottish Country Dance Society in 2007. Kathleen’s patient teaching, encouragement, and infectious good humor have enriched the San Francisco branch and Scottish dancing worldwide. For many years she has taught a youth class and this dance is intended to be suitable for young dancers.



One of Kathleen’s favorite figures is hands round and back due to its sociability. 

Those who know her will recall that her talk-throughs for dances are sometimes 8 bars short until she remembers rights and lefts. Tongue firmly planted in cheek, I’ve included rights and lefts here. But Kathleen, don’t worry, only the corners dance it; the 1s don’t have to remember rights and lefts at all.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10650, '2002-07-21 22:00:00+00', '2014-04-30 23:23:41.960972+00', 'Brecon in March', 'BRECON IN MARCH', 1, 40, 9999, 4, 5, 16, 3165, NULL, '', 70, '84044  80404  88080  88888  88888', 0, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (739, '1999-08-06 22:00:00+00', '2018-12-16 17:21:13.300376+00', 'Braes of Balluder, The', 'BRAES OF BALLUDER', 1, 32, 9999, 1, 3, 42, 1977, NULL, '', 44, '840/800/844/866', 0, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (849, '2001-11-26 23:00:00+00', '2014-04-30 23:23:42.523486+00', 'Buchan Gate', 'BUCHAN GATE', 1, 32, 9999, 5, 2, NULL, 146, NULL, '', 100, '88  88  88  88', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (9169, '2000-04-11 22:00:00+00', '2014-04-30 23:23:42.628297+00', 'Burns Night', 'BURNS NIGHT', 2, 32, 9999, 1, 2, NULL, 1061, '1998-01-01', '', 60, '66  66  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (13686, '2011-06-14 22:00:00+00', '2014-04-30 23:23:42.643401+00', 'Burntisland Jig, The', 'BURNTISLAND JIG', 2, 32, NULL, 3, 5, 7, 27, NULL, 'There are five islands in the Firth of Forth: May, Inchkeith, Inchmickery, Inchcolm, Inchgarvie.  It is a small step to a five couple dance.  There is one ''island'' however whcih is not an ''island'' - Burntisland.  Hence the name of the dance.', 67, '80800  88888  82842  84844', 1, 0, 1, 1, 67);
INSERT INTO 'dance' VALUES (15535, '2014-07-14 11:21:01.445511+00', '2014-07-14 11:21:01.445511+00', 'Orchy''s Walkies', 'ORCHYS WALKIES', 2, 40, NULL, 4, 6, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (753, '1998-09-29 22:00:00+00', '2020-05-13 19:08:02.053611+00', 'Braes of Mellinish, The', 'BRAES OF MELLINISH', 3, 32, 9999, 1, 2, 76, 9998, NULL, '', 62, '86  88  88  84', 1, 1, 1, 1, 90);
INSERT INTO 'dance' VALUES (11561, '2003-10-30 23:00:00+00', '2021-01-23 11:40:21.410285+00', 'Brunswick Hussars, The', 'BRUNSWICK HUSSARS', 2, 32, 9999, 1, 3, 42, 1445, NULL, '', 55, '555  888  844  844', 0, 1, 0, 0, 73);
INSERT INTO 'dance' VALUES (11260, '2003-03-17 23:00:00+00', '2020-05-18 22:56:54.418071+00', 'British Man o'' War', 'BRITISH MAN O WAR', 1, 32, 9999, 5, 2, 30, 9998, NULL, 'E-crib derived from the video.', 75, '88/08/80/88', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (10545, '2002-08-05 22:00:00+00', '2021-02-07 10:51:58.941128+00', 'Breakish Postie, The', 'BREAKISH POSTIE', 3, 32, 9999, 1, 4, 1, 2980, NULL, '', 47, '8222  8222  8800  8044', 1, 1, 1, 1, 46);
INSERT INTO 'dance' VALUES (9289, '2002-02-28 23:00:00+00', '2021-02-26 13:57:19.853302+00', 'Betty Burke', 'BETTY BURKE', 2, 32, 9999, 1, 3, 42, 501, '1993-01-01', '', 47, '800  822  844  888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (8812, '2001-11-20 23:00:00+00', '2021-03-14 20:21:07.419656+00', 'Brodie''s Fancy', 'BRODIES FANCY', 1, 32, 9999, 1, 3, 42, 550, '1992-01-01', '', 50, '840  888  822  844', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (8660, '1999-08-06 22:00:00+00', '2021-03-15 22:50:17.048666+00', 'Broken Promises', 'BROKEN PROMISES', 3, 32, 9999, 5, 2, 76, 479, '1996-01-01', '"Dedicated to Sabina Schuetz"', 100, '88  88  88  88', 0, 0, 0, 1, 100);
INSERT INTO 'dance' VALUES (8331, '2001-05-21 22:00:00+00', '2021-03-20 19:36:56.770862+00', 'Bubbles in the Pond', 'BUBBLES IN THE POND', 3, 32, 9999, 1, 3, 42, 2868, NULL, '', 59, '880  822  888  888', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (795, '1997-04-03 22:00:00+00', '2021-04-17 17:40:50.963987+00', 'Bridge of Sighs, The', 'BRIDGE OF SIGHS', 3, 32, 9999, 1, 3, 42, 108, '1986-01-01', '', 62, '808  866  866  888', 0, 1, 0, 1, 83);
INSERT INTO 'dance' VALUES (717, '1997-09-13 22:00:00+00', '2021-06-29 09:33:25.039649+00', 'Boston Scottish Fiddle Club Jig', 'BOSTON SCOTTISH FIDDLE CLUB JIG', 2, 32, 9999, 1, 3, 42, 280, NULL, 'Dedicated to "the members of the Boston Scottish Fiddle Club, led by Ed Pearlman."

', 53, '880  888  880  840', 1, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (654, '1998-09-29 22:00:00+00', '2021-07-01 09:06:04.060149+00', 'Bonnie Kate of Aberdeen', 'BONNIE KATE OF ABERDEEN', 3, 40, 9999, 1, 3, 42, 466, '1760-01-01', '', 60, '888  888  800  888  880', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (629, '1997-08-19 22:00:00+00', '2021-07-01 09:18:18.508829+00', 'Bon Voyage', 'BON VOYAGE', 1, 32, 9999, 1, 3, 42, 104, '1986-04-01', '"Devised for Eileen Sadler on the occasion of her departure to Paris"', 66, '880  888  822  888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (13681, '2011-06-13 22:00:00+00', '2021-07-15 22:37:54.445094+00', 'Bruce Frazer''s Jig', 'BRUCE FRAZERS JIG', 2, 32, 9999, 1, 4, 11, 10332, '2006-05-24', 'Bruce Frazer''s Jig was devised to celebrate the many years Bruce has taught SCD classes in the Frimley Green area.  The dance was originally called "Bruce Frazer''s Farewell to Frimley Green", and was performed by the ''Badenoch Dancers'' on 24th May 2006 at the farewell party to mark Bruce''s move back to Scotland.  The ''Badenoch Dancers'' were a team which Bruce coached for competition at the Slough Arts Festival. ', 87, '8888  8888  4444  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (10288, '2001-12-16 23:00:00+00', '2015-06-28 20:46:36.683371+00', 'Bridge of Athlone', 'BRIDGE OF ATHLONE', 1, 48, 9999, 3, 5, 16, 9998, NULL, 'This can be danced in a 3C, 4C or 5C set.  This entry uses a 5C/5L set.  ', 87, '88888  88888  80000  88888  88888  88888', 0, 1, 1, 0, 86);
INSERT INTO 'dance' VALUES (11188, '2003-02-16 23:00:00+00', '2015-09-13 13:23:35.983327+00', 'Bruce''s Men', 'BRUCES MEN', 3, 32, 9999, 2, 3, 17, 146, '2002-01-01', 'This dance is identical to the dance Caerlaverock Castle (Graded&Social 3)', 75, '880  844  844  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (780, '1997-08-31 22:00:00+00', '2016-01-18 14:23:24.643549+00', 'Breeks Are Loose (and the Button''s Awa''), The', 'BREEKS ARE LOOSE AND THE BUTTONS AWA', 2, 32, 9999, 1, 3, 42, 108, '1978-01-01', '', 50, '800  880  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (738, '1999-08-06 22:00:00+00', '2017-07-08 14:20:18.863634+00', 'Braes of Atholl', 'BRAES OF ATHOLL', 3, 40, 9999, 1, 3, 42, 397, '1731-01-01', '', 50, '800/888/888/844/800', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (877, '1998-09-29 22:00:00+00', '2019-03-19 00:30:41.094924+00', 'Burns'' Hornpipe', 'BURNS HORNPIPE', 1, 32, 9999, 1, 4, 1, 9998, '1841-01-01', '', 25, '8000  4000  4000  8008', 0, 1, 0, 0, 25);
INSERT INTO 'dance' VALUES (14983, '2013-07-20 13:28:43.742758+00', '2018-01-06 22:48:20.65737+00', 'Bruce Frazer of Strathkinness', 'BRUCE FRAZER OF STRATHKINNESS', 3, 32, NULL, 1, 3, 42, 463, '2013-01-01', 'In recognition of Bruce Frazer''s contribution to the work of the RSCDS, most recently in Fife, and to commemorate the 75th Anniversary of the St. Andrews Branch.', 50, '880  844  844  844', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (820, '1998-11-03 23:00:00+00', '2019-03-19 10:32:30.816099+00', 'British Immigrant, The', 'BRITISH IMMIGRANT', 2, 32, 9999, 1, 4, 1, 394, '1980-01-01', '', 50, '8888  8000  8000  8008', 0, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (776, '1997-04-03 22:00:00+00', '2019-03-19 10:47:59.91629+00', 'Breakdown, The', 'BREAKDOWN', 1, 32, 9999, 2, 3, 17, 270, NULL, '', 67, '800  800  888  888', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (917, '1997-04-03 22:00:00+00', '2018-11-09 22:52:30.718457+00', 'Cairn Strathspey, The', 'CAIRN STRATHSPEY', 3, 32, 9999, 1, 4, 1, 146, NULL, '', 75, '8888/4444/4444/8888', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (796, '1998-07-09 22:00:00+00', '2014-10-23 21:49:08.514268+00', 'Bridge Over The Atlantic', 'BRIDGE OVER THE ATLANTIC', 3, 32, 9999, 2, 3, 17, 533, '1975-09-01', 'Bars 1-16 were devised by John Gradon, and 17-32 by Derek Haynes.



First published in SD Archives, september 1975



Clachan Bridge links Seil Island with the mainland, crossing waters of the Atlantic.  The dance tells the story of boys on one side of the bridge and girls on the other, dancing on their own sides.  One couple cross over the bridge and then return.  Bars 17-32 represent the wedding procession and festivities.  ', 100, '888/888/888/888', 1, 1, 1, 1, 97);
INSERT INTO 'dance' VALUES (916, '1997-09-16 22:00:00+00', '2019-01-22 15:19:57.447714+00', 'Cairn Edward', 'CAIRN EDWARD', 2, 24, 9999, 1, 3, 42, 129, NULL, 'Music is in 6 bar phrases', 44, '633  633  12 3 3', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (909, '1998-09-29 22:00:00+00', '2019-10-01 00:26:15.326649+00', 'Cadgers in the Canongate', 'CADGERS IN THE CANONGATE', 1, 48, 9999, 1, 3, 42, 397, '1748-02-02', '', 51, '888  888  820  880  800  880', 0, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (18102, '2017-12-04 16:56:12.384089+00', '2019-10-10 09:12:36.526401+00', 'Jacquie''s Fankle', 'JACQUIES FANKLE', 1, 32, NULL, 2, 3, 17, 515, '2006-12-01', 'Dedicated to Jacquie Riddell, member of the class in Cockburnspath, who asked me to write a dance for her.  She suggested the title.  This is the result.', 88, '707/888/868/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18250, '2018-03-10 21:54:10.086858+00', '2018-03-10 21:54:10.086858+00', 'Daniel and Roger''s Wedding', 'DANIEL AND ROGERS WEDDING', 1, 32, NULL, 1, 4, 1, 11237, '2017-10-01', 'Devised to help celebrate the wedding of Daniel Capron and Roger Juplo on 10 March 2018.



Daniel and Roger met through Scottish Country Dancing. In autumn 2005 Daniel took the initiative to launch the Gay Gordons group in London. Nearly 12 years later Roger came to the annual Gay Gordons picnic in Kensington Gardens at one of the London Dancing in the Park events. Good things come - eventually - to those who wait!', 75, '8844/8888/8000/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4847, '1998-01-04 23:00:00+00', '2014-04-30 23:23:43.201643+00', 'Cameron of Erracht', 'CAMERON OF ERRACHT', 3, 32, 9999, 1, 4, 1, 595, '1994-01-01', '', 84, '8888  8448  0884  8888', 1, 1, 1, 0, 84);
INSERT INTO 'dance' VALUES (981, '1998-04-29 22:00:00+00', '2014-04-30 23:23:43.29671+00', 'Campbell''s Hornpipe', 'CAMPBELLS HORNPIPE', 1, 32, 9999, 1, 4, 1, 181, '1973-01-01', 'For many years erroneous cribs have asserted that 4c+3c+2c dance down under the arch and then cast up.  This has now been corrected, but those cribs are still present on the Web.', 66, '8448  8008  8444  0888', 0, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (900, '1997-08-31 22:00:00+00', '2018-04-03 00:07:36.327388+00', 'Cabbages And Kings', 'CABBAGES AND KINGS', 2, 32, 9999, 1, 3, 42, 59, NULL, '', 50, '880  800  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (963, '1997-08-31 22:00:00+00', '2015-04-01 17:23:16.945097+00', 'Cambusdoon', 'CAMBUSDOON', 1, 32, 9999, 4, 4, NULL, 270, NULL, '', 75, '8448  8008  8008  8888', 0, 0, 0, 0, 75);
INSERT INTO 'dance' VALUES (984, '1998-09-29 22:00:00+00', '2015-08-31 14:21:57.122201+00', 'Campbells are coming, The', 'CAMPBELLS ARE COMING', 2, 32, 9999, 5, 2, NULL, 9998, NULL, '', 100, '88/88/88/88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (902, '1998-11-14 23:00:00+00', '2018-04-03 00:07:36.335823+00', 'Caberfei', 'CABERFEI', 1, 32, 9999, 1, 3, 42, 9998, '1740-01-01', '', 48, '880  800  833  888', 0, 1, 1, 0, 64);
INSERT INTO 'dance' VALUES (9768, '2002-04-28 22:00:00+00', '2021-10-29 14:16:04.74178+00', 'Brunette d''Ecosse', 'BRUNETTE DECOSSE', 3, 32, 9999, 1, 3, 42, 104, '1993-03-01', 'Devised for Lindsey and Philippe Rousseau.



''Brunette'' is a type of French song which came into existence at about the same time as the strathspey became a form of dance.', 66, '884  888  844  888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (924, '1997-09-05 22:00:00+00', '2020-08-02 23:41:47.790404+00', 'Cairnsmore of Carsphairn', 'CAIRNSMORE OF CARSPHAIRN', 3, 32, 9999, 3, 5, 7, 129, NULL, '', 76, '84884  86866  80800  88888', 1, 1, 0, 0, 76);
INSERT INTO 'dance' VALUES (977, '1997-04-03 22:00:00+00', '2023-02-21 12:38:46.341242+00', 'Campbell''s Caper', 'CAMPBELLS CAPER', 2, 32, 9999, 1, 2, 76, 108, '1968-01-01', 'Inscribed "to Aileen Campbell, of Aberdeen."', 64, '84  88  88  88', 1, 1, 0, 1, 93);
INSERT INTO 'dance' VALUES (905, '1998-10-15 22:00:00+00', '2020-08-07 20:02:06.982702+00', 'Caddam Wood', 'CADDAM WOOD', 1, 32, 9999, 3, 5, 4, 270, NULL, 'Mixer dance. I.e. partner changes.', 62, '80008  88888  88088  60006', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (888, '1997-08-28 22:00:00+00', '2020-10-09 18:08:22.587271+00', 'Button Boy, The', 'BUTTON BOY', 1, 32, 9999, 1, 3, 42, 15, NULL, '', 62, '888  888  888  800', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (11887, '2004-11-01 23:00:00+00', '2021-01-18 18:48:21.677172+00', 'Caffeine Reel, The', 'CAFFEINE REEL', 1, 32, 9999, 3, 5, 16, 1445, NULL, '', 55, '80000  84444  80880  88448', 1, 1, 1, 1, 55);
INSERT INTO 'dance' VALUES (7355, '1998-10-18 22:00:00+00', '2021-03-27 19:28:41.152641+00', 'Brownrigg Reel, The', 'BROWNRIGG REEL', 1, 32, 9999, 1, 4, 1, 394, '1996-01-01', 'Bobby Brown''s band worked as the Brownrigg Company, in Toronto (?) Canada. Trew wrote this dance for the Band, and one more for each member.', 66, '8800  0088  8888  8444', 0, 1, 0, 0, 65);
INSERT INTO 'dance' VALUES (8348, '1998-04-24 22:00:00+00', '2021-03-20 12:55:40.176342+00', 'Burns Bicentenary Strathspey', 'BURNS BICENTENARY STRATHSPEY', 3, 32, 9999, 1, 100, 2, 108, '1996-01-01', '', 75, '8888  8888  8008  8008', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (9167, '2001-03-30 22:00:00+00', '2021-03-27 19:22:38.606002+00', 'Cambusnethan', 'CAMBUSNETHAN', 2, 32, 9999, 2, 3, 18, 2409, '1999-11-19', 'Devised on 19 November 1999 for teaching phrasing of figures-of-eight.', 63, '080  880  884  484', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (980, '1998-09-29 22:00:00+00', '2021-06-25 11:35:01.524597+00', 'Campbell''s Frolic', 'CAMPBELLS FROLIC', 2, 32, 9999, 1, 3, 42, 453, '1750-01-01', '', 50, '880  808  800  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (958, '1998-01-04 23:00:00+00', '2021-06-25 22:41:56.142594+00', 'Calver Lodge', 'CALVER LODGE', 1, 24, 9999, 1, 2, 76, 9998, '1827-01-01', '', 69, '88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (919, '1998-07-09 22:00:00+00', '2021-06-26 20:06:55.531733+00', 'Cairncross', 'CAIRNCROSS', 3, 32, 9999, 3, 5, 7, 82, NULL, '', 71, '84048  88088  84048  85885', 1, 1, 0, 1, 71);
INSERT INTO 'dance' VALUES (873, '1998-11-14 23:00:00+00', '2018-01-12 20:49:44.807086+00', 'Burnieboozle', 'BURNIEBOOZLE', 1, 32, 9999, 1, 3, 42, 316, NULL, '"Burnieboozle is the name of the house where Jim and Rhoda McMillan live in Formby. The dance has been written to honour Jim''s year as the President of the Lancashire and Cheshire Federation of Scottish Societies 1987-88"', 62, '800  888  888  888', 0, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (7553, '1999-12-21 23:00:00+00', '2014-04-30 23:23:43.356429+00', 'Canadian Barn Dance', 'CANADIAN BARN DANCE', 11, 16, 9999, 5, 1, NULL, 1992, NULL, '', 100, '44  44  44  44', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (7629, '1998-01-04 23:00:00+00', '2014-04-30 23:23:43.401006+00', 'Cannadine Strathspey, The', 'CANNADINE STRATHSPEY', 3, 32, 9999, 1, 4, 1, 181, '1992-01-01', 'Dedicated to Reg Cannadine on the occasion of his 70th birthday in 1992.



 ', 75, '8800  8888  0880  8888', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (15177, '2013-09-28 22:20:03.263751+00', '2018-04-02 23:56:33.313782+00', 'Captain''s House, The', 'CAPTAINS HOUSE', 1, 32, 9999, 1, 3, 42, 10568, '2010-02-01', '"I wrote this for my daughter Leah and her boyfriend when they got engaged.  They are married now.  Best move she ever made!"



', 56, '800  888  844  888', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (7362, '2000-11-22 23:00:00+00', '2018-12-19 12:00:47.812816+00', 'Celtic Reel, The', 'CELTIC REEL', 1, 32, 9999, 1, 2, NULL, 352, NULL, 'In the original text, this was a 3-couple dance, with 1c dancing the ½ Fig8 down on [29-32], and 3c only being »posts«. The conversion to a 2c dance was approved by Barry in his »Strathspey« message <<sspey:23362>>. In the 3C variant, 1st couple, at the end, dances the 1/2 Figure of 8 round 3rd couple instead of the 2nd.', 56, '80  88  88  84', 0, 1, 1, 0, 81);
INSERT INTO 'dance' VALUES (1024, '1998-09-29 22:00:00+00', '2014-04-30 23:23:43.579569+00', 'Captain White', 'CAPTAIN WHITE', 2, 32, 9999, 1, 2, NULL, 9998, NULL, '', 60, '88  88  44  88', 0, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (2050, '2002-11-18 23:00:00+00', '2019-03-17 11:54:37.008992+00', 'Cape Spear', 'CAPE SPEAR', 3, 32, 9999, 1, 4, 13, 585, NULL, '', 87, '8888  8888  6666  8880', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (13581, '2010-08-07 22:00:00+00', '2018-04-03 00:07:36.861299+00', 'Capital Jig, A', 'CAPITAL JIG', 2, 32, NULL, 1, 3, 42, 2823, NULL, '', 56, '880  888  844  844', 0, 0, 0, 0, 75);
INSERT INTO 'dance' VALUES (1060, '1998-11-14 23:00:00+00', '2014-04-30 23:23:43.656612+00', 'Cashmere Shawl, The', 'CASHMERE SHAWL', 3, 32, 9999, 1, 3, 42, 44, NULL, 'On Thu, 14 Nov 2013 the author wrote to <strathspey@strathspey.org>



The right shoulder pass was a deliberate choice because the two half reels are not the

same - first couple''s track during the second half reel is shorter than during the first

half reel. 



The right shoulder pass forces first couple to pass wide which means that they should

finish on the side-lines rather than in from the side-lines - which can easily happen if

they dance the reels at the same speed / in the same way.', 42, '800  822  844  666', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (1030, '1997-04-03 22:00:00+00', '2019-08-29 18:32:32.236264+00', 'Cargill''s Leap', 'CARGILLS LEAP', 2, 32, 9999, 1, 3, 42, 332, NULL, '', 61, '886  888  800  888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (8041, '1997-09-17 22:00:00+00', '2014-04-30 23:23:43.819338+00', 'Caterpillar, The', 'CATERPILLAR', 1, 32, 9999, 1, 4, 1, 1265, '1993-01-01', '', 62, '8888  8888  8000  8000', 1, 1, 1, 0, 62);
INSERT INTO 'dance' VALUES (9341, '2001-03-13 23:00:00+00', '2017-01-07 22:02:59.023859+00', 'Casting Glances', 'CASTING GLANCES', 3, 32, 9999, 1, 2, NULL, 2701, '1998-01-01', '', 60, '44  88  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (1128, '2001-03-17 23:00:00+00', '2016-03-28 21:57:59.240359+00', 'Celtic Cross, The', 'CELTIC CROSS', 1, 48, 9999, 4, 4, 4, 175, '1991-01-01', '', 83, '8888  8888  8080  0808  8888  8888', 0, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (8042, '2002-02-27 23:00:00+00', '2020-02-20 21:29:06.258296+00', 'Ceilidh Madness', 'CEILIDH MADNESS', 1, 32, 9999, 1, 4, 1, 1381, NULL, '', 56, '4444  4444  8000  8888', 1, 1, 1, 0, 56);
INSERT INTO 'dance' VALUES (899, '1998-09-29 22:00:00+00', '2020-05-28 10:09:25.51238+00', 'Ca'' the Ewes tae the Knowes', 'CA THE EWES TAE THE KNOWES', 3, 32, 9999, 1, 2, 76, 432, '1816-01-01', '', 52, '80  80  88  88', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (985, '1998-09-28 22:00:00+00', '2020-08-03 06:24:16.970119+00', 'Campbeltown Loch', 'CAMPBELTOWN LOCH', 2, 48, 9999, 1, 4, 2, 82, NULL, '', 79, '8888  8888  8888  0880  8008  4884', 0, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (13721, '2011-07-09 22:00:00+00', '2020-09-19 20:59:33.869817+00', 'Ceilidh Night', 'CEILIDH NIGHT', 2, 32, NULL, 9, 7, 87, 175, NULL, 'Note in the original text: "This dance may also be danced in 4-couple sets".', 57, '8008000  8888880  8888880  8008000', 0, 1, 0, 0, 57);
INSERT INTO 'dance' VALUES (976, '2001-11-20 23:00:00+00', '2021-01-06 15:00:28.78373+00', 'Campbell of Laphroaig', 'CAMPBELL OF LAPHROAIG', 4, 32, 1, 1, 3, 42, 388, '1986-01-01', '', 56, '844  880  844  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (12809, '2006-07-27 22:00:00+00', '2021-08-05 11:41:29.848184+00', 'Clare''s Dance', 'CLARES DANCE', 1, 32, 9999, 1, 3, 42, 3698, '2005-08-01', 'Written as a celebration and appreciation of Clare Bunton’s life.', 76, '800/888/844/888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (9148, '2002-10-22 22:00:00+00', '2021-03-01 11:05:25.604093+00', 'Catriona Joan Stewart', 'CATRIONA JOAN STEWART', 3, 32, 9999, 1, 3, 42, 2674, '1994-01-01', '', 50, '800  844  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (8568, '2002-03-02 23:00:00+00', '2021-03-16 16:38:13.323746+00', 'Capelthwaite', 'CAPELTHWAITE', 1, 32, 9999, 1, 2, 76, 348, '1993-01-01', 'Written in memory of a man who died of aids.', 69, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (910, '1998-09-29 22:00:00+00', '2021-06-22 19:16:39.848978+00', 'Cadies Lady, The', 'CADIES LADY', 1, 40, 9999, 1, 3, 42, 1977, NULL, '', 37, '820  802  800  822  866', 1, 1, 0, 1, 50);
INSERT INTO 'dance' VALUES (1087, '1998-10-15 22:00:00+00', '2021-04-05 13:05:05.272702+00', 'Catch the Wind', 'CATCH THE WIND', 1, 32, 9999, 1, 3, 42, 59, '1983-01-01', 'The original tune is a hornpipe.', 38, '800  800  888  800', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (1066, '1998-04-05 22:00:00+00', '2021-06-23 11:58:35.609636+00', 'Castle Douglas', 'CASTLE DOUGLAS', 3, 32, 9999, 1, 3, 42, 146, NULL, 'Inscribed "For Hope and Bill Little".', 47, '820  844  846  844', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (1034, '1998-09-30 22:00:00+00', '2021-06-23 12:06:37.046486+00', 'Carl Cam'' Ower the Croft, The', 'CARL CAM OWER THE CROFT', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 69, '888  888  880  888', 1, 1, 0, 1, 91);
INSERT INTO 'dance' VALUES (1022, '1998-04-05 22:00:00+00', '2021-06-24 09:28:58.501622+00', 'Captain Ross', 'CAPTAIN ROSS', 1, 32, 9999, 1, 3, 42, 9998, '1740-01-01', 'Described a for a 4 (or 5) couple set.', 34, '800  880  822  800', 1, 1, 0, 1, 45);
INSERT INTO 'dance' VALUES (11610, '2003-12-04 23:00:00+00', '2022-09-23 16:48:51.050698+00', 'Cane Toad Jig, The', 'CANE TOAD JIG', 2, 32, 9999, 1, 3, 42, 2682, '1993-01-01', '', 44, '888   16 4 4   800', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (954, '1998-04-21 22:00:00+00', '2023-02-21 13:05:33.32417+00', 'Calm Before the Storm, The', 'CALM BEFORE THE STORM', 1, 32, 9999, 1, 3, 42, 44, NULL, '', 37, '800  880  800  880', 1, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (1020, '1998-09-29 22:00:00+00', '2021-06-24 09:30:50.595684+00', 'Captain McBride''s Hornpipe', 'CAPTAIN MACBRIDES HORNPIPE', 1, 32, 9999, 1, 3, 42, 263, '1795-01-01', '', 44, '844  800  808  880', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (1018, '1998-09-29 22:00:00+00', '2021-06-24 09:44:17.843779+00', 'Captain Macdonald''s Fancy', 'CAPTAIN MACDONALDS FANCY', 1, 32, 9999, 1, 3, 42, 373, '1792-02-01', '', 34, '800  080  880  822', 1, 1, 1, 1, 45);
INSERT INTO 'dance' VALUES (1017, '1998-09-29 22:00:00+00', '2021-06-24 09:46:33.609186+00', 'Captain MacBean''s Reel', 'CAPTAIN MACBEANS REEL', 1, 32, 9999, 1, 3, 42, 466, '1760-01-01', '', 56, '888  888  800  880', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (972, '1998-09-29 22:00:00+00', '2021-06-25 22:34:44.786368+00', 'Camp of Pleasure, The', 'CAMP OF PLEASURE', 3, 32, 9999, 1, 2, 76, 9998, NULL, '', 67, '77  88  88  88', 1, 1, 0, 1, 96);
INSERT INTO 'dance' VALUES (848, '2002-02-27 23:00:00+00', '2021-06-28 09:04:34.14607+00', 'Buchan Eightsome Reel, The', 'BUCHAN EIGHTSOME REEL', 1, 400, 9999, 4, 4, 3, 9998, NULL, '', 45, '8888  6020  4202  8040  4404', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (929, '1998-04-05 22:00:00+00', '2021-11-09 21:04:39.579622+00', 'Caldercruix', 'CALDERCRUIX', 2, 32, 9999, 1, 3, 42, 108, '1993-03-01', 'The notes say this dance was for the wedding, in Caldercruix, of James Kutzner and Alma Gollogly in June 1993.', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (1100, '2001-04-03 22:00:00+00', '2017-07-07 12:49:23.29561+00', 'Cauld Kail', 'CAULD KAIL', 4, 32, 1, 1, 3, 42, 9998, NULL, 'The name derives from a Robert Burns song, »Cauld Kail in

Aberdeen«. In former times, kail (or, more commonly, curly-leaved

kale) – *Brassica oleracea acephala* –, a form of greenish leaf

cabbage, formed a very important part of the Scottish diet.



In the 1890s, Scottish writers including J. M. Barrie (of *Peter Pan*

fame) and George MacDonald developed the »Kailyard school« of fiction,

depicting a sentimental version of rural Scottish life. A kailyard is

a small cabbage patch, often adjacent to a crofter''s cottage.



The dance introduces the formation »set to corners and partner« –

today commonly referred to as »hello-goodbye setting« – and got

connected to it to the degree that the formation used to be known as

»Cauld Kail setting«.

', 38, '880  840  800  822', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (11619, '2003-12-04 23:00:00+00', '2014-04-30 23:23:43.969503+00', 'Celtic Rover, The', 'CELTIC ROVER', 1, 32, 9999, 3, 5, 37, 2682, '1995-01-01', '', 82, '84844  86846  88888  84884', 1, 1, 1, 1, 82);
INSERT INTO 'dance' VALUES (14271, '2011-10-15 22:00:00+00', '2018-09-02 19:52:15.234148+00', 'Birthday in Prague', 'BIRTHDAY IN PRAGUE', 2, 40, NULL, 1, 3, 42, 1445, NULL, 'To commemorate George Flett''s remarkable birthday in Prague.   



The formation on bars 1-4 is an "Allemande Right", known from 19th century dances, and re-introduced into SCD by Derek Haynes."', 46, '800  880  880  828  808', 0, 1, 1, 0, 61);
INSERT INTO 'dance' VALUES (1167, '2002-02-26 23:00:00+00', '2014-04-30 23:23:44.175581+00', 'Chatsworth House', 'CHATSWORTH HOUSE', 2, 32, 9999, 1, 4, 2, 371, NULL, '', 72, '8008  8228  8448  8888', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (18588, '2018-09-15 16:27:49.9245+00', '2018-09-15 16:58:08.843897+00', 'Golden Hills of Glen Orrin, The', 'GOLDEN HILLS OF GLEN ORRIN', 2, 32, NULL, 1, 100, 2, 2762, '2015-09-01', 'Written to mark the 50th Wedding Anniversary of Margaret & Norman Hill in September 2015 & danced to a tune especially commissioned by members of the Glen Orrin Dancers and composed by Marian Anderson.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1210, '2000-02-21 23:00:00+00', '2014-04-30 23:23:44.303345+00', 'Circassian Circle', 'CIRCASSIAN CIRCLE', 1, 32, 9999, 5, 2, NULL, 9998, NULL, '', 100, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (18591, '2018-09-15 17:57:14.772949+00', '2019-01-28 22:37:16.059624+00', 'Welcome to Beaumaris', 'WELCOME TO BEAUMARIS', 2, 32, NULL, 1, 3, 42, 2886, NULL, '', 44, '804/840/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1244, '2000-02-21 23:00:00+00', '2014-04-30 23:23:44.434793+00', 'Clutha', 'CLUTHA', 1, 48, 9999, 4, 4, 46, 9998, '1890-01-01', 'Named after the passenger steamers plying the Clyde from 1884-1903, all named "Clutha" (= Gaelic for "Clyde").  ', 62, '4040  8080  8080  8080  8888  8888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (14984, '2013-07-21 13:11:27.954995+00', '2019-02-26 17:29:28.375286+00', 'Chairman''s Chain, The', 'CHAIRMANS CHAIN', 2, 32, 9999, 1, 4, 2, 99, '2004-01-01', 'Devised by Lewis N Derrick in 2004 for Irene Bennett, Chairman-Elect of the RSCDS', 81, '8888  8888  8008  8448', 0, 1, 1, 0, 81);
INSERT INTO 'dance' VALUES (8250, '1998-01-06 23:00:00+00', '2019-03-06 23:52:19.026478+00', 'Clarsach, The', 'CLARSACH', 2, 32, 9999, 1, 4, 1, 1110, '1989-01-01', '', 42, '4000  8200  8800  8844', 0, 1, 0, 0, 42);
INSERT INTO 'dance' VALUES (1161, '1998-04-08 22:00:00+00', '2019-03-18 23:48:25.208553+00', 'Charlotte Clarke''s Strathspey', 'CHARLOTTE CLARKES STRATHSPEY', 3, 32, 9999, 4, 5, 35, 728, NULL, '', 55, '44444  80808  08088  00004  44422', 0, 1, 0, 0, 55);
INSERT INTO 'dance' VALUES (18589, '2018-09-15 17:53:32.575655+00', '2019-04-25 08:08:49.860829+00', 'Teifi Jig, The', 'TEIFI JIG', 2, 32, NULL, 6, 3, 17, 2886, '2018-06-01', '', 83, '888/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1218, '1999-10-19 22:00:00+00', '2015-05-11 21:50:05.150177+00', 'Clachan, The', 'CLACHAN', 2, 32, 9999, 1, 3, 42, 129, '1960-01-01', '', 56, '800/888/844/888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (11375, '2003-06-26 22:00:00+00', '2020-05-15 14:59:38.856202+00', 'Castle in the Air, A', 'CASTLE IN THE AIR', 1, 32, 9999, 1, 2, NULL, 3355, '2002-01-01', '', 60, '80  88  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (1143, '1998-10-22 22:00:00+00', '2020-08-29 15:43:04.043525+00', 'Ceres Games', 'CERES GAMES', 2, 32, 9999, 1, 2, 76, 50, '1975-01-01', '', 51, '88  44  44  88', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (9203, '2000-01-16 23:00:00+00', '2020-09-08 08:41:32.928914+00', 'Cherry Blossom Time', 'CHERRY BLOSSOM TIME', 2, 32, 9999, 1, 3, 42, 108, '1998-01-01', '', 56, '880  880  888  844', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (13584, '2010-08-08 22:00:00+00', '2020-09-19 11:32:30.750195+00', 'Christine M Phillips', 'CHRISTINE M PHILLIPS', 2, 32, NULL, 1, 3, 42, 884, NULL, '', 47, '800  833  833  888', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (18590, '2018-09-15 17:55:14.551296+00', '2020-11-17 20:10:21.004196+00', 'Trip to Ravenscar, A', 'TRIP TO RAVENSCAR', 1, 32, NULL, 3, 5, 16, 2886, NULL, '', 62, '88088/44444/88888/80000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13075, '2006-11-10 23:00:00+00', '2020-11-30 11:18:01.803066+00', 'Christine''s Fancy', 'CHRISTINES FANCY', 3, 32, 9999, 2, 3, 18, 884, '2002-01-01', '', 63, '080  383  383  884', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (13679, '2011-05-05 22:00:00+00', '2020-12-28 20:29:36.42941+00', 'City of Christchurch, The', 'CITY OF CHRISTCHURCH', 4, 32, 2, 1, 100, 11, 3179, '2011-04-01', '', 59, '8008  8448  0880  8228', 0, 1, 0, 0, 59);
INSERT INTO 'dance' VALUES (11368, '2003-06-26 22:00:00+00', '2021-01-25 15:30:50.645942+00', 'Celebration Strathspey, The', 'CELEBRATION STRATHSPEY', 3, 32, 9999, 1, 3, 42, 246, '2002-01-01', '', 52, '550  880  888  844', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (10049, '2002-11-01 23:00:00+00', '2021-02-13 12:51:56.515046+00', 'Certificate Pleasure', 'CERTIFICATE PLEASURE', 1, 32, 9999, 1, 3, 42, 227, '1997-04-01', 'Written for the certificate class in Germany.



Music: own tune or any good reel.

', 56, '16 12 12   822  866', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (9633, '2000-09-05 22:00:00+00', '2021-02-21 18:20:26.094448+00', 'Chantry Hall', 'CHANTRY HALL', 3, 32, 9999, 2, 3, 17, 146, '2000-01-01', '', 45, '644  804  888  800', 0, 1, 0, 0, 60);
INSERT INTO 'dance' VALUES (9632, '2002-11-13 23:00:00+00', '2021-02-21 18:23:32.426009+00', 'Chain Walk, The', 'CHAIN WALK', 3, 32, 9999, 2, 3, 17, 146, '2000-01-01', 'For Maureen and Derek Haynes', 69, '707  840  888  844', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (8086, '1998-09-29 22:00:00+00', '2021-03-22 12:39:42.748864+00', 'Clydeside Lassies', 'CLYDESIDE LASSIES', 1, 32, 9999, 1, 2, 76, 9998, NULL, '<<scddb:not-identical:1246>>

', 60, '88 80 88 88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (7369, '1998-04-24 22:00:00+00', '2021-03-27 00:11:14.543911+00', 'Clydebank Strathspey', 'CLYDEBANK STRATHSPEY', 3, 32, 9999, 1, 2, 76, 146, NULL, '', 52, '84  48  80  88', 0, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (18252, '2018-03-11 09:24:27.056796+00', '2022-04-26 19:55:21.747607+00', 'Never Let Go', 'NEVER LET GO', 3, 40, NULL, 2, 3, 18, 11606, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9835, '2001-10-07 22:00:00+00', '2022-09-30 21:29:10.489984+00', 'Chairman''s Jig, The', 'CHAIRMANS JIG', 2, 32, 9999, 1, 3, 42, 146, NULL, 'That Chairman was Alastair Aitkenhead.', 59, '888  844  888  822', 0, 1, 0, 0, 79);
INSERT INTO 'dance' VALUES (1182, '1997-04-03 22:00:00+00', '2023-02-17 18:29:27.210716+00', 'Chevy Chase', 'CHEVY CHASE', 1, 32, 9999, 1, 3, 42, 313, NULL, 'The dance notes elaborate that "The Ballad of Chevy Chase tells of a battle in 1388 between Harry Percy (Hotspur) and the son of the Black Douglas. On the night before the battle, Douglas dreamed that he saw a dead man win a fight. Douglas was mortally wounded and ordered his men to conceal his corpse. Hotspur was beaten and ordered to yield formally to a bracken bush. Hidden in the bush was the body of Douglas."', 44, '800  844  844  844', 1, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (1163, '1998-09-29 22:00:00+00', '2023-01-16 10:31:48.158372+00', 'Charmer, The', 'CHARMER', 2, 32, 9999, 1, 3, 42, 397, '1719-01-01', 'The RSCDS Books Combined 25 to 30 says this was “Adapted from Walsh: Second Book Compleat Dancing Master, 1719.”', 37, '802  082  840  844', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (1207, '2001-05-03 22:00:00+00', '2021-03-27 21:39:40.385701+00', 'Ciamar a Tha (How are You?)', 'CIAMAR A THA HOW ARE YOU', 2, 32, 9999, 1, 3, 42, 146, '1992-01-01', 'For the 21st anniversary of the Ilkley SCD club.  

Pronunciation Kamera Ha or (better) Kem ar-a haa oo.', 44, '804  840  822  866', 0, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (7120, '1998-11-28 23:00:00+00', '2021-04-17 18:58:17.182031+00', 'White Rose of Scotland, The', 'WHITE ROSE OF SCOTLAND', 3, 32, 9999, 1, 3, 42, 510, NULL, '', 50, '800/844/844/888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (1154, '1998-09-29 22:00:00+00', '2021-06-22 17:35:48.576611+00', 'Chapman, The', 'CHAPMAN', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 69, '888  888  888  844', 1, 1, 0, 1, 91);
INSERT INTO 'dance' VALUES (1215, '1998-11-14 23:00:00+00', '2021-06-21 10:36:51.839591+00', 'City of Nairobi Reel, The', 'CITY OF NAIROBI REEL', 1, 40, 9999, 1, 3, 42, 781, NULL, '', 40, '800  844  844  800  866', 0, 1, 0, 0, 56);
INSERT INTO 'dance' VALUES (7650, '2002-04-11 22:00:00+00', '2018-04-03 00:07:38.947642+00', 'Cobblestones, The', 'COBBLESTONES', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 50, '800  822  888  866', 0, 0, 0, 0, 66);
INSERT INTO 'dance' VALUES (7109, '2001-09-13 22:00:00+00', '2018-04-03 00:08:25.533728+00', 'White Cockade, The', 'WHITE COCKADE', 1, 32, 9999, 1, 3, 42, 459, '1797-01-01', '', 47, '888  800  804  880', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (14637, '2013-01-01 13:30:30.000294+00', '2014-04-30 23:23:44.558935+00', 'Cold Quarry Jig', 'COLD QUARRY JIG', 2, 32, NULL, 1, 3, 18, 3453, '2011-01-01', 'Full source from Youtube http://www.youtube.com/watch?v=T9F7362yxjg



Published on 15 april 2012



The 15th Bluebonnet Ball was held on March 31, 2012. Our excellent musicians--Mara Shea from North Carolina on the fiddle, and Dave Wiesler form Delaware on piano. This dance, Cold Quarry Jig, was devised by John Roby and is danced to an original tune by Dave Wiesler. See dance description below.



Cold Quarry Jig 32J3 Roby 2011



1-4 1s cross and cast; 2s step up on 3-4

5-8 1s petronella right and set, while corners set and change by RH along the sides, facing out ends of set to start the reel

9-14 Six bar reel of three across the dance with 1s giving left shoulder to corner on the left (second corner position)

15-16 1s petronella right

17-20 1s turn 3/4 RH to end woman between 2s and man between 3s

21-24 1s petronella right and set, while corners cross by the RH facing away to start the reel

25-30 Six bar reel of three along the sides with 1s giving left shoulder to corner on the left (first corner position)

31-32 All cross RH to finish 3,1,2 on own sides', 59, '844  866  844  888', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (10787, '2002-08-25 22:00:00+00', '2018-04-03 00:07:38.129762+00', 'Chequered Court, The', 'CHEQUERED COURT', 2, 32, 9999, 1, 3, 42, 854, '2001-01-01', '', 53, '800/844/888/866', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (17279, '2016-09-06 21:24:27.61852+00', '2018-09-02 06:15:23.280161+00', 'Larnach Castle', 'LARNACH CASTLE', 3, 32, NULL, 1, 3, 42, 59, NULL, '', 56, '800/866/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1282, '1997-04-03 22:00:00+00', '2019-03-18 15:39:02.291653+00', 'College Ramble', 'COLLEGE RAMBLE', 3, 32, 9999, 1, 4, 1, 109, NULL, '', 91, '8888  8888  8888  8444', 0, 1, 0, 0, 90);
INSERT INTO 'dance' VALUES (14552, '2012-09-02 20:38:47.158772+00', '2014-04-30 23:23:44.800688+00', 'Compleat Gardener, The', 'COMPLEAT GARDENER', 2, 32, NULL, 1, 3, 42, 3593, '2006-07-01', 'This dance was devised to celebrate David Vandegrift’s retirement from a long and successful teaching career.

', 50, '880  800  844  888', 1, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (15424, '2014-04-17 22:15:56.348789+00', '2014-04-30 23:23:44.831204+00', 'Connie''s Favorites', 'CONNIES FAVORITES', 3, 32, NULL, 2, 3, 18, 10949, NULL, 'Source: crib from the 2014 Highland Mist Ball (St. Louis, Missouri) will be held on Saturday, JUN 28.



CONNIE''S FAVORITES

LEVEL: 	Advanced

FORMATION: 	A three-couple set

SOURCE: 	Tom Bellinghausen

TEMPO: 	32-bar strathspey

01 - 04 	All three couples set and link for three on the side.

05 - 06	1st man & 3rd woman change places by the right hand.

07 - 08	All change places with partner, by the right hand, up and down the set.

09 - 10	All chase 1/4 round the set clockwise, end 3-2-1 on own side.

11 - 22	Rights and lefts for 3 couples.

23 - 24	All set on the side.

24 - 32	1st cpl & 2nd cpl rondel (end 3-1-2).', 88, '767   16 16 16   880', 0, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (15398, '2014-03-21 20:37:28.655039+00', '2014-04-30 23:23:44.927166+00', 'Convict Ship, The', 'CONVICT SHIP', 1, 32, NULL, 5, 2, NULL, 431, NULL, 'This dance tells the story of a convict ship travelling to Australia

1–8       Portholes of the ship

9–12     Hoisting the sails

13–16   Lowering the sails

17–24   Tacking through the Great Barrier Reef on the final approach to Australia

25–32   Negotiating the waves near the shore', 87, '88  44  88  88', 0, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (10365, '2002-03-04 23:00:00+00', '2014-04-30 23:23:44.957412+00', 'Cooma Highland Reel', 'COOMA HIGHLAND REEL', 1, 32, 9999, 5, 56, NULL, 9998, NULL, 'The sole source for this dance is a Ball programme found on a website in Cabramurra, NSW, Australia, on 30 may 1992.  The programme included many other, more common, dances.  No information on the background of the programme or on the devisers was given, though it is told that the “Trip to Cabramurra” was a once-only get-together of some local SCD groups. 



COOMA HIGHLAND REEL  



3 facing 3 32R



• 6 hands round and back



• reel of 3 with person on right and right opposite



• same 3 people 3 hands across and back



• advance and retire and pass through to new set of 3 people.

. ', 100, '888  888  888  888', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (12736, '2006-05-11 22:00:00+00', '2018-04-03 00:07:39.189559+00', 'Come Along and Dance', 'COME ALONG AND DANCE', 2, 40, 9999, 1, 3, 42, 1445, '2006-01-01', '', 52, '800  880  888  822  888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (11374, '2003-06-26 22:00:00+00', '2014-04-30 23:23:45.019069+00', 'Corian Strathspey, The', 'CORIAN STRATHSPEY', 3, 32, 9999, 2, 3, 17, 1163, '1995-01-01', '', 71, '840  408  668  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (8569, '2002-03-04 23:00:00+00', '2019-06-01 23:26:12.408101+00', 'Coming Through the Rye', 'COMING THROUGH THE RYE', 2, 40, 9999, 1, 3, 42, 895, '1991-01-01', '', 51, '644  804  888  888  800', 0, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (1299, '1998-04-20 22:00:00+00', '2018-04-03 00:07:39.222999+00', 'Come Let Us Dance and Sing', 'COME LET US DANCE AND SING', 1, 40, 9999, 1, 3, 42, 44, NULL, '', 65, '888  888  888  880  808', 1, 1, 1, 1, 86);
INSERT INTO 'dance' VALUES (1330, '2001-10-04 22:00:00+00', '2016-03-06 22:17:28.810597+00', 'Cooper''s Wife, The', 'COOPERS WIFE', 2, 40, 9999, 1, 3, 42, 270, NULL, '10 bar phrases', 40, '10 0 0   10 4 4   10 4 4  10 4 4', 1, 1, 1, 1, 53);
INSERT INTO 'dance' VALUES (1295, '1998-04-08 22:00:00+00', '2020-08-29 23:00:19.233837+00', 'Come And Dance With Me', 'COME AND DANCE WITH ME', 3, 32, 9999, 1, 2, 76, 227, '1987-01-01', '', 60, '80  88  88  88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (13272, '2007-04-01 22:00:00+00', '2021-01-03 13:56:25.81194+00', 'Contrary Mary', 'CONTRARY MARY', 2, 32, 9999, 1, 3, 42, 316, '2006-01-01', 'Devised: 2006', 53, '620  844  884  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (11187, '2003-02-16 23:00:00+00', '2021-01-29 22:31:13.385057+00', 'Coats Land', 'COATS LAND', 2, 32, 9999, 1, 3, 42, 146, '2002-01-01', '', 62, '844  888  844  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (10600, '2002-06-19 22:00:00+00', '2021-02-06 13:08:44.101913+00', 'Cologne Round the Room', 'COLOGNE ROUND THE ROOM', 2, 32, 9999, 5, 2, NULL, 2847, '1998-01-01', 'The dance was devised for a »Join-In« Demonstration Evening on 20.3.98', 100, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (10308, '2002-04-24 22:00:00+00', '2021-02-10 11:04:00.362729+00', 'Come on, Eileen', 'COME ON EILEEN', 2, 32, 9999, 1, 3, 42, 534, NULL, '', 50, '800  844  888  844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (7368, '1998-04-24 22:00:00+00', '2021-03-27 00:12:30.511617+00', 'Clatterin'' Brig', 'CLATTERIN BRIG', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 47, '800  822  844  888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (4727, '2004-05-11 22:00:00+00', '2021-05-06 13:52:30.208297+00', 'Coalsons'' Silver Strathspey, The', 'COALSONS SILVER STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1268, '2003-01-01', '"In honor of Bill and Becky Coalson''s 25th Anniversary"', 44, '880  800  800  888', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (1296, '2002-06-20 22:00:00+00', '2021-06-20 10:01:36.897995+00', 'Come Ashore Jolly Tar', 'COME ASHORE JOLLY TAR', 1, 32, 9999, 1, 109, NULL, 9998, NULL, 'This dance »was collected in Angus and Perthshire and there called ›Jacky Tar‹«. However, this was never an official RSCDS moniker of the dance.', 69, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (1293, '1998-04-08 22:00:00+00', '2021-06-20 10:07:50.640469+00', 'Columba Strathspey', 'COLUMBA STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1990-07-01', 'Inscribed as "a dance for the marriage of Diane Holden to Peter Lumsden on 22nd September 1990".', 66, '866  888  866  866', 1, 1, 0, 1, 87);
INSERT INTO 'dance' VALUES (1223, '2003-01-30 23:00:00+00', '2021-06-21 08:46:24.277291+00', 'Clansman, The', 'CLANSMAN', 1, 32, 9999, 1, 2, 76, 175, '1981-01-01', '', 60, '84  88  88  84', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (1304, '1998-09-30 22:00:00+00', '2021-08-05 20:57:14.561523+00', 'Come Under My Plaidie', 'COME UNDER MY PLAIDIE', 2, 32, 9999, 5, 2, 76, 9998, NULL, '', 100, '88  88  88  88', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (18253, '2018-03-11 09:32:05.180059+00', '2018-03-11 09:32:05.180059+00', 'Olympic Village', 'OLYMPIC VILLAGE', 1, 40, NULL, 1, 4, 2, 11062, NULL, '“Olympic Village and Ring Dance are presents for Ramona Zohm and Matthias Rank of the Munich Scottish Association on the occasion of their wedding in March, 2018. The Olympic reels are a reference to the venue of the MSA Wednesday dance class, the church hall in the former Olympic Village of Munich that the society first used in 1986. Ramona leads our team of excellent dance teachers, while Matthias plays the violin as one of our musicians.”



DEVISED:2018-01', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1348, '1999-10-27 22:00:00+00', '2014-04-30 23:23:45.033816+00', 'Corn Rigs', 'CORN RIGS', 1, 32, 9999, 1, 2, NULL, 9998, NULL, '', 43, '80  80  80  88', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (14610, '2012-12-17 23:21:56.556905+00', '2014-04-30 23:23:45.267452+00', 'Country Gallop, A', 'COUNTRY GALLOP', 1, 32, NULL, 2, 3, 17, 3597, '2012-02-01', '', 67, '800  888  888  800', 0, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (18256, '2018-03-11 10:27:39.661309+00', '2018-03-17 19:21:27.043892+00', 'Romancing Ramona', 'ROMANCING RAMONA', 3, 40, NULL, 1, 4, 11, 10759, '2018-01-01', '“Devised for Ramona Zohm and Matthias Rank on the occasion of their wedding on 9th March 2018. Ramona and Matthias met during their studies in Finland where both sang in a student choir. The dance represents the efforts Matthias took to attract Ramona''s attention and finally win her heart.”', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10463, '2002-09-25 22:00:00+00', '2014-04-30 23:23:45.593563+00', 'Craven Reel, The', 'CRAVEN REEL', 1, 32, 9999, 1, 3, 42, 175, NULL, '', 44, '804  840  888  800', 0, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (14119, '2011-08-25 22:00:00+00', '2018-09-01 22:57:22.453341+00', 'Sheena and Bill''s Strathspey', 'SHEENA AND BILLS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10433, NULL, 'This dance is dedicated to Sheena and Bill McLatchie. As well as their commitment to the Waverley Scottish Society both are very involved in the Melbourne and District Branch of the RSCDS.', 69, '888/888/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14611, '2012-12-17 23:23:27.648355+00', '2014-04-30 23:23:45.638701+00', 'Crewkerne 2012', 'CREWKERNE 2012', 3, 32, NULL, 3, 5, 41, 3597, '2011-12-01', '', 52, '80008  84848  80008  42428', 1, 1, 1, 1, 52);
INSERT INTO 'dance' VALUES (1375, '2002-12-31 23:00:00+00', '2018-04-02 23:56:33.60282+00', 'Cousin Jim', 'COUSIN JIM', 1, 32, 9999, 1, 3, 42, 129, NULL, '', 50, '800  822  888  866', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (9534, '2003-02-16 23:00:00+00', '2014-04-30 23:24:15.585966+00', 'Widdershins', 'WIDDERSHINS', 2, 32, 9999, 1, 3, 42, 2197, NULL, '', 50, '800  822  866  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (13405, '2009-11-10 23:00:00+00', '2014-09-24 22:27:23.408015+00', 'Courting Couples', 'COURTING COUPLES', 3, 32, NULL, 3, 5, 7, 10451, NULL, 'Written for the many couples who have met and courted most elegantly while dancing in the Kuckucksnest over the past 20 years.  It replaces the 3C/4L dance "The Courting Couple", which Carola wants to discontinue.', 67, '80800  83863  83863  84888', 0, 1, 1, 1, 67);
INSERT INTO 'dance' VALUES (14120, '2011-08-25 22:00:00+00', '2018-09-01 23:21:32.189176+00', 'Monash Mixer, The', 'MONASH MIXER', 1, 32, NULL, 4, 4, 4, 10433, NULL, 'Waverley Scottish Society is based in the City of Monash, named for Sir John Monash, engineer, lawyer and soldier. Commander in Chief of the Australian Corps in WW1, he was called "the best General of the Western Front".', 59, '444/888/555/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7124, '1997-12-15 23:00:00+00', '2015-01-28 10:54:37.066451+00', 'Whiteadder Jig, The', 'WHITEADDER JIG', 2, 32, 9999, 1, 3, 42, 1502, '1993-01-01', '', 66, '880  866  888  888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (13211, '2006-12-17 23:00:00+00', '2015-09-14 22:59:42.664719+00', 'Courting Couple, The', 'COURTING COUPLE', 3, 32, 9999, 1, 3, 42, 2113, '2003-01-01', 'Carola wants this dance to be replaced by its successor "Courting Couples", a 4C/5L dance.', 47, '800  833  833  888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (18554, '2018-09-03 19:02:40.695423+00', '2018-09-03 19:02:40.695423+00', 'New York Frolic', 'NEW YORK FROLIC', 2, 32, NULL, 1, 3, 42, 11200, '2018-08-05', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1410, '2002-04-19 22:00:00+00', '2018-04-03 00:07:39.881984+00', 'Craven Strathspey, The', 'CRAVEN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 175, '1991-01-01', '', 56, '880  880  888  844', 0, 0, 0, 0, 75);
INSERT INTO 'dance' VALUES (1388, '2000-06-12 22:00:00+00', '2019-03-18 11:18:13.365143+00', 'Craigellachie Bridge', 'CRAIGELLACHIE BRIDGE', 3, 32, 9999, 1, 4, 1, 9998, NULL, '', 86, '8888  8888  8888  8222', 0, 1, 0, 0, 85);
INSERT INTO 'dance' VALUES (9157, '2002-03-11 23:00:00+00', '2019-03-07 22:58:06.186212+00', 'Cranberry Tart, The', 'CRANBERRY TART', 2, 32, 9999, 1, 3, 42, 2677, NULL, '', 52, '15,6,6/880/888', 1, 1, 1, 1, 69);
INSERT INTO 'dance' VALUES (8490, '2001-06-12 22:00:00+00', '2020-03-27 19:16:01.928835+00', 'Corner Capers', 'CORNER CAPERS', 2, 32, 9999, 1, 3, 42, 2789, NULL, '', 47, '880  822  844  844', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (18592, '2018-09-15 17:59:17.622465+00', '2020-11-17 20:15:02.760417+00', 'Hello to Stranraer', 'HELLO TO STRANRAER', 1, 32, NULL, 5, 2, 76, 2886, NULL, 'For Holidays, at The North West Castle Hotel, Dumfries & Galloway 2011 & 2013', 100, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10007, '2002-09-25 22:00:00+00', '2021-02-13 15:50:24.537815+00', 'Craven Twelvesome, The', 'CRAVEN TWELVESOME', 1, 32, 9999, 4, 98, NULL, 175, NULL, '', 83, '888  080  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (7141, '1998-01-04 23:00:00+00', '2020-12-18 20:28:01.21665+00', 'Widdershins', 'WIDDERSHINS', 1, 32, 9999, 1, 3, 42, 1350, NULL, '', 69, '888  888  888  880', 0, 1, 0, 0, 91);
INSERT INTO 'dance' VALUES (9003, '2001-12-17 23:00:00+00', '2021-03-06 22:23:02.689768+00', 'Cramond Wedding, The', 'CRAMOND WEDDING', 3, 32, 9999, 2, 3, 17, 146, NULL, '', 83, '886  855  844  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (7375, '2002-02-26 23:00:00+00', '2021-03-27 00:09:09.820312+00', 'Craigleith', 'CRAIGLEITH', 1, 88, 9999, 4, 4, 3, 146, NULL, '', 60, '8080  8080  0808  0808  4444  4444  4444  4444  8080 0808 8888', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (1383, '2002-04-29 22:00:00+00', '2021-03-27 21:37:33.605883+00', 'Cradle Song, The', 'CRADLE SONG', 3, 32, 9999, 1, 4, 1, 173, '1971-12-06', 'Do not confuse this with the Drewry Strathspey of the same name, see below.', 87, '8888  8888  8888  8080', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (7143, '1998-09-29 22:00:00+00', '2021-03-30 20:29:25.991739+00', 'Widows, The', 'WIDOWS', 3, 32, 9999, 1, 3, 42, 9998, '1805-01-01', '', 44, '844  800  822  866', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (7142, '1998-01-05 23:00:00+00', '2021-03-30 20:33:42.911584+00', 'Widdershins Of Bothwell', 'WIDDERSHINS OF BOTHWELL', 1, 40, 9999, 2, 3, 17, 737, NULL, '', 77, '888  888  800  866  808', 0, 1, 0, 0, 76);
INSERT INTO 'dance' VALUES (1376, '1998-09-29 22:00:00+00', '2021-06-19 19:46:05.442799+00', 'Couteraller''s Rant', 'COUTERALLERS RANT', 3, 32, 9999, 1, 3, 42, 339, '1749-01-01', '', 47, '888  800  800  866', 1, 1, 0, 1, 62);
INSERT INTO 'dance' VALUES (1350, '1997-12-29 23:00:00+00', '2021-06-20 09:50:26.441607+00', 'Corner House Jig, The', 'CORNER HOUSE JIG', 2, 32, 9999, 1, 3, 42, 175, '1976-01-01', 'First published in SD Archives, january 1976', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (1368, '1998-09-30 22:00:00+00', '2021-06-21 23:16:12.878561+00', 'Countess of Sutherland''s Reel, The', 'COUNTESS OF SUTHERLANDS REEL', 1, 32, 9999, 1, 3, 42, 9998, '1797-01-01', '', 34, '800  800  822  844', 1, 1, 0, 1, 45);
INSERT INTO 'dance' VALUES (12080, '2005-03-09 23:00:00+00', '2019-03-27 18:37:26.405035+00', 'Covalence', 'COVALENCE', 3, 32, 9999, 1, 4, 1, 3107, '1992-01-01', '', 97, '8888  8888  8848  8888', 1, 1, 1, 1, 96);
INSERT INTO 'dance' VALUES (18258, '2018-03-11 10:37:18.044322+00', '2018-07-19 04:14:13.597855+00', 'High Time', 'HIGH TIME', 3, 32, NULL, 1, 2, 76, 11534, '2018-03-09', '“Devised for two wonderful friends and their momentous day on 9th March 2018.”', 48, '73/73/80/88', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14519, '2012-07-19 23:42:32.884384+00', '2018-10-04 05:10:45.573036+00', 'Custom Builder, The', 'CUSTOM BUILDER', 2, 32, NULL, 1, 3, 42, 2766, '2010-09-07', 'In memory of Sue''s uncle George, who was a custom home builder in New Jersey and died on 7 September 2010 at age 86.', 37, '800  844  844  800', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (8165, '2003-01-30 23:00:00+00', '2018-11-24 21:58:52.687475+00', 'Crossing the Line', 'CROSSING THE LINE', 1, 32, 9999, 2, 3, 30, 108, '1996-01-01', '', 75, '888/880/800/888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (9083, '2002-12-16 23:00:00+00', '2022-10-04 14:32:18.71094+00', 'Craven Jig, The', 'CRAVEN JIG', 2, 32, 9999, 1, 4, 1, 175, '1998-01-01', 'Devised February 1998, and dedicated tio the North West Craven Branch of the RSCDS on the occasion of their 40th anniversary.', 50, '8000  8484  8484  8000', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (1405, '1998-11-14 23:00:00+00', '2023-02-17 12:08:02.511798+00', 'Cramond Bridge', 'CRAMOND BRIDGE', 1, 32, 9999, 1, 3, 42, 805, NULL, 'According to the notes Valerie Farr''s maiden name was Crammond and "Cramond Bridge spans the River Almond on the Western outskirts of the City of Edinburgh."', 44, '800  844  844  844', 1, 1, 0, 1, 58);
INSERT INTO 'dance' VALUES (1382, '1998-09-28 22:00:00+00', '2023-02-17 12:22:31.392415+00', 'Cradle Song, The', 'CRADLE SONG', 3, 32, 9999, 1, 3, 42, 108, '1976-01-01', '', 66, '880  848  888  888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (14395, '2012-01-06 23:00:00+00', '2014-04-30 23:23:45.776752+00', 'Crossing Paths', 'CROSSING PATHS', 3, 32, NULL, 1, 3, 42, 10598, NULL, 'Recommended music: Cairngorms, by Robert H. MacKay (Muriel Johnstone and Keth Smith)', 56, '800  844  888  880', 0, 0, 0, 0, 75);
INSERT INTO 'dance' VALUES (11277, '2003-05-04 22:00:00+00', '2014-04-30 23:23:45.840904+00', 'Crowcombe and Stogumber', 'CROWCOMBE AND STOGUMBER', 1, 32, 9999, 1, 3, 42, 401, '2001-06-06', 'For Ken McFarland and the SC dancers on the English Manors Tour 2001.  Crowcombe and Stogumber (CROW-come and Sta-GUM-ber) are two villages in Somerset near Halsway (HALL-zee) Manor where Ken arranged for us to stay and dance.', 56, '800  844  888  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (13364, '2009-08-02 22:00:00+00', '2014-04-30 23:23:45.884349+00', 'Cruit Mo Chridh', 'CRUIT MO CHRIDH', 1, 32, NULL, 1, 3, 42, 101, NULL, 'Inscribed to Bertha Small.  The name is pronounced *crootch mochree*.', 57, '800  866  866  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (1495, '2001-05-21 22:00:00+00', '2019-04-18 17:34:37.032242+00', 'Dagmar''s Fancy', 'DAGMARS FANCY', 3, 32, 9999, 2, 3, 17, 228, '1993-01-01', '', 83, '888  888  800  888', 0, 0, 0, 0, 83);
INSERT INTO 'dance' VALUES (1473, '2002-03-11 23:00:00+00', '2014-04-30 23:23:45.944327+00', 'Culla Bay', 'CULLA BAY', 3, 32, 9999, 4, 4, 1, 104, '1992-01-01', '', 81, '8484  8888  8888  0808', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (1478, '1998-11-07 23:00:00+00', '2014-04-30 23:23:45.974065+00', 'Cumberland Reel', 'CUMBERLAND REEL', 2, 32, 9999, 1, 4, 1, 9998, NULL, 'As with many dances of ceilidh origin, there are several variants of the "Cumberland Reel".  In the RSCDS version (Book 1 #11) the figure "dance down and lead up" is 6+6 bars [bars 17-28].  The crib shows this version.



The diagram shows another version.  The figure is now 4+4 [bars 17-24], which is easier to dance.  Then "all turn partner RH" is added at the end to fill in the missing 4 bars.



In yet other versions 3c+4c also dance "RHA ; LHA" for bars 1-8.', 69, '8800  8000  12 12 12 12   4444', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (1480, '1998-09-29 22:00:00+00', '2014-04-30 23:23:46.003961+00', 'Cumbrae Reel, The', 'CUMBRAE REEL', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 47, '880  880  880  822', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (1465, '1999-10-07 22:00:00+00', '2019-06-11 21:34:48.72537+00', 'Cuckoo Clock, The', 'CUCKOO CLOCK', 1, 32, 9999, 1, 3, 42, 21, '1991-01-01', '', 69, '888  880  888  888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (1424, '2002-02-28 23:00:00+00', '2019-09-08 11:06:35.870784+00', 'Crockett''s Victory Garden', 'CROCKETTS VICTORY GARDEN', 1, 32, 9999, 1, 4, 1, 406, '1972-01-01', '', 50, '8000  8800  8440  8448', 0, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (18254, '2018-03-11 09:36:21.771524+00', '2018-03-11 21:23:14.437724+00', 'Finnish RoMance, A', 'FINNISH ROMANCE', 4, 192, 3, 2, 3, 3, 10612, NULL, '', 44, '800/888/888/800', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1492, '2001-03-13 23:00:00+00', '2014-10-26 14:16:10.678418+00', 'Rain Dancin'', Da', 'RAIN DANCIN', 1, 32, 9999, 1, 3, 42, 401, '1991-01-01', '', 53, '844  844  822  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (10693, '2002-07-21 22:00:00+00', '2014-11-06 08:40:37.202459+00', 'Dance for Alisa', 'DANCE FOR ALISA', 2, 32, 9999, 1, 2, NULL, 2961, NULL, '', 69, '88  88  88  88', 0, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (1486, '2001-10-18 22:00:00+00', '2018-01-13 00:22:04.335287+00', 'Currie Mountain', 'CURRIE MOUNTAIN', 1, 32, 9999, 1, 3, 42, 602, NULL, 'A note from the dance which may be of interest:



"Currie Mountain is a pine-clad hill on the left bank of the Saint John River five miles east of Fredericton. For many years the property of the Currie Family, the mountain was donated to in 1965 to the University of New Brunswick by Dr Earl Turner on condition that it remain in its natural state."', 50, '800  844  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (7662, '1998-04-24 22:00:00+00', '2016-04-19 12:59:57.251557+00', 'Croft Castle', 'CROFT CASTLE', 3, 32, 9999, 2, 3, 17, 181, NULL, 'Devised to celebrate the Silver Jubilee of the Herefordshire Branch.', 67, '844  800  888  088', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (18259, '2018-03-11 10:43:51.779643+00', '2018-04-02 00:34:49.289268+00', 'Summer Party, A', 'SUMMER PARTY', 1, 32, NULL, 1, 3, 42, 10951, NULL, '“Devised for Matthias [Rank] and Ramona [Zohm] on the occasion of their wedding with thanks for much fun I had dancing with them at Summer School in St Andrews.”', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12023, '2005-02-15 23:00:00+00', '2018-04-03 00:07:40.140379+00', 'Crossing Corryvreckan', 'CROSSING CORRYVRECKAN', 1, 32, 9999, 1, 3, 42, 3508, '2005-01-01', '', 45, '808  080  888  820', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (18257, '2018-03-11 10:32:22.273935+00', '2018-04-02 00:34:20.190517+00', 'Bavaria Birl', 'BAVARIA BIRL', 1, 32, NULL, 1, 3, 42, 11134, NULL, '“Devised on the occasion of the wedding of Ramona Zohm and Matthias Rank – two dancers not averse to a good birl! – in Munich, 9th March 2018.”', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10771, '2002-09-25 22:00:00+00', '2018-04-03 00:07:40.179819+00', 'Crossing the Bay', 'CROSSING THE BAY', 3, 32, 9999, 1, 3, 42, 175, NULL, '', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (1469, '1998-09-29 22:00:00+00', '2020-07-17 16:03:02.234518+00', 'Cuillins of Skye', 'CUILLINS OF SKYE', 3, 32, 9999, 1, 3, 42, 146, '1977-01-01', '', 64, '888  802  888  888', 1, 1, 1, 1, 85);
INSERT INTO 'dance' VALUES (13696, '2011-06-29 22:00:00+00', '2020-09-19 11:41:02.963037+00', 'Daffodil Strathspey, The', 'DAFFODIL STRATHSPEY', 3, 32, NULL, 1, 3, 42, 3199, '2007-01-01', 'Spring 2007, when the daffodils come out.', 45, '707  880  822  844', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (9103, '2001-11-21 23:00:00+00', '2021-01-17 00:28:26.390891+00', 'Cutty Sark', 'CUTTY SARK', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 47, '800  880  822  888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (10866, '2002-10-13 22:00:00+00', '2021-02-04 12:18:55.634312+00', 'Crieff Hydro', 'CRIEFF HYDRO', 2, 32, 9999, 1, 3, 42, 479, NULL, '', 47, '880  822  822  866', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (10366, '2007-04-01 22:00:00+00', '2021-02-09 12:28:08.384083+00', 'Dance of the Decades', 'DANCE OF THE DECADES', 4, 128, 2, 1, 4, 11, 316, NULL, '', 81, '8008  8888  8888  8448', 1, 1, 1, 1, 20);
INSERT INTO 'dance' VALUES (10356, '2002-04-24 22:00:00+00', '2021-02-09 12:40:50.081881+00', 'Crossing the Tay', 'CROSSING THE TAY', 3, 32, 9999, 1, 4, 2, 831, '2002-01-01', 'Dedicated to Bruce Frazer and Ian Muir, from Dundee.', 75, '4444  4884  8888  8448', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (8603, '1998-07-09 22:00:00+00', '2021-03-16 10:17:12.623679+00', 'Dance With Me?', 'DANCE WITH ME', 2, 32, 9999, 2, 3, 17, 2018, NULL, '', 54, '444  880  844  800', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (1467, '1997-08-25 22:00:00+00', '2021-06-18 21:03:36.18986+00', 'Cuddy, The', 'CUDDY', 2, 32, 9999, 1, 3, 42, 101, '1986-01-01', 'The Cuddy is a small stretch of the Eddleston Water, near Peebles.', 53, '888  800  822  888', 1, 1, 0, 1, 70);
INSERT INTO 'dance' VALUES (12106, '2005-03-20 23:00:00+00', '2021-07-09 08:41:32.86196+00', 'Dance Illustrator, The', 'DANCE ILLUSTRATOR', 3, 32, 9999, 1, 4, 2, 3522, '2003-07-01', 'The notes say this was devised "by Sue Porter July 2003 for her father, Dan Blackwood''s 80th birthday on 4th August 2003, which he celebrated while attending the Senior Class at Summer School. Dan is the illustrator of the Society''s notelets and many posters depicting dances. This dance shows his connection with the Scouts, painting and having a ''reel'' good time dancing."



Published as a 4 page leaflet (information from <<https://my.strathspey.org/dd/issue/2548/|issue 2548>>).', 84, '8888  8888  8004  8888', 1, 1, 1, 1, 84);
INSERT INTO 'dance' VALUES (13904, '2011-08-22 22:00:00+00', '2018-04-08 08:30:55.081386+00', 'Elegant Gentleman, The', 'ELEGANT GENTLEMAN', 4, 256, 55, 1, 3, 42, 10403, '2007-01-01', 'Devised in 2007 by Sandra Turton and Norma Craven of the 51st Club (Johannesburg Branch) in memory of Geoff Muller, a dancer of note, an inspiring teacher and a truly elegant gentleman.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8235, '1998-01-04 23:00:00+00', '2019-03-07 00:33:15.707141+00', 'Dawn in the Heather', 'DAWN IN THE HEATHER', 3, 32, 9999, 4, 4, 1, 1194, '1994-01-01', '', 94, '6  8  8  8', 0, 1, 0, 0, 23);
INSERT INTO 'dance' VALUES (1549, '1998-04-08 22:00:00+00', '2019-03-17 23:30:09.073256+00', 'Dancing Years, The', 'DANCING YEARS', 1, 88, 9999, 4, 4, 3, 146, '1992-01-01', '', 59, '44  44  44  44  44  44  44  44  84  48  88', 0, 1, 0, 0, 59);
INSERT INTO 'dance' VALUES (11872, '2004-10-31 23:00:00+00', '2019-04-02 20:45:47.790565+00', 'Dancing in the Cuckoo''s Nest', 'DANCING IN THE CUCKOOS NEST', 3, 32, 9999, 1, 3, 42, 479, '2000-01-01', '', 69, '400  12 12 12  888  888', 0, 1, 0, 0, 91);
INSERT INTO 'dance' VALUES (1499, '1998-03-08 23:00:00+00', '2023-02-12 16:35:44.646628+00', 'Dalesman, The', 'DALESMAN', 1, 40, 9999, 1, 3, 42, 146, NULL, 'Inscribed "In memory of Will Milner, 1910-1990, a friend to everyone."', 60, '804  855  855  888  888', 1, 1, 0, 0, 80);
INSERT INTO 'dance' VALUES (1476, '1999-11-01 23:00:00+00', '2023-02-17 11:49:26.069412+00', 'Culloden''s Fancy', 'CULLODENS FANCY', 1, 16, 9999, 1, 2, 76, 9998, '1754-02-01', '', 52, '84  84', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (1452, '1997-08-31 22:00:00+00', '2023-02-17 11:53:41.402892+00', 'Crown Court', 'CROWN COURT', 2, 32, 9999, 1, 3, 42, 430, NULL, '', 44, '880  880  844  844', 1, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (1428, '1998-09-29 22:00:00+00', '2023-02-17 12:03:41.00247+00', 'Cromarties Rant', 'CROMARTIES RANT', 1, 32, 9999, 1, 3, 42, 432, '1812-01-01', '', 28, '440  440  800  822', 1, 1, 0, 1, 37);
INSERT INTO 'dance' VALUES (8514, '2002-03-04 23:00:00+00', '2014-04-30 23:23:46.758173+00', 'Ddraig Goch', 'DDRAIG GOCH', 1, 32, 9999, 1, 3, 42, 2074, NULL, '', 44, '840  844  844  804', 1, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (1588, '2000-09-20 22:00:00+00', '2014-04-30 23:23:46.802957+00', 'Dean Bridge of Edinburgh, The', 'DEAN BRIDGE OF EDINBURGH', 3, 32, 9999, 1, 3, 42, 173, NULL, '', 66, '844  888  884  888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (7152, '1998-11-24 23:00:00+00', '2014-04-30 23:24:15.647379+00', 'Wild Goose Chase, The', 'WILD GOOSE CHASE', 2, 32, 9999, 1, 4, 2, 108, '1982-01-01', '', 75, '8008  8888  8888  8008', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (1546, '2002-04-30 22:00:00+00', '2019-07-19 08:47:13.353143+00', 'Dancing Shepherds, The', 'DANCING SHEPHERDS', 2, 32, 9999, 1, 3, 42, 89, NULL, '', 56, '880  844  844  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14811, '2013-04-15 18:59:54.274906+00', '2014-04-30 23:24:15.67915+00', 'Will Starr', 'WILL STARR', 2, 32, NULL, 1, 2, NULL, 2682, '2013-04-15', 'For teaching La-Chain in quicktime.', 56, '80  88  88  84', 1, 1, 1, 0, 81);
INSERT INTO 'dance' VALUES (9559, '2001-11-21 23:00:00+00', '2014-09-25 14:10:40.363315+00', 'Dancers'' Wedding, The', 'DANCERS WEDDING', 1, 32, 9999, 1, 3, 42, 2787, '1998-01-01', '', 56, '800  888  888  844', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (9500, '2001-07-30 22:00:00+00', '2016-06-03 13:37:45.769382+00', 'Dancing at the Mill', 'DANCING AT THE MILL', 3, 32, 9999, 1, 3, 42, 228, NULL, '', 51, '810  880  888  844', 1, 1, 1, 1, 67);
INSERT INTO 'dance' VALUES (1625, '1998-07-08 22:00:00+00', '2021-04-17 21:46:33.470882+00', 'Deveron Reel, The', 'DEVERON REEL', 1, 40, 9999, 1, 100, 2, 108, '1977-01-01', 'Drewry writes that the river Deveron is one of the major rivers of N.E Scotland. It rises in the hills N.W. of Alford and flows through Huntly being joined by the Bogie. Huntly Castle, home of the Clan Gordon chiefs, was built at this confluence. The Deveron reaches the Moray Firth between the towns of Banff and Macduff.', 67, '8008  0880  0880  8888  8668', 1, 1, 1, 1, 67);
INSERT INTO 'dance' VALUES (1521, '2002-04-24 22:00:00+00', '2021-10-02 14:43:54.366927+00', 'Dance of Diamonds, The', 'DANCE OF DIAMONDS', 1, 32, 9999, 1, 3, 42, 68, '1983-01-01', '', 53, '888/800/822/888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (9222, '2001-12-17 23:00:00+00', '2020-03-17 19:55:17.408072+00', 'Dancing Career, A', 'DANCING CAREER', 2, 32, 9999, 1, 2, 76, 108, '1997-01-01', '', 64, '84  88  88  88', 0, 1, 0, 0, 93);
INSERT INTO 'dance' VALUES (5171, '1998-09-17 22:00:00+00', '2021-04-25 13:12:27.172282+00', 'Dance With Mother', 'DANCE WITH MOTHER', 1, 32, 9999, 1, 3, 42, 168, NULL, '', 50, '800  888  800  888', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (13697, '2011-06-29 22:00:00+00', '2020-09-19 13:16:24.231312+00', 'Dancing Towers', 'DANCING TOWERS', 2, 40, NULL, 1, 4, 11, 3135, '2007-01-01', '', 90, '6666  8888  8888  8888  8448', 1, 1, 1, 1, 90);
INSERT INTO 'dance' VALUES (8859, '2002-11-03 23:00:00+00', '2020-09-27 08:53:25.95313+00', 'Dee in Spring, The', 'DEE IN SPRING', 3, 32, 9999, 2, 3, 18, 51, '1996-04-01', 'The dance was presented to Sally Dee at the April 1996 Salem Spring Party in Salem, Massachusetts. The dance is meant to express timeless strength, beauty, and joy, like the Dee in Spring.



Being originally devised in April 1996, the dance was revised and corrected in September 2013.', 69, '880  888  888  888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (9059, '2002-10-10 22:00:00+00', '2020-11-11 21:09:18.692571+00', 'Dr Wm Cunningham', 'DR WM CUNNINGHAM', 1, 40, 9999, 1, 3, 42, 815, '1997-01-01', '', 57, '822  844  888  844  888', 0, 0, 0, 0, 76);
INSERT INTO 'dance' VALUES (12675, '2006-02-14 23:00:00+00', '2021-01-11 11:32:55.263086+00', 'Dancing Hands', 'DANCING HANDS', 3, 32, 9999, 1, 3, 42, 1445, '2006-01-01', '', 53, '880  880  888  822', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (9406, '2001-08-19 22:00:00+00', '2021-01-08 10:07:03.812322+00', 'Dancing Forth', 'DANCING FORTH', 1, 32, 9999, 1, 3, 42, 531, '1999-01-01', 'Dance devised to celebrate the 75th Anniversary of the founding of the Edinburgh Branch in 1924.', 56, '822/888/822/888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (10788, '2002-08-25 22:00:00+00', '2021-02-05 12:30:36.10417+00', 'Dancing in the Street', 'DANCING IN THE STREET', 1, 32, 9999, 1, 4, 1, 827, NULL, '', 88, '8080  8888  8888  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (8344, '1998-01-04 23:00:00+00', '2021-03-20 13:03:49.132814+00', 'Dancing Dominie, The', 'DANCING DOMINIE', 3, 32, 9999, 1, 4, 11, 13, '1996-01-01', '"In memory of the late Barry Priddey - a teacher by profession, a dancer by inclination."', 94, '8888  8888  8448  8888', 0, 1, 0, 0, 93);
INSERT INTO 'dance' VALUES (8120, '1998-04-24 22:00:00+00', '2021-03-21 20:08:15.348636+00', 'Wilhelm Tell Strathspey, The', 'WILHELM TELL STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1445, '1996-01-01', '', 61, '820  888  866  888', 0, 0, 0, 0, 81);
INSERT INTO 'dance' VALUES (8811, '2002-01-08 23:00:00+00', '2021-03-27 19:25:14.41079+00', 'Devil in the Bearpit, The', 'DEVIL IN THE BEARPIT', 1, 32, 9999, 2, 3, 17, 2409, '1998-10-30', 'Variant on ladies chain figure and an unexpected entrance to Poussette. Devised on 30 October 1998, to be danced to the music for Deil Amang the Tailors. The Devil in the title is, of course, the one who has finished with the Tailors and is now in Berne, Switzerland, visiting the city''s chief tourist attraction.', 74, '880  771  808  888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (1544, '2002-03-03 23:00:00+00', '2021-04-17 17:44:59.892115+00', 'Dancing Master, The', 'DANCING MASTER', 2, 96, 9999, 4, 4, 3, 108, '1989-04-01', 'A dance to mark the retirement of Bill Ireland as teacher of the London Branch Demonstration Class ', 83, '8080  8484  8888  8484    0808  4848  8888  4848    8888  8888  8888  8888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (1558, '2002-02-27 23:00:00+00', '2021-06-17 21:14:09.601565+00', 'Dark Lochnagar', 'DARK LOCHNAGAR', 3, 32, 9999, 1, 2, 76, 44, NULL, '', 69, '88  88  88  88', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (1641, '2002-02-28 23:00:00+00', '2014-04-30 23:23:46.996928+00', 'Dhoon, The', 'DHOON', 2, 32, 9999, 1, 4, 1, 454, '1981-01-01', 'The Dhoon is a sandy bay near Kirkudbright, much loved by children+', 81, '8888  8888  8000  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (11278, '2003-05-04 22:00:00+00', '2014-04-30 23:23:47.071934+00', 'Diamond Quarrie, The', 'DIAMOND QUARRIE', 1, 32, 9999, 1, 3, 42, 1760, '2002-01-01', 'Devised on the occasion of Avril Quarrie''s ''significant'' (60th) birthday.', 53, '880  888  822  844', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (14396, '2012-01-06 23:00:00+00', '2019-02-19 15:57:30.362282+00', 'Diamond Celebration, The', 'DIAMOND CELEBRATION', 3, 40, NULL, 1, 4, 1, 3444, '2007-01-01', '', 90, '8880  8888  0888  8888  8888', 0, 1, 0, 0, 90);
INSERT INTO 'dance' VALUES (1615, '2000-09-20 22:00:00+00', '2019-03-12 22:07:03.475208+00', 'Delvine Side', 'DELVINE SIDE', 3, 32, 9999, 1, 3, 42, 263, '1790-01-01', 'According to the notes in the original RSCDS Book II: 



- Delvine is near Dunkeld 



- The dance was taken from "William Campbell''s Country Dances". Published about 1790.



There is a nice video of this dance at  http://www.rscds-atlanta.org/MovieClips/scotD2.m4v.', 41, '880  800  880  822', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (1647, '1998-09-29 22:00:00+00', '2019-10-29 19:59:20.322149+00', 'Diamond Jubilee, The', 'DIAMOND JUBILEE', 2, 32, 9999, 1, 4, 2, 62, '1981-01-01', '', 87, '8008  8888  8888  8888', 0, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (1562, '2002-01-08 23:00:00+00', '2022-05-07 21:31:51.65992+00', 'Dashing White Sergeant, The', 'DASHING WHITE SERGEANT', 1, 32, 9999, 5, 56, NULL, 9998, NULL, '', 92, '888  484  888  888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (1586, '2002-11-13 23:00:00+00', '2022-07-31 10:17:02.812716+00', 'Deacon of the Weavers, The', 'DEACON OF THE WEAVERS', 3, 32, 9999, 1, 3, 42, 9998, NULL, 'The dance was taken from "A Collection of Scots Reels or Country Dances for the year 1769" by <<ddp:Bremner, Robert>>.', 47, '880  800  822  844', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (10579, '2002-05-12 22:00:00+00', '2022-08-19 09:05:36.450218+00', 'Willie Winkie', 'WILLIE WINKIE', 2, 48, 9999, 1, 4, 1, 3135, '1999-01-01', '', 65, '8888  4224  8008  4884  8000  8444', 0, 1, 0, 0, 64);
INSERT INTO 'dance' VALUES (9084, '1999-07-25 22:00:00+00', '2022-10-04 13:31:28.062917+00', 'Domino Five', 'DOMINO FIVE', 1, 32, 9999, 4, 55, 6, 175, NULL, 'This dance is included to give an example of basic right and left shouldered reels of three from each starting position', 55, '44448  80808  08088  42442', 1, 1, 1, 1, 55);
INSERT INTO 'dance' VALUES (8133, '2002-03-11 23:00:00+00', '2022-10-14 20:06:36.505519+00', 'Dundee Sailor, The', 'DUNDEE SAILOR', 1, 32, 9999, 1, 3, 42, 1445, '1995-01-01', 'This dance was devised for Ellen and Ferry Schütt. They met in wartime Dundee, where Ferry was stationed as a sailor in the submarine corps.', 47, '888  800  822  844', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (9830, '2001-04-29 22:00:00+00', '2022-12-19 14:32:55.967613+00', 'Dancing Ribbons', 'DANCING RIBBONS', 3, 32, 9999, 1, 4, 1, 2860, '2000-01-01', '', 94, '8888  8888  8888  0888', 0, 1, 0, 0, 93);
INSERT INTO 'dance' VALUES (1578, '1998-11-14 23:00:00+00', '2023-02-12 16:16:22.2687+00', 'Davy Nick Nack', 'DAVY NICK NACK', 1, 32, 9999, 1, 3, 42, 62, '1965-01-01', '', 47, '888  800  833  833', 1, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (14612, '2012-12-17 23:24:59.985203+00', '2014-04-30 23:23:47.266887+00', 'Double Diamond, A', 'DOUBLE DIAMOND', 2, 40, NULL, 2, 3, 17, 2627, '2012-01-01', 'Dedicated to Isabelle on her 17th birthday.  So called because both the Queen and Winchester Branch celebrate their Diamond Jubilee this year.', 73, '800  888  888  800  888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (1713, '1997-09-01 22:00:00+00', '2016-07-15 12:49:22.244867+00', 'Doughnuts Reel', 'DOUGHNUTS REEL', 2, 32, 9999, 4, 4, 1, 838, NULL, 'dance twice, 2c+4c beginning second time.', 75, '4444  8888  4444  8888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (11393, '2003-07-06 22:00:00+00', '2016-12-06 21:34:55.344651+00', 'Double Diamond Strathspey, The', 'DOUBLE DIAMOND STRATHSPEY', 3, 32, 9999, 1, 4, 1, 146, NULL, 'For Susan and Alan Carr', 69, '8888  4444  4444  8088', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (18261, '2018-03-14 14:22:31.212783+00', '2018-03-15 23:19:19.18102+00', 'Ballylesson''s Ruby Celebrations', 'BALLYLESSONS RUBY CELEBRATIONS', 2, 32, NULL, 3, 5, 7, 10387, '2018-01-01', 'Ballylesson Dance Class was formed fourty years ago, five of the original members are still dancing in the class.   This dance with devised to show appreciation for the excellent tuition the class has received over these years from our talented teachers, Hilary Ferguson, Sharon Ross and present teacher Linda Cooper. ', 55, '80800/88808/80880/80800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18651, '2018-09-18 23:15:21.91405+00', '2018-09-19 09:13:49.164748+00', 'Sunflower, The', 'SUNFLOWER', 2, 32, NULL, 1, 3, 42, 3617, '2002-02-01', 'A good dance to teach the Allemande.', 49, '880/800/880/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16928, '2016-04-16 00:33:02.641346+00', '2018-09-19 09:47:28.790938+00', 'Margaret Lambourne''s Strathspey', 'MARGARET LAMBOURNES STRATHSPEY', 3, 40, NULL, 2, 3, 17, 3645, '2016-03-01', 'Devised for Margaret Lambourne', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1783, '2001-04-03 22:00:00+00', '2020-05-16 09:11:59.247789+00', 'Duke he was a Bonnie Beau, The', 'DUKE HE WAS A BONNIE BEAU', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 69, '88  88  88  88', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (1848, '1997-08-24 22:00:00+00', '2020-06-19 22:35:19.648824+00', 'Dunkeld House', 'DUNKELD HOUSE', 2, 32, 9999, 1, 3, 42, 108, '1989-01-01', '', 53, '888  844  822  844', 1, 1, 0, 1, 70);
INSERT INTO 'dance' VALUES (18593, '2018-09-15 18:28:18.432599+00', '2020-11-17 20:20:48.299163+00', 'Scarborough Holiday, A', 'SCARBOROUGH HOLIDAY', 2, 96, NULL, 4, 4, 3, 2886, NULL, 'For Scarborough Holidays 2007 and 2008', 83, '8888/8888/8888/8080/0808/8888/8888/8080/0808/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14249, '2011-09-02 22:00:00+00', '2020-12-26 10:04:53.171465+00', 'Duke of Gelre', 'DUKE OF GELRE', 3, 32, NULL, 1, 4, 1, 10478, NULL, '', 100, '8888  8888  8888  8888', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (13436, '2009-11-16 23:00:00+00', '2021-01-02 13:44:08.108362+00', 'Diamond Celebration Jig, The', 'DIAMOND CELEBRATION JIG', 2, 32, 9999, 1, 3, 42, 10323, NULL, 'Published in the Diamond Jubilee Collection of the RSCDS Inverness and District Branch: http://my.strathspey.org/dd/publ/1027/', 56, '800  888  844  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (13275, '2007-04-01 22:00:00+00', '2021-01-03 13:52:46.355175+00', 'Don & Dee''s Reel', 'DON AND DEES REEL', 1, 32, 9999, 3, 5, 7, 316, '2004-01-01', 'Devised: 2004', 57, '80800  63663  63663  84844', 1, 1, 1, 1, 57);
INSERT INTO 'dance' VALUES (1763, '1998-04-08 22:00:00+00', '2021-01-14 21:24:27.241035+00', 'Drummond Castle', 'DRUMMOND CASTLE', 2, 32, 9999, 1, 3, 42, 108, '1992-01-01', '', 66, '844/888/866/888', 1, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (11512, '2003-10-02 22:00:00+00', '2021-01-23 20:50:25.234367+00', 'Double Eighty', 'DOUBLE EIGHTY', 3, 32, 9999, 1, 4, 2, 2024, '2003-01-01', '', 81, '8888  6666  8008  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (11013, '2002-11-24 23:00:00+00', '2021-01-30 11:09:44.69746+00', 'Don''s Reel', 'DONS REEL', 1, 40, 9999, 1, 3, 42, 374, NULL, '', 57, '888  800  888  888  804', 0, 1, 0, 0, 76);
INSERT INTO 'dance' VALUES (10669, '2002-07-21 22:00:00+00', '2021-02-06 11:22:38.409929+00', 'Devil''s Quandary', 'DEVILS QUANDARY', 3, 40, 9999, 1, 3, 42, 2961, NULL, '', 65, '800  888  888  888  888', 0, 1, 0, 0, 86);
INSERT INTO 'dance' VALUES (10114, '2001-10-17 22:00:00+00', '2021-02-11 15:05:58.919739+00', 'Doctor''s Dilemma', 'DOCTORS DILEMMA', 1, 48, 9999, 1, 4, 13, 17, '1980-01-01', 'Devised to practice appropriate signaling and quick reactions - or simply as a fun dance.', 67, '8484  8484  8400  4044  8888  4848', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (10014, '2001-08-19 22:00:00+00', '2021-02-13 15:36:48.472165+00', 'Double Top Jig', 'DOUBLE TOP JIG', 2, 32, 9999, 1, 3, 42, 831, NULL, 'For Eileen and Neil Oxlade in celebration of their 40th birthdays.', 61, '842  888  844  888', 0, 1, 0, 0, 81);
INSERT INTO 'dance' VALUES (9855, '2001-08-19 22:00:00+00', '2021-02-17 20:00:36.129212+00', 'Dog''s Breakfast, A', 'DOGS BREAKFAST', 2, 32, 9999, 1, 3, 42, 21, NULL, '', 59, '844  866  888  880', 0, 1, 0, 0, 79);
INSERT INTO 'dance' VALUES (8562, '2001-06-12 22:00:00+00', '2021-03-16 18:21:13.183376+00', 'Doo''cot, The', 'DOOCOT', 3, 32, 9999, 1, 3, 42, 2024, NULL, '', 50, '880  844  888  800', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (8665, '1998-03-31 22:00:00+00', '2021-03-15 22:26:40.809313+00', 'Dove Cot Chase, The', 'DOVE COT CHASE', 2, 32, 9999, 1, 3, 42, 2106, NULL, '', 62, '888  880  888  880', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (1677, '1998-09-29 22:00:00+00', '2021-06-15 11:31:57.949116+00', 'Donald Bane', 'DONALD BANE', 3, 32, 9999, 1, 3, 42, 432, '1816-01-01', '', 59, '888  844  888  822', 1, 1, 0, 1, 79);
INSERT INTO 'dance' VALUES (5693, '2002-03-03 23:00:00+00', '2019-03-11 11:10:52.365784+00', 'Dunnet Head', 'DUNNET HEAD', 1, 32, 9999, 1, 4, 1, 218, NULL, '', 66, '4444  4444  8888  8444', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (1854, '2002-03-03 23:00:00+00', '2019-03-19 09:38:05.44882+00', 'Duns 500', 'DUNS 500', 3, 64, 9999, 4, 4, 3, 388, '1990-01-01', 'Devised to mark the quincentenary in 1990 of the granting of the Burgh of Barony Charter to Duns, the county town of Berwickshire.  The tune, Eagle Hall, is the home of the well-known accordionist Marian Anderson.', 69, '8080  0808  8888  8080  0808  4444  8888  8888', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (7694, '2002-10-28 23:00:00+00', '2014-04-30 23:23:47.884926+00', 'Dunnington Strathspey, The', 'DUNNINGTON STRATHSPEY', 3, 32, 9999, 2, 3, 18, 854, NULL, '', 92, '888   880  12 12 12  444', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (1834, '1999-08-09 22:00:00+00', '2019-05-04 13:22:46.8552+00', 'Dundee Reel', 'DUNDEE REEL', 2, 40, 9999, 1, 3, 42, 9998, NULL, 'This is the "Standard" version of this Jig, as described n the "Border Book", but many other versions have always existed.  The local 48-bar Dundee version is also on this database', 55, '888/888/800/844/844', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (15724, '2015-01-07 15:13:58.409747+00', '2015-01-07 15:13:58.409747+00', 'Swallowdale', 'SWALLOWDALE', 3, 32, 9999, 3, 5, 16, 3549, '2002-05-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1777, '1998-11-14 23:00:00+00', '2016-11-21 17:01:03.74802+00', 'Duchess Tree, The', 'DUCHESS TREE', 3, 32, 9999, 1, 3, 42, 108, '1971-01-01', 'Drewry writes" The Duchess Tree was a lime tree in the grounds of Gordon Castle at Fochabers. It spread to vast proportions and, when measured in 1911, had a girth of 17 feet 5 inches and a circumference of

144 yards. Sadly the tree is no more but was famous in its time and marked on ordnance survey maps. (I am indebted to Margaret Cooke of Forres for this information.)', 62, '888  888  880  880', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (1816, '1997-04-03 22:00:00+00', '2019-08-07 17:22:15.138026+00', 'Duncan Gray', 'DUNCAN GRAY', 1, 40, 9999, 1, 3, 42, 108, '1967-01-01', 'Dedicated to Mr Bill Cheyne of Aberdeen.', 65, '880  888  888  844  888', 1, 1, 1, 1, 86);
INSERT INTO 'dance' VALUES (1799, '2001-09-06 22:00:00+00', '2018-04-03 00:07:43.318433+00', 'Dumbarton Drums', 'DUMBARTON DRUMS', 1, 32, 9999, 1, 3, 42, 432, '1816-01-01', '', 56, '888  800  880  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (12983, '2006-10-26 22:00:00+00', '2018-01-17 23:51:21.911083+00', 'Drunken Sailor, The', 'DRUNKEN SAILOR', 1, 32, 9999, 1, 3, 42, 3645, '2003-02-01', 'Edwin Werner revised this dance in 2011, changing the "Figures of Eight" in bars [17-24] into reels of three across with the end couple.   However, this variant has now (jan 2018) been withdrawn, and removed from SCDDB; only this original version remains. ', 41, '800/888/800/822', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (16385, '2015-05-21 14:56:31.314022+00', '2016-04-18 23:24:29.425763+00', 'Skippit a Wee', 'SKIPPIT A WEE', 2, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1841, '1997-12-26 23:00:00+00', '2022-08-11 23:13:44.249112+00', 'Dunedin Festival Dance, The', 'DUNEDIN FESTIVAL DANCE', 1, 32, 9999, 6, 3, 4, 175, '1991-01-01', '', 100, '888  888  888  888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1843, '1998-04-01 22:00:00+00', '2023-02-10 13:48:37.382198+00', 'Dunfermline Glen', 'DUNFERMLINE GLEN', 3, 32, 9999, 1, 2, 76, 146, NULL, 'Inscribed "For Anna Holden".', 42, '62  26  44  88', 0, 1, 0, 1, 62);
INSERT INTO 'dance' VALUES (1776, '1998-09-29 22:00:00+00', '2023-02-10 14:31:16.40338+00', 'Duchess of York', 'DUCHESS OF YORK', 3, 32, 9999, 1, 3, 42, 459, '1797-01-01', '', 44, '804  808  840  880', 1, 1, 0, 1, 58);
INSERT INTO 'dance' VALUES (12940, '2006-10-22 22:00:00+00', '2014-04-30 23:23:48.152859+00', 'Easy Wee Dance, An', 'EASY WEE DANCE', 1, 32, 9999, 1, 2, NULL, 2793, NULL, '', 69, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (18246, '2018-02-24 13:07:35.456372+00', '2018-11-22 20:23:20.717672+00', 'Chiswick Jig, The', 'CHISWICK JIG', 2, 32, NULL, 1, 3, 42, 11237, '2018-02-01', 'For the Chiswick Scottish Country Dance Club who requested a fairly simple warm up jig to use as the first dance on a programme.', 56, '800/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2484, '2002-02-26 23:00:00+00', '2019-01-05 23:24:20.449242+00', 'Elephant''s Stampede, The', 'ELEPHANTS STAMPEDE', 2, 48, 9999, 4, 4, 1, 2915, '1995-08-01', 'Danced on 19 August 1995 to celebrate the wedding of Helen Bonar and Steve Beaney in Aberdeen.

', 90, '8888/8686/8888/4444/8888/8888', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (1786, '2000-02-21 23:00:00+00', '2020-06-02 06:29:07.617782+00', 'Duke of Atholl''s Reel, The', 'DUKE OF ATHOLLS REEL', 2, 32, 9999, 1, 2, 76, 455, '1776-01-01', '', 52, '88/44/80/88', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (1768, '1998-09-30 22:00:00+00', '2020-10-19 10:15:32.751957+00', 'Drumtochty Glen', 'DRUMTOCHTY GLEN', 3, 32, 9999, 1, 3, 42, 495, NULL, '*From the publication (courtesy <<https://my.strathspey.org/dd/issue/2187/|this issue>>):*



"The dance was arranged for the Strathspey [sic] music composed by Nan

Main for Miss Anderson.  Miss Anderson''s home was in the Glen of

Drumtochty, which lies between Auchinblae and Cairn o''Mount.  There are

two Glens [sic], Drumtochty becoming Glen Sough as it nears the Cairn

o''Mount; the hill opposite Miss Anderson''s home is called Finella (the

alternative tune, also composed by Nan Main)."



*Additional information from Robb Quint:*



"Drumtochty Glen itself is a small coastal valley about a dozen miles from the North Sea in the part of southern Aberdeenshire that once was the now erstwhile Kincardineshire, running upward and westward from the little village of Auchenblae. To its north is the 1,524-foot Goyle Hill and to its south the 1,358-foot Finella Hill, alongside the northeast slope of which the annual (typically fourth Saturday in June) Drumtochty Highland Games is held.



At the head of the glen is Drumtochty Castle, an 1812 neo-gothic castellated mansion. During World War II this house was purchased by the Norwegian Government in Exile and used as a school for Norwegian refugee children. Between 1947 and 1971 it was a boys'' preparatory school. Today it is privately owned and run as a small (and very luxurious) hotel and event center, particularly for "fairy-tale" weddings, not only for the setting and appearance of the "castle," but all the more so because of the nearby "fairy-tale" Saint Palladius (Episcopal) Church,which is often used for the wedding ceremony in conjunction with the receptions and accommodations at the mansion. Through the short glen (only about two miles from its head at the castle down to its foot at Auchenblae) runs the Luther Water, a left tributary of the North Esk. To the north of the glen is the mostly coniferous Drumtochty Forest."', 68, '888  888  844  888', 0, 1, 0, 0, 91);
INSERT INTO 'dance' VALUES (1934, '1998-04-08 22:00:00+00', '2020-11-15 20:46:52.055919+00', 'Eilean Donan Castle', 'EILEAN DONAN CASTLE', 2, 48, 9999, 6, 3, 17, 159, NULL, '', 78, '822  800  888  888  888  888', 0, 1, 0, 0, 77);
INSERT INTO 'dance' VALUES (1790, '2002-03-11 23:00:00+00', '2020-12-06 10:58:52.049398+00', 'Duke of Hamilton''s Reel', 'DUKE OF HAMILTONS REEL', 3, 32, 9999, 1, 3, 42, 9998, '1754-01-01', '', 44, '880  800  844  844', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (9853, '2002-11-12 23:00:00+00', '2021-02-18 10:58:41.271718+00', 'Ederline', 'EDERLINE', 3, 32, 9999, 2, 3, 17, 2673, NULL, '', 54, '800  833  833  808', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (9385, '2000-04-11 22:00:00+00', '2021-02-25 16:00:31.23951+00', 'Earl of Northampton, The', 'EARL OF NORTHAMPTON', 3, 32, 9999, 1, 2, 76, 2719, '1995-01-01', '', 69, '88  88  88  88', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (8981, '1999-08-06 22:00:00+00', '2021-03-07 19:20:29.37156+00', 'Duns and District', 'DUNS AND DISTRICT', 1, 32, 9999, 1, 3, 42, 479, NULL, '', 47, '800  844  844  866', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (7696, '2001-12-17 23:00:00+00', '2021-03-23 21:36:55.256777+00', 'Durisdeer', 'DURISDEER', 3, 32, 9999, 1, 4, 2, 861, NULL, '', 75, '8008  8888  8888  8008', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (1884, '1999-08-06 22:00:00+00', '2021-06-12 18:41:11.507931+00', 'Earl of Mansfield, The', 'EARL OF MANSFIELD', 1, 48, 9999, 1, 4, 1, 108, '1980-01-01', '', 69, '8800  8888  6868  8080  8440  8484', 1, 1, 0, 1, 68);
INSERT INTO 'dance' VALUES (1829, '1998-07-06 22:00:00+00', '2021-06-13 08:33:51.203352+00', 'Dundee City Police Jig, The', 'DUNDEE CITY POLICE JIG', 2, 32, 9999, 3, 5, 8, 270, NULL, 'Canon. Requires 6x16 music.', 67, '{84840  88888} occurs 5 times in 6 rounds', 1, 1, 0, 1, 40);
INSERT INTO 'dance' VALUES (1804, '1998-04-08 22:00:00+00', '2021-06-13 08:58:33.82393+00', 'Dumfries Lad, The', 'DUMFRIES LAD', 3, 32, 9999, 2, 3, 17, 146, '1983-01-01', '"For Jackie Johnstone"', 73, '860  844  888  844', 1, 1, 0, 0, 72);
INSERT INTO 'dance' VALUES (1780, '1998-09-29 22:00:00+00', '2021-06-14 20:43:39.067051+00', 'Duff''s House', 'DUFFS HOUSE', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 52, '402  888  822  888', 1, 1, 0, 1, 68);
INSERT INTO 'dance' VALUES (1774, '1999-08-09 22:00:00+00', '2021-06-14 20:46:05.305609+00', 'Duchess of Buccleuch''s Favourite, The', 'DUCHESS OF BUCCLEUCHS FAVOURITE', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 44, '444  888  822  800', 1, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (1762, '2001-04-03 22:00:00+00', '2021-06-14 20:49:14.034299+00', 'Drummer, The', 'DRUMMER', 1, 48, 9999, 1, 3, 42, 453, '1752-01-01', '', 48, '840  880  880  844  888  800', 1, 1, 0, 1, 63);
INSERT INTO 'dance' VALUES (1757, '1997-08-25 22:00:00+00', '2021-06-15 08:16:09.592973+00', 'Drumduan Cottage', 'DRUMDUAN COTTAGE', 3, 32, 9999, 1, 3, 42, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Margaret Hutcheon of Drumduan Cottage, Forres.



The tune *Drumduan Cottage* was composed by Drummond Cook, who used to live at Drumduan Cottage.', 53, '880  822  888  844', 1, 1, 0, 1, 70);
INSERT INTO 'dance' VALUES (14269, '2011-09-15 22:00:00+00', '2014-04-30 23:23:48.33244+00', 'Eifel Welcome', 'EIFEL WELCOME', 3, 32, NULL, 1, 3, 42, 558, NULL, '', 50, '800  888  800  888', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (9004, '1999-04-24 22:00:00+00', '2019-03-05 20:57:14.047912+00', 'Elisabeth Hunter''s Strathspey', 'ELISABETH HUNTERS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 146, NULL, '', 69, '880  707  884  844', 0, 1, 0, 0, 68);
INSERT INTO 'dance' VALUES (8113, '1998-10-15 22:00:00+00', '2019-03-07 09:20:27.307822+00', 'Early in the Morning', 'EARLY IN THE MORNING', 1, 32, 9999, 3, 5, 7, 788, '1992-01-01', '', 59, '82822  80800  88888  80800', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (18262, '2018-03-15 18:05:16.386778+00', '2019-08-29 15:31:54.153543+00', 'Left is the new Right', 'LEFT IS THE NEW RIGHT', 1, 32, NULL, 2, 3, 17, 10805, '2018-01-01', '', 92, '888/484/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15182, '2013-10-14 07:58:24.670584+00', '2014-04-30 23:23:48.550874+00', 'Elm Tree Jig', 'ELM TREE JIG', 2, 40, NULL, 1, 4, 1, 3246, NULL, '', 60, '8888  8888  8800  8000  8000', 1, 1, 1, 0, 60);
INSERT INTO 'dance' VALUES (1916, '1999-08-06 22:00:00+00', '2018-04-03 00:07:44.068904+00', 'Edinburgh Volunteers', 'EDINBURGH VOLUNTEERS', 3, 24, 9999, 1, 3, 42, 862, '1796-01-01', '', 50, '620  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (1858, '1998-07-09 22:00:00+00', '2017-02-14 15:45:58.182007+00', 'Dunsmuir Strathspey, The', 'DUNSMUIR STRATHSPEY', 3, 32, 9999, 2, 3, 17, 108, '1991-01-01', '', 75, '800  888  888  844', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (18511, '2018-08-21 09:04:19.340796+00', '2018-09-03 19:49:41.64525+00', 'Grenoble Walnuts', 'GRENOBLE WALNUTS', 1, 32, NULL, 1, 3, 42, 11509, '2018-04-01', 'One of our dancers commented: not suitable for those who easily feel dizzy.', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18594, '2018-09-15 19:09:17.869869+00', '2018-09-15 19:09:17.869869+00', 'Eric''s Brush Strokes', 'ERICS BRUSH STROKES', 3, 32, NULL, 1, 100, 2, 10799, NULL, 'To Celebrate Eric''s 80th Birthday, November 2OO9', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1998, '2002-08-06 22:00:00+00', '2018-04-03 00:07:44.61743+00', 'Equilibrium', 'EQUILIBRIUM', 2, 32, 9999, 1, 3, 42, 21, NULL, '', 56, '800  888   12 12 12   400', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (12107, '2005-03-20 23:00:00+00', '2014-04-30 23:23:48.868245+00', 'Eyrie in the Glen, The', 'EYRIE IN THE GLEN', 2, 32, 9999, 1, 3, 42, 108, '2003-01-01', '', 56, '884  884  800  888', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (9373, '2000-04-03 22:00:00+00', '2018-09-04 18:34:26.672146+00', 'Lady Grace', 'LADY GRACE', 3, 32, 9999, 1, 3, 42, 2712, '1999-01-01', 'Devised by Katrina Begordis, 1999, using her favorite Scottish country dance formations.', 63, '800/880/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2034, '2001-03-13 23:00:00+00', '2014-04-30 23:23:48.913298+00', 'Fair Jenny''s Jig', 'FAIR JENNYS JIG', 2, 32, 9999, 1, 3, 42, 401, '1990-01-01', '', 53, '800  822  888  888', 1, 1, 1, 0, 70);
INSERT INTO 'dance' VALUES (11280, '2003-05-04 22:00:00+00', '2014-04-30 23:23:48.928316+00', 'Fair Ronny''s Reel', 'FAIR RONNYS REEL', 1, 32, 9999, 1, 3, 42, 2701, '1999-01-01', 'Dance in honour of Ron Wallace.  ', 47, '800  880  888  822', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (18652, '2018-09-18 23:18:34.790894+00', '2018-09-19 09:19:54.587627+00', 'Tartan Ties', 'TARTAN TIES', 3, 32, NULL, 2, 3, 17, 11710, '2015-06-07', 'Green sleeves and tartan ties  

Mark my true love where she lies  

-Robert Burns', 66, '844/880/808/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18694, '2018-10-02 13:35:30.42748+00', '2018-10-02 13:35:30.42748+00', 'Candles', 'CANDLES', 3, 32, NULL, 1, 4, NULL, 2766, '2012-08-01', 'This dance reminds me of the cat''s cradle figure called candles.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1972, '1997-09-01 22:00:00+00', '2020-08-30 09:40:16.119371+00', 'Emblem, The', 'EMBLEM', 2, 32, 9999, 1, 3, 42, 463, NULL, '', 44, '888  800  880  800', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (1942, '1997-04-03 22:00:00+00', '2022-08-14 21:57:58.744997+00', 'Elegant Lassies Of Elgin', 'ELEGANT LASSIES OF ELGIN', 5, 32, 9999, 1, 3, 42, 108, '1984-01-01', '', 62, '880   12 12 12   400  888', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (2030, '1998-09-29 22:00:00+00', '2023-02-09 11:57:29.178569+00', 'Fair Donald', 'FAIR DONALD', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 47, '800  844  844  866', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (1793, '2002-03-11 23:00:00+00', '2022-10-22 14:21:37.02503+00', 'Duke of Roxburgh''s Reel', 'DUKE OF ROXBURGHS REEL', 1, 24, 9999, 1, 3, 42, 9998, NULL, '', 54, '800  888  866', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (10883, '2002-10-23 22:00:00+00', '2022-12-22 18:25:59.639373+00', 'Fairfield Bridge', 'FAIRFIELD BRIDGE', 1, 32, 9999, 5, 2, NULL, 725, NULL, '', 75, '88  80  08  88', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (1983, '1998-01-05 23:00:00+00', '2023-02-09 12:13:35.091389+00', 'Enchanted Isle, The', 'ENCHANTED ISLE', 1, 32, 9999, 1, 2, 76, 44, NULL, '', 52, '44  44  88  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (1927, '1998-09-29 22:00:00+00', '2023-02-09 12:28:32.872455+00', 'Eight Men of Moidart, The', 'EIGHT MEN OF MOIDART', 1, 32, 9999, 1, 4, 52, 9998, '1754-01-01', 'This is a 4-couple dance in a 4-couple longwise set but it still goes 8 times through!', 62, '888  888  888  800', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (1891, '1998-11-12 23:00:00+00', '2023-02-09 13:02:02.16821+00', 'Earlstoun Loch', 'EARLSTOUN LOCH', 1, 32, 9999, 3, 5, 7, 129, '1966-01-01', '', 65, '80800  88888  80800  84884', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (13367, '2009-08-02 22:00:00+00', '2020-08-30 21:31:04.046081+00', 'Engine Room, The', 'ENGINE ROOM', 1, 32, NULL, 1, 3, 42, 390, NULL, '', 56, '888  800  866  866', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (13698, '2011-06-29 22:00:00+00', '2020-09-19 13:20:00.605101+00', 'Elsa''s Turn', 'ELSAS TURN', 1, 40, NULL, 1, 4, 1, 10348, '2007-01-01', '', 77, '8008  6886  8888  4444  8888', 0, 0, 0, 0, 77);
INSERT INTO 'dance' VALUES (11721, '2004-06-13 22:00:00+00', '2020-11-28 11:32:59.433461+00', 'Electrification', 'ELECTRIFICATION', 1, 32, 9999, 1, 3, 42, 3323, '2004-01-01', '', 69, '844  888  888  888', 0, 1, 0, 0, 91);
INSERT INTO 'dance' VALUES (8668, '1998-03-31 22:00:00+00', '2021-03-15 22:23:59.114422+00', 'Edna''s Farewell', 'EDNAS FAREWELL', 2, 40, 9999, 1, 3, 42, 2108, '1998-01-01', 'For the farewell of Edna Reid', 57, '800  888  822  888  888', 0, 1, 0, 0, 76);
INSERT INTO 'dance' VALUES (1937, '1997-09-01 22:00:00+00', '2020-12-06 11:07:43.23547+00', 'Eilidh MacIain', 'EILIDH MACIAIN', 2, 40, 9999, 1, 3, 42, 865, NULL, '', 55, '800  880  844  888  844', 0, 1, 0, 0, 73);
INSERT INTO 'dance' VALUES (12910, '2006-10-14 22:00:00+00', '2020-12-25 15:28:35.854826+00', 'Eindhoven Thistles, The', 'EINDHOVEN THISTLES', 3, 48, 9999, 2, 3, 17, 872, '2006-01-01', '', 89, '880  888  888  888  808  888', 0, 1, 0, 0, 88);
INSERT INTO 'dance' VALUES (8116, '2002-03-12 23:00:00+00', '2020-12-19 14:12:57.635666+00', 'Dutchman, The', 'DUTCHMAN', 2, 32, 9999, 1, 3, 42, 1445, '1996-01-01', '', 53, '844  844  822  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (9372, '2002-03-24 23:00:00+00', '2020-12-20 23:58:22.582523+00', 'Ebb and Flow', 'EBB AND FLOW', 3, 32, 9999, 1, 3, 42, 2711, '1999-01-01', '', 62, '800  888  888  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (10537, '2002-05-01 22:00:00+00', '2021-02-07 12:14:36.214921+00', 'Een Strathspey voor E', 'STRATHSPEY VOOR E', 3, 40, 9999, 1, 4, 1, 3120, '2002-01-01', '', 70, '8888  8008  8008  8088  8088', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (1907, '2001-06-12 22:00:00+00', '2021-03-13 18:46:00.458619+00', 'Edina''s Pride', 'EDINAS PRIDE', 3, 32, 9999, 1, 3, 42, 154, '1984-01-01', '', 47, '800  888  808  822', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (9817, '2001-10-22 22:00:00+00', '2021-06-08 10:18:27.066197+00', 'Duthie Park', 'DUTHIE PARK', 2, 32, 9999, 1, 4, 2, 165, NULL, 'According to the dance notes "Duthie Park, one of Aberdeen''s renowned municipal parks, dates back to 1880 when the land was gifted to the city by Miss Elizabeth Duthie of the shipbuilding family."', 94, '8888  4884  8888  8888', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (2042, '1998-09-29 22:00:00+00', '2021-06-09 16:19:22.558337+00', 'Fairly Shot o'' her', 'FAIRLY SHOT O HER', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 47, '800  844  888  822', 1, 1, 0, 1, 62);
INSERT INTO 'dance' VALUES (2008, '2000-09-02 22:00:00+00', '2021-06-11 20:30:49.106422+00', 'Ettrick Water', 'ETTRICK WATER', 3, 32, 9999, 1, 3, 42, 146, NULL, '', 47, '822  808  880  880', 1, 1, 0, 1, 62);
INSERT INTO 'dance' VALUES (2004, '1998-09-30 22:00:00+00', '2021-06-11 20:32:52.298221+00', 'Espie McNabb', 'ESPIE MACNABB', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 50, '888  800  800  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (1965, '1998-11-14 23:00:00+00', '2021-06-12 09:44:20.328942+00', 'Ellwyn Strathspey', 'ELLWYN STRATHSPEY', 3, 48, 9999, 1, 4, 1, 116, NULL, '', 85, '8888  6666  8888  6666  8888  8444', 1, 1, 0, 1, 85);
INSERT INTO 'dance' VALUES (1909, '1998-09-30 22:00:00+00', '2021-06-12 18:22:06.959148+00', 'Edinburgh Jigs', 'EDINBURGH JIGS', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 41, '501  511  888  880', 1, 1, 0, 1, 55);
INSERT INTO 'dance' VALUES (1908, '1997-11-18 23:00:00+00', '2021-06-12 18:25:11.880839+00', 'Edinburgh Castle Reel, The', 'EDINBURGH CASTLE REEL', 1, 32, 9999, 1, 3, 42, 9998, '1792-01-01', '', 28, '800  800  822  800', 1, 1, 0, 1, 37);
INSERT INTO 'dance' VALUES (1866, '1999-08-09 22:00:00+00', '2021-06-13 08:02:33.702702+00', 'Dusty Miller, The', 'DUSTY MILLER', 2, 32, 9999, 1, 3, 42, 9998, NULL, 'Collected in Berwickshire', 53, '800  888  844  866', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (8351, '2002-06-02 22:00:00+00', '2019-09-20 19:53:45.257176+00', 'Exciseman, The', 'EXCISEMAN', 2, 32, 9999, 1, 3, 42, 108, '1996-01-01', '', 64, '828  888  888  844', 1, 1, 1, 0, 85);
INSERT INTO 'dance' VALUES (2053, '1999-10-27 22:00:00+00', '2018-04-03 00:07:45.053057+00', 'Falkland Beauty, The', 'FALKLAND BEAUTY', 2, 24, 9999, 1, 3, 42, 9998, NULL, '', 55, '866  854  880', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (13905, '2011-08-22 22:00:00+00', '2018-04-04 09:29:37.845955+00', 'Fairest Cape, The', 'FAIREST CAPE', 3, 32, NULL, 1, 2, 76, 3254, '2006-08-01', 'Devised by Terry Lynne Harris, Pretoria, August 2006.



Written for Barbara Martlew, in celebration of the Martlews'' visit to our beautiful shores, 25August-10September2006.



Notes:  

"The fairest Cape we saw in the whole circumference of the earth." Sir Francis Drake, on entering Table Bay aboard the Golden Hind in 1580.



The Slip Knot was devised by Mel Briscoe.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2168, '1999-05-09 22:00:00+00', '2014-11-11 01:29:00.611655+00', 'Filoli Gardens', 'FILOLI GARDENS', 3, 40, 9999, 2, 3, 17, 1309, NULL, '', 53, '800  888  822  822  800', 0, 1, 1, 0, 53);
INSERT INTO 'dance' VALUES (2222, '2000-09-05 22:00:00+00', '2018-05-17 21:56:31.958598+00', 'Flight of the Falcon, The', 'FLIGHT OF THE FALCON', 2, 32, 9999, 1, 3, 42, 313, NULL, '', 41, '800  844  844  822', 0, 1, 1, 0, 54);
INSERT INTO 'dance' VALUES (2126, '2002-04-10 22:00:00+00', '2018-04-03 00:07:45.453528+00', 'Ferry Louper, The', 'FERRY LOUPER', 2, 32, 9999, 1, 3, 42, 146, NULL, '', 56, '888  880  800  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (2136, '2002-04-19 22:00:00+00', '2014-04-30 23:23:49.334522+00', 'Fête, The', 'FETE', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 41, '880  800  804  880', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (18549, '2018-08-30 09:20:46.200523+00', '2018-09-04 14:05:24.191894+00', 'Gone With The Wind', 'GONE WITH THE WIND', 2, 40, NULL, 1, 3, 42, 11700, '2017-01-01', 'This dance was devised in 2017 by Christiane Orgeret, as a happy memory of her 30 years at the head of the RSCDS Lyon group, then Branch - spot the number 30 in the first 12 bars, and feel the wind in the last 12!', 61, '800/828/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11281, '2003-05-04 22:00:00+00', '2014-04-30 23:23:49.364625+00', 'Fiddlehead, The', 'FIDDLEHEAD', 3, 32, 9999, 1, 2, NULL, 2783, '2000-11-01', '', 56, '84  88  88  80', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (9389, '2000-04-11 22:00:00+00', '2019-02-22 18:33:16.581952+00', 'Fill the Fetters', 'FILL THE FETTERS', 3, 32, 9999, 4, 4, 13, 2725, '1993-01-01', '', 87, '8888  8888  4444  8888', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (8048, '1997-12-03 23:00:00+00', '2019-03-07 09:37:16.896428+00', 'Fish and Chips', 'FISH AND CHIPS', 2, 32, 9999, 1, 4, 1, 1383, '1994-01-01', '', 56, '8800  8800  8000  8888', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (2235, '1998-04-12 22:00:00+00', '2019-10-16 10:23:43.176832+00', 'Floating on Air', 'FLOATING ON AIR', 3, 32, 9999, 1, 3, 42, 108, '1994-01-01', '', 50, '880  880  880  844', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (8515, '2001-05-20 22:00:00+00', '2014-04-30 23:23:49.700611+00', 'Five Times Five Makes Twenty Five', 'FIVE TIMES FIVE MAKES TWENTY FIVE', 1, 32, 9999, 3, 5, 7, 2075, NULL, '', 85, '88880  84884  88888  80888', 1, 1, 1, 0, 85);
INSERT INTO 'dance' VALUES (2010, '1997-11-18 23:00:00+00', '2020-04-27 17:55:38.917603+00', 'Euan''s Jig', 'EUANS JIG', 2, 32, 9999, 1, 2, 76, 9998, NULL, '', 52, '62  26  88  88', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (10854, '2002-11-01 23:00:00+00', '2020-12-24 18:16:49.048368+00', 'Ferguson''s Folly', 'FERGUSONS FOLLY', 2, 32, 9999, 1, 3, 42, 1445, NULL, 'This dance was written for Eric Ferguson, in gratitude for many years of cleaning the dance floor with his scraper after our weekly dance.', 47, '800  642  866  866', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (2153, '1998-09-29 22:00:00+00', '2020-05-27 06:17:17.102523+00', 'Fidget', 'FIDGET', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'Dances 1814, published by Button and Whitaker', 62, '880/888/880/888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (2156, '1998-09-30 22:00:00+00', '2020-07-11 20:48:02.606145+00', 'Fife Hunt, The', 'FIFE HUNT', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'The choreography of this dance is identical to that of <<ddd:Wedderburn''s Reel>>.', 34, '800  800  822  844', 0, 1, 0, 0, 45);
INSERT INTO 'dance' VALUES (2140, '2002-04-10 22:00:00+00', '2020-07-26 08:50:06.932063+00', 'Fiddle Faddle', 'FIDDLE FADDLE', 3, 32, 9999, 1, 3, 42, 198, '1748-01-01', '', 53, '800  888  888  822', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (2076, '1997-04-03 22:00:00+00', '2021-06-09 08:40:36.129697+00', 'Far Up The Glen', 'FAR UP THE GLEN', 1, 32, 9999, 1, 3, 42, 392, NULL, '', 53, '800  888  844  866', 1, 1, 0, 1, 70);
INSERT INTO 'dance' VALUES (2100, '2003-02-10 23:00:00+00', '2020-08-30 09:47:07.675761+00', 'Farewell To The Island', 'FAREWELL TO THE ISLAND', 3, 32, 9999, 1, 3, 42, 2130, NULL, '', 56, '800  866  866  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (2192, '1998-04-12 22:00:00+00', '2020-08-30 10:02:53.751561+00', 'First Love', 'FIRST LOVE', 3, 32, 9999, 1, 2, 76, 227, '1987-01-01', '', 52, '80  80  88  88', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (2039, '1997-09-02 22:00:00+00', '2020-12-06 11:11:33.272504+00', 'Fairbridge Reel, The', 'FAIRBRIDGE REEL', 1, 48, 9999, 2, 3, 18, 884, '1989-01-01', 'The official description in book 45 tells 1c to finish the turn on bars [35-36] in second place; that makes it very hard to finish bars [37-40] correctly.



The deviser, John Brenchley, responded as follows in the Strathspey List message 68984 of 27 June 2017. 



“As Brian Charlton correctly states, The Fairbridge Reel was originally published in The Swan River Selection in 1992.  It was subsequently submitted by the Western Australia Branch and accepted for publication in Book 45.



My original wording in the Swan River Selection for bars 33 - 36 stated: 



"1st and 3rd couples set to partners, then turn three quarters with the right hand. 1st couple finish facing up with right hand joined.  3rd couple finish in third place on the wrong side.  2nd couple step up to top place on bars 35 - 36."



Prior to the setting, 1st couple will be in the same place as they were after the petronella turn at the start of the dance, i.e. 1st woman slightly above first place and 1st man slightly below first place.  It seems logical to me that their right hand turn will therefore be in first place, not second place.  Although not stated in the instructions, 1st couple finish the turn on opposite sides and I expect 1st man to dance a polite turn in order to face up at the end of bar 36.



In the demonstration being performed by the team at St Andrews in 2008, John Wilkinson and his partner as 1st couple clearly follow the above description.



If I recall correctly, book 45 was issued prior to the current approach of sending the recommended wording to the dance devisor for review.  I was never consulted about the RSCDS version of the instructions so am not sure why they felt it necessary to include the words "at second place".  My only thought is that perhaps it was felt that there was too much time during bars 37 - 40 for the lead up and cast off, hence the suggestion that the turn should move slightly down the dance and give a greater distance to be covered in the next 4 bars.  I note that in TAC notes, they suggest that 1st lady should dance down into the turn which is presumably to help the turn move to second place.  There is also a display on You Tube danced by a team from Canberra Branch and this is exactly what both sets do, the women can be seen dancing down and the turn finishes nearer to second place than first place.  The dancers do not appear to have any great difficulty in doing this and still have enough time to lead up and cast  during the next 4 bars so I do not think the RSCDS version is "impossible" of "not even doable", just an unnecessary complication in my view



I believe that by having 2nd couple step up during bars 35 - 36, 1st couple are forced to lead up slightly above first place before casting and this seems to fit the amount of time available during bars 37 - 40 without the need for steps to be either too short or too long.  I think after the setting, the next 6 bars should be danced as a flowing movement - it is not necessary to be regimented in keeping the turn to exactly 2 bars.



In summary, my preference would be for the turn to be danced in first place as demonstrated by the team at St Andrews, but if some dancers follow the RSCDS wording exactly, its not going to overly worry me.



Best wishes



John Brenchley”



', 72, '484  808  484  484  808  888', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (7738, '2001-05-21 22:00:00+00', '2020-12-18 20:58:52.172568+00', 'Frankfurt Fancy, A', 'FRANKFURT FANCY', 1, 32, 9999, 1, 100, 2, 228, '1998-01-01', '', 75, '8008  8448  8448  8888', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (11719, '2004-06-13 22:00:00+00', '2022-09-23 16:29:56.112066+00', 'Fifty-Fifty', 'FIFTYFIFTY', 1, 32, 9999, 7, 1, 4, 1268, NULL, 'Dedicated to Alex and Carrie Sutherland.', 69, '44  66  66  66', 1, 1, 0, 0, 68);
INSERT INTO 'dance' VALUES (8726, '2003-02-15 23:00:00+00', '2020-12-19 15:16:03.055535+00', 'Fire in the Rye', 'FIRE IN THE RYE', 1, 32, 9999, 8, 105, 32, 1510, '1998-01-01', '', 87, '888888  888888  848848  844448', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (12502, '2005-07-30 22:00:00+00', '2020-12-25 12:35:23.891047+00', 'Firth of Lorne', 'FIRTH OF LORNE', 3, 32, 9999, 2, 3, 17, 2805, NULL, '', 58, '888  800  822  804', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (14397, '2012-01-07 23:00:00+00', '2021-07-30 08:40:12.330335+00', 'Evelyn''s Surprise', 'EVELYNS SURPRISE', 3, 32, NULL, 3, 5, 44, 308, '2008-01-01', 'Fot the presentationsof the Branch Certificate to Evelyn Ramwell', 70, '88088  82428  48444  88808', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (11879, '2004-11-01 23:00:00+00', '2021-01-18 18:54:13.152205+00', 'First Green of Spring, The', 'FIRST GREEN OF SPRING', 3, 32, 9999, 1, 2, 76, 1445, NULL, '', 47, '62  44  88  84', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (10469, '2002-04-12 22:00:00+00', '2021-02-08 15:47:25.373785+00', 'Enjoy the Moment', 'ENJOY THE MOMENT', 3, 32, 9999, 1, 3, 42, 3095, NULL, 'A Note from "The Vienna Book":  

For Beatrix (Bexi) Wepner who, during a beginners’ class, praised bar 6 of the allemande with the following words: “This is as close as you''ll get in Scottish Country Dancing – Enjoy the Moment!”



Crib derived from the video.  Eric', 37, '800  808  820  860', 0, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (2079, '1998-04-11 22:00:00+00', '2021-06-09 08:26:21.93493+00', 'Farewell, My Fancy', 'FAREWELL MY FANCY', 3, 32, 9999, 1, 3, 42, 62, '1966-06-01', 'Devised in June 1966 as a tribute to the late Matthew Sutherland and the contribution he made to our dancing.', 62, '844  844  888  888', 0, 1, 0, 1, 83);
INSERT INTO 'dance' VALUES (9005, '2001-12-19 23:00:00+00', '2021-03-06 22:20:01.582048+00', 'Eric''s Jubilee', 'ERICS JUBILEE', 1, 32, 9999, 1, 4, 1, 146, NULL, '', 75, '8080  8888  8484  8484', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (11878, '2004-11-01 23:00:00+00', '2021-03-16 05:10:43.336071+00', 'Fine Day in March, A', 'FINE DAY IN MARCH', 1, 32, 9999, 1, 2, 76, 1445, NULL, '', 54, '82/88/80/88', 1, 1, 1, 1, 78);
INSERT INTO 'dance' VALUES (9041, '2001-05-03 22:00:00+00', '2021-06-06 13:17:55.772945+00', 'Fairground Frolic', 'FAIRGROUND FROLIC', 1, 48, 9999, 2, 3, 17, 2605, NULL, '', 86, '888  484  888  444  888  888', 0, 1, 0, 0, 86);
INSERT INTO 'dance' VALUES (1533, '2005-04-06 22:00:00+00', '2021-11-19 14:01:21.655291+00', 'First of September, The', 'FIRST OF SEPTEMBER', 1, 32, 9999, 1, 4, 2, 104, '2001-01-01', 'Written for the wedding of Dave and Judy Hall.



<<scddb:not-identical:11808>>', 94, '8888  8448  8888  8448', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (2063, '1998-10-20 22:00:00+00', '2021-06-09 08:44:37.822198+00', 'Falls of Rogie, The', 'FALLS OF ROGIE', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 56, '800  888  888  844', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (2044, '1998-11-10 23:00:00+00', '2021-06-21 10:49:41.072838+00', 'Fairy Dance, The', 'FAIRY DANCE', 1, 32, 9999, 1, 3, 42, 9998, '1827-01-01', '', 34, '444  800  844  800', 1, 1, 1, 1, 45);
INSERT INTO 'dance' VALUES (2203, '2002-09-22 22:00:00+00', '2021-08-02 09:54:03.515859+00', 'Fisherman''s Reel', 'FISHERMANS REEL', 1, 32, 9999, 4, 5, 6, 3108, '1994-02-01', 'Written for the Grimsby Scottish Country Dance Club.', 75, '88888  44448  88888  42442', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (2166, '1998-11-07 23:00:00+00', '2018-04-03 00:07:45.812244+00', 'Fight about the Fireside', 'FIGHT ABOUT THE FIRESIDE', 1, 32, 9999, 1, 3, 42, 1517, '1822-01-01', '', 44, '800  888  844  800', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (9382, '2000-04-09 22:00:00+00', '2016-01-17 02:31:25.497708+00', 'Flights of Fancy', 'FLIGHTS OF FANCY', 2, 32, 9999, 1, 3, 42, 259, '1998-01-01', 'Jeanetta McColl wrote this dance on a whim and felt that 6/8 pipe marches would be the appropriate musical accompaniment.  Her brother, lain, suggested that their father''s composition be used as the title tune.', 53, '808/888/448/804', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (11518, '2003-10-02 22:00:00+00', '2014-04-30 23:23:50.125066+00', 'Flying High', 'FLYING HIGH', 2, 32, 9999, 1, 4, 1, 900, '2002-01-01', 'Published as a leaflet.', 47, '8040  8660  8660  8000', 1, 1, 1, 1, 46);
INSERT INTO 'dance' VALUES (2268, '1997-09-02 22:00:00+00', '2014-04-30 23:23:50.218633+00', 'Follow Me To Saint Andrews', 'FOLLOW ME TO SAINT ANDREWS', 3, 40, 9999, 1, 4, 1, 916, '1968-01-01', 'Devised on the occasion of the 10th anniversary of the “The Hague District Branch of the R.S.C.D.S.” in 1968, and named in appreciation of the many happy holidays spent in St Andrews at the RSCDS Summer School ', 65, '8008  0880  8888  8440  8448', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (2277, '1998-01-05 23:00:00+00', '2014-04-30 23:23:50.261649+00', 'For Lack of Silver', 'FOR LACK OF SILVER', 1, 32, 9999, 1, 2, NULL, 44, NULL, '', 52, '88  44  44  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (12674, '2006-02-12 23:00:00+00', '2018-04-26 22:51:03.530783+00', 'Flowers of Dunbeg', 'FLOWERS OF DUNBEG', 1, 32, 9999, 3, 5, 16, 3522, '2003-01-01', '', 65, '88088  08880  80000  88888', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (14559, '2012-09-04 00:29:00.834068+00', '2014-04-30 23:23:50.427967+00', 'Foxgloves', 'FOXGLOVES', 2, 32, NULL, 2, 3, 17, 10651, '2009-09-01', 'Original Description as sent to DanceData editors



Foxgloves 	3C (3C Set) Jig 6x32



1-8 	all set in line, cross RH, all set, cross RH



9-16 	1c lead down the middle and up to end in 2nd place (2c step up) in double triangle

position, ladies facing ladies’s side, men facing men’s side 



17-18 	all set 



19-20 	1c turn 3c in double triangle position



21-22 	all set 



23-24 	3c turn 1c back into 2nd place



25-30 	mirror reels of three (1c starting up and out)



31-32 	1c cast down into 3rd place (2c and 3c step up)



(music: just a nice- not too fast- jig)



', 75, '888  800  848  866', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (12941, '2006-10-22 22:00:00+00', '2019-02-26 21:40:38.078378+00', 'Flower of Glasgow, The', 'FLOWER OF GLASGOW', 3, 32, 9999, 2, 3, 18, 2793, '2004-01-01', '', 53, '822  888  844  880', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (9105, '2002-03-11 23:00:00+00', '2015-10-30 21:38:46.987014+00', 'Forth Bridge Jig', 'FORTH BRIDGE JIG', 2, 32, 9999, 1, 4, 1, 553, '1988-01-01', '', 67, '8864  8444  8888  8000', 1, 1, 1, 1, 67);
INSERT INTO 'dance' VALUES (10390, '2002-03-11 23:00:00+00', '2017-08-18 14:29:26.947028+00', 'Fly Fishers'' Strathspey, The', 'FLY FISHERS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 1339, NULL, 'A dance devised for the fortieth wedding anniversary of Pat and Ray Lawson, Scottish country

dancers and fly fishers', 50, '800/888/822/848', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (9504, '2001-07-30 22:00:00+00', '2016-06-03 13:39:24.673409+00', 'Flower of the Mill, The', 'FLOWER OF THE MILL', 4, 64, 5, 4, 4, 1, 228, NULL, '', 75, '8080  8080  0808  0808  8888  8888  8888  8888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (2263, '1998-11-14 23:00:00+00', '2017-04-21 23:46:16.58934+00', 'Flying Spur, The', 'FLYING SPUR', 2, 32, 9999, 1, 3, 42, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Jackie Johnstone of Dumfries.



The Johnstone Clan Crest bears a winged spur, thus that name.', 69, '844/888/888/888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (18766, '2018-10-05 07:41:19.77557+00', '2018-10-05 07:41:19.77557+00', 'Frisky Feet', 'FRISKY FEET', 1, 32, NULL, 2, 3, 17, 2766, '2007-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14413, '2012-03-08 16:35:05.406367+00', '2020-08-24 22:24:12.768797+00', 'Forget the Progression', 'FORGET THE PROGRESSION', 2, 32, NULL, 3, 5, 33, 10517, NULL, '', 71, '16 14 12 10 8   24224   04004  08888', 0, 1, 0, 0, 71);
INSERT INTO 'dance' VALUES (2119, '1998-04-11 22:00:00+00', '2020-08-03 21:15:42.097922+00', 'Fellside Ramble', 'FELLSIDE RAMBLE', 2, 32, 9999, 5, 2, NULL, 893, NULL, '', 100, '88  88  88 88', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (2312, '1997-08-30 22:00:00+00', '2021-06-06 12:45:31.587658+00', 'Four Minute Reel, The', 'FOUR MINUTE REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 62, '880  888  844  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (2308, '1998-04-12 22:00:00+00', '2021-06-06 12:48:48.209326+00', 'Four Daisies', 'FOUR DAISIES', 2, 32, 9999, 1, 2, 76, 227, '1987-01-01', '', 43, '80  08  88  80', 1, 1, 0, 1, 62);
INSERT INTO 'dance' VALUES (2244, '1998-11-17 23:00:00+00', '2020-12-06 11:15:33.872994+00', 'Flower of Portencross', 'FLOWER OF PORTENCROSS', 3, 32, 9999, 2, 3, 18, 2431, NULL, '', 92, '686   686  12 12 12 444', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (2259, '1997-04-03 22:00:00+00', '2020-12-06 11:22:51.337327+00', 'Flying High', 'FLYING HIGH', 2, 32, 9999, 1, 3, 42, 109, NULL, '', 56, '888  840  844  866', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (9989, '2001-07-19 22:00:00+00', '2020-12-21 16:58:32.495995+00', 'Four Couples'' Pleasure', 'FOUR COUPLES PLEASURE', 3, 32, 9999, 1, 4, 2, 2917, '1984-01-01', '', 87, '4444  8888  8888  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (11367, '2003-06-26 22:00:00+00', '2021-01-25 15:32:42.019856+00', 'Fifty Years On', 'FIFTY YEARS ON', 2, 40, 9999, 1, 100, 2, 108, '2002-01-01', 'The Pilling diagram in the 8th edition is in error, see the supplement to the 8th edition for the correct one.', 85, '0880  8888  8448  8888  8888', 1, 1, 1, 1, 85);
INSERT INTO 'dance' VALUES (16382, '2015-05-21 14:37:44.945261+00', '2016-04-18 23:27:06.231394+00', 'Wedding Ring, The', 'WEDDING RING', 1, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2495, '1998-09-29 22:00:00+00', '2021-06-03 19:43:46.968746+00', 'Glasgow Flourish', 'GLASGOW FLOURISH', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 56, '880  888  800  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (2158, '1998-09-29 22:00:00+00', '2023-02-09 11:29:52.812615+00', 'Fife Ness', 'FIFE NESS', 1, 32, 9999, 1, 3, 42, 50, '1972-01-01', '', 54, '800  777  866  866', 1, 1, 0, 0, 71);
INSERT INTO 'dance' VALUES (10859, '2002-11-01 23:00:00+00', '2020-12-24 18:20:00.681206+00', 'Flowers for Christine', 'FLOWERS FOR CHRISTINE', 2, 32, 9999, 1, 4, 1, 227, '2002-04-01', 'This dance was devised for Christine Houwen''s 50th birthday on 11 April 2002.  Christine has been our excellent treasurer for many years.', 78, '8080  8686  8888  8484', 1, 1, 1, 1, 78);
INSERT INTO 'dance' VALUES (9811, '2002-04-10 22:00:00+00', '2021-02-19 15:06:29.613787+00', 'Farewell to the Highlands', 'FAREWELL TO THE HIGHLANDS', 3, 32, 9999, 1, 4, 1, 831, NULL, '', 81, '8888  8888  8440  8448', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (9338, '2002-12-05 23:00:00+00', '2021-02-25 20:12:21.515209+00', 'Flirtation Chase, The', 'FLIRTATION CHASE', 1, 32, 9999, 1, 2, 76, 635, NULL, '', 43, '44  44  80  88', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (2196, '2002-04-19 22:00:00+00', '2021-06-07 11:22:02.346911+00', 'Firth of Beauly', 'FIRTH OF BEAULY', 1, 32, 9999, 1, 3, 42, 693, NULL, 'The title is in jest of a small round body of water bordering Beauly near Inverness.', 59, '822  888  844  888', 1, 1, 0, 1, 79);
INSERT INTO 'dance' VALUES (8173, '2001-11-20 23:00:00+00', '2021-03-21 19:49:26.216653+00', 'Founder''s Jig', 'FOUNDERS JIG', 2, 32, 9999, 1, 2, 76, 1502, NULL, 'Devised in honour of Miss Margaret Rae, the founder of Duns and District Branch, who sadly died shortly before this collection of dances was produced.', 60, '88  88  66  84', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (485, '1998-01-11 23:00:00+00', '2021-07-02 12:24:01.354773+00', 'Fireside Strathspey, The', 'FIRESIDE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 175, '1995-05-01', 'Devised by Derek Haynes, May 1995.', 69, '880  888  844  888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (9802, '2001-03-18 23:00:00+00', '2021-08-05 22:35:31.238883+00', 'Foggy River Reel', 'FOGGY RIVER REEL', 1, 40, 9999, 1, 3, 42, 2835, '2001-01-01', '', 55, '800/888/844/844/888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (17144, '2016-07-11 19:37:48.71686+00', '2019-02-05 11:26:07.500343+00', 'Shadow', 'SHADOW', 2, 32, NULL, 2, 3, 18, 11308, '2014-11-01', '', 87, '844/888/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2436, '1998-09-29 22:00:00+00', '2018-04-03 11:46:51.163224+00', 'Gentle Shepherd, The', 'GENTLE SHEPHERD', 2, 32, 9999, 1, 4, 1, 9998, NULL, 'The RSCDS publication "Scottish Country Dances Books 13-18" states that this dances originates from *an old book of Scottish-Irish dances (title page lost)*.  [Thus, if somebody knows more of the whereabouts of this book, please let us know by hitting the "Submit Correction/Addition" button.]



The above mentioned RSCDS publication adds the following note: in bars 11-12, 3rd man may find it

easier to lead partner with the left hand.



The dance is danced as a Slow Jig.', 52, '8060  8480  8880  8000', 0, 1, 1, 1, 51);
INSERT INTO 'dance' VALUES (13685, '2011-06-14 22:00:00+00', '2014-04-30 23:23:50.549974+00', 'Frimley Green Reel, The', 'FRIMLEY GREEN REEL', 1, 32, NULL, 1, 3, 42, 347, NULL, 'Named after the village where our General class is held.', 56, '800  888  888  844', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14642, '2013-01-05 07:28:13.930036+00', '2018-07-23 10:16:12.931849+00', 'Game on the Links, A', 'GAME ON THE LINKS', 1, 32, 9999, 1, 3, 42, 17, '2009-03-03', 'Source: Strathspey List 3 march 2009 message 55165', 50, '800  844  866  844', 1, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (2365, '1997-09-02 22:00:00+00', '2018-04-07 22:53:06.391037+00', 'Fusilier''s Dream, The', 'FUSILIERS DREAM', 1, 40, 9999, 1, 3, 42, 937, NULL, 'Only 1c and 2c move in this dance, but as they dance round 3c it is registered as a 3c dance.', 40, '440/440/880/880/880', 0, 1, 1, 1, 53);
INSERT INTO 'dance' VALUES (2409, '2001-07-30 22:00:00+00', '2019-02-22 22:07:19.341844+00', 'Garry Strathspey, The', 'GARRY STRATHSPEY', 3, 32, 9999, 1, 4, 1, 87, NULL, 'Named after Gary Blair, son of Jimmy Blair, composer of Jigtime Polka.', 81, '8448  6442  8888  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (2388, '2001-05-03 22:00:00+00', '2014-04-30 23:23:50.8235+00', 'Galloping Carousel, The', 'GALLOPING CAROUSEL', 2, 32, 9999, 1, 4, 2, 428, NULL, '', 75, '8448  8448  8448  8448', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (7546, '2000-02-21 23:00:00+00', '2014-04-24 11:29:05.420994+00', 'Gay Gordons', 'GAY GORDONS', 11, 16, 9999, 5, 1, NULL, 9998, NULL, '', 100, '8 8', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13585, '2010-08-08 22:00:00+00', '2015-10-29 23:21:40.268805+00', 'Gardeners'' Fantasia, The', 'GARDENERS FANTASIA', 3, 32, NULL, 2, 3, 17, 3721, NULL, '', 76, '881  808  448  888', 0, 1, 1, 1, 76);
INSERT INTO 'dance' VALUES (695, '2001-10-25 22:00:00+00', '2020-05-17 21:29:59.015755+00', 'Gaelforce Wind', 'GAELFORCE WIND', 2, 32, 9999, 1, 3, 42, 175, '1996-01-01', 'This dance introduces the Set and Link figure and the Men''s Chain in Jig time.', 53, '840  880  844  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (2349, '2002-11-21 23:00:00+00', '2020-01-15 23:26:54.981871+00', 'Frisky, The', 'FRISKY', 2, 32, 9999, 1, 3, 42, 442, NULL, '', 47, '800/888/840/880', 1, 1, 1, 0, 62);
INSERT INTO 'dance' VALUES (2421, '1998-11-12 23:00:00+00', '2020-08-04 21:21:14.747125+00', 'Gavin''s Reel', 'GAVINS REEL', 1, 32, 9999, 4, 5, 16, 105, NULL, '', 44, '06066  40408  44448  40008', 0, 1, 1, 0, 43);
INSERT INTO 'dance' VALUES (18660, '2018-09-24 22:54:01.788975+00', '2020-11-14 20:08:33.690109+00', 'Nimble Flower of Nyon, The', 'NIMBLE FLOWER OF NYON', 3, 32, NULL, 2, 3, 17, 11237, '2018-07-01', 'A palindromic dance for <<ddp:#11236|Florence Burgy>> who is originally from Geneva but now lives in nearby Nyon.



Florence discovered Scottish Country Dancing in her teens, was quickly hooked and later trained as an RSCDS teacher under the supervision of <<ddp:#3342|Avril and David Quarrie>> for whom she wrote <<ddd:#16857|A Dance to Say Thank You>>.', 62, '880 842 824 808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9820, '2001-04-25 22:00:00+00', '2020-12-21 16:33:56.819117+00', 'Furlie, The', 'FURLIE', 2, 32, 9999, 3, 5, 7, 165, NULL, '', 80, '88884  80888  84488  44488', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (18274, '2018-04-05 10:07:17.998731+00', '2020-12-28 11:04:45.417568+00', 'Glasgow Lassie', 'GLASGOW LASSIE', 1, 32, 9999, 1, 3, 42, 2766, '2010-07-01', '', 39, '8200/8880/8880/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10494, '2002-04-23 22:00:00+00', '2021-02-08 14:39:39.281946+00', 'Carnival Study', 'CARNIVAL STUDY', 1, 32, 9999, 1, 3, 42, 558, '1992-01-01', '', 41, '800  822  844  844', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (8977, '2002-03-11 23:00:00+00', '2021-03-07 19:22:19.045674+00', 'Full Monty, The', 'FULL MONTY', 1, 32, 9999, 1, 3, 42, 108, '1998-01-01', '', 53, '888  820  844  844', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (2419, '1998-10-23 22:00:00+00', '2021-06-05 11:34:38.377554+00', 'Gathering, The', 'GATHERING', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 59, '844  888  844  866', 1, 1, 0, 1, 79);
INSERT INTO 'dance' VALUES (2367, '1998-09-29 22:00:00+00', '2021-03-13 15:44:32.331485+00', 'Fyket, The', 'FYKET', 2, 40, 9999, 1, 3, 42, 9998, NULL, '', 58, '550/888/888/826', 0, 1, 1, 1, 61);
INSERT INTO 'dance' VALUES (10555, '2002-05-11 22:00:00+00', '2022-08-13 12:07:01.794325+00', 'For Adam', 'FOR ADAM', 1, 32, 9999, 5, 56, 76, 9998, NULL, '', 100, '888  888  888  888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2129, '2002-04-10 22:00:00+00', '2022-06-11 16:22:19.036902+00', 'Ferryboat, The', 'FERRYBOAT', 2, 32, 9999, 7, 1, NULL, 895, '1989-01-01', 'Suited for Jig as well as Reel time (stated explicitly in the description of the dance).', 87, '84  48  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (9810, '2001-05-03 22:00:00+00', '2022-09-30 21:31:09.672861+00', 'Friendly Jig, The', 'FRIENDLY JIG', 2, 32, 9999, 1, 3, 42, 2845, NULL, '', 44, '840  804  800  888', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (18276, '2018-04-05 15:59:04.766238+00', '2022-10-01 15:15:16.689548+00', 'Engagement Ring, The', 'ENGAGEMENT RING', 3, 32, NULL, 2, 3, 18, 12208, '2018-02-01', 'Devised by Wouter and Liebet Joubert, February 2018. In honour of Emily Rosenberg and Tim Hill’s engagement.



In this dance third and fourth corners refer to the corner positions and whoever occupies them at that time.', 67, '800/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18277, '2018-04-05 17:32:30.560612+00', '2022-10-11 03:17:45.098677+00', 'With a Smile', 'WITH A SMILE', 2, 32, NULL, 2, 3, 17, 11520, '2017-09-01', 'Devised by Liebet Joubert, September 2017.  

This dance was devised to celebrate John Hanley’s life; to remember the joy he brought to everyone around him.', 58, '880/448/660/660', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2332, '1998-09-30 22:00:00+00', '2022-12-08 16:58:45.342555+00', 'Fraser''s Favourite', 'FRASERS FAVOURITE', 1, 32, 9999, 1, 3, 42, 387, '1972-01-01', 'The publication states: "For Fraser Malcolm Patrick, born 8th August, 1972, son of Joye and Alistair Patrick, members of London Branch"', 50, '440  880  866  866', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (2380, '1997-04-03 22:00:00+00', '2023-01-27 12:09:14.278466+00', 'Gala Water', 'GALA WATER', 3, 32, 9999, 1, 2, 76, 116, NULL, '', 60, '88  44  88  88', 1, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (2353, '1998-09-30 22:00:00+00', '2021-05-01 21:58:41.391331+00', 'From Scotia''s Shores We''re Noo Awa''', 'FROM SCOTIAS SHORES WERE NOO AWA', 3, 32, 9999, 1, 3, 42, 62, NULL, '', 53, '800  822  886  880', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (2389, '1998-09-29 22:00:00+00', '2021-06-05 11:50:47.327405+00', 'Galloway House', 'GALLOWAY HOUSE', 1, 32, 9999, 1, 2, 76, 9998, '1797-01-01', '', 52, '80  88  80  88', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (2354, '1998-04-12 22:00:00+00', '2021-06-06 10:23:56.428065+00', 'From the Broomielaw', 'FROM THE BROOMIELAW', 3, 32, 9999, 1, 4, 1, 181, '1983-01-01', 'Devised for the T.A.C. Silver Anniversary, 1983.', 78, '6666  6666  8444  8888', 1, 1, 1, 1, 78);
INSERT INTO 'dance' VALUES (2352, '1997-09-02 22:00:00+00', '2021-06-06 12:26:54.025467+00', 'From Ochtertyre To Amulree', 'FROM OCHTERTYRE TO AMULREE', 3, 32, 9999, 2, 3, 17, 181, NULL, '', 77, '444  888  666  848', 1, 1, 0, 0, 77);
INSERT INTO 'dance' VALUES (2333, '1997-08-25 22:00:00+00', '2021-06-06 12:43:25.476274+00', 'Fraser''s Fiddle', 'FRASERS FIDDLE', 1, 32, 9999, 1, 3, 42, 15, '1993-01-01', '', 59, '866  800  888  888', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (2350, '1999-09-12 22:00:00+00', '2021-06-06 12:37:21.434388+00', 'Frog in the Middle', 'FROG IN THE MIDDLE', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 50, '800  800  888  888', 1, 1, 0, 1, 66);
INSERT INTO 'dance' VALUES (2254, '1998-07-08 22:00:00+00', '2021-06-07 09:12:27.660737+00', 'Flowers of the West', 'FLOWERS OF THE WEST', 3, 40, 9999, 1, 100, 2, 884, '1992-01-01', 'The notes explain that "Western Australia is often referred to as the Wild Flower State due to the abundance of its wildflower species."', 80, '8008/8008/8888/8888/8888', 1, 1, 0, 0, 80);
INSERT INTO 'dance' VALUES (2428, '1998-09-29 22:00:00+00', '2021-10-11 22:34:17.83043+00', 'General Stuart''s Reel', 'GENERAL STUARTS REEL', 1, 32, 9999, 1, 3, 42, 339, '1749-01-01', '', 41, '440  822  822  866', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (2344, '1998-01-14 23:00:00+00', '2017-08-28 14:17:03.307228+00', 'Friday''s Child', 'FRIDAYS CHILD', 2, 32, 9999, 1, 3, 42, 127, NULL, '', 56, '800/888/844/888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (2401, '1998-04-12 22:00:00+00', '2017-10-25 22:04:56.242646+00', 'Garden Party, The', 'GARDEN PARTY', 3, 32, 9999, 1, 3, 42, 227, '1993-03-25', 'Level:  advanced.



"For Rik and Claire de Vroome, whose house and garden are very often open to their dance-friends".



When danced to recorded music, any good strathspey would do, but I prefer a softer one, as there are many circles in this dance.', 59, '800/888/888/866', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (9006, '1999-04-24 22:00:00+00', '2019-02-21 21:37:49.613553+00', 'Glen Lyon', 'GLEN LYON', 3, 32, 9999, 2, 3, 17, 146, NULL, '', 67, '882  828  880  804', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (2494, '1998-09-29 22:00:00+00', '2014-10-14 22:01:16.303362+00', 'Glasgow Country Dance', 'GLASGOW COUNTRY DANCE', 4, 32, 1, 1, 3, 42, 62, NULL, '', 62, '880/888/844/844', 0, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (2508, '1997-09-03 22:00:00+00', '2014-04-30 23:23:51.531696+00', 'Glen Clova', 'GLEN CLOVA', 3, 32, 9999, 1, 4, 1, 956, NULL, '', 81, '8888  8888  8840  8048', 0, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (2562, '1998-09-29 22:00:00+00', '2014-04-30 23:23:51.771263+00', 'Glens of Angus, The', 'GLENS OF ANGUS', 1, 32, 9999, 1, 4, 1, 176, NULL, 'Note that after the publication of the original Book 23, the Spurtle formation was changed to finish with »set and cross over« rather than »cross over and set« (which is what the book says).', 81, '8888  8888  16 8 8 8', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (15270, '2013-11-27 20:00:47.960886+00', '2015-02-24 14:40:41.097203+00', 'Gleneagles Gold', 'GLENEAGLES GOLD', 3, 32, 9999, 1, 4, 2, 1089, '2013-01-01', '', 93, '8888  8888  8888  4884', 0, 1, 1, 0, 93);
INSERT INTO 'dance' VALUES (15267, '2013-11-26 19:11:17.464244+00', '2015-02-24 14:45:55.446672+00', 'Gleneagles Treasure', 'GLENEAGLES TREASURE', 3, 32, 9999, 3, 5, 7, 1089, '2010-01-01', '', 71, '44444  88888  44444  86886', 0, 1, 1, 0, 72);
INSERT INTO 'dance' VALUES (15266, '2013-11-26 01:53:28.776926+00', '2017-11-23 00:19:31.186598+00', 'Gleneagles', 'GLENEAGLES', 3, 32, NULL, 1, 3, 42, 417, NULL, '', 53, '880/888/822/844', 0, 1, 1, 0, 70);
INSERT INTO 'dance' VALUES (2532, '2000-06-12 22:00:00+00', '2018-04-03 00:07:48.673073+00', 'Glen Feshie', 'GLEN FESHIE', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 47, '880  880  880  822', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (2531, '1997-04-03 22:00:00+00', '2017-08-28 23:02:58.911918+00', 'Gleneagles Dominie, The', 'GLENEAGLES DOMINIE', 2, 48, 9999, 1, 100, 2, 108, '1979-01-01', '', 69, '8008/0880/8228/8008/8888/8888', 0, 1, 1, 0, 68);
INSERT INTO 'dance' VALUES (13001, '2006-11-01 23:00:00+00', '2020-03-29 19:28:42.740656+00', 'Giants of Foudland, The', 'GIANTS OF FOUDLAND', 1, 48, 9999, 6, 3, 17, 3286, NULL, '', 83, '888/444/444/888/888/888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (3898, '1999-08-06 22:00:00+00', '2020-08-31 14:55:50.855224+00', 'Gentleman Jack', 'GENTLEMAN JACK', 1, 32, 9999, 1, 3, 42, 479, '1997-01-01', '', 62, '808  808  888  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (11299, '2003-05-06 22:00:00+00', '2020-12-25 10:57:24.55289+00', 'Gillian''s Strathspey', 'GILLIANS STRATHSPEY', 3, 40, 9999, 1, 4, 1, 3345, '2003-01-01', '', 70, '8800  8888  8888  8440  8008', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (13910, '2011-08-22 22:00:00+00', '2020-09-24 13:04:52.262227+00', 'Gifts', 'GIFTS', 3, 32, NULL, 2, 3, 17, 64, '2007-01-01', '', 71, '800  888  488  088', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (2510, '1997-09-03 22:00:00+00', '2020-10-13 18:03:20.151447+00', 'Glen Dochart Reel', 'GLEN DOCHART REEL', 1, 32, 9999, 1, 2, 76, 181, NULL, '', 60, '80  88  88  88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (2507, '1997-09-03 22:00:00+00', '2020-12-06 18:29:25.703069+00', 'Glen Affric', 'GLEN AFFRIC', 3, 32, 9999, 1, 4, 1, 181, NULL, '', 84, '8888  4444  8884  8888', 0, 1, 0, 0, 84);
INSERT INTO 'dance' VALUES (8129, '1997-10-26 23:00:00+00', '2020-12-19 14:18:48.808269+00', 'Girl From Edam, The', 'GIRL FROM EDAM', 1, 32, 9999, 1, 3, 42, 1445, '1995-01-01', '', 50, '800  888  844  844', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (12427, '2005-05-05 22:00:00+00', '2021-01-14 20:20:41.958035+00', 'Gary Scott''s Jig', 'GARY SCOTTS JIG', 2, 32, 9999, 1, 3, 42, 2701, '2004-01-01', '', 56, '800  844  888  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (9819, '2001-10-22 22:00:00+00', '2021-02-19 14:51:51.400195+00', 'Gladys McDonald of Glencoe', 'GLADYS MACDONALD OF GLENCOE', 2, 40, 9999, 1, 3, 42, 108, '2000-01-01', '', 60, '080  880  888  888  888', 0, 1, 0, 0, 80);
INSERT INTO 'dance' VALUES (9813, '2001-04-01 22:00:00+00', '2021-02-19 15:05:10.986796+00', 'Ghost Dance', 'GHOST DANCE', 3, 32, 9999, 1, 4, 1, 2847, NULL, '', 56, '8600  8444  8888  8000', 0, 1, 0, 0, 57);
INSERT INTO 'dance' VALUES (8051, '1998-01-05 23:00:00+00', '2021-03-02 07:19:51.07857+00', 'Glen Etive', 'GLEN ETIVE', 1, 32, 9999, 1, 3, 42, 44, '1996-01-01', 'The crib has been derived from the video.  Eric, 2014-01-01', 56, '800  888  844  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (2226, '1997-12-03 23:00:00+00', '2021-06-07 11:03:45.668374+00', 'Gallagher''s Fairest Flower', 'GALLAGHERS FAIREST FLOWER', 2, 32, 9999, 1, 3, 42, 586, NULL, '', 50, '800  844  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (14652, '2013-01-05 11:05:19.954446+00', '2021-03-14 20:23:48.240864+00', 'Golden Jubilee Strathspey, The', 'GOLDEN JUBILEE STRATHSPEY', 3, 32, NULL, 1, 3, 42, 3645, '2008-01-01', 'This dance has been modified; in the original version bars 9-16 were RHA; LHA for 3 couples.', 56, '660  888  888  444', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (2453, '1998-09-29 22:00:00+00', '2021-04-02 10:31:12.99967+00', 'Georgie''s Jig', 'GEORGIES JIG', 2, 32, 9999, 1, 4, 1, 99, NULL, '', 75, '6666  6666  6666  0888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (2713, '1998-10-12 22:00:00+00', '2021-06-01 20:59:09.609185+00', 'Ha! Ha! The Wooin'' o'' it', 'HA HA THE WOOIN O IT', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 52, '66  66  80  88', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (2525, '1998-07-08 22:00:00+00', '2021-06-03 14:58:32.173181+00', 'Glencoe', 'GLENCOE', 3, 32, 9999, 1, 4, 2, 313, NULL, 'For Peggy and Ray Russell.', 94, '8888  4884  8888  8888', 1, 1, 0, 1, 93);
INSERT INTO 'dance' VALUES (2504, '1998-09-30 22:00:00+00', '2023-01-27 11:39:02.202685+00', 'Glasgow Regatta', 'GLASGOW REGATTA', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 45, '82  80  80  88', 1, 1, 0, 1, 65);
INSERT INTO 'dance' VALUES (2501, '1998-09-29 22:00:00+00', '2023-01-27 11:42:48.586168+00', 'Glasgow Lasses', 'GLASGOW LASSES', 3, 32, 9999, 1, 2, 76, 397, '1748-01-01', '', 43, '44  44  84  84', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (2488, '1998-04-12 22:00:00+00', '2023-01-27 11:48:44.809541+00', 'Glaikit Stirk and The Parrot, The', 'GLAIKIT STIRK AND THE PARROT', 4, 64, 5, 5, 2, NULL, 108, '1994-11-01', 'Inscribed: A dance to mark the final show of "SCOTLAND THE WHAT".', 100, '88  88  88  88', 1, 1, 0, 1, 50);
INSERT INTO 'dance' VALUES (2471, '1998-04-05 22:00:00+00', '2021-06-04 10:30:15.717015+00', 'Gimlet, The', 'GIMLET', 2, 32, 9999, 1, 3, 42, 9998, '1740-01-01', 'Described as for a 4 or 5 couple set.', 28, '800  800  822  800', 1, 1, 0, 1, 37);
INSERT INTO 'dance' VALUES (2469, '1998-09-29 22:00:00+00', '2021-06-05 09:44:50.562953+00', 'Gilly Flower, The', 'GILLY FLOWER', 2, 32, 9999, 1, 3, 42, 503, NULL, '', 62, '880  888  844  888', 1, 1, 0, 1, 83);
INSERT INTO 'dance' VALUES (2464, '2002-04-19 22:00:00+00', '2021-06-05 09:56:53.417858+00', 'Gift from Heaven, A', 'GIFT FROM HEAVEN', 3, 32, 9999, 1, 4, 2, 950, NULL, 'Devised by Norman Whitson in memory of his daughter Shona.', 81, '8008  8888  8448  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (14700, '2013-01-31 10:20:47.036746+00', '2017-09-26 00:56:56.717877+00', 'George''s Bees', 'GEORGES BEES', 1, 32, NULL, 1, 4, 1, 10732, '2012-01-01', 'Devised for Allan''s brother George Shepherd of Market Overton, Leicestershire on the occasion of his 70th birthday.', 94, '8484  8888  8888  8888', 1, 1, 0, 0, 93);
INSERT INTO 'dance' VALUES (12717, '2006-03-23 23:00:00+00', '2018-04-06 21:28:09.550149+00', 'White Pine, The', 'WHITE PINE', 1, 32, 9999, 1, 4, 2, 152, NULL, 'The Arboreal Emblem Act passed May 1, 1984 by the Ontario Legislature declared that *Pinus Strobus Linnaeus* known as the *Eastern White Pine* is to be the arboreal emblem of Ontario.', 88, '8888/8888/8888/8008/', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2600, '1998-09-29 22:00:00+00', '2018-02-21 00:20:20.586365+00', 'Golden Wedding Strathspey, The', 'GOLDEN WEDDING STRATHSPEY', 3, 40, 9999, 1, 4, 1, 498, '1983-01-01', '', 85, '8888  8888  8888  8440  8448', 1, 1, 1, 1, 85);
INSERT INTO 'dance' VALUES (15125, '2013-09-15 20:52:36.408193+00', '2014-04-30 23:23:51.878069+00', 'Going Dutch', 'GOING DUTCH', 3, 32, NULL, 2, 3, 17, 2874, '2012-01-01', '', 58, '855  888  888  800', 0, 1, 1, 0, 77);
INSERT INTO 'dance' VALUES (11590, '2003-11-29 23:00:00+00', '2019-02-04 13:30:19.221379+00', 'Graham''s Frolic', 'GRAHAMS FROLIC', 1, 40, 9999, 4, 5, 6, 411, '2001-01-01', '', 75, '88888  44448  44448  80044  04840', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (9061, '2002-04-02 22:00:00+00', '2019-03-05 20:50:54.635811+00', 'Gordonian Strathspey, The', 'GORDONIAN STRATHSPEY', 3, 32, 9999, 2, 3, 18, 104, '1994-01-01', '', 62, '880/888/844/888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (13580, '2010-08-07 22:00:00+00', '2014-04-30 23:23:52.239645+00', 'Grassmarket Reel, The', 'GRASSMARKET REEL', 1, 32, NULL, 5, 56, NULL, 2701, NULL, '', 87, '888  888  444  888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (13133, '2006-12-05 23:00:00+00', '2014-04-30 23:23:52.269653+00', 'Green Ginger', 'GREEN GINGER', 3, 32, 9999, 1, 3, 42, 104, NULL, '', 70, '864  888  888  888', 1, 1, 1, 0, 93);
INSERT INTO 'dance' VALUES (15725, '2015-01-07 15:21:22.193887+00', '2015-01-07 15:21:22.193887+00', 'William Wakeman', 'WILLIAM WAKEMAN', 3, 32, 9999, 1, 4, 2, 3549, '2004-06-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9114, '1999-08-08 22:00:00+00', '2015-03-30 00:23:48.092295+00', 'Golden Sands Strathspey', 'GOLDEN SANDS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2605, '1999-07-04', '', 62, '888/880/880/888', 1, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (13300, '2007-07-22 22:00:00+00', '2016-06-03 13:42:47.794828+00', 'Golden Snitch, The', 'GOLDEN SNITCH', 2, 32, 9999, 1, 3, 42, 228, '2005-01-01', '', 53, '800  844  888  866', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (2682, '1998-11-07 23:00:00+00', '2018-04-03 00:07:50.108051+00', 'Greig''s Pipes', 'GREIGS PIPES', 3, 32, 9999, 1, 3, 42, 457, '1797-01-01', '', 53, '844  844  844  866', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (2661, '1998-09-29 22:00:00+00', '2016-10-10 16:05:07.885813+00', 'Green grow the Rashes', 'GREEN GROW THE RASHES', 3, 32, 9999, 1, 3, 42, 198, '1742-01-01', 'Notes:  



1. In bars 17-20, the circle needs to break in time to allow 3rd man to dance out to his partner''s place while 1st man and 3rd woman continue to dance round, finishing with 1st man in 2nd man''s place and 3rd woman in her partner''s place.  



2. Bars 21-24 are danced similarly.', 44, '888  840  408  800', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (2645, '1999-12-21 23:00:00+00', '2017-07-07 13:15:35.77998+00', 'Grant''s Reel', 'GRANTS REEL', 3, 32, 9999, 1, 2, NULL, 453, '1760-01-01', '', 31, '44  80  80  88', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (2635, '1998-04-12 22:00:00+00', '2017-10-12 15:38:27.230968+00', 'Grand Chain And Allepouss', 'GRAND CHAIN AND ALLEPOUSS', 2, 40, 9999, 1, 4, 1, 227, '1989-12-01', 'Intermediate level.   

', 70, '8880  8880  0888  8000  8888', 0, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (2556, '1998-11-14 23:00:00+00', '2020-03-21 08:18:41.076122+00', 'Glen Mor', 'GLEN MOR', 2, 32, 9999, 1, 3, 42, 128, NULL, '', 53, '844  822  888  880', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (2593, '1998-09-29 22:00:00+00', '2020-05-29 01:54:16.507496+00', 'Golden Pheasant, The', 'GOLDEN PHEASANT', 2, 40, 9999, 1, 3, 42, 432, NULL, 'Source:  Button & Whitaker: Le Sylphe. An elegant Collection of Twenty four Country dances, the Figures by Mr Wilson for the year 1813.



', 65, '888  880  888  844  888', 0, 1, 1, 1, 86);
INSERT INTO 'dance' VALUES (2674, '1998-01-12 23:00:00+00', '2020-12-06 18:36:05.942294+00', 'Greenburn Reel, The', 'GREENBURN REEL', 1, 32, 9999, 1, 3, 42, 108, '1994-01-01', '', 48, '888  820  822  844', 1, 1, 1, 1, 64);
INSERT INTO 'dance' VALUES (8674, '2002-05-06 22:00:00+00', '2020-09-18 22:53:19.826015+00', 'Globe Inn, The', 'GLOBE INN', 2, 32, 9999, 1, 3, 42, 200, '1996-01-01', '', 62, '404  12 12 12  848  880', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (2589, '1997-04-03 22:00:00+00', '2020-12-06 18:32:13.101023+00', 'Golden Hind, The', 'GOLDEN HIND', 3, 32, 9999, 1, 3, 18, 313, NULL, '', 87, '888  822  888  888', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (13723, '2011-07-09 22:00:00+00', '2020-10-13 19:49:26.197652+00', 'Golden Celebration Jig, The', 'GOLDEN CELEBRATION JIG', 2, 32, NULL, 1, 102, 2, 175, NULL, '"For the Lakes SD Club on their 50th anniversary"', 87, '8888  8448  8448  8448', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (2660, '1998-04-12 22:00:00+00', '2020-12-06 18:33:45.063803+00', 'Green Garden, The', 'GREEN GARDEN', 3, 32, 9999, 1, 3, 42, 227, '1988-11-05', '', 62, '800  888  888  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (10695, '2002-07-21 22:00:00+00', '2020-12-24 17:59:09.650347+00', 'Gloria''s Wee Jig', 'GLORIAS WEE JIG', 2, 32, 9999, 1, 2, 76, 2961, NULL, '', 45, '80  62  88  82', 0, 1, 0, 0, 65);
INSERT INTO 'dance' VALUES (11217, '2003-02-24 23:00:00+00', '2020-12-25 10:46:33.382417+00', 'Glenora Ferry, The', 'GLENORA FERRY', 2, 40, 9999, 1, 3, 42, 2677, '2000-01-01', '', 45, '804  480  800  888  844', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (14339, '2011-12-09 23:00:00+00', '2020-12-31 11:50:27.51757+00', 'Golden Bracken (32-bar version)', 'GOLDEN BRACKEN 32BAR VERSION', 1, 32, NULL, 1, 3, 42, 872, NULL, 'This dance was originally published in "Stepping Out Part 3" as a 24-bar dance, and later republished in "A Second Graded Book" with an added "circle and back" at the end, making it a 32-bar dance.', 53, '800  844  866  888', 1, 1, 1, 1, 53);
INSERT INTO 'dance' VALUES (2644, '1998-09-29 22:00:00+00', '2021-01-07 19:50:00.725997+00', 'Grant''s Rant', 'GRANTS RANT', 1, 48, 9999, 1, 3, 42, 453, '1772-01-01', '', 37, '800  080  800  888  800  880', 0, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (12634, '2005-11-08 23:00:00+00', '2021-01-11 23:15:50.661251+00', 'Glenrothes, The', 'GLENROTHES', 2, 32, 9999, 1, 4, 1, 3689, '1997-01-01', '', 48, '8640  8026  8044  8400', 1, 1, 1, 1, 48);
INSERT INTO 'dance' VALUES (10672, '2002-08-04 22:00:00+00', '2021-02-06 11:19:10.166411+00', 'Golden Gateway Reel', 'GOLDEN GATEWAY REEL', 1, 32, 9999, 1, 3, 42, 2961, '2000-01-01', '', 47, '480  888  822  822', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (5100, '2000-04-09 22:00:00+00', '2014-04-30 23:23:52.559561+00', 'Hal Robinson''s Rant', 'HAL ROBINSONS RANT', 1, 40, 9999, 3, 5, 7, 331, NULL, '', 60, '80800  88888  82842  44404', 1, 1, 1, 1, 48);
INSERT INTO 'dance' VALUES (9583, '2002-04-28 22:00:00+00', '2019-02-21 21:50:52.367071+00', 'Herstmonceux Castle', 'HERSTMONCEUX CASTLE', 3, 32, 9999, 2, 3, 17, 2794, '1994-01-01', '', 83, '880  808  888  888', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (16740, '2015-09-19 17:06:32.563285+00', '2015-09-22 11:29:23.250932+00', 'Bruichladdich', 'BRUICHLADDICH', 2, 32, 9999, 2, 3, 17, 595, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3104, '1998-09-30 22:00:00+00', '2018-04-03 00:07:53.652174+00', 'Inveraray', 'INVERARAY', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 50, '808  800  888  880', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (9007, '2002-01-06 23:00:00+00', '2022-10-04 14:46:15.51517+00', 'Grants'' New Rant, The', 'GRANTS NEW RANT', 3, 32, 9999, 1, 3, 42, 146, '1997-01-01', 'Inscribed "for David and Betty Grant in celebration of their Golden Wedding."', 62, '844  880  844  888', 1, 1, 0, 1, 83);
INSERT INTO 'dance' VALUES (7406, '1998-09-24 22:00:00+00', '2022-10-23 20:00:31.108505+00', 'Goat Fell Gallop, The', 'GOAT FELL GALLOP', 2, 32, 9999, 1, 4, 1, 146, NULL, 'Inscribed "To celebrate Walter Proven''s 50th birthday and to remind him of holidays on the Isle of Arran."', 47, '4444  4444  8000  8444', 1, 1, 1, 1, 46);
INSERT INTO 'dance' VALUES (2716, '1997-04-03 22:00:00+00', '2023-01-20 12:24:51.980346+00', 'Haddington Assembly', 'HADDINGTON ASSEMBLY', 2, 32, 9999, 1, 3, 42, 177, NULL, '', 41, '800  811  811  888', 1, 1, 0, 0, 54);
INSERT INTO 'dance' VALUES (2616, '2002-08-26 22:00:00+00', '2023-01-20 19:41:39.206284+00', 'Gothenburg''s Welcome', 'GOTHENBURGS WELCOME', 2, 32, 9999, 1, 3, 42, 278, NULL, 'This dance was devised by Bobby Munro to mark the occasion of the 1st Scandinavian Scottish Weekend Course in Gothenburg by the Gothenburg Branch.', 62, '400/12,12,12/844/888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (13223, '2007-01-07 23:00:00+00', '2014-04-30 23:23:52.574547+00', 'Half a Century', 'HALF A CENTURY', 1, 32, 9999, 1, 4, 1, 1049, '2006-10-26', 'Dance devised for Francien van Heuvel on the occasion of her 50th anniversary, October 25, 2006,

by Anne-Miek Klokgieters, The Hague. 



{{dance}}

1- 4::

    1st couple, giving right hands, cross over and cast off to second place, 2nd couple step up on bars 3-4.

5- 8::

    1st couple dance a half figure of eight round 2nd couple.

9-16::

    1st couple dance reels of three on the opposite side with 3rd and 4th couple.

17-20::

    1st couple lead up to the top, cross over and cast off to second place.

21-24::

    2nd and 1st couples dance right hands across once round.

25-32::

    1st, 3rd and 4th couples poussette.

::

    Repeat, with a new top couple.



(Original description added at author''s request.)', 53, '8000  8088  8400  8088', 1, 1, 1, 1, 53);
INSERT INTO 'dance' VALUES (15265, '2013-11-25 19:16:21.030199+00', '2014-04-30 23:23:52.96631+00', 'Happy Weasel, The', 'HAPPY WEASEL', 2, 32, NULL, 1, 3, 42, 10898, NULL, '', 69, '844  888  888  888', 0, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (14978, '2013-07-13 19:59:42.700134+00', '2014-04-30 23:23:53.254927+00', 'Heart to Heart', 'HEART TO HEART', 3, 32, NULL, 1, 3, 42, 10808, NULL, 'dance of as yet unknown source and deviser.', 44, '800  800  844  888', 0, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (9948, '2001-06-12 22:00:00+00', '2014-04-30 23:23:53.279098+00', 'Heather Bank Jig, The', 'HEATHER BANK JIG', 2, 32, 9999, 1, 4, 2, 335, NULL, '', 94, '8008  8448  4884  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (10790, '2002-08-25 22:00:00+00', '2015-08-31 14:14:49.22516+00', 'Hall Change', 'HALL CHANGE', 2, 32, 9999, 1, 4, 1, 38, NULL, '', 75, '8620  8888  8080  8888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (2631, '1998-09-30 22:00:00+00', '2015-05-18 19:31:22.238925+00', 'Gramachie', 'GRAMACHIE', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 44, '880  800  844  844', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (2746, '1997-04-03 22:00:00+00', '2016-04-18 23:14:19.774095+00', 'Hamilton Races', 'HAMILTON RACES', 2, 16, 9999, 1, 2, NULL, 129, NULL, '', 64, '88  77', 1, 0, 0, 0, 93);
INSERT INTO 'dance' VALUES (9565, '2000-08-20 22:00:00+00', '2016-10-16 15:29:09.177309+00', 'Hamilton Welcome', 'HAMILTON WELCOME', 3, 32, 9999, 3, 5, 16, 146, '1999-01-01', 'Devised by Roy Goldring and presented to the Hamilton (Ontario) Branch of the RSCDS to commemorate his visit in 1999 to teach the Hamilton Week-end. This was the only visit Roy & Doreen Goldring made to North America

', 45, '80808  80808  84000  80040', 1, 1, 1, 1, 45);
INSERT INTO 'dance' VALUES (9564, '2002-05-06 22:00:00+00', '2016-10-16 14:43:59.260092+00', 'Hamilton Hospitality', 'HAMILTON HOSPITALITY', 1, 32, 9999, 3, 5, 16, 146, '1999-01-01', 'Devised by Roy Goldring and presented to the Hamilton (Ontario) Branch of the RSCDS to commemorate his visit in 1999 to teach the Hamilton Week-end. This was the only visit Roy & Doreen Goldring made to North America', 40, '80044  84400  88000  80080', 1, 1, 1, 1, 40);
INSERT INTO 'dance' VALUES (2770, '1998-04-12 22:00:00+00', '2018-04-03 00:07:50.747398+00', 'Happy Dancers, The', 'HAPPY DANCERS', 2, 32, 9999, 1, 3, 42, 146, NULL, '', 53, '844  855  855  844', 0, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (2711, '1999-12-16 23:00:00+00', '2017-02-13 14:47:28.860763+00', 'H.I.S.C.D.', 'HISCD', 1, 32, 9999, 1, 3, 42, 850, NULL, 'The title means: »Happiness Is Scottish Country Dancing«', 53, '844  822  844  888', 0, 1, 1, 0, 70);
INSERT INTO 'dance' VALUES (2747, '1999-04-21 22:00:00+00', '2017-07-07 14:25:46.977054+00', 'Hamilton Rant, The', 'HAMILTON RANT', 1, 48, 9999, 1, 3, 42, 62, NULL, '', 42, '422  844  800  844  844  866', 1, 1, 1, 1, 55);
INSERT INTO 'dance' VALUES (18695, '2018-10-02 13:42:36.738301+00', '2018-11-04 13:04:24.479618+00', 'Candy Cane Reel, The', 'CANDY CANE REEL', 1, 32, NULL, 1, 3, 42, 2766, '2008-12-01', '', 50, '800/880/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2825, '1997-09-03 22:00:00+00', '2019-03-16 13:01:56.352921+00', 'He Built A Crooked House', 'HE BUILT A CROOKED HOUSE', 1, 32, 9999, 2, 3, 17, 992, NULL, '', 50, '800  008  080  888', 0, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (2782, '1998-04-21 22:00:00+00', '2019-03-16 15:49:53.162529+00', 'Happy To Meet', 'HAPPY TO MEET', 2, 32, 9999, 2, 3, 17, 44, NULL, '', 41, '666  666  800  800', 0, 1, 1, 0, 54);
INSERT INTO 'dance' VALUES (2777, '1998-09-29 22:00:00+00', '2021-01-14 20:31:37.345978+00', 'Happy Meeting, The', 'HAPPY MEETING', 2, 32, 9999, 1, 2, 76, 9998, NULL, '', 43, '44  44  80  88', 0, 1, 1, 0, 62);
INSERT INTO 'dance' VALUES (2805, '1998-07-08 22:00:00+00', '2020-04-06 08:44:05.928809+00', 'Harvest Moon, The', 'HARVEST MOON', 1, 32, 9999, 1, 3, 42, 108, '1994-01-01', '', 69, '844/888/888/888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (2812, '1999-10-27 22:00:00+00', '2020-06-01 17:59:20.893741+00', 'Haughs o'' Cromdale', 'HAUGHS O CROMDALE', 3, 16, 9999, 1, 2, 76, 9998, NULL, '', 64, '77  88', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (9332, '2000-08-29 22:00:00+00', '2020-07-14 20:24:13.408313+00', 'Grimaldi 700', 'GRIMALDI 700', 1, 88, 9999, 4, 4, 3, 146, '1996-01-01', 'Devised for the 700th anniversary of the arrival of the Grimaldi family in Monaco.', 68, '8080  8888  0808  8888    6666  4444  6666  4444    8080  0808  8888', 0, 1, 0, 0, 68);
INSERT INTO 'dance' VALUES (2725, '1998-09-29 22:00:00+00', '2021-06-01 20:50:34.797815+00', 'Haig of Bemersyde', 'HAIG OF BEMERSYDE', 3, 32, 9999, 1, 4, 1, 388, '1980-01-01', 'Devised to mark the Diamond Jubilee of The Royal British Legion Scotland in 1981.', 95, '8888  8888  8558  8888', 1, 1, 0, 1, 95);
INSERT INTO 'dance' VALUES (18574, '2018-09-10 19:21:55.319285+00', '2020-09-01 15:24:32.049711+00', 'Wandering Eggplant, The', 'WANDERING EGGPLANT', 1, 32, NULL, 1, 3, 42, 2766, '2009-02-01', '', 50, '866/866/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18505, '2018-08-13 16:47:37.266238+00', '2020-11-16 21:28:47.3074+00', 'Saltspring Strathspey, The', 'SALTSPRING STRATHSPEY', 3, 32, NULL, 2, 3, 17, 80, '2006-01-01', 'Inscribed to ALL the Saltspring Dancers - HISCD', 79, '800/888/888/848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18575, '2018-09-10 23:15:50.421665+00', '2020-11-17 19:57:50.479282+00', 'Kingussie Promenade', 'KINGUSSIE PROMENADE', 2, 32, NULL, 5, 2, 30, 1582, NULL, '', 100, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2709, '1998-07-09 22:00:00+00', '2020-12-06 18:37:47.280159+00', 'Gypsy Glen', 'GYPSY GLEN', 3, 32, 9999, 2, 3, 18, 101, NULL, '', 71, '888  800  844  866', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (2822, '1998-11-14 23:00:00+00', '2020-12-06 18:40:10.24692+00', 'Hazel Tree, The', 'HAZEL TREE', 2, 32, 9999, 1, 3, 42, 108, '1982-01-01', '', 50, '880  844  844  844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (9165, '1999-11-09 23:00:00+00', '2020-12-20 23:43:57.084284+00', 'Gypsy Weaver', 'GYPSY WEAVER', 3, 32, 9999, 1, 3, 42, 2679, NULL, '', 50, '808  844  844  844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (2801, '2002-09-20 22:00:00+00', '2021-01-31 11:28:54.202832+00', 'Harry And The Harem', 'HARRY AND THE HAREM', 2, 32, 9999, 4, 54, 30, 752, NULL, 'Dedicated to Harry Robertson for his unsurpassed generosity in squiring and partnering as many ladies as possible at the same time !!!!!', 83, '8800  8888  8666  8888', 0, 1, 0, 0, 82);
INSERT INTO 'dance' VALUES (3145, '1997-11-20 23:00:00+00', '2021-05-26 09:14:19.929721+00', 'Islay Strathspey, The', 'ISLAY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 47, '800  880  822  888', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (2781, '1998-09-30 22:00:00+00', '2021-05-31 10:21:00.459603+00', 'Happy Returns', 'HAPPY RETURNS', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 56, '888  888  800  844', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (2745, '2000-02-21 23:00:00+00', '2021-05-31 10:31:06.334038+00', 'Hamilton House', 'HAMILTON HOUSE', 2, 32, 9999, 1, 3, 42, 263, '1789-01-01', '', 50, '422  844  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (2727, '1997-09-03 22:00:00+00', '2021-06-01 20:31:16.926364+00', 'Half and Half', 'HALF AND HALF', 2, 32, 9999, 1, 3, 42, 982, NULL, '', 34, '440  880  800  822', 1, 1, 0, 1, 45);
INSERT INTO 'dance' VALUES (2853, '2002-04-10 22:00:00+00', '2014-04-30 23:23:53.406482+00', 'Helen MacDonald of Forres', 'HELEN MACDONALD OF FORRES', 3, 32, 9999, 1, 3, 42, 173, '1984-10-01', 'Preferred recording: The Silver Tassie, bt Bobby Frewe Trio "Northern Jubilee". The lead tune is marked below.', 69, '844  888  888  888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (2916, '1999-10-27 22:00:00+00', '2018-04-03 00:07:52.142744+00', 'Highland Laddie', 'HIGHLAND LADDIE', 1, 32, 9999, 1, 3, 42, 9998, '1754-01-01', '', 47, '444  800  844  888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (17832, '2017-06-22 17:14:10.491807+00', '2017-07-18 22:34:12.849728+00', 'Pope Street', 'POPE STREET', 2, 40, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8055, '1997-09-18 22:00:00+00', '2022-10-14 21:41:55.261124+00', 'High Expectations', 'HIGH EXPECTATIONS', 3, 32, 9999, 1, 4, 1, 146, NULL, '', 44, '4040  4040  8000  8888', 1, 1, 1, 1, 43);
INSERT INTO 'dance' VALUES (12769, '2006-05-31 22:00:00+00', '2022-12-18 16:42:19.426935+00', 'Heatherbrae', 'HEATHERBRAE', 1, 88, 9999, 4, 4, 3, 370, '2003-01-01', 'The booklet states: "Dedicated to both Doncaster and Retford Branches of the RSCDS on my retirement as teacher of both branches with much love and happy memories, November, 2003."', 78, '8484  8484  8888  8888  4848  4848  4444  4444  6666  7777  8888', 1, 1, 1, 1, 78);
INSERT INTO 'dance' VALUES (12603, '2005-11-02 23:00:00+00', '2014-04-30 23:23:53.744786+00', 'Highlander''s Farewell', 'HIGHLANDERS FAREWELL', 1, 32, 9999, 1, 3, 42, 2682, '2004-01-01', '»Devised by Rod Downey, Wellington, New Zealand. TAC is a great place to meet dancers from all around the world, and similarly great musicians. At the 2004 TAC Summer School I met Mara Shea, from Raleigh, North Carolina and admired her fiddle playing greatly. Mara played with Bobby and Laird Brown and Lisa Scott on several nights at that School. Mara generously gifted me some of her CDs from her group ›The Elftones‹, and I was inspired to write a dance based on one of the tunes, a stirring reel called ›Highlander''s Farewell‹.«', 43, '800  800  888  844', 1, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (14390, '2012-01-04 23:00:00+00', '2014-04-30 23:23:53.787091+00', 'Hirsel, The', 'HIRSEL', 2, 40, NULL, 1, 3, 42, 9998, NULL, 'Source: crib sheet of the RSCDS Delft Branch dance on 1997-10-04.  Source called "Leaflet"; no deviser named.  The Delft Branch was asked but cannot find any further information on either.', 45, '804  840  800  844  888', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (14239, '2011-08-27 22:00:00+00', '2018-10-11 14:08:22.506829+00', 'Easy Peasy', 'EASY PEASY', 1, 32, NULL, 1, 2, 76, 10474, NULL, '', 69, '88/88/88/88', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2944, '2002-11-26 23:00:00+00', '2019-03-15 20:45:12.193079+00', 'Hirsel, The', 'HIRSEL', 3, 32, 9999, 2, 3, 18, 13, NULL, '', 71, '808  888  840  844', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (2972, '1998-09-29 22:00:00+00', '2014-04-30 23:23:53.934549+00', 'Honeymoon, The', 'HONEYMOON', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 44, '800  880  800  888', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (11538, '2003-10-05 22:00:00+00', '2015-10-04 07:26:38.447944+00', 'Hooper''s Double Jig', 'HOOPERS DOUBLE JIG', 2, 32, 9999, 1, 4, 11, 10377, '2007-01-01', 'This dance long named Adrian Conrad as author, but in an e-mail (december 2010) to Eric Ferguson, Adrian wrote "Thank you for putting Iain McLennan-Brown''s name in. Mine really shouldn''t be mentioned. I''m only a publisher."', 75, '8008  8448  6666  8888', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (2842, '1998-01-11 23:00:00+00', '2019-03-16 12:51:50.382318+00', 'Heather Strathspey, The', 'HEATHER STRATHSPEY', 3, 40, 9999, 1, 4, 1, 87, NULL, '', 82, '4444  8888  8888  8888  8444', 1, 1, 1, 1, 82);
INSERT INTO 'dance' VALUES (7415, '1997-04-04 22:00:00+00', '2016-04-18 23:03:02.510289+00', 'Her Majesty''s Crown', 'HER MAJESTYS CROWN', 3, 32, 9999, 1, 3, 42, 557, NULL, 'Devised in July 1986 to commemorate several visits made to the Bluegrass by Queen Elizabeth II. The Queen, an avid horsewomen, has made regular tours of Kentucky to assess American stallions for her mares. On her second visit in 1986, she made a rare public appearance and worshipped with parishioners as St. John Episcopal Church in Versailles. Two Central Kentucky Branch members had the honour of being a part of that memorable service.', 50, '800  844  844  888', 1, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (2975, '1998-11-17 23:00:00+00', '2018-04-03 00:07:52.601517+00', 'Honeysuckle (and the Bindweed), The', 'HONEYSUCKLE AND THE BINDWEED', 3, 32, 9999, 1, 3, 42, 2435, NULL, '', 55, '851  866  866  844', 0, 1, 1, 0, 72);
INSERT INTO 'dance' VALUES (2924, '2000-09-20 22:00:00+00', '2016-11-15 15:47:42.904016+00', 'Highland Rambler, The', 'HIGHLAND RAMBLER', 1, 40, 9999, 1, 3, 42, 146, '1985-01-01', '', 50, '804  840  888  800  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (2925, '1999-11-01 23:00:00+00', '2017-07-07 13:02:41.269438+00', 'Highland Reel, The', 'HIGHLAND REEL', 1, 32, 9999, 5, 56, 76, 9998, NULL, '', 100, '888  888  888  888', 0, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (13587, '2010-08-08 22:00:00+00', '2017-11-14 00:55:18.741641+00', 'High Society', 'HIGH SOCIETY', 1, 40, NULL, 1, 102, 2, 884, NULL, '', 85, '8888  8888  0880  4884  8888', 0, 1, 1, 1, 85);
INSERT INTO 'dance' VALUES (11930, '2004-12-06 23:00:00+00', '2018-04-03 00:08:17.486687+00', 'Snowgoose, The', 'SNOWGOOSE', 2, 32, 9999, 1, 3, 42, 3480, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15263, '2013-11-16 23:29:43.293487+00', '2014-04-30 23:23:54.051118+00', 'Howell at the Moon', 'HOWELL AT THE MOON', 2, 32, NULL, 1, 3, 42, 1268, NULL, 'For Herb And Kathryn Howell''s 25th Wedding Anniversary.  2 versions:  A is Kathryn''s Version of their Courtship,  B is Herb''s Version of their Courtship ', 31, '840  804  800  800', 1, 1, 1, 0, 41);
INSERT INTO 'dance' VALUES (3021, '1997-08-24 22:00:00+00', '2018-03-03 23:30:04.830274+00', 'Hunter''s Moon', 'HUNTERS MOON', 2, 32, 9999, 1, 100, 2, 108, '1994-01-01', '', 75, '0880  8888  0880  8888', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (7745, '2002-03-03 23:00:00+00', '2014-04-30 23:23:54.118297+00', 'Hunter''s Hill', 'HUNTERS HILL', 4, 64, 5, 1, 4, 3, 21, NULL, '', 91, '8080  8888  8484  8888    8888  8888  8888  8888', 0, 1, 1, 1, 90);
INSERT INTO 'dance' VALUES (3027, '1997-09-04 22:00:00+00', '2014-04-30 23:23:54.14859+00', 'Hunting Horn, The', 'HUNTING HORN', 2, 32, 9999, 1, 3, 42, 249, '1975-01-01', '', 50, '800  888  844  844', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (2887, '2001-05-21 22:00:00+00', '2020-08-05 14:35:08.170269+00', 'Hey, Johnnie Cope', 'HEY JOHNNIE COPE', 1, 32, 9999, 1, 3, 42, 129, NULL, '', 67, '800/844/888/822', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (14086, '2011-08-25 22:00:00+00', '2020-09-26 07:11:20.972686+00', 'Hurrying Home', 'HURRYING HOME', 1, 32, NULL, 1, 3, 42, 2804, NULL, '', 56, '800  888  888  844', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (2868, '1998-09-29 22:00:00+00', '2020-12-06 18:42:29.383819+00', 'Her Majesty is Welcome', 'HER MAJESTY IS WELCOME', 4, 64, 5, 1, 4, 1, 326, '1974-01-01', '', 62, '8888  8888  8080  8800  8220  8660  8080  8008', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (2900, '1999-10-16 22:00:00+00', '2020-12-06 18:44:38.499734+00', 'High Lodge, The', 'HIGH LODGE', 2, 32, 9999, 1, 3, 42, 2672, NULL, '', 47, '840  844  844  808', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (2962, '1998-09-29 22:00:00+00', '2020-12-06 18:46:22.751837+00', 'Holyrood House', 'HOLYROOD HOUSE', 2, 48, 9999, 1, 4, 1, 319, '1962-01-01', '', 69, '6006  8448  6006  8448  8888  4888', 0, 1, 0, 0, 68);
INSERT INTO 'dance' VALUES (10231, '2001-11-07 23:00:00+00', '2020-12-23 10:58:26.773863+00', 'Helen Frame''s Jig', 'HELEN FRAMES JIG', 2, 32, 9999, 1, 3, 42, 1827, NULL, '', 52, '800  888  882  484', 0, 1, 0, 0, 68);
INSERT INTO 'dance' VALUES (12835, '2006-09-03 22:00:00+00', '2021-01-08 18:06:48.522167+00', 'Holden My Own', 'HOLDEN MY OWN', 2, 32, 9999, 1, 3, 42, 3703, NULL, '', 47, '804  808  888  800', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (2970, '1998-09-30 22:00:00+00', '2021-05-27 21:35:07.663678+00', 'Honey Moon, The', 'HONEY MOON', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 41, '444  800  880  880', 1, 1, 0, 1, 54);
INSERT INTO 'dance' VALUES (2910, '1998-09-29 22:00:00+00', '2021-05-28 12:44:22.814996+00', 'Highland Fair, The', 'HIGHLAND FAIR', 2, 32, 9999, 1, 2, 76, 9998, NULL, '', 60, '80  88  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (2957, '1998-11-14 23:00:00+00', '2021-05-27 21:51:05.528119+00', 'Holly Bush, The', 'HOLLY BUSH', 2, 48, 9999, 1, 3, 42, 9998, NULL, '', 48, '840  800  800  880  888  888', 1, 1, 0, 1, 63);
INSERT INTO 'dance' VALUES (2903, '1998-09-30 22:00:00+00', '2021-05-28 12:53:12.121046+00', 'High Road to Wigton', 'HIGH ROAD TO WIGTON', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 60, '88  88  80  88', 1, 1, 0, 1, 87);
INSERT INTO 'dance' VALUES (2934, '1998-09-30 22:00:00+00', '2021-10-11 22:49:52.213841+00', 'Highlandman kissed his Mother, The', 'HIGHLANDMAN KISSED HIS MOTHER', 1, 32, 9999, 1, 3, 42, 9998, NULL, '<<scddb:not-identical:8087>>

', 53, '800  844  866  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (9930, '2001-06-05 22:00:00+00', '2014-04-30 23:23:54.233148+00', 'Hurlygush', 'HURLYGUSH', 2, 32, 9999, 1, 4, 2, 101, NULL, 'Hurlygush is the sound of a running burn.', 84, '8008  8888  8888  8668', 1, 1, 1, 0, 84);
INSERT INTO 'dance' VALUES (18699, '2018-10-02 22:12:20.4898+00', '2018-10-02 22:12:20.4898+00', 'Card Trick', 'CARD TRICK', 2, 32, NULL, 1, 3, 42, 2766, '2008-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9636, '2002-01-08 23:00:00+00', '2019-02-06 23:04:24.291613+00', 'Inchmickery', 'INCHMICKERY', 2, 32, 9999, 3, 5, 16, 146, '2000-01-01', 'Dedicated to Karen & Neil Barron who shared an 80th birthday in 1999.', 40, '84000  80880  84004  80004', 0, 1, 1, 0, 40);
INSERT INTO 'dance' VALUES (13461, '2009-11-17 23:00:00+00', '2014-04-30 23:23:54.805776+00', 'In Traditional Mode', 'IN TRADITIONAL MODE', 3, 32, NULL, 1, 3, 42, 146, NULL, '', 50, '800  888  822  866', 0, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (3083, '1997-04-03 22:00:00+00', '2014-04-30 23:23:54.849052+00', 'Ina Souter''s Jig', 'INA SOUTERS JIG', 2, 32, 9999, 1, 3, 42, 173, '1968-11-20', 'Preferred Music: "Ashludie Rant" by Ian Holmes or Jimmy Shand, or "The Starry-Eyed Lassie" by Bobby Frew Four with Ian Powrie.  The corresponding tunes are shows as favourites below.', 50, '880  808  800  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (14678, '2013-01-22 00:11:51.310921+00', '2019-08-11 20:16:30.850549+00', 'Honeybee Hornpipe, The', 'HONEYBEE HORNPIPE', 1, 32, NULL, 1, 2, 76, 10719, NULL, '', 52, '80  44  80  44', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (2931, '1997-12-05 23:00:00+00', '2022-03-02 21:15:24.174463+00', 'Highland Welcome, A', 'HIGHLAND WELCOME', 1, 32, 9999, 5, 2, NULL, 127, NULL, '', 100, '88  88  88  88', 0, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (2886, '1998-07-09 22:00:00+00', '2023-01-20 12:02:31.777647+00', 'Hey Johnny Cope', 'HEY JOHNNY COPE', 2, 32, 9999, 2, 3, 17, 82, NULL, '', 41, '820  802  880  880', 1, 1, 0, 1, 54);
INSERT INTO 'dance' VALUES (3019, '1997-09-04 22:00:00+00', '2023-01-27 10:57:27.986462+00', 'Hunter Valley Strathspey', 'HUNTER VALLEY STRATHSPEY', 3, 32, 9999, 1, 2, 76, 109, NULL, '', 60, '62  88  88  88', 1, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (9836, '2006-10-31 23:00:00+00', '2019-05-16 13:48:09.131954+00', 'Inimitable Derek, The', 'INIMITABLE DEREK', 1, 32, 9999, 1, 3, 42, 146, '2005-01-01', 'Roy Goldring wrote this dance in honour of Derek Haynes who died in 2005.', 53, '880  888  822  844', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (14650, '2013-01-05 08:59:53.486654+00', '2014-04-30 23:23:55.037865+00', 'Inverdruie Jig', 'INVERDRUIE JIG', 2, 32, NULL, 1, 3, 42, 108, '1994-11-01', 'For Bob Grant of Edinburgh when he taught at Coylumbridge Hotel.  The river Druie flows past that hotel and into the Spey.', 66, '888  880  848  888', 0, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (3038, '1998-09-29 22:00:00+00', '2015-09-18 00:47:48.005668+00', 'I Canna Buckle To', 'I CANNA BUCKLE TO', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 56, '880/800/844/880', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (7420, '1997-04-14 22:00:00+00', '2017-02-13 14:49:34.451995+00', 'Hope Little''s Strathspey', 'HOPE LITTLES STRATHSPEY', 3, 32, 9999, 2, 3, 17, 146, NULL, '', 71, '840  888  800  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (14484, '2012-06-15 05:31:30.336457+00', '2017-03-09 16:19:18.474422+00', 'Hungarian Bride', 'HUNGARIAN BRIDE', 1, 48, NULL, 4, 5, 35, 2626, '2007-07-21', 'For the wedding of Judit Hunyadi and Jean-François Ginoux in Szeged on 21 July 2007.', 57, '88888  08088  80808  04048  84004  04840', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (3045, '1998-09-29 22:00:00+00', '2017-07-07 13:23:17.599594+00', 'I''ll gang nae mair tae yon Toon', 'ILL GANG NAE MAIR TAE YON TOON', 3, 40, 9999, 1, 3, 42, 9998, '1825-01-01', '', 55, '880  800  888  888  880', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (3017, '1997-04-03 22:00:00+00', '2017-11-23 00:43:33.243746+00', 'Hunt The Gowk', 'HUNT THE GOWK', 1, 32, 9999, 4, 4, 4, 417, NULL, '', 100, '8888/8888/8888/8888', 0, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (14465, '2012-06-13 08:21:34.906808+00', '2014-04-30 23:23:55.07366+00', 'Invitation Dance, The', 'INVITATION DANCE', 2, 32, NULL, 1, 3, 42, 146, NULL, 'For Derek Kendall''s 75th birthday celebration evening at Leeds Branch.', 50, '844  844  844  844', 0, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (3137, '1997-04-03 22:00:00+00', '2018-04-02 23:56:35.335357+00', 'Irongray', 'IRONGRAY', 3, 32, 9999, 1, 3, 42, 129, NULL, '', 62, '822  888  888  866', 1, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (3042, '1998-04-24 22:00:00+00', '2020-08-30 21:12:15.353665+00', 'I Met Her In St. Andrews', 'I MET HER IN ST ANDREWS', 3, 32, 9999, 1, 2, 76, 227, '1988-01-01', 'For Miriam and James Leonard, who married on the Isle of Arran in June 1988.  Miriam was the Thistle Club''s treasure(r) for a long time.', 60, '44  88  88  88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (10295, '2003-02-09 23:00:00+00', '2020-12-23 11:06:04.87869+00', 'I Don''t Want to be One', 'I DONT WANT TO BE ONE', 2, 32, 9999, 1, 4, 13, 1084, NULL, 'Written by a Scottish Country Dance Band player who kept hearing dances say ''I don''t want to be one. Will you go first?'' So he devised a dance where the 4C start as the dancing couple and progress to 1st place.

', 58, '0048  0608  8808  8448', 1, 1, 1, 1, 57);
INSERT INTO 'dance' VALUES (14276, '2011-10-15 22:00:00+00', '2020-09-27 08:31:16.441314+00', 'Hurray for Two!', 'HURRAY FOR TWO', 3, 40, NULL, 1, 100, 14, 1445, NULL, 'For Mia and Peter to celebrate their (joint) 120th birthday!', 72, '8008  8888  8668  8008  8448', 0, 1, 0, 0, 72);
INSERT INTO 'dance' VALUES (3033, '2003-01-22 23:00:00+00', '2020-12-06 18:49:56.604387+00', 'Huntsman, The', 'HUNTSMAN', 2, 40, 9999, 1, 4, 1, 21, NULL, '', 72, '8040  8888  8000  16 16 16 16', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (3108, '1998-09-29 22:00:00+00', '2020-12-07 21:38:46.16439+00', 'Inverneill House', 'INVERNEILL HOUSE', 1, 32, 9999, 1, 3, 42, 108, '1986-01-01', '', 45, '860  804  800  888', 0, 1, 1, 0, 60);
INSERT INTO 'dance' VALUES (3111, '1998-09-30 22:00:00+00', '2020-12-07 21:40:59.411011+00', 'Inverness Reel, The', 'INVERNESS REEL', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 64, '84  88  88  88', 0, 1, 0, 0, 93);
INSERT INTO 'dance' VALUES (7285, '2001-11-21 23:00:00+00', '2020-12-18 20:31:26.371397+00', 'Immigrant Lass, The', 'IMMIGRANT LASS', 2, 32, 9999, 1, 4, 1, 197, NULL, 'The following corrections were included on a loose sheet "Notes on Dances by Bob Grant June 1996", when Book 39 was first sold in the Summer School bookshop:



5-8  Right hands across need to be ''driven'' round



9-16  1/2 rights and lefts have polite turns at end



31-32  1st couple don''t ''cast'' up into 4th place although it feels more natural and I''m sure it will be done !



', 63, '8844  8484  8080  8008', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (3102, '1997-09-04 22:00:00+00', '2020-12-08 09:03:01.821681+00', 'Inveran Bridge', 'INVERAN BRIDGE', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 62, '888  880  808  888', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (8123, '1997-12-03 23:00:00+00', '2020-12-19 14:15:37.458636+00', 'I''ll Come Over to You', 'ILL COME OVER TO YOU', 2, 32, 9999, 1, 3, 42, 1445, '1996-01-01', '', 62, '844  844  888  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (12566, '2005-10-19 22:00:00+00', '2021-01-14 00:37:36.199999+00', 'Jenny''s Happiness', 'JENNYS HAPPINESS', 3, 32, 9999, 2, 2, 76, 3135, '2005-01-01', 'Written in honour of Jenny van Kessel of the Geldermalsen SCD Group.', 58, '77  44  88  88', 1, 1, 1, 1, 84);
INSERT INTO 'dance' VALUES (9635, '2002-01-06 23:00:00+00', '2021-02-21 18:19:22.517019+00', 'Hutton Castle', 'HUTTON CASTLE', 3, 32, 9999, 1, 4, 1, 146, '2000-01-01', '', 66, '8888  4444  6060  8484', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (14550, '2012-09-02 16:42:01.658403+00', '2021-03-27 18:56:02.125322+00', 'Iona Jig', 'IONA JIG', 2, 32, NULL, 1, 4, 1, 3199, NULL, 'Devised for a Friday evening dance in Iona Village Hall, for local dancers with no SCD experience.  Not published elsewhere than on this database.', 75, '4444  8888  4444  8888', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (3105, '1998-10-07 22:00:00+00', '2021-05-26 09:26:54.272009+00', 'Invercauld''s Reel', 'INVERCAULDS REEL', 3, 32, 9999, 1, 3, 42, 1977, '1758-01-01', '', 47, '800  880  844  866', 1, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (3093, '2002-01-06 23:00:00+00', '2021-05-26 09:44:43.959764+00', 'Inn On The Moor', 'INN ON THE MOOR', 3, 32, 9999, 2, 3, 18, 21, NULL, '', 92, '888  484  888  888', 1, 1, 0, 1, 91);
INSERT INTO 'dance' VALUES (3084, '1998-09-29 22:00:00+00', '2021-05-26 09:47:50.819294+00', 'Inch of Perth', 'INCH OF PERTH', 3, 32, 9999, 1, 3, 42, 1977, '1758-02-01', '', 47, '880  804  822  866', 1, 1, 0, 1, 62);
INSERT INTO 'dance' VALUES (3046, '1998-11-11 23:00:00+00', '2021-06-17 10:00:31.221659+00', 'I''ll mak'' ye fain to follow me', 'ILL MAK YE FAIN TO FOLLOW ME', 2, 32, 9999, 1, 3, 42, 457, '1797-01-01', '', 41, '800  800  844  866', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (9528, '2002-09-22 22:00:00+00', '2021-07-30 07:57:34.891639+00', 'Iain''s Obsession', 'IAINS OBSESSION', 2, 40, 9999, 1, 3, 42, 308, NULL, '', 47, '800  822  844  844  888', 1, 1, 1, 1, 63);
INSERT INTO 'dance' VALUES (14654, '2013-01-05 11:12:01.557714+00', '2014-04-30 23:23:55.341629+00', 'It''s About Time', 'ITS ABOUT TIME', 3, 32, NULL, 1, 3, 42, 1760, '2004-01-01', '', 45, '880  880  811  844', 0, 1, 1, 0, 60);
INSERT INTO 'dance' VALUES (11360, '2003-06-11 22:00:00+00', '2018-11-26 03:42:14.172375+00', 'Ivy Leaf, The', 'IVY LEAF', 3, 32, 9999, 6, 3, 17, 411, '2002-01-01', '', 92, '888/12 12 12/444/844', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (3165, '1998-09-29 22:00:00+00', '2014-04-30 23:23:55.371841+00', 'It''s Just for Fun', 'ITS JUST FOR FUN', 2, 32, 9999, 1, 3, 42, 123, '1984-01-01', '', 56, '800  866  866  888', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (9087, '1999-07-25 22:00:00+00', '2014-04-30 23:23:55.386795+00', 'It''s nae Bother', 'ITS NAE BOTHER', 2, 32, 9999, 1, 2, NULL, 175, NULL, '', 60, '66  88  66  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (10794, '2002-08-25 22:00:00+00', '2019-01-09 23:12:02.523295+00', 'James Gray', 'JAMES GRAY', 2, 32, 9999, 1, 100, 2, 2815, NULL, '', 62, '8008/8008/8888/8008', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (13323, '2007-09-03 22:00:00+00', '2014-04-30 23:23:55.539646+00', 'Janette Bulloch''s Strathspey', 'JANETTE BULLOCHS STRATHSPEY', 3, 32, 9999, 1, 4, 2, 640, NULL, 'Dance information derived from the video made at Kuckucksnest.', 94, '8888  8888  8888  8448', 0, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (3237, '1998-11-09 23:00:00+00', '2014-04-30 23:23:55.645485+00', 'Jenny, Come down to Jock', 'JENNY COME DOWN TO JOCK', 2, 24, 9999, 1, 2, NULL, 9998, NULL, 'Former RSCDS Archivist Marilyn Healy says:



> The RSCDS 1985 edition called [the dance] Hey! Jenny,

> Come Down to Jock, whereas the 2001 revised edition called it Jenny, Come

> Down to Jock.  (The tune is given as Hey! Jenny, Come Down to Jock in both

> versions).  The source we give for it is Allan’s Ballroom Guide (c.1880) and

> it is also in David Anderson’s Ball-Room Guide (approx. same time) and both

> call it Jenny, Come down to Jock  (We have Allan and David Anderson pocket

> books in the archive.)



In current RSCDS publications the dance is called »Jenny, …« (without the »Hey!«).', 57, '88  44  88', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (20638, '2022-01-23 18:34:05.217845+00', '2022-01-23 18:34:05.217845+00', 'Roses and Heather', 'ROSES AND HEATHER', 7, 96, NULL, NULL, 51, 54, 2805, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1766, '1998-04-08 22:00:00+00', '2022-07-31 10:40:51.994549+00', 'Drumnadrochit', 'DRUMNADROCHIT', 3, 40, 9999, 3, 5, 7, 90, '1978-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3235, '1998-09-29 22:00:00+00', '2023-01-10 19:57:24.002327+00', 'Jenny dang the Weaver', 'JENNY DANG THE WEAVER', 1, 32, 9999, 1, 2, 76, 198, '1748-01-01', '', 43, '44  44  80  88', 1, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (11365, '2003-06-11 22:00:00+00', '2023-01-18 16:44:03.532964+00', 'Inside Oot Fish Eater, The', 'INSIDE OOT FISH EATER', 1, 32, 9999, 3, 5, 7, 1853, '1995-01-01', '', 80, '80800  84884  88888  88888', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (13134, '2006-12-05 23:00:00+00', '2016-01-01 22:56:07.693778+00', 'Island Celebration', 'ISLAND CELEBRATION', 2, 32, 9999, 1, 4, 2, 104, NULL, '', 75, '8008  8008  8888  8888', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (10797, '2002-10-13 22:00:00+00', '2019-04-20 10:49:06.383377+00', 'Irene McLean of Duns', 'IRENE MACLEAN OF DUNS', 1, 32, 9999, 1, 4, 1, 1502, '1999-11-01', 'Irene McLean was well kent in the Bordeers in dancing circles, and contributed much to the life of the Duns and District Branch.', 69, '8800  8088  8800  8888', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (3231, '1998-11-14 23:00:00+00', '2019-06-23 09:29:00.628541+00', 'Jennifer''s Jig', 'JENNIFERS JIG', 2, 32, 9999, 1, 3, 42, 108, '1968-01-01', 'Dedicated to Jennifer Wilson.



In June 2019 she was awarded an MBE for her contributions to Scottish Country Dancing and charity work. See <<https://www.pressandjournal.co.uk/fp/news/moray/1767662/queens-birthday-honours-two-moray-dancing-stalwarts-honoured-for-their-work/>> for more details.', 62, '888  880  888  880', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (3176, '1998-10-28 23:00:00+00', '2014-07-11 16:52:42.315897+00', 'Jack o'' Carron', 'JACK O CARRON', 2, 48, 9999, 1, 4, 1, 1016, NULL, '', 68, '8888  8484  8444  8444  8444  8222', 0, 1, 1, 0, 67);
INSERT INTO 'dance' VALUES (3147, '1998-07-06 22:00:00+00', '2020-08-06 14:55:49.438553+00', 'Isle of Arran Strathspey', 'ISLE OF ARRAN STRATHSPEY', 3, 40, 9999, 1, 4, 22, 82, NULL, '', 80, '0880  8888  8888  8888  0880', 0, 1, 0, 0, 80);
INSERT INTO 'dance' VALUES (3154, '1998-09-29 22:00:00+00', '2020-09-11 20:19:25.391572+00', 'Isle, The', 'ISLE', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 47, '888  800  822  880', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (9637, '2000-09-05 22:00:00+00', '2020-09-09 09:40:49.202645+00', 'Isle of Tiree, The', 'ISLE OF TIREE', 3, 32, 9999, 1, 3, 42, 146, '2000-01-01', '', 62, '888  888  844  844', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (13131, '2006-12-05 23:00:00+00', '2020-09-16 22:12:10.761081+00', 'Jig for Denise, A', 'JIG FOR DENISE', 2, 32, 9999, 1, 3, 42, 104, '2002-01-01', '', 56, '888  808  800  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (13465, '2009-11-17 23:00:00+00', '2020-09-18 08:07:42.294416+00', 'It Should be Fun', 'IT SHOULD BE FUN', 2, 32, NULL, 1, 4, 1, 146, NULL, 'For Brenda Burnell, who has spent much time and energy teaching children and the young at heart.', 50, '8880  8880  8000  8000', 0, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (13508, '2009-11-21 23:00:00+00', '2020-09-18 16:01:11.872925+00', 'Jenny''s Well', 'JENNYS WELL', 3, 32, NULL, 2, 3, 17, 1269, NULL, '', 98, '688  16 16 16  888', 0, 1, 0, 0, 97);
INSERT INTO 'dance' VALUES (3326, '2002-11-21 23:00:00+00', '2021-05-23 20:12:36.202889+00', 'John of Bon Accord', 'JOHN OF BON ACCORD', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 44, '840/804/800/888', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (3281, '2001-04-03 22:00:00+00', '2020-12-07 21:47:09.49887+00', 'Jimmy''s Fancy', 'JIMMYS FANCY', 3, 32, 9999, 1, 3, 42, 466, '1751-01-01', '', 50, '880  888  844  800', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (9803, '2001-04-25 22:00:00+00', '2020-12-21 16:28:57.752082+00', 'Jack''s Jig', 'JACKS JIG', 2, 32, 9999, 2, 3, 17, 165, NULL, '', 69, '888  888  664  888', 0, 1, 0, 0, 91);
INSERT INTO 'dance' VALUES (10792, '2002-08-25 22:00:00+00', '2020-12-24 18:07:14.224523+00', 'James Senior of St Andrews', 'JAMES SENIOR OF ST ANDREWS', 3, 32, 9999, 1, 100, 2, 48, NULL, '', 75, '8008  8888  8888  8008', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (13318, '2007-09-03 22:00:00+00', '2021-01-03 12:44:48.580132+00', 'Jennifer''s Itchy Fingers', 'JENNIFERS ITCHY FINGERS', 1, 32, 9999, 1, 3, 42, 175, NULL, '', 50, '844  844  808  880', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (12428, '2005-05-05 22:00:00+00', '2021-01-14 20:19:00.472564+00', 'It''s all right', 'ITS ALL RIGHT', 2, 32, 9999, 1, 3, 42, 2015, NULL, '', 50, '888  888  800  800', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (9580, '2000-09-06 22:00:00+00', '2021-02-21 19:38:19.855615+00', 'Jig for Elthea, A', 'JIG FOR ELTHEA', 2, 32, 9999, 2, 2, 76, 394, NULL, '', 52, '88  80  08  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (9091, '1999-08-05 22:00:00+00', '2021-03-02 14:17:12.321366+00', 'Jean''s Jig', 'JEANS JIG', 2, 32, 9999, 1, 2, 76, 727, NULL, '', 52, '80  80  88  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (3197, '1998-11-17 23:00:00+00', '2021-03-10 11:56:18.802919+00', 'Jamie''s Jig', 'JAMIES JIG', 2, 32, 9999, 1, 3, 42, 2432, NULL, 'Marie Buckle writes, “Our son, Jamie, was indirectly responsible for introducing me to the Cambridge Scottish Society, a happy association”.', 56, '844/800/12,12,12/444', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (8922, '2001-03-30 22:00:00+00', '2021-03-13 09:28:46.800906+00', 'Join the Dance', 'JOIN THE DANCE', 1, 32, 9999, 1, 3, 42, 2533, '1998-01-01', '', 44, '800  844  844  808', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (3391, '1997-04-03 22:00:00+00', '2021-05-22 01:18:27.200603+00', 'Kafoozalum', 'KAFOOZALUM', 3, 32, 9999, 1, 100, 11, 108, '1979-01-01', '', 62, '0880/0880/0880/8888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (3152, '2002-01-06 23:00:00+00', '2021-05-26 09:11:32.253002+00', 'Isle of Skye, The', 'ISLE OF SKYE', 1, 32, 9999, 1, 3, 42, 432, '1816-01-01', '', 56, '888  888  800  880', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (3246, '1998-09-29 22:00:00+00', '2021-07-20 18:35:08.45956+00', 'Jessie''s Hornpipe', 'JESSIES HORNPIPE', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'Note from ETF: Variant: on [1-8] mirror Figs8, 1c starting inwards (flows better on bar 9).', 38, '800  800  880  880', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (3461, '1997-08-25 22:00:00+00', '2019-03-15 10:30:47.935405+00', 'Kildrummy Castle', 'KILDRUMMY CASTLE', 3, 64, 9999, 4, 4, 3, 146, NULL, '', 75, '8  8  4  4    8  4  4  8', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3396, '1997-11-27 23:00:00+00', '2019-03-17 22:17:56.009606+00', 'Kaleidoscope', 'KALEIDOSCOPE', 4, 64, 5, 1, 4, 1, 23, NULL, '', 94, '8888  8888  8888  4848', 0, 1, 1, 0, 45);
INSERT INTO 'dance' VALUES (3343, '2002-03-11 23:00:00+00', '2014-04-30 23:23:56.132287+00', 'Johnny''s New Jig', 'JOHNNYS NEW JIG', 2, 32, 9999, 1, 2, NULL, 954, '1985-01-01', 'The author''s note says: "the 2nd half of the dance is the same as "Lady Catherine Bruce''s Reel. The dance can be used just before introducing the Allemande to a new beginner''s class. An audience participation / teaching dance."', 52, '88  80  80  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14677, '2013-01-22 00:10:16.613791+00', '2019-08-11 20:27:36.405171+00', 'Just for the Fun of It', 'JUST FOR THE FUN OF IT', 1, 32, NULL, 2, 3, 46, 11849, NULL, 'The progression after one repeat is (2,1,3) but then the top & bottom of the set are inverted after each repeat, so 3rd couple start the 2nd repeat.', 67, '800  844  880  888', 1, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (3310, '2002-02-26 23:00:00+00', '2019-10-20 22:55:28.461025+00', 'Joe MacDiarmid''s Jig', 'JOE MACDIARMIDS JIG', 2, 32, 9999, 1, 4, 1, 487, '1980-01-01', '', 75, '8888/8448/8000/8888', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (10926, '2002-11-14 23:00:00+00', '2014-04-30 23:23:56.463873+00', 'Justine''s Delight', 'JUSTINES DELIGHT', 5, 32, 9999, 7, 113, 4, 9998, NULL, '', 75, '44  44  88  88', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (15503, '2014-06-27 21:07:54.66438+00', '2022-04-26 21:54:17.229146+00', 'Longwood Strathspey, The', 'LONGWOOD STRATHSPEY', 3, 32, NULL, 1, 4, 1, 10971, NULL, '', 97, '8888/8888/8488/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15219, '2013-10-25 22:55:48.047785+00', '2022-11-08 12:31:10.846313+00', 'John of Montrose', 'JOHN OF MONTROSE', 3, 32, NULL, 2, 3, 17, 728, '2007-06-01', 'John of Montrose was written for John McKillop ("now" (2007) living in Port Talbot, South Wales) for his 40th birthday last year ', 53, '840/844/844/888', 1, 1, 1, 0, 70);
INSERT INTO 'dance' VALUES (9869, '2002-10-13 22:00:00+00', '2022-11-30 23:37:46.626362+00', 'Jubilee Quadrille', 'JUBILEE QUADRILLE', 1, 88, 9999, 4, 4, 3, 246, NULL, '', 72, '15 0 15 0   0 15 0 15   4444  8888  4444  8888   16 16 16 16   8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8138, '2002-12-16 23:00:00+00', '2022-12-21 21:23:42.96922+00', 'Jim Dougal of Eyemouth', 'JIM DOUGAL OF EYEMOUTH', 3, 32, 9999, 2, 3, 17, 1502, '1994-01-01', '', 68, '880  485  448  880', 1, 1, 1, 1, 67);
INSERT INTO 'dance' VALUES (3381, '1997-08-22 22:00:00+00', '2023-01-10 13:10:19.685259+00', 'Just a Dance', 'JUST A DANCE', 2, 32, 9999, 1, 2, 76, 511, NULL, '', 52, '44  44  88  88', 1, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (3365, '2002-11-21 23:00:00+00', '2023-01-10 13:16:29.757067+00', 'Jubilee Jig, The', 'JUBILEE JIG', 2, 32, 9999, 1, 3, 42, 319, '1973-01-01', '', 36, '403  403  844  844', 1, 1, 0, 1, 47);
INSERT INTO 'dance' VALUES (3339, '1998-09-29 22:00:00+00', '2023-01-10 19:34:54.377025+00', 'Johnny Groat''s House', 'JOHNNY GROATS HOUSE', 1, 32, 9999, 1, 3, 42, 453, '1748-01-01', '', 38, '800  800  888  800', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (1624, '1998-09-29 22:00:00+00', '2023-02-12 16:02:56.909661+00', 'Just as I was in the Morning', 'JUST AS I WAS IN THE MORNING', 2, 40, 9999, 1, 2, 76, 453, '1757-01-01', 'Originally (re)published by the RSCDS in Book 19 with the title "The Deuks Dang Ow’re My Daddie" it was later found the dance was originally called "Just as I was in the Morning" which is now used as the main title. The other is added as an alias.', 34, '80  08  61  44  80', 1, 1, 1, 1, 48);
INSERT INTO 'dance' VALUES (12715, '2006-03-23 23:00:00+00', '2018-04-06 21:55:58.254619+00', 'Tides of Cape d''Or, The', 'TIDES OF CAPE DOR', 3, 32, 9999, 1, 3, 42, 2115, '2004-04-01', 'TIlis dance was devised to commemorate the visit by members of the Hamilton Branch to the Halifax International Weekend in 2001. Several members of the Branch afterwards stayed at Cape D''or which juts out into the Bay of Fundy, Nova Scotia, at its northern end, and is scoured by fierce tidal rips containing numerous whirlpools.', 69, '888/888/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7433, '1997-12-03 23:00:00+00', '2014-10-28 12:23:26.750733+00', 'Joy Newman''s Jig', 'JOY NEWMANS JIG', 2, 32, 9999, 1, 3, 42, 1, '1995-01-01', 'A Christmas gift for Joy', 50, '880  808  800  888', 1, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (3503, '1998-04-12 22:00:00+00', '2019-03-15 10:24:32.290384+00', 'Kingston Flyer, The', 'KINGSTON FLYER', 1, 32, 9999, 1, 4, 1, 788, NULL, '', 37, '4444  4444  8000  8000', 1, 1, 1, 1, 37);
INSERT INTO 'dance' VALUES (3435, '2001-09-13 22:00:00+00', '2014-04-30 23:23:56.719326+00', 'Kendall''s Hornpipe', 'KENDALLS HORNPIPE', 2, 32, 9999, 1, 2, NULL, 9998, NULL, '', 56, '88  80  88  84', 0, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (6813, '1998-07-08 22:00:00+00', '2020-04-14 11:49:39.861102+00', 'Twixt Don and Dee', 'TWIXT DON AND DEE', 3, 32, 9999, 1, 4, 2, 108, '1975-01-01', 'A dance to mark the 50th anniversary of the Aberdeen branch of the RSCDS.', 78, '8888  8228  8448  8448', 1, 1, 0, 1, 78);
INSERT INTO 'dance' VALUES (13618, '2010-10-08 22:00:00+00', '2020-06-27 21:04:11.254992+00', 'Jig to the Music', 'JIG TO THE MUSIC', 2, 32, 9999, 2, 3, 17, 10255, NULL, '', 83, '888  888  800  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (13511, '2009-11-23 23:00:00+00', '2020-09-18 16:13:56.512726+00', 'Jig for Garry, A', 'JIG FOR GARRY', 2, 32, NULL, 1, 3, 42, 175, NULL, '"Devised for Gary McIntosh of Forres, as a birthday surprise"', 56, '800  888  844  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (14242, '2011-08-28 22:00:00+00', '2020-09-27 08:08:03.114326+00', 'Kandahar Reel (original)', 'KANDAHAR REEL ORIGINAL', 1, 32, NULL, 8, 4, NULL, 10306, NULL, '', 46, '840000  883200  848400  888800', 0, 1, 0, 0, 46);
INSERT INTO 'dance' VALUES (3373, '1997-08-28 22:00:00+00', '2020-12-07 21:53:50.549344+00', 'Julian''s Jig', 'JULIANS JIG', 2, 32, 9999, 1, 3, 42, 381, NULL, '', 56, '844  844  844  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (3390, '1999-07-25 22:00:00+00', '2020-12-07 21:59:09.069598+00', 'Jute Spinner''s Reel, The', 'JUTE SPINNERS REEL', 1, 32, 9999, 1, 3, 42, 1038, NULL, '', 69, '880  888  888  888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (10675, '2002-07-21 22:00:00+00', '2020-12-24 10:31:41.597756+00', 'Joie de Musique', 'JOIE DE MUSIQUE', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', 55, '811  866  844  888', 0, 1, 0, 0, 72);
INSERT INTO 'dance' VALUES (13227, '2007-01-11 23:00:00+00', '2020-12-25 21:34:42.889322+00', 'Jubilee Flowers', 'JUBILEE FLOWERS', 3, 40, 9999, 1, 4, 1, 3135, NULL, '', 77, '8888  8000  4884  8888  4888', 0, 1, 0, 0, 77);
INSERT INTO 'dance' VALUES (14386, '2011-12-22 23:00:00+00', '2020-12-26 10:23:23.067481+00', 'Juggling with Kiwis', 'JUGGLING WITH KIWIS', 2, 32, NULL, 1, 3, 42, 228, '2008-06-29', '', 59, '800  888  884  888', 0, 1, 0, 1, 79);
INSERT INTO 'dance' VALUES (3474, '1998-11-16 23:00:00+00', '2021-01-06 15:21:54.643662+00', 'Kilt Is My Delight, The', 'KILT IS MY DELIGHT', 1, 32, 9999, 1, 4, 1, 87, NULL, '', 62, '4224  4884  4044  8888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (9123, '2000-09-03 22:00:00+00', '2021-08-02 13:58:34.388354+00', 'July 28th Jig, The', 'JULY 28TH JIG', 2, 32, 9999, 2, 3, 17, 2440, '1999-01-01', '', 41, '880  800  822  808', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (11890, '2004-11-02 23:00:00+00', '2021-01-18 18:45:39.10931+00', 'Jim Johnstone''s Reel', 'JIM JOHNSTONES REEL', 1, 32, 9999, 1, 3, 42, 146, '2004-01-01', '', 53, '888  844  844  822', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (11164, '2003-02-24 23:00:00+00', '2021-01-29 22:32:43.429717+00', 'Jig for Sally Peavine, A', 'JIG FOR SALLY PEAVINE', 2, 32, 9999, 1, 3, 42, 2677, NULL, '', 66, '840  888  888  888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (3541, '2002-08-29 22:00:00+00', '2021-05-18 20:19:44.732219+00', 'Knit the Pocky', 'KNIT THE POCKY', 1, 32, 9999, 1, 2, 76, 461, '1806-01-01', '', 52, '44  44  88  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (3436, '1999-10-19 22:00:00+00', '2021-03-13 18:56:22.861977+00', 'Kendoon Strathspey, The', 'KENDOON STRATHSPEY', 3, 32, 9999, 1, 3, 42, 129, '1960-01-01', '', 56, '880  808  884  884', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (8556, '2002-03-11 23:00:00+00', '2021-03-16 18:53:43.034595+00', 'Jig for Joe, A', 'JIG FOR JOE', 2, 32, 9999, 1, 3, 42, 692, '1992-06-01', 'For Joe, to celebrate his retirement.', 69, '844  888  888  888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (3412, '1998-09-29 22:00:00+00', '2021-05-20 10:54:03.484753+00', 'Keep The Country Bonnie Lassie', 'KEEP THE COUNTRY BONNIE LASSIE', 3, 40, 9999, 1, 3, 42, 453, '1760-01-01', '', 50, '800  800  844  888  888', 1, 1, 0, 1, 66);
INSERT INTO 'dance' VALUES (3342, '1998-09-29 22:00:00+00', '2021-05-23 08:31:28.51721+00', 'Johnny McGill', 'JOHNNY MACGILL', 2, 40, 9999, 1, 2, 76, 457, '1797-01-01', '', 55, '80  80  88  88  88', 1, 1, 0, 1, 80);
INSERT INTO 'dance' VALUES (3338, '1998-09-29 22:00:00+00', '2021-05-23 12:31:32.494255+00', 'Johnnie''s Welcome Hame', 'JOHNNIES WELCOME HAME', 1, 40, 9999, 1, 3, 42, 153, '1982-12-01', 'Devised to mark John Mortimer''s visit to Forres after 16 years in New Zealand.', 60, '888  12 12 12  400  888  800', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (3317, '2002-04-19 22:00:00+00', '2021-05-23 20:26:59.951035+00', 'John Derek Evans', 'JOHN DEREK EVANS', 3, 32, 9999, 1, 3, 42, 401, '1993-01-01', 'Derek and his wife Emily dance in Ron Wallace''s Santa Rosa class. Ron devised the dance after Emily commissioned the music as a gift for Derek.', 43, '800  888  800  880', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (3280, '1997-04-03 22:00:00+00', '2021-05-24 09:55:50.734461+00', 'Jimmy Shand''s Delight', 'JIMMY SHANDS DELIGHT', 1, 40, 9999, 1, 3, 42, 39, NULL, '', 51, '822  844  888  888  800', 0, 1, 0, 1, 70);
INSERT INTO 'dance' VALUES (3364, '1998-04-12 22:00:00+00', '2021-06-16 16:40:25.7803+00', 'Jubilee Greeting, The', 'JUBILEE GREETING', 3, 32, 9999, 1, 3, 42, 108, '1990-01-01', '', 50, '800/844/844/888', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (3256, '2000-11-12 23:00:00+00', '2021-05-25 12:08:00.192592+00', 'Jig for Judith Pretty', 'JIG FOR JUDITH PRETTY', 2, 32, 9999, 1, 3, 42, 1021, NULL, '', 50, '800  888  822  866', 1, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (7561, '2001-05-21 22:00:00+00', '2015-07-13 19:09:05.109203+00', 'Karlsruhe Anniversary, The', 'KARLSRUHE ANNIVERSARY', 1, 32, 9999, 3, 5, 7, 228, '1997-01-01', '', 57, '80800  82842  82842  84844', 1, 1, 1, 1, 57);
INSERT INTO 'dance' VALUES (3506, '1998-09-29 22:00:00+00', '2017-07-07 14:22:00.283615+00', 'Kingussie Flower', 'KINGUSSIE FLOWER', 1, 40, 9999, 1, 2, NULL, 9998, NULL, '', 55, '80  44  88  88  88', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (3418, '1998-09-29 22:00:00+00', '2016-12-03 08:19:25.819373+00', 'Kelloholm Jig, The', 'KELLOHOLM JIG', 2, 32, 9999, 1, 3, 42, 36, NULL, '', 50, '822/822/844/888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (6897, '1998-10-25 23:00:00+00', '2018-04-03 00:08:24.041159+00', 'Waggle O'' The Kilt, The', 'WAGGLE O THE KILT', 2, 40, 9999, 1, 3, 42, 87, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3617, '2001-04-03 22:00:00+00', '2018-04-03 00:13:41.443344+00', 'Lady MacIntosh''s Rant', 'LADY MACINTOSHS RANT', 3, 32, 9999, 1, 110, 42, 453, '1754-01-01', '', 47, '800  844  888  840', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (14368, '2011-12-16 23:00:00+00', '2018-10-09 14:15:16.209061+00', 'Kölbls'' Reel, The', 'KOLBLS REEL', 1, 32, NULL, 1, 3, 42, 854, '2011-01-01', 'for Dirk and Kay Kölbl shortly after their wedding 2010.', 56, '800  866  866  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (3577, '2002-04-19 22:00:00+00', '2014-04-30 23:23:57.61192+00', 'Ladies of Dunse, The', 'LADIES OF DUNSE', 1, 40, 9999, 1, 3, 42, 9998, NULL, 'The town of Duns (modern spelling) is in the Scottish borders,

south-east of Edinburgh. The tune is »The Duchess of Buccleuch«

(Buck-LOO), but Buccleuch is near Selkirk, which is quite a distance

from Duns.', 47, '800  080  880  808  822', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (3585, '1998-09-30 22:00:00+00', '2014-04-30 23:23:57.64227+00', 'Lads of Saltcoats, The', 'LADS OF SALTCOATS', 1, 32, 9999, 1, 2, NULL, 9998, NULL, 'Saltcoats is a town on the west coast of Scotland, south-west of

Glasgow. Its name is based on the earliest local industry, namely the

extraction of salt from sea water.

', 52, '84  84  80  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (2558, '1998-04-12 22:00:00+00', '2018-03-19 04:42:44.339119+00', 'Glenmorven', 'GLENMORVEN', 1, 32, 9999, 1, 3, 42, 44, '1992-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3669, '1997-12-27 23:00:00+00', '2020-08-31 14:32:58.341863+00', 'Lake Shore Jig, The', 'LAKE SHORE JIG', 2, 32, 9999, 1, 3, 42, 361, NULL, '', 62, '800  888  888  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (3529, '1998-09-30 22:00:00+00', '2022-12-20 12:42:20.8249+00', 'Kiss under the Stairs', 'KISS UNDER THE STAIRS', 2, 32, 9999, 1, 3, 42, 9998, '1756-01-01', 'The notes in MMM say this came from Rutherfords collection of 1756. ', 38, '804  804  800  844', 1, 1, 0, 1, 50);
INSERT INTO 'dance' VALUES (3490, '1997-09-07 22:00:00+00', '2023-01-10 11:31:23.684702+00', 'King Over the Water, The', 'KING OVER THE WATER', 3, 32, 9999, 1, 3, 42, 146, NULL, '', 47, '800  808  880  866', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (3437, '1999-10-27 22:00:00+00', '2023-01-10 11:33:47.221226+00', 'Kenmure''s on and awa''', 'KENMURES ON AND AWA', 2, 24, 9999, 1, 2, 76, 9998, '1822-01-01', '', 69, '88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (15313, '2013-12-19 22:47:24.469678+00', '2019-03-11 19:45:07.524347+00', 'Peinture, La', 'PEINTURE', 3, 32, NULL, 2, 3, 17, 3135, '2013-12-19', 'Devised for Noor Seegers on becoming honorary member of the Geldermalsen Scottish Dance Club "White Heather", on its 25th anniversary.  This dance makes allusions to Noor''s hobbies: SCD, Painting and the French language.



Suggested recording: Amstel Court, by George Meikle and the Lothian S. Dance Band', 59, '822  888  888  808', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (3601, '1998-09-30 22:00:00+00', '2019-07-18 10:30:59.157279+00', 'Lady Dumfries', 'LADY DUMFRIES', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 62, '880/880/888/888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (3626, '2002-02-27 23:00:00+00', '2020-03-06 21:07:25.006338+00', 'Lady McGowan''s Dream', 'LADY MACGOWANS DREAM', 3, 32, 9999, 1, 2, 76, 406, '1975-01-01', '', 64, '88  75  88  88', 0, 1, 0, 0, 93);
INSERT INTO 'dance' VALUES (3562, '1998-11-07 23:00:00+00', '2020-07-05 09:08:57.925116+00', 'Tempête, La', 'TEMPETE', 1, 48, 9999, 5, 4, NULL, 9998, NULL, '', 92, '8008  0880  8888  8888  8888  8888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (3424, '1998-09-30 22:00:00+00', '2020-07-25 22:20:14.972348+00', 'Kelso Races', 'KELSO RACES', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 38, '440  440  800  888', 0, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (3544, '1998-10-23 22:00:00+00', '2021-05-18 20:17:11.209898+00', 'Knockendarroch', 'KNOCKENDARROCH', 1, 32, 9999, 1, 3, 42, 176, NULL, '', 58, '882  844  844  888', 0, 1, 0, 0, 77);
INSERT INTO 'dance' VALUES (3444, '1998-09-29 22:00:00+00', '2020-12-08 09:50:09.347084+00', 'Keppoch''s Rant', 'KEPPOCHS RANT', 3, 32, 9999, 1, 3, 42, 453, '1756-01-01', '', 62, '844  808  888  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (3486, '1997-04-03 22:00:00+00', '2020-12-08 09:51:33.14212+00', 'King o'' the Rookery', 'KING O THE ROOKERY', 2, 32, 9999, 1, 3, 42, 21, NULL, 'Devised for Bobby Crowe', 69, '844  888  888  888', 0, 1, 1, 0, 91);
INSERT INTO 'dance' VALUES (3493, '1997-08-25 22:00:00+00', '2020-12-08 09:52:43.392591+00', 'King''s Chapel', 'KINGS CHAPEL', 3, 32, 9999, 1, 3, 42, 108, '1993-01-01', '', 56, '800  866  866  888', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (3525, '1998-01-05 23:00:00+00', '2020-12-08 22:21:21.019762+00', 'Kiss for a Ha''pennie, A', 'KISS FOR A HAPENNIE', 1, 32, 9999, 1, 3, 42, 976, '1740-01-01', '', 47, '880  800  844  866', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (3611, '1998-09-29 22:00:00+00', '2020-12-08 22:44:47.620461+00', 'Lady Jean Murray''s Rant', 'LADY JEAN MURRAYS RANT', 3, 32, 9999, 1, 2, 76, 453, '1750-02-01', 'According to Book 10, Lady Jean Murray was the elder daughter of James, 2nd Duke of Atholl. She was born in 1730, married John, Earl of Crawford in 1747 and died the same year.', 52, '44  44  88  88', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (3631, '1998-09-29 22:00:00+00', '2020-12-08 22:52:15.15863+00', 'Lady of the Lake', 'LADY OF THE LAKE', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 54, '86  84  80  88', 1, 1, 1, 1, 78);
INSERT INTO 'dance' VALUES (7782, '2002-03-11 23:00:00+00', '2020-12-18 21:02:55.9419+00', 'Kirkbrae Welcome', 'KIRKBRAE WELCOME', 1, 32, 9999, 1, 3, 42, 1, NULL, '', 50, '800  844  888  844', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (10632, '2002-07-01 22:00:00+00', '2020-12-24 10:28:16.93673+00', 'Kitten in the Mirror, The', 'KITTEN IN THE MIRROR', 1, 32, 9999, 1, 3, 42, 2203, NULL, '', 50, '800  888  844  844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (7084, '1998-12-10 23:00:00+00', '2021-01-09 22:39:56.02515+00', 'Where East Meets West', 'WHERE EAST MEETS WEST', 3, 32, 9999, 2, 3, 17, 108, '1983-01-01', 'Devised by John Drewry for the 1983 wedding of Mel and Ellie Briscoe, who met at TAC Summer School in Ontario when Mel lived in Massachusetts and Ellie lived in California. ', 83, '844/880/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10900, '2003-01-30 23:00:00+00', '2021-02-02 17:37:22.171861+00', 'Ladies from DeKalb, The', 'LADIES FROM DEKALB', 2, 32, 9999, 1, 3, 42, 2766, '2002-01-01', 'Suggested music is Flights of Fancy from Celebrate 50 Years with the Boston Branch.



This dance is dedicated to Mary Helen and Melissa, who drive in from DeKalb (45 minutes to an hour) each week to dance.', 44, '800  844  844  844', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (3542, '1998-07-08 22:00:00+00', '2021-03-13 16:19:29.323192+00', 'Knock o'' Braemoray, The', 'KNOCK O BRAEMORAY', 2, 40, 9999, 1, 4, 2, 153, NULL, '', 58, '8008/0880/8008/8668/8008', 0, 1, 1, 1, 57);
INSERT INTO 'dance' VALUES (3473, '1999-10-09 22:00:00+00', '2021-03-27 19:52:58.089387+00', 'Kilspindie', 'KILSPINDIE', 2, 32, 9999, 1, 2, 76, 392, NULL, 'Recommended tune: Blue Bonnets (6/8 time).', 52, '88  88  80  80', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (3485, '1999-07-25 22:00:00+00', '2021-04-09 20:11:38.667061+00', 'Kinfauns Castle', 'KINFAUNS CASTLE', 3, 32, 9999, 3, 5, 7, 175, '1968-01-01', 'First published on a Glendarroch SCD Sheet in 1968.



This can be done in a 3 couple set with a modification of bars 25-32: 1st with 2nd, then 1st with 3rd couples dance half poussettes ending in order 2,3,1.', 71, '48884  48884  08080  84885', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (3502, '1998-11-02 23:00:00+00', '2021-05-18 20:49:13.384412+00', 'Kings Town Spurtle, The', 'KINGS TOWN SPURTLE', 1, 32, 9999, 2, 3, 17, 118, '1985-01-01', 'Devised "just to keep things stirring in Kingston".', 60, '880  820  844  888', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (3499, '1997-09-07 22:00:00+00', '2021-05-19 10:38:44.702965+00', 'Kingdom Of Fife, The', 'KINGDOM OF FIFE', 3, 32, 9999, 1, 3, 42, 976, '1740-01-01', '', 47, '840  800  844  888', 1, 1, 0, 1, 62);
INSERT INTO 'dance' VALUES (2372, '2000-08-06 22:00:00+00', '2021-06-05 19:36:48.751236+00', 'Kelvinside', 'KELVINSIDE', 1, 40, 9999, 1, 3, 42, 2939, NULL, '', 67, '666  888  888  666  888', 1, 1, 1, 1, 90);
INSERT INTO 'dance' VALUES (3593, '1997-11-18 23:00:00+00', '2015-09-28 21:47:25.607215+00', 'Lady C Bruce''s Reel', 'LADY C BRUCES REEL', 1, 32, 9999, 1, 3, 42, 9998, '1801-01-01', '<<scddb-not-identical:3594>>



The description in the 2007 edition of <<ddpub:Miss Milligan''s Miscellany of Scottish Country Dances>> states:



> In the first edition of The Miscellanies, this dance is a reel. In the second edition the dance is given

> as a jig. However, it has continued to be danced as a reel and, accordingly, this edition reflects

> that practice.', 56, '800/888/888/880', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (3607, '1998-09-30 22:00:00+00', '2016-11-15 15:53:22.35134+00', 'Lady Glasgow', 'LADY GLASGOW', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 62, '888  888  800  888', 0, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (10089, '2002-01-08 23:00:00+00', '2017-02-13 17:27:06.416763+00', 'Lady Hamilton''s Strathspey', 'LADY HAMILTONS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 108, '2000-01-01', '', 79, '888  848  888  008', 1, 1, 0, 0, 79);
INSERT INTO 'dance' VALUES (3588, '1998-09-29 22:00:00+00', '2017-07-07 14:00:48.175405+00', 'Lady Auckland''s Reel', 'LADY AUCKLANDS REEL', 3, 32, 9999, 1, 2, NULL, 263, '1794-01-01', '', 47, '55  55  80  88', 1, 1, 1, 0, 68);
INSERT INTO 'dance' VALUES (3621, '1997-09-07 22:00:00+00', '2018-04-03 00:07:58.363983+00', 'Lady Mary Douglas', 'LADY MARY DOUGLAS', 2, 48, 9999, 1, 3, 42, 432, NULL, '', 44, '888  888  800  800  822  800', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (3695, '1998-09-29 22:00:00+00', '2018-04-04 21:22:50.180708+00', 'Lanes of Au, The', 'LANES OF AU', 1, 32, 9999, 2, 3, 17, 491, '1982-01-01', '', 71, '686  484  484  862', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (13850, '2011-08-21 22:00:00+00', '2014-04-30 23:23:58.298664+00', 'Lagan Bridges, The', 'LAGAN BRIDGES', 2, 48, NULL, 1, 4, 1, 10389, NULL, '', 92, '8888  8080  8888  8888  8888  8888', 0, 1, 1, 0, 91);
INSERT INTO 'dance' VALUES (8571, '2000-09-05 22:00:00+00', '2014-04-30 23:23:58.313798+00', 'Laird of Atherton, The', 'LAIRD OF ATHERTON', 3, 32, 9999, 2, 3, 17, 952, '1987-01-01', '', 52, '800  866  844  868', 1, 1, 1, 0, 68);
INSERT INTO 'dance' VALUES (360, '1997-08-24 22:00:00+00', '2018-04-02 23:56:32.919978+00', 'Balgownie Brig', 'BALGOWNIE BRIG', 3, 32, 9999, 1, 3, 42, 108, '1981-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18655, '2018-09-19 23:31:17.025484+00', '2019-02-23 18:47:19.9745+00', 'Musician''s Wedding, The', 'MUSICIANS WEDDING', 3, 32, NULL, 1, 4, 1, 11035, NULL, '', 53, '8440/8440/8880/8022', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9818, '2001-04-22 22:00:00+00', '2019-02-21 21:59:07.149802+00', 'Langstane Kirk Jig, The', 'LANGSTANE KIRK JIG', 2, 32, 9999, 1, 4, 1, 2855, NULL, '', 44, '8000  8888  8000  8444', 0, 1, 0, 0, 53);
INSERT INTO 'dance' VALUES (3635, '1998-11-14 23:00:00+00', '2019-03-15 10:20:13.394498+00', 'Lady Sophia Anne Of Bute', 'LADY SOPHIA ANNE OF BUTE', 1, 48, 9999, 1, 4, 1, 476, NULL, '', 86, '8000  8888  8002  8220  8800  8888', 1, 1, 1, 1, 57);
INSERT INTO 'dance' VALUES (3463, '2001-06-13 22:00:00+00', '2022-08-18 21:10:15.516728+00', 'Kilkenny Castle', 'KILKENNY CASTLE', 3, 32, 9999, 1, 3, 42, 127, NULL, '', 59, '822/888/888/844', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (3594, '1998-09-29 22:00:00+00', '2023-02-20 13:42:06.542039+00', 'Lady Catherine Bruce''s Reel', 'LADY CATHERINE BRUCES REEL', 2, 32, 9999, 1, 2, NULL, 9998, NULL, '<<scddb:not-identical:3593>>



Not identical to Lady C Bruce''s Reel', 52, '80/88/80/88', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (3725, '1998-11-14 23:00:00+00', '2014-04-30 23:23:58.725959+00', 'Lassie Come And Dance With Me', 'LASSIE COME AND DANCE WITH ME', 2, 32, 9999, 1, 3, 42, 1, NULL, '', 53, '800  888  844  866', 0, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (3685, '1998-09-29 22:00:00+00', '2015-10-30 11:53:44.427286+00', 'Land o'' Cakes', 'LAND O CAKES', 3, 32, 9999, 1, 3, 42, 485, '1793-01-01', '', 55, '800  868  888  880', 0, 1, 1, 0, 72);
INSERT INTO 'dance' VALUES (18654, '2018-09-19 14:03:01.249226+00', '2020-11-19 19:25:31.316473+00', 'Margaret Ewart''s Reel', 'MARGARET EWARTS REEL', 1, 40, NULL, 1, 3, 42, 11717, NULL, '', 60, '880/888/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3570, '1999-08-09 22:00:00+00', '2020-12-08 22:26:37.571291+00', 'Laddies o'' Dunse, The', 'LADDIES O DUNSE', 2, 48, 9999, 1, 3, 42, 9998, NULL, '', 44, '800  080  880  880  844  866', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (3700, '1998-04-12 22:00:00+00', '2021-09-18 21:13:08.768037+00', 'Langholm Fair', 'LANGHOLM FAIR', 3, 32, 9999, 2, 3, 17, 13, NULL, 'This dance depicts a fair, where boys meet girls, celebrate "handfasting" (1-year trial marriage) and then marry.  There was a handfasting fair in Langholm, 16th-18th centuries..', 70, '555  888  666  820', 0, 1, 1, 0, 69);
INSERT INTO 'dance' VALUES (3625, '2001-04-03 22:00:00+00', '2020-12-08 22:48:39.606844+00', 'Lady Maxwell''s Reel', 'LADY MAXWELLS REEL', 4, 32, 1, 1, 3, 42, 9998, NULL, '', 56, '880  808  880  888', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (3710, '1998-11-14 23:00:00+00', '2020-12-08 22:59:03.226669+00', 'Largo Bay', 'LARGO BAY', 3, 48, 9999, 1, 107, 30, 108, '1987-01-01', '', 83, '8888  8888  0880  8008  8888  8888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (3705, '1997-08-25 22:00:00+00', '2021-04-17 21:39:52.303289+00', 'Lantern of the North, The', 'LANTERN OF THE NORTH', 2, 32, 9999, 1, 3, 42, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was written for a visit to Bavaria by Jennifer Hilson''s team from Elgin.', 69, '888/888/888/844', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (3728, '1997-09-07 22:00:00+00', '2021-05-15 19:23:58.830973+00', 'Lassie Wi'' The Lint White Locks', 'LASSIE WI THE LINT WHITE LOCKS', 3, 32, 9999, 1, 2, 76, 313, NULL, '', 60, '44  88  88  88', 1, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (3723, '1998-09-30 22:00:00+00', '2021-05-15 20:42:12.222219+00', 'Lass o'' Loudon', 'LASS O LOUDON', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 59, '888  888  862  822', 1, 1, 0, 1, 79);
INSERT INTO 'dance' VALUES (3722, '1998-09-29 22:00:00+00', '2021-05-16 08:51:10.01278+00', 'Lass o'' Livingston, The', 'LASS O LIVINGSTON', 1, 32, 9999, 1, 2, 76, 445, '1844-01-01', '', 52, '44  80  88  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (3623, '2001-04-03 22:00:00+00', '2021-05-17 22:48:46.106634+00', 'Lady Mary Menzies'' Reel', 'LADY MARY MENZIES REEL', 1, 32, 9999, 1, 3, 42, 339, '1749-01-01', '', 47, '880  822  822  866', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (3620, '1998-09-29 22:00:00+00', '2021-05-17 22:52:28.913553+00', 'Lady Mary Cochrane''s Reel', 'LADY MARY COCHRANES REEL', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'Note: In the original Book 26, 2nd couple stepped up on bars 15-16. This has been changed to align with the same 8 bar phrase in other dances.  

(source: the combined RSCDS Books 25-30)', 37, '840  800  822  880', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (3595, '1998-09-30 22:00:00+00', '2021-05-17 23:02:36.356226+00', 'Lady Charlotte Bruce', 'LADY CHARLOTTE BRUCE', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 62, '888  888  800  888', 1, 1, 0, 1, 83);
INSERT INTO 'dance' VALUES (3569, '1997-09-07 22:00:00+00', '2021-05-18 11:25:59.967413+00', 'Lad''s Awa'', The', 'LADS AWA', 1, 40, 9999, 1, 3, 42, 128, '1973-01-01', '', 60, '888  888  800  888  844', 1, 1, 0, 1, 80);
INSERT INTO 'dance' VALUES (3584, '1997-09-07 22:00:00+00', '2021-06-16 13:50:44.206517+00', 'Lads Of Leith, The', 'LADS OF LEITH', 2, 32, 9999, 1, 3, 42, 976, '1740-01-01', 'Described as for a 4 (or 5) couple set.', 50, '800  844  888  844', 1, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (7751, '1997-09-04 22:00:00+00', '2018-03-20 09:58:25.185035+00', 'In the Eyes of Hitomi', 'IN THE EYES OF HITOMI', 3, 32, 9999, 2, 3, 17, 827, '1990-01-01', 'Devised by Tom Toriyama, October 1990 and revised March 1991.  

For Mrs. Hitomi Sato, attained her Teacher’s Certificate.', 79, '888/880/228/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3637, '1999-11-01 23:00:00+00', '2018-04-03 00:07:58.480787+00', 'Lady Susan Stewart''s Reel', 'LADY SUSAN STEWARTS REEL', 1, 32, 9999, 1, 3, 42, 9998, '1754-01-01', '', 31, '800  822  822  800', 1, 1, 1, 1, 41);
INSERT INTO 'dance' VALUES (7441, '1998-04-24 22:00:00+00', '2018-04-03 00:07:58.514103+00', 'Lady Wynd, The', 'LADY WYND', 2, 32, 9999, 1, 3, 42, 146, NULL, '', 56, '844  888  800  888', 0, 0, 0, 0, 75);
INSERT INTO 'dance' VALUES (13588, '2010-08-08 22:00:00+00', '2019-08-29 18:43:44.941582+00', 'Links with St Petersburg', 'LINKS WITH ST PETERSBURG', 2, 32, NULL, 1, 3, 42, 635, '2009-01-01', '', 47, '880  880  844  822', 0, 1, 1, 0, 62);
INSERT INTO 'dance' VALUES (7775, '1997-12-28 23:00:00+00', '2018-03-20 17:43:17.984279+00', 'Junko and her Fellows', 'JUNKO AND HER FELLOWS', 3, 32, 9999, 1, 3, 42, 827, '1990-10-01', 'Devised by Tom Toriyama, October 1990, and inscribed to Mrs. Junko Matsuhashi, a keen teacher of the Tokyo Branch and the Urawa S.C.D. Group since 1970’s.', 63, '404/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3803, '1997-09-17 22:00:00+00', '2019-02-23 00:45:58.443074+00', 'Light on the Water', 'LIGHT ON THE WATER', 3, 32, 9999, 1, 3, 42, 954, '1988-01-01', '', 50, '800  888  800  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (18663, '2018-09-24 23:10:56.874498+00', '2019-03-03 09:45:47.020862+00', 'Estate Revisited, The', 'ESTATE REVISITED', 3, 32, NULL, 1, 3, 42, 1445, NULL, 'Dedicated to the memory of our friend John Sturrock. We visited him and his wife Sheena in the summer of 2017.    

Music: John M. Sturrock of Nether Rumgally.  ', 58, '811/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3789, '1998-10-16 22:00:00+00', '2019-03-15 09:48:58.12256+00', 'Letham Ladies', 'LETHAM LADIES', 3, 40, 9999, 1, 4, 1, 1071, NULL, '', 70, '8888  8888  8888  8000  8000', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (8357, '2002-06-02 22:00:00+00', '2014-04-30 23:23:59.47986+00', 'Loanhead of Daviot', 'LOANHEAD OF DAVIOT', 3, 32, 9999, 1, 4, 1, 108, '1996-01-01', '', 84, '6666  8888  6666  8488', 1, 1, 1, 0, 84);
INSERT INTO 'dance' VALUES (7681, '1997-12-28 23:00:00+00', '2018-03-20 20:12:42.476022+00', 'Dix Juillet, Le', 'DIX JUILLET', 3, 32, 9999, 1, 4, 2, 827, '1991-04-01', 'Devised by Tom Toriyama, April 1991, for Mrs. Taeko Tamura.  

(The 10th of July is her birthday).', 75, '8888/8008/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13081, '2006-11-10 23:00:00+00', '2014-11-05 14:04:28.426927+00', 'Lauraine''s Delight', 'LAURAINES DELIGHT', 1, 48, 9999, 2, 3, 18, 884, '1999-01-01', '', 78, '484  888  484  484  448  888', 0, 1, 1, 0, 77);
INSERT INTO 'dance' VALUES (7686, '1997-12-28 23:00:00+00', '2018-03-21 08:32:24.566978+00', 'Drive the Hot Summer Away', 'DRIVE THE HOT SUMMER AWAY', 1, 32, 9999, 1, 3, 42, 843, '1991-07-01', '', 63, '884/822/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14399, '2012-01-12 23:00:00+00', '2015-04-03 18:03:02.932236+00', 'Poisson d''Avril, Le', 'POISSON DAVRIL', 4, 64, 5, 1, 3, 42, 10599, '2011-01-01', 'Devised for a weekend in Retie, 1-3 April 2011.  The Tournee in reeltime is an innovation.', 56, '880  880  888  880', 0, 0, 0, 0, 75);
INSERT INTO 'dance' VALUES (3802, '1999-10-27 22:00:00+00', '2018-04-03 00:07:59.49835+00', 'Light and Airy', 'LIGHT AND AIRY', 2, 32, 9999, 1, 3, 42, 263, '1790-01-01', '', 34, '800  800  880  822', 1, 1, 1, 1, 45);
INSERT INTO 'dance' VALUES (3915, '1998-09-30 22:00:00+00', '2016-06-15 10:16:42.584913+00', 'Long Live the Queen', 'LONG LIVE THE QUEEN', 1, 32, 9999, 1, 4, NULL, 9998, NULL, '', 88, '8888  8888  8888  8800', 0, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (13273, '2007-04-01 22:00:00+00', '2017-02-06 11:51:05.732822+00', 'Long Frank''s Reel', 'LONG FRANKS REEL', 1, 32, 9999, 1, 3, 42, 316, '2005-01-01', '', 53, '888  862  840  880', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (9816, '2001-10-22 22:00:00+00', '2017-02-14 15:40:13.698092+00', 'Lochindorb Strathspey', 'LOCHINDORB STRATHSPEY', 3, 32, 9999, 2, 3, 17, 2853, NULL, '', 75, '808  080  888  888', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (3732, '1997-11-25 23:00:00+00', '2020-08-06 15:34:40.247444+00', 'Lassies And Laddies', 'LASSIES AND LADDIES', 4, 32, 1, 1, 4, 2, 82, NULL, '', 53, '4444  4444  5445  5445', 0, 1, 0, 0, 53);
INSERT INTO 'dance' VALUES (3857, '1997-09-05 22:00:00+00', '2020-12-08 23:07:15.047766+00', 'Loch Doon Castle', 'LOCH DOON CASTLE', 3, 32, 9999, 3, 5, 7, 129, '1966-01-01', '', 80, '80800/88888/86882/88888', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (3885, '1998-07-08 22:00:00+00', '2020-12-08 23:10:30.394694+00', 'Lochearnside', 'LOCHEARNSIDE', 3, 32, 9999, 1, 4, 2, 108, '1990-03-01', '', 81, '6666  8888  8888  8008', 1, 1, 0, 1, 81);
INSERT INTO 'dance' VALUES (3608, '1998-02-12 23:00:00+00', '2022-08-20 18:21:02.882674+00', 'Lady Harriet Hope''s Reel', 'LADY HARRIET HOPES REEL', 1, 32, 9999, 1, 3, 42, 432, '1816-01-01', '', 55, '888  880  820  866', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (3888, '1998-09-29 22:00:00+00', '2022-12-10 12:48:48.186999+00', 'Lochiel''s Rant', 'LOCHIELS RANT', 3, 32, 9999, 1, 3, 42, 453, '1754-01-01', '', 28, '620  620  800  822', 1, 1, 0, 0, 37);
INSERT INTO 'dance' VALUES (3684, '1997-04-03 22:00:00+00', '2022-11-27 21:06:47.763017+00', 'Lancastrian Wanderer, The', 'LANCASTRIAN WANDERER', 2, 32, 9999, 1, 3, 42, 21, NULL, '', 50, '880  822  822  888', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (11438, '2003-09-16 22:00:00+00', '2022-12-10 23:18:43.64118+00', 'Left-Handed Fiddler, The', 'LEFTHANDED FIDDLER', 1, 32, 9999, 1, 3, 42, 3374, '1997-01-01', '', 44, '800/822/822/888', 0, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (7793, '1998-10-20 22:00:00+00', '2020-09-05 10:10:39.976932+00', 'Lang Frae Glasgow', 'LANG FRAE GLASGOW', 100, 32, 9999, 1, 3, 42, 1061, '1992-01-01', '', 50, '800  884  844  866', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (8131, '1997-10-26 23:00:00+00', '2020-09-06 10:05:29.785992+00', 'Lady Sophia Amelia Elphinstone', 'LADY SOPHIA AMELIA ELPHINSTONE', 3, 32, 9999, 1, 3, 42, 1445, '1995-01-01', '', 50, '800  844  844  888', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (13130, '2006-12-05 23:00:00+00', '2020-09-16 22:08:20.209534+00', 'Little Leigh', 'LITTLE LEIGH', 1, 32, 9999, 1, 3, 42, 104, NULL, '', 50, '800  844  844  888', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (3748, '1998-11-14 23:00:00+00', '2020-10-05 17:30:22.323225+00', 'Lauderdale Lads', 'LAUDERDALE LADS', 1, 32, 9999, 1, 2, 76, 116, NULL, '', 60, '62  88  88  88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (3912, '1998-09-29 22:00:00+00', '2020-09-19 10:03:34.377945+00', 'Long Chase, The', 'LONG CHASE', 1, 64, 9999, 1, 4, NULL, 9998, '1805-01-01', '', 64, 'no bar count made', 0, 1, 0, 0, 64);
INSERT INTO 'dance' VALUES (3798, '1998-01-05 23:00:00+00', '2020-12-08 23:01:02.804056+00', 'Lieutenant Shortland''s Reel', 'LIEUTENANT SHORTLANDS REEL', 1, 40, 9999, 3, 5, 7, 742, NULL, '', 92, '84844  84884  88888  88888', 0, 1, 0, 0, 74);
INSERT INTO 'dance' VALUES (3901, '1997-09-08 22:00:00+00', '2020-12-08 23:11:41.20338+00', 'Lomondside', 'LOMONDSIDE', 3, 32, 9999, 2, 3, 18, 13, NULL, '', 75, '080  888  484  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (8730, '1998-07-12 22:00:00+00', '2020-12-19 15:22:16.564208+00', 'Lady Susan Montgomery', 'LADY SUSAN MONTGOMERY', 3, 40, 9999, 1, 3, 42, 2204, '1740-01-01', '', 41, '412  412  800  888  866', 1, 1, 1, 1, 55);
INSERT INTO 'dance' VALUES (3656, '1998-09-29 22:00:00+00', '2021-12-04 11:16:49.772289+00', 'Laird of Dumbiedykes'' Favourite, The', 'LAIRD OF DUMBIEDYKES FAVOURITE', 1, 40, 9999, 1, 3, 42, 9998, NULL, 'An alternative reconstruction of this dance was published in the Walter Scott Book by the RSCDS in 2021.  <<https://my.strathspey.org/dd/dance/20569/>>', 60, '880  888  888  880  880', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (3763, '1997-11-18 23:00:00+00', '2021-05-15 18:49:36.252911+00', 'Leap Year', 'LEAP YEAR', 2, 24, 9999, 1, 2, 76, 9998, NULL, '', 57, '88  80  88', 1, 1, 0, 1, 83);
INSERT INTO 'dance' VALUES (9667, '2000-09-18 22:00:00+00', '2021-02-21 11:18:30.995142+00', 'Lassie with the Red Ghillies, The', 'LASSIE WITH THE RED GHILLIES', 2, 32, 9999, 1, 3, 42, 1268, '1990-01-01', '', 59, '800  888  888  866', 0, 1, 0, 0, 79);
INSERT INTO 'dance' VALUES (3829, '1998-11-14 23:00:00+00', '2021-05-15 10:11:38.800158+00', 'Linkumdoddie', 'LINKUMDODDIE', 1, 48, 9999, 3, 5, 7, 108, '1967-01-01', '', 73, '80800  88888  88888  82842  88888  80800', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (3783, '2002-03-03 23:00:00+00', '2021-05-15 18:11:38.190224+00', 'Let the Hackles Rise', 'LET THE HACKLES RISE', 2, 48, 9999, 1, 4, 2, 108, '1977-01-01', '', 94, '8888  8448  8888  8668  8888  8888', 1, 1, 0, 1, 93);
INSERT INTO 'dance' VALUES (3769, '1999-08-09 22:00:00+00', '2021-05-15 18:41:35.608187+00', 'Legacy, The', 'LEGACY', 2, 32, 9999, 1, 3, 42, 9998, NULL, '<<scddb-not-identical:3770>>', 31, '444  444  800  800', 1, 1, 1, 1, 41);
INSERT INTO 'dance' VALUES (3691, '2002-03-11 23:00:00+00', '2021-05-16 17:35:12.043122+00', 'Land of the Prince Bishops', 'LAND OF THE PRINCE BISHOPS', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 64, '862  888  828  888', 0, 1, 0, 0, 85);
INSERT INTO 'dance' VALUES (3711, '1998-09-30 22:00:00+00', '2021-05-16 10:45:10.333285+00', 'Largo Law', 'LARGO LAW', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 44, '888  800  880  800', 1, 1, 0, 1, 58);
INSERT INTO 'dance' VALUES (3638, '1998-09-30 22:00:00+00', '2021-05-17 22:45:23.031364+00', 'Lady Susan Stewart''s Strathspey', 'LADY SUSAN STEWARTS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 41, '800  800  888  822', 1, 1, 0, 1, 54);
INSERT INTO 'dance' VALUES (9419, '2002-09-22 22:00:00+00', '2021-07-30 08:11:26.796991+00', 'London''s Burning', 'LONDONS BURNING', 2, 32, 9999, 1, 4, 8, 308, NULL, 'New couple starts after each 16 bars.', 65, 'no bar count made', 0, 1, 1, 0, 162);
INSERT INTO 'dance' VALUES (3891, '1998-01-05 23:00:00+00', '2018-04-03 00:08:00.190474+00', 'Lochnagar', 'LOCHNAGAR', 1, 32, 9999, 1, 3, 42, 175, '1991-01-01', '', 50, '800  844  844  888', 0, 0, 0, 0, 66);
INSERT INTO 'dance' VALUES (3862, '2001-03-11 23:00:00+00', '2017-07-07 14:20:28.411905+00', 'Loch Leven Castle', 'LOCH LEVEN CASTLE', 1, 32, 9999, 1, 2, NULL, 9998, NULL, '', 60, '80  88  88  88', 0, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (3759, '1998-09-29 22:00:00+00', '2017-07-07 14:21:16.585045+00', 'Lea Rig, The', 'LEA RIG', 3, 32, 9999, 1, 2, NULL, 9998, '1816-01-01', '', 58, '86 88 80 88', 0, 1, 1, 1, 84);
INSERT INTO 'dance' VALUES (13900, '2011-08-22 22:00:00+00', '2018-04-07 23:46:39.674076+00', 'Cosmos in the Highlands', 'COSMOS IN THE HIGHLANDS', 2, 32, NULL, 1, 3, 42, 64, '2006-04-01', 'Devised by Irene van Maarseveen, Pretoria, April 2006.



Dedicated to Wouter Joubert, for his friendship and his selfless and tireless contribution to Scottish country dancing in Pretoria. Devised while driving through the highlands of Mpumalanga, South Africa, when the fields were awash with cosmos in bloom.



The "faerie garden" on the opposite page is based on a mural I did for my daughter''s bedroom. The figures and some of the plant designs were borrowed from a selection of her favourite faerie story books. ', 53, '800/888/888/822', 0, 1, 1, 0, 62);
INSERT INTO 'dance' VALUES (3921, '2002-02-27 23:00:00+00', '2019-03-14 23:16:38.088065+00', 'Longwise Eightsome Reel', 'LONGWISE EIGHTSOME REEL', 4, 64, 5, 1, 4, 3, 9998, NULL, '', 100, '8888  8888  8888  8888    8888  8888  8888  8888', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (3935, '1998-07-08 22:00:00+00', '2014-04-30 23:23:59.855929+00', 'Lord Huntly''s Cave', 'LORD HUNTLYS CAVE', 1, 32, 9999, 1, 100, 2, 108, '1975-02-02', 'Drewry named this dance after the tune.', 59, '8008  8448  8228  8008', 0, 1, 1, 1, 59);
INSERT INTO 'dance' VALUES (127, '2007-04-01 22:00:00+00', '2019-03-20 00:13:31.933795+00', 'Lost Gardens, The', 'LOST GARDENS', 3, 32, 9999, 2, 3, 17, 316, NULL, '', 67, '844  822  888  822', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (7173, '2001-12-04 23:00:00+00', '2014-04-30 23:24:15.725662+00', 'Willie''s Rare and Willie''s Fair', 'WILLIES RARE AND WILLIES FAIR', 2, 48, 9999, 1, 3, 42, 9998, NULL, '', 50, '440  888  888  800  808  880', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (7179, '1997-04-03 22:00:00+00', '2014-04-30 23:24:15.757058+00', 'Wind In The Willows, The', 'WIND IN THE WILLOWS', 2, 32, 9999, 1, 2, NULL, 44, NULL, '', 60, '88  88  80  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (7811, '1998-04-24 22:00:00+00', '2015-02-12 23:35:42.632584+00', 'Lost in Edinburgh', 'LOST IN EDINBURGH', 2, 32, 9999, 1, 4, 1, 1083, NULL, '', 50, '8000  8080  8888  8000', 0, 1, 1, 0, 50);
INSERT INTO 'dance' VALUES (13726, '2011-07-09 22:00:00+00', '2016-07-15 22:45:43.81571+00', 'Looking for a Partner', 'LOOKING FOR A PARTNER', 2, 32, NULL, 5, 2, 4, 175, NULL, '', 75, '88  88  44  44', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (3934, '1998-09-29 22:00:00+00', '2020-05-28 19:00:40.436099+00', 'Lord Hume''s Reel', 'LORD HUMES REEL', 3, 40, 9999, 1, 3, 42, 432, '1816-01-01', '', 42, '840  800  880  844  880', 1, 1, 1, 0, 56);
INSERT INTO 'dance' VALUES (3774, '1998-09-29 22:00:00+00', '2021-05-15 18:37:42.851217+00', 'Leith Country Dance', 'LEITH COUNTRY DANCE', 2, 32, 9999, 1, 2, 76, 432, '1816-01-01', '', 50, '44  70  88  88', 1, 1, 0, 1, 73);
INSERT INTO 'dance' VALUES (9351, '2000-03-12 23:00:00+00', '2021-02-25 19:59:00.941084+00', 'Willow Tree, The', 'WILLOW TREE', 2, 48, 9999, 10, 8, NULL, 2702, '2000-01-01', '', 49, '6000002  20000006  16 2 2 2 2 2 2 16  88888888  88888888', 0, 1, 0, 0, 48);
INSERT INTO 'dance' VALUES (11001, '2002-11-23 23:00:00+00', '2020-09-13 22:20:53.09524+00', 'Longfield Reel', 'LONGFIELD REEL', 1, 32, 9999, 1, 3, 42, 3240, NULL, '', 50, '808  080  880  888', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (13901, '2011-08-22 22:00:00+00', '2020-10-13 19:55:14.059024+00', 'Dance Wizard, The', 'DANCE WIZARD', 2, 32, NULL, 1, 100, 2, 3179, '2003-01-01', 'Devised by Wouter Joubert, Pretoria, 2003, and dedicated to <<ddp:Boyd, Iain#44>>, a true dance Wizard.



The tune I devised "The Dance Wizard" to was "He''s o''er the hills that I lo''e weel" only to discover it has been used by the RSCDS before for "Berwick Johnnie". I therefore chose an altemative tune as name tune for "The Dance Wizard" but want to request that "He''s o''er the hills ..." be played as the 4th tune.



The figure in the 1st 8 bars I discovered in a dance called "<<ddd:Under a Shady Tree>>" by <<ddp:O''Connor, Noeline#788>> from the New Zealand collection "Silver Threads". Noeline happens to be lain Boyd''s wife. ', 88, '8008/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9387, '2002-04-25 22:00:00+00', '2020-12-23 10:20:20.260152+00', 'Latvian Lass, The', 'LATVIAN LASS', 4, 32, 1, 1, 3, 42, 2722, '1998-01-01', '', 56, '800  844  888  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (3818, '1998-01-05 23:00:00+00', '2020-12-08 23:05:18.292051+00', 'Lincoln Reel, The', 'LINCOLN REEL', 1, 32, 9999, 1, 3, 42, 109, NULL, '', 62, '800  888  888  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (8965, '2000-11-23 23:00:00+00', '2022-10-04 18:06:01.633109+00', 'Loopy Bonners, The', 'LOOPY BONNERS', 1, 32, 9999, 1, 3, 42, 531, '1999-01-01', '', 62, '800  888  888  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (3988, '1998-11-29 23:00:00+00', '2022-12-10 12:38:15.148469+00', 'Lucy of Lammermoor', 'LUCY OF LAMMERMOOR', 3, 48, 9999, 1, 4, 1, 129, NULL, '', 53, '8000/8800/0086/8008/0880/8888', 1, 1, 1, 1, 53);
INSERT INTO 'dance' VALUES (3730, '1998-09-29 22:00:00+00', '2022-12-10 19:36:54.270623+00', 'Lassie wi'' the Yellow Coatie', 'LASSIE WI THE YELLOW COATIE', 1, 32, 9999, 1, 3, 42, 453, '1756-01-01', '<<scddb-not-identical:3729>>', 31, '800  800  844  800', 1, 1, 1, 1, 41);
INSERT INTO 'dance' VALUES (9468, '2000-05-21 22:00:00+00', '2020-12-21 11:06:52.207039+00', 'MacKenzie Rant, The', 'MACKENZIE RANT', 3, 96, 9999, 4, 4, 3, 108, '1999-01-01', '', 83, '8484  8484  4848  4848    8484  8888  8888  8888    4444  4444  8888  8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9515, '2000-06-12 22:00:00+00', '2020-12-29 11:47:35.461374+00', 'Lonely Lassie, The', 'LONELY LASSIE', 2, 32, 9999, 1, 3, 42, 2772, '2000-01-01', '', 47, '840  844  844  880', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (10306, '2002-08-05 22:00:00+00', '2021-02-10 11:09:13.96916+00', 'Lochalsh Reel, The', 'LOCHALSH REEL', 1, 40, 9999, 1, 3, 42, 2985, NULL, 'The Pilling diagram in the 8th edition is in error, see the supplement to the 8th edition for the correct one.', 51, '800  808  888  820  888', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (9193, '2002-07-04 22:00:00+00', '2021-02-26 22:20:01.712661+00', 'Laura''s Jig', 'LAURAS JIG', 2, 32, 9999, 1, 3, 42, 854, NULL, '', 56, '800  888  844  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (3941, '2002-02-27 23:00:00+00', '2021-03-03 19:36:48.533034+00', 'Lord MacLay''s Reel', 'LORD MACLAYS REEL', 1, 40, 9999, 1, 4, 1, 1081, '1954-01-01', 'This dance originally appeared in a James S. Kerr leaflet entitled: The Boy’s Brigade, Glasgow Battalion, A Scottish Country Dance composed for B.B.Fanfare 1954 (<<https://my.strathspey.org/dd/issue/2325/|issue 2325>>)', 75, '8008  8888  8888  8888  8000', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (5160, '1998-11-25 23:00:00+00', '2021-04-25 18:11:52.746689+00', 'Papillon, Le', 'PAPILLON', 2, 32, 9999, 1, 3, 42, 455, '1788-02-01', '', 38, '804  840  800  880', 0, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (3932, '1998-09-29 22:00:00+00', '2021-05-13 16:05:59.138113+00', 'Lord Elgin''s Reel', 'LORD ELGINS REEL', 3, 32, 9999, 1, 3, 42, 9998, NULL, 'Note by ETF: on bars 17-20 and 21-24, it looks nicer if the corners make a 4-bar turn, letting go early, rather than a 2-bar turn.', 37, '440  800  844  844', 1, 1, 0, 1, 50);
INSERT INTO 'dance' VALUES (3931, '1998-09-30 22:00:00+00', '2021-05-13 16:09:16.135277+00', 'Lord Eglinton''s Reel', 'LORD EGLINTONS REEL', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'The lead tune is correct. Played in Reel time, of course.', 50, '800  800  888  888', 1, 1, 0, 1, 66);
INSERT INTO 'dance' VALUES (3923, '1998-01-05 23:00:00+00', '2021-05-13 20:14:47.442143+00', 'Loon Mountain Reel, The', 'LOON MOUNTAIN REEL', 1, 32, 9999, 1, 4, 1, 358, NULL, 'The notes say the dance was composed for Gov. Shennan Adams, host to the New Hampshire Gathering of the Scottish Clans at Loon Mountain.



The figures are intended to depict:  

1-8: Loon Pond  

9-16: Waves on the pond  

17-24: Loons flying  

25-32: Diving and surfacing again  

', 91, '8888  8888  8888  8444', 1, 1, 1, 1, 90);
INSERT INTO 'dance' VALUES (3940, '1998-11-11 23:00:00+00', '2018-04-03 00:08:00.515839+00', 'Lord Macdonald''s Reel', 'LORD MACDONALDS REEL', 1, 32, 9999, 1, 3, 42, 263, '1790-01-01', '', 41, '800  800  844  866', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (13907, '2011-08-22 22:00:00+00', '2018-04-08 00:20:52.684162+00', 'Farquharson Fifty', 'FARQUHARSON FIFTY', 2, 32, NULL, 2, 3, 17, 64, '2006-07-17', 'Devised by Irene van Maarseveen, for the 50th birthday of Ingrid le Roux, descendant o

the Farquharson clan, 17 July 2006.



In a simplified ve . on of Farquharson Fifty, named The Celebration, only 1st couple lead

down the middle and up again in bars 1-8.', 83, '888/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4008, '1998-04-12 22:00:00+00', '2014-04-30 23:24:00.263876+00', 'MacPherson''s Jig', 'MACPHERSONS JIG', 2, 32, 9999, 6, 3, 17, 31, NULL, '', 75, '844  888  844  844', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (18266, '2018-03-23 22:19:27.517744+00', '2018-05-20 09:42:51.718273+00', 'Dancing in the Highlands', 'DANCING IN THE HIGHLANDS', 1, 32, NULL, 1, 3, 42, 44, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17457, '2016-10-30 12:24:54.52275+00', '2018-09-05 02:42:34.224423+00', 'Portwilliam Lass', 'PORTWILLIAM LASS', 1, 32, NULL, 1, 3, 42, 433, NULL, 'In the oroginal publication, this dance is called "Portwilliam Lass" on the dance page, and "Port William Lass" in the index.  



Dedicated to Rosemary Smith (nee Kinnear) – the “Portwilliam Lass”, who did splendid work in Scottish Country Dancing in the area and at Douglas Ewart High School, Newton Stewart.', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14280, '2011-10-15 22:00:00+00', '2014-04-30 23:24:00.537454+00', 'Mammoth Hunter''s Reel, The', 'MAMMOTH HUNTERS REEL', 1, 32, NULL, 1, 3, 42, 1445, NULL, 'For Fumitaka Saito, who built a tiny flute from the tusk of a giant Mammoth.', 45, '800  440  441  888  800', 0, 1, 1, 1, 59);
INSERT INTO 'dance' VALUES (10316, '2002-04-08 22:00:00+00', '2014-04-30 23:24:00.603809+00', 'Maple Leaf Rant', 'MAPLE LEAF RANT', 1, 40, 9999, 1, 3, 42, 9998, NULL, '(from the original leaflet: This dance was collected in Carnoustie, Scotland, by Betty Grant.  It was written out by a local dancer on a paper towel from the men’s washroom at the Beach Ballroom.  The dance was said to  have been brought to Glasgow by a Canadian visitor in 1952 – ’53.  To date the author is unknown.', 55, '800  844  888  844  888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (12309, '2005-04-25 22:00:00+00', '2014-04-30 23:24:00.618969+00', 'March Hare, The', 'MARCH HARE', 1, 32, 9999, 2, 3, 17, 29, NULL, '', 62, '822  822  866  844', 0, 1, 1, 0, 62);
INSERT INTO 'dance' VALUES (7182, '2000-03-06 23:00:00+00', '2015-01-11 23:27:41.030976+00', 'Wind that Shakes the Barley, The', 'WIND THAT SHAKES THE BARLEY', 1, 32, 9999, 1, 3, 42, 116, '1961-01-01', '', 53, '800  888  822  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (4046, '2000-09-20 22:00:00+00', '2015-03-25 10:58:27.300798+00', 'Macleod''s Fancy', 'MACLEODS FANCY', 2, 32, 9999, 1, 4, 2, 108, '1985-01-01', '', 75, '8008  8888  8888  8008', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (12254, '2005-04-24 22:00:00+00', '2018-03-26 07:29:42.436813+00', 'Gentle Breeze', 'GENTLE BREEZE', 3, 32, 9999, 1, 2, 76, 843, '2001-03-01', 'For the 25th Anniversary of Urawa Scottish Country Dance Group.  

This movement ("BtoB, back to next place cclw") is named “Chevron” by the devisor of the movement. Fried de Metz Herman of the USA. She has devised many interesting dances in English Country Dances field.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12278, '2005-04-25 22:00:00+00', '2018-01-23 23:44:56.989973+00', 'Maple Dancing', 'MAPLE DANCING', 1, 32, 9999, 1, 2, NULL, 550, '2005-01-01', 'The original online instructions were not clear, the author confirmed by e-mail that [17-24] (except for the initial cast) follows the pattern of a Men''s Chain.', 69, '88  88  88  88', 0, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (17342, '2016-09-14 12:59:14.136436+00', '2018-03-27 15:21:37.765262+00', 'Stella''s in a Fogg', 'STELLAS IN A FOGG', 3, 32, NULL, 1, 3, 42, 11358, '2006-04-01', 'This dance is dedicated to Stella Fogg, whose love of Scottish Country Dance and lively spirit have been instrumental in the vitality of the Richmond SCD group for more than twenty-five years. Though I''ve never seen Stella in a fog, I couldn''t resist the play on words. The first night we tried the dance in class, I jokingly gave this title to it with every intention of changing to a more dignified name when I finished with revisions.  Stella, with her typical sense of humor, insisted the title was a good one.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18265, '2018-03-23 22:12:56.130536+00', '2018-04-02 23:56:34.475058+00', 'Favourite of Kazue, A', 'FAVOURITE OF KAZUE', 1, 32, NULL, 1, 3, 42, 11612, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4103, '1998-09-29 22:00:00+00', '2020-05-17 20:07:04.137851+00', 'Mairrit Man''s Favourite, The', 'MAIRRIT MANS FAVOURITE', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 60, '88  80  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (8118, '1997-10-26 23:00:00+00', '2020-09-06 09:45:44.910308+00', 'Man from Pennsylvania, The', 'MAN FROM PENNSYLVANIA', 3, 32, 9999, 1, 3, 42, 1445, '1996-01-01', '', 66, '822/888/888/888', 0, 1, 0, 0, 85);
INSERT INTO 'dance' VALUES (4073, '1997-04-03 22:00:00+00', '2020-12-10 00:08:49.589828+00', 'Magic Airt o'' Gow, The', 'MAGIC AIRT O GOW', 3, 32, 9999, 1, 2, 76, 108, '1967-01-01', '', 69, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (7570, '2002-04-03 22:00:00+00', '2020-12-18 20:52:39.790949+00', 'MacPhail''s Magic', 'MACPHAILS MAGIC', 1, 32, 9999, 1, 3, 42, 104, '1993-01-01', '', 56, '880  880  808  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (12953, '2006-10-25 22:00:00+00', '2020-12-25 15:34:10.830632+00', 'Lost in the Mist', 'LOST IN THE MIST', 3, 32, 9999, 1, 3, 42, 3718, '2004-01-01', '', 44, '800  844  888  800', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (7188, '1998-11-14 23:00:00+00', '2021-03-29 11:28:04.13584+00', 'Winding Nith, The', 'WINDING NITH', 3, 40, 9999, 1, 4, 1, 200, NULL, '', 77, '8000  8888  8888  8888  8444', 0, 0, 0, 0, 77);
INSERT INTO 'dance' VALUES (2387, '2000-04-09 22:00:00+00', '2021-03-13 15:53:11.660815+00', 'Maine Medley, The', 'MAINE MEDLEY', 4, 32, 1, 1, 2, 76, 2716, '1997-01-01', '', 60, '88  88  66  66', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (17864, '2017-06-23 09:04:14.252367+00', '2017-06-23 09:04:14.252367+00', 'Ashe''s, The', 'ASHES', 3, 32, NULL, 2, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10776, '2002-09-25 22:00:00+00', '2021-03-27 21:56:28.54154+00', 'Windmills', 'WINDMILLS', 3, 32, 9999, 1, 3, 42, 175, NULL, '"The more energetic dancer may wish to dance this as a reel.  It then becomes <<ddd:The Whirlwind#13729>>."

', 50, '844  844  844  844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (7189, '1998-11-16 23:00:00+00', '2021-03-29 10:00:48.422846+00', 'Winding Road, The', 'WINDING ROAD', 3, 32, 9999, 1, 4, 1, 87, NULL, '', 59, '4444  4444  8008  8488', 1, 1, 1, 1, 59);
INSERT INTO 'dance' VALUES (4068, '2001-09-13 22:00:00+00', '2021-05-11 10:59:48.289582+00', 'Maggie Lauder', 'MAGGIE LAUDER', 3, 32, 9999, 1, 2, 76, 432, '1816-01-01', '', 60, '88  88  80  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (4051, '1998-11-07 23:00:00+00', '2021-05-12 17:39:22.45681+00', 'Macphersons Of Edinburgh Strathspey', 'MACPHERSONS OF EDINBURGH STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1094, NULL, '', 41, '800  811  811  888', 1, 1, 0, 0, 54);
INSERT INTO 'dance' VALUES (4019, '1997-09-08 22:00:00+00', '2021-05-12 17:58:48.52594+00', 'Macdonald''s Rant', 'MACDONALDS RANT', 3, 32, 9999, 1, 3, 42, 976, '1740-01-01', '', 59, '844  884  866  866', 1, 1, 0, 1, 79);
INSERT INTO 'dance' VALUES (3963, '1998-11-14 23:00:00+00', '2021-05-13 10:18:32.873337+00', 'Lothian Lads', 'LOTHIAN LADS', 1, 32, 9999, 1, 3, 42, 108, '1979-01-01', 'Drewry writes that this dance is for Mary Prentice of Stirling and that it was first performed in Palma Nova, Mallorca on Friday 9th February 1979.', 47, '800  822  844  888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (3957, '1998-04-12 22:00:00+00', '2021-05-13 15:56:15.093885+00', 'Lords Of The Wind, The', 'LORDS OF THE WIND', 1, 32, 9999, 1, 3, 42, 44, '1991-01-01', '', 61, '420  888  888  888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (3938, '1998-09-29 22:00:00+00', '2021-05-13 16:01:22.550367+00', 'Lord Kilmory''s Delight', 'LORD KILMORYS DELIGHT', 1, 32, 9999, 1, 3, 42, 9998, '1710-01-01', '', 31, '800  080  880  440', 1, 1, 0, 1, 41);
INSERT INTO 'dance' VALUES (4086, '1998-09-29 22:00:00+00', '2018-04-03 00:08:01.574962+00', 'Maid of the Mill, The', 'MAID OF THE MILL', 2, 40, 9999, 1, 3, 42, 9998, NULL, '', 47, '800  888  822  844  844', 0, 1, 1, 0, 63);
INSERT INTO 'dance' VALUES (13868, '2011-08-22 22:00:00+00', '2018-04-09 20:52:19.30588+00', 'Manchester Busy Bees', 'MANCHESTER BUSY BEES', 2, 32, NULL, 1, 3, 42, 10397, NULL, 'Written to commemorate the 75th Anniversary of the RSCDS Manchester Branch, in 2009.  The imagery is taken from the combination of the Busy Bee symbol of Manchester, and the cotton industry which made Manchester the busy city it is today.



Bars 1-8 illustrate the box of the weaving machine.



Bars 9-16 have the imagery of bees in the hive, and the pattern of the bees wings.



Bars 17-28 show the imagery of the conveyer belts used in the cotton industry



Bars 29-32 illustrate the actually weaving of the cloth.

', 48, '860/844/808/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4233, '1997-09-08 22:00:00+00', '2014-04-30 23:24:00.860934+00', 'Maureen and Paddy', 'MAUREEN AND PADDY', 1, 32, 9999, 1, 3, 42, 211, '1979-01-01', 'For Maureen and Paddy Chevens', 56, '822  822  888  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14346, '2011-12-12 23:00:00+00', '2019-02-26 17:24:20.478729+00', 'Mentor, The', 'MENTOR', 3, 96, NULL, 4, 4, 3, 74, '2007-10-01', 'Devised by Brian Charlton (briangcharlton [at] gmail.com), October, 2007. This dance was written to honour Margaret Sim on the occasion of her being presented with a well-deserved RSCDS Branch Award at the Branch Closing Social on 8th December 2007. Margaret has been a mentor for dancers, teachers, clubs and the Branch over many years.



The formations (many!) still need to be added.



Music: suitable recorded music is "Singing Sands" on Reflections of Dalriada.', 79, '4444  8888  6666  8888    4444  8888  6666  8888    8888  8080  0808  8888', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (4190, '1997-09-08 22:00:00+00', '2019-03-15 01:07:00.456132+00', 'Marquess Of Hartington''s Strathspey, The', 'MARQUESS OF HARTINGTONS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 1103, NULL, '', 66, '8008/0880/8888/8444', 0, 1, 1, 0, 65);
INSERT INTO 'dance' VALUES (14976, '2013-07-03 22:23:55.416026+00', '2014-04-30 23:24:01.075625+00', 'Memories of Mary Ann', 'MEMORIES OF MARY ANN', 3, 32, NULL, 2, 3, 17, 3703, NULL, '', 50, '844  844  844  808', 0, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (10795, '2002-08-25 22:00:00+00', '2014-04-30 23:24:01.167278+00', 'Mercia', 'MERCIA', 1, 32, 9999, 1, 3, 42, 3190, '2001-01-01', '', 50, '800  888  844  844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (4165, '1998-04-12 22:00:00+00', '2019-04-20 10:41:29.436227+00', 'Margot''s Love', 'MARGOTS LOVE', 2, 32, 9999, 1, 3, 42, 348, '1990-01-01', 'Dedicated to the memory of Mark de Lemos.', 53, '800  888  822  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (14964, '2013-07-03 18:43:57.580825+00', '2016-03-04 21:24:03.778101+00', 'Merchant City, The', 'MERCHANT CITY', 3, 32, NULL, 2, 3, 17, 3183, NULL, '', 83, '880  888  808  888', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (4180, '1998-04-12 22:00:00+00', '2017-04-22 15:30:12.359533+00', 'Marjolijn''s Jig', 'MARJOLIJNS JIG', 2, 32, 9999, 1, 3, 42, 227, '1987-01-01', 'For Marjolijn''s beginners class September 1987', 44, '440/800/844/888', 0, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (7457, '1998-04-29 22:00:00+00', '2017-04-03 12:27:51.515362+00', 'Mathematicians, The', 'MATHEMATICIANS', 1, 80, 9999, 1, 4, 8, 154, NULL, 'Canon. Each 40 bars a new couple starts, and dances 80 bars.  Requires 5 x 40 music.', 70, 'no bar count made', 1, 1, 1, 0, 175);
INSERT INTO 'dance' VALUES (4236, '1997-04-03 22:00:00+00', '2018-04-03 00:08:02.717384+00', 'Maureen''s Reel', 'MAUREENS REEL', 1, 32, 9999, 1, 3, 42, 175, NULL, '', 53, '800  844  866  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (15333, '2014-02-06 14:34:59.811708+00', '2018-08-12 14:24:10.268393+00', 'Miss Ella Catherine Hughes', 'MISS ELLA CATHERINE HUGHES', 1, 32, NULL, 1, 3, 42, 10640, '2008-06-10', 'Dedicated to the real Miss Ella Catherine Hughes, born June 10th 2008 to Adam & Ruth', 56, '822  866  866  866', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (18267, '2018-04-01 14:42:53.881075+00', '2018-04-01 14:42:53.881075+00', 'Shades of Gray', 'SHADES OF GRAY', 3, 32, NULL, 1, 100, 2, 316, NULL, 'Devised for Alex Gray''s 60th birthday.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18268, '2018-04-01 14:53:25.768964+00', '2018-04-01 14:53:25.768964+00', 'Farewell to Whisky', 'FAREWELL TO WHISKY', 3, 32, NULL, 2, 3, 4, 11534, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10789, '2002-08-25 22:00:00+00', '2020-02-12 09:31:08.532819+00', 'May Yarker''s Strathspey', 'MAY YARKERS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 146, '1995-01-01', 'Dedicated to May Yarker, awarded the RSCDS Scroll in 1995', 52, '806  844  804  888', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (4144, '1998-11-10 23:00:00+00', '2020-05-24 17:29:30.166299+00', 'Marchioness of Blandford''s Reel, The', 'MARCHIONESS OF BLANDFORDS REEL', 2, 48, 9999, 1, 2, 76, 263, '1794-01-01', '', 63, '88  80  88  88  88  88', 0, 1, 0, 0, 91);
INSERT INTO 'dance' VALUES (9724, '2000-11-17 23:00:00+00', '2021-02-21 10:49:40.605572+00', 'Marmalade Maker, The', 'MARMALADE MAKER', 3, 32, 9999, 4, 4, 1, 2815, '1997-01-01', '', 94, '8888  8888  8888  8484', 1, 1, 1, 1, 110);
INSERT INTO 'dance' VALUES (4175, '2000-01-28 23:00:00+00', '2020-12-12 10:40:25.226332+00', 'Marigold', 'MARIGOLD', 2, 40, 9999, 1, 3, 42, 87, NULL, '', 42, '800  16 16 16  822', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (4223, '1997-04-03 22:00:00+00', '2020-12-12 10:42:26.102171+00', 'Maryland Strathspey, The', 'MARYLAND STRATHSPEY', 3, 32, 9999, 5, 2, NULL, 200, NULL, '', 100, '88  88  88  88', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (4312, '1998-07-09 22:00:00+00', '2020-12-12 10:46:14.857191+00', 'Mercat Cross, The', 'MERCAT CROSS', 3, 32, 9999, 2, 3, 17, 101, '1993-01-01', '', 79, '404  848  848  404  884', 0, 1, 0, 0, 79);
INSERT INTO 'dance' VALUES (14021, '2011-08-25 22:00:00+00', '2020-12-26 09:59:50.05394+00', 'Maitland to Manchester', 'MAITLAND TO MANCHESTER', 2, 32, NULL, 1, 3, 42, 390, NULL, '', 53, '840  844  888  844', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (4293, '1998-11-07 23:00:00+00', '2021-02-26 18:18:58.786051+00', 'Meg Merrilees', 'MEG MERRILEES', 1, 24, 9999, 1, 2, 76, 9998, '1827-01-01', 'A discussion of this dance can be found in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-032-May-1967.pdf#page=2|issue 32 of The Thistle magazine>>.', 57, '44  88  88', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (4300, '1998-04-12 22:00:00+00', '2021-05-08 21:26:26.228658+00', 'Melville Castle', 'MELVILLE CASTLE', 1, 32, 9999, 1, 2, 76, 154, NULL, '', 64, '88  88  88  84', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (4257, '1997-09-08 22:00:00+00', '2022-08-12 10:45:16.986641+00', 'McEwan''s Reel', 'MACEWANS REEL', 2, 32, 9999, 1, 3, 42, 175, NULL, '', 53, '844  480  888  880', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (11403, '2003-07-26 22:00:00+00', '2022-09-23 17:25:45.805786+00', 'Mellerstain Meeting', 'MELLERSTAIN MEETING', 3, 32, 9999, 1, 3, 42, 515, '2002-04-01', 'Note: In honour of JW''s parents. Original version May 1992, revised April 2002.', 56, '844  844  844  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (4230, '1998-04-12 22:00:00+00', '2022-12-03 12:10:13.076743+00', 'Master Of Earley, The', 'MASTER OF EARLEY', 2, 32, 9999, 1, 3, 42, 227, '1988-01-01', 'Intermediate level.



For Frank Reid to play on the occasion of the tenth visit of Frank Reid''s Band to the Thistle Club, Eindhoven, 5 November 1988', 56, '800  888  888  888', 1, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (4303, '1998-01-05 23:00:00+00', '2021-05-09 09:18:01.083259+00', 'Memory Lane', 'MEMORY LANE', 1, 32, 9999, 1, 3, 42, 488, '1988-10-01', '', 47, '822  822  822  888', 1, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (4262, '1997-04-03 22:00:00+00', '2021-05-09 10:28:53.83319+00', 'McGregor''s Leap', 'MACGREGORS LEAP', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 62, '888  800  888  888', 1, 1, 0, 1, 83);
INSERT INTO 'dance' VALUES (4227, '1999-08-09 22:00:00+00', '2021-05-09 11:26:54.841947+00', 'Mason''s Apron, The', 'MASONS APRON', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 41, '800  800  844  866', 0, 1, 0, 0, 54);
INSERT INTO 'dance' VALUES (4196, '1998-09-30 22:00:00+00', '2021-05-09 18:00:44.099328+00', 'Marquis of Lorne, The', 'MARQUIS OF LORNE', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 56, '880  888  888  800', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (4126, '1998-09-29 22:00:00+00', '2021-05-10 18:09:14.034187+00', 'Man''s a Man for a'' That, A', 'MANS A MAN FOR A THAT', 3, 32, 9999, 1, 3, 42, 432, '1816-01-01', '', 55, '880  820  822  888', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (4106, '1998-09-29 22:00:00+00', '2021-05-10 21:54:04.320937+00', 'Major Ian Stewart', 'MAJOR IAN STEWART', 2, 32, 9999, 1, 3, 42, 108, '1986-01-01', 'The notes to the dance say that Major John Charles Stewart of Fasnacloich, known as Ian, was the husband

of Ysobel Campbell, co-founder of the RSCDS. He served with the Scottish Horse.', 67, '880  888  833  888', 1, 1, 1, 1, 89);
INSERT INTO 'dance' VALUES (14241, '2011-08-28 22:00:00+00', '2018-03-31 18:53:21.191782+00', 'Kandahar Reel (RSCDS)', 'KANDAHAR REEL RSCDS', 1, 32, NULL, 3, 4, 52, 10306, '2009-09-30', 'This dance was recently invented by Capt. Andy Colquhoun and Lt. Rob

Colquhoun while in Afghanistan (hence the name). It follows in the

tradition of dances like <<ddd:The Reel of the 51st Division>> which were

created by soldiers with time on their hands. At least this time no

POW camp was involved.



The dance is superficially simple but requires great presence of mind,

good technique, and perfect teamwork if it is supposed to look

good. Legend claims that the one-and-a-half-times-round hands across

stand for both the big rotors of a Chinook helicopter and the fact

that soldiers are constantly exhorted to give 150% of what is expected

from them. The end involves a little cheating but, given the

situation, this probably ought to be forgiven.



Unusually for a dance involving four couples, the Kandahar Reel was

originally choreographed for a five-couple set, but that, too, follows

the »Reel of the 51st«. One could say with some justification that the

dancing couple have earned their little 32-bar break after their turn.

', 56, '84000  88320  84840  88880', 0, 1, 0, 0, 69);
INSERT INTO 'dance' VALUES (16525, '2015-07-31 14:06:07.921762+00', '2018-10-13 15:03:36.140264+00', 'First Rain of Spring, The', 'FIRST RAIN OF SPRING', 2, 32, 9999, 2, 3, 17, 3179, NULL, 'Those who live in the drier parts of the world, especially in areas of predominantly summer rainfall, will appreciate the joy of those first spring showers after three or four months of "drought".', 62, '820/880/808/828', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4333, '1998-01-05 23:00:00+00', '2014-04-30 23:24:01.272876+00', 'Merry Moores, The', 'MERRY MOORES', 1, 32, 9999, 4, 54, 13, 9, NULL, '', 94, '8888  8484  8888  8888', 0, 1, 1, 0, 93);
INSERT INTO 'dance' VALUES (9029, '2001-05-03 22:00:00+00', '2019-02-05 16:49:28.64524+00', 'Midnight Toil', 'MIDNIGHT TOIL', 1, 32, 9999, 3, 5, 7, 17, '1996-01-01', '', 60, '80800/82842/12 6 12 12 6/40400', 1, 1, 1, 0, 60);
INSERT INTO 'dance' VALUES (13622, '2010-10-13 22:00:00+00', '2019-05-12 09:22:19.356559+00', 'Midnight Ferry, The', 'MIDNIGHT FERRY', 1, 40, 9999, 4, 4, 1, 374, NULL, '', 85, '8080  8484  8888  8888  8888', 0, 1, 1, 0, 85);
INSERT INTO 'dance' VALUES (4334, '1998-09-30 22:00:00+00', '2014-08-24 14:24:02.119404+00', 'Merry Oddfellows, The', 'MERRY ODDFELLOWS', 2, 32, 9999, 1, 2, NULL, 9998, NULL, '', 52, '88/44/80/88', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14022, '2011-08-25 22:00:00+00', '2014-04-30 23:24:01.532914+00', 'Millville Grange, The', 'MILLVILLE GRANGE', 3, 32, NULL, 1, 3, 42, 401, NULL, 'Information derived from animation video.', 62, '800  888  888  888', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (4325, '1999-08-06 22:00:00+00', '2018-04-03 00:08:03.201135+00', 'Merry Lads of Ayr', 'MERRY LADS OF AYR', 1, 32, 9999, 1, 3, 42, 9998, '1827-01-01', '', 41, '800  800  844  866', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (4433, '1998-09-29 22:00:00+00', '2014-04-30 23:24:01.706042+00', 'Miss Betty Boyle', 'MISS BETTY BOYLE', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'Not to be confused with the Strathspey "Miss Betty Boyle''s Reel" which differs in bars 1-8 only.', 62, '888  800  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (4434, '1997-11-18 23:00:00+00', '2016-04-05 20:33:38.125788+00', 'Miss Betty Boyle''s Reel', 'MISS BETTY BOYLES REEL', 3, 32, 9999, 1, 3, 42, 9998, NULL, 'Not to be confused with the reel "Miss Betty Boyle" which differs in bars 1-8 only.', 56, '880  800  888  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (9933, '2001-06-05 22:00:00+00', '2015-12-17 21:54:39.962935+00', 'Mince and Tatties', 'MINCE AND TATTIES', 3, 32, 9999, 2, 104, 17, 101, NULL, '', 83, '484  888  484  888', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (4365, '1998-07-09 22:00:00+00', '2017-01-21 23:54:48.977131+00', 'Midnight Oil', 'MIDNIGHT OIL', 2, 48, 9999, 3, 5, 7, 108, '1992-01-01', '', 62, '80800  82842  84884  80800  80800  80800', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (4356, '2003-01-27 23:00:00+00', '2017-09-11 20:44:05.895428+00', 'Mid Lothian', 'MID LOTHIAN', 1, 40, 9999, 1, 3, 42, 263, '1795-01-01', '', 37, '800  800  880  822  880', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (18271, '2018-04-01 23:29:24.584461+00', '2018-04-09 23:22:12.704701+00', 'Can I Take Your Place?', 'CAN I TAKE YOUR PLACE', 2, 32, NULL, 1, 2, 76, 11622, NULL, 'The dance was devised to celebrate the birthday of the person whose place was always taken for demonstration of figures.



', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18280, '2018-04-10 21:53:04.254974+00', '2018-04-10 21:53:04.254974+00', 'Duke & Duchess of Cambridge', 'DUKE AND DUCHESS OF CAMBRIDGE', 3, 32, NULL, 4, 4, 1, 10397, NULL, 'Written for a special dance at Brighouse to commemorate the wedding of Prince William of Wales and Miss Kate Middleton in April 2011.', 93, '8888/8888/8888/6666', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14437, '2012-05-09 13:50:31.603847+00', '2014-04-30 23:24:01.896253+00', 'Miss Emily Gordon''s Jig', 'MISS EMILY GORDONS JIG', 2, 32, 9999, 1, 3, 42, 15, NULL, '', 66, '888  888  808  884', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (4359, '2000-02-21 23:00:00+00', '2020-05-29 01:53:02.584619+00', 'Middling, thank you', 'MIDDLING THANK YOU', 2, 40, 9999, 1, 3, 42, 432, NULL, 'Source:  Dances for 18J3, published by Button and Whitaker, 1813', 42, '880/880/880/800/822', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (4431, '2002-11-21 23:00:00+00', '2020-09-01 13:50:13.907543+00', 'Miss Bennet''s Jig', 'MISS BENNETS JIG', 2, 32, 9999, 1, 3, 42, 263, '1797-01-01', 'It is not immediately obvious that this is a 3-couple dance, but 1st couple dance around 3rd couple during bars 17–24. However, 3rd couple never move (similar to <<ddd:Flowers of Edinburgh#2250>>).', 31, '660  660  800  800', 0, 1, 0, 0, 41);
INSERT INTO 'dance' VALUES (4394, '1997-09-09 22:00:00+00', '2020-12-12 10:49:04.234058+00', 'Miller Of Drone, The', 'MILLER OF DRONE', 3, 32, 9999, 1, 3, 42, 976, '1740-01-01', '', 50, '880  880  800  888', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (10565, '2002-05-12 22:00:00+00', '2020-12-24 10:15:20.489227+00', 'Miskin Reel, The', 'MISKIN REEL', 1, 40, 9999, 1, 3, 42, 3131, NULL, 'Devised for the Gravesend and District Scottish Association who meet in the Miskin Hall at Gravesend. Published on Strathspey by Ron Mackey on 24 Feb 2001', 55, '802  888  886  888  800', 0, 1, 0, 0, 73);
INSERT INTO 'dance' VALUES (4404, '1998-09-29 22:00:00+00', '2020-12-13 11:54:58.966182+00', 'Milton''s Welcome', 'MILTONS WELCOME', 1, 32, 9999, 1, 3, 42, 26, '1974-01-01', '', 51, '888  808  646  880', 0, 1, 0, 0, 68);
INSERT INTO 'dance' VALUES (4422, '1998-10-20 22:00:00+00', '2021-05-08 11:05:05.541742+00', 'Miss Alison Little', 'MISS ALISON LITTLE', 1, 32, 9999, 1, 2, 76, 181, NULL, 'Devised for Alison, daughter of Bill and Hope Little of Castle Douglas.

', 54, '80  82  88  88', 1, 1, 1, 1, 78);
INSERT INTO 'dance' VALUES (4336, '1998-10-12 22:00:00+00', '2022-12-03 11:55:51.751094+00', 'Merry Reapers, The', 'MERRY REAPERS', 2, 24, 9999, 1, 3, 42, 9998, NULL, '', 44, '800  888  888', 1, 1, 0, 0, 77);
INSERT INTO 'dance' VALUES (9009, '2002-01-08 23:00:00+00', '2023-02-17 19:27:51.731474+00', 'Miller of Sessnie, The', 'MILLER OF SESSNIE', 2, 32, 9999, 3, 5, 16, 146, NULL, 'Inscribed "For Margaret and Derek Kendall."



The notes also say that "Sessnie is in Aberdeenshire and the miller - known as Mull Pa - was Margaret''s great grandfather."', 50, '88880  80008  86200  80062', 1, 1, 0, 1, 50);
INSERT INTO 'dance' VALUES (4374, '1998-09-29 22:00:00+00', '2021-05-08 20:55:46.990602+00', 'Mile to ride, A', 'MILE TO RIDE', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 37, '800  844  822  804', 1, 1, 0, 1, 50);
INSERT INTO 'dance' VALUES (4318, '1999-08-09 22:00:00+00', '2021-05-08 20:59:38.872602+00', 'Merrily Danced the Quaker''s Wife', 'MERRILY DANCED THE QUAKERS WIFE', 2, 40, 9999, 1, 3, 42, 9998, NULL, '', 40, '840  800  800  844  866', 1, 1, 0, 0, 53);
INSERT INTO 'dance' VALUES (4324, '2002-11-21 23:00:00+00', '2021-06-15 20:48:31.783658+00', 'Merry Dancers, The', 'MERRY DANCERS', 2, 32, 9999, 1, 3, 42, 9998, '1827-01-01', '', 50, '800  866  844  866', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (12662, '2006-01-02 23:00:00+00', '2021-07-30 08:31:25.399676+00', 'Miss Betty Ferguson of Dumfries', 'MISS BETTY FERGUSON OF DUMFRIES', 3, 32, 9999, 1, 102, 11, 308, '2005-01-01', '', 78, '6006  8888  8448  8888', 1, 1, 1, 1, 78);
INSERT INTO 'dance' VALUES (18659, '2018-09-24 22:49:32.089607+00', '2018-09-25 07:43:34.072222+00', 'Broken Symmetry', 'BROKEN SYMMETRY', 1, 48, NULL, 2, 3, 17, 11237, '2012-05-01', '', 72, '862 888 822 866 866 804', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18269, '2018-04-01 14:54:39.333755+00', '2018-04-01 14:54:39.333755+00', 'Welcome Whisky Back Again', 'WELCOME WHISKY BACK AGAIN', 1, 32, NULL, 2, 3, 18, 11534, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18270, '2018-04-01 14:57:00.014191+00', '2018-04-01 14:57:00.014191+00', 'Farewell to Whisky & Welcome Whisky Back Again', 'FAREWELL TO WHISKY AND WELCOME WHISKY BACK AGAIN', 4, 192, 3, 2, 3, 3, 11534, NULL, 'This is <<ddd:Farewell to Whisky>> immediately followed by <<ddd:Welcome Whisky Back Again>>, as suggested in the dance description. This entry is intended to help programme planning.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10567, '2002-05-12 22:00:00+00', '2019-04-25 22:43:41.094795+00', 'Monastery Meeting, The', 'MONASTERY MEETING', 1, 32, 9999, 5, 1, 4, 9998, NULL, '', 100, '8  8  8  8  8', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4511, '1998-09-29 22:00:00+00', '2016-10-28 22:42:34.820056+00', 'Miss Janet Laing''s Strathspey', 'MISS JANET LAINGS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 91, NULL, '', 69, '4224  4224  8888  8888', 0, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (4461, '1998-09-29 22:00:00+00', '2017-02-13 03:03:02.296628+00', 'Miss Dumbreck', 'MISS DUMBRECK', 1, 32, 9999, 1, 3, 42, 9998, '1841-01-01', '', 55, '800  888  886  880', 0, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (9701, '2000-11-12 23:00:00+00', '2017-02-14 15:21:31.463486+00', 'Miss Jane Muirhead of Dunsmuir', 'MISS JANE MUIRHEAD OF DUNSMUIR', 3, 32, 9999, 1, 3, 42, 2783, '2000-07-01', '', 53, '800  888  822  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (4558, '1997-10-28 23:00:00+00', '2017-09-19 16:41:57.055507+00', 'Miss Murray of Lintrose', 'MISS MURRAY OF LINTROSE', 1, 32, 9999, 1, 3, 42, 1749, '1784-01-01', '', 45, '880  808  810  880', 0, 1, 1, 1, 59);
INSERT INTO 'dance' VALUES (4555, '2000-04-05 22:00:00+00', '2017-09-30 16:26:01.180287+00', 'Miss Milligan''s Strathspey', 'MISS MILLIGANS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 319, '1973-01-01', '', 58, '880  888  882  880', 1, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (4548, '1998-09-29 22:00:00+00', '2018-04-03 00:08:04.71868+00', 'Miss Mary Douglas', 'MISS MARY DOUGLAS', 2, 48, 9999, 1, 3, 42, 432, '1816-01-01', '', 52, '888  888  800  800  822  888', 1, 1, 1, 1, 69);
INSERT INTO 'dance' VALUES (11048, '2002-11-24 23:00:00+00', '2018-04-07 23:21:11.877723+00', 'Wheel of Fortune', 'WHEEL OF FORTUNE', 3, 32, 9999, 1, 3, 42, 3254, '2002-08-01', 'Devised by Terry Lynne Harris, Pretoria, South Africa; August 2002



The idea for this dance was born when I encountered a description of the Roulette formation for the first time. It conjured up visions of roulette tables and casinos, where fortunes are won or lost through the spinning of a wheel.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15113, '2013-09-13 11:44:09.887037+00', '2018-04-10 11:44:49.215652+00', 'Land of the Rising Sun', 'LAND OF THE RISING SUN', 3, 32, 9999, 2, 3, 17, 3179, '2011-03-11', 'Devised by Wouter Joubert, 20 March 2011, as a tribute to the brave people of Japan who are rebuilding their lives, their homes and their country after the devastating earthquake and Tsunami that struck Japan on 11 March 2011.



On 2 December 2017, Wouter J. wrote: "The e-crib instructions for bars 17-20 differs from any of the printed versions of this dance but it represents how I want these bars to be danced. The movement is intended to simulate waves slapping against something. Retaining hands on bar 18 certainly helps the dancers to execute the quick underarm change of places successfully and also adds energy and tension to the movement."', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4506, '1998-09-29 22:00:00+00', '2020-05-08 17:03:49.946467+00', 'Miss Isabella McLeod', 'MISS ISABELLA MACLEOD', 3, 32, 9999, 1, 2, 76, 9998, NULL, '', 60, '80  88  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (4442, '1999-11-01 23:00:00+00', '2020-05-26 10:32:00.6337+00', 'Miss Cahoon''s Reel', 'MISS CAHOONS REEL', 2, 48, 9999, 1, 3, 42, 442, '1757-01-01', '', 46, '804/840/800/822/866/888', 0, 1, 1, 0, 61);
INSERT INTO 'dance' VALUES (4552, '1997-08-31 22:00:00+00', '2021-04-17 21:17:34.299673+00', 'Miss McLean of Inverness', 'MISS MACLEAN OF INVERNESS', 3, 32, 9999, 1, 4, 1, 200, NULL, 'Dedicated to Phyllis Draper of the RSCDS London Branch.', 83, '8080  8888  8888  8666', 1, 1, 0, 0, 82);
INSERT INTO 'dance' VALUES (14676, '2013-01-22 00:06:39.073934+00', '2020-10-01 18:18:10.005837+00', 'Miss Lesley Martin', 'MISS LESLEY MARTIN', 3, 32, NULL, 1, 3, 42, 10718, '2010-01-01', '', 47, '880  822  800  888', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (4444, '2001-11-22 23:00:00+00', '2020-12-12 10:53:32.867497+00', 'Miss Catherine Allan', 'MISS CATHERINE ALLAN', 3, 32, 9999, 1, 3, 42, 121, NULL, '', 44, '844  800  822  866', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (4447, '2002-11-13 23:00:00+00', '2020-12-12 10:56:00.502521+00', 'Miss Chirsty Stewart', 'MISS CHIRSTY STEWART', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'Even some RSCDS publications have used the erroneous spelling "Miss Christy Stewart", so that has been included as a spelling alias.', 47, '880/880/880/822', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (4476, '1998-09-29 22:00:00+00', '2020-12-12 10:59:56.394861+00', 'Miss Flora''s Favourite', 'MISS FLORAS FAVOURITE', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 53, '804  888  888  800', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (4477, '1999-01-07 23:00:00+00', '2020-12-12 11:07:17.150948+00', 'Miss Florence Adams', 'MISS FLORENCE ADAMS', 3, 32, 9999, 1, 3, 42, 108, '1991-01-01', '', 88, '884  888  888  844', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (4494, '2002-04-24 22:00:00+00', '2020-12-13 11:57:57.079479+00', 'Miss Heather Bartel', 'MISS HEATHER BARTEL', 3, 32, 9999, 1, 4, 2, 316, NULL, '', 100, '8888  8888  8888  8888', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (4500, '1997-04-03 22:00:00+00', '2020-12-13 12:01:41.212988+00', 'Miss Hilary Ann', 'MISS HILARY ANN', 2, 40, 9999, 1, 3, 42, 47, NULL, '', 37, '440  440  800  888  822', 0, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (4518, '2001-04-03 22:00:00+00', '2020-12-13 12:04:18.637294+00', 'Miss Jessie Dalrymple''s Reel', 'MISS JESSIE DALRYMPLES REEL', 1, 32, 9999, 1, 2, 76, 9998, '1783-01-01', '', 60, '88  88  80  88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (4521, '1997-09-09 22:00:00+00', '2020-12-13 12:15:44.63995+00', 'Miss Johnstone of Dumfries', 'MISS JOHNSTONE OF DUMFRIES', 2, 32, 9999, 1, 3, 42, 62, NULL, '', 50, '880  880  844  844', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (4544, '1997-08-21 22:00:00+00', '2020-12-29 11:38:33.57729+00', 'Miss Margaret Prentice', 'MISS MARGARET PRENTICE', 3, 32, 9999, 1, 3, 42, 108, '1991-09-01', 'June 1999, in memory of Miss Margaret Prentice of Glasgow Branch.', 67, '808  888  888  886', 0, 1, 0, 0, 89);
INSERT INTO 'dance' VALUES (4561, '1998-09-29 22:00:00+00', '2021-05-07 20:09:18.364253+00', 'Miss Nancy Arnott', 'MISS NANCY ARNOTT', 3, 32, 9999, 5, 56, NULL, 493, '1983-01-01', 'Inscribed to Miss Arnott, Branch Secretary since 1951.', 85, '484  888  828  888', 1, 1, 0, 0, 85);
INSERT INTO 'dance' VALUES (4512, '1998-11-07 23:00:00+00', '2021-05-07 20:30:12.679638+00', 'Miss Jarvis''s Reel', 'MISS JARVISS REEL', 1, 40, 9999, 1, 4, 1, 375, NULL, '', 66, '8440  8044  8020  8888  8888', 1, 1, 0, 1, 66);
INSERT INTO 'dance' VALUES (4450, '1998-09-29 22:00:00+00', '2021-05-08 10:40:24.745444+00', 'Miss Clemy Stewart''s Reel', 'MISS CLEMY STEWARTS REEL', 1, 32, 9999, 1, 3, 42, 339, '1749-01-01', '', 45, '402  844  844  866', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (4440, '1998-09-29 22:00:00+00', '2021-05-08 10:48:20.106674+00', 'Miss Burns''s Reel', 'MISS BURNSS REEL', 1, 32, 9999, 1, 2, 76, 263, '1794-01-01', 'This dance is »Miss Burns'' Reel« in *99 More Scottish Country Dances*. »Burns''s« is the official RSCDS spelling.', 52, '84  84  80  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (4484, '1998-09-30 22:00:00+00', '2023-01-12 22:37:36.823648+00', 'Miss Gibson''s Strathspey', 'MISS GIBSONS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 175, '1979-01-01', 'Muriel Gibson was secretary of the RSCDS from 1975 to 1988.', 53, '880  880  822  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (7543, '2001-11-21 23:00:00+00', '2023-02-08 11:03:12.569302+00', 'Milltimber Jig, The', 'MILLTIMBER JIG', 2, 32, 9999, 1, 2, 76, 861, NULL, '', 52, '88  84  84  44', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (4618, '2002-03-03 23:00:00+00', '2014-04-30 23:24:02.512816+00', 'Moffat Weavers, The', 'MOFFAT WEAVERS', 2, 32, 9999, 4, 4, 46, 1, '1990-01-01', '', 69, '8888  8080  8000  8888', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (11287, '2003-05-04 22:00:00+00', '2014-04-30 23:24:02.544674+00', 'Mole''s Frolic', 'MOLES FROLIC', 2, 32, 9999, 1, 3, 42, 2783, '2001-02-01', '', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (4654, '1997-08-22 22:00:00+00', '2019-03-12 23:39:12.720681+00', 'Moorgate Ramble', 'MOORGATE RAMBLE', 3, 32, 9999, 1, 4, 1, 525, NULL, '', 84, '8448  8888  6666  4888', 0, 1, 0, 0, 84);
INSERT INTO 'dance' VALUES (4662, '1998-11-06 23:00:00+00', '2016-12-23 01:13:35.040464+00', 'Moray Rant, The', 'MORAY RANT', 3, 48, 9999, 2, 3, 17, 108, '1968-01-01', '', 58, '866  800  804  840  880  808', 0, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (9473, '2002-01-08 23:00:00+00', '2018-04-03 00:08:05.360937+00', 'Morland Triples', 'MORLAND TRIPLES', 3, 32, 9999, 1, 3, 42, 108, '1999-01-01', '', 69, '808  888  888  888', 0, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (4579, '1998-09-29 22:00:00+00', '2018-04-03 00:08:04.877244+00', 'Miss Shaftesbury''s Fancy', 'MISS SHAFTESBURYS FANCY', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 60, '881  888  884  880', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (18281, '2018-04-10 22:04:46.559975+00', '2018-04-10 22:04:46.559975+00', 'Waverley Station Jig', 'WAVERLEY STATION JIG', 2, 32, NULL, 3, 5, 16, 10397, NULL, 'A fun dance aiming to give an impression of the busy Waverley Station in Edinburgh.', 50, '80004/48000/80080/88888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4808, '1998-04-19 22:00:00+00', '2018-03-13 22:21:14.790895+00', 'Mrs Stuart Linnell', 'MRS STUART LINNELL', 1, 40, 9999, 1, 3, 42, 26, '1976-01-01', '', 55, '844  833  455  488  888', 0, 1, 1, 0, 73);
INSERT INTO 'dance' VALUES (14403, '2012-02-12 23:12:34.615855+00', '2018-07-23 10:22:49.446111+00', 'Mrs Lambert''s Black Bun', 'MRS LAMBERTS BLACK BUN', 2, 32, NULL, 1, 3, 42, 9998, NULL, 'Posted on Strathspey by Rod Downey in Message 56073 · 8 Jun 2009 14:17:56.



The copy I have has no author nor history of the dance. I gather it has something to do with NZ summer school. I now know who the person was, but not who devised the dance.  Does anyone have any information? 

', 34, '800  633  633  822', 0, 1, 1, 1, 45);
INSERT INTO 'dance' VALUES (15211, '2013-10-14 22:27:08.25684+00', '2018-08-18 18:56:33.732729+00', 'Autumn Leaves', 'AUTUMN LEAVES', 1, 40, NULL, 1, 3, 42, 10884, NULL, 'Devised by the Senior Girls (ages 11-17), Selkirk Girls Country Dancing Club.  



Bars 1·8 represent the leaves falling down from the trees. 1st couple dancing down the middle and back show the leaves being tossed around by the wind. The remainder of the dance represents the leaves being blown into the river, swirling in the rapids until, finally, they are gently washed onto the shore."', 69, '880/800/880/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4679, '1998-09-29 22:00:00+00', '2019-11-27 20:24:38.797023+00', 'Moudiewort, The', 'MOUDIEWORT', 2, 32, 9999, 1, 3, 42, 1977, '1758-02-01', '', 38, '440/800/822/866', 0, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (9658, '2000-09-17 22:00:00+00', '2020-04-14 12:10:26.925047+00', 'Morag''s Strathspey', 'MORAGS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 2804, NULL, '', 87, '8448  8888  8888  8088', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (4725, '1998-09-29 22:00:00+00', '2020-05-27 18:48:32.934304+00', 'Mr Watson''s Favourite', 'MR WATSONS FAVOURITE', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 60, '88  80  88  88', 0, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (10566, '2002-05-12 22:00:00+00', '2020-06-13 11:55:01.62605+00', 'Missing Class, The', 'MISSING CLASS', 3, 32, 9999, 1, 4, 1, 3132, '2002-01-01', '', 75, '8888/8008/8224/8888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (4585, '1997-09-09 22:00:00+00', '2020-08-07 03:47:20.922963+00', 'Miss Stewart''s Jig', 'MISS STEWARTS JIG', 2, 32, 9999, 1, 2, 76, 129, '1966-01-01', '', 60, '88  88  88  80', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (8127, '1997-10-26 23:00:00+00', '2020-09-06 09:51:33.124026+00', 'Mr MacLennan''s Visit to Eindhoven', 'MR MACLENNANS VISIT TO EINDHOVEN', 1, 32, 9999, 1, 2, 76, 1445, '1995-01-01', '', 38, '84  84  88  71', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (11529, '2003-10-02 22:00:00+00', '2020-12-29 11:50:04.095957+00', 'Muckle Burn', 'MUCKLE BURN', 2, 40, 9999, 3, 5, 7, 21, NULL, 'I changed the name from "The Muckle Burn" to correspond with the text in the booklet "Highlander Collection volume 1".  Other publications may disagree.   ETF', 78, '80800  86846  86886  80888  88888', 0, 1, 0, 0, 78);
INSERT INTO 'dance' VALUES (13886, '2011-08-22 22:00:00+00', '2020-09-24 12:48:35.2198+00', 'Wingrove Strathspey, The', 'WINGROVE STRATHSPEY', 3, 32, NULL, 1, 4, 1, 2788, NULL, 'Devised for the 21st anniversary of Wingrove SC dancers.', 62, '8000  8800  8880  8888', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (3244, '2002-01-08 23:00:00+00', '2020-12-08 09:43:47.618889+00', 'Monadh Liath', 'MONADH LIATH', 3, 32, 9999, 1, 3, 42, 108, '1996-01-01', '', 56, '840  844  844  888', 0, 1, 0, 0, 283);
INSERT INTO 'dance' VALUES (4610, '1997-04-03 22:00:00+00', '2020-12-13 12:48:16.447907+00', 'Misty Isle In Summer, The', 'MISTY ISLE IN SUMMER', 3, 32, 9999, 1, 3, 42, 146, NULL, '', 56, '866  844  822  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (4620, '1997-09-09 22:00:00+00', '2020-12-13 12:52:17.676444+00', 'Moira Sinclair', 'MOIRA SINCLAIR', 2, 32, 9999, 1, 3, 42, 175, NULL, 'Moira Sinclair was Derek''s first wife', 56, '880  880  888  844', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (4692, '2000-03-05 23:00:00+00', '2020-12-13 12:56:04.494511+00', 'Moving Cloud, The', 'MOVING CLOUD', 1, 32, 9999, 1, 3, 42, 1154, NULL, '', 56, '800  844  888  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (10376, '2002-03-10 23:00:00+00', '2020-12-23 11:10:21.774836+00', 'Missing Turn, The', 'MISSING TURN', 1, 32, 9999, 1, 3, 42, 2998, NULL, '', 56, '800/888/844/888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (12690, '2006-02-16 23:00:00+00', '2021-01-10 21:22:22.830245+00', 'Morrison Measure, The', 'MORRISON MEASURE', 1, 32, 9999, 3, 5, 16, 146, NULL, '', 45, '88800  80400  80088  80004', 1, 1, 1, 1, 45);
INSERT INTO 'dance' VALUES (11884, '2004-11-01 23:00:00+00', '2020-12-25 12:20:34.245898+00', 'Missed Steak, The', 'MISSED STEAK', 2, 40, 9999, 1, 3, 42, 1445, NULL, '', 55, '800  888  844  888  844', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (12090, '2005-03-16 23:00:00+00', '2020-12-25 12:30:37.580703+00', 'Monday Night Reel, The', 'MONDAY NIGHT REEL', 1, 32, 9999, 8, 105, 91, 1047, NULL, '', 50, '800 008   844 448   008 800  448 844', 0, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (11772, '2004-09-02 22:00:00+00', '2021-01-20 10:13:50.802511+00', 'Wishing Well, The', 'WISHING WELL', 3, 32, 9999, 1, 2, 76, 3355, NULL, '', 58, '77  88  80  88', 1, 1, 1, 1, 84);
INSERT INTO 'dance' VALUES (4629, '1998-09-29 22:00:00+00', '2021-05-06 20:12:00.579419+00', 'Moment Of Truth', 'MOMENT OF TRUTH', 3, 32, 9999, 1, 3, 42, 348, NULL, '', 47, '800  822  888  844', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (9010, '2002-01-08 23:00:00+00', '2021-03-06 21:59:32.478434+00', 'Monique''s Jig', 'MONIQUES JIG', 2, 40, 9999, 1, 4, 2, 146, NULL, '', 60, '4444  4444  4444  8008  8888', 0, 1, 0, 0, 60);
INSERT INTO 'dance' VALUES (7466, '2002-04-08 22:00:00+00', '2021-03-26 23:41:44.511099+00', 'Mouswald', 'MOUSWALD', 1, 32, 9999, 1, 2, 76, 146, NULL, '', 43, '44  44  80  88', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (7465, '1998-04-24 22:00:00+00', '2021-03-26 23:43:21.93748+00', 'More Bees A-Dancing', 'MORE BEES ADANCING', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 44, '800  844  844  844', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (13360, '2009-08-02 22:00:00+00', '2021-04-24 22:45:17.844716+00', 'Montréal Rendezvous', 'MONTREAL RENDEZVOUS', 1, 32, NULL, 1, 3, 42, 777, NULL, 'Written for the 50th Anniversary of the Montréal Branch.



<<scddb-not-identical:4642>>

', 50, '822  822  400  12 12 12', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (4595, '1998-09-29 22:00:00+00', '2021-05-07 19:34:19.483624+00', 'Miss Welsh''s Reel', 'MISS WELSHS REEL', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 41, '880  880  800  822', 1, 1, 0, 1, 54);
INSERT INTO 'dance' VALUES (4565, '2002-04-19 22:00:00+00', '2021-05-07 19:50:43.172136+00', 'Miss Ogilvie''s Fancy', 'MISS OGILVIES FANCY', 3, 32, 9999, 1, 3, 42, 263, '1795-01-01', '', 44, '880  800  808  880', 0, 0, 0, 1, 58);
INSERT INTO 'dance' VALUES (7204, '1998-09-29 22:00:00+00', '2017-06-19 21:10:39.603591+00', 'Wisp of Thistle', 'WISP OF THISTLE', 3, 32, 9999, 1, 3, 42, 209, NULL, '', 55, '808  868  888  800', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (17526, '2017-01-05 09:30:52.181813+00', '2018-04-11 00:44:52.598363+00', 'Farewell to Portrush', 'FAREWELL TO PORTRUSH', 2, 32, NULL, 1, 3, 42, 10387, NULL, 'Devised by Lucy Mulholland.



With fond memories of wonderful dancing weekends with the Portrush Branch.', 59, '880/888/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4674, '1997-09-09 22:00:00+00', '2022-11-27 16:33:21.973497+00', 'Morven''s Welcome', 'MORVENS WELCOME', 1, 40, 9999, 1, 3, 42, 153, NULL, '', 50, '800  880  844  844  888', 1, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (4563, '1997-11-18 23:00:00+00', '2022-11-27 17:45:08.202979+00', 'Miss Nellie Wemyss', 'MISS NELLIE WEMYSS', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 34, '840  401  304  822  800', 1, 1, 1, 1, 45);
INSERT INTO 'dance' VALUES (4663, '1998-09-29 22:00:00+00', '2022-11-27 16:52:28.75208+00', 'Moray Reel, The', 'MORAY REEL', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 28, '440  440  800  822', 1, 1, 0, 1, 37);
INSERT INTO 'dance' VALUES (8835, '2000-06-04 22:00:00+00', '2022-12-19 16:25:57.204537+00', 'Windy Strath, The', 'WINDY STRATH', 2, 32, 9999, 1, 2, 76, 2419, NULL, '', 64, '84  88  88  88', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (15830, '2015-01-18 13:37:24.68135+00', '2018-05-01 07:30:21.164863+00', 'Linda''s Jig', 'LINDAS JIG', 2, 32, 9999, 2, 3, 17, 1582, '2009-03-01', 'A dance devised in March 2009 for Linda Gaul who teaches the Pitlochry class to their great enjoyment.', 83, '888/844/088/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15759, '2015-01-10 14:17:31.020052+00', '2018-04-02 23:56:37.68162+00', 'Song of Summer', 'SONG OF SUMMER', 1, 32, 9999, 1, 3, 42, 993, '2006-06-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7473, '1997-04-04 22:00:00+00', '2014-04-30 23:24:03.615065+00', 'Nameless Lassie, The', 'NAMELESS LASSIE', 3, 32, 9999, 1, 3, 42, 173, '1989-08-02', 'This dance is for a dancer whose name is Bunny.  Alec used to tease, "Bunny" is not a real name, you''re "nameless".



', 62, '888  884  844  866', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (4881, '1998-01-05 23:00:00+00', '2014-04-30 23:24:03.631457+00', 'Nameless Lassie, The', 'NAMELESS LASSIE', 1, 40, 9999, 1, 3, 42, 94, NULL, 'Tune  The Original (Alex Mackenzie)', 37, '804  840  800  860  806', 1, 1, 1, 0, 50);
INSERT INTO 'dance' VALUES (4832, '1997-04-03 22:00:00+00', '2019-12-23 20:57:43.949648+00', 'Murdochcairnie', 'MURDOCHCAIRNIE', 2, 32, 9999, 1, 3, 42, 176, NULL, '', 62, '888  888  888  800', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (4959, '1997-11-18 23:00:00+00', '2020-04-10 16:22:07.115109+00', 'Nineteenth of December', 'NINETEENTH OF DECEMBER', 2, 32, 9999, 1, 2, NULL, 9998, '1754-01-01', 'Nineteenth of December is believed to refer to the last day that the Jacobite Army, led by Bonnie Prince Charlie in 1745, spent on English soil (reluctantly deferring to his advisors).', 60, '88  88  80  88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (7219, '1998-09-29 22:00:00+00', '2020-05-28 10:03:38.928499+00', 'Woo''d and married and a''', 'WOOD AND MARRIED AND A', 2, 32, 9999, 1, 3, 42, 432, '1816-01-01', '', 69, '888  888  880  888', 1, 1, 1, 0, 91);
INSERT INTO 'dance' VALUES (4864, '1998-09-29 22:00:00+00', '2020-05-29 01:53:52.206249+00', 'My Mother''s coming in', 'MY MOTHERS COMING IN', 1, 32, 9999, 1, 3, 42, 432, NULL, 'Source:  Dances for 1813, published by Button and Whitaker, 1813', 62, '888/800/888/888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (4848, '2001-11-13 23:00:00+00', '2020-08-07 08:47:08.956014+00', 'My Ain Hoose', 'MY AIN HOOSE', 2, 32, 9999, 1, 2, 76, 129, '1966-01-01', '', 52, '80/08/88/88', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (4865, '2002-04-19 22:00:00+00', '2021-05-03 09:25:10.820172+00', 'My only Jo and Dearie, O', 'MY ONLY JO AND DEARIE O', 3, 32, 9999, 1, 3, 42, 432, '1816-01-01', '', 44, '444  444  880  808', 1, 0, 0, 1, 58);
INSERT INTO 'dance' VALUES (4903, '1998-04-19 22:00:00+00', '2020-09-01 14:19:48.776981+00', 'Ness Point', 'NESS POINT', 1, 40, 9999, 1, 4, 1, 227, '1987-01-01', '', 57, '8000  7034  7632  8888  8444', 0, 1, 0, 0, 45);
INSERT INTO 'dance' VALUES (7474, '1998-04-24 22:00:00+00', '2020-09-04 13:40:30.829398+00', 'New Abbey', 'NEW ABBEY', 3, 32, 9999, 1, 2, 76, 146, NULL, '', 56, '80  88  84  88', 0, 1, 0, 0, 81);
INSERT INTO 'dance' VALUES (9639, '2000-09-05 22:00:00+00', '2020-09-09 09:45:56.296599+00', 'Mr Hamilton''s Hornpipe', 'MR HAMILTONS HORNPIPE', 1, 32, 9999, 1, 3, 42, 146, '2000-01-01', '', 44, '404  844  822  866', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (4816, '2002-04-19 22:00:00+00', '2020-09-22 16:15:34.328272+00', 'Ms Gillian McMullen Of Cambridge', 'MS GILLIAN MACMULLEN OF CAMBRIDGE', 3, 32, 9999, 1, 4, 1, 331, NULL, '', 78, '8668  8008  8088  8888', 0, 1, 0, 0, 78);
INSERT INTO 'dance' VALUES (4806, '1999-11-01 23:00:00+00', '2020-12-13 19:07:18.044898+00', 'Mrs Stewart''s Strathspey', 'MRS STEWARTS STRATHSPEY', 3, 48, 9999, 1, 3, 42, 465, '1800-01-01', '', 52, '880/800/888/822/880/888', 0, 1, 1, 0, 69);
INSERT INTO 'dance' VALUES (9560, '2001-11-21 23:00:00+00', '2020-12-21 11:16:12.485045+00', 'Music Will Tell You, The', 'MUSIC WILL TELL YOU', 1, 32, 9999, 1, 4, 1, 2788, '1996-01-01', '', 88, '8888  8080  8888  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (9672, '2000-09-18 22:00:00+00', '2020-12-21 12:22:10.263478+00', 'Mrs Schneider''s Strathspey', 'MRS SCHNEIDERS STRATHSPEY', 3, 32, 9999, 1, 2, 76, 2488, '1982-01-01', '', 56, '66  88  44  88', 0, 1, 0, 0, 81);
INSERT INTO 'dance' VALUES (13617, '2010-10-08 22:00:00+00', '2021-01-01 18:54:29.685699+00', 'Mr Michael Bear''s Reel', 'MR MICHAEL BEARS REEL', 1, 32, 9999, 1, 3, 42, 10254, NULL, '', 50, '880  800  808  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (7210, '2001-04-03 22:00:00+00', '2021-01-06 16:15:04.453519+00', 'Within a Mile of Edinburgh Toon', 'WITHIN A MILE OF EDINBURGH TOON', 3, 32, 9999, 1, 3, 42, 455, '1795-01-01', '', 47, '800  840  844  888', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (11814, '2004-10-05 22:00:00+00', '2021-01-18 19:17:51.140816+00', 'Montparnasse', 'MONTPARNASSE', 3, 32, 9999, 1, 4, 2, 104, '2003-05-01', 'For Danielle and Jerry Reinstein whose Parisian home is in Montparnasse.', 87, '8008  8888  8888  8888', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (12569, '2005-10-20 22:00:00+00', '2021-03-27 21:49:29.940551+00', 'Neidpath Tower', 'NEIDPATH TOWER', 3, 32, 9999, 1, 4, 2, 2682, '2005-02-22', 'Devised 22nd February, 2005 in Wellington, whilst sitting out as part of a spare couple during the dancing of Neidpath Castle. Evidently, the dance is a four couple version of Neidpath Castle. The tower of Neidpath Castle is not square but rather the shape of a parallelogram with rounded corners.



Recommended music is "Neidpath Castle," but there is no 4 x32 recording.

Acceptable alternative would be a pastoral 4x32 Strathspey such as "St John''s

River," or "Bonnie Lass of Bon Accord."', 82, '8888  8888  8118  8448', 1, 1, 1, 1, 82);
INSERT INTO 'dance' VALUES (7220, '1999-08-06 22:00:00+00', '2021-03-28 13:59:20.636934+00', 'Wood of Fyvie, The', 'WOOD OF FYVIE', 1, 32, 9999, 1, 3, 42, 976, '1740-01-01', '', 44, '440  660  844  866', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (4782, '1998-11-11 23:00:00+00', '2021-04-13 21:56:55.379414+00', 'Mrs MacLeod', 'MRS MACLEOD', 1, 32, 9999, 1, 3, 42, 9998, '1827-01-01', 'The revised version of Book 6 changed "lead" down & up to "dance" down & up in bars 9-16. Though all the available videos show the original "lead" version with RH joined.

', 47, '880  800  844  866', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (4882, '1997-09-10 22:00:00+00', '2021-05-03 08:38:52.382133+00', 'Nancy Dawson', 'NANCY DAWSON', 2, 32, 9999, 1, 2, 76, 129, '1966-01-01', '', 52, '88  88  80  80', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (4844, '2000-09-05 22:00:00+00', '2021-05-03 09:28:02.089392+00', 'Music Makars, The', 'MUSIC MAKARS', 1, 32, 9999, 1, 3, 42, 146, '1979-01-01', 'Inscribed to the many talented musicians who have inspired both teachers and dancers at the Society''s Annual Summer School,', 47, '800  833  833  888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (4908, '1997-08-20 22:00:00+00', '2021-05-04 08:43:19.783823+00', 'Netherby Hall', 'NETHERBY HALL', 1, 32, 9999, 1, 2, 76, 108, '1964-01-01', '', 58, '68  88  84  84', 1, 1, 0, 1, 90);
INSERT INTO 'dance' VALUES (4804, '1998-09-29 22:00:00+00', '2021-05-04 23:11:17.77184+00', 'Mrs Stewart Sinton''s Reel', 'MRS STEWART SINTONS REEL', 2, 32, 9999, 1, 2, 76, 9998, NULL, '', 60, '88  88  80  88', 1, 1, 0, 1, 87);
INSERT INTO 'dance' VALUES (4784, '2002-04-30 22:00:00+00', '2021-05-04 23:13:04.553872+00', 'Mrs MacPherson of Inveran', 'MRS MACPHERSON OF INVERAN', 1, 32, 9999, 1, 3, 42, 108, '1964-01-01', '', 62, '888  800  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (4744, '1998-09-29 22:00:00+00', '2021-05-06 13:48:51.612249+00', 'Mrs Cholmondeley''s Reel', 'MRS CHOLMONDELEYS REEL', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 31, '800  080  800  880', 0, 1, 0, 0, 41);
INSERT INTO 'dance' VALUES (4720, '1998-09-29 22:00:00+00', '2021-05-06 13:55:11.2243+00', 'Mr Robert H Mackay', 'MR ROBERT H MACKAY', 3, 32, 9999, 1, 3, 42, 509, NULL, '', 64, '884  868  808  888', 1, 1, 1, 1, 85);
INSERT INTO 'dance' VALUES (4774, '2002-09-22 22:00:00+00', '2021-08-02 09:50:00.139163+00', 'Mrs Leeman Dances', 'MRS LEEMAN DANCES', 2, 32, 9999, 1, 3, 42, 308, '1995-03-01', '"Mrs Joyce Leeman is a long standing member of Scunthorpe Scottish Country Dance Club, who, like many of us, sometimes has problems knowing which is right and which is left."', 62, '880  844  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (5006, '1998-09-29 22:00:00+00', '2017-02-06 00:49:35.517901+00', 'Nurseryman, The', 'NURSERYMAN', 2, 32, 9999, 1, 3, 42, 505, '1988-01-01', 'In memory of Roy Clowes of Ormskirk.



Bars 9 - 16 of this dance are taken from the dance, “Angus MacKinnon’s Hornpipe”, by John Bowie Dickson, published in 1978  (statement made by the deviser)', 56, '800  888  888  844', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (9503, '2001-07-30 22:00:00+00', '2017-04-27 21:04:34.833202+00', 'Off the Ground', 'OFF THE GROUND', 1, 40, 9999, 1, 3, 42, 228, NULL, '', 55, '800  844  888  844  888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (4857, '2000-08-30 22:00:00+00', '2022-04-26 09:18:45.103674+00', 'My Friend Joe', 'MY FRIEND JOE', 3, 32, 9999, 1, 3, 42, 62, NULL, '', 56, '880  880  848  884', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (4877, '1998-11-29 23:00:00+00', '2022-11-20 16:09:42.127075+00', 'Myrtle And Joy', 'MYRTLE AND JOY', 2, 32, 9999, 8, 6, 88, 480, '1992-04-19', '"In my salad days, I lived on Beacon Hill in Boston, MA at the corner of Myrtle and Joy streets."', 71, '888888  880880  844844  804840', 1, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (9011, '2002-01-08 23:00:00+00', '2023-01-17 00:15:26.421789+00', 'My Jo', 'MY JO', 3, 32, 9999, 1, 2, 76, 146, NULL, '', 52, '44/44/88/88', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (12334, '2005-04-27 22:00:00+00', '2014-04-30 23:24:03.847519+00', 'New Forest Wedding', 'NEW FOREST WEDDING', 2, 48, 9999, 1, 4, 13, 3580, '2002-04-01', 'Suggested CD: Highlander Music SD vol 2 # 11 "The Moray House Of Edinburgh" (Neil Barron)



Devised for the celebration of the marriage of Sue Ramsay and Barry Dudgeon at Minstead, Hampshire on 29th June 2002.



Description	



1-8	  1st couple cross right hand and cast down one place (2s step up on bars 3 and 4) and dance a half figure of eight up through the 2nd couple.(2134)



9-16	  1s, 3s and 4s dance Inveran reels (1s crossing down to start). (2134)



17-24	  4th couple cross right hand and cast up one place (3s step down on bars 3 and 4) and dance a half figure of eight down through the 3rd couple. (2143)



25-32	  2s, 1s and 4s dance inverted Inveran reels (4s crossing up to start). (2143)



33-40	  2s, 1s and 4s set and cross right hand and set and turn right hand finishing facing up in allemande hold. (2143)



41-48	  2s, 1s and 4s dance a three couple allemande. (4123)

', 58, '8000  8088  0008  8808  8808  8808', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (4929, '2002-02-09 23:00:00+00', '2019-03-12 11:37:15.769513+00', 'New Scotia Quadrille', 'NEW SCOTIA QUADRILLE', 1, 48, 9999, 4, 4, 3, 499, '1897-01-01', '', 75, '8080  8888  4444  4444  8888  8888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (8727, '1998-06-18 22:00:00+00', '2015-04-27 21:44:31.739375+00', 'Nessie''s Neuk', 'NESSIES NEUK', 1, 40, 9999, 1, 3, 42, 2190, NULL, '', 45, '800  644  822  644  888', 1, 1, 1, 0, 60);
INSERT INTO 'dance' VALUES (4830, '1998-09-30 22:00:00+00', '2015-10-12 10:39:36.57388+00', 'Munro Rant, The', 'MUNRO RANT', 3, 32, 9999, 1, 2, NULL, 9998, NULL, 'This was originally published as a 3c dance; 1c then cross below 3c on [5].  It would be useful to look up in which editions of the RDCDS books and Pocket Books this change was made.

', 60, '80  88  88  88', 0, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (4927, '1998-01-04 23:00:00+00', '2019-03-12 11:39:19.129595+00', 'New Petronella, The', 'NEW PETRONELLA', 1, 48, 9999, 4, 4, 54, 9998, NULL, '', 75, '4  4  6  6  8  8', 0, 0, 0, 0, 75);
INSERT INTO 'dance' VALUES (4911, '1998-11-07 23:00:00+00', '2017-03-31 22:39:01.015507+00', 'New Ashludie Rant, The', 'NEW ASHLUDIE RANT', 2, 32, 9999, 1, 3, 42, 176, '1959-01-01', 'Publication marked Copyright Mozart Allan 1959.', 55, '864  800  888  866', 0, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (4925, '2002-04-19 22:00:00+00', '2017-07-07 14:11:29.943161+00', 'New Park', 'NEW PARK', 3, 32, 9999, 1, 3, 42, 469, '1788-01-01', '', 57, '818  888  800  888', 1, 1, 1, 1, 76);
INSERT INTO 'dance' VALUES (17533, '2017-01-05 10:21:17.853749+00', '2018-04-11 06:47:47.956613+00', 'Comber Car Park', 'COMBER CAR PARK', 3, 32, NULL, 2, 3, 17, 575, '2009-01-01', 'Devised by Kathrine Burke.



This dance was devised in the car park outside the Leisure Centre in Comber Co. Down on the 8th March 2009 and is inscribed to Russell Orr who was born on 08.03.83 ', 83, '844/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4195, '1999-10-27 22:00:00+00', '2018-04-03 00:08:07.837964+00', 'Ninety-second, The', 'NINETYSECOND', 3, 24, 9999, 1, 3, 42, 263, '1790-01-01', '', 48, '886  800  880', 1, 1, 1, 1, 63);
INSERT INTO 'dance' VALUES (11628, '2003-12-08 23:00:00+00', '2019-03-02 11:54:03.302429+00', 'Norah', 'NORAH', 2, 96, 9999, 4, 4, 3, 3183, '2003-01-01', '', 71, '8080  8484  8888  8080  0808  4848  8888  0808  8080  0808  8888  8888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (5033, '1998-09-29 22:00:00+00', '2019-03-11 19:24:05.879838+00', 'Off she goes in the North', 'OFF SHE GOES IN THE NORTH', 2, 32, 9999, 1, 4, 1, 9998, NULL, '', 62, '8000  8000  8888  8888', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (4998, '1998-11-14 23:00:00+00', '2019-03-12 11:27:02.769658+00', 'Nottingham Lace', 'NOTTINGHAM LACE', 1, 96, 9999, 4, 4, 3, 48, NULL, 'Dance strucured into 4 24 bar phrases. Suitable music should be phrased 4 times ABB.', 92, '8888 8888 8888   8080 8888 8888   repeat', 0, 1, 0, 0, 91);
INSERT INTO 'dance' VALUES (4894, '2002-02-27 23:00:00+00', '2015-06-14 21:06:32.08784+00', 'Niel Gow''s Farewell to Whisky', 'NIEL GOWS FAREWELL TO WHISKY', 1, 48, 9999, 5, 4, NULL, 9998, NULL, 'Collected in Canada and made available to the Society by Miss Jenny MacLachlan', 83, '8888  8888  8888  4444  4444  8888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (7613, '1998-07-12 22:00:00+00', '2020-06-22 10:06:29.261736+00', 'New Biggin', 'NEW BIGGIN', 2, 48, 9999, 1, 3, 42, 2204, NULL, '', 40, '800  800  888  800  800  866', 1, 1, 1, 1, 52);
INSERT INTO 'dance' VALUES (4931, '2002-03-03 23:00:00+00', '2020-12-14 09:30:04.044185+00', 'New Scotland Strathspey, The', 'NEW SCOTLAND STRATHSPEY', 3, 40, 9999, 1, 4, 1, 1169, '1948-01-01', '', 83, '8484  8888  8888  8888  8131', 0, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (4930, '1998-01-05 23:00:00+00', '2020-08-07 08:50:12.048663+00', 'New Scotland Reel, A', 'NEW SCOTLAND REEL', 1, 64, 9999, 1, 4, 22, 82, NULL, '', 39, '8668  6886  12 12 12 12  0440  0880  0880  4884  8888', 0, 1, 0, 0, 78);
INSERT INTO 'dance' VALUES (9649, '2001-06-12 22:00:00+00', '2020-09-09 09:52:13.375245+00', 'Newcastle Half Century, The', 'NEWCASTLE HALF CENTURY', 2, 32, 9999, 1, 3, 42, 2806, '1999-01-01', '', 62, '844  844  888  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (4858, '2000-02-20 23:00:00+00', '2020-12-13 19:12:33.92262+00', 'My Heather Hills', 'MY HEATHER HILLS', 2, 48, 9999, 2, 3, 17, 175, '1991-01-01', '', 62, '800  844  844  822  880  868', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (4982, '1997-04-03 22:00:00+00', '2020-12-14 09:37:50.769358+00', 'North Gate Reel, The', 'NORTH GATE REEL', 2, 32, 9999, 1, 2, 76, 200, NULL, '', 62, '82  88  88  88', 0, 1, 0, 0, 90);
INSERT INTO 'dance' VALUES (8654, '2004-05-31 22:00:00+00', '2020-12-19 15:08:39.945944+00', 'Newcastle Festival, The', 'NEWCASTLE FESTIVAL', 1, 32, 9999, 1, 100, 11, 2788, '2004-01-01', '', 69, '8668  8008  8008  6886', 0, 1, 1, 0, 68);
INSERT INTO 'dance' VALUES (9391, '2002-12-15 23:00:00+00', '2020-12-21 00:16:45.526105+00', 'Nifty Shiftin''', 'NIFTY SHIFTIN', 1, 32, 9999, 1, 4, 2, 550, '2000-01-01', '', 87, '8008  8888  8888  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (12745, '2006-05-11 22:00:00+00', '2021-01-09 11:15:43.495998+00', 'Off to Gretna', 'OFF TO GRETNA', 3, 32, 9999, 1, 2, 76, 1445, '2006-01-01', '', 52, '80  88  80  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (12744, '2006-05-11 22:00:00+00', '2021-01-09 21:21:27.526234+00', 'New Years'' Challenge', 'NEW YEARS CHALLENGE', 2, 32, 9999, 4, 4, 1, 1445, '2006-01-01', '', 81, '8484  8888  2626  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (4862, '1998-09-29 22:00:00+00', '2021-01-24 11:47:13.338869+00', 'My Love she''s but a Lassie yet', 'MY LOVE SHES BUT A LASSIE YET', 1, 32, 9999, 1, 109, 76, 9998, NULL, '<<scddb-not-identical:11308>>', 69, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (5007, '1998-11-07 23:00:00+00', '2021-02-19 19:02:30.576508+00', 'Nut, The', 'NUT', 2, 24, 9999, 1, 2, 76, 9998, '1827-01-01', 'An article by <<ddp:Thompson, Meryl#2695>> about The Nut appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2020/05/Reel-311A-electronic.pdf#page=13|issue 311 of The Reel>>.', 52, '66  80  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (5034, '2002-09-10 22:00:00+00', '2021-04-29 09:43:30.41266+00', 'Off to Speyside', 'OFF TO SPEYSIDE', 2, 32, 9999, 1, 2, 76, 146, NULL, '', 52, '80  08  88  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (4948, '1998-01-04 23:00:00+00', '2021-05-03 08:11:03.332174+00', 'Newington Assembly', 'NEWINGTON ASSEMBLY', 1, 32, 9999, 1, 2, 76, 9998, '1794-01-01', '', 60, '88  80  88  88', 1, 1, 0, 1, 87);
INSERT INTO 'dance' VALUES (4968, '2002-08-26 22:00:00+00', '2021-04-30 10:36:57.180312+00', 'None so Pretty', 'NONE SO PRETTY', 1, 40, 9999, 1, 3, 42, 432, '1816-01-01', '“None so pretty” is a common name for *Saxifraga × urbium*, a popular garden flower which is also known as “London Pride”.', 55, '800  888  888  880  880', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (4932, '2001-04-03 22:00:00+00', '2021-05-03 08:13:54.306162+00', 'New Town of Edinburgh, The', 'NEW TOWN OF EDINBURGH', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 44, '880  880  800  844', 1, 1, 0, 1, 58);
INSERT INTO 'dance' VALUES (11372, '2003-06-26 22:00:00+00', '2016-03-10 11:24:18.945002+00', 'Noah''s Ark', 'NOAHS ARK', 2, 32, 9999, 1, 2, NULL, 64, '2002-01-01', '', 56, '84/48/66/88', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (4990, '2003-01-30 23:00:00+00', '2022-04-26 01:24:15.595303+00', 'Northern Lights, The', 'NORTHERN LIGHTS', 3, 32, 9999, 2, 3, 17, 1177, NULL, '', 83, '880/808/888/888', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (4995, '1997-11-18 23:00:00+00', '2022-08-13 17:09:23.592676+00', 'Not I', 'NOT I', 1, 32, 9999, 1, 3, 42, 9998, '1754-01-01', '', 53, '800  888  822  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (7233, '1997-04-03 22:00:00+00', '2022-10-23 20:45:01.523851+00', 'World Around the Corner, The', 'WORLD AROUND THE CORNER', 1, 32, 9999, 1, 3, 42, 44, '1991-06-01', '', 48, '420  844  888  844', 1, 1, 1, 1, 64);
INSERT INTO 'dance' VALUES (5032, '1997-08-20 22:00:00+00', '2022-11-20 15:54:19.334499+00', 'Off she goes', 'OFF SHE GOES', 2, 16, 9999, 1, 2, 76, 263, '1800-01-01', '', 34, '44  80', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (13627, '2010-11-07 23:00:00+00', '2022-12-20 12:37:30.153744+00', 'October in Rechberg', 'OCTOBER IN RECHBERG', 3, 32, NULL, 2, 3, 18, 2672, '2010-10-30', 'Presented at the 40th anniversary of the Rechberg weekend.', 67, '800  844  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (5065, '1998-09-29 22:00:00+00', '2014-04-30 23:24:04.617361+00', 'Old Nick''s Lumber Room', 'OLD NICKS LUMBER ROOM', 2, 32, 9999, 1, 3, 42, 9998, '1759-01-01', '', 53, '800  888  866  844', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (14659, '2013-01-05 11:47:59.152766+00', '2014-04-30 23:24:04.725866+00', 'Once Upon a Dream', 'ONCE UPON A DREAM', 1, 32, NULL, 1, 3, 42, 10699, NULL, '', 41, '880  880  822  800', 0, 1, 1, 0, 54);
INSERT INTO 'dance' VALUES (13071, '2006-11-10 23:00:00+00', '2014-04-30 23:24:04.820336+00', 'Open Road, The', 'OPEN ROAD', 2, 32, 9999, 1, 100, 2, 884, '1995-01-01', '', 67, '7227  6446  8448  8448', 1, 1, 1, 1, 67);
INSERT INTO 'dance' VALUES (5111, '1998-09-29 22:00:00+00', '2014-04-30 23:24:04.882623+00', 'Oriel Strathspey', 'ORIEL STRATHSPEY', 3, 32, 9999, 1, 4, 1, 349, '1982-01-01', '', 75, '8448  4884  8888  8008', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (13929, '2011-08-22 22:00:00+00', '2018-04-12 09:00:06.882924+00', 'Toast to Tobie, A', 'TOAST TO TOBIE', 2, 32, NULL, 1, 4, 1, 3179, '2003-02-01', 'Devised by Wouter Joubert, Pretoria, February 2003.



Dedicated to my non-dancing wife, Tobie.', 72, '8080/8888/8484/8282', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12796, '2006-07-02 22:00:00+00', '2014-10-19 15:48:12.26641+00', 'Outer Circle, The', 'OUTER CIRCLE', 1, 48, 9999, 1, 3, 42, 1275, NULL, '', 54, '800  844  888  844  888  844', 1, 1, 1, 1, 61);
INSERT INTO 'dance' VALUES (12538, '2005-09-24 22:00:00+00', '2015-03-11 23:20:52.03811+00', 'Orkney Reel, The', 'ORKNEY REEL', 1, 96, 9999, 4, 4, 3, 374, '2005-01-01', '', 92, '8888  8888  8888  8888    8888  8888  8888  8888    8888  8080  0808  8888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (7874, '1997-09-10 22:00:00+00', '2016-01-11 00:10:56.915276+00', 'Ocean Frolic, An', 'OCEAN FROLIC', 1, 32, 9999, 4, 4, 1, 352, '1994-01-01', 'This dance contains Schiehallion Reels with lead-change, that means men start with ladies closely behind and lead is changed during the loops.', 81, '4444/8888/8888/6666', 1, 1, 1, 0, 81);
INSERT INTO 'dance' VALUES (15126, '2013-09-15 21:17:15.163652+00', '2015-09-05 21:20:16.707352+00', 'Painter''s Daughter, The', 'PAINTERS DAUGHTER', 3, 40, NULL, 2, 3, 18, 1445, '2013-01-01', '', 46, '882  800  844  844  844', 0, 1, 1, 0, 61);
INSERT INTO 'dance' VALUES (5090, '1998-01-05 23:00:00+00', '2019-04-18 17:39:44.754311+00', 'One Man Short', 'ONE MAN SHORT', 1, 40, 9999, 2, 3, 17, 128, NULL, '', 55, '800  880  880  888  888', 0, 1, 0, 0, 73);
INSERT INTO 'dance' VALUES (14661, '2013-01-13 00:22:23.012348+00', '2017-11-11 00:17:38.498368+00', 'Outside the Box', 'OUTSIDE THE BOX', 2, 32, NULL, 1, 102, 2, 854, '2012-12-01', 'Devised 2012 for Chris Ronald, who when devising dances is always willing to think Outside the Box.', 81, '8448  8448  8448  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (5062, '1997-08-17 22:00:00+00', '2020-02-10 15:37:37.096941+00', 'Old Man of Storr, The', 'OLD MAN OF STORR', 1, 32, 9999, 1, 3, 42, 146, '1980-01-01', '', 38, '840  804  800  880', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (5136, '1998-09-29 22:00:00+00', '2020-10-10 00:01:04.870678+00', 'Over the Water to Charlie (New Way)', 'OVER THE WATER TO CHARLIE NEW WAY', 2, 32, 9999, 1, 3, 42, 319, '1750-01-01', '', 47, '800  880  844  866', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (9215, '2002-02-09 23:00:00+00', '2020-12-20 23:53:38.919541+00', 'Pentagon, The', 'PENTAGON', 1, 32, 9999, 102, 5, NULL, 108, '1998-01-01', '', 58, '5x{80440  80880  80000  88888})  (44444  44444  88888  88888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10799, '2002-08-26 22:00:00+00', '2020-12-24 18:09:13.128898+00', 'Par for the Course', 'PAR FOR THE COURSE', 1, 32, 9999, 1, 3, 42, 2672, '2001-01-01', 'Devised as a birthday present for Margaret Adam of Atlanta', 50, '800  888  800  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (11934, '2004-12-06 23:00:00+00', '2020-12-25 12:27:46.978787+00', 'Old Snuff Mill Bridge, The', 'OLD SNUFF MILL BRIDGE', 1, 32, 9999, 1, 3, 42, 3482, NULL, '', 50, '800  888  844  844', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (5040, '1998-09-29 22:00:00+00', '2021-01-06 10:47:15.833589+00', 'Oh, whistle and I''ll come tae ye, my Lad', 'OH WHISTLE AND ILL COME TAE YE MY LAD', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 62, '888  888  800  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (12277, '2005-04-25 22:00:00+00', '2021-01-15 10:54:26.148643+00', 'Oot Dancing', 'OOT DANCING', 1, 32, 9999, 1, 4, 1, 550, '2005-01-01', 'may 2005.  Note: Bars 25-32 are deliberately not broken down. 4+4 doesn''t work well

- the lead up is too slow and the arches too frantic. I suspect 2+6 may

be the opposite and 3+5 be about right, but play around and see what works

for you in your set - and don''t worry if it varies!



Notes from Ian:

When my son Stuart was first born, his sister Lorna called him "Oot". This

then progressed to "''Ua''t" and then "S''ua''t". This dance was written just

before Stuart''s first birthday, and is dedicated to him.', 93, '8888  8888  8888  8555', 1, 1, 1, 1, 92);
INSERT INTO 'dance' VALUES (5147, '1997-09-11 22:00:00+00', '2021-04-25 18:27:12.089365+00', 'Paddy In The Car', 'PADDY IN THE CAR', 2, 40, 9999, 1, 3, 42, 1189, NULL, '', 42, '800  840  888  800  880', 0, 0, 0, 0, 56);
INSERT INTO 'dance' VALUES (10957, '2002-11-14 23:00:00+00', '2021-01-30 16:41:18.546015+00', 'Palindrome, The', 'PALINDROME', 1, 40, 9999, 1, 100, 2, 108, '2002-01-01', '', 75, '8448/8448/8888/8448/8008', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (8117, '2002-03-12 23:00:00+00', '2021-03-22 01:00:52.902265+00', 'Pipe Major William McVean', 'PIPE MAJOR WILLIAM MACVEAN', 1, 32, 9999, 1, 3, 42, 1445, '1996-01-01', '', 56, '800  888  844  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (5118, '1998-05-05 22:00:00+00', '2021-03-27 19:44:47.838589+00', 'Our Dancing Soutar', 'OUR DANCING SOUTAR', 1, 32, 9999, 1, 3, 42, 1185, NULL, 'Soutar = Sutter = a shoemaker.', 41, '800  888  800  822', 0, 1, 0, 0, 54);
INSERT INTO 'dance' VALUES (5099, '1998-09-29 22:00:00+00', '2021-04-28 09:27:20.563728+00', 'Open the Door to Three', 'OPEN THE DOOR TO THREE', 2, 48, 9999, 1, 3, 42, 339, '1749-01-01', '', 46, '440  440  800  866  866  888', 1, 1, 0, 1, 61);
INSERT INTO 'dance' VALUES (5080, '1998-04-29 22:00:00+00', '2021-04-28 23:09:57.817474+00', 'On The Quarter-Deck', 'ON THE QUARTERDECK', 1, 32, 9999, 1, 2, 76, 44, NULL, '', 56, '80  84  88  88', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (5168, '1997-04-03 22:00:00+00', '2019-03-11 19:15:43.538705+00', 'Partans In His Creel', 'PARTANS IN HIS CREEL', 3, 32, 9999, 1, 4, 1, 127, NULL, '', 82, '8040  8888  8888  6887', 0, 1, 1, 0, 82);
INSERT INTO 'dance' VALUES (12530, '2005-08-29 22:00:00+00', '2019-08-12 08:20:50.617913+00', 'Orange County Welcome', 'ORANGE COUNTY WELCOME', 1, 32, 9999, 5, 2, NULL, 3308, '2003-01-01', 'Devised in 2003 to commemorate the 20th anniversary of the Orange County Branch.', 100, '88  88  88  88', 0, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (5060, '1997-09-10 22:00:00+00', '2019-02-22 13:21:21.853683+00', 'Old Man of Hoy, The', 'OLD MAN OF HOY', 3, 40, 9999, 1, 100, 2, 108, '1975-02-02', 'The instructions say 3c & 4c "start on the wrong side of the dance", and do not mention one or two chords.  

The tune is referenced as "Kerr''s Second Collection of Merry Melodies for the Violin No 157 page 18"

', 95, '8888  8888  4444  12 12 12 12  8008', 0, 1, 1, 1, 95);
INSERT INTO 'dance' VALUES (8069, '1997-12-03 23:00:00+00', '2019-09-26 21:45:56.96953+00', 'Ox, The', 'OX', 2, 32, 9999, 1, 2, NULL, 1395, '1992-01-01', '', 69, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (11639, '2004-01-14 23:00:00+00', '2014-04-30 23:24:05.202787+00', 'Partnerships', 'PARTNERSHIPS', 1, 32, 9999, 3, 5, 16, 3415, NULL, 'Devised to celebrate both the 50th anniversary of Croydon & District Branch and the eight strong partnership of the Tartan Jigsaw, an umbrella organisation formed to share resources and diaries of Scottish country dance groups within the area.', 70, '88888  44844  44844  84444', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (14544, '2012-08-24 20:48:19.769488+00', '2014-04-30 23:24:05.704736+00', 'Picnic Invitation', 'PICNIC INVITATION', 2, 32, NULL, 5, 2, NULL, 10647, '2012-01-01', '', 87, '84  48  88  88', 0, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (18468, '2018-07-25 22:40:08.504841+00', '2018-09-25 20:12:21.816658+00', 'Jean''s Strathspey', 'JEANS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 2886, NULL, '', 58, '440/008/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9540, '2000-09-14 22:00:00+00', '2015-10-16 16:27:51.662442+00', 'Peter and Madeleine Quince', 'PETER AND MADELEINE QUINCE', 1, 32, 9999, 1, 3, 42, 21, '1993-01-01', 'On the occasion of their wedding on 2nd June 1993', 62, '888  800  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (7234, '1997-09-17 22:00:00+00', '2016-02-27 09:43:10.965177+00', 'Wormbridge House', 'WORMBRIDGE HOUSE', 3, 32, 9999, 3, 5, 7, 175, NULL, '', 77, '86860  88888  82842  80888', 1, 1, 1, 0, 77);
INSERT INTO 'dance' VALUES (12691, '2006-02-16 23:00:00+00', '2022-09-19 09:49:54.014854+00', 'One Pair of Hands', 'ONE PAIR OF HANDS', 3, 32, 9999, 1, 4, 1, 146, NULL, '', 62, '4400  8800  8844  8888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (8071, '1998-07-09 22:00:00+00', '2022-10-14 21:40:04.35173+00', 'Peanut Butter and Jelly', 'PEANUT BUTTER AND JELLY', 2, 32, 9999, 2, 3, 17, 1265, '1993-01-01', '', 50, '440  440  800  888', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (5170, '1998-10-21 22:00:00+00', '2022-11-20 15:15:45.409699+00', 'Pasadena Prom, The', 'PASADENA PROM', 3, 32, 9999, 1, 4, 1, 2363, '1971-11-12', 'Devised for the wedding of Judi and Bob Buford.', 84, '4884  8888  8888  4844', 1, 1, 1, 1, 84);
INSERT INTO 'dance' VALUES (10428, '2003-01-30 23:00:00+00', '2023-02-08 15:29:42.796383+00', 'Pensioner''s Reel, The', 'PENSIONERS REEL', 1, 32, 9999, 1, 3, 42, 2980, NULL, '', 44, '800  888  800  844', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (5239, '2001-09-13 22:00:00+00', '2019-08-20 20:50:07.565158+00', 'Petronella', 'PETRONELLA', 1, 32, 9999, 1, 2, 76, 9998, '1808-01-01', '##>>

The dance is named for the very old tune also known by various derivative names such as Petronelle. The tune has been memorably described by one well-known Scottish musician as more of a drumbeat than a tune.  



The exact origin of the name of the tune is unknown but it has been suggested that it refers to the sister of Eleanor of Aquitaine. Eleanor married Louis VII of France in 1137. According to some sources, Eleanor and Petronella accompanied the King on a Crusade and Petronella regularly led troops into battle while naked from the waist up.

##<<

', 43, '80  80  80  88', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (5207, '1998-09-29 22:00:00+00', '2018-01-22 10:33:16.936964+00', 'Peggy''s Love', 'PEGGYS LOVE', 3, 32, 9999, 1, 3, 42, 9998, '1816-01-01', 'Collected in Moray', 44, '808  822  840  880', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (5208, '1998-09-29 22:00:00+00', '2019-03-11 19:04:53.968211+00', 'Peggy''s Wedding', 'PEGGYS WEDDING', 2, 64, 9999, 1, 4, 1, 444, NULL, '', 70, '8888  8800  8880  8080  8080  8088  8444  8888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (5198, '1998-11-14 23:00:00+00', '2020-03-04 22:58:30.402378+00', 'Peat Fire Flame, The', 'PEAT FIRE FLAME', 1, 40, 9999, 1, 3, 42, 108, '1964-01-01', '', 45, '800/822/844/822/888', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (5204, '1998-09-29 22:00:00+00', '2021-04-25 12:58:36.345256+00', 'Peggy Dewar', 'PEGGY DEWAR', 1, 32, 9999, 1, 3, 42, 507, NULL, '', 50, '800  866  866  844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (5264, '1997-10-26 23:00:00+00', '2020-09-02 17:52:25.47381+00', 'Pink Roses', 'PINK ROSES', 1, 32, 9999, 1, 2, 76, 227, '1992-03-07', 'Level: intermediate/advanced.



Suitable recorded music: "Mason''s Apron (4 x 32) in "Memory Lane" no 2  ', 52, '80  88  88  80', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (9074, '2001-11-21 23:00:00+00', '2020-12-20 11:23:25.072112+00', 'Peggy''s Strathspey', 'PEGGYS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2626, NULL, '', 62, '888  888  844  880', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (13460, '2009-11-17 23:00:00+00', '2020-09-17 22:29:31.30897+00', 'Pipe Opener, The', 'PIPE OPENER', 2, 32, NULL, 3, 5, 16, 146, NULL, '', 55, '80004  80880  84000  88888', 0, 1, 0, 0, 55);
INSERT INTO 'dance' VALUES (5159, '2000-06-12 22:00:00+00', '2020-10-13 18:42:54.432539+00', 'Paper Nautilis, The', 'PAPER NAUTILIS', 3, 32, 9999, 1, 102, 11, 1192, NULL, '', 100, '8888/8888/8888/8888', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (8729, '1998-07-12 22:00:00+00', '2020-10-21 09:14:12.827586+00', 'Old Way of Killiecrankie, The', 'OLD WAY OF KILLIECRANKIE', 1, 48, 9999, 2, 3, 17, 9998, NULL, '', 44, '800  800  800  880  800  808', 0, 1, 0, 0, 44);
INSERT INTO 'dance' VALUES (5237, '1997-08-25 22:00:00+00', '2020-12-29 11:40:53.669002+00', 'Peterhead Lassies, The', 'PETERHEAD LASSIES', 2, 32, 9999, 1, 2, 76, 146, NULL, '', 52, '44  44  88  88', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (5243, '1998-11-14 23:00:00+00', '2020-12-14 09:48:21.977953+00', 'Phantom Piper, The', 'PHANTOM PIPER', 2, 32, 9999, 1, 100, 11, 313, NULL, '', 87, '8888  8668  8228  8888', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (5265, '1997-09-11 22:00:00+00', '2020-12-14 09:59:40.932507+00', 'Pinkie', 'PINKIE', 2, 32, 9999, 1, 3, 42, 1203, NULL, '', 59, '844  866  866  866', 0, 1, 0, 0, 79);
INSERT INTO 'dance' VALUES (9647, '2000-09-07 22:00:00+00', '2020-12-21 12:12:02.944699+00', 'Opera Reel', 'OPERA REEL', 1, 32, 9999, 8, 6, 9, 9998, NULL, '', 71, '844444  484444  888888  884444', 0, 1, 1, 0, 70);
INSERT INTO 'dance' VALUES (13589, '2010-08-08 22:00:00+00', '2020-12-26 09:54:06.449358+00', 'Peggy Spouse MBE', 'PEGGY SPOUSE MBE', 3, 32, NULL, 1, 3, 42, 515, NULL, '', 66, '660  888  888  888', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (13982, '2011-08-24 22:00:00+00', '2020-12-26 09:57:46.322105+00', 'Paula''s Pleasure', 'PAULAS PLEASURE', 3, 32, NULL, 2, 3, 17, 1331, '2003-01-01', 'This dance was named for Paula Jacobson, who teaches the SF Branch and has been instrumental in gathering people together to try out new dances, including this one.  ', 75, '800  888  888  808', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (5223, '2001-04-03 22:00:00+00', '2020-12-29 11:40:03.740998+00', 'Perthshire Highlanders', 'PERTHSHIRE HIGHLANDERS', 3, 32, 9999, 1, 3, 42, 263, '1790-01-01', 'This Society version of the dance can be traced back to William Campbell''s *11th Book of New and Favorite, Country Dances, & Strathspey Reels* published about 1790.', 34, '800  800  822  844', 0, 1, 0, 0, 45);
INSERT INTO 'dance' VALUES (11669, '2004-01-29 23:00:00+00', '2021-01-21 22:49:46.87524+00', 'Peerie, The', 'PEERIE', 1, 32, 9999, 1, 3, 42, 3422, NULL, '', 58, '660  888  888  800', 1, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (5236, '1998-07-08 22:00:00+00', '2021-04-18 20:11:45.019206+00', 'Peterhead Express, The', 'PETERHEAD EXPRESS', 2, 64, 9999, 1, 4, 11, 304, '1983-01-01', '', 89, '8888/8888/8888/8888/8888/0880/2882/8888', 0, 1, 0, 1, 87);
INSERT INTO 'dance' VALUES (9121, '2000-09-03 22:00:00+00', '2021-08-02 13:52:10.102179+00', 'Pinwheels', 'PINWHEELS', 1, 32, 9999, 1, 3, 42, 2245, '1999-01-01', '', 53, '880  808  888  804', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (9187, '2000-01-10 23:00:00+00', '2019-03-05 20:18:50.737774+00', 'Peggy and Arnold''s Strathspey', 'PEGGY AND ARNOLDS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 142, NULL, '', 75, '888  800  844  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (13928, '2011-08-22 22:00:00+00', '2018-04-12 11:00:20.298893+00', 'To Have and To Hold', 'TO HAVE AND TO HOLD', 2, 32, NULL, 1, 3, 42, 64, '2005-07-01', 'Devised by Irene van Maarseveen, Pretoria, July 2005.



In celebration of the marriage of Ryan Nelson and Malindi Shäfer. 1 October 2005.



"... to have and to hold from his day forward.  ... to love and to cherish ..."', 47, '880/840/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12099, '2005-03-16 23:00:00+00', '2018-04-15 10:33:06.77449+00', 'Six Belles of Bon Accord', 'SIX BELLES OF BON ACCORD', 3, 32, 9999, 8, 6, 39, 1047, '2003-01-01', 'To nobody''s surprise, this is a 6-couple version of <<ddd:The Belle of Bon Accord>>.', 68, '848484/808080/888888/808080', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9641, '2000-09-05 22:00:00+00', '2014-04-30 23:24:06.110854+00', 'Post Chaise, The', 'POST CHAISE', 2, 32, 9999, 1, 4, 1, 146, '2000-01-01', 'For Pauline Farrar and Cynthia Wheatley who deserve long service medals for supporting the Ilkley class.', 56, '4440  4440  8080  8888', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (5384, '1998-10-04 22:00:00+00', '2014-04-30 23:24:06.343801+00', 'Provost Wynd, The', 'PROVOST WYND', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 44, '888  440  800  844', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (18700, '2018-10-02 22:15:10.273585+00', '2018-10-02 22:20:48.438433+00', 'Carousel Canter', 'CAROUSEL CANTER', 3, 88, NULL, 4, 4, NULL, 2766, '2012-01-01', 'I wrote this dance to emulate the feel of a merry-go-round (carousel).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8097, '2001-11-20 23:00:00+00', '2019-02-08 17:41:09.904092+00', 'President''s Dilemma, The', 'PRESIDENTS DILEMMA', 2, 32, 9999, 1, 4, 1, 550, '1996-01-01', '', 87, '8888  8080  8888  8888', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (11453, '2003-09-22 22:00:00+00', '2018-10-02 22:22:10.369579+00', 'But Carlyn, Who''s Counting?', 'BUT CARLYN WHOS COUNTING', 1, 32, 9999, 4, 5, 35, 2766, '2002-03-01', 'This dance is in honor of Carlyn''s "special" birthday March 8, 2002.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18702, '2018-10-03 00:25:18.759293+00', '2018-10-03 00:25:18.759293+00', 'Cat Play', 'CAT PLAY', 1, 32, NULL, 1, 3, 42, 2766, '2015-01-01', 'https://suedan.com/dances/instructions/catnipmice.html', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5376, '1998-11-07 23:00:00+00', '2018-04-03 00:08:11.307434+00', 'Princess Royal, The', 'PRINCESS ROYAL', 1, 28, 9999, 1, 3, 42, 9998, NULL, '', 54, '800  888  844  444', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (10166, '2002-04-24 22:00:00+00', '2018-01-27 14:23:38.430023+00', 'Ramadan-ce', 'RAMADANCE', 1, 32, 9999, 1, 3, 42, 108, '2000-01-01', '', 56, '888  800  844  888', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (5260, '1998-11-14 23:00:00+00', '2022-01-29 14:21:02.933007+00', 'Pines Of Pitlochry, The', 'PINES OF PITLOCHRY', 2, 48, 9999, 1, 3, 42, 696, NULL, '', 62, '800  844  888  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (9640, '2000-09-05 22:00:00+00', '2022-08-13 11:13:12.292983+00', 'Pele Tower, The', 'PELE TOWER', 2, 32, 9999, 1, 4, 1, 146, '2000-01-01', 'For Lis Thomas and the Castlemaine dancers', 50, '8400  8880  8800  8004', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (5219, '1998-07-12 22:00:00+00', '2022-11-20 14:29:12.280036+00', 'Periwig, The', 'PERIWIG', 1, 48, 9999, 1, 4, 1, 9998, NULL, 'The notes say this dance was "collected by Miss Milligan and given to Bill Clement."', 47, '8440  8004  8000  8220  8002  8888', 1, 1, 0, 0, 46);
INSERT INTO 'dance' VALUES (5366, '2000-09-06 22:00:00+00', '2022-11-20 14:29:45.225659+00', 'Prince Rupert''s Fancy', 'PRINCE RUPERTS FANCY', 3, 32, 9999, 2, 3, 17, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Frances Mary Gordon of Aberdeen, who has a King Charles Spaniel called "Rupert".', 75, '800  888  844  888', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (18728, '2018-10-04 07:47:31.912435+00', '2018-10-04 07:47:31.912435+00', 'Day of the Dead', 'DAY OF THE DEAD', 3, 32, NULL, 1, 4, NULL, 2766, '2014-10-01', 'This dance was written during a Halloween party at Fermilab.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5347, '1998-09-29 22:00:00+00', '2020-05-15 10:28:55.305108+00', 'Pretty Polly', 'PRETTY POLLY', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 48, '440/860/844/888', 1, 1, 1, 1, 64);
INSERT INTO 'dance' VALUES (12454, '2005-06-19 22:00:00+00', '2020-06-28 08:28:37.458667+00', 'Preston Mill', 'PRESTON MILL', 1, 32, 9999, 3, 5, 7, 2889, '2002-01-01', '', 67, '44044  84804  86866  86866', 1, 1, 1, 1, 67);
INSERT INTO 'dance' VALUES (5327, '1997-10-26 23:00:00+00', '2020-09-02 18:01:08.621557+00', 'Portree Harbour', 'PORTREE HARBOUR', 1, 32, 9999, 1, 2, 76, 227, '1987-11-01', 'Level: intermediate.', 64, '84  88  88  88', 0, 0, 0, 0, 93);
INSERT INTO 'dance' VALUES (13469, '2009-11-17 23:00:00+00', '2020-09-18 08:20:54.443606+00', 'Pleasure is Mine, The', 'PLEASURE IS MINE', 3, 32, NULL, 1, 2, 76, 146, NULL, 'For Kathie Dosell - an enthusiastic convert to Scottish dancing.', 56, '88  66  44  88', 0, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (14274, '2011-10-15 22:00:00+00', '2020-09-27 08:24:46.227368+00', 'Piper''s Knot, The', 'PIPERS KNOT', 3, 32, NULL, 1, 3, 42, 1445, NULL, 'For our friends Sjoerd and Sophie on their wedding.  Well may their knot be tied!', 50, '800  848  888  804', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (13983, '2011-08-24 22:00:00+00', '2020-10-27 09:44:09.242663+00', 'Pleasure of Her Company, The', 'PLEASURE OF HER COMPANY', 3, 32, NULL, 1, 3, 42, 1331, NULL, 'Crib derived from this dance taught in class.  Eric.', 59, '800  888  866  888', 0, 1, 1, 0, 79);
INSERT INTO 'dance' VALUES (5200, '1998-11-14 23:00:00+00', '2020-12-14 09:40:29.171736+00', 'Peerie, The', 'PEERIE', 2, 32, 9999, 1, 4, 1, 154, NULL, '', 62, '8600  8884  8000  8444', 0, 1, 0, 0, 54);
INSERT INTO 'dance' VALUES (5320, '1997-09-11 22:00:00+00', '2020-12-15 19:32:13.313879+00', 'Porchester Hall', 'PORCHESTER HALL', 3, 32, 9999, 1, 3, 42, 1205, NULL, '', 53, '880  888  833  833', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (5351, '1998-09-29 22:00:00+00', '2020-12-15 19:44:41.190705+00', 'Priest and his Books, The', 'PRIEST AND HIS BOOKS', 2, 24, 9999, 1, 3, 42, 339, '1749-01-01', '', 33, '404  808 800', 1, 1, 1, 1, 44);
INSERT INTO 'dance' VALUES (8132, '1998-04-24 22:00:00+00', '2020-12-19 14:23:09.872347+00', 'Prelim Hornpipe, The', 'PRELIM HORNPIPE', 1, 32, 9999, 1, 2, 76, 1445, '1994-01-01', '', 56, '66  66  84  88', 0, 1, 0, 0, 81);
INSERT INTO 'dance' VALUES (11885, '2004-11-01 23:00:00+00', '2020-12-25 12:25:02.2791+00', 'Rad in Rechberg', 'RAD IN RECHBERG', 4, 128, 2, 4, 4, 1, 1445, NULL, '', 75, '8080  0808  8888  8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13129, '2006-12-05 23:00:00+00', '2021-01-01 19:56:38.987035+00', 'Pawling in May', 'PAWLING IN MAY', 3, 32, 9999, 1, 4, 2, 104, NULL, '', 81, '8008  8448  8888  8888', 0, 1, 0, 0, 81);
INSERT INTO 'dance' VALUES (7490, '1999-01-03 23:00:00+00', '2021-03-26 22:42:09.391567+00', 'Piper''s Leg, The', 'PIPERS LEG', 2, 32, 9999, 3, 5, 7, 480, '1977-01-01', '', 72, '80800  84884  84844  88888', 0, 1, 0, 0, 72);
INSERT INTO 'dance' VALUES (9764, '2002-04-08 22:00:00+00', '2021-02-20 21:01:41.596213+00', 'Plum Tree Jig', 'PLUM TREE JIG', 2, 32, 9999, 3, 5, 7, 104, '1995-03-01', 'Devised for Tom and Pauline Smith, with thanks for many a happy evening at Plum Tree Cottage.', 70, '80800  88888  88888  80800', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (7245, '2002-12-08 23:00:00+00', '2021-03-28 13:46:53.644071+00', 'Ye''re welcome, Charly Stuart', 'YERE WELCOME CHARLY STUART', 1, 32, 9999, 1, 3, 42, 339, '1749-01-01', '', 47, '440  880  844  866', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (7242, '1998-09-29 22:00:00+00', '2021-03-28 13:56:33.982445+00', 'Ye''ll Aye be Welcome Back Again', 'YELL AYE BE WELCOME BACK AGAIN', 3, 32, 9999, 1, 3, 42, 339, '1749-01-01', '', 44, '880  800  822  866', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (5326, '1998-09-29 22:00:00+00', '2021-04-25 08:49:13.947513+00', 'Portnacraig', 'PORTNACRAIG', 1, 32, 9999, 1, 3, 42, 463, '1988-01-01', '', 53, '822  888  844  844', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (5358, '1998-09-30 22:00:00+00', '2021-04-25 08:38:57.771976+00', 'Prince Edward', 'PRINCE EDWARD', 1, 40, 9999, 1, 3, 42, 9998, NULL, '', 37, '840  840  800  880  822', 0, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (5282, '1997-09-11 22:00:00+00', '2021-04-25 10:04:19.94469+00', 'Piper, The', 'PIPER', 2, 32, 9999, 1, 3, 42, 976, '1740-01-01', '', 34, '880  800  822  800', 1, 1, 0, 1, 45);
INSERT INTO 'dance' VALUES (7239, '1997-08-24 22:00:00+00', '2021-11-27 17:24:37.742997+00', 'Yan, Tan, Tethera', 'YAN TAN TETHERA', 2, 32, 9999, 1, 3, 42, 175, '1991-01-01', 'For Dennis and Rhoda Park, the Westmorland farmers who still count their sheep ''Yan, Tan, Tethera ...''





On 13th may 2019 Robb Quint posted the following e-mail message on "Strathspey" about this dance:



Many thanks to Sue Ronald of Edgewater, New Jersey, and Quorn, Leicestershire, for calling my attention to Derek Haynes''s jig Yan, Tan, Tethera, which she was at that moment preparing to teach.  Sue thoughtfully did so knowing of my interest in Celtic languages.   



Yan, Tan, Tethera, again also an SCD jig, is a remnant of the Brythonic which was spoken across the majority of Britain, including Scotland south to the Firths of Clyde and Forth, two millennia ago, and it means "one, two, three."  Despite linguistic assault from from Anglic Northumbrian as well as Viking languages in the north of Britain and to some extent from Irish-import Gaelic as well as from Saxon in the south, Brythonic lived on in isolated locations in northern England and southern Scotland as Cumbric, though barely by then, into the 13th century, thereby likely the persistent existence of yan, tan, tethera, et al.  (In the extremity of England''s West Country Celtic Cornish held on until c. 1800.)  Brythonic was likely fairly similar to the Pictish of central and northern Scotland that was gradually but ultimately overrun linguistically by Gaelic a millennium ago.  What is left today of Brythonic is modern Welsh, spoken mostly in northern Wales, and Breton, the descendant language of the southern-Britain Celts who crossed the English Channel, bringing Celtic back to the European continent from which it had essentially disappeared, establishing themselves in French Brittany (thus that name for it) as they emigrated from an England being overrun by Saxon settlers from today''s Netherlands and northwestern Germany.   



With Brythonic gone and replaced in northern England and southern Scotland by Germanic languages developing into English and Scots, shepherds though retained the Celtic numbers from one through twenty for the specific purpose of the important task of twice daily counting sheep.  It was a sing-song-y (cf. today''s children''s alphabet song) specialty counting system for this particular use only, and it lasted into fairly modern times, enough so that linguists have been able to collect many different variations of it, which change slightly from one dale (valley) to another.  Though they certainly exist in modern Welsh and Breton, numbers beyond twenty long ago disappeared from the shepherds'' counting vocabulary.  Reaching twenty the shepherd would simply move a finger down a notch on a staff or place another pebble in a pocket and start again with number one.     



Derek Haynes (1932-2005) was a prolific SCD deviser from Lancashire right in the midst of yan-tan-tethera territory.  



The Scottish-Borders variant of this (and remember that this is neither Gaelic nor Scots but rather a remnant of extinct Brythonic) runs as follows from one to twenty:  yan, tyan, tethera, methera, pimp, sethera, lethera, hovera, dovera, dik, yanadik (1+10), tyanadik (2+10), tetheradik (3+10), metheradik (4+10), bumfitt, yanabumfitt (1+15), tyanabumfitt (2+15), tetherabumfitt (3+15), metherabumfitt (4+15), giggot.  One can well imagine a shepherd reciting this for memory in a sing-song-y manner while counting sheep.   



Many centuries removed from a common Brythonic ancestor with the above, modern Welsh''s 1-20 are as follows:  un, dau, tri, pedwar, pump, chwech, saith, wyth, naw, deg, un ar ddeg, deuddeg, tri ar ddeg, pedwar ar ddeg, pymtheg, un ar bymtheg (again the +15 counting), dau ar bymtheg, deunaw, pedwar ar bymtheg, ugain.   





', 47, '800/844/844/866', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (723, '1999-11-01 23:00:00+00', '2018-04-03 00:08:11.507456+00', 'Punch Bowl, The', 'PUNCH BOWL', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 31, '800  800  800  880', 1, 1, 1, 1, 41);
INSERT INTO 'dance' VALUES (14418, '2012-03-13 15:07:33.423563+00', '2018-03-20 20:19:13.897419+00', 'Railway 4 Meeting', 'RAILWAY 4 MEETING', 1, 40, 9999, 1, 2, NULL, 10612, '2011-01-01', '', 69, '88 /88 /88 /88/88', 0, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (5407, '1998-09-29 22:00:00+00', '2018-04-02 23:56:37.08832+00', 'Quarries'' Jig', 'QUARRIES JIG', 2, 32, 9999, 1, 3, 42, 361, NULL, '', 59, '800  888  888  866', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (5436, '1999-10-27 22:00:00+00', '2014-04-30 23:24:06.596665+00', 'Queen''s Welcome', 'QUEENS WELCOME', 1, 32, 9999, 1, 2, NULL, 9998, NULL, '', 60, '88  80  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (5450, '1998-11-10 23:00:00+00', '2018-04-03 00:08:11.807653+00', 'Rachael Rae', 'RACHAEL RAE', 1, 24, 9999, 1, 3, 42, 445, '1844-01-02', '', 50, '880  844  880', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (5440, '1997-11-27 23:00:00+00', '2018-11-27 02:02:17.447128+00', 'Quiet Achiever, The', 'QUIET ACHIEVER', 4, 32, 1, 1, 3, 42, 1214, '1994-03-01', '', 59, '844  844  866  888', 0, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (5430, '2001-12-16 23:00:00+00', '2019-02-04 13:34:57.409195+00', 'Queen''s Jubilee, The', 'QUEENS JUBILEE', 3, 40, 9999, 1, 4, 30, 5, NULL, 'Progression: after 1st time 2134; after second time 2341, and so on.', 67, '888+8  444  888  888  844', 1, 1, 1, 1, 67);
INSERT INTO 'dance' VALUES (9296, '2002-11-26 23:00:00+00', '2019-02-22 21:57:14.815487+00', 'Quaker, The', 'QUAKER', 3, 32, 9999, 2, 104, 4, 501, '1995-01-01', '', 75, '484  484  484  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (13466, '2009-11-17 23:00:00+00', '2014-04-30 23:24:06.933905+00', 'Rannoch Moor', 'RANNOCH MOOR', 3, 32, NULL, 3, 5, 16, 146, NULL, '', 40, '84400  80800  80080  80044', 0, 1, 1, 1, 40);
INSERT INTO 'dance' VALUES (11286, '2003-05-04 22:00:00+00', '2014-04-30 23:24:06.964535+00', 'Ratty''s Hornpipe', 'RATTYS HORNPIPE', 1, 32, 9999, 1, 3, 42, 2783, '2001-08-01', '', 50, '888  800  888  800', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (10773, '2002-09-25 22:00:00+00', '2018-04-03 00:08:12.133039+00', 'Raven''s Dance, The', 'RAVENS DANCE', 2, 32, 9999, 1, 3, 42, 175, NULL, '', 50, '880  888  880  800', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (13135, '2006-12-05 23:00:00+00', '2019-02-26 23:07:08.707637+00', 'Rachel''s Strathspey', 'RACHELS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 104, NULL, '', 84, '888/880/845/888', 0, 1, 1, 1, 84);
INSERT INTO 'dance' VALUES (10088, '2001-09-12 22:00:00+00', '2022-07-21 17:04:01.308924+00', 'Weakest Link, The', 'WEAKEST LINK', 3, 32, 9999, 1, 100, 14, 108, '2001-02-01', 'The dedication of the dance reads: for the <u>Weak<\u>end at Edzell, March 2001.



John Drewry wrote that dance in the month prior to the Edzell event.



Drewry specifies:  

»The dance may be done as a Strathspey, as a Reel, or as a Medley (a Strathspey followed by a Reel).  It involves almost continuous dancing and therefore should not be done too many times or it will expose those who are "the Weakest Link" stamina-wise.«



Note the progression: back at starting positions after twice through.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14658, '2013-01-05 11:38:47.922266+00', '2022-08-14 09:00:48.081701+00', 'Queensferry Welcome', 'QUEENSFERRY WELCOME', 1, 32, NULL, 5, 2, NULL, 10698, '2009-01-01', '', 87, '44  88  88  88', 0, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (11722, '2004-06-16 22:00:00+00', '2022-09-23 16:18:44.272789+00', 'Quaker Meeting, A', 'QUAKER MEETING', 2, 32, 9999, 5, 2, NULL, 550, '2004-01-01', 'This dance was devised for Michael Grimes and Vanessa Williams and presented to them during the barn dance to celebrate their wedding on the 5th of June 2004. They were married in Bourneville Quaker Meeting House, and had the barn dance in Tardebigge.', 100, '88  88  88  88', 1, 1, 0, 1, 100);
INSERT INTO 'dance' VALUES (14818, '2013-04-29 14:01:50.213032+00', '2022-08-16 20:42:40.051118+00', 'Rainbow of Saitama, The', 'RAINBOW OF SAITAMA', 2, 32, NULL, 1, 3, 42, 2780, '2010-04-01', 'Devised in April 2010 for the 10th Anniversary of Saitama Branch.', 62, '800/888/888/888', 1, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (16295, '2015-05-07 18:45:23.078584+00', '2023-01-24 17:11:08.296496+00', 'Catnip Mice', 'CATNIP MICE', 2, 32, NULL, 1, 2, 76, 2766, '2011-04-01', '', 43, '80/48/48/80', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9809, '2002-05-12 22:00:00+00', '2023-02-28 15:52:54.008611+00', 'Yksi Kaksi Kolme', 'YKSI KAKSI KOLME', 1, 40, 9999, 1, 3, 42, 2844, NULL, 'The title means "One Two Three" in Finnish.  

This dance was written for a girl from Finnland who danced one year in the Bielefeld Group.', 55, '800/844/888/844/888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (5462, '1998-09-29 22:00:00+00', '2016-11-15 16:09:08.021678+00', 'Rakes of Glasgow', 'RAKES OF GLASGOW', 3, 32, 9999, 1, 3, 42, 459, '1806-01-01', 'See <<http://ssa.nls.uk/film.cfm?fid=0313|here>> for a historic video from the 1950s (http://ssa.nls.uk/film.cfm?fid=0313)', 50, '880  800  880  888', 0, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (5499, '1997-09-12 22:00:00+00', '2014-04-30 23:24:07.098823+00', 'Red Nose Jig', 'RED NOSE JIG', 2, 40, 9999, 4, 4, 13, 1219, NULL, '', 60, '8080  0808  4444  4444  8888', 0, 1, 1, 0, 60);
INSERT INTO 'dance' VALUES (10570, '2002-05-12 22:00:00+00', '2020-12-24 10:17:58.31576+00', 'Reel of the Black Cocks', 'REEL OF THE BLACK COCKS', 1, 64, 9999, 107, 8, 3, 9998, NULL, 'Traditional Hebridean dance, arranged by Jennifer and John Kelly, directors of the Red Thistle Dancers.', 87, '4  8  8  8  4  8  8  8', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11105, '2002-12-05 23:00:00+00', '2020-04-24 20:42:03.48389+00', 'Quantock Hills', 'QUANTOCK HILLS', 4, 128, 10034, 4, 4, 13, 154, '2001-09-01', 'Dedicaed to our friends in the South Dorset Caledonian Society, who hold a weekend at Halsway Manor on Quantock Hills.', 87, '8484  8888  8484  8888', 1, 1, 1, 0, 21);
INSERT INTO 'dance' VALUES (12017, '2005-02-04 23:00:00+00', '2021-01-17 18:32:28.171707+00', 'Railway Reel, The', 'RAILWAY REEL', 1, 32, 9999, 1, 3, 42, 3345, '2003-01-01', '', 69, '888  888  888  844', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (5388, '1997-10-26 23:00:00+00', '2020-09-02 18:05:07.009899+00', 'Puffins, The', 'PUFFINS', 3, 32, 9999, 1, 2, 76, 227, '1990-10-17', 'Level: intermediate/advanced.



Suggested tune: any good strathsepy suitable for Highland Schottische.



(We were taught this dance in the Thistle Club class on 2 september 1989, well before the "devised on" date above)', 60, '44  88  88  88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (13471, '2009-11-17 23:00:00+00', '2020-09-18 08:23:10.593552+00', 'Rachel in Maryland', 'RACHEL IN MARYLAND', 2, 32, NULL, 1, 4, 1, 146, NULL, 'For Rachel Wilton, to remind her of "Argyll" weekends at Maryland College.', 44, '8004  8080  8400  8422', 0, 1, 0, 0, 43);
INSERT INTO 'dance' VALUES (14024, '2011-08-25 22:00:00+00', '2020-09-25 21:07:08.907743+00', 'Pugwash and Tatamagouche', 'PUGWASH AND TATAMAGOUCHE', 1, 32, NULL, 1, 3, 42, 401, NULL, '', 56, '884  822  844  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (5474, '1998-04-19 22:00:00+00', '2020-12-16 10:10:49.919222+00', 'Rare Bird, The', 'RARE BIRD', 3, 32, 9999, 1, 4, 30, 108, '1994-01-01', 'Non-standard starting position.', 81, '4444  8888  8888  4884', 1, 1, 1, 0, 81);
INSERT INTO 'dance' VALUES (9513, '2002-04-28 22:00:00+00', '2020-12-21 11:14:41.158069+00', 'Railway Coupling - Jim & Aline, The', 'RAILWAY COUPLING  JIM AND ALINE', 2, 32, 9999, 1, 3, 42, 2197, '2000-01-01', '', 69, '888  888  888  880', 0, 1, 0, 0, 91);
INSERT INTO 'dance' VALUES (10116, '2002-05-11 22:00:00+00', '2020-12-23 10:30:43.563459+00', 'Pretty Face', 'PRETTY FACE', 2, 40, 9999, 1, 3, 42, 2169, NULL, '', 42, '804  808  880  880  844', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (12692, '2006-02-16 23:00:00+00', '2020-12-25 12:49:20.977455+00', 'Quaker''s Daughter, The', 'QUAKERS DAUGHTER', 3, 32, 9999, 2, 3, 17, 146, NULL, '', 77, '844  444  888  888', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (11866, '2004-10-31 23:00:00+00', '2021-01-18 19:03:53.667441+00', 'Quiet Man, The', 'QUIET MAN', 1, 32, 9999, 1, 3, 42, 479, '2000-01-01', '', 50, '800  888  844  844', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (10388, '2002-03-11 23:00:00+00', '2021-02-09 12:20:56.680659+00', 'Pudding Mixer, The', 'PUDDING MIXER', 1, 40, 9999, 1, 4, 11, 3066, '2002-01-01', '', 72, '8888/8448/8448/8448/6006', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (9108, '2001-11-21 23:00:00+00', '2021-03-01 20:09:45.445656+00', 'Rabbie''s Reel', 'RABBIES REEL', 1, 32, 9999, 1, 4, 1, 2663, '1996-01-01', '', 53, '4444  4444  4444  8444', 0, 1, 0, 0, 53);
INSERT INTO 'dance' VALUES (5444, '2002-03-03 23:00:00+00', '2021-03-27 19:43:01.701731+00', 'Quincentenary Reel, The', 'QUINCENTENARY REEL', 1, 32, 9999, 1, 4, 2, 108, '1994-01-01', 'Devised: 1994

A dance to mark 500 years since the foundation of the University of Aberdeen by Bishop Elphinstone.

', 80, '8800  8888  8068  8888', 1, 1, 1, 0, 79);
INSERT INTO 'dance' VALUES (5410, '2002-04-19 22:00:00+00', '2021-04-24 19:33:15.510093+00', 'Queen Anne', 'QUEEN ANNE', 3, 48, 9999, 2, 3, 17, 546, '1977-01-01', '', 58, '402  402  888  808  840  848', 1, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (8075, '2003-01-30 23:00:00+00', '2014-04-30 23:24:07.12696+00', 'Redbud Reel, The', 'REDBUD REEL', 1, 32, 9999, 1, 4, 1, 1381, NULL, '', 56, '8888  8800  0088  8000', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (13897, '2011-08-22 22:00:00+00', '2018-04-03 07:33:50.580831+00', 'Bring Forrit the Tartan', 'BRING FORRIT THE TARTAN', 3, 32, NULL, 1, 3, 42, 44, '1991-06-01', 'Devised by lain Boyd and completed on Saturday, 8th June, 1991. Modified during the evening of Saturday, 15th June, 1991.  

Devised to celebrate Scotland''s national cloth: the tartan.  

"Bring Forrit The Tartan" is said to be the command given by General Sir Colin Campbell when he ordered the 93rd Regiment of Foot (the Sutherland Highlanders) to join the attack on the fort at Secundrabagh during the Relief of Lucknow in November, 1857.  

The portrait of James Moray of Abercairney (1705-1777), believed to be painted by Jeremiah Davison in about 1739, is a magnificent illustration of highland dress - particularly of the belted plaid - hence the choice of tune. The painting is owned by Major James Drummond Moray of Abercaimey and is illustrated in "A Short History Of The Scottish Dress" by R M D Grange, facing page 62, and "Tartans" by Christian Hesketh, page 49.', 56, '804/840/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5463, '1998-10-08 22:00:00+00', '2018-04-03 00:08:12.007839+00', 'Rakish Highlandman, The', 'RAKISH HIGHLANDMAN', 2, 40, 9999, 1, 3, 42, 432, '1816-01-01', '', 52, '888  800  880  822  888', 0, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (15421, '2014-04-14 21:24:28.614186+00', '2014-09-04 09:16:07.026581+00', 'Red Flower', 'RED FLOWER', 1, 32, NULL, 2, 3, 17, 10947, '2010-08-01', 'Written for Pat Houghton by the units 2 and 3 candidates, Summer School 2010.', 77, '864  888  080  888', 1, 1, 1, 0, 77);
INSERT INTO 'dance' VALUES (5532, '1998-09-29 22:00:00+00', '2014-04-30 23:24:07.349726+00', 'Reel of Tulloch', 'REEL OF TULLOCH', 1, 128, 9999, 1, 106, NULL, 9998, NULL, '', 52, '44  44  88  88', 1, 1, 1, 1, 18);
INSERT INTO 'dance' VALUES (5460, '2000-07-02 22:00:00+00', '2016-04-18 23:22:07.595401+00', 'Rakes Of Auld Reekie', 'RAKES OF AULD REEKIE', 3, 32, 9999, 1, 2, NULL, 313, '1980-01-01', 'Auld Reekie (= Old Smokey) is a colloquial name for Edinburgh.



"Previously published in Scottish Dance Archives. It is given here with the original ending which I have always preferred."', 58, '80  88  88  86', 1, 1, 0, 1, 84);
INSERT INTO 'dance' VALUES (18283, '2018-04-17 10:36:58.513474+00', '2018-04-18 05:39:44.171674+00', 'Star Shines Upon the Hour of Our Meeting, A', 'STAR SHINES UPON THE HOUR OF OUR MEETING', 3, 32, NULL, 1, 3, NULL, 11487, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8956, '2001-06-05 22:00:00+00', '2017-03-19 11:32:27.532566+00', 'Reel of the Puffins', 'REEL OF THE PUFFINS', 1, 32, 9999, 1, 100, 2, 101, '1998-01-01', 'For the wedding of Katie Fallas and Iain Roxburgh in August 1998. Katie and Iain met while dancing and watching puffins in the Faroes with Dunedin Dancers.', 81, '8008  8888  8448  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (5522, '1998-09-29 22:00:00+00', '2017-07-07 14:25:23.142766+00', 'Reel of Mey, The', 'REEL OF MEY', 2, 48, 9999, 1, 3, 42, 470, NULL, '', 46, '840  804  800  844  844  888', 1, 1, 1, 1, 61);
INSERT INTO 'dance' VALUES (8575, '1998-10-20 22:00:00+00', '2019-08-10 21:53:11.630813+00', 'Remaking the Circle', 'REMAKING THE CIRCLE', 1, 40, 9999, 1, 4, 11, 214, '1993-01-01', '', 85, '8008  8888  8888  8888  8448', 0, 1, 0, 0, 85);
INSERT INTO 'dance' VALUES (8539, '1998-02-08 23:00:00+00', '2020-09-07 08:48:07.256271+00', 'Saint Fergus Interchange', 'SAINT FERGUS INTERCHANGE', 1, 32, 9999, 4, 4, 4, 2083, NULL, '', 87, '8484  4848  8888  8888', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (13467, '2009-11-17 23:00:00+00', '2020-09-18 08:09:06.38752+00', 'Reel On', 'REEL ON', 1, 32, 9999, 1, 4, 1, 146, NULL, 'For Di Rooney and Roger Gurtner who spend much time travelling to different venues to enjoy their dancing.  The tune was composed to mark a special birthday for Roger.', 56, '8880  8220  8880  8004', 0, 1, 0, 0, 56);
INSERT INTO 'dance' VALUES (5520, '2002-04-08 22:00:00+00', '2022-11-12 19:22:08.694192+00', 'Reel of Glamis, The', 'REEL OF GLAMIS', 3, 32, 9999, 1, 2, 76, 198, '1748-01-01', '', 39, '62  62  44  84', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (5441, '1998-09-29 22:00:00+00', '2022-09-15 12:25:00.485534+00', 'Quiet and Snug', 'QUIET AND SNUG', 3, 32, 9999, 1, 2, 76, 453, '1749-01-01', '', 47, '82  82  80  88', 1, 1, 0, 1, 68);
INSERT INTO 'dance' VALUES (11723, '2004-06-16 22:00:00+00', '2023-01-18 16:48:47.756058+00', 'Quaker Mixup, A', 'QUAKER MIXUP', 2, 32, 9999, 6, 3, 4, 550, '2004-01-01', '', 100, '888  888  888  888', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (5519, '2001-05-20 22:00:00+00', '2020-12-16 10:20:49.056798+00', 'Reel of Five, The', 'REEL OF FIVE', 4, 64, 5, 4, 55, 3, 9998, NULL, '', 80, '88080  88888  80808  88888  repeat', 0, 1, 0, 0, 40);
INSERT INTO 'dance' VALUES (5543, '1998-09-29 22:00:00+00', '2020-12-16 10:22:36.207607+00', 'Reivers, The', 'REIVERS', 1, 32, 9999, 1, 2, 76, 475, NULL, '', 56, '44  66  88  88', 0, 1, 0, 0, 81);
INSERT INTO 'dance' VALUES (13274, '2007-04-01 22:00:00+00', '2021-01-03 13:54:50.116448+00', 'Ribble Valley Ramblers, The', 'RIBBLE VALLEY RAMBLERS', 2, 32, 9999, 1, 3, 42, 316, NULL, '', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (9102, '2002-02-27 23:00:00+00', '2021-03-01 20:12:24.285655+00', 'Reel for Jeannie, A', 'REEL FOR JEANNIE', 1, 32, 9999, 1, 4, 1, 2663, '1996-01-01', '', 81, '8888  8000  8888  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (5496, '2002-03-02 23:00:00+00', '2021-04-24 18:42:55.170554+00', 'Red Ghillies', 'RED GHILLIES', 1, 40, 9999, 1, 4, 1, 355, NULL, '', 55, '8000  8000  8440  8448  8888', 1, 1, 1, 1, 55);
INSERT INTO 'dance' VALUES (5521, '1998-04-19 22:00:00+00', '2021-03-27 19:41:19.392719+00', 'Reel of Happiness, The', 'REEL OF HAPPINESS', 1, 32, 9999, 1, 3, 42, 227, '1989-01-01', 'Level: very advanced



Devised for teaching reels in various forms, and their linking.', 56, '888  880  800  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (7293, '2006-03-07 23:00:00+00', '2021-03-28 12:46:41.324354+00', 'Renaissance', 'RENAISSANCE', 2, 32, NULL, 1, 4, 1, 370, NULL, '', 44, '8008  8448  8888  8000', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (5547, '2000-04-18 22:00:00+00', '2021-04-24 10:17:21.398844+00', 'Rendezvous, The', 'RENDEZVOUS', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 59, '800  888  888  866', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (5493, '2001-05-03 22:00:00+00', '2021-04-24 18:54:06.422581+00', 'Red Balloon, The', 'RED BALLOON', 2, 40, 9999, 1, 4, 1, 719, NULL, '', 55, '8000  8880  8000  8088  8444', 1, 1, 0, 1, 52);
INSERT INTO 'dance' VALUES (10013, '2002-02-27 23:00:00+00', '2019-02-07 22:54:08.925666+00', 'Ring, The', 'RING', 1, 32, 9999, 1, 4, 1, 1346, '2001-01-01', 'The ring is a name for the mile wide accelerator at Fermilab in Batavia, IL, home of the" Silk and Thistle " class of the Chicago Branch of the RSCDS', 91, '8444/8888/8888/8888', 1, 1, 1, 0, 90);
INSERT INTO 'dance' VALUES (5623, '1998-12-17 23:00:00+00', '2014-11-11 20:13:20.052462+00', 'Rob Roy', 'ROB ROY', 1, 32, 9999, 1, 4, 1, 129, NULL, '', 81, '8040  8884  8888  8888', 1, 1, 1, 0, 81);
INSERT INTO 'dance' VALUES (11288, '2003-05-04 22:00:00+00', '2014-04-30 23:24:07.858065+00', 'Robert''s Reel', 'ROBERTS REEL', 3, 32, 9999, 1, 3, 42, 3343, '2001-01-01', 'For Robert Sargent', 56, '800  888  844  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (5641, '1998-11-10 23:00:00+00', '2014-04-30 23:24:07.88675+00', 'Rock and the wee pickle tow, The', 'ROCK AND THE WEE PICKLE TOW', 2, 32, 9999, 1, 2, NULL, 9998, NULL, '', 52, '80  88  80  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (5713, '2002-02-27 23:00:00+00', '2019-03-11 11:05:51.970199+00', 'Round Reel of Eight', 'ROUND REEL OF EIGHT', 1, 88, 9999, 4, 4, 3, 9998, NULL, '', 63, '4444  4444  8888  8888  8080  8080  0808  0808  4444  4444  8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14535, '2012-08-15 09:05:38.788993+00', '2016-08-16 14:54:30.376501+00', 'Rodney''s Rant', 'RODNEYS RANT', 2, 32, NULL, 1, 3, 42, 104, NULL, '»Devised at the request of the Saltire Scottish Country Dance club for Rodney Mount''s 80th birthday.«



Note (additional to the book and the Manual) collected by Helen Russell from staff teaching The Diamond Jubilee book at Summer School 2012. 



1 - 16    2nd, 1st and 3rd couples dance two consecutive half rights and lefts on the diagonal.



', 50, '800  844  888  844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (11919, '2004-11-24 23:00:00+00', '2016-01-22 08:04:39.696091+00', 'Robbie over the Waves', 'ROBBIE OVER THE WAVES', 1, 32, 9999, 1, 3, 42, 2419, NULL, '', 47, '880  822  888  800', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (10457, '2002-11-24 23:00:00+00', '2018-04-03 00:08:16.869481+00', 'S''il Vous Plait', 'SIL VOUS PLAIT', 1, 32, 9999, 1, 3, 42, 2140, '2002-01-01', '', 56, '880  888  800  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (1458, '1997-04-03 22:00:00+00', '2018-04-02 23:56:33.656858+00', 'Cry Of The Falcon', 'CRY OF THE FALCON', 1, 32, 9999, 1, 3, 42, 352, '1993-08-08', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10921, '2002-11-12 23:00:00+00', '2014-04-30 23:24:08.99392+00', 'Saint Margaret''s Strathspey', 'SAINT MARGARETS STRATHSPEY', 3, 32, 9999, 4, 4, 13, 2673, NULL, '', 94, '8888  4444  8888  8888', 1, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (9944, '2001-06-10 22:00:00+00', '2020-02-08 19:47:55.716641+00', 'Rose Acre', 'ROSE ACRE', 3, 32, 9999, 1, 100, 2, 861, NULL, '', 81, '8888  8008  8888  8448', 0, 1, 0, 0, 81);
INSERT INTO 'dance' VALUES (11397, '2003-07-06 22:00:00+00', '2020-02-18 22:14:34.745979+00', 'Rockside', 'ROCKSIDE', 2, 96, 9999, 4, 4, 3, 146, NULL, '', 58, '4444  4444  4444  4444  8080  8080  0808  0808  4444  4444  8888  8888', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (5612, '1998-09-29 22:00:00+00', '2020-12-17 22:02:42.300177+00', 'Road To Mallaig, The', 'ROAD TO MALLAIG', 3, 32, 9999, 1, 4, 1, 500, NULL, '', 78, '2882  6446  8888  4888', 0, 1, 0, 0, 78);
INSERT INTO 'dance' VALUES (5621, '2002-01-08 23:00:00+00', '2020-08-07 09:02:05.86023+00', 'Roaring Jelly', 'ROARING JELLY', 2, 32, 9999, 1, 3, 42, 129, '1966-01-01', '', 47, '800  888  800  866', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (14075, '2011-08-25 22:00:00+00', '2020-09-26 07:05:27.117944+00', 'Road to Washington (CD), The', 'ROAD TO WASHINGTON CD', 2, 32, NULL, 1, 3, 42, 10435, NULL, '', 59, '820  844  888  888', 0, 1, 0, 0, 79);
INSERT INTO 'dance' VALUES (5609, '1998-07-09 22:00:00+00', '2020-12-16 10:34:30.833364+00', 'Road To Dundee, The', 'ROAD TO DUNDEE', 3, 48, 9999, 2, 3, 17, 82, NULL, '', 50, '888  822  844  844  844  822', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (5616, '1998-11-16 23:00:00+00', '2020-12-17 22:08:51.738818+00', 'Road To The Isles, The', 'ROAD TO THE ISLES', 3, 32, 9999, 1, 4, 1, 87, '1973-01-01', '', 75, '8880  8444  8444  8888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (10774, '2002-09-25 22:00:00+00', '2020-12-24 18:00:41.906101+00', 'Ring of Brodgar, The', 'RING OF BRODGAR', 3, 32, 9999, 4, 4, 46, 175, NULL, 'The Ring of Brodgar is an ancient Stone Circle situated on a narrow strip of land between the salt water Loch of Stenness and the fresh water Loch of Harray, on Orkney', 63, '8404  8808  8000  8888', 0, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (14076, '2011-08-25 22:00:00+00', '2021-01-01 20:10:20.725275+00', 'Rita''s Ramble', 'RITAS RAMBLE', 3, 32, NULL, 2, 104, 4, 10437, NULL, '', 83, '484  484  888  888', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (12742, '2006-05-11 22:00:00+00', '2021-01-09 21:31:16.184013+00', 'Road to Achiltibuie, The', 'ROAD TO ACHILTIBUIE', 1, 40, 9999, 1, 3, 42, 1445, '2006-01-01', '', 45, '800  888  800  844  844', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (12693, '2006-02-16 23:00:00+00', '2021-01-10 21:20:44.717291+00', 'Right Way Up, The', 'RIGHT WAY UP', 2, 32, 9999, 1, 3, 42, 146, NULL, '', 53, '840  880  888  844', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (5671, '1998-11-14 23:00:00+00', '2021-10-11 22:32:07.637227+00', 'Rose of the North, The', 'ROSE OF THE NORTH', 3, 32, 9999, 1, 3, 42, 146, '1986-01-01', '', 56, '400  12 12 12  844  844', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (8140, '2002-04-08 22:00:00+00', '2021-03-21 20:00:01.133972+00', 'Safe Journey Hame, A', 'SAFE JOURNEY HAME', 2, 40, 9999, 1, 3, 42, 190, NULL, '', 60, '880  888  088  880  888', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (9760, '2002-04-02 22:00:00+00', '2021-02-20 21:00:50.92318+00', 'Riviera Reel, The', 'RIVIERA REEL', 1, 32, 9999, 1, 3, 42, 104, '1995-08-01', 'Devised for all the friends I have made during my visits to the South of France.', 50, '844  822  888  822', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (13613, '2010-10-07 22:00:00+00', '2021-02-23 18:08:28.835348+00', 'Rose of Dunure', 'ROSE OF DUNURE', 3, 32, NULL, 2, 3, 18, 3325, '2007-04-21', 'For Rose Waddell''s 70th birthday.', 55, '822/888/820/888', 1, 1, 1, 0, 72);
INSERT INTO 'dance' VALUES (14477, '2012-06-15 04:46:27.321533+00', '2021-03-27 18:57:54.107223+00', 'Rolling Dancers', 'ROLLING DANCERS', 2, 32, NULL, 1, 3, 42, 3661, '2007-01-01', 'Devised for wheelchair dancers (see the second URL) .  Video on www.bstk.hu/rolling



On 2009-06-24 a group of fully novice wheelchair dancers learnt this dance in just one day. ', 50, '844  888  880  800', 1, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (5658, '1998-11-07 23:00:00+00', '2021-03-27 19:38:45.434818+00', 'Rory o''More', 'RORY OMORE', 2, 32, 9999, 1, 2, 76, 9998, NULL, 'Collected locally. The weird spelling is because of the RSCDS Combined Book 1–6.', 60, '88/88/80/88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (5795, '1998-05-08 22:00:00+00', '2021-04-20 00:10:37.953087+00', 'Sailor''s Guide, The', 'SAILORS GUIDE', 1, 32, 9999, 1, 3, 42, 352, NULL, '', 47, '844  822  844  844', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (5624, '1998-09-29 22:00:00+00', '2021-04-22 20:44:26.31702+00', 'Rob Roy MacGregor', 'ROB ROY MACGREGOR', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 47, '880  880  822  880', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (11703, '2004-02-27 23:00:00+00', '2022-12-22 18:30:46.671739+00', 'Rose Jacob''s Reel', 'ROSE JACOBS REEL', 1, 32, 9999, 1, 3, 42, 725, NULL, '', 44, '800  880  888  800', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (5591, '1998-09-29 22:00:00+00', '2021-04-24 09:22:45.239056+00', 'River Cree, The', 'RIVER CREE', 2, 32, 9999, 1, 2, 76, 9998, NULL, 'See <<http://ssa.nls.uk/film.cfm?fid=0850|here>> for a historic video including step demonstrations.', 52, '44  88  80  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (18494, '2018-08-07 20:48:23.896559+00', '2021-04-24 22:42:59.946053+00', 'Montréal Diamond Anniversary Reel', 'MONTREAL DIAMOND ANNIVERSARY REEL', 1, 40, NULL, 8, 6, 12, 10568, '2018-03-01', 'Written to celebrate the Montréal RSCDS 60th Anniversary, March 2018.', 78, '800008/888888/888888/806608/888888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5618, '2002-05-04 22:00:00+00', '2021-06-12 10:58:59.398335+00', 'Road To Wigan Pier, The', 'ROAD TO WIGAN PIER', 3, 32, 9999, 1, 4, 1, 3125, NULL, 'Devised for the 18th Anniversary of The Thistle Society, Wigan.', 91, '8888  8888  8444  8888', 1, 1, 0, 1, 90);
INSERT INTO 'dance' VALUES (5807, '1997-11-18 23:00:00+00', '2021-05-01 20:31:07.414629+00', 'St Andrew''s Nicht', 'SAINT ANDREWS NICHT', 2, 48, 9999, 5, 2, 76, 9998, NULL, '', 86, '88  77  77  44  88  88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5697, '1997-04-03 22:00:00+00', '2014-04-30 23:24:08.158707+00', 'Rosslyn Castle', 'ROSSLYN CASTLE', 1, 32, 9999, 1, 3, 42, 392, NULL, '', 56, '840  888  888  840', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (5702, '1998-11-11 23:00:00+00', '2014-04-30 23:24:08.188567+00', 'Rothesay Country Dance', 'ROTHESAY COUNTRY DANCE', 2, 48, 9999, 1, 2, NULL, 9998, NULL, '', 60, '80  84  88  88  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (18273, '2018-04-02 22:26:36.569787+00', '2019-06-30 10:21:16.844784+00', 'Carefree Highway', 'CAREFREE HIGHWAY', 2, 32, NULL, 1, 3, 42, 2766, '2017-10-01', 'This dance was inspired by the English Country dance Crossroads and is named for a favorite Gordon Lightfoot song.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5734, '1998-09-29 22:00:00+00', '2014-04-30 23:24:08.335688+00', 'Royal Albert Country Dance', 'ROYAL ALBERT COUNTRY DANCE', 1, 32, 9999, 1, 2, NULL, 319, '1890-02-01', '', 69, '88  88  88  88', 0, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (13925, '2011-08-22 22:00:00+00', '2018-04-17 10:44:34.472184+00', 'S C D', 'S C D', 3, 32, NULL, 1, 2, 76, 64, '2004-10-01', 'Devised by Irene van Maarseveen, Pretoria, October 2004.



S C D - Strathspey for Cooks Dauth; also widely used as an abbreviation for Scottish Country Dancing. In Pretoria, the two have long been almost synonymous. Cooks helped found the Pretoria Branch of the RSCDS in 1972 having become the first RSCDS-qualified teacher in Pretoria.



This dance could be used to introduce a reel of 4 to inexperienced dancers.', 78, '80/88/28/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (779, '1998-09-29 22:00:00+00', '2014-05-04 21:35:25.541886+00', 'Brechin Lassies', 'BRECHIN LASSIES', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 52, '808/868/800/866', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (15554, '2014-07-27 13:43:35.436657+00', '2014-07-27 13:43:35.436657+00', 'Clara''s Wedding', 'CLARAS WEDDING', 2, 32, NULL, 2, 3, NULL, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8576, '1998-10-20 22:00:00+00', '2014-08-24 09:49:08.640988+00', 'Rose Garden, The', 'ROSE GARDEN', 3, 24, 9999, 1, 2, NULL, 1283, '1993-01-01', '', 69, '88  88  88', 0, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (5754, '1998-09-30 22:00:00+00', '2014-04-30 23:24:08.427319+00', 'Royal Visit, The', 'ROYAL VISIT', 2, 32, 9999, 1, 2, NULL, 9998, NULL, '', 60, '80  88  88  88', 0, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (5755, '1998-09-29 22:00:00+00', '2014-04-30 23:24:08.442518+00', 'Royal Wedding, The', 'ROYAL WEDDING', 3, 32, 9999, 1, 3, 42, 488, '1981-01-01', '', 53, '800  866  844  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (18492, '2018-08-07 20:41:39.445962+00', '2018-08-08 20:09:13.662927+00', 'Granny Kempock', 'GRANNY KEMPOCK', 3, 32, NULL, 1, 3, 42, 11052, '2017-12-01', 'Granny Kempock is a megalithic stone in the town of Gourock, Scotland.', 56, '844/888/844/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8839, '2000-06-04 22:00:00+00', '2018-04-03 00:08:14.317948+00', 'Ruthven''s Fancy', 'RUTHVENS FANCY', 2, 32, 9999, 1, 3, 42, 2419, NULL, '', 64, '864  888  888  880', 1, 1, 1, 1, 85);
INSERT INTO 'dance' VALUES (9194, '2002-07-04 22:00:00+00', '2018-04-03 00:08:14.2516+00', 'Ruth''s Jig', 'RUTHS JIG', 2, 32, 9999, 1, 3, 42, 854, NULL, 'Devised for Ruth Mumford of Cardiff. ', 50, '800  844  888  880', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (18490, '2018-08-07 20:34:34.022932+00', '2018-08-08 20:06:01.828723+00', 'Cast Away', 'CAST AWAY', 3, 32, NULL, 2, 3, 18, 11674, '2017-12-01', 'Written for Holly Boyd.', 64, '833/844/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19055, '2018-11-18 20:02:49.552854+00', '2018-11-19 23:36:23.236659+00', 'Magic Moment, A', 'MAGIC MOMENT', 1, 32, NULL, 1, 4, 1, 10607, '2018-04-01', '', 93, '8888/8888/8088/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10798, '2002-08-26 22:00:00+00', '2019-03-04 23:15:43.876511+00', 'Ruby Hornpipe, The', 'RUBY HORNPIPE', 1, 32, 9999, 2, 3, 17, 1502, '1998-09-06', 'The dance and the tune were commissioned from Muriel by Joan Clisham for her husband Tom on the occasion of their Ruby Wedding, 6th September 1998.', 77, '844/811/888/888', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (5703, '2002-08-26 22:00:00+00', '2019-03-11 11:09:10.880226+00', 'Rothesay Rant, The', 'ROTHESAY RANT', 2, 32, 9999, 4, 4, 13, 181, NULL, '', 75, '8888  8080  0808  8888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (5215, '1997-04-03 22:00:00+00', '2019-05-12 09:00:34.084933+00', 'Penny Reel, The', 'PENNY REEL', 1, 32, 9999, 1, 3, 42, 13, NULL, 'A Penny Reel was a dance for which one paid an admission charge.', 56, '800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5898, '1998-07-08 22:00:00+00', '2018-04-04 11:10:42.825301+00', 'Sarona', 'SARONA', 3, 32, 9999, 1, 100, 2, 108, '1979-01-01', '', 87, '8668/8228/8888/8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (1417, '1998-01-05 23:00:00+00', '2018-04-02 23:56:33.640162+00', 'Crimson Bloom', 'CRIMSON BLOOM', 1, 32, 9999, 1, 3, 42, 352, '1993-04-12', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5723, '1997-09-13 22:00:00+00', '2020-01-07 08:20:40.525312+00', 'Rovin'' Robin', 'ROVIN ROBIN', 1, 32, 9999, 1, 2, 76, 154, '1972-09-01', '', 44, '62/54/88/62', 1, 1, 1, 1, 64);
INSERT INTO 'dance' VALUES (6368, '1998-04-19 22:00:00+00', '2020-04-14 21:37:00.689791+00', 'Stuttgart Strathspey', 'STUTTGART STRATHSPEY', 3, 32, 9999, 1, 2, 76, 497, '1982-01-01', '', 56, '80/48/88/88', 0, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (5732, '1997-04-03 22:00:00+00', '2020-08-07 09:10:59.30743+00', 'Roy''s Reel', 'ROYS REEL', 1, 40, 9999, 1, 4, 30, 82, NULL, '', 80, '8008  8888  8008  8888  8888', 0, 0, 0, 0, 80);
INSERT INTO 'dance' VALUES (5731, '1998-11-11 23:00:00+00', '2020-08-27 09:38:29.798924+00', 'Roxburgh Castle', 'ROXBURGH CASTLE', 1, 32, 9999, 1, 2, 76, 9998, NULL, '', 60, '88  88 80  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (10066, '2001-09-10 22:00:00+00', '2021-02-12 18:51:03.53936+00', 'Royal Deeside', 'ROYAL DEESIDE', 3, 32, 9999, 1, 4, 1, 127, NULL, '', 87, '8888  7777  7777  0888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (11758, '2004-08-03 22:00:00+00', '2021-04-02 22:00:12.276272+00', 'Ruby for Phyllis, A', 'RUBY FOR PHYLLIS', 3, 80, 9999, 4, 4, 3, 2605, '2004-01-01', '', 95, '8888  4444  8888 8888  8888  8888 8888  8888 8888  8888', 0, 1, 0, 0, 95);
INSERT INTO 'dance' VALUES (11369, '2003-06-26 22:00:00+00', '2021-01-25 15:27:11.0451+00', 'Royal Yacht Britannia, The', 'ROYAL YACHT BRITANNIA', 1, 40, 9999, 1, 3, 42, 108, '2002-01-01', 'The Pilling diagram in the 8th edition is in error, see the supplement to the 8th edition for the correct one.', 57, '800  888  822  888  888', 1, 1, 1, 1, 76);
INSERT INTO 'dance' VALUES (17724, '2017-04-30 10:03:05.825482+00', '2021-02-20 19:52:10.445+00', 'Brownsea Island Jig, The', 'BROWNSEA ISLAND JIG', 2, 32, NULL, 1, 3, 42, 3325, '1988-04-01', 'Brownsea Island in Poole Harbour, UK , owned by The National Trust was the site of the first Boy Scout camp. Stephen taught two separate groups of girl guides (Boxmoor and Potten End Guides) in 1988. They were taught the rudiments of SCD to enable them to gain their dancing badge. For this they were required to know a dance and dance it with a reasonable level of proficiency. They danced The Brownsea Island Jig and were adjudged by Stephen (a Fully Certificated Teacher) to have attained the required level.', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5726, '1997-08-27 22:00:00+00', '2021-03-14 20:39:54.357617+00', 'Rowan Tree, The', 'ROWAN TREE', 3, 32, 9999, 1, 102, 1, 59, '1967-01-01', '<<scddb-not-identical:5727;5728;14296>>', 75, '4444  8888  8888  8080', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (8177, '2002-03-03 23:00:00+00', '2021-03-21 14:21:07.937684+00', 'Ruby Strathspey, The', 'RUBY STRATHSPEY', 3, 32, 9999, 1, 4, 1, 1235, '1993-01-01', '', 62, '8400  8080  8888  8444', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (5741, '1998-11-16 23:00:00+00', '2021-04-20 18:43:20.488317+00', 'Royal Exchange', 'ROYAL EXCHANGE', 2, 32, 9999, 1, 3, 42, 87, NULL, '', 53, '822  888  844  844', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (8970, '1999-03-02 23:00:00+00', '2021-08-04 17:07:05.044949+00', 'Salmonfield Poacher, The', 'SALMONFIELD POACHER', 1, 40, 9999, 1, 3, 42, 21, NULL, 'Devised for Eddie Harding.', 60, '800  866  866  888  888', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (5721, '1997-04-03 22:00:00+00', '2022-11-12 12:37:29.002012+00', 'Rover''s Rant, The', 'ROVERS RANT', 2, 32, 9999, 1, 3, 42, 146, NULL, 'Inscribed "For Reg Dyson''s 60th birthday".', 53, '620  822  888  888', 1, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (5691, '1998-09-29 22:00:00+00', '2021-04-21 20:19:21.726373+00', 'Ross Meor', 'ROSS MEOR', 3, 32, 9999, 1, 3, 42, 198, '1750-01-01', 'The first version of Book 29 says this was published by Johnson in 1750. The notes to the revised Book 29 say it was adapted from Walsh: Caledonian Country Dances 2nd edition of 1735.', 44, '440  880  808  808', 1, 1, 0, 1, 58);
INSERT INTO 'dance' VALUES (1826, '1997-09-01 22:00:00+00', '2021-06-13 08:47:37.183014+00', 'Duncan''s Jig', 'DUNCANS JIG', 2, 32, 9999, 1, 3, 42, 618, NULL, '', 69, '844/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14122, '2011-08-25 22:00:00+00', '2021-07-04 08:17:45.64883+00', 'Ruby Red', 'RUBY RED', 3, 40, NULL, 3, 5, 16, 10433, NULL, '', 71, '82822  84884  88808  86846  82662', 1, 1, 0, 0, 71);
INSERT INTO 'dance' VALUES (5847, '1998-11-09 23:00:00+00', '2014-04-30 23:24:09.024098+00', 'Saint Patrick''s Day', 'SAINT PATRICKS DAY', 2, 24, 9999, 1, 2, NULL, 9998, NULL, '', 57, '88  80  88', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (3687, '2002-03-02 23:00:00+00', '2018-11-19 14:35:15.281912+00', 'Land O''MacLeod, The', 'LAND OMACLEOD', 1, 32, 9999, 4, 4, NULL, 347, '1985-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19056, '2018-11-20 00:55:52.017063+00', '2018-11-20 00:55:52.017063+00', 'Glyn-Garry Swing', 'GLYNGARRY SWING', 11, 16, NULL, 5, 1, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5860, '1998-09-30 22:00:00+00', '2018-04-03 00:08:14.760011+00', 'Saltire Society Reel, The', 'SALTIRE SOCIETY REEL', 1, 32, 9999, 1, 3, 42, 146, '1985-01-01', '', 53, '822  888  844  844', 1, 1, 1, 0, 70);
INSERT INTO 'dance' VALUES (5921, '1998-09-29 22:00:00+00', '2014-04-30 23:24:09.393541+00', 'Scotch Circle, The', 'SCOTCH CIRCLE', 1, 32, 9999, 5, 2, NULL, 9998, NULL, '', 100, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (5821, '1997-09-13 22:00:00+00', '2015-01-30 22:39:58.80328+00', 'Saint David''s Reel', 'SAINT DAVIDS REEL', 1, 32, 9999, 1, 4, 1, 1162, NULL, '', 47, '4444  4444  8000  8444', 0, 1, 1, 0, 46);
INSERT INTO 'dance' VALUES (8154, '1999-12-21 23:00:00+00', '2015-06-28 14:48:14.626759+00', 'St Bernard''s Waltz', 'SAINT BERNARDS WALTZ', 5, 16, 9999, 5, 1, NULL, 3640, '1913-01-01', 'Collected by Barbara Gibbons.  Composed by Billy Smith of Glasgow in 1913.', 100, '88  88', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (14982, '2013-07-20 13:24:17.797594+00', '2015-10-15 22:31:12.075878+00', 'St. Andrews 600', 'SAINT ANDREWS 600', 2, 32, NULL, 1, 3, 42, 2683, '2013-01-01', 'Devised by John M Sturrock to celebrate the founding of St Andrews University in 1413

', 50, '840  840  844  888', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (5829, '2000-08-15 22:00:00+00', '2016-02-28 19:57:02.03517+00', 'Saint John River, The', 'SAINT JOHN RIVER', 3, 32, 9999, 1, 4, 1, 1249, '1966-01-01', '', 59, '8000  8202  8888  8556', 1, 1, 1, 1, 59);
INSERT INTO 'dance' VALUES (3650, '2000-06-12 22:00:00+00', '2018-08-28 21:13:17.01328+00', 'Laird and the Lass, The', 'LAIRD AND THE LASS', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 50, '888/888/800/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18742, '2018-10-04 10:46:29.308048+00', '2018-10-04 10:46:29.308048+00', 'Eighteen-Six', 'EIGHTEENSIX', 2, 32, NULL, 1, 3, 42, 2766, '2013-06-01', 'I''m not sure where the title for this dance came.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7311, '2006-03-07 23:00:00+00', '2019-01-24 15:13:17.729379+00', 'Seven to Seven', 'SEVEN TO SEVEN', 3, 32, 9999, 2, 3, 18, 2688, '2002-01-01', '', 77, '888  877  822  844', 1, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (542, '1997-08-24 22:00:00+00', '2014-05-05 14:59:42.436909+00', 'Black Donald', 'BLACK DONALD', 2, 32, 9999, 1, 2, NULL, 175, '1991-01-01', '', 60, '88  88  80  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (5889, '1998-09-30 22:00:00+00', '2020-02-10 15:41:29.419048+00', 'Sandy o''er the Lea', 'SANDY OER THE LEA', 3, 32, 9999, 1, 2, NULL, 9998, NULL, '', 69, '88  88  88  88', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (5904, '2002-04-19 22:00:00+00', '2021-04-16 22:48:46.658155+00', 'Sauchie Haugh, The', 'SAUCHIE HAUGH', 3, 32, 9999, 1, 2, 76, 121, '1967-01-01', 'The Sauchie Haugh refers to a willowy meadow by a river: in this instance the meadow which gave modern Sauchiehall Street in Glasgow its name.



The RSCDS leaflet gives the tune as <<ddt:Lord Eglinton''s Auld Man#1008>> but a presumably earlier typescript suggests both <<ddt:Mrs Lumsden of Achindores#1327>> and <<ddt:Mr Hamilton of Pencaitland#1275>>.', 60, '80  88  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (5934, '1998-09-29 22:00:00+00', '2020-04-06 15:59:24.04279+00', 'Scotland', 'SCOTLAND', 2, 32, 9999, 1, 2, 76, 446, '1728-01-01', '', 52, '88  88  44  44', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (6130, '1998-09-29 22:00:00+00', '2020-05-15 13:41:59.925939+00', 'Sixteensome Reel', 'SIXTEENSOME REEL', 1, 464, 9999, 4, 8, 3, 9998, NULL, '', 62, 'no bar count made', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5878, '1998-09-29 22:00:00+00', '2020-05-27 08:39:04.629599+00', 'Sandal, The', 'SANDAL', 1, 48, 9999, 1, 3, 42, 9998, NULL, 'Source:  Button and Whitaker''s   Le Sylphe, 1813.', 50, '880/880/888/800/888/800', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (7935, '1997-12-03 23:00:00+00', '2020-06-21 09:13:32.169185+00', 'Sandy Butterly', 'SANDY BUTTERLY', 2, 48, 9999, 1, 4, 1, 50, '1974-01-01', '', 37, '8000  0008  0880  8008  0880  8000', 1, 1, 1, 1, 37);
INSERT INTO 'dance' VALUES (5759, '1997-09-13 22:00:00+00', '2021-04-20 16:43:38.209468+00', 'Rubislaw Jig, The', 'RUBISLAW JIG', 2, 48, 9999, 2, 3, 17, 108, '1981-01-01', '', 94, '888  884  888  888  888  888', 1, 1, 0, 1, 94);
INSERT INTO 'dance' VALUES (6017, '1997-09-14 22:00:00+00', '2020-08-07 09:20:06.21057+00', 'Shake Yourself', 'SHAKE YOURSELF', 2, 32, 9999, 1, 2, 76, 129, '1966-01-01', '', 69, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (10595, '2002-06-04 22:00:00+00', '2020-08-23 08:31:42.024591+00', 'Bridgwater Geordie, The', 'BRIDGWATER GEORDIE', 1, 32, 9999, 1, 100, 11, 316, NULL, '', 81, '8008  8888  8448  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (9642, '2000-09-05 22:00:00+00', '2020-09-09 09:48:01.951291+00', 'Saint Columba''s Reel', 'SAINT COLUMBAS REEL', 1, 40, 9999, 1, 3, 42, 146, '2000-01-01', '', 60, '888  840  888  822  888', 0, 1, 0, 0, 80);
INSERT INTO 'dance' VALUES (10381, '2002-03-10 23:00:00+00', '2020-12-23 11:15:15.294387+00', 'Saltire Strathspey, The', 'SALTIRE STRATHSPEY', 3, 32, 9999, 1, 4, 2, 740, '2001-01-01', '', 81, '4444  8888  8888  6666', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (5937, '1998-10-23 22:00:00+00', '2021-01-08 00:01:19.024001+00', 'Scots Bonnet, The', 'SCOTS BONNET', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 37, '880  800  800  880', 0, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (12059, '2005-02-23 23:00:00+00', '2021-01-16 20:19:47.27062+00', 'San Francisco Surprise', 'SAN FRANCISCO SURPRISE', 3, 32, 9999, 1, 3, 42, 2766, '2004-07-01', 'Written for Nicole Clifton and Ian Sutherland, who married in May 2004 in San Francisco - and told the dance group about it several weeks later.', 66, '844  866   12 12 12  444', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (5830, '1997-04-03 22:00:00+00', '2021-01-23 23:30:44.704554+00', 'Saint John''s Jig', 'SAINT JOHNS JIG', 2, 32, 9999, 1, 3, 42, 108, '1975-02-02', '<<scddb-not-identical:10973>>', 56, '844  888  800  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (8463, '1997-12-28 23:00:00+00', '2021-03-19 22:07:48.198981+00', 'St. John Strathspey, The', 'SAINT JOHN STRATHSPEY', 3, 32, 9999, 1, 2, 76, 872, NULL, '', 52, '88  80  80  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (8155, '2002-02-12 23:00:00+00', '2021-03-21 19:57:48.063258+00', 'Sheena''s Saunter', 'SHEENAS SAUNTER', 11, 32, 9999, 7, 113, NULL, 9998, NULL, '', 88, '8  4  8  8', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5927, '1998-11-12 23:00:00+00', '2021-04-16 22:38:03.809454+00', 'Scotch Mist', 'SCOTCH MIST', 3, 32, 9999, 3, 5, 7, 108, '1971-01-01', '', 67, '84844  84884  80800  84844', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (5848, '1998-04-19 22:00:00+00', '2021-04-19 21:02:57.755838+00', 'Saint Patrick''s Jig', 'SAINT PATRICKS JIG', 2, 40, 9999, 1, 3, 42, 87, NULL, '', 57, '844  844  888  888  822', 1, 1, 1, 1, 76);
INSERT INTO 'dance' VALUES (5817, '1997-09-13 22:00:00+00', '2021-04-19 22:26:14.611183+00', 'St. Anne''s Reel', 'SAINT ANNES REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, 'The title in the book is "St. Anne''s Reel" but previously both SCDDB and MiniCrib had "Saint Anne''s Reel" which is now added as an alias.', 52, '860  888  804  880', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (5868, '2002-05-26 22:00:00+00', '2022-11-12 12:03:58.765161+00', 'Salute to Miss Milligan', 'SALUTE TO MISS MILLIGAN', 1, 32, 9999, 1, 3, 42, 108, '1976-01-01', 'John Drewry wrote in the original description that the dance was dedicated with permission to Miss Jean Milligan - a tribute to her work, marking the Golden Jubilee of the RSCDS.', 62, '880  844  888  888', 1, 1, 0, 1, 83);
INSERT INTO 'dance' VALUES (5952, '2002-08-25 22:00:00+00', '2022-01-29 17:50:36.223236+00', 'Scottish Castle, The', 'SCOTTISH CASTLE', 3, 64, 9999, 4, 4, 3, 108, '1992-06-01', '', 94, '8888  4444  8888  8888  8888  8888  8888  8888', 0, 1, 0, 1, 93);
INSERT INTO 'dance' VALUES (5911, '1997-11-20 23:00:00+00', '2022-11-12 11:58:02.66816+00', 'Scamp, The', 'SCAMP', 2, 32, 9999, 1, 3, 42, 316, '1993-01-01', '', 66, '822  888  888  888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (5858, '1998-09-29 22:00:00+00', '2022-11-12 12:09:54.287596+00', 'Sally''s Fancy', 'SALLYS FANCY', 3, 32, 9999, 1, 3, 42, 9998, '1754-01-01', '', 44, '800  800  844  888', 1, 1, 0, 1, 58);
INSERT INTO 'dance' VALUES (5964, '2000-02-21 23:00:00+00', '2014-04-30 23:24:09.620191+00', 'Scottish Reform', 'SCOTTISH REFORM', 2, 32, 9999, 1, 2, NULL, 9998, NULL, 'This traditional dance celebrates the movement for political and

economic reform in Scotland at the end of the 18th century, which

unlike its predecessors in France and the USA didn''t really lead

anywhere.



The setting movement served as an inspiration for the middle part of

<<ddd:The Reel of the 51st Division>>, while the dance as a whole is fairly

typical of the early 19th century, when many dances followed the

»Something-Something-Down-the-middle-and-up-Poussette« pattern.

', 54, '86  84  80  88', 1, 1, 1, 1, 78);
INSERT INTO 'dance' VALUES (5982, '2002-03-11 23:00:00+00', '2014-04-30 23:24:09.695515+00', 'Seann Triubhas Willichan', 'SEANN TRIUBHAS WILLICHAN', 3, 32, 9999, 1, 2, NULL, 432, NULL, 'The Gaelic title (pronounced approximately like »shorn troos

WILLI-shan«) means »William''s Old Trousers«, which has a little less

of a Celtic ring to it.



The spelling of Truibhas/Triubhas has been inconsistent for many years.  In this database the entry is now spelled »Triubhas«, with the »Truibhas« spelling as an official alias. The reasoning for this is that the »Truibhas« version in the 1974 edition of Book 27 was apparently a typo.



Asked about the spelling in November 2011 the RSCDS (Elspeth Gray) replied:



> I ran your email past the Archivist, Marilyn Healy. She has consulted various sources, and her

> reply is as follows:

>

> > "The correct spelling of the word is ''Triubhas'' which is what can be found in any decent

> > Gaelic-English dictionary, including those readily available on-line. It was spelled "Truibhas"

> > in the first edition of Book 27 in 1975 but since the book was reprinted (with minor revisions) in

> > 1984 the RSCDS has spelled it consistently - and correctly - "Triubhas".  The pocket book Eric

> > refers to was printed in 1976, although it does not have a date of print.  

> >

> > This has been discussed many times and I quote from a reply to a previous enquiry by Iain

> > [sic!] Brockbank:  

> >

> > > "I don''t claim to be a Gaelic expert, but IU fits the rules I learned - the vowels on either side

> > > of a consonant cluster have to match slender (IE) or broad (AOU).  Tr__bhas has an ''a'' after

> > > the bh, so needs a, o  or u before it, leading to triubhas.  This is probably the reason for the

> > > change.  When it happened, I can''t say".

>

> The Highland Dance is consistently spelled ''Truibhas'' - the other way - and I can only assume that

> this is yet another case where the name was taken from a source before the 20th Century urge to

> standardise Gaelic orthography."



To this statement from Elspeth, Anselm adds:  »Note, though, that *Highland Dancing*, the official textbook of the SOBHD, spells the highland dance ›Triubhas‹, and has done so since the first edition of 1955.«

', 52, '80  88  80  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (15057, '2013-08-07 20:49:03.142537+00', '2014-04-30 23:24:09.755726+00', 'Secrets of Callum McCallum, The', 'SECRETS OF CALLUM MACCALLUM', 3, 32, NULL, 1, 3, 42, 9998, NULL, '', 55, '888  855  888  808', 0, 1, 1, 0, 85);
INSERT INTO 'dance' VALUES (8830, '2001-05-21 22:00:00+00', '2014-04-30 23:24:09.816658+00', 'September Wedding, The', 'SEPTEMBER WEDDING', 1, 32, 9999, 1, 4, 1, 228, '1998-01-01', '', 47, '8000  8044  8440  8444', 0, 0, 0, 0, 46);
INSERT INTO 'dance' VALUES (6010, '2000-02-21 23:00:00+00', '2014-04-30 23:24:09.831965+00', 'Seton''s Ceilidh Band', 'SETONS CEILIDH BAND', 2, 64, 9999, 1, 4, 1, 1042, NULL, '', 48, '8000  8088  8000  8880  8110  8110  8440  8448', 0, 1, 1, 0, 48);
INSERT INTO 'dance' VALUES (6035, '2002-03-03 23:00:00+00', '2019-03-10 16:14:15.362549+00', 'Shene Gate', 'SHENE GATE', 2, 32, 9999, 4, 4, 13, 104, '1992-01-01', '', 81, '8080  8888  4848  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (6020, '1997-04-03 22:00:00+00', '2019-03-10 16:17:05.474602+00', 'Shamrock Girl, The', 'SHAMROCK GIRL', 3, 32, 9999, 1, 4, 1, 146, NULL, '', 83, '8484  8888  8181  8888', 0, 0, 0, 0, 82);
INSERT INTO 'dance' VALUES (11291, '2003-05-04 22:00:00+00', '2014-04-30 23:24:10.659902+00', 'Sleepers Awake', 'SLEEPERS AWAKE', 1, 32, 9999, 1, 3, 42, 2783, '1996-11-01', '', 50, '800  822  866  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (5872, '2002-03-03 23:00:00+00', '2015-09-18 12:18:16.478223+00', 'Salute to Summer', 'SALUTE TO SUMMER', 1, 32, 9999, 1, 4, 2, 439, NULL, '', 75, '8008/8888/8008/8888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (11185, '2003-02-16 23:00:00+00', '2015-06-06 06:45:02.111662+00', 'Scotia Sea', 'SCOTIA SEA', 1, 32, 9999, 1, 3, 42, 146, '2002-01-01', '', 53, '800/888/844/866', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (5939, '2001-11-20 23:00:00+00', '2019-03-10 19:04:16.534487+00', 'Scots Gate, The', 'SCOTS GATE', 2, 32, 9999, 1, 4, 1, 388, '1982-01-01', '', 56, '8008  0880  8000  8888', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (3715, '2002-04-19 22:00:00+00', '2019-04-20 22:18:07.16635+00', 'Larry Bell Of Lexington', 'LARRY BELL OF LEXINGTON', 2, 48, 9999, 2, 3, 17, 963, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5963, '1999-11-01 23:00:00+00', '2018-04-03 00:08:15.36864+00', 'Scottish Ramble', 'SCOTTISH RAMBLE', 3, 32, 9999, 1, 3, 42, 9998, '1754-01-01', '', 44, '800  844  822  866', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (9124, '2002-08-25 22:00:00+00', '2018-04-03 00:08:16.127366+00', 'Sheena''s Buckle', 'SHEENAS BUCKLE', 2, 32, 9999, 1, 3, 42, 15, '1999-09-09', 'For Sheena Skinner''s wedding.', 50, '800  862  888  808', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (14295, '2011-11-03 23:00:00+00', '2014-04-30 23:24:10.016446+00', 'Shining Lights', 'SHINING LIGHTS', 3, 32, 9999, 1, 3, 42, 1773, NULL, 'Source of Dance: Tullochgorum CD

Title Tune: Duke of Athol''s Forrest Lodge, Glen Tilt - aka - Ca'' the Wethers to the Hill



The Dance: 



1s advance & retire (taking RH), turn halfway 2H (finish on opposite sides, facing down, 2s facing up); 1s & 2s advance & retire (taking RH), turn halfway 2H (1s finish between corners).



1s, 2s & 3s advance & retire, all turn partners 2H; 1s cast round 1st corners (W up, M down) (finish in the middle facing 1st corners).



1s set to 1st corners, 1s dance round each other to the R (clockwise) (finish facing 2nd corners); 1s set to 2nd corners, 1s dance round each other to the R (clockwise) (finish in 2nd place, own sides).



1s, 2s & 3s dance Reels of 3 on the sides (1st M gives RS to 2nd M and 1st W gives RS to 3rd W to begin the reels; 1s change sides on bars 3-4, and start the second half-reel on opposite sides on bars 5-6, then cross to own sides on bars 7-8; effectively, the 1s are dancing around a big oval as the others continue their reels).', 50, '840  844  822  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (6057, '2003-01-30 23:00:00+00', '2014-04-30 23:24:10.062139+00', 'Shores of Solway, The', 'SHORES OF SOLWAY', 3, 32, 9999, 1, 3, 42, 146, NULL, '', 53, '440  888  822  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (11524, '2003-10-02 22:00:00+00', '2019-02-13 18:24:47.711402+00', 'Liquid Assets', 'LIQUID ASSETS', 2, 32, 9999, 1, 3, 42, 108, '2002-11-01', '', 59, '888/844/888/804', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8524, '2001-09-02 22:00:00+00', '2019-02-15 20:32:45.440536+00', 'Silver Penny Farthing, The', 'SILVER PENNY FARTHING', 1, 32, 9999, 2, 3, 17, 48, NULL, '', 75, '800  884  848  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (10707, '2002-07-21 22:00:00+00', '2020-09-12 21:56:55.732051+00', 'Shelley''s Circle', 'SHELLEYS CIRCLE', 2, 32, 9999, 5, 2, 76, 2961, NULL, '', 87, '88  88  44  88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (6029, '1998-09-29 22:00:00+00', '2020-07-13 21:40:27.213822+00', 'She''s ower young to marry yet', 'SHES OWER YOUNG TO MARRY YET', 3, 32, 9999, 1, 3, 42, 466, '1751-01-01', '', 59, '840  880  888  888', 0, 1, 0, 0, 79);
INSERT INTO 'dance' VALUES (13502, '2009-11-21 23:00:00+00', '2020-09-18 15:59:35.123837+00', 'Sheltered Cove, The', 'SHELTERED COVE', 3, 32, 9999, 1, 2, 76, 1269, '2007-01-01', '', 58, '86  88  80  88', 0, 1, 0, 0, 84);
INSERT INTO 'dance' VALUES (14671, '2013-01-21 23:52:00.248579+00', '2020-10-01 18:16:18.884013+00', 'Second Time Around', 'SECOND TIME AROUND', 3, 32, NULL, 2, 3, 17, 10715, NULL, '', 58, '880  800  088  808', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (6036, '1997-11-18 23:00:00+00', '2020-12-17 22:24:16.960727+00', 'Shepherd''s Crook, The', 'SHEPHERDS CROOK', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 37, '822  822  800  880', 0, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (11564, '2003-10-31 23:00:00+00', '2020-12-25 11:11:11.083205+00', 'Sheila Morris''s Strathspey', 'SHEILA MORRISS STRATHSPEY', 3, 32, 9999, 1, 4, 2, 2605, '2003-01-01', '', 100, '8888  8888  8888  8888', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (8703, '2001-07-18 22:00:00+00', '2021-03-14 23:32:46.11777+00', 'Scots Brigade, The', 'SCOTS BRIGADE', 1, 32, 9999, 1, 3, 42, 2118, '1989-01-01', '', 47, '800  880  888  822', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (8175, '2001-11-20 23:00:00+00', '2021-03-21 14:22:26.708376+00', 'Scots Guards, The', 'SCOTS GUARDS', 3, 32, 9999, 1, 3, 42, 388, '1992-01-01', '', 59, '880  888  822  888', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (5996, '1997-09-13 22:00:00+00', '2021-04-15 10:53:07.707766+00', 'Selkirk Settlers, The', 'SELKIRK SETTLERS', 1, 40, 9999, 2, 3, 17, 1269, NULL, 'Devised for use in a performance with children and adults in the same set.', 37, '800  008  444  080  800', 1, 1, 1, 1, 36);
INSERT INTO 'dance' VALUES (5981, '1998-09-30 22:00:00+00', '2021-04-16 11:40:52.19656+00', 'Seagull, The', 'SEAGULL', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 44, '800  826  808  880', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (5945, '1998-11-16 23:00:00+00', '2021-04-16 22:25:07.992976+00', 'Scotsman In America, The', 'SCOTSMAN IN AMERICA', 3, 32, 9999, 1, 4, 1, 87, NULL, '', 88, '8888  8448  8088  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (8464, '1997-12-28 23:00:00+00', '2021-10-06 21:54:46.391249+00', 'Scotch Tangle, The', 'SCOTCH TANGLE', 1, 32, 9999, 1, 4, 1, 872, NULL, '', 100, '8888  8888  8888  8888', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (18661, '2018-09-24 22:58:22.63522+00', '2019-09-01 20:46:39.685743+00', '10/6 In This Style', '10/6 IN THIS STYLE', 1, 32, NULL, 2, 104, 4, 11237, '2018-07-01', 'A dance for the Mad Hatter’s hat which was priced at ten shillings and six pence (this used to be written as 10/6 and pronounced "ten and six").', 83, '888 888 444 767', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10853, '2002-11-01 23:00:00+00', '2014-04-30 23:24:11.129321+00', 'Spider, The', 'SPIDER', 1, 32, 9999, 1, 3, 42, 227, '1996-01-01', 'Frans adds the note "For all the spiders in my house a new intricate pattern for their webs"', 55, '800  888  888  860', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (9111, '2002-02-28 23:00:00+00', '2022-01-29 20:59:50.984318+00', 'Simon''s Dance', 'SIMONS DANCE', 1, 128, 9999, 4, 4, 3, 683, '1990-01-01', '', 62, '40 + 16 + 24', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10083, '2001-09-12 22:00:00+00', '2022-07-21 16:47:09.67312+00', 'Secret Garden, The', 'SECRET GARDEN', 3, 40, 9999, 2, 3, 17, 108, '2000-07-01', 'John Drewry wrote the dance for Betty Keir of Perth in July 2000.', 60, '484  888  080  888  800', 0, 1, 0, 0, 60);
INSERT INTO 'dance' VALUES (5976, '1997-09-12 22:00:00+00', '2022-08-19 08:40:13.658596+00', 'Sea Tangle of Skye', 'SEA TANGLE OF SKYE', 3, 32, 9999, 1, 2, 76, 1763, '1975-01-01', '', 60, '80  88  88  88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (9892, '2001-06-04 22:00:00+00', '2022-09-30 21:24:44.001354+00', 'Smiddy Jig', 'SMIDDY JIG', 2, 32, 9999, 1, 3, 42, 246, NULL, '', 59, '840  888  844  888', 0, 1, 0, 0, 79);
INSERT INTO 'dance' VALUES (13690, '2011-06-14 22:00:00+00', '2014-04-30 23:24:10.08286+00', 'Shortfield Jig, The', 'SHORTFIELD JIG', 2, 40, NULL, 1, 3, 42, 10338, NULL, 'Named after Shortfield Common, near Frensham', 62, '844  822  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (18101, '2017-11-27 18:30:47.21917+00', '2018-04-02 23:56:33.920085+00', 'Deep Cove Dancers', 'DEEP COVE DANCERS', 1, 32, 9999, 1, 3, 42, 1727, NULL, 'For all the Deep Cove Dancers.



First 8-bar progression as described by Francis Walduck in bars 1-8 of The Ruby Rant.', 92, '880/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17927, '2017-09-12 23:50:18.595681+00', '2018-04-02 23:56:34.149524+00', 'Eifel Wedding', 'EIFEL WEDDING', 3, 32, NULL, 1, 3, 42, 11524, NULL, 'Devised by Anett Sievers, Susanne Staub, and Matthias Lang, for the wedding of Liane Hoess and Thomas Schürfeld who met in the Eifel and got married in Schleiden on 29 December 2016.



DEVISED:2016', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15986, '2015-02-06 14:16:11.050468+00', '2018-04-02 23:56:34.449977+00', 'Faithful Friends', 'FAITHFUL FRIENDS', 3, 32, 9999, 1, 3, 42, 703, '2010-01-01', 'Devised for Jim and Marya Washington of Richmond, Virginia in January, 20]0. Jim and Marya knew each other from childhood, but they reconnected and married in 2005. Sadly, Jim passed away in February, 2010. So, this dance shows their paths crossing throughout life and finally spending time together.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13138, '2006-12-05 23:00:00+00', '2014-04-30 23:24:10.204444+00', 'Silver Halsway', 'SILVER HALSWAY', 3, 32, 9999, 1, 4, 2, 104, NULL, '', 94, '8888 8448  8888  8888', 1, 1, 1, 0, 93);
INSERT INTO 'dance' VALUES (10681, '2002-07-21 22:00:00+00', '2018-04-03 00:08:16.435869+00', 'Shortness of Breath', 'SHORTNESS OF BREATH', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', 59, '844  888  844  866', 0, 1, 1, 0, 63);
INSERT INTO 'dance' VALUES (14400, '2012-01-12 23:00:00+00', '2018-09-19 08:04:50.364931+00', 'St Luke''s Circle', 'SAINT LUKES CIRCLE', 1, 40, NULL, 7, 1, NULL, 3617, '1992-01-01', 'For the Monday night class at St. Luke''s Episcopal Church in Des Moines, Iowa.', 80, '8/8/4/4/8', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15269, '2013-11-27 04:44:31.239234+00', '2015-02-24 14:51:18.737457+00', 'Silver Strings', 'SILVER STRINGS', 3, 32, NULL, 1, 4, 2, 1089, '2014-01-01', '', 87, '8888  8008  8888  8888', 0, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (6051, '2002-02-12 23:00:00+00', '2017-04-03 00:19:23.683502+00', 'Ship in Full Sail, The', 'SHIP IN FULL SAIL', 2, 32, 9999, 3, 5, 7, 127, NULL, '', 84, '86866/88888/84884/84844', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (1749, '1997-12-03 23:00:00+00', '2014-04-30 23:24:10.768382+00', 'Snapdragon', 'SNAPDRAGON', 2, 32, 9999, 1, 2, NULL, 895, '1992-01-01', 'I was in my flower phase. Some spectacular hollyhocks were abloom in my garden at

the time, but this seemed more like a snapdragon kind of dance. Hollyhocks came

later. (CH)', 52, '80  08  88  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (12720, '2006-04-17 22:00:00+00', '2014-11-11 11:38:21.526589+00', 'Skipping Rock Reel, The', 'SKIPPING ROCK REEL', 1, 32, 9999, 2, 3, 17, 3674, '2006-01-01', '', 87, '888  888  888  822', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (6490, '2002-11-03 23:00:00+00', '2020-12-17 22:55:30.251775+00', 'Silver Square, The', 'SILVER SQUARE', 1, 32, 9999, 4, 5, 16, 2169, NULL, 'Originally posted as a <<sspey:6310|message to the strathspey mailing list>>.', 81, '80808  08088  80008  88888', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (6168, '1998-04-19 22:00:00+00', '2020-09-03 16:03:08.123164+00', 'Snow on a Hilltop', 'SNOW ON A HILLTOP', 3, 32, 9999, 1, 2, 76, 227, '1987-01-01', '', 52, '80  88  88  80', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (9012, '1999-04-24 22:00:00+00', '2020-09-07 22:31:20.811778+00', 'Side by Side', 'SIDE BY SIDE', 2, 40, 9999, 1, 3, 42, 146, NULL, '', 50, '800  844  844  844  888', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (10470, '2002-04-14 22:00:00+00', '2021-02-08 15:19:53.732164+00', 'Silver Birch Strathspey, The', 'SILVER BIRCH STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3644, NULL, '', 41, '840  633  633  844', 0, 1, 0, 0, 54);
INSERT INTO 'dance' VALUES (14318, '2011-11-15 23:00:00+00', '2020-09-27 09:14:12.906324+00', 'Snowball, The', 'SNOWBALL', 2, 48, NULL, 3, 5, 16, 9998, NULL, 'Instructions published on Strathspey by John Wood; no original source given.', 47, '80000  88000  88800  88880  00008  84444', 0, 1, 0, 0, 46);
INSERT INTO 'dance' VALUES (8566, '2002-02-12 23:00:00+00', '2021-03-16 16:40:32.966399+00', 'Simon''s Petronella', 'SIMONS PETRONELLA', 3, 32, 9999, 2, 3, 17, 2026, NULL, '', 87, '484  888  888  686', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (14531, '2012-08-13 08:28:22.346866+00', '2020-11-15 13:19:15.782299+00', 'Sleepdancer, The', 'SLEEPDANCER', 3, 32, NULL, 1, 3, 42, 10642, '2003-01-01', '', 42, '200  888  400  820  833', 0, 1, 1, 0, 56);
INSERT INTO 'dance' VALUES (6116, '2002-11-13 23:00:00+00', '2020-12-17 22:29:11.249155+00', 'Sir Murdoch MacDonald''s Strathspey', 'SIR MURDOCH MACDONALDS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 490, '1980-01-01', '', 75, '8000  6666  8888  8888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (7517, '2002-02-18 23:00:00+00', '2020-12-18 20:46:43.823088+00', 'Silver Grey, The', 'SILVER GREY', 3, 32, 9999, 2, 3, 17, 146, NULL, '', 79, '888  888  808  804', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (8511, '2002-04-14 22:00:00+00', '2020-12-20 11:16:43.894039+00', 'Silver Chains', 'SILVER CHAINS', 1, 32, 9999, 7, 5, 35, 28, NULL, '', 100, '88888  88888  88888  88888', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (13517, '2009-12-01 23:00:00+00', '2020-12-25 21:47:06.049616+00', 'Sir J. M. Barrie of Thrums', 'SIR J M BARRIE OF THRUMS', 1, 48, NULL, 1, 4, 1, 2419, '2006-01-11', '', 62, '6666  4444  6666  4444  8000  8888', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (10395, '2002-03-12 23:00:00+00', '2021-02-09 11:55:19.351287+00', 'Skye Barbecue', 'SKYE BARBECUE', 1, 32, 9999, 1, 3, 42, 550, '2001-01-01', '', 75, '888  888  888  888', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (9093, '1999-08-05 22:00:00+00', '2021-03-02 14:09:51.127914+00', 'Silver Thistle, The', 'SILVER THISTLE', 1, 32, 9999, 1, 3, 42, 2640, '1986-01-01', '', 50, '822  800  888  884', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (6152, '1998-09-29 22:00:00+00', '2021-04-14 11:26:42.416533+00', 'Sleepy Maggie', 'SLEEPY MAGGIE', 1, 32, 9999, 1, 3, 42, 1977, '1758-01-01', '', 50, '840  808  844  866', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (6058, '1998-09-29 22:00:00+00', '2021-04-14 21:25:52.099987+00', 'Short and Sweet', 'SHORT AND SWEET', 2, 40, 9999, 1, 3, 42, 453, '1775-01-01', '', 37, '800  822  800  844  880', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (9120, '2000-09-03 22:00:00+00', '2021-08-02 12:10:18.687788+00', 'Slip the Surly Bonds', 'SLIP THE SURLY BONDS', 3, 32, 9999, 1, 2, 76, 1113, '1999-01-01', 'The title refers to the poem »<<http://www.physics.mcgill.ca/~dominic/summer2k/Flying/HFann.html|High Flight>>« by John Gillespie Magee Jr. (1922–1941), a WWII pilot. Strathspey database management recommends that dancers join the tumbling mirth only with appropriate care.', 69, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (11970, '2004-12-15 23:00:00+00', '2021-08-05 14:40:45.678092+00', 'Silver Thistle Ball, The', 'SILVER THISTLE BALL', 3, 32, 9999, 2, 3, 17, 3495, '2004-01-01', '', 71, '800/844/848/888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (11731, '2004-07-04 22:00:00+00', '2014-04-30 23:24:10.957545+00', 'Sons of the Rock', 'SONS OF THE ROCK', 1, 32, 9999, 5, 56, NULL, 9998, NULL, '', 100, '888  888  888  888', 0, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (6202, '1998-04-19 22:00:00+00', '2014-04-30 23:24:10.972494+00', 'Sorcerer''s Apprentice, The', 'SORCERERS APPRENTICE', 2, 32, 9999, 1, 2, NULL, 44, NULL, '', 60, '88  88  84  48', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (6209, '2002-04-27 22:00:00+00', '2019-03-10 15:14:33.358465+00', 'Sounding The Deep', 'SOUNDING THE DEEP', 1, 24, 9999, 1, 4, 2, 352, NULL, '', 67, '8008  8888  8008', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (9501, '2001-07-30 22:00:00+00', '2022-01-29 20:54:32.254104+00', 'Silly Sisters, The', 'SILLY SISTERS', 1, 32, 9999, 1, 3, 42, 228, NULL, '', 48, '860  880  844  888', 1, 1, 1, 1, 64);
INSERT INTO 'dance' VALUES (6148, '2003-01-30 23:00:00+00', '2022-08-12 12:54:06.137777+00', 'Slainte Mhor', 'SLAINTE MHOR', 1, 64, 9999, 4, 4, NULL, 370, '1987-01-01', 'Devised by Moira Stacey for John Staniland’s 60th Birthday', 75, '8484  4848  6666  6666  8888  4444  8484  4848', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (6098, '1997-09-14 22:00:00+00', '2022-10-24 12:42:37.830822+00', 'Simon Brodie', 'SIMON BRODIE', 3, 32, 9999, 1, 3, 42, 976, '1740-01-01', '', 34, '440/840/844/800', 1, 1, 0, 1, 45);
INSERT INTO 'dance' VALUES (6182, '1998-11-07 23:00:00+00', '2018-04-03 00:08:17.636788+00', 'Soldier''s Joy, The', 'SOLDIERS JOY', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 44, '800  888  800  880', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (6233, '2000-02-21 23:00:00+00', '2018-04-03 00:08:17.928738+00', 'Speed the Plough', 'SPEED THE PLOUGH', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 38, '880  800  844  800', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (6250, '1998-07-09 22:00:00+00', '2014-04-30 23:24:11.220175+00', 'Splicing, The', 'SPLICING', 2, 32, 9999, 3, 5, 7, 108, '1992-01-01', '', 70, '84840  84884  88888  80800', 0, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (9390, '2000-05-11 22:00:00+00', '2014-04-30 23:24:11.24105+00', 'Sprig of Ivy, The', 'SPRIG OF IVY', 1, 32, 9999, 1, 3, 42, 101, '1990-01-01', '', 56, '800  844  888  888', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (6199, '2001-05-21 22:00:00+00', '2016-06-03 13:51:09.168935+00', 'Songs and Tunes', 'SONGS AND TUNES', 3, 32, 9999, 1, 3, 42, 228, '1993-01-01', '', 62, '800  888  888  888', 0, 0, 0, 0, 83);
INSERT INTO 'dance' VALUES (8477, '1997-12-28 23:00:00+00', '2017-03-05 08:21:17.076125+00', 'Small Glen, The', 'SMALL GLEN', 2, 32, 9999, 1, 3, 42, 872, NULL, '', 50, '800  844  844  888', 1, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (10655, '2003-01-30 23:00:00+00', '2017-03-30 15:44:11.546926+00', 'Spanish Falcon, The', 'SPANISH FALCON', 3, 32, 9999, 1, 4, 1, 3169, NULL, '', 47, '8800  8440  8440  8004', 0, 1, 1, 0, 46);
INSERT INTO 'dance' VALUES (12739, '2006-05-11 22:00:00+00', '2017-07-21 08:19:26.071054+00', 'Sound Technician, The', 'SOUND TECHNICIAN', 2, 32, 9999, 1, 2, 76, 1445, '2006-01-01', 'See also The Sound Technician (Variant 2017), http://my.strathspey.org/dd/dance/17879/ by the same author which differs only in bars 25-32', 54, '64/88/88/80', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (6255, '1997-04-03 22:00:00+00', '2014-04-30 23:24:11.246448+00', 'Sprig of Ivy', 'SPRIG OF IVY', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 62, '844  888  844  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (9967, '2001-06-12 22:00:00+00', '2018-04-03 00:08:18.362298+00', 'Starter, The', 'STARTER', 3, 32, 9999, 1, 3, 42, 2102, NULL, '', 47, '800  822  888  880', 0, 0, 0, 0, 62);
INSERT INTO 'dance' VALUES (6287, '1998-09-29 22:00:00+00', '2018-04-16 23:48:29.412257+00', 'Starry Eyed Lassie, The', 'STARRY EYED LASSIE', 2, 32, 9999, 1, 3, 42, 365, NULL, '', 66, '880  888  888  866', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (13615, '2010-10-07 22:00:00+00', '2014-04-30 23:24:11.437737+00', 'Startled Rabbits, The', 'STARTLED RABBITS', 2, 32, NULL, 3, 5, 7, 175, NULL, '"Dedicated to all those dancers for whom the next eight bars come as a complete surprise"', 70, '80800  88888  88888  80800', 0, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (7972, '1997-09-15 22:00:00+00', '2018-08-08 19:34:59.099153+00', 'TGV, Le', 'TGV', 4, 192, 5, 2, 3, 17, 1301, '1990-01-01', 'The type of the dance alternates between strathspey and reel. Uneven turn strathspey, even turn reel.  

Devised for the 25th anniversary of "Le Chardon d''Ecosse" Paris - 1990.', 50, '800/800/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14981, '2013-07-20 13:20:02.273454+00', '2014-04-30 23:24:11.618284+00', 'Strathspey for John, A', 'STRATHSPEY FOR JOHN', 3, 40, NULL, 2, 3, 17, 10809, '2013-01-01', 'Stub entry, needs to be checked from the publication', 45, '800  800  888  844  808', 0, 1, 1, 0, 60);
INSERT INTO 'dance' VALUES (6359, '1999-12-21 23:00:00+00', '2014-04-30 23:24:11.663668+00', 'Strip the Willow', 'STRIP THE WILLOW', 101, 40, 9999, 1, 4, 1, 9998, NULL, '', 32, '8100  8011  8011  8300  8022', 1, 1, 1, 1, 32);
INSERT INTO 'dance' VALUES (14657, '2013-01-05 11:31:38.855204+00', '2019-02-12 22:49:52.093023+00', 'Sunflowers, The', 'SUNFLOWERS', 2, 40, NULL, 2, 3, 17, 3135, '2008-01-01', 'Dedicated to Hans van Zon', 69, '444/888/444/888/844', 0, 1, 1, 0, 73);
INSERT INTO 'dance' VALUES (10153, '2001-11-07 23:00:00+00', '2021-02-11 09:53:13.149829+00', 'Spinkie Den', 'SPINKIE DEN', 3, 32, 9999, 2, 3, 17, 1190, NULL, '', 41, '660  880  800  808', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (6224, '2003-01-30 23:00:00+00', '2020-12-17 22:39:01.464723+00', 'Sow''s Tail, The', 'SOWS TAIL', 3, 32, 9999, 1, 3, 42, 9998, '1748-01-01', '', 53, '804  844  888  880', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (13463, '2009-11-17 23:00:00+00', '2020-09-17 22:32:30.361095+00', 'Starter for Ten, A', 'STARTER FOR TEN', 2, 32, NULL, 3, 5, 16, 146, NULL, '', 42, '80440  80440  82002  84444', 0, 1, 0, 0, 42);
INSERT INTO 'dance' VALUES (6186, '2001-07-25 22:00:00+00', '2020-10-30 09:52:20.638659+00', 'Solway Reel, The', 'SOLWAY REEL', 1, 48, 9999, 1, 4, 1, 212, NULL, '', 54, '4004  4004  0880  8888  8440  8448', 0, 1, 0, 0, 54);
INSERT INTO 'dance' VALUES (11533, '2003-10-02 22:00:00+00', '2021-03-14 20:29:36.71661+00', 'Strathspey for the Black Watch', 'STRATHSPEY FOR THE BLACK WATCH', 3, 32, 9999, 1, 4, 1, 2419, '2004-01-01', '', 72, '8448  8008  8888  8417', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (6177, '2002-04-14 22:00:00+00', '2020-12-17 22:31:48.861645+00', 'Society Piper', 'SOCIETY PIPER', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 41, '822  822  822  844', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (10286, '2002-08-29 22:00:00+00', '2020-12-23 11:01:26.238817+00', 'Sleepwalking', 'SLEEPWALKING', 1, 32, 9999, 1, 3, 42, 2976, '1996-10-22', 'This dance is dedicated to Kate & Ed Nealley, and to Inverarity, with many happy memories of dancing there', 45, '800  888  802  844', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (8487, '1997-12-28 23:00:00+00', '2021-03-19 10:43:46.935498+00', 'Trip to Glenmoor (Reel version), A', 'TRIP TO GLENMOOR REEL VERSION', 1, 32, 9999, 1, 3, 42, 872, NULL, '', 53, '888  844  866  800', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (11795, '2004-09-08 22:00:00+00', '2020-12-25 12:08:06.473916+00', 'Station X', 'STATION X', 1, 32, 9999, 2, 2, 76, 108, '2003-01-01', 'Drewry advises to dance in a 3C set to avoid overtiring the dancers.



"Station X" was one of the names of Bletchley Park, near Milton Keynes, where some of the brightest brains of the country (including Hugh Foss) worked to decipher the Enigma code in the early 1940''s.  It was the birthplace of modern computing.', 69, '88  44  44  88  88', 1, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (11371, '2003-06-26 22:00:00+00', '2021-01-25 15:24:52.290661+00', 'Strathmore', 'STRATHMORE', 3, 40, 9999, 1, 4, 2, 108, '2002-01-01', '', 95, '8888  8888  8888  8448  8888', 1, 1, 1, 1, 95);
INSERT INTO 'dance' VALUES (11190, '2003-02-16 23:00:00+00', '2021-01-29 22:29:53.229584+00', 'Speirs Bruce, The Pole Star', 'SPEIRS BRUCE THE POLE STAR', 2, 32, 9999, 1, 3, 42, 146, '2002-01-01', '', 53, '840  880  646  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (6358, '1997-09-14 22:00:00+00', '2021-04-12 22:09:21.40303+00', 'Strings Of Clair', 'STRINGS OF CLAIR', 3, 32, 9999, 1, 3, 42, 90, '1983-01-01', 'From the notes:

"This dance is designed to celebrate the wealth of musical talent which has emerged from the small village of Clair in Madawaska County - population 926 as of January 1, 1983. Les Jeunes Violonistes de Clair, Inc. has toured extensively in New Brunswick, Quebec and the New England states. Several former members have gone on to higher music education and a number are now teaching in the province."', 47, '888  800  844  822', 1, 1, 0, 1, 62);
INSERT INTO 'dance' VALUES (6336, '2002-04-19 22:00:00+00', '2021-04-12 22:17:53.614484+00', 'Strathcare', 'STRATHCARE', 3, 32, 9999, 1, 3, 42, 388, '1990-01-01', '', 44, '880  800  822  866', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (6323, '1998-09-29 22:00:00+00', '2021-04-12 22:33:35.031379+00', 'Stoorie Miller, The', 'STOORIE MILLER', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 44, '844  800  822  866', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (6161, '1997-12-15 23:00:00+00', '2021-04-14 11:09:41.143937+00', 'Snake Pass, The', 'SNAKE PASS', 2, 32, 9999, 1, 3, 42, 525, NULL, '', 50, '844  800  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (6188, '2000-06-12 22:00:00+00', '2021-05-07 22:08:03.336523+00', 'Somebody', 'SOMEBODY', 3, 16, 9999, 5, 2, 76, 129, NULL, '', 100, '88  88', 1, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (7521, '1998-04-24 22:00:00+00', '2019-03-07 22:47:26.198096+00', 'Stepping It Out', 'STEPPING IT OUT', 2, 32, 9999, 1, 4, 1, 146, NULL, '', 56, '8008  0880  8000  8888', 0, 1, 0, 0, 56);
INSERT INTO 'dance' VALUES (6328, '1997-04-03 22:00:00+00', '2019-03-09 21:48:37.208637+00', 'Stow Alert, The', 'STOW ALERT', 1, 40, 9999, 1, 4, 1, 259, NULL, '', 45, '8000  8088  8000  8880  8000', 0, 1, 0, 0, 45);
INSERT INTO 'dance' VALUES (6384, '1997-08-26 22:00:00+00', '2014-04-30 23:24:11.816006+00', 'Summer on the Clyde', 'SUMMER ON THE CLYDE', 3, 32, 9999, 1, 4, 1, 477, '1973-01-01', '', 72, '4444  8888  8888  8004', 0, 1, 1, 0, 71);
INSERT INTO 'dance' VALUES (11293, '2003-05-04 22:00:00+00', '2014-04-30 23:24:11.846696+00', 'Sunday Afternoon Jig', 'SUNDAY AFTERNOON JIG', 2, 32, 9999, 1, 3, 42, 3341, '2000-01-01', '', 62, '880  880  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (11113, '2002-12-31 23:00:00+00', '2015-05-12 22:29:42.594895+00', 'Stable, The', 'STABLE', 1, 32, 9999, 3, 5, 16, 267, NULL, '', 60, '88888/88088/00800/82222', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (15231, '2013-11-09 23:18:50.751184+00', '2017-11-10 02:56:29.016274+00', 'Swirling Leaves', 'SWIRLING LEAVES', 2, 32, NULL, 1, 3, 42, 3369, '2012-10-01', 'Revised ', 56, '800  844  888  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (6407, '1998-09-29 22:00:00+00', '2022-11-08 15:57:15.125947+00', 'Sutters of Selkirk, The', 'SUTTERS OF SELKIRK', 1, 32, 9999, 1, 2, 76, 9998, '1748-01-01', '', 34, '80  08  44  62', 1, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (6393, '1997-08-24 22:00:00+00', '2023-01-25 17:45:16.592301+00', 'Sunlit Square, The', 'SUNLIT SQUARE', 3, 64, 9999, 4, 4, 3, 108, '1993-01-01', 'A dance to mark the 21st winter holiday organised by Mary Prentice, to be held in January 1994 in the Algarve - Portugal', 88, '88  88  88  88  80  08  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (14648, '2013-01-05 08:30:51.324079+00', '2016-01-29 23:59:25.002893+00', 'Star Petronella', 'STAR PETRONELLA', 1, 32, NULL, 1, 2, NULL, 129, NULL, 'True source unknown.  Described by Hugh Foss in "Notes on Evolution in Scottish Country Dancing" (1973), page 31-32, as "New Version" of "Petronella".  In a common variant 2c steps up on [1-2]  instead of casting up using PdB.



The name "Star Petronella" came from hearsay, i.e. the origin is unknown.  ', 69, '88  88  88  88', 1, 1, 1, 0, 96);
INSERT INTO 'dance' VALUES (10684, '2002-07-21 22:00:00+00', '2016-03-18 00:24:19.835362+00', 'Stanford Swing', 'STANFORD SWING', 2, 40, 9999, 1, 3, 42, 2961, NULL, 'In some published descriptions, the "set" that precedes each "La Baratte" is sometimes missing.', 42, '800  844  822  844  844', 0, 1, 1, 0, 56);
INSERT INTO 'dance' VALUES (6271, '1998-09-29 22:00:00+00', '2017-02-13 02:28:51.981834+00', 'Staffin Harvest', 'STAFFIN HARVEST', 3, 32, 9999, 1, 4, 1, 484, '1976-01-01', 'Staffin is a village in the north of the Isle of Skye. Near Staffin there is one of the oldest archeological sites in Scotland, a Mesolithic campsite from the 7th millennium (!) BCE.

', 84, '6666  8888  8888  8444', 0, 1, 1, 1, 84);
INSERT INTO 'dance' VALUES (6382, '1998-11-14 23:00:00+00', '2017-11-25 01:07:40.097083+00', 'Summer in Assynt', 'SUMMER IN ASSYNT', 3, 32, 9999, 1, 3, 42, 128, '1973-01-01', '', 62, '880/888/880/888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (18493, '2018-08-07 20:44:32.431636+00', '2018-08-08 20:09:51.360125+00', 'Cloch Lighthouse, The', 'CLOCH LIGHTHOUSE', 2, 32, NULL, 1, 3, 42, 11052, '2018-02-01', 'The Cloch Lighthouse is a beacon on the River Clyde in the town of Gourock, Scotland.', 59, '800/866/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6295, '1997-04-03 22:00:00+00', '2014-11-09 21:46:00.971377+00', 'Steamboat, The', 'STEAMBOAT', 2, 32, 9999, 1, 2, NULL, 173, '1982-08-09', 'Preferred music: Cumberland Reel recorded by Bobby Crowe (Music for book 1).  The lead tune shown below.', 56, '88  80  44  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (15760, '2015-01-10 14:32:26.204248+00', '2018-04-02 23:56:37.881758+00', 'Sullivan Hall', 'SULLIVAN HALL', 1, 32, 9999, 1, 3, 42, 993, '2003-09-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14718, '2013-02-27 22:34:01.989738+00', '2014-04-30 23:24:12.211961+00', 'Swinging Braes, The', 'SWINGING BRAES', 3, 32, NULL, 2, 3, 17, 3645, '2013-02-01', '', 67, '880  844  844  808', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (6381, '1997-04-03 22:00:00+00', '2018-04-03 00:08:18.979395+00', 'Summer Breeze, A', 'SUMMER BREEZE', 1, 32, 9999, 1, 3, 42, 227, NULL, 'Music: a lively reel', 50, '800  888  800  888', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (6451, '1997-09-14 22:00:00+00', '2014-04-30 23:24:12.348197+00', 'Tambourine', 'TAMBOURINE', 1, 32, 9999, 1, 3, 42, 653, NULL, '', 62, '800  888  888  888', 0, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (6680, '1997-04-03 22:00:00+00', '2019-02-05 23:14:06.13088+00', 'Travelling Dancers, The', 'TRAVELLING DANCERS', 2, 64, 9999, 1, 4, 1, 360, NULL, '', 44, '8000/8800/8000/8080/8000/8008/8000/8888', 0, 1, 1, 0, 43);
INSERT INTO 'dance' VALUES (9122, '2000-09-03 22:00:00+00', '2021-08-02 13:53:12.102562+00', 'Swelterin'' Strathspey, The', 'SWELTERIN STRATHSPEY', 3, 32, 9999, 2, 3, 17, 2440, '1999-01-01', '', 67, '808/888/800/844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (9896, '2002-03-03 23:00:00+00', '2021-01-23 23:28:52.60982+00', 'Teddybear''s Picnic', 'TEDDYBEARS PICNIC', 2, 32, 9999, 1, 4, 1, 2864, NULL, '<<scddb-not-identical:8166>>', 81, '8888/8888/8000/8888', 0, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (6362, '1998-09-29 22:00:00+00', '2020-05-27 17:41:47.967969+00', 'Struan Robertson''s Reel', 'STRUAN ROBERTSONS REEL', 1, 40, 9999, 1, 3, 42, 453, '1750-01-01', '', 50, '800  822  822  888  888', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (12792, '2006-06-25 22:00:00+00', '2020-06-27 21:31:03.57251+00', 'Sueno''s Stone', 'SUENOS STONE', 1, 32, 9999, 1, 3, 42, 153, NULL, '', 50, '800  844  844  888', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (6373, '1998-09-29 22:00:00+00', '2020-08-18 17:53:00.921959+00', 'Sugar Candie', 'SUGAR CANDIE', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 44, '800  844  822  866', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (8577, '1998-10-20 22:00:00+00', '2020-08-30 10:43:52.249464+00', 'Swashbuckling Iain', 'SWASHBUCKLING IAIN', 2, 32, 9999, 1, 2, 76, 895, '1991-01-01', '', 56, '84  88  80  88', 0, 1, 0, 0, 81);
INSERT INTO 'dance' VALUES (6417, '1997-04-03 22:00:00+00', '2020-09-03 17:57:08.95322+00', 'Sweet Mary', 'SWEET MARY', 3, 32, 9999, 1, 2, 76, 227, '1989-01-01', 'Advanced level', 47, '44  44  88  66', 0, 1, 0, 0, 68);
INSERT INTO 'dance' VALUES (8496, '2001-06-12 22:00:00+00', '2020-09-06 20:27:03.240122+00', 'Supertram', 'SUPERTRAM', 2, 32, 9999, 1, 3, 42, 2900, NULL, '', 55, '800  888  808  886', 0, 1, 0, 0, 72);
INSERT INTO 'dance' VALUES (6450, '1997-08-21 22:00:00+00', '2020-12-17 22:47:00.3534+00', 'Tamatea''s Flute', 'TAMATEAS FLUTE', 2, 32, 9999, 1, 2, 76, 108, '1991-01-01', '', 69, '88  88  88  88', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (9189, '2001-01-28 23:00:00+00', '2020-12-20 23:49:18.756065+00', 'Sunny Hogmanay', 'SUNNY HOGMANAY', 1, 32, 9999, 1, 3, 42, 244, '1998-01-01', '', 53, '800  888  888  822', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (9940, '2001-06-05 22:00:00+00', '2020-12-21 16:50:02.167201+00', 'Tak Tent', 'TAK TENT', 1, 32, 9999, 3, 5, 7, 101, '1998-01-01', 'For the 10th wedding anniversary of Morag and Nigel Fairhead in 1998.', 77, '88888  84884  82842  84844', 0, 1, 1, 0, 77);
INSERT INTO 'dance' VALUES (10817, '2002-09-09 22:00:00+00', '2020-12-24 18:14:18.23457+00', 'Sturrock Strathspey, The', 'STURROCK STRATHSPEY', 3, 32, 9999, 1, 4, 15, 3192, '2001-01-01', 'Dedicated to John and Sheena Sturrock on their farewell from Cambridge on 12 Dec 2001', 55, '8200  8444  8466  8800', 0, 1, 0, 0, 54);
INSERT INTO 'dance' VALUES (11725, '2004-06-17 22:00:00+00', '2021-01-20 18:32:43.235814+00', 'Summer Bunting', 'SUMMER BUNTING', 1, 32, 9999, 1, 3, 42, 3440, '2003-01-01', '', 50, '888  800  888  800', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (6505, '1999-10-27 22:00:00+00', '2021-03-12 23:42:41.991031+00', 'Teviot Bridge', 'TEVIOT BRIDGE', 2, 24, 9999, 1, 2, 76, 9998, NULL, '', 57, '80/88/88', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (8954, '2000-01-17 23:00:00+00', '2021-03-08 21:45:53.638483+00', 'Sunset Over Solway', 'SUNSET OVER SOLWAY', 3, 32, 9999, 1, 4, 2, 692, '1997-01-01', '', 81, '8888  8448  8008  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (11769, '2004-09-02 22:00:00+00', '2021-03-31 15:37:00.423023+00', 'Starlight', 'STARLIGHT', 1, 32, 9999, 1, 3, 42, 3429, NULL, '', 53, '822  866  888  822', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (6518, '1998-09-29 22:00:00+00', '2021-04-10 11:18:16.15537+00', 'Theeket Hoose, The', 'THEEKET HOOSE', 3, 48, 9999, 1, 2, 76, 466, NULL, 'In Thompson''s 1755 collection the title of the dance is "The Thatch''d House".', 46, '80  08  44  84  84  88', 1, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (6477, '1998-11-29 23:00:00+00', '2021-04-11 11:08:46.052238+00', 'Tartan Plaidie', 'TARTAN PLAIDIE', 3, 32, 9999, 1, 2, 76, 263, '1790-01-01', 'This dance used to carry the alternate title »Highland Plaid« in early RSCDS books but this is no longer being used.', 60, '88  88  80  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (6471, '1998-09-29 22:00:00+00', '2021-04-11 11:27:03.949714+00', 'Tarry a while', 'TARRY A WHILE', 2, 32, 9999, 1, 2, 76, 9998, NULL, 'Adapted from D Anderson: Ball-Room Guide, Dundee.', 47, '44  44  66  88', 1, 1, 0, 1, 68);
INSERT INTO 'dance' VALUES (6414, '1998-04-19 22:00:00+00', '2021-04-11 18:50:19.237751+00', 'Swans of Berneray, The', 'SWANS OF BERNERAY', 3, 32, 9999, 1, 3, 42, 227, '1989-01-01', 'Suggested music: a swanlike strathspey, strong and beautiful lines.



For Renske, who spent a happy week on Berneray in 1986', 66, '444  888  888  888', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (6391, '1998-09-29 22:00:00+00', '2021-04-11 23:19:58.594809+00', 'Sunday Morning', 'SUNDAY MORNING', 1, 32, 9999, 1, 4, 13, 489, '1981-01-01', '', 81, '8000  8888  8888  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (6386, '1998-09-29 22:00:00+00', '2021-04-12 21:58:58.415877+00', 'Summer Wooing', 'SUMMER WOOING', 1, 32, 9999, 1, 3, 42, 246, NULL, '', 56, '880  888  880  880', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14527, '2012-07-22 14:02:24.944987+00', '2014-04-30 23:24:12.48454+00', 'Tempest in a Teacup', 'TEMPEST IN A TEACUP', 1, 64, NULL, 2, 104, 17, 2677, NULL, 'Deviser’s note: Although this is a 64-bar dance, the music is specified as 6 x 32 because it is really a 32-bar dance with a twist in the repeat. After 32 bars 1st couple is ready to »repeat, having passed a couple,« but the repeat is danced as if the set were turned upside down.



From the Deviser.  »The tempest figure was inspired by a friend’s science demonstration. Take a cup of black tea, stir it briskly until a whirlpool forms, remove the spoon, pour a small amount of milk into the center of the cup, and observe. This also works with a mug of coffee.«', 75, '880  440  880  440  888', 1, 1, 1, 1, 37);
INSERT INTO 'dance' VALUES (18931, '2018-10-09 15:24:14.373135+00', '2018-10-09 15:24:14.373135+00', 'Wheels within Wheels', 'WHEELS WITHIN WHEELS', 1, 32, NULL, 1, 3, 42, 2766, '2008-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13314, '2007-07-26 22:00:00+00', '2014-04-30 23:24:12.560149+00', 'Thank You Helen', 'THANK YOU HELEN', 3, 32, 9999, 2, 3, 17, 3775, '2007-05-12', '', 48, '404  282  282  455', 1, 1, 1, 0, 47);
INSERT INTO 'dance' VALUES (6349, '1999-11-01 23:00:00+00', '2017-07-07 13:05:16.069021+00', 'Strathglass House', 'STRATHGLASS HOUSE', 3, 32, 9999, 1, 3, 42, 442, '1757-01-01', '', 47, '888  800  822  844', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (17908, '2017-08-03 17:07:32.6374+00', '2017-08-03 17:07:32.6374+00', 'Sixpack', 'SIXPACK', 1, 32, NULL, 2, 3, 17, 11514, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6431, '1998-04-19 22:00:00+00', '2019-03-09 20:08:28.808473+00', 'Tae Fife And Back', 'TAE FIFE AND BACK', 2, 32, 9999, 1, 4, 1, 146, NULL, '', 69, '4444  4444  8888  8088', 0, 1, 0, 0, 68);
INSERT INTO 'dance' VALUES (6420, '1998-09-29 22:00:00+00', '2019-03-09 23:50:59.397399+00', 'Swilcan, The', 'SWILCAN', 2, 32, 9999, 1, 4, 1, 87, NULL, '', 75, '8448/8888/8448/6082', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14606, '2012-12-13 22:37:29.769944+00', '2014-04-30 23:24:12.620912+00', 'There and Back Again', 'THERE AND BACK AGAIN', 2, 32, NULL, 1, 3, 42, 3715, NULL, 'Source of information: see Strathspey message 57311 by Margaret Allen.  No publication known.  Issy Bristow is from the Ribble Valley branch.', 37, '800  800  800  888', 0, 1, 1, 0, 50);
INSERT INTO 'dance' VALUES (13922, '2011-08-22 22:00:00+00', '2018-04-17 14:25:39.749263+00', 'Muriel''s Magic', 'MURIELS MAGIC', 2, 32, NULL, 1, 3, 42, 3179, '2003-01-01', 'Devised by Wouter Joubert, 2003 (bars 25-32 revised June 2007).



In honour of Muriel Johnstone and her piano magic.



Notes:  

In this dance 2nd couple start each repeat.  

Therefore the couples who start the dance from 2nd place the 2nd, 4th and 6th times round must be aware that they will be starting the 3rd, 5th and 7th times round from 2nd position as well.  

At the end of the 2nd repeat 1st and 4th couple must promptly step down/up to allow the new 2nd couple space for leading down and crossing below 3rd place.', 64, '820/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12038, '2005-02-20 23:00:00+00', '2018-04-02 23:56:38.090435+00', 'Tracey''s Wedding Jig', 'TRACEYS WEDDING JIG', 2, 32, 9999, 1, 3, 42, 777, NULL, '', 41, '800  822  844  844', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (15463, '2014-06-09 19:47:19.552852+00', '2018-04-03 00:08:15.068297+00', 'Saxtead Mill, The', 'SAXTEAD MILL', 2, 32, NULL, 1, 3, 42, 10965, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12036, '2005-02-20 23:00:00+00', '2018-08-08 22:08:36.451526+00', 'Kiss the Lass ye Like Best', 'KISS THE LASS YE LIKE BEST', 3, 32, 9999, 2, 2, 76, 777, NULL, 'In the Montreal book this is a 2C/3L dance.', 64, '84/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (878, '1997-04-03 22:00:00+00', '2018-08-19 14:40:39.543989+00', 'Burnside', 'BURNSIDE', 3, 32, 9999, 1, 2, 76, 28, NULL, 'To Joan and Leon Morris, who both taught the Westbury Scottish Club and organised many social events.', 44, '80/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9013, '2002-02-16 23:00:00+00', '2014-04-30 23:24:12.780422+00', 'Thornhill Strathspey, The', 'THORNHILL STRATHSPEY', 3, 32, 9999, 2, 3, 17, 146, NULL, '', 77, '844  888  844  846', 0, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (18481, '2018-07-26 10:14:18.775546+00', '2018-09-26 07:09:23.346649+00', 'Salute to Scottish Country Dancing Musicians', 'SALUTE TO SCOTTISH COUNTRY DANCING MUSICIANS', 1, 40, NULL, 1, 3, 42, 2886, NULL, '', 52, '844/888/800/822/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6577, '1998-11-07 23:00:00+00', '2014-04-30 23:24:12.898223+00', 'Three Sisters, The', 'THREE SISTERS', 3, 32, 9999, 1, 3, 42, 108, '1971-01-01', '', 62, '888  888  880  880', 1, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (11295, '2003-05-04 22:00:00+00', '2014-04-30 23:24:13.004754+00', 'Toad of Toad Hall', 'TOAD OF TOAD HALL', 1, 32, 9999, 1, 3, 42, 2783, '2001-02-01', '', 53, '800  844  866  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (6523, '1998-09-29 22:00:00+00', '2020-07-12 22:12:51.392744+00', 'There''s Nae Luck aboot the Hoose', 'THERES NAE LUCK ABOOT THE HOOSE', 3, 32, 9999, 1, 3, 42, 432, '1816-01-01', '', 44, '800  844  822  866', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (8238, '2005-05-29 22:00:00+00', '2020-12-19 14:27:19.095142+00', 'Sweetness of Heather, The', 'SWEETNESS OF HEATHER', 3, 32, 9999, 1, 3, 42, 1393, '2004-01-01', '', 62, '800  888  888  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (9643, '2000-09-05 22:00:00+00', '2020-09-09 09:49:32.539664+00', 'Susanne''s Strathspey', 'SUSANNES STRATHSPEY', 3, 32, 9999, 1, 2, 76, 146, '2000-01-01', '', 60, '88  44  88  88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (6424, '2002-02-28 23:00:00+00', '2020-12-17 22:43:44.106154+00', 'Swing of the Kilt, The', 'SWING OF THE KILT', 1, 32, 9999, 1, 4, 1, 406, '1966-01-01', '', 62, '8880/8800/12 12 12  0/4000', 1, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (9484, '2000-09-04 22:00:00+00', '2020-12-21 11:11:18.664934+00', 'Whirlybird', 'WHIRLYBIRD', 2, 32, 9999, 1, 3, 42, 2766, '1999-02-01', '', 44, '800  644  077  855', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (10601, '2002-06-19 22:00:00+00', '2020-12-24 10:25:39.205792+00', 'Tête à Tête in Paris', 'TETE A TETE IN PARIS', 3, 32, 9999, 1, 2, 76, 2847, '2002-01-01', 'Devised for the Ball »Cologne meets Europe«, 28th of September 2002.', 60, '88  88  88  80', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (13228, '2007-01-19 23:00:00+00', '2020-12-25 21:37:22.37207+00', 'Tanz Mit Uns', 'TANZ MIT UNS', 2, 32, 9999, 1, 3, 42, 2961, '2007-01-01', '', 44, '880  880  844  800', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (7527, '1998-04-24 22:00:00+00', '2021-01-09 11:42:09.589045+00', 'Thornycroft', 'THORNYCROFT', 1, 32, 9999, 1, 2, 76, 146, NULL, '', 43, '44  44  80  88', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (18937, '2018-10-09 15:48:54.428083+00', '2021-01-22 00:00:40.854234+00', 'Winter Lace', 'WINTER LACE', 1, 32, NULL, 1, 3, 42, 2766, '2007-01-01', '', 50, '800/844/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10877, '2002-10-29 23:00:00+00', '2021-02-04 12:11:17.202392+00', 'Temptation', 'TEMPTATION', 3, 32, 9999, 1, 3, 42, 3645, '2002-01-01', '', 56, '880  880  848  848', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (8715, '1999-08-06 22:00:00+00', '2021-03-14 23:23:08.033015+00', 'Time for Change, A', 'TIME FOR CHANGE', 1, 32, 9999, 1, 4, 2, 479, '1996-01-01', '', 69, '8888  8008  8448  8008', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (9052, '2002-10-28 23:00:00+00', '2021-03-14 00:31:45.965399+00', 'Thormanby Strathspey, The', 'THORMANBY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 854, NULL, '', 56, '800/888/844/888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (6484, '1998-11-25 23:00:00+00', '2021-04-10 11:36:44.351275+00', 'Tattie Bogle, The', 'TATTIE BOGLE', 2, 32, 9999, 1, 3, 42, 175, '1991-01-01', 'A Tattie Bogle is a scarecrow.', 50, '800  844  844  888', 0, 1, 0, 1, 66);
INSERT INTO 'dance' VALUES (6550, '2002-05-04 22:00:00+00', '2021-04-09 10:50:50.437185+00', 'Thistle Welcome', 'THISTLE WELCOME', 1, 32, 9999, 1, 3, 42, 1253, '1978-01-01', 'Devised for the first of our annual charity concerts, "Thistle Show ''78".', 50, '800  844  844  888', 1, 1, 0, 1, 66);
INSERT INTO 'dance' VALUES (9417, '2002-09-22 22:00:00+00', '2021-07-30 08:19:51.107123+00', 'Tartan Rainbow', 'TARTAN RAINBOW', 3, 32, 9999, 2, 3, 18, 308, NULL, '', 46, '484  484  888  080', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (14619, '2012-12-17 23:57:32.241407+00', '2014-04-30 23:24:13.125598+00', 'Torquay Gathering, The', 'TORQUAY GATHERING', 1, 32, NULL, 1, 3, 42, 2627, '2012-01-01', '', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (6658, '1999-10-27 22:00:00+00', '2014-04-30 23:24:13.169265+00', 'Torryburn Lassies', 'TORRYBURN LASSIES', 1, 32, 9999, 1, 2, NULL, 9998, NULL, '', 52, '84  84  80  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (10644, '2002-07-04 22:00:00+00', '2019-02-07 22:54:59.720919+00', 'Thornwood Strathspey, The', 'THORNWOOD STRATHSPEY', 3, 32, 9999, 2, 3, 17, 1415, NULL, '', 90, '828/888/888/488', 1, 1, 1, 1, 89);
INSERT INTO 'dance' VALUES (6662, '1997-09-16 22:00:00+00', '2019-03-09 14:06:11.802478+00', 'Touch Me Not', 'TOUCH ME NOT', 2, 32, 9999, 1, 4, 1, 108, '1986-01-01', '', 59, '4662  4662  8800  8484', 0, 1, 0, 0, 59);
INSERT INTO 'dance' VALUES (15465, '2014-06-09 19:53:16.132038+00', '2015-03-03 10:05:49.638256+00', 'Ann of West Lodge', 'ANN OF WEST LODGE', 1, 32, NULL, 1, 3, 42, 10966, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6650, '1997-09-16 22:00:00+00', '2016-09-04 19:56:29.754127+00', 'Top, The', 'TOP', 2, 24, 9999, 1, 2, 76, 351, NULL, 'This dance was inspired by the American square-dance figure "Spin the Top" (bars 5-8).', 100, '88  88  88', 0, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (6539, '1998-09-29 22:00:00+00', '2017-11-12 21:57:59.033483+00', 'This is no'' my ain Hoose', 'THIS IS NO MY AIN HOOSE', 3, 32, 9999, 1, 3, 42, 9998, '1715-02-01', '', 34, '844  800  800  822', 0, 1, 0, 0, 45);
INSERT INTO 'dance' VALUES (14569, '2012-09-08 22:40:55.612524+00', '2014-08-13 02:47:19.96396+00', 'Double the Trouble', 'DOUBLE THE TROUBLE', 1, 32, NULL, 8, 105, 12, 10657, '2007-03-01', 'This is a doubled version of "3 Feisty Women".



Devised in the Cleveland Heights Group, spring 2007



', 67, '880088  888888  800008  844448', 0, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (9785, '2001-03-13 23:00:00+00', '2022-09-30 21:34:20.538197+00', 'Timepiece', 'TIMEPIECE', 2, 32, 9999, 1, 3, 42, 389, '1990-01-01', '', 62, '800  888  888  888', 1, 1, 0, 1, 83);
INSERT INTO 'dance' VALUES (6436, '1997-04-03 22:00:00+00', '2022-08-12 22:09:28.760842+00', 'Tak The Gate', 'TAK THE GATE', 1, 32, 9999, 1, 4, 1, 181, '1987-01-01', 'The subtitle is "To Depart or Leave". Devised "for the TAC Weekend and AGM. in Vancouver, 1987."', 84, '7777  4444  8888  8888', 1, 1, 0, 1, 84);
INSERT INTO 'dance' VALUES (6637, '1998-01-12 23:00:00+00', '2022-11-01 18:55:40.488567+00', 'Togetherness', 'TOGETHERNESS', 1, 32, 9999, 1, 3, 42, 108, '1988-01-01', 'Inscribed "for Scott Harmon of Callfornia who likes to stay with his partner in a dance".', 62, '16 16 16  844  844', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (14681, '2013-01-23 11:32:25.214738+00', '2023-01-16 10:59:59.73391+00', 'Three Score and Ten', 'THREE SCORE AND TEN', 3, 32, NULL, 1, 4, 1, 10722, '2006-02-01', 'To mark our 70th anniversary; bars 1-16 representing the 7, the circle at the end representing the 0.', 91, '8888  8888  8444  8888', 1, 1, 1, 0, 90);
INSERT INTO 'dance' VALUES (13920, '2011-08-22 22:00:00+00', '2018-04-17 16:35:40.314077+00', 'Moroccan Magic', 'MOROCCAN MAGIC', 1, 32, NULL, 1, 3, 42, 3254, '2004-04-01', 'Devised by Terry Lynne Harris, Pretoria, April 2004.



For Martin and Geneviève Sheffield (of Grenoble, France), who met in Morocco.', 47, '880/844/866/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8809, '2001-11-07 23:00:00+00', '2018-08-08 23:21:49.778639+00', 'Salute to Glasgow', 'SALUTE TO GLASGOW', 3, 32, 9999, 1, 3, 42, 640, NULL, 'Originally, the instructions for bars 9–16 read “2nd, 1st and 3rd couples dance the knot and finish facing 1st corners”. “And finish facing 1st corners” was omitted from the actual book, but it has always been John Johnston''s intention for 1st couple to finish facing 1st corners. (Maureen Daniel)', 64, '882/888/844/888', 1, 1, 1, 1, 85);
INSERT INTO 'dance' VALUES (9675, '2000-09-18 22:00:00+00', '2014-04-24 11:29:29.766435+00', 'Waltzing to Iowa', 'WALTZING TO IOWA', 5, 32, 9999, 7, 1, 4, 1268, '1993-01-01', '', 100, '8  8  8  8', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14656, '2013-01-05 11:25:49.095147+00', '2018-04-03 00:08:22.456701+00', 'Trip to Delft, A', 'TRIP TO DELFT', 1, 32, NULL, 1, 3, 42, 3645, NULL, '', 50, '800  888  844  844', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (6734, '1998-09-29 22:00:00+00', '2014-04-30 23:24:13.644765+00', 'Trip to the Drakensberg, A', 'TRIP TO THE DRAKENSBERG', 2, 40, 9999, 1, 3, 42, 447, NULL, '', 55, '800  880  844  888  888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (6763, '1999-08-11 22:00:00+00', '2014-04-30 23:24:13.720741+00', 'Tulloch gorm', 'TULLOCH GORM', 3, 32, 9999, 1, 3, 42, 263, '1796-01-01', '', 56, '888  888  800  880', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (3252, '1998-10-20 22:00:00+00', '2019-05-10 08:40:16.602214+00', 'Tomalena', 'TOMALENA', 1, 32, 9999, 3, 5, 7, 587, '1984-01-01', 'Devised in 1984 for Thomas and Helena Garvie upon their retirement both from work and as driving-force teachers of the SCD class on the Monterey Peninsula', 65, '80800/88888/80800/80888', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (9049, '2002-10-28 23:00:00+00', '2020-06-27 16:51:06.813921+00', 'Threave Reel', 'THREAVE REEL', 1, 32, 9999, 1, 3, 42, 2623, NULL, '', 47, '800  888  822  880', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (6687, '2002-04-15 22:00:00+00', '2020-07-12 22:10:56.162662+00', 'Treasure Island Jig', 'TREASURE ISLAND JIG', 2, 32, 9999, 1, 3, 42, 118, '1984-01-01', '', 62, '880  880  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (14668, '2013-01-21 23:39:55.457735+00', '2020-10-01 17:43:40.406406+00', 'Tribute to John Middleton', 'TRIBUTE TO JOHN MIDDLETON', 1, 32, NULL, 1, 3, 42, 2497, NULL, '', 50, '800  888  888  800', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (14669, '2013-01-21 23:41:46.805898+00', '2020-10-01 17:46:39.737321+00', 'Travelling Piano, The', 'TRAVELLING PIANO', 4, 32, 1, 1, 3, 42, 10647, NULL, '', 53, '800  822  888  888', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (14748, '2013-03-24 14:17:11.077203+00', '2020-10-01 18:20:11.793704+00', 'Trio, The', 'TRIO', 3, 40, NULL, 2, 3, 17, 3444, NULL, '', 55, '800  844  888  844  888', 0, 1, 0, 0, 73);
INSERT INTO 'dance' VALUES (6599, '1998-09-29 22:00:00+00', '2020-12-18 20:09:08.363391+00', 'Tibby Fowler o'' the Glen', 'TIBBY FOWLER O THE GLEN', 3, 32, 9999, 1, 3, 42, 9998, '1804-01-01', '', 55, '880  886  880  880', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (9833, '2001-11-25 23:00:00+00', '2020-12-21 16:41:47.590292+00', 'Tungsten Turkey', 'TUNGSTEN TURKEY', 1, 32, 9999, 1, 3, 42, 2766, '2001-04-01', 'This dance was inspired by the name Oberdan Otto uses when he refers to a well-known dance he does not care for.', 50, '842/844/822/866', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (10775, '2002-09-25 22:00:00+00', '2021-02-05 12:51:30.230829+00', 'This Way Up', 'THIS WAY UP', 2, 32, 9999, 2, 3, 46, 175, NULL, '', 83, '880  880  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (9998, '2001-07-19 22:00:00+00', '2021-02-14 12:22:00.974724+00', 'Tom and Anja''s Silver Wedding', 'TOM AND ANJAS SILVER WEDDING', 3, 40, 9999, 1, 3, 42, 1049, '1995-01-01', '', 62, '800  833  833  888  488', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (7529, '2002-04-15 22:00:00+00', '2021-03-25 23:51:22.690831+00', 'Tomtain Brae', 'TOMTAIN BRAE', 2, 32, 9999, 1, 4, 1, 146, NULL, '', 69, '8880  8880  8000  8888', 0, 1, 0, 0, 68);
INSERT INTO 'dance' VALUES (6816, '1997-12-07 23:00:00+00', '2021-04-05 10:49:55.82899+00', 'Twizell Bridge', 'TWIZELL BRIDGE', 2, 32, 9999, 1, 3, 42, 146, '1980-01-01', 'From the notes: "Twizell Bridge is a high, single-arch bridge which spans the river Till shortly before it joins the Tweed near Coldstream."', 50, '822  822  866  866', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (6711, '1998-09-29 22:00:00+00', '2021-04-05 13:22:29.882425+00', 'Trip to Aberdeen, A', 'TRIP TO ABERDEEN', 2, 32, 9999, 1, 3, 42, 453, '1756-01-01', '', 48, '402  888  844  844', 1, 1, 1, 1, 64);
INSERT INTO 'dance' VALUES (6710, '1998-09-29 22:00:00+00', '2021-04-05 13:26:49.469792+00', 'Trip o''er the Tweed, A', 'TRIP OER THE TWEED', 2, 48, 9999, 1, 3, 42, 446, '1728-01-01', '', 42, '844  844  800  880  880  800', 1, 1, 1, 1, 55);
INSERT INTO 'dance' VALUES (6707, '2000-07-25 22:00:00+00', '2021-04-05 13:30:07.798995+00', 'Trinity Tensome', 'TRINITY TENSOME', 1, 40, 9999, 3, 5, 16, 200, NULL, '', 56, '00800  88888  08880  80808  80800', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (6638, '2002-02-16 23:00:00+00', '2021-04-05 20:15:12.918489+00', 'Tolsta Rant, The', 'TOLSTA RANT', 2, 32, 9999, 3, 5, 7, 141, NULL, '', 75, '80800  84884  84866  88888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (12637, '2005-11-08 23:00:00+00', '2021-06-06 19:17:59.146979+00', 'Tripitup Troupe, The', 'TRIPITUP TROUPE', 2, 32, 9999, 1, 3, 42, 3379, '2002-01-01', '', 53, '822  844  844  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (6771, '1997-09-17 22:00:00+00', '2014-04-30 23:24:13.782672+00', 'Turkey Trot', 'TURKEY TROT', 1, 32, 9999, 1, 3, 42, 758, '1990-01-01', '', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (6791, '2002-06-02 22:00:00+00', '2014-04-30 23:24:13.812936+00', 'Twa Meenit Reel, The', 'TWA MEENIT REEL', 1, 32, 9999, 1, 4, 1, 82, '1974-01-01', '', 62, '2222  4444  2222  6666  8444', 0, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (13210, '2006-12-15 23:00:00+00', '2014-04-30 23:24:13.858214+00', 'Twelfth Night Revels', 'TWELFTH NIGHT REVELS', 2, 40, 9999, 1, 3, 42, 2672, NULL, '', 61, '820  880  888  888  888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (14541, '2012-08-19 11:56:38.046828+00', '2015-02-24 15:38:05.283895+00', 'Tribute to Amanda', 'TRIBUTE TO AMANDA', 1, 32, NULL, 1, 3, 42, 10645, '2012-02-27', 'This dance is dedicated to Amanda Peart for her hard work organising a Dancing Holiday in Lagos Portugal. The  dance was performed by those on the holiday at the Vila Gale Hotel on 27th February 2012', 45, '855  448  804  840', 1, 1, 1, 0, 60);
INSERT INTO 'dance' VALUES (6793, '1997-04-03 22:00:00+00', '2018-04-03 00:08:22.982025+00', 'Twa Sparkling Een', 'TWA SPARKLING EEN', 2, 32, 9999, 1, 3, 42, 44, NULL, '', 62, '888  800  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (6768, '1998-01-05 23:00:00+00', '2016-07-28 21:26:41.45802+00', 'Tullyvolan', 'TULLYVOLAN', 1, 32, 9999, 3, 5, 7, 313, NULL, '', 85, '04840/88888/88888/88888', 1, 1, 1, 0, 85);
INSERT INTO 'dance' VALUES (15027, '2013-08-02 15:49:47.224737+00', '2014-07-25 23:04:49.046093+00', 'Trip to Sucker Bay, A', 'TRIP TO SUCKER BAY', 2, 32, NULL, 1, 3, 42, 431, '1986-01-01', '', 62, '888/888/888/800', 1, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (8842, '2002-04-24 22:00:00+00', '2014-04-30 23:24:14.070979+00', 'Underpass, The', 'UNDERPASS', 2, 32, 9999, 1, 4, 2, 663, NULL, '', 69, '8008  0880  8888  8448', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (17957, '2017-09-25 19:10:15.165125+00', '2018-09-26 22:49:53.338952+00', 'Customs Made', 'CUSTOMS MADE', 1, 40, NULL, 1, 3, 42, 10568, '2016-08-01', 'I wrote this for my son David and his wife Élaine to celebrate their marriage. They met while working

at Canada Customs during their university breaks and it was love at first sight (*Holly Boyd*)', 63, '884/844/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17909, '2017-08-05 13:14:33.809748+00', '2017-08-05 13:14:33.809748+00', 'Monday Night', 'MONDAY NIGHT', 1, 32, NULL, 2, 3, 17, 11514, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6792, '1997-04-03 22:00:00+00', '2022-01-30 19:16:16.521462+00', 'Twa Rogueish Een', 'TWA ROGUEISH EEN', 2, 40, 9999, 1, 3, 42, 108, '1967-01-01', '', 50, '680/800/864/888/880', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (10857, '2002-11-01 23:00:00+00', '2022-09-30 12:03:40.340489+00', 'Uphill', 'UPHILL', 2, 32, 9999, 1, 2, 76, 227, '1998-01-01', '', 54, '88  82  88  80', 1, 1, 1, 1, 78);
INSERT INTO 'dance' VALUES (9770, '2002-04-03 22:00:00+00', '2022-09-30 21:36:00.047788+00', 'Tri-Mariner, The', 'TRIMARINER', 1, 32, 9999, 1, 3, 42, 104, '1993-01-01', '', 58, '864/888/800/888', 1, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (6721, '1998-09-29 22:00:00+00', '2022-11-01 18:06:21.936568+00', 'Trip to Holland, A', 'TRIP TO HOLLAND', 3, 32, 9999, 1, 3, 42, 263, '1794-01-01', '', 31, '880  440  800  800', 1, 1, 0, 1, 41);
INSERT INTO 'dance' VALUES (14975, '2013-07-03 22:18:25.94564+00', '2014-04-30 23:24:14.265736+00', 'Vintage Simon', 'VINTAGE SIMON', 2, 32, NULL, 3, 5, 59, 1727, NULL, 'For Simon Scott, at the request of the Gleneagles Scottish Dance Group, West Vancouver, to celebrate his 50 year as a teacher of Scottish Country Dance.', 62, '80808  86338  86338  84448', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (8466, '1997-12-28 23:00:00+00', '2019-03-06 18:51:37.786236+00', 'Walking Thru'' the Bracken', 'WALKING THRU THE BRACKEN', 2, 32, 9999, 1, 4, 1, 872, NULL, '', 66, '8888  8080  0808  8444', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (7531, '1998-01-05 23:00:00+00', '2019-03-07 22:45:54.162717+00', 'Unicef Circle, The', 'UNICEF CIRCLE', 1, 88, 9999, 4, 4, 3, 146, '1995-01-01', '', 45, '4040  4040  0404  0404    8080  8080  0808  0808    4444  4444  8888', 0, 1, 0, 0, 45);
INSERT INTO 'dance' VALUES (6894, '2002-04-15 22:00:00+00', '2014-04-30 23:24:14.346608+00', 'Vital Spark', 'VITAL SPARK', 2, 32, 9999, 1, 3, 42, 2619, '1995-01-01', 'Copyright Northallerton Caledonian Society 1995', 59, '800  866  888  888', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (6748, '1998-11-07 23:00:00+00', '2019-03-09 14:00:24.356606+00', 'Triumph, The', 'TRIUMPH', 1, 24, 9999, 1, 4, 1, 1517, '1827-01-01', '', 33, '8000  8800  8000', 1, 1, 1, 1, 33);
INSERT INTO 'dance' VALUES (6848, '1998-09-29 22:00:00+00', '2018-04-03 00:08:23.448965+00', 'Up in the Air', 'UP IN THE AIR', 3, 32, 9999, 1, 3, 42, 457, '1797-01-01', '', 61, '811  888  866  888', 0, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (6712, '2002-11-21 23:00:00+00', '2021-03-01 02:18:34.659884+00', 'Trip to Bavaria, A', 'TRIP TO BAVARIA', 1, 32, 9999, 1, 4, 1, 240, '1960-01-01', '##RSCDS-DI:omit-ta

The dance has been dated 1960 by an original handwritten copy of this dance by James MacGregor-Brown owned by Stephen Webb.



It should perhaps be added that the title of this dance was originally "Eine Reise nach Bayern".



There is quite some discussion on details.  Do 3c and 4c face up from bar 17 or only when they start setting?  Does 1c switch sides RH or BH on bar 30?  There were over 280 posts on "strathspey" Mailing List from the mid-1990s to recently.  The deviser''s original says "face across till you start setting" and "RH", but many local traditions keep to "face up from bar 17" and "BH".  



In a Strathspey "Q&A" from 2011 (see the URL below) the deviser says:



> You asked me about a leaflet copy of A Trip to Bavaria. I could not refer you to one, as I have

> never published it in anything other than the Collins book and the companion video, in which, as I

> believe I may have mentioned, it is danced to the original tune; that is to say, mine. However, I’m

> delighted that the group [i.e. TACBooks], to whose site you referred me, makes it available to

> others who may enjoy the dance. Their leaflet does, as you point out, call for a two-handed turn.

>

> Just a word on that:

>

> Being, as they call it, “a full certificate teacher”, when “grooming” dancers for theatrical

> presentations, I use my original deft almost surreptitious one, i.e., RIGHT hand turn. Ideally the

> turn should be tight and fully effected, in the middle of the set, so that the impression is given to

> the audience, of a preferably unnoticed “correction“ of side, for couple number one.

>

> HOWEVER...

>

> This nicety is not called for, when we are dancing just for pleasure and delight – what better

> reason!? So, as I have already recommended, dancers should dance ‘that bit’ in whatever way

> they like best.



There is also a discussion on the tune.



The deviser wrote a tune »A Trip to Bavaria / Eine Reise nach Bayern«, but he has not replied to requests (in 2011) for the notes or for a publication where it can be found.  The deviser does not approve of the now mostly used tune "The Remmerts of Herford".    



For details see <<http://qa.strathspey.org/questions/5/whats-the-name-of-the-tune-for-a-trip-to-bavaria>>



Eric Ferguson, 2012. ', 81, '8888  8888  8440  8448', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (6835, '1997-09-16 22:00:00+00', '2020-12-18 20:11:27.187296+00', 'Under The Arches', 'UNDER THE ARCHES', 1, 32, 9999, 1, 4, 1, 1332, NULL, '', 75, '8008  0880  8888  8888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (16315, '2015-05-09 12:22:32.799626+00', '2021-01-06 00:13:44.25886+00', 'Going Lightly', 'GOING LIGHTLY', 3, 32, 9999, 2, 3, 18, 11133, '2010-01-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12743, '2006-05-11 22:00:00+00', '2021-01-09 21:24:39.04209+00', 'Visit to the Estate, A', 'VISIT TO THE ESTATE', 3, 32, 9999, 1, 3, 42, 1445, '2006-01-01', '', 44, '800  880  822  866', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (12246, '2005-04-19 22:00:00+00', '2021-01-15 11:48:33.460095+00', 'Victoria Plums', 'VICTORIA PLUMS', 3, 32, 9999, 1, 4, 2, 108, '2004-01-01', '', 69, '4444  8888  4884  8008', 0, 1, 0, 0, 68);
INSERT INTO 'dance' VALUES (10602, '2002-06-19 22:00:00+00', '2021-02-06 13:07:03.234626+00', 'Visit in Rome', 'VISIT IN ROME', 2, 32, 9999, 1, 2, 76, 2847, '2002-01-01', 'Devised for the Cologne Ball »Cologne meets Europe«, 28th September 2002.', 60, '80  88  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (9158, '1999-11-04 23:00:00+00', '2021-03-01 11:04:14.455864+00', 'Wednesday Welcome', 'WEDNESDAY WELCOME', 1, 32, 9999, 7, 1, 4, 2677, NULL, 'or jig.', 100, '8  8  8  8', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9899, '2001-11-25 23:00:00+00', '2021-06-08 10:10:43.460718+00', 'Two Peas in a Pod', 'TWO PEAS IN A POD', 1, 32, 9999, 1, 3, 42, 479, '2000-01-01', '', 41, '800  800  822  888', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (6919, '1998-07-08 22:00:00+00', '2021-04-03 19:19:46.989735+00', 'Wapenshaw, The', 'WAPENSHAW', 2, 32, 9999, 1, 100, 2, 108, '1979-01-01', '', 75, '8008  8008  8888  8888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (6913, '2002-04-19 22:00:00+00', '2021-04-03 19:26:32.92837+00', 'Walled Garden, The', 'WALLED GARDEN', 3, 32, 9999, 1, 2, 76, 146, NULL, '', 51, '88  44  80  88', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (6797, '1998-09-29 22:00:00+00', '2021-04-05 10:59:22.673873+00', 'Tweedside', 'TWEEDSIDE', 100, 36, 9999, 1, 3, 42, 9998, '1748-01-01', '6 or 12 bar phrases.', 50, '330  330   12 12 0   12 12 12', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (6736, '1998-09-29 22:00:00+00', '2021-04-05 13:16:18.966958+00', 'Trip to the Netherlands, A', 'TRIP TO THE NETHERLANDS', 1, 40, 9999, 1, 3, 42, 181, '1982-01-01', 'Inscribed to the Thistle Club of SCD, Eindhoven.



', 54, '800  855  888  888  444', 1, 1, 0, 1, 71);
INSERT INTO 'dance' VALUES (6720, '1997-11-18 23:00:00+00', '2021-04-05 13:20:04.01972+00', 'Trip to Glasgow, A', 'TRIP TO GLASGOW', 2, 32, 9999, 1, 2, 76, 9998, NULL, 'A Trip to Glasgow (together with Frost and Snow) were the two new dances taught by Jean Milligan at the Palace of Art in Glasgow on 3 December 1977. Jean Milligan died in 1978 and this was the last time she taught in Glasgow.', 52, '44  44  88  88', 0, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (6845, '2002-05-04 22:00:00+00', '2021-06-12 18:06:29.964748+00', 'Up And Coming', 'UP AND COMING', 1, 32, 9999, 1, 3, 42, 1253, '1994-01-01', 'A tribute to the young people of The Thistle Society.', 47, '602/646/888/840', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (14577, '2012-09-14 05:35:48.10905+00', '2021-08-02 18:46:52.525019+00', 'Ute and Tris', 'UTE AND TRIS', 1, 32, NULL, 3, 5, 7, 10451, '2012-01-01', '', 55, '80800  82842  84884  80800', 0, 1, 1, 0, 55);
INSERT INTO 'dance' VALUES (14667, '2013-01-21 23:15:20.384384+00', '2019-07-17 19:28:42.385489+00', 'Warren, The', 'WARREN', 1, 28, NULL, 1, 2, 76, 3690, NULL, '', 51, '44/88/88/42', 1, 1, 1, 0, 82);
INSERT INTO 'dance' VALUES (18486, '2018-07-27 23:35:21.42341+00', '2018-08-09 17:23:28.503128+00', 'Wedding Toast, The', 'WEDDING TOAST', 1, 96, NULL, 4, 4, 3, 11673, NULL, 'The youtube video comment says this was "presumably written by Paul Suttie and Kate Gentles". This is now verified.', 81, '8888/8888/8484/8888/4444/4444/4444/4444/8888/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7139, '2002-02-28 23:00:00+00', '2014-04-24 11:29:31.128647+00', 'Wicked Willy', 'WICKED WILLY', 1, 32, 9999, 1, 4, 1, 406, '1971-01-01', '', 69, '8008  8888  8448  4084', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11813, '2004-10-05 22:00:00+00', '2014-04-30 23:24:14.709046+00', 'Wedding Guests', 'WEDDING GUESTS', 2, 40, 9999, 4, 4, 1, 3135, '2004-10-01', 'No tune specified.', 80, '8080  0808  8888  8888  8888', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (7018, '2002-11-12 23:00:00+00', '2019-10-28 07:52:00.291549+00', 'Welcome Reel, The', 'WELCOME REEL', 1, 32, 9999, 5, 2, 76, 1349, NULL, '', 75, '88  44  44  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (13706, '2011-07-04 22:00:00+00', '2014-04-30 23:24:14.912028+00', 'Welcome to Bluebell', 'WELCOME TO BLUEBELL', 2, 32, NULL, 1, 4, 1, 10357, NULL, '', 72, '8888  8888  8000  8444', 0, 1, 1, 0, 71);
INSERT INTO 'dance' VALUES (13730, '2011-07-10 22:00:00+00', '2018-04-02 23:56:38.507575+00', 'Welcome to Ayr', 'WELCOME TO AYR', 2, 32, NULL, 1, 3, 42, 10807, NULL, 'Written in recognition of the warm welcome Jill and Kathy received from Ayr Branch Members when they moved to Ayrshire', 50, '880  844  844  844', 0, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (15543, '2014-07-27 13:05:55.959183+00', '2014-07-27 13:05:55.959183+00', 'Doublet, The', 'DOUBLET', 3, 32, NULL, 2, 3, 17, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16387, '2015-05-21 15:08:54.839957+00', '2015-05-21 15:08:54.839957+00', 'Guise, The', 'GUISE', 3, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14647, '2013-01-05 07:58:39.473724+00', '2020-12-26 10:42:48.617422+00', 'Welcome to Lidewij', 'WELCOME TO LIDEWIJ', 2, 32, NULL, 1, 3, 42, 3135, '2009-01-01', '', 50, '804  840  888  844', 1, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (9804, '2001-03-26 22:00:00+00', '2020-12-21 16:31:01.445773+00', 'Wedding in Saint Monans', 'WEDDING IN SAINT MONANS', 2, 32, 9999, 1, 3, 42, 50, '1999-01-01', '', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (13728, '2011-07-09 22:00:00+00', '2020-09-19 21:08:22.012999+00', 'Welcome to Higham Hall', 'WELCOME TO HIGHAM HALL', 1, 32, NULL, 5, 2, 76, 175, NULL, 'Higham Hall is a residential Adult Education Centre in Cumbria, where many happy Hogmanays have been celebrated.', 87, '88  88  44  88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (6939, '1997-09-16 22:00:00+00', '2020-10-16 10:00:37.251403+00', 'Water Mill, The', 'WATER MILL', 1, 48, 9999, 8, 133, 9, 270, NULL, '', 86, '888888  888888  888888  888888  888888  800000', 0, 1, 0, 0, 86);
INSERT INTO 'dance' VALUES (13468, '2009-11-17 23:00:00+00', '2022-08-14 08:17:51.59596+00', 'Uncle Bill''s Jig', 'UNCLE BILLS JIG', 2, 32, NULL, 1, 2, 76, 146, NULL, 'For Bill Little of Castle Douglas, who has encouraged children to dance for many a year.', 52, '84  88  84  44', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (10548, '2002-08-05 22:00:00+00', '2022-09-30 12:15:55.497601+00', 'Waternish Tangle, The', 'WATERNISH TANGLE', 2, 32, 9999, 1, 3, 42, 3127, NULL, '', 36, '800  842  880  800', 1, 1, 1, 1, 47);
INSERT INTO 'dance' VALUES (15531, '2014-07-14 11:14:45.944365+00', '2022-09-13 16:27:59.767224+00', 'Beinglas Farm', 'BEINGLAS FARM', 4, 128, 2, 4, 4, 3, 1415, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6915, '2001-09-13 22:00:00+00', '2022-11-01 17:32:56.831228+00', 'Waltz Country Dance', 'WALTZ COUNTRY DANCE', 5, 40, 9999, 5, 2, NULL, 9998, '1827-01-01', 'According to the notes in the RSCDS book, this dance is derived from a longer dance called »The Guaracha, or Spanish Waltz«. However, that title has never been applied to the RSCDS dance.', 100, '88  88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (6824, '1997-11-18 23:00:00+00', '2022-11-01 18:00:21.132686+00', 'Two to One', 'TWO TO ONE', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 52, '555  555  888  822', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (14472, '2012-06-13 08:55:20.352633+00', '2022-11-18 11:52:55.695627+00', 'Vancouver Island Reel, The', 'VANCOUVER ISLAND REEL', 1, 32, NULL, 1, 3, 42, 146, NULL, '', 53, '808  808  840  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (6995, '2001-10-04 22:00:00+00', '2020-12-18 20:16:30.2818+00', 'Wee Cooper O'' Fife, The', 'WEE COOPER O FIFE', 2, 40, 9999, 1, 2, 76, 129, NULL, '##RSCDS-DI:bars:10-bar ph

10-bar phrases', 60, '10,0/10,10/10,10/10,10', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (12694, '2006-02-16 23:00:00+00', '2020-12-25 15:20:18.150917+00', 'Well Kent', 'WELL KENT', 3, 32, 9999, 2, 3, 17, 146, NULL, '', 59, '776  776  880  848', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (12696, '2006-02-19 23:00:00+00', '2021-01-10 21:13:28.705376+00', 'Vive la Danse', 'VIVE LA DANSE', 2, 32, 9999, 1, 3, 42, 104, '2003-01-01', '', 50, '800  888  822  866', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (11569, '2003-11-01 23:00:00+00', '2021-01-23 11:37:07.052169+00', 'Visit to Japan, A', 'VISIT TO JAPAN', 3, 32, 9999, 1, 3, 42, 1445, NULL, '', 47, '880  844  866  800', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (10864, '2002-10-13 22:00:00+00', '2021-02-04 12:51:15.916384+00', 'Wellington Connection, The', 'WELLINGTON CONNECTION', 1, 32, 9999, 1, 3, 42, 2694, NULL, '', 69, '880  888  888  888', 0, 1, 0, 0, 91);
INSERT INTO 'dance' VALUES (9765, '2002-04-02 22:00:00+00', '2021-02-20 20:52:37.488718+00', 'Welcome Aboard', 'WELCOME ABOARD', 4, 128, 2, 4, 4, 3, 104, '1993-01-01', '', 91, '8  8  8  8  5  5  8  8  repeat', 1, 1, 1, 1, 45);
INSERT INTO 'dance' VALUES (9505, '2000-06-06 22:00:00+00', '2021-02-22 20:13:29.872934+00', 'Water of Dryfe, The', 'WATER OF DRYFE', 1, 32, 9999, 3, 5, 7, 2770, NULL, '', 71, '88880  80800  84884  86866', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (9015, '1999-07-27 22:00:00+00', '2021-03-06 21:54:59.715841+00', 'Water of Fleet, The', 'WATER OF FLEET', 2, 32, 9999, 1, 4, 2, 146, NULL, '', 70, '8464 8888  8080  8444', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (7532, '1997-12-03 23:00:00+00', '2021-03-25 23:49:09.287293+00', 'W. James', 'W JAMES', 2, 32, 9999, 1, 3, 42, 154, NULL, '"For my son James."', 50, '840  880  822  888', 0, 1, 0, 1, 66);
INSERT INTO 'dance' VALUES (12567, '2005-10-19 22:00:00+00', '2021-03-27 21:48:06.640314+00', 'Violynne', 'VIOLYNNE', 1, 32, 9999, 1, 3, 42, 2682, '2004-01-01', 'Note: a teaching dance for the beginners class.', 62, '888  888  880  880', 0, 0, 0, 0, 83);
INSERT INTO 'dance' VALUES (7031, '2002-03-03 23:00:00+00', '2021-04-02 17:37:38.17721+00', 'Welcome To Skye', 'WELCOME TO SKYE', 2, 32, 9999, 1, 4, 2, 1911, NULL, 'From the book: The dance was devised by Isla Henderson (nee Macleod) and the music is by her father. Isla spent many of her formative years in Skye and is now a teacher of Scottish country dancing in Inverness. She returns frequently to Skye to dance and husband David to hillwalk.

This dance is a nice opener for any programme and indeed for this book.', 81, '8448  8888  8008  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (6879, '1997-09-16 22:00:00+00', '2021-04-04 11:42:11.126232+00', 'Victorian Strathspey, The', 'VICTORIAN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1983-01-01', '"For the dancers of Victoria, Vancouver Island."', 53, '880  822  844  888', 1, 1, 0, 1, 70);
INSERT INTO 'dance' VALUES (6849, '1997-09-16 22:00:00+00', '2021-04-04 19:08:45.029215+00', 'Up In The Morning Early', 'UP IN THE MORNING EARLY', 2, 32, 9999, 1, 3, 42, 976, '1740-01-01', '', 45, '800  864  844  844', 0, 1, 0, 1, 60);
INSERT INTO 'dance' VALUES (6817, '1999-09-09 22:00:00+00', '2021-04-05 10:46:29.059614+00', 'Two and Two', 'TWO AND TWO', 2, 32, 9999, 1, 2, 76, 9998, '1763-01-01', '', 60, '88  88  88  80', 1, 1, 0, 1, 87);
INSERT INTO 'dance' VALUES (15148, '2013-09-25 08:16:07.349888+00', '2021-07-30 06:12:28.497657+00', 'Welcome Home', 'WELCOME HOME', 1, 32, NULL, 1, 3, 42, 308, '2008-09-01', 'The first eight bars represent all the people who are travelling home to Scotland, and bars nine to sixteen represent the arrival of travellers to their homeland.

Bars seventeen to twenty four represent the homecomer’s visiting places and people and the final eight bars are a celebration of meeting old and new friends and a successful homecoming year.', 50, '888/800/800/888', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (8829, '2001-05-21 22:00:00+00', '2016-06-03 13:53:50.888306+00', 'Wedding Bells, The', 'WEDDING BELLS', 2, 32, 9999, 1, 2, 76, 228, '1998-05-01', 'Devised: 1998-05', 60, '80  88  88  88', 0, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (14980, '2013-07-20 13:02:32.229807+00', '2014-04-30 23:23:36.920431+00', '75th Anniversary Medley, The', '75TH ANNIVERSARY MEDLEY', 4, 32, 1, 1, 4, 2, 99, '2013-01-01', 'This entry needs to be checked with the publication.', 81, '8888  8008  8888  8448', 0, 1, 1, 0, 81);
INSERT INTO 'dance' VALUES (15555, '2014-07-27 13:46:54.591123+00', '2014-07-27 13:46:54.591123+00', 'It''s Past Eight O''Clock', 'ITS PAST EIGHT OCLOCK', 2, 40, NULL, 7, 1, NULL, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10755, '2002-07-24 22:00:00+00', '2018-08-11 04:38:34.38815+00', 'Jean Robertson''s Jig', 'JEAN ROBERTSONS JIG', 2, 32, 9999, 1, 3, 42, 1, '1998-01-01', 'Harry Rhodes wrote: "Jean Robertson was my first Scottish Country Dancing teacher some 45 years ago."', 56, '880/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18497, '2018-08-10 10:22:20.056683+00', '2018-08-10 10:32:57.594567+00', 'Flying Scotsman (4C Ceilidh version), The', 'FLYING SCOTSMAN 4C CEILIDH VERSION', 2, 32, NULL, 1, 4, 1, 319, NULL, 'Devised by Hugh Thurston, and adapted by RSCDS for the RSCDS Medal Tests for Young Dancers ', 56, '4444/4444/8000/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1559, '2001-05-03 22:00:00+00', '2014-06-01 09:37:35.998265+00', 'Dark Mile, The', 'DARK MILE', 3, 32, 9999, 2, 3, 17, 313, NULL, 'The Dark Mile is a tree-lined avenue to the north of Achnacarry on the road from Gairlochy to Loch Arkaig.', 87, '880  888  888  848', 1, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (11543, '2003-10-05 22:00:00+00', '2018-04-03 00:07:29.347223+00', '51st Travellers, The', '51ST TRAVELLERS', 2, 32, 9999, 1, 3, 42, 3389, '2001-01-01', 'This dance''s other name is »Perpetual Motion«. This is listed as an unofficial alias so it won''t show up in the RSCDS Index of Dances, which would be confusing.', 62, '844  888  888  844', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (15494, '2014-06-27 21:02:19.905457+00', '2014-11-12 09:04:27.602518+00', 'In the Maple Forest', 'IN THE MAPLE FOREST', 3, 32, NULL, 1, 3, 42, 10971, NULL, 'I devised this dance one cold January evening after walking our dog in the Maple Woods behind our home



Suggested Music:  “Dear Gladys,” Campbell’s Birl, Muriel Johnstone and Keith Smith.', 50, '800/844/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1930, '2001-11-20 23:00:00+00', '2018-04-03 00:07:29.372478+00', '8th Battalion - The Royal Scots', '8TH BATTALION  THE ROYAL SCOTS', 1, 32, 9999, 1, 3, 42, 388, '1989-01-01', '', 59, '888  888  866  800', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (15472, '2014-06-16 10:15:31.139526+00', '2014-06-16 10:15:31.139526+00', 'Valentine Strathspey', 'VALENTINE STRATHSPEY', 3, 40, NULL, 1, 4, 2, 3444, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15461, '2014-06-09 19:40:47.850993+00', '2014-06-09 19:40:47.850993+00', 'Winifred''s Welcome', 'WINIFREDS WELCOME', 1, 32, NULL, 1, 4, NULL, 10963, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15462, '2014-06-09 19:44:54.557548+00', '2014-06-09 19:44:54.557548+00', 'Luckenbooth Spinner', 'LUCKENBOOTH SPINNER', 1, 32, NULL, 1, 4, NULL, 10964, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15546, '2014-07-27 13:16:59.260971+00', '2014-07-27 13:16:59.260971+00', 'Feilleadh Beag', 'FEILLEADH BEAG', 3, 32, NULL, 1, 4, 1, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15556, '2014-07-27 13:49:18.910989+00', '2014-07-27 13:49:18.910989+00', 'Tulloch Burn', 'TULLOCH BURN', 1, 32, NULL, 7, 1, 4, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15457, '2014-06-09 00:43:36.697433+00', '2017-12-19 21:27:50.407574+00', 'Very Legal Wedding, A', 'VERY LEGAL WEDDING', 2, 32, NULL, 1, 3, 42, 2197, '2013-11-03', 'For the Newly-wed lawyers Helen and Ollie.', 43, '800/888/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12635, '2005-11-08 23:00:00+00', '2015-06-14 21:20:01.838182+00', 'We''ve Nae Electric', 'WEVE NAE ELECTRIC', 1, 32, 9999, 3, 5, 7, 3379, NULL, '', 71, '82822  88888  80800  84888', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (3974, '1997-04-03 22:00:00+00', '2016-02-28 11:32:48.481447+00', 'Lowland Lilt, The', 'LOWLAND LILT', 2, 32, 9999, 5, 1, 4, 200, NULL, '', 100, '88/88/88/88', 0, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (14528, '2012-07-23 11:32:22.594392+00', '2018-08-12 14:22:59.043462+00', 'Mairi''s Hangover', 'MAIRIS HANGOVER', 1, 40, 9999, 1, 4, 2, 10639, NULL, 'The crib "SCDDB Contributed cribs and diagrams" is actually the official description as published.



The Cambridge University Strathspey & Reel Club display team who made the video says "we found it impractical for the dancing couples to pass RSh in the middle (i.e. going the long way around the other three dancers), as the deviser specified. We passed LSh, as you can see in the video."', 90, '8008  8888 8888  8888  8888', 1, 1, 1, 1, 90);
INSERT INTO 'dance' VALUES (5576, '2001-05-03 22:00:00+00', '2020-08-07 08:54:22.029674+00', 'Riggs Of Corn', 'RIGGS OF CORN', 1, 32, 9999, 1, 2, 76, 62, '1965-01-01', 'This dance is substantially identical to <<ddd:Canadian Corn Rigs>>, except that for bars 17-24 1c leads 2c dancing down and again leads 2c when dancing up.', 69, '88  88  88  88', 1, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (4424, '1998-09-30 22:00:00+00', '2020-06-04 23:32:40.890104+00', 'Miss Allie Anderson', 'MISS ALLIE ANDERSON', 2, 32, 9999, 1, 3, 42, 86, NULL, '', 61, '666  888  888  840', 0, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (7035, '2002-04-12 22:00:00+00', '2021-01-23 23:26:37.048541+00', 'Welcome to the Dance', 'WELCOME TO THE DANCE', 2, 32, 9999, 5, 2, 76, 723, NULL, '<<scddb-not-identical:9702>>', 100, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (10641, '2002-07-21 22:00:00+00', '2020-09-11 08:49:01.406544+00', 'Down Unda', 'DOWN UNDA', 1, 32, 9999, 5, 1, 4, 2961, NULL, 'Deviser''s notes:  This is an easy audience participation/beginner dance.  I have used it many times with great success.  The trick is to change partners after the Back to Back.  The last turn is by the left hand, allowing the dancer to easily flow into the beginning figure.



Dedcated to our Australian dancers who live ''down unda''. ', 100, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13621, '2010-10-08 22:00:00+00', '2020-09-12 20:25:25.746986+00', 'Granville Market', 'GRANVILLE MARKET', 2, 32, 9999, 1, 3, 42, 723, '1985-05-01', '', 47, '880  800  822  888', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (13472, '2009-11-17 23:00:00+00', '2020-09-18 08:25:55.882341+00', 'Yvonne''s Lasses', 'YVONNES LASSES', 2, 96, NULL, 4, 4, 3, 146, NULL, 'Fior Yvonne Tredgett, who has introduced many young people to the joys of dancing.', 56, '8080  8080  0808  0808   4242  4444  2424  4444    4444  4444  8888  8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1283, '1998-09-29 22:00:00+00', '2020-09-30 14:48:17.316045+00', 'Collichur', 'COLLICHUR', 2, 32, 9999, 1, 3, 42, 1977, NULL, '', 44, '800  880  888  800', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (13283, '2007-06-20 22:00:00+00', '2021-01-03 13:51:46.564695+00', 'Wee Touch o'' Class, A', 'WEE TOUCH O CLASS', 2, 32, 9999, 1, 3, 42, 167, NULL, '', 47, '880  800  888  840', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (15650, '2014-10-01 23:37:14.428772+00', '2020-10-12 17:13:47.475733+00', 'Corners of Edinburgh', 'CORNERS OF EDINBURGH', 1, 32, 9999, 1, 3, 42, 531, NULL, '', 50, '800/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6532, '2002-03-03 23:00:00+00', '2020-11-15 13:17:37.263028+00', '1314 (Thirteen-Fourteen)', '1314 THIRTEENFOURTEEN', 4, 128, 2, 4, 4, 3, 108, '1967-01-01', 'This dance commemorates the <<http://en.wikipedia.org/wiki/Battle_of_Bannockburn|Battle of Bannockburn>>, which took place at the end of June, 1314 – Scotland under its king, Robert the Bruce, fought an English army under king Edward II. and won. Bannockburn, being as it is one of the rare Scottish triumphs over their southerly neighbours, plays an important role in Scottish tradition and lore; the victory is not only celebrated in Burns'' famous poem, *Scots Wha Hae*, but also in the modern

(inofficial) rugby anthem *Flower of Scotland*.



Bannockburn is near Stirling, a strategically important city at the edge of the Highlands. It features a memorial and a Robert the Bruce monument, even though by now historical researchers are fairly unanimous in concluding that the battle did not actually take place where the memorial is today, but somewhere else in the vicinity (it is not completely clear where).



The dance is a comparatively early work by John Drewry, and his selection of music mirrors the actual event: <<ddt:Bonnybridge>> is a bridge across Bannock Burn (»burn« meaning »small river«), where the battle took place. <<ddt:Stirling Castle>> is, so to speak, the starter of the whole affair: The castle was occupied by English troops and being besieged by Edward Bruce (Robert''s brother). It was agreed that the English were to relinquish the castle during the summer of 1314, unless there had been reinforcements from England by that time (Edward – the English king – was busy with internal politics at the time). Robert the Bruce was not enthusiastic about this arrangement, since in his opinion it gave the  castle''s garrison too much time, and Edward – the English king – managed to take care of his domestic problems and to raise a comparatively huge (two or three times the number of Bruce''s men) army in order to liberate Stirling Castle and put the rebellious Scots into their place at the same time. He reached Stirling immediately before the ultimatum for clearing the castle expired. – The first reel, <<ddt:Old Bog Hole, The>>, alludes to the actual battle in the plains near Stirling; Bruce, having had the area along the Falkirk road riddled with deep pits, forced the English army to detour through the open country off the road, where they were crammed between various water courses and had little room to maneuver. The second reel, <<ddt:Soldier''s Joy>>, naturally symbolises the elation of the Scottish troops after winning the day.



The only recording that actually uses all of these prescribed tunes is the one by <<ddp:Adamson, Deirdre>>, which unfortunately uses a nearly undanceable speed for the reels. This is slightly strange since 1314 is a popular and fairly frequently recorded dance.', 100, '8/8/8/8/8/16/8', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (10791, '2002-08-25 22:00:00+00', '2020-12-24 18:02:25.478024+00', 'Ways in New Hall', 'WAYS IN NEW HALL', 1, 32, 9999, 1, 3, 42, 3187, NULL, 'To celebrate the 70th Summer School', 44, '888  800  800  880', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (9106, '2001-11-21 23:00:00+00', '2021-03-01 20:10:51.727066+00', '12 Coates Crescent', '12 COATES CRESCENT', 3, 32, 9999, 1, 4, 1, 319, '1998-01-01', '', 72, '8888  8004  0088  8888', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (8057, '1997-12-03 23:00:00+00', '2021-03-22 17:22:24.293527+00', 'Hospitality Circle, The', 'HOSPITALITY CIRCLE', 2, 32, 9999, 5, 2, 76, 1385, '1983-01-01', '', 75, '44/44/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6981, '1998-09-29 22:00:00+00', '2021-04-04 11:34:17.421589+00', 'Wedderburn''s Reel', 'WEDDERBURNS REEL', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'The choreography of this dance is identical to that of <<ddd:Fife Hunt, The>>.', 34, '800  800  822  844', 1, 1, 0, 1, 45);
INSERT INTO 'dance' VALUES (9420, '2002-09-22 22:00:00+00', '2021-07-30 08:43:38.702337+00', 'Corstorphine Road', 'CORSTORPHINE ROAD', 3, 32, 9999, 1, 4, 1, 308, '1995-11-01', 'This dance was inspired by watching the traffic negotiate the double mini roundabouts near the end of Corstorphine Road in Edinburgh.', 94, '8888  8888  4848  8888', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (5983, '1997-09-13 22:00:00+00', '2018-08-12 19:52:13.388595+00', 'Seashells', 'SEASHELLS', 1, 40, 9999, 1, 3, 42, 480, '1990-05-31', 'This dance grew from the scallops recipe.', 57, '888/844/808/822/888', 0, 1, 1, 0, 76);
INSERT INTO 'dance' VALUES (13325, '2007-09-03 22:00:00+00', '2018-12-28 19:41:30.117629+00', 'Meet Me in the Middle', 'MEET ME IN THE MIDDLE', 2, 32, 9999, 1, 3, 42, 640, '2007-01-01', '', 50, '822/866/822/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18495, '2018-08-09 22:28:24.067778+00', '2018-10-24 16:52:21.614496+00', 'Zombie Town', 'ZOMBIE TOWN', 3, 40, NULL, 2, 3, 17, 11676, NULL, 'e-crib derived from a dem quality video.', 73, '888/844/888/808/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7513, '1997-09-14 22:00:00+00', '2019-03-07 22:53:19.441807+00', 'Shambellie House', 'SHAMBELLIE HOUSE', 3, 32, 9999, 1, 4, 1, 1, NULL, '', 77, '8228/2882/8888/8666', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15683, '2014-10-28 11:37:12.879097+00', '2018-04-17 08:35:06.27807+00', 'Waipu Wanderers, The', 'WAIPU WANDERERS', 1, 32, NULL, 1, 3, 42, 411, '2008-01-01', '', 69, '844/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3920, '1997-09-08 22:00:00+00', '2014-07-11 17:22:17.063628+00', 'Longhope Strathspey, The', 'LONGHOPE STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 179, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15545, '2014-07-27 13:14:58.39398+00', '2014-07-27 13:14:58.39398+00', 'Jist a wee drappie', 'JIST A WEE DRAPPIE', 3, 40, NULL, 1, 4, 1, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1150, '1997-08-31 22:00:00+00', '2018-04-03 00:07:37.97132+00', 'Changing of the Guard, The', 'CHANGING OF THE GUARD', 2, 32, 9999, 1, 3, 42, 179, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15692, '2014-11-02 21:26:15.010613+00', '2014-11-02 21:26:15.010613+00', 'Miss Mackenzie of Briar Lea', 'MISS MACKENZIE OF BRIAR LEA', 1, 32, NULL, 1, 3, 42, 3593, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15703, '2014-11-18 15:56:39.027861+00', '2014-11-18 16:07:04.366419+00', 'Mr Robert Gregg of Woodbridge', 'MR ROBERT GREGG OF WOODBRIDGE', 3, 32, NULL, 2, 3, 18, 870, '2008-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7665, '1998-01-04 23:00:00+00', '2018-04-03 00:07:40.315476+00', 'Cruachan of the Argyll''s', 'CRUACHAN OF THE ARGYLLS', 3, 48, 9999, 1, 3, 42, 386, '1969-03-01', 'Dance was devised to mark the 10th anniversary of Stirling Castle Scottish Country Dance Group.



‘Cruachan’ is the name given to the Shetland pony mascot of the Argyll and Sutherland Highlanders. When this dance was devised the Stirling Castle Scottish Country Dance Group met in Stirling Castle which was also home to the Argyll and Sutherland Highlanders.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6413, '1997-09-14 22:00:00+00', '2014-05-05 22:54:45.687981+00', 'Swan, The', 'SWAN', 3, 32, 9999, 1, 2, NULL, 59, NULL, '', 62, '77  66  88  88', 1, 1, 1, 1, 90);
INSERT INTO 'dance' VALUES (13595, '2010-09-16 22:00:00+00', '2014-09-30 08:05:43.745344+00', 'Riverside, The', 'RIVERSIDE', 2, 32, NULL, 103, 2, 30, 10969, '1988-01-01', 'The dance is danced by any number of couples, forming two long lines, each lady on her partner’s right.  For the duration, each couple is dancing in a four with the couple opposite them in the set.



This dance was named after The Riverside Club in Glasgow – scene of many a good night’s dancing!  The dance floor there is long and narrow, hence the full, long set. It was written primarily for children or beginners, and can be easily learned which is perhaps why it has grown in popularity at Ceilidh dances.



As with many ceilidh dances, there are countless variants; the crib and the videos show some of them.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1637, '1997-04-03 22:00:00+00', '2018-08-19 16:31:02.294835+00', 'Devonside', 'DEVONSIDE', 3, 32, 9999, 1, 3, 42, 28, NULL, 'To Betty Brown (now Mrs. Sandy Towers) who so thoroughly taught us, the Bath Branch class, all the basic and the finer points, of Scottish Country Dancing, for more than fifteen years.', 59, '880/888/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10594, '2002-12-05 23:00:00+00', '2014-05-09 14:26:40.692684+00', 'Sugar Spoon, The', 'SUGAR SPOON', 3, 48, 9999, 2, 3, 17, 154, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1177, '1997-08-25 22:00:00+00', '2014-05-16 19:57:45.313768+00', 'Chest Of Dee, The', 'CHEST OF DEE', 3, 32, 9999, 1, 3, 42, 108, '1981-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11957, '2004-12-13 23:00:00+00', '2018-08-13 14:10:39.512851+00', 'Millennium Reel', 'MILLENNIUM REEL', 2, 32, 9999, 1, 3, 42, 3354, '1999-01-01', 'In the book the dance name is accidentally misspelled as "Millenium Reel".  That name has been added as a spelling alias to facilitate searches.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15497, '2014-06-27 21:04:13.281982+00', '2019-01-22 23:38:50.152404+00', 'Stratford Strathspey', 'STRATFORD STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10971, NULL, 'Inscribed "For all my Stratford friends"', 63, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1725, '2000-07-02 22:00:00+00', '2014-05-30 15:39:12.191994+00', 'Dowie Dens, The', 'DOWIE DENS', 3, 32, 9999, 1, 100, 11, 313, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5277, '1998-07-08 22:00:00+00', '2014-05-31 14:12:10.128125+00', 'Piper''s Brae', 'PIPERS BRAE', 3, 32, 9999, 1, 114, 2, 313, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15521, '2014-06-27 21:18:49.898012+00', '2019-01-23 18:26:18.291908+00', 'Maple Leaf Reel, The', 'MAPLE LEAF REEL', 1, 40, NULL, 1, 4, 1, 10971, NULL, '', 73, '8440/8044/8888/8444/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15528, '2014-07-14 11:05:36.396136+00', '2018-04-03 00:07:48.264405+00', 'Gilly-Ann', 'GILLYANN', 1, 32, NULL, 1, 3, 42, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15529, '2014-07-14 11:08:20.879467+00', '2014-07-14 11:08:20.879467+00', 'Rowardennan', 'ROWARDENNAN', 3, 32, NULL, 1, 4, 1, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15673, '2014-10-19 16:45:25.084063+00', '2021-04-09 07:33:04.444811+00', 'There and Back', 'THERE AND BACK', 3, 80, NULL, 4, 4, 3, 11029, NULL, '', 80, '8888/8888/8888/8888/4444/4444/8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1501, '2000-02-21 23:00:00+00', '2021-06-18 17:33:52.468294+00', 'Dalkeith''s Strathspey', 'DALKEITHS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 37, '840  800  880  822', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (15448, '2014-05-25 08:57:12.228777+00', '2018-04-03 00:08:10.715305+00', 'Pipe Major Mullen', 'PIPE MAJOR MULLEN', 1, 32, NULL, 1, 3, 42, 3192, NULL, 'Dedicated to Tom Mullen, a man of many talents and a very popular personality in Manchester Scottish circles, including RSCDS dancing and RSCDS dance band, Pipe Bands and Caledonian Choir.

I have personally known Tom since the early 60''s when he was Pipe Major of the Prince Charles Edward Pipe Band in Manchester in which I was a drummer.

The first time I heard Harvest Home was when Tom introduced it to the Pipe Band as part of a very exciting medley.

(Notes are by Peter Dawson and are from Ten Modern SCDs)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15505, '2014-06-27 21:09:07.509107+00', '2019-01-23 00:17:55.594992+00', 'Transitions', 'TRANSITIONS', 3, 96, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8863, '2002-03-03 23:00:00+00', '2019-03-06 10:53:50.333579+00', 'Byrnes'' Reel, The', 'BYRNES REEL', 1, 32, 9999, 4, 4, 4, 2489, '1996-01-01', '', 88, '8888/4444/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10145, '2001-10-22 22:00:00+00', '2019-05-27 11:07:49.545893+00', 'Pieces of Eight', 'PIECES OF EIGHT', 3, 32, 9999, 1, 3, 42, 2943, NULL, '', 69, '888/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15498, '2014-06-27 21:04:48.119822+00', '2019-10-18 11:02:34.388966+00', 'Sylvia Strathspey, The', 'SYLVIA STRATHSPEY', 3, 32, NULL, 1, 2, 76, 10971, NULL, 'Inscribed "A tribute to my wife, Sylvia, for her birthday."



The instructions say this is a "8 x 32 bar strathspey for 3 couples", but only 1c+2c take part in the dance.  It is therefore entered in this database to be a 2C/4L dance.  The video is also danced as 2C/4L', 64, '88/57/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4796, '1997-12-15 23:00:00+00', '2020-05-15 16:52:51.58914+00', 'Mrs Milne of Kinneff', 'MRS MILNE OF KINNEFF', 3, 32, 9998, 4, 4, 1, 246, NULL, 'Devised for Doris Milne, a pianist of long standing with RSCDS Stirling branch.', 94, '8484  8888  8888  8888', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (937, '1997-08-31 22:00:00+00', '2020-08-02 23:43:18.301835+00', 'Caledonian Reel, The', 'CALEDONIAN REEL', 7, 96, 9999, 105, 53, NULL, 175, NULL, 'Highland Medley for three ladies.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15639, '2014-10-01 22:09:56.849306+00', '2020-10-12 11:24:36.874568+00', 'Blethering Beth', 'BLETHERING BETH', 2, 32, 9999, 1, 3, 42, 11011, '2012-01-01', '', 44, '840/804/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15431, '2014-05-09 21:52:23.600737+00', '2020-12-29 19:22:17.817366+00', 'Brenda''s Jig', 'BRENDAS JIG', 2, 32, 9999, 1, 4, 1, 452, '2013-04-01', 'Inscribed to our two Brendas: Brenda Burness and Brenda Morris.', 55, '8800/8800/8680/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15542, '2014-07-27 13:02:37.753317+00', '2020-11-23 15:41:07.184524+00', 'Tartan Buckle, The', 'TARTAN BUCKLE', 2, 32, NULL, 2, 3, 17, 2018, NULL, '', 61, '880/888/822/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8725, '2002-07-21 22:00:00+00', '2021-03-14 23:20:28.321691+00', 'Daphne''s Jig', 'DAPHNES JIG', 2, 32, 9999, 1, 3, 42, 558, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15532, '2014-07-14 11:16:08.006677+00', '2014-07-14 11:16:08.006677+00', 'Froome''s Fancy', 'FROOMES FANCY', 1, 32, NULL, 3, 5, 7, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15547, '2014-07-27 13:19:13.452964+00', '2014-07-27 13:19:13.452964+00', 'Breccan Feile', 'BRECCAN FEILE', 1, 32, NULL, 1, 4, 1, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15557, '2014-07-27 13:51:49.300453+00', '2014-07-27 13:51:49.300453+00', 'French Knot, The', 'FRENCH KNOT', 3, 32, NULL, 2, 3, 17, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15548, '2014-07-27 13:22:18.146483+00', '2014-07-27 13:22:18.146483+00', 'Roundabout, The', 'ROUNDABOUT', 2, 32, NULL, 2, 3, 17, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8301, '1998-01-12 23:00:00+00', '2014-07-27 13:53:32.223833+00', 'Drowsy Maggie', 'DROWSY MAGGIE', 1, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14518, '2012-07-19 23:21:10.090498+00', '2014-04-30 23:24:08.810629+00', 'St Andrews Platinum Reel, The', 'SAINT ANDREWS PLATINUM REEL', 1, 32, NULL, 1, 3, 42, 99, NULL, 'Dance devised to celebrate the 70th anniversary of St Andrews Branch.', 47, '800  844  822  888', 0, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (548, '2002-08-25 22:00:00+00', '2014-05-05 22:55:55.059845+00', 'See You Down Under', 'SEE YOU DOWN UNDER', 2, 32, 9999, 1, 4, 1, 1988, '1997-01-01', 'For Mechtild and Andrew Timmins on leaving Rechberg to  move to Adelaide, Australia', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4311, '1997-04-03 22:00:00+00', '2018-04-02 23:56:36.286943+00', 'Mercat Cross, The', 'MERCAT CROSS', 2, 32, 9999, 1, 3, 42, 13, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15447, '2014-05-25 08:52:24.209501+00', '2014-05-25 09:48:06.932581+00', 'Those Golden Years', 'THOSE GOLDEN YEARS', 3, 32, NULL, 3, 5, 16, 3192, '1998-01-01', 'Dedicated to Jim and June Andrew on their Golden Wedding Anniversary', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2476, '1998-07-08 22:00:00+00', '2014-05-30 14:48:26.662586+00', 'Girdleness Light', 'GIRDLENESS LIGHT', 3, 40, 9999, 1, 100, 2, 108, '1971-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5395, '2002-04-19 22:00:00+00', '2014-05-23 22:27:26.209728+00', 'Purple Heather Jig, The', 'PURPLE HEATHER JIG', 2, 32, 9999, 1, 3, 42, 369, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2592, '2000-07-02 22:00:00+00', '2014-05-30 15:14:57.804207+00', 'Golden Oriole, The', 'GOLDEN ORIOLE', 3, 32, 9999, 1, 100, 2, 313, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15449, '2014-05-25 09:00:18.595438+00', '2017-05-31 12:36:55.710849+00', 'Scottish Emigrant, The', 'SCOTTISH EMIGRANT', 3, 32, NULL, 4, 5, 35, 3192, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15482, '2014-06-27 20:54:36.035228+00', '2018-12-23 22:08:46.897535+00', 'Cathcart Memories', 'CATHCART MEMORIES', 2, 32, NULL, 1, 2, 76, 10971, NULL, 'In memory of my first visit to Scotland, Christmas with relatives in Cathcart, a district of Glasgow.', -1, '44/48/48/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12998, '2006-11-01 23:00:00+00', '2017-11-11 19:06:27.594629+00', 'Two''s Company - Three''s A Crowd', 'TWOS COMPANY  THREES A CROWD', 3, 32, 9999, 2, 3, 17, 3723, '2005-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13278, '2007-04-16 22:00:00+00', '2017-11-12 00:54:40.995226+00', 'Rug Beater, The', 'RUG BEATER', 1, 32, 9999, 1, 3, 42, 3773, '2007-01-01', '', 59, '800  866  888  888', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (10348, '2002-02-16 23:00:00+00', '2018-04-03 00:08:23.682506+00', 'Via Aberlemno', 'VIA ABERLEMNO', 2, 40, 9999, 1, 3, 42, 619, '1998-01-01', 'Inscribed to Laura and Angus Adam for the Aberlemno Dance Class Sept 1998', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (54, '2002-03-02 23:00:00+00', '2019-06-18 23:55:15.010103+00', 'Aird of Coigach', 'AIRD OF COIGACH', 2, 48, 9999, 1, 4, 1, 26, '1975-01-01', '', 65, '4444/8888/8440/8404/8866/4444', 1, 1, 1, 1, 64);
INSERT INTO 'dance' VALUES (15439, '2014-05-09 22:28:03.687592+00', '2019-08-29 18:31:08.609268+00', 'Quinte Gathering, The', 'QUINTE GATHERING', 1, 32, 9999, 1, 3, 42, 2998, NULL, 'Inscribed to the Belleville Scottish Country Dance Group for their wonderful workshops.', 58, '888/820/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15668, '2014-10-19 16:16:42.65329+00', '2020-06-23 05:51:53.251269+00', 'Crannog, The', 'CRANNOG', 1, 32, NULL, 1, 4, 2, 325, NULL, '', 94, '8888/8888/8888/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5794, '1998-09-29 22:00:00+00', '2020-07-12 22:37:01.175838+00', 'Sailor, The', 'SAILOR', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 50, '844  888  800  880', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (15661, '2014-10-19 09:23:38.924455+00', '2020-10-13 08:39:59.848121+00', 'Biologist, The', 'BIOLOGIST', 1, 32, NULL, 1, 3, 42, 11026, '2013-01-01', 'Devised as a sister dance to the Zoologist.', 63, '844/888/866/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15663, '2014-10-19 09:47:12.139499+00', '2020-10-13 08:45:05.741614+00', 'Dandelion, The', 'DANDELION', 2, 48, NULL, 4, 55, 35, 325, NULL, '', 47, '44448/40408/04048/44448/84004/04840', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12397, '2005-04-28 22:00:00+00', '2020-10-13 18:00:39.52364+00', 'Summer School Peregrinations', 'SUMMER SCHOOL PEREGRINATIONS', 2, 32, 9999, 1, 4, 2, 3594, '2001-07-01', '', 78, '8228/8888/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9293, '2000-01-16 23:00:00+00', '2020-10-21 10:18:52.284015+00', 'General Worth''s Strathspey', 'GENERAL WORTHS STRATHSPEY', 3, 32, 9999, 1, 2, 76, 501, '1992-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4100, '1997-11-18 23:00:00+00', '2020-12-10 09:49:11.275858+00', 'Mairi''s Fancy', 'MAIRIS FANCY', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 45, '440  880  808  846', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (7068, '1998-09-29 22:00:00+00', '2020-12-18 20:23:07.104398+00', 'What a Beau my Granny was', 'WHAT A BEAU MY GRANNY WAS', 1, 32, 9999, 1, 3, 42, 373, '1792-02-01', 'According to the RSCDS publication "Scottish Country Dances Books 13-18" this dance can be traced back to "Preston''s Selection of the most favorite Country Dances, Reels etc" (c. 1800) where it was published with bars 1-8 and 9-16 in the opposite order.', 62, '888  888  880  808', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (12616, '2005-11-08 23:00:00+00', '2021-01-13 11:32:54.25342+00', 'Sunningdale Strathspey, The', 'SUNNINGDALE STRATHSPEY', 3, 32, 9999, 2, 3, 17, 3647, NULL, '', 50, '888/800/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5120, '1997-08-25 22:00:00+00', '2022-11-20 15:25:31.536429+00', 'Our Highland Queen', 'OUR HIGHLAND QUEEN', 3, 40, 9999, 1, 4, 1, 108, '1971-01-01', '', 70, '8888/8080/8080/8404/8888', 1, 1, 0, 1, 70);
INSERT INTO 'dance' VALUES (11894, '2004-11-04 23:00:00+00', '2021-07-30 07:36:40.968317+00', 'Red Squirrel Reel', 'RED SQUIRREL REEL', 1, 40, 9999, 1, 3, 42, 308, '2004-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6086, '1998-07-08 22:00:00+00', '2014-06-01 03:00:59.290216+00', 'Silver Rose, The', 'SILVER ROSE', 1, 32, 9999, 1, 4, 11, 313, NULL, 'For Andrina Rose, RSCDS Sutton Coldfield Branch Chairman, and in celebration of 25 years of organized Scottish Country Dancing in the Royal Town of Sutton Coldfield, of which the emblem is the Tudor Rose.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16470, '2015-07-07 15:02:26.872977+00', '2018-04-02 23:56:34.717197+00', 'Friends Across the Ocean', 'FRIENDS ACROSS THE OCEAN', 3, 32, 9999, 1, 3, 42, 671, NULL, 'Devised by Chris Harris, an IB Member living in Rapperswil-Jona, SG, Switzerland.



To all his friends around the world who have made him feel so very welcome.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14977, '2013-07-03 22:28:38.072632+00', '2018-04-02 23:56:35.735777+00', 'Kissing Bridge, The', 'KISSING BRIDGE', 1, 32, NULL, 1, 3, 42, 59, NULL, 'A "kissing bridge" is another name for a North American "covered bridge".', 44, '800  888  800  880', 1, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (3315, '1998-07-09 22:00:00+00', '2014-05-16 20:08:00.722007+00', 'John Brown', 'JOHN BROWN', 3, 40, 9999, 2, 3, 17, 108, '1971-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5357, '2000-07-02 22:00:00+00', '2018-04-02 23:56:37.046771+00', 'Prince Charlie''s Well', 'PRINCE CHARLIES WELL', 2, 32, 9999, 1, 3, 42, 313, NULL, '', -1, '', 1, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (15549, '2014-07-27 13:25:02.692654+00', '2018-04-02 23:56:38.465838+00', 'Wee Bit Fu'', A', 'WEE BIT FU', 2, 32, NULL, 1, 3, 42, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15450, '2014-05-25 09:01:50.77204+00', '2014-05-28 21:37:00.915951+00', 'Rhoda''s Jig 2000', 'RHODAS JIG 2000', 2, 40, NULL, 3, 5, NULL, 3192, NULL, 'This dance is dedicated to Rhoda Purcell, the Peterborough RSCDS Branch Chairperson and Advanced Class Instructor who helps me to perfect my dances.

The dance was inspired by the ''double M'' (Roman Numerals) denoting the year 2000.  The ''double M'' is shown twice, once on the Ladies side of the dance and then once more across the dance, all in the first 16 bars.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10852, '2002-09-26 22:00:00+00', '2018-08-13 13:06:25.398403+00', 'Millennium Medley', 'MILLENNIUM MEDLEY', 4, 32, 1, 1, 4, 1, 3197, NULL, 'In the book the dance name is accidentally misspelled as "Millenium Medley".  That name has been added as a spelling alias to facilitate searches.', 41, '8330/8330/8000/8008', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14645, '2013-01-05 07:47:08.89881+00', '2014-04-30 23:24:15.155851+00', 'Werf Welcome', 'WERF WELCOME', 2, 32, NULL, 1, 3, 42, 227, '2004-01-01', 'The group''s classes were held in "De Werf".', 47, '800  880  822  888', 1, 1, 1, 0, 62);
INSERT INTO 'dance' VALUES (7061, '2000-09-20 22:00:00+00', '2014-04-30 23:24:15.248611+00', 'Westminster Reel, The', 'WESTMINSTER REEL', 1, 32, 9999, 1, 2, NULL, 1360, NULL, '', 60, '44  88  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (17690, '2017-04-01 19:45:18.292679+00', '2018-09-19 09:49:50.67264+00', 'St Valentine''s Chase', 'SAINT VALENTINES CHASE', 1, 32, NULL, 2, 3, 17, 11164, NULL, 'Initially devised on 14 February 2015. The chase element in the dance symbolises the romantic "chasing game" in which Valentine''s Day cards were traditionally sent anonymously.



Recommended music: "St Valentine’s Chase" by Thomas Naefe', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8699, '1999-08-06 22:00:00+00', '2014-05-05 22:59:47.149627+00', 'Pinewoods Two-Step, The', 'PINEWOODS TWOSTEP', 11, 32, 9999, 5, 2, NULL, 479, NULL, '', 100, '88  88  88  88', 0, 0, 1, 0, 100);
INSERT INTO 'dance' VALUES (15550, '2014-07-27 13:30:09.937556+00', '2014-07-27 13:30:09.937556+00', 'Shades of Cape Breton', 'SHADES OF CAPE BRETON', 1, 160, NULL, 4, 4, 3, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15558, '2014-07-27 13:56:21.94837+00', '2016-04-18 23:24:01.890602+00', 'Rigmarole, The', 'RIGMAROLE', 1, 32, NULL, 1, 2, NULL, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9014, '1999-04-24 22:00:00+00', '2017-01-27 21:53:48.990497+00', 'Thirty Years On', 'THIRTY YEARS ON', 3, 32, 9999, 1, 4, 1, 146, NULL, '', 75, '8888  4444  8888  8080', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (15451, '2014-05-25 09:03:46.495479+00', '2017-05-31 10:55:57.547256+00', 'Posh Wedding in Dumfries, A', 'POSH WEDDING IN DUMFRIES', 1, 32, NULL, 1, 4, NULL, 3192, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7060, '1997-08-25 22:00:00+00', '2019-03-08 19:13:41.686751+00', 'Westgate Reel, The', 'WESTGATE REEL', 1, 32, 9999, 1, 4, 1, 146, NULL, '', 67, '8222  8888  8000  8888', 0, 1, 1, 0, 67);
INSERT INTO 'dance' VALUES (15440, '2014-05-09 22:30:59.112724+00', '2019-08-10 21:55:50.302917+00', 'Itchy Feet', 'ITCHY FEET', 2, 32, 9999, 1, 3, 42, 403, NULL, '“When the music starts and we are Itching to start dancing, then that is the time we have itchy feet.”', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4310, '1998-07-08 22:00:00+00', '2014-05-31 14:15:20.249+00', 'Mercat Cross, The', 'MERCAT CROSS', 1, 32, 9999, 1, 102, 2, 313, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9295, '2000-01-16 23:00:00+00', '2014-11-05 16:56:03.064206+00', 'Lettie G. Howard', 'LETTIE G HOWARD', 3, 32, 9999, 1, 2, NULL, 501, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14644, '2013-01-05 07:43:06.327639+00', '2021-03-27 18:51:10.901519+00', 'Wheelchair Strathspey, The', 'WHEELCHAIR STRATHSPEY', 3, 32, NULL, 1, 3, 42, 2106, '2005-09-01', 'Devised for a dancer who had become confined to a wheel chair.', 44, '800  844  888  800', 1, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (7045, '1997-04-03 22:00:00+00', '2020-12-18 20:20:25.793113+00', 'Wemyss Place Hornpipe, The', 'WEMYSS PLACE HORNPIPE', 1, 32, 9999, 1, 3, 42, 108, '1975-02-02', '', 62, '800  888  888  888', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (7534, '1998-04-24 22:00:00+00', '2020-08-16 10:33:29.194528+00', 'West End Strathspey', 'WEST END STRATHSPEY', 3, 32, 9999, 1, 2, 76, 146, NULL, '', 60, '66/66/88/88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (14646, '2013-01-05 07:52:52.777037+00', '2020-12-26 10:38:01.606109+00', 'Wellness', 'WELLNESS', 3, 32, NULL, 1, 3, 42, 3135, '2010-01-01', '', 59, '824  888  888  770', 1, 1, 1, 0, 79);
INSERT INTO 'dance' VALUES (18938, '2018-10-09 15:50:44.035628+00', '2021-01-21 06:52:18.98662+00', 'Winter Solstice', 'WINTER SOLSTICE', 1, 32, NULL, 1, 3, 42, 2766, '2015-12-01', 'Celebrating the holiday season.', 41, '800/880/880/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15436, '2014-05-09 22:11:16.62654+00', '2020-12-29 19:02:43.349168+00', 'Reel of the Pinehurst Eight, The', 'REEL OF THE PINEHURST EIGHT', 1, 32, NULL, 1, 4, 2, 10208, NULL, 'Devised at the request of one of the eight male dancers who travel annually to Pinehurst to golf.', 75, '8008/8668/8668/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11479, '2003-09-22 22:00:00+00', '2021-01-24 12:12:09.881324+00', 'Wellington Street', 'WELLINGTON STREET', 1, 32, 9999, 1, 3, 42, 3375, NULL, 'During this dance, 1st couple meet all the people with whom they are dancing, just as we, in Leicester, do at Wellington Street on Thursday evenings', 50, '822  844  844  866', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (11112, '2002-12-16 23:00:00+00', '2021-01-29 22:39:09.290112+00', 'West Highland Line, The', 'WEST HIGHLAND LINE', 1, 32, 9999, 1, 3, 42, 2672, NULL, '', 58, '844  868  822  888', 1, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (7071, '1997-09-17 22:00:00+00', '2021-03-31 09:45:38.309887+00', 'What Muckle Sorrow Ails You?', 'WHAT MUCKLE SORROW AILS YOU', 1, 32, 9999, 1, 3, 42, 976, '1740-01-01', '', 28, '800  800  822  800', 0, 1, 0, 1, 37);
INSERT INTO 'dance' VALUES (7049, '1997-06-19 22:00:00+00', '2021-04-02 17:24:03.769668+00', 'Wesley Harry', 'WESLEY HARRY', 1, 32, 9999, 1, 3, 42, 3462, NULL, '', 66, '884  884  855  855', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (1409, '1999-11-26 23:00:00+00', '2021-06-19 10:12:07.034352+00', 'Crathie Bellman, The', 'CRATHIE BELLMAN', 2, 32, 9999, 1, 3, 42, 108, '1981-01-01', '', 69, '888/808/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7055, '1998-09-29 22:00:00+00', '2021-10-11 22:47:24.071344+00', 'West''s Hornpipe', 'WESTS HORNPIPE', 1, 32, 9999, 1, 4, 1, 9998, '1797-01-01', '', 55, '8888  8888  8000  8204', 1, 1, 1, 0, 54);
INSERT INTO 'dance' VALUES (15551, '2014-07-27 13:34:31.306919+00', '2016-05-11 14:21:13.759138+00', 'Beauty of the South', 'BEAUTY OF THE SOUTH', 1, 128, NULL, 1, 107, 3, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15537, '2014-07-14 11:23:47.295182+00', '2018-04-03 00:07:44.886247+00', 'Extra Mile, The', 'EXTRA MILE', 2, 32, NULL, 1, 3, 42, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15442, '2014-05-09 22:35:13.485403+00', '2018-04-03 00:07:48.072726+00', 'George Watson of Tipperlinn', 'GEORGE WATSON OF TIPPERLINN', 2, 32, 9999, 1, 3, 42, 555, '2003-07-06', 'George Watson''s College in Edinburgh was the secondary school the devisor attended and first learned to Scottish Country Dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7042, '2000-09-02 22:00:00+00', '2022-08-19 08:47:45.850213+00', 'Wells House', 'WELLS HOUSE', 3, 32, 9999, 1, 3, 42, 146, NULL, '', 59, '822  844  888  888', 1, 1, 0, 0, 79);
INSERT INTO 'dance' VALUES (13918, '2011-08-22 22:00:00+00', '2018-04-18 11:59:38.729688+00', 'Tying the Knot', 'TYING THE KNOT', 2, 32, NULL, 1, 3, 42, 64, '2005-07-01', 'Devised by Irene van Maarseveen, Pretoria. July 2005.  



In celebration of marriage. A couple dancing the under-the-arm turns for the first time usually gets themselves tied in a knot. The last 16 bars of the dance form a Celtic knotwork pattern.  



Notes:  

If the set is a little wider and shorter than usual. it is easier for 2nd couple to dance down behind 1st couple on bar 4.  



In bars 17-32, 1st couple dance round each of their 4 corner positions in turn, moving anticlockwise round the set, and passing corners alternately by the right shoulder and the left shoulder. They dance right shoulder round 4th corner position. then left round the 1st, right round the 2nd and left round the 3rd. Between each pair of ½ reels. 1st couple should pass partner closely in the middle of the dance, i.e. not finish in the line of the reels except at the end of bar 32. ', 59, '880/840/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7700, '1997-09-01 22:00:00+00', '2014-06-17 00:56:01.978169+00', 'Eilean Donan Castle', 'EILEAN DONAN CASTLE', 1, 48, 9999, 1, 4, NULL, 386, '1968-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15476, '2014-06-18 14:06:28.562257+00', '2014-06-18 14:06:28.562257+00', 'Letchworth Garden City Jig', 'LETCHWORTH GARDEN CITY JIG', 2, 32, NULL, 1, 4, 1, 10970, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4939, '1998-04-19 22:00:00+00', '2014-06-23 09:54:31.920555+00', 'New Zealand 1990', 'NEW ZEALAND 1990', 3, 128, 9999, 4, 4, 54, 108, '1989-09-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15054, '2013-08-06 13:26:40.461568+00', '2014-06-26 15:47:18.490586+00', 'New Approach, A', 'NEW APPROACH', 3, 32, 9999, 3, 5, 7, 154, NULL, 'Devised: 2006-11', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15426, '2014-05-02 15:22:42.40629+00', '2018-04-02 23:56:34.625249+00', 'Fly on the Table, The', 'FLY ON THE TABLE', 4, 32, 1, 1, 3, 42, 10950, '2009-01-01', 'The dance was devised at the 2009 Saskatchewan Branch workshop at Manitou Lake.



A fly was taking a stroll around the drinking glasses on the banquet table in Danceland Hall. The dance replicates the fly''s leisurely stroll around the table. The fly''s stroll takes him down the handle of the fly swatter, completely unaware of what awaits him upon his stroll''s completion. Suddenly, the swatter closes in. He takes flight moving around, avoiding the swatter. The swatter (corners) tries hard to swat the fly, but it''s not easy. The fly manages to survive and he begins his leisurely stroll again.



Note: clapping hands with the person diagonally opposite rarely comes together gracefully – have fun catching that pesky fly!', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15527, '2014-07-14 09:40:35.715404+00', '2014-07-14 09:40:35.715404+00', 'Santa Barbara Strathspey', 'SANTA BARBARA STRATHSPEY', 3, 32, NULL, 1, 4, 1, 2488, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15657, '2014-10-07 22:44:19.807646+00', '2014-10-08 16:32:38.41063+00', 'Festival Dream', 'FESTIVAL DREAM', 3, 64, NULL, 4, 4, 3, 11024, '1991-01-01', 'This is a demonstration dance.  ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8953, '1999-02-21 23:00:00+00', '2014-10-15 02:02:03.360472+00', 'St Barnabas Strathspey', 'SAINT BARNABAS STRATHSPEY', 3, 32, 9999, 3, 5, 16, 692, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11991, '2005-01-30 23:00:00+00', '2014-10-14 07:42:41.574897+00', 'Avis Harrison''s Strathspey', 'AVIS HARRISONS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 692, NULL, '', 92, '880/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15559, '2014-07-27 13:59:10.226924+00', '2018-04-02 23:56:38.44906+00', 'Weave the Plaid', 'WEAVE THE PLAID', 2, 32, NULL, 1, 3, 42, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15479, '2014-06-20 11:04:30.987182+00', '2018-08-14 18:15:42.358443+00', 'Thistle and the Columbine, The', 'THISTLE AND THE COLUMBINE', 2, 32, NULL, 1, 3, 42, 10323, NULL, '', 56, '844/888/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13590, '2010-08-08 22:00:00+00', '2018-04-02 23:56:38.649511+00', 'Zoologist, The', 'ZOOLOGIST', 2, 32, NULL, 1, 3, 42, 854, NULL, '', 62, '844  844  888  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (15469, '2014-06-09 20:02:46.432871+00', '2018-04-03 00:07:46.963243+00', 'Freshwater Bay', 'FRESHWATER BAY', 3, 32, NULL, 1, 3, 42, 347, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15757, '2015-01-10 14:04:55.866354+00', '2015-01-10 14:04:55.866354+00', 'Sheila Carmichael', 'SHEILA CARMICHAEL', 2, 32, 9999, 1, 4, 1, 993, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15480, '2014-06-22 09:40:08.569881+00', '2016-09-19 00:36:20.47912+00', 'Trip to Tallinn, A', 'TRIP TO TALLINN', 3, 32, NULL, 2, 3, 17, 228, '2014-06-22', 'Written for Anselm''s weekend workshop in Tallinn, Estonia, in June 2014.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5801, '1997-11-27 23:00:00+00', '2016-05-11 08:14:21.274106+00', 'St Andrew''s Double Foursome', 'SAINT ANDREWS DOUBLE FOURSOME', 4, 128, 2, 107, 4, NULL, 251, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15467, '2014-06-09 19:58:24.906655+00', '2018-04-03 00:08:00.899372+00', 'Luckenbooth Challenge, The', 'LUCKENBOOTH CHALLENGE', 2, 32, NULL, 1, 3, 42, 10967, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19003, '2018-10-17 13:02:01.845824+00', '2018-10-17 13:02:01.845824+00', 'Peregrinations of Mistress Bradley, The', 'PEREGRINATIONS OF MISTRESS BRADLEY', 4, 128, 10034, 1, 4, 11, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15655, '2014-10-04 00:49:15.320345+00', '2018-12-23 14:29:23.477087+00', 'Our Breton Friends', 'OUR BRETON FRIENDS', 4, 128, 2, 4, 4, 3, 11019, '2012-12-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15486, '2014-06-27 20:57:15.926986+00', '2019-01-22 22:57:50.956696+00', 'Simplicity at Home', 'SIMPLICITY AT HOME', 2, 32, NULL, 1, 3, 42, 10971, NULL, '', 69, '880/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15523, '2014-06-27 21:19:58.043162+00', '2019-01-23 23:31:29.576942+00', 'Tribute to Ellen and Jim, A', 'TRIBUTE TO ELLEN AND JIM', 1, 40, NULL, 3, 5, 16, 10971, NULL, 'Dedicated to Jim and Ellen McRanor, in celebration of their 50th Wedding Anniversary.

', 64, '80008/84848/40444/48488/44888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3869, '2002-04-28 22:00:00+00', '2019-03-14 22:04:19.841583+00', 'Loch Ness Monster', 'LOCH NESS MONSTER', 3, 48, 9999, 1, 4, 1, 697, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16593, '2015-08-26 15:47:44.488373+00', '2018-04-02 23:56:38.482432+00', 'Wee Giant, The', 'WEE GIANT', 1, 32, 9999, 1, 3, 42, 403, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15536, '2014-07-14 11:22:48.918683+00', '2020-03-09 15:23:31.794781+00', 'Duckies in the Bath', 'DUCKIES IN THE BATH', 3, 32, NULL, 2, 3, 18, 1415, NULL, '', 88, '888/888/848/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7943, '1997-09-14 22:00:00+00', '2020-04-18 23:17:25.636006+00', 'Shake the Pudding Down', 'SHAKE THE PUDDING DOWN', 1, 40, 9999, 3, 5, 26, 1, NULL, '', 70, '80008/88888/82428/88888/80408', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11066, '2002-12-01 23:00:00+00', '2020-06-03 22:19:56.551772+00', 'Garden City Strathspey, The', 'GARDEN CITY STRATHSPEY', 3, 40, 9999, 1, 3, 42, 3268, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6682, '1998-04-19 22:00:00+00', '2021-06-14 23:08:58.673357+00', 'Travelling Men, The', 'TRAVELLING MEN', 2, 32, 9999, 3, 5, 7, 146, '1986-01-01', '"For the bands who come to play for the Branch."', 65, '84844/84844/82842/82842', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18500, '2018-08-13 16:33:21.595163+00', '2020-11-16 21:12:17.601479+00', 'Golden Hornpipe, The', 'GOLDEN HORNPIPE', 1, 32, NULL, 1, 4, 1, 80, '2007-01-01', 'Inscribed to the founders of TAC and all the teachers over the years who helped

this happy family grow and prosper. HISCD', 69, '8484/4848/8000/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18570, '2018-09-09 21:58:53.607065+00', '2021-01-20 01:55:07.530471+00', 'Woggle Bug, The', 'WOGGLE BUG', 2, 32, NULL, 1, 3, 42, 2766, '2010-12-01', 'The Woggle Bug is a character in the OZ books by L. Frank Baum.', 56, '844/844/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9905, '2001-06-13 22:00:00+00', '2018-04-03 00:08:26.159624+00', 'Windings of the Forth, The', 'WINDINGS OF THE FORTH', 1, 40, 9999, 1, 3, 42, 2889, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15488, '2014-06-27 20:58:22.845055+00', '2019-01-22 23:05:04.714825+00', 'Lady Lauren', 'LADY LAUREN', 2, 32, NULL, 4, 4, 1, 10971, NULL, 'Inscribed "For my granddaughter Lauren, on her birthday."', 100, '8888/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15508, '2014-06-27 21:11:52.939967+00', '2019-01-23 17:09:40.010688+00', 'Bonnie''s Reel', 'BONNIES REEL', 1, 32, NULL, 1, 2, 76, 10971, NULL, 'Inscribed "For my daughter-in-law, Bonnie Dugan."', 69, '88/88/88/88', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15489, '2014-06-27 20:58:51.769361+00', '2019-01-22 23:08:44.711939+00', 'Spirit of Stratford', 'SPIRIT OF STRATFORD', 2, 32, NULL, 1, 4, 1, 10971, NULL, '', 81, '8888/8888/8888/8000', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5828, '1997-09-13 22:00:00+00', '2019-04-26 22:37:38.81072+00', 'Saint James''s Jig', 'SAINT JAMESS JIG', 2, 32, 9999, 1, 3, 42, 313, NULL, 'For Lorena Bartlett, first Chairman of Sutton Coldfield Branch of the Royal Scottish Country Dance Society. For many years, St. James''s Church Hall, Mere Green, was the venue for monthly Social Dances in Sutton Coldfield.', 56, '800/880/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3791, '2002-02-26 23:00:00+00', '2021-05-15 11:18:59.580171+00', 'Asilomar Romantic', 'ASILOMAR ROMANTIC', 3, 32, 9999, 1, 3, 42, 588, '1985-01-01', '', 41, '808  880  800  822', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (12618, '2005-11-08 23:00:00+00', '2014-05-05 22:52:04.969236+00', 'Three Couple Reel, A', 'THREE COUPLE REEL', 1, 96, 9999, 2, 3, 17, 3647, NULL, 'Demonstration dance.



Bars 



1 - 4  All set to partner and Petronella turn into a line up and down the centre of the set, Men facing up to partners and Ladies facing down.



5 - 16  All dance a right shoulder reel of 6 finishing in starting position.



17 - 20  All set and turn partners with the right hand to finish facing up in promenade hold.



21 - 24  Half circular promenade, 1st Cpl. casting down and round to finish with the 1st Lady in 3rd Ladies position, 2nd Cpl. moving slightly out to right before following 1st Cpl. finishing 2nd Lady in partners position and the 3rd Cp] dance the remaining part of the circle to finish with the 3rd Lady in 1st Lady’s position.



Dancing couples finish in a three pointed star position facing anticlockwise Men on the inside joining Lt. hands in the centre and Ladies on the outside all having their nearer arm around their partners waist to keep the star tight.



25 - 28  Lt. hands across half way round. Finish with the men rotating their partners into the centre with the Ladies taking Rt. hands in the centre as in the eightsome reel.



29 - 32  Rt. hands across back to the position at the start of the Lt. hands across, Ladies still facing anti clockwise and retaining Rt. hands in the centre.



LADIES CHAINS – Bars 33 – 44 Note Men dance as per normal ladies chain.



33 - 34  Ladies drop their partners and continue the right hand across to the next but one man.



35 - 36  Ladies turn that man with the Lt. hand.



37 - 44  Ladies repeat bars 33 to 36 twice with new Men but finish retaining partners Lt. hand.



45 - 46  Continue turning partners with the Lt. hand to finish in a longwise set, (3, 2, 1) with 1st and 3rd Cpl.s on own sides and 2nd Cpl. in partner’s place.



47 - 48  Set to partners, on the last bar the 2nd and 1st Cpl.s turn to face ready for grand chain. 3rd Cpl. remain facing across the dance.



49 - 60  Pass and turn grand chain. (Pass first person right hand and turn the next person with left hand, repeat right round the set, each combination of right and left hand movement takes 4 bars.)



61 - 64  All Set and cross passing partner with the left shoulder.



65 - 72  Irish Rover rights and lefts, 2nd Lady going up each time and Man down. All finish in original place.



73 - 80  All set and Petronella twice to opposite side of the dance.



81 - 84  Men set and high cuts, Ladies set and point.



85 - 88  All set and turn partners into Allemande position.



89 - 96  Three Cpl. Allemande finishing 3, 2, 1.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15468, '2014-06-09 20:00:30.013654+00', '2014-06-09 20:00:30.013654+00', 'Elspeth''s Farewell', 'ELSPETHS FAREWELL', 2, 48, NULL, 2, 3, NULL, 10967, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15477, '2014-06-18 14:07:55.96624+00', '2014-06-18 14:24:09.152176+00', 'Garden City Strathspey', 'GARDEN CITY STRATHSPEY', 3, 32, NULL, 4, 4, 4, 10970, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15487, '2014-06-27 20:57:47.61527+00', '2019-01-22 23:00:15.378851+00', 'Latha Math', 'LATHA MATH', 2, 40, NULL, 1, 3, 42, 10971, NULL, 'A Scottish Gaelic Greeting.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15500, '2014-06-27 21:05:45.923631+00', '2019-01-22 23:53:13.944662+00', 'Why Not?', 'WHY NOT', 3, 32, NULL, 1, 3, 42, 10971, NULL, '', 63, '888/888/800/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6775, '1997-04-03 22:00:00+00', '2019-03-09 13:57:07.750156+00', 'Turnberry Tensome, The', 'TURNBERRY TENSOME', 1, 32, 9999, 3, 5, 7, 13, NULL, '', 75, '08080/48884/48884/88888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15452, '2014-05-25 09:04:52.093549+00', '2018-01-12 01:54:03.614479+00', 'Posh Scotsman, A', 'POSH SCOTSMAN', 2, 32, NULL, 1, 3, 42, 3192, NULL, 'Dedicated to George Kerr, the regular musician at the Peterborough RSCDS practice sessions, who helps me with the music for my dances.

George, a Scotsman settled in Peterborough (nickname of ''POSH'') after serving in WW2.

The City underwent a major rebuilding exercise some years ago and the dance is intended to show signs of the initial upheaval in the first eight bars of the dance.

The City is famous for all its roundabouts and this is reflected in the circling shown in the last eight bars of the music.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2056, '1998-07-08 22:00:00+00', '2016-07-26 00:21:07.072525+00', 'Falls of Bracklinn, The', 'FALLS OF BRACKLINN', 3, 32, 9999, 1, 114, 2, 313, NULL, 'The Falls of Bracklinn are on the Keltie Water to the North-East of Callander.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15427, '2014-05-07 22:16:33.922956+00', '2017-06-21 10:13:47.408902+00', 'Clydeside Reel, The', 'CLYDESIDE REEL', 1, 32, NULL, 5, 2, NULL, 144, NULL, '', 100, '88/88/88/88', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5725, '1997-04-03 22:00:00+00', '2014-06-01 03:13:03.012857+00', 'Rowan Glen, The', 'ROWAN GLEN', 2, 32, 9999, 3, 5, 7, 313, NULL, 'For Sue Barnes, first secretary of the Sutton Coldfield Branch of the Royal Scottish Country Dance Society.



Glen Esk, fairest of the Glens of Angus, is famed for its rowan trees, and way up the glen is the Rowan itself, a hill noted for whisky bothy and cairn as much as for its trees.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13394, '2009-11-08 23:00:00+00', '2020-09-17 08:36:27.871068+00', 'Tribute to Peter McBryde, A', 'TRIBUTE TO PETER MACBRYDE', 3, 32, NULL, 2, 3, 17, 10374, NULL, '»Devised by Louis Emslie of Kitchener-Waterloo, Ontario, and dedicated to the memory of Peter McBryde, dancer, teacher, and friend to many members of the Kitchener-Waterloo Branch of the RSCDS. Peter was also a very active member of TAC.«', 90, '888/888/886/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18501, '2018-08-13 16:36:27.971804+00', '2020-11-16 21:18:22.022661+00', 'King Sized Bed, The', 'KING SIZED BED', 2, 32, NULL, 1, 4, 1, 80, '2001-01-01', 'Dedicated to Sheila Kennedy and all the ladies of the Qualicum Beach (Vancouver Island) Wednesday afternoon class', 66, '8008/0880/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4871, '1998-09-30 22:00:00+00', '2021-01-11 18:00:28.032409+00', 'My Spouse Nancy', 'MY SPOUSE NANCY', 1, 32, 9999, 1, 3, 42, 386, '1981-01-01', 'Devised by Jimmy Taylor in 1981 for his wife.', 62, '800  888  888  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (12437, '2005-05-09 22:00:00+00', '2021-01-14 20:13:42.728817+00', 'Promise of Spring', 'PROMISE OF SPRING', 1, 32, 9999, 1, 3, 42, 2793, '2004-01-01', 'Devised for the Winnipeg Workshop, March 2004. 



The triangle formation signifies the geese returning and the last figure gives the idea of lambs frolicking and changing directions!', 56, '800/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2135, '2000-07-02 22:00:00+00', '2021-03-11 14:03:10.507737+00', 'Fete Champetre, The', 'FETE CHAMPETRE', 2, 128, 9999, 4, 4, 54, 313, NULL, 'Barry Priddey also devised a simplified version of this dance called <<ddd:Woodland Assembly#7227>>.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15539, '2014-07-17 14:16:23.987282+00', '2021-04-02 21:14:11.088332+00', 'Around the World to Meet You', 'AROUND THE WORLD TO MEET YOU', 3, 40, NULL, 4, 4, 1, 10517, '2011-01-01', 'Devised by Dirk Kölbl telling the story of the meeting of Sophie and Sjoerd.', 70, '6060/0606/6666/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15478, '2014-06-18 14:12:28.75396+00', '2014-06-18 14:12:28.75396+00', 'Tribute to Ebenezer Howard', 'TRIBUTE TO EBENEZER HOWARD', 1, 48, NULL, 1, 4, 1, 3122, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5262, '1998-01-05 23:00:00+00', '2014-06-27 21:20:11.421833+00', 'Pinewoods Reel', 'PINEWOODS REEL', 1, 32, 9999, 1, 3, 42, 101, NULL, 'There is an issue with video #2 - it is not performed as written. ', 54, '808  888  844  867', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (6073, '1997-04-03 22:00:00+00', '2018-04-02 23:56:37.589289+00', 'Silver Castle Reel', 'SILVER CASTLE REEL', 1, 40, 9999, 1, 3, 42, 386, '1985-01-01', 'Devised in 1985 to celebrate the Silver Jubilee of the Stirling Castle Scottish Country Dance Group.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15533, '2014-07-14 11:18:07.945394+00', '2014-07-14 11:18:07.945394+00', 'Dags of Inveroran', 'DAGS OF INVERORAN', 3, 32, NULL, 1, 4, NULL, 1415, NULL, '2nd and 4th couples start on the opposite side. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9842, '2001-06-13 22:00:00+00', '2018-04-03 00:07:34.558368+00', 'Boggs Chase, The', 'BOGGS CHASE', 2, 32, 9999, 1, 3, 42, 2904, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15560, '2014-07-27 14:02:24.794823+00', '2014-07-27 14:02:24.794823+00', 'Hodden Shawl, The', 'HODDEN SHAWL', 2, 32, NULL, 5, 56, NULL, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15563, '2014-07-27 14:14:44.809263+00', '2014-07-27 14:14:44.809263+00', 'Weave the Basket', 'WEAVE THE BASKET', 2, 48, NULL, 4, 4, 4, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15561, '2014-07-27 14:05:39.337829+00', '2014-07-27 14:05:39.337829+00', 'Better on the Other Side', 'BETTER ON THE OTHER SIDE', 3, 32, NULL, 5, 56, NULL, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11480, '2003-09-22 22:00:00+00', '2019-01-27 20:29:12.384164+00', 'Swithland Woods', 'SWITHLAND WOODS', 3, 40, 9999, 2, 3, 17, 335, NULL, 'Swithland Woods used to be part of the ancient forest of Charnwood and is now in the new National Forest.  This is a very popular area for walking for the people of Leicestershire.', 83, '888/808/484/866/888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (17998, '2017-10-10 16:49:33.641196+00', '2022-08-19 09:20:00.517222+00', 'Heather''s Real', 'HEATHERS REAL', 1, 32, 9999, 1, 3, 42, 10582, '2016-01-01', 'Celebrating the 10 year anniversary of meeting my wife for the first time.', 52, '820/800/888/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4564, '1997-09-09 22:00:00+00', '2022-11-27 17:41:51.984408+00', 'Miss Nicholl''s Reel', 'MISS NICHOLLS REEL', 1, 32, 9999, 1, 102, 1, 102, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14649, '2013-01-05 08:39:42.438157+00', '2023-01-22 19:53:05.234449+00', 'Rougemont Castle', 'ROUGEMONT CASTLE', 3, 32, NULL, 2, 3, 17, 854, NULL, 'For Exeter Branch 40th anniversary', 69, '800/888/666/808', 0, 1, 1, 0, 68);
INSERT INTO 'dance' VALUES (15501, '2014-06-27 21:06:42.663567+00', '2019-10-15 00:30:25.891403+00', 'Celebration Strathspey', 'CELEBRATION STRATHSPEY', 3, 32, NULL, 1, 4, 1, 10971, NULL, 'To celebrate 10 years of friendship with the Sarasota Dancers.', 75, '8448/8448/8884/4448', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15474, '2014-06-17 00:53:58.422402+00', '2014-06-17 01:06:40.17476+00', 'Stirling Castle 40th Anniversary Reel', 'STIRLING CASTLE 40TH ANNIVERSARY REEL', 1, 40, 9999, 1, 4, 1, 386, '1999-01-01', 'This dance was devised in April 1999, to celebrate 40 years of dancing at the ‘Castle’.



The Dance depicts the movement of young soldiers and their lasses promenading up and down the streets of Stirling as they make their way to a dance at the Castle.

They cross the bridge, enter through the arch and proceed to join in an evening’s reeling before finishing with the traditional Argyll Circle of Eight.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15534, '2014-07-14 11:19:09.580529+00', '2018-04-03 00:07:59.915276+00', 'Lochaber Lass, The', 'LOCHABER LASS', 1, 32, NULL, 1, 3, 42, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13591, '2010-08-08 22:00:00+00', '2014-07-14 21:46:37.86753+00', 'President''s Quadrille, The', 'PRESIDENTS QUADRILLE', 1, 128, NULL, 4, 4, NULL, 246, '2007-11-01', '##RSCDS-DI:bars:8-bar intr', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18498, '2018-08-13 16:26:56.047051+00', '2020-11-15 12:26:42.605752+00', 'Glendalough Strathspey, The', 'GLENDALOUGH STRATHSPEY', 3, 32, NULL, 2, 3, 17, 80, '2009-01-01', 'The name in Irish “Gleann Da Locha” translates to “Valley of the Two Lakes” – a lovely peaceful place to rest and be thankful.', 73, '820/888/844/848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18504, '2018-08-13 16:46:06.956316+00', '2020-11-16 21:24:06.403933+00', 'Sailing to Saltspring', 'SAILING TO SALTSPRING', 2, 32, NULL, 2, 3, 17, 80, '2002-04-13', 'Devised for the Saltspring Island Workshop, April 13, 2002.', 75, '888/800/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18506, '2018-08-13 16:49:50.976676+00', '2020-11-16 21:32:31.659097+00', 'Sailing on Shawnigan Lake', 'SAILING ON SHAWNIGAN LAKE', 1, 32, NULL, 2, 3, 17, 80, '2007-01-01', '', 92, '888/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11749, '2004-07-06 22:00:00+00', '2021-01-20 18:19:08.435204+00', 'Colin''s Kilts', 'COLINS KILTS', 2, 40, 9999, 1, 3, 42, 2986, '2003-01-01', 'Devised in memory of Colin Coull, a member of the Ericht Scottish Country Dance Club, who died 2nd October 2002.', 64, '808/808/886/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5617, '1998-10-13 22:00:00+00', '2021-04-22 21:00:43.774361+00', 'Road to Tomintoul', 'ROAD TO TOMINTOUL', 1, 32, 9999, 1, 3, 42, 697, NULL, '', 59, '822/888/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (867, '1998-10-20 22:00:00+00', '2021-06-28 00:46:06.26996+00', 'Burn of Sorrow, The', 'BURN OF SORROW', 3, 32, 9999, 1, 2, 76, 313, NULL, 'Rising in the Ochil Hills, the Burn of Sorrow flows through the spectacular Windy Pass into the Dollar Glen, where it is joined by the Burn of Care, below the ruins of Castle Campbell.', 60, '66/66/88/88', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15576, '2014-08-26 16:54:35.088728+00', '2021-07-30 08:21:11.041862+00', 'Barrie Alexander Strathspey, The', 'BARRIE ALEXANDER STRATHSPEY', 3, 32, NULL, 1, 4, 2, 308, '2007-06-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15470, '2014-06-13 23:21:51.927455+00', '2014-06-23 19:23:45.554776+00', 'Melanie''s Reel', 'MELANIES REEL', 1, 32, NULL, 1, 3, 42, 3342, '2012-05-01', 'The dance has not been published on paper or online.  The PDF written by the authors reads in full: 



Melanie’s Reel



A 32 bar reel for 3 couples in a 4 couple set



1 - 8 1C and 2C dance the Chain Progression, 1C finish facing out.



9 - 16 1C cast to their right round 3rd corner and dance towards each other up and down the dance, turn right hand one and a half times to finish facing each other, pull right shoulder back and finish back to back, 1L facing up, 1M facing down.



17 – 24 1C dance Double Triangles; on bars 23 and 24, 1L rotates around to face down, 1M does a

quarter rotation to finish in the middle in 2nd place, with his partner on his right.



25 – 32 1C with nearer hands joined, dance down the middle; on bars 28 and 29, 1L dances under

her partners arm, 1M dancing below his partner and 1C dance up to 2nd place own side.



Repeat from 2nd place



"For Melanie, who brightened the Lausanne Group with her smile and especially her fits of giggles.  We will miss her but our loss will be another group''s gain.  She might even learn to love the strathspey.



Devised by Avril and David Quarrie, May 2012



', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15538, '2014-07-16 14:50:15.023752+00', '2018-04-03 00:08:24.98339+00', 'Whangarei Scottish, The', 'WHANGAREI SCOTTISH', 1, 32, NULL, 1, 3, 42, 411, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14183, '2011-08-26 22:00:00+00', '2015-04-05 09:46:02.843463+00', 'Dundee Dragon, The', 'DUNDEE DRAGON', 1, 32, NULL, 1, 3, 42, 127, NULL, 'Devised for Clare Davitt.', 41, '800/833/833/844', 0, 1, 0, 0, 54);
INSERT INTO 'dance' VALUES (19004, '2018-10-17 13:02:53.735904+00', '2019-01-29 00:17:51.128691+00', 'Reel, Margaret Johnstone, The', 'REEL MARGARET JOHNSTONE', 1, 32, NULL, 1, 3, 42, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14685, '2013-01-23 12:42:19.47465+00', '2017-07-15 00:24:07.539343+00', 'It Wisnae Me', 'IT WISNAE ME', 3, 32, NULL, 1, 100, 2, 1359, '2006-01-01', 'Inscribed to her students who when mistakes happen in class say "It wisnae me".', 87, '8008  8888  8888  8888', 1, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (15502, '2014-06-27 21:07:14.870955+00', '2019-01-23 00:04:15.963227+00', 'Cottage Country', 'COTTAGE COUNTRY', 3, 32, NULL, 1, 100, NULL, 10971, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19005, '2018-10-17 13:03:53.102079+00', '2018-10-17 13:03:53.102079+00', 'Rose of Arbeia', 'ROSE OF ARBEIA', 2, 32, NULL, 1, 4, 2, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19006, '2018-10-17 13:04:43.660865+00', '2018-10-17 13:04:43.660865+00', 'Sand Dancer, The', 'SAND DANCER', 2, 32, NULL, 2, 3, 17, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15509, '2014-06-27 21:12:24.605061+00', '2019-01-23 17:14:07.015032+00', 'Loon Dance, The', 'LOON DANCE', 1, 32, NULL, 1, 2, 76, 10971, NULL, 'Devised at Haliburton while listening to the mournful call of loons.

', 69, '88/88/88/88', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15514, '2014-06-27 21:14:55.713151+00', '2019-01-23 18:12:56.354866+00', 'October in the Rain', 'OCTOBER IN THE RAIN', 1, 32, NULL, 1, 3, 42, 10971, NULL, '', 69, '888/888/880/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15519, '2014-06-27 21:17:50.344299+00', '2019-10-15 08:36:45.376633+00', 'Murphy''s Reel', 'MURPHYS REEL', 1, 32, NULL, 1, 4, 1, 10971, NULL, 'Murphy is the name of the deviser''s dog.', 84, '8888/8888/8048/8448', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15622, '2014-09-12 20:18:29.926745+00', '2018-04-10 12:00:27.633038+00', 'No', 'NO', 1, 32, 9999, 2, 3, 18, 3179, '2014-09-07', 'In response to George Watt''s "YES"



In Pretoria we will have a Scottish Referendum social on the 18th september 2014  and will dance both "YES" and "NO". Whatever the outcome of the referendum - Scotland will be Scotland :-)



Published as Strathspey message 66179; (typos corrected in 66180  and 66181)



The URL - on that page click on "NO" - will give both the instructions and the tune.

', 71, '080/484/888/884', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18021, '2017-10-20 16:11:14.601621+00', '2017-10-20 16:11:14.601621+00', 'Gypsy Tap', 'GYPSY TAP', 11, 32, NULL, 5, 1, NULL, 11536, '1920-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10800, '2002-08-25 22:00:00+00', '2022-09-27 15:46:19.133641+00', 'Miss Shearer''s Strathspey', 'MISS SHEARERS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 246, '2001-01-01', 'This dance was devised as a tribute from RSCDS Stirling to Miss A N (Nana) Shearer, the senior teacher in the Branch, in recognition of over 55 years of dedicated and distinguished service to the Branch and to the work of the Society.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18729, '2018-10-04 07:50:05.094566+00', '2023-01-22 19:52:23.062426+00', 'Death Star, The', 'DEATH STAR', 1, 32, NULL, 1, 3, 42, 2766, '2014-04-01', 'This dance is one of two written especially for a Star Wars themed dance night.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15524, '2014-06-27 21:20:33.213719+00', '2022-12-18 12:36:11.431634+00', 'Martin''s Hornpipe', 'MARTINS HORNPIPE', 1, 32, NULL, 1, 4, 2, 10971, NULL, 'For Martin, a cherished friend.', 75, '8008/8008/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4246, '1997-09-08 22:00:00+00', '2023-02-07 22:11:48.928447+00', 'Mayflower, The', 'MAYFLOWER', 1, 32, 9999, 5, 1, 4, 209, NULL, 'On the description: The Mayflower is our provincial flower emblem. This dance was first performed at the Nova Scotia dance camp to introduce Scottish Country Dancing to folk dancers, ballroom dancers and square dancers, and has become a favourite of the camp for quite a number of years.', 69, '8  4  4  6', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2933, '1998-04-12 22:00:00+00', '2014-10-04 10:35:12.950952+00', 'Highlander''s Jig, The', 'HIGHLANDERS JIG', 2, 32, 9999, 1, 3, 42, 101, '1993-01-01', 'The dance was devised for Robert and Barbara McOwen', 56, '808/888/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10419, '2002-03-25 23:00:00+00', '2014-10-07 14:03:42.968236+00', 'Odd Man Out', 'ODD MAN OUT', 1, 32, 9999, 1, 3, 42, 3075, NULL, 'Daniel wrote: A friend of mine saw the video [of the variant] and commented that the dance was lame because the 3C stands out until the last eight bars.  I had to inform her it was even more lame than the video showed because they are not even included in the last eight bars.  The 3M is so excluded, he is not even danced around, thus, "Odd Man Out."



In a variant of this dance, 2c+1c+3c make the final circle and back.', 37, '800/880/800/880', 1, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (15660, '2014-10-19 09:05:31.655918+00', '2014-10-19 09:18:46.10593+00', 'Bev''s Dance', 'BEVS DANCE', 1, 32, NULL, 1, 3, 42, 11025, '2013-01-01', 'Written for Bev Rush, treasurer of Blue Mountains Scottish Country Dance Club.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12572, '2005-10-27 22:00:00+00', '2014-11-09 19:36:19.21284+00', 'Spinnaker Hornpipe', 'SPINNAKER HORNPIPE', 1, 40, 9999, 1, 2, NULL, 2682, '2004-01-01', 'This dance introduces the GAY GORDONS POUSSETTE, a new progression. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6585, '1997-11-25 23:00:00+00', '2020-07-15 20:03:24.489306+00', 'Threesome Reel, The', 'THREESOME REEL', 4, 96, 11, 107, 53, NULL, 9998, NULL, '', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18502, '2018-08-13 16:38:32.854202+00', '2020-11-16 21:21:06.96823+00', 'MacLeod''s Silver Sea', 'MACLEODS SILVER SEA', 1, 32, NULL, 2, 3, 17, 80, '2002-01-01', 'Inscribed to Anne and Gavin MacLeod for their Silver Wedding Anniversary. The title refers to the sea around Skye and Raasay where Gavin’s family originated. Also the sea surrounding Vancouver Island which Ann and Gavin can SEE (pun intended) from their lovely garden, where the Silver Jubilee was celebrated in style.', 92, '888/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11597, '2003-11-29 23:00:00+00', '2021-01-16 12:52:00.362608+00', 'Whangarei Whirlwind, The', 'WHANGAREI WHIRLWIND', 3, 32, 9999, 1, 3, 42, 411, '2000-01-01', '"For Fiona Bullivant who shares teaching at the Whangarei Scottish Country Dance Club. Fiona has boundless energy and among many other gifts as a teacher can really make the Tourbillon flow."', 78, '8800/4488/8888/4888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15669, '2014-10-19 16:22:12.559878+00', '2021-04-09 15:44:16.009096+00', 'Katoomba', 'KATOOMBA', 3, 32, NULL, 4, 4, 1, 11029, NULL, 'Dance devised to celebrate the annual Branch Katoomba Weekend, where the dancers gather to dance and mix together.', 88, '8686/8888/2828/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2269, '1997-11-25 23:00:00+00', '2021-07-09 08:10:11.443659+00', 'Follow my Love', 'FOLLOW MY LOVE', 2, 128, 9999, 4, 4, 3, 917, NULL, 'Different editions of the Imperial Books ascribed this to Freda Sattler or John Bayly.', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15540, '2014-07-21 11:01:28.617199+00', '2018-04-03 00:07:31.871769+00', 'Back to Berlin', 'BACK TO BERLIN', 1, 32, 9999, 1, 3, 42, 10974, '2014-06-25', 'Teaching note: When dancing the advance and retire, make sure the dancing couple does not advance too close to be able to petronella out to sides.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15674, '2014-10-19 16:48:30.71365+00', '2014-10-19 16:48:37.261563+00', 'Reeling on the Rocks', 'REELING ON THE ROCKS', 1, 32, NULL, 1, 3, 42, 10800, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3431, '1997-04-03 22:00:00+00', '2018-07-18 14:56:49.181907+00', 'Ken Bridge', 'KEN BRIDGE', 1, 32, 9999, 1, 3, 42, 129, NULL, '', 49, '880/888/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15541, '2014-07-27 12:59:54.148529+00', '2014-07-27 12:59:54.148529+00', 'Silver Buckle, The', 'SILVER BUCKLE', 3, 32, NULL, 2, 3, 17, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15544, '2014-07-27 13:12:49.045841+00', '2014-07-27 13:12:49.045841+00', 'Balanced Rock Reel', 'BALANCED ROCK REEL', 1, 32, NULL, 2, 3, 17, 2018, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6214, '1997-09-14 22:00:00+00', '2014-07-30 09:08:56.710622+00', 'South Of The Grampians', 'SOUTH OF THE GRAMPIANS', 3, 32, 9999, 1, 4, 1, 173, NULL, '', 100, '8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15565, '2014-08-18 13:59:46.548987+00', '2014-08-18 14:13:34.683385+00', 'Spark Dance', 'SPARK DANCE', 1, 202, NULL, 1, 4, 28, 10910, NULL, 'This is a stub entry, still very incomplete; the information has been derived from the Danciemaetion video.  ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7914, '1997-12-03 23:00:00+00', '2014-08-23 07:27:19.481414+00', 'Round House Jig, The', 'ROUND HOUSE JIG', 2, 64, 9999, 4, 4, NULL, 619, NULL, '', -1, '840  800  844  866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5711, '1997-04-03 22:00:00+00', '2014-08-23 07:41:49.300776+00', 'Round House Reel, The', 'ROUND HOUSE REEL', 1, 32, 9999, 4, 4, 4, 13, NULL, '', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15456, '2014-05-31 21:16:26.368677+00', '2019-01-02 23:54:15.126161+00', 'Red Squirrel, The', 'RED SQUIRREL', 1, 32, NULL, 1, 3, 42, 640, NULL, '', 59, '866/866/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15691, '2014-11-02 21:23:30.01251+00', '2015-09-05 21:19:07.540474+00', 'Major Clark''s Farewell', 'MAJOR CLARKS FAREWELL', 2, 32, NULL, 1, 3, 42, 3593, '2012-05-01', 'This dance and tune celebrate the life of Clark Cavin, a long time member of the Seattle Branch.  Clark served in many positions, and was a valued participant.', 66, '888/822/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15575, '2014-08-26 16:24:47.809725+00', '2016-12-31 21:27:44.923758+00', 'Abbie''s Twizzle', 'ABBIES TWIZZLE', 1, 32, NULL, 1, 3, 42, 10991, '2011-01-01', 'Specially devised for and danced at RSCDS AGM Weekend, Glasgow, 2011. ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14895, '2013-05-24 14:01:03.824921+00', '2017-12-26 20:36:49.958065+00', 'Extraordinary Marilyn', 'EXTRAORDINARY MARILYN', 3, 32, NULL, 1, 3, 42, 3504, NULL, 'For Marilyn Stocker, dancer, singer, pilot, and quilter extraordinaire', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19007, '2018-10-17 13:05:38.160285+00', '2019-01-29 00:17:38.652867+00', 'Smiling Margaret', 'SMILING MARGARET', 1, 32, NULL, 1, 3, 42, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13163, '2006-12-11 23:00:00+00', '2019-04-03 21:56:12.814537+00', 'Rye Twist', 'RYE TWIST', 1, 32, 9999, 3, 5, 16, 2766, '2006-01-01', 'The figure in bars 1-20 is taken from the dance Coming Through the Rye. I liked the figure and wanted to use it in my own dance.', 61, '68400/80484/80008/88888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13624, '2010-10-13 22:00:00+00', '2019-09-13 21:49:19.55738+00', 'Reel for Davina, A', 'REEL FOR DAVINA', 1, 32, 9999, 1, 4, 1, 374, NULL, '', 41, '8000/8440/8440/8004', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17721, '2017-04-30 09:56:46.205677+00', '2018-04-02 23:56:36.378684+00', 'Miss Lilian Ross'' Socks', 'MISS LILIAN ROSS SOCKS', 1, 32, NULL, 1, 3, 42, 3325, '2012-01-01', 'This dance links a favourite pair of white socks knitted for the deviser by Miss Lilian Ross in 1975 and the 90th Annversary of the RSCDS - ninety is depicted in the first 8 bars of the dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3636, '1998-11-14 23:00:00+00', '2014-08-24 19:54:55.18484+00', 'Lady Sophia Lindsay', 'LADY SOPHIA LINDSAY', 1, 32, 9999, 1, 100, 2, 13, NULL, '', 69, '0880  4884  8888  8008', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (13647, '2011-03-09 23:00:00+00', '2014-08-25 05:20:20.559769+00', 'Forget Me Knot', 'FORGET ME KNOT', 3, 32, 9999, 2, 3, 18, 10307, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15580, '2014-08-26 20:31:13.449197+00', '2014-08-26 20:33:53.100111+00', 'Compass Rose, The', 'COMPASS ROSE', 3, 32, NULL, 1, 3, 42, 555, '2008-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15581, '2014-08-26 20:38:54.368789+00', '2014-08-26 20:54:05.838882+00', 'Falling Maple Leaf, The', 'FALLING MAPLE LEAF', 3, 32, NULL, 4, 55, 16, 10993, '2012-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15584, '2014-08-26 21:22:06.42+00', '2014-08-26 21:29:58.316282+00', 'Jig For Hazel, A', 'JIG FOR HAZEL', 2, 32, NULL, 1, 3, 42, 9998, '2011-01-01', 'This Video was the only source available for creating this entry', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8058, '1998-07-08 22:00:00+00', '2014-08-26 22:49:25.116815+00', 'Jamie''s Jig', 'JAMIES JIG', 2, 32, 9999, 1, 4, 1, 598, NULL, '', 72, '8888/8888/8000/8444', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10488, '2002-04-19 22:00:00+00', '2022-04-26 09:30:26.869261+00', 'Tony and Judith of Formby', 'TONY AND JUDITH OF FORMBY', 3, 32, 9999, 1, 3, 42, 3097, '1999-03-14', 'In 2014 a revision of this dance (original from the 2007 Nutmeg Collection) was published.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15704, '2014-11-18 18:34:40.674635+00', '2022-04-26 09:32:55.05712+00', 'Tony and Judith of Formby, (Take II)', 'TONY AND JUDITH OF FORMBY TAKE II', 3, 32, NULL, 1, 3, 42, 3097, '2014-04-14', '2014 revision of original dance published in The Nutmeg Collection, 2002', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3699, '1997-08-25 22:00:00+00', '2022-12-10 19:47:15.063345+00', 'Lang Whang, The', 'LANG WHANG', 3, 32, 9999, 1, 3, 42, 101, NULL, 'The notes say that the "Lang Whang Is a stretch of the A70 near Edinburgh."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15564, '2014-08-06 16:06:06.102683+00', '2023-01-01 02:02:46.385769+00', '4 Diane', '4 DIANE', 1, 88, 9999, 4, 4, 3, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15562, '2014-07-27 14:12:17.834863+00', '2014-07-27 14:12:17.834863+00', 'Follow My Lassokie', 'FOLLOW MY LASSOKIE', 3, 48, NULL, 4, 4, 1, 2018, NULL, 'According to George Ellis''s <<http://books.google.de/books?id=IdATAAAAQAAJ&lpg=PA403&ots=CTMWEtUjX8&dq=lassokie&hl=de&pg=PA403#v=onepage&q=lassokie&f=false|book>>, *Specimens of early English metrical romances*, »Lassokie« is a Western Scottish diminutive of »lass«, i.e., girl.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16811, '2015-10-28 19:51:56.705396+00', '2015-10-28 19:51:56.705396+00', 'Freedom Reel 1314', 'FREEDOM REEL 1314', 1, 48, NULL, 1, 4, NULL, 2419, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15571, '2014-08-20 12:04:35.390672+00', '2020-02-08 13:13:52.887447+00', 'Snowball Fight', 'SNOWBALL FIGHT', 1, 32, 9999, 1, 3, 42, 10913, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15572, '2014-08-20 12:14:20.326693+00', '2020-02-08 13:44:48.50212+00', 'Flakes on the Road', 'FLAKES ON THE ROAD', 1, 32, 9999, 1, 2, 76, 10913, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15567, '2014-08-19 13:34:55.500123+00', '2020-02-08 13:25:05.669947+00', 'Glacier Express, The', 'GLACIER EXPRESS', 2, 32, 9999, 1, 3, 42, 10913, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3337, '1997-04-03 22:00:00+00', '2020-08-06 15:18:02.019367+00', 'Johnnie''s Jig', 'JOHNNIES JIG', 2, 32, 9999, 5, 2, NULL, 151, NULL, '', 75, '88/80/08/88', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (15651, '2014-10-04 00:12:19.993728+00', '2020-02-12 16:35:54.196421+00', 'Sylvie de Pen Lan', 'SYLVIE DE PEN LAN', 1, 40, NULL, 2, 3, NULL, 11018, NULL, 'Devised by Val Ford in June 2004 for one of our dancing friends at St Quay-Perros, Brittany', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15568, '2014-08-20 11:10:41.698591+00', '2020-07-18 11:51:46.331952+00', 'Midnight Jig, The', 'MIDNIGHT JIG', 2, 32, 9999, 1, 2, 76, 10913, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15582, '2014-08-26 21:02:14.914514+00', '2020-10-09 21:19:41.831137+00', 'Frolic For Fred, A', 'FROLIC FOR FRED', 2, 40, NULL, 4, 4, 46, 186, NULL, 'Deviser uncertain.', 50, '8000/8404/8080/8080/8484', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15588, '2014-08-26 22:15:34.907319+00', '2020-10-09 21:27:48.758171+00', 'Ship Of Dreams', 'SHIP OF DREAMS', 4, 64, 5, 1, 4, 1, 10647, NULL, '', 47, '8000/8880/8220/8800/8000/8088/8022/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19077, '2018-12-06 12:26:20.241695+00', '2021-03-13 20:33:54.546917+00', 'Linktown Strathspey', 'LINKTOWN STRATHSPEY', 3, 32, NULL, 2, 2, 76, 11755, NULL, '', 56, '82/88/88/75', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15552, '2014-07-27 13:38:03.368209+00', '2021-02-19 00:59:01.150553+00', 'Haliburton Circle', 'HALIBURTON CIRCLE', 3, 32, NULL, 4, 4, 13, 2018, NULL, '', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2835, '2003-01-25 23:00:00+00', '2021-05-31 09:38:43.235082+00', 'Heather Hills', 'HEATHER HILLS', 2, 32, 9999, 1, 3, 42, 35, '1978-01-01', 'Written for Heather Bates in 1978 when she moved away from our city, as a thank you for her willing help whenever called upon, and to commemorate a very happy event when her marriage to Jack Kissinger took place in 1980.', 62, '888/800/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15672, '2014-10-19 16:41:55.097676+00', '2021-04-09 08:40:15.096143+00', 'Jacqui''s Lib.', 'JACQUIS LIB', 2, 32, NULL, 1, 116, 2, 197, NULL, 'Dance devised for Jacqui Brocker''s 21st birthday', 81, '8448/8888/8888/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18665, '2018-09-26 21:47:39.841794+00', '2018-09-29 09:46:55.165285+00', 'For the Love of Scottish Country Dancing', 'FOR THE LOVE OF SCOTTISH COUNTRY DANCING', 1, 32, NULL, 1, 3, 42, 2886, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11508, '2003-09-22 22:00:00+00', '2018-10-02 22:37:03.468428+00', 'Caterpillar Calisthenics', 'CATERPILLAR CALISTHENICS', 1, 32, 9999, 1, 3, 42, 2766, '2001-12-01', 'This dance reminds me of a caterpillar at the beginning and a butterfly at the end; thus the name.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14906, '2013-05-27 16:49:52.681478+00', '2017-12-29 07:28:05.400376+00', 'Ladies of Berkland Rose, The', 'LADIES OF BERKLAND ROSE', 3, 32, NULL, 2, 3, 17, 10790, NULL, 'For Anne Torkington, Jillian Kunher, and her daughter Charlotte Kunher, the ladies in my first-year pratice group.



Suggested music: 

A "light" 3x32 Strathspey, such as Old Fruitmarket or Miss Trotter', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2809, '1998-04-12 22:00:00+00', '2018-01-21 22:04:15.331435+00', 'Haste Ye Back', 'HASTE YE BACK', 1, 88, 9999, 4, 4, 3, 146, NULL, '', 59, '8080 8888  0808  0808  0808  8888  8080  8080  4040  0404  8888', 0, 1, 1, 0, 59);
INSERT INTO 'dance' VALUES (18698, '2018-10-02 22:08:14.793964+00', '2018-10-02 22:08:14.793964+00', 'Canfield Connection, The', 'CANFIELD CONNECTION', 3, 32, NULL, 1, 3, 42, 2766, '2015-05-01', 'This dance is written to honor Stephanie McDaniel and Greg Canfield on their wedding day August 23, 2015.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18743, '2018-10-04 18:05:16.363698+00', '2018-10-04 18:05:16.363698+00', 'Emily Grace', 'EMILY GRACE', 3, 32, NULL, 1, 3, 42, 2766, '2011-04-01', 'This dance was for Emily Grace, born January 31st to a couple who met Scottish country dancing.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18763, '2018-10-05 07:24:15.986011+00', '2018-10-05 07:24:15.986011+00', 'Follow Your Dream', 'FOLLOW YOUR DREAM', 2, 32, NULL, 1, 3, 42, 2766, '2013-05-01', 'The title of this dance comes from so many people following others in the various figures.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18768, '2018-10-05 08:30:55.778412+00', '2018-10-05 08:30:55.778412+00', 'Fur Pile, The', 'FUR PILE', 3, 32, NULL, 1, 3, 42, 2766, '2014-04-01', 'I found our 4 cats asleep on the bed in a pile of fur one day and had to look hard to figure which cat was where.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15585, '2014-08-26 21:33:39.741545+00', '2019-02-11 18:28:01.767666+00', 'Kiloran Bay', 'KILORAN BAY', 3, 32, NULL, 1, 4, 2, 640, NULL, '', 88, '4444/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15395, '2014-03-20 14:39:29.977827+00', '2014-07-27 20:52:11.287526+00', 'Those Russians', 'THOSE RUSSIANS', 2, 270, NULL, 1, 4, 3, 10933, NULL, 'The music: "Rasputin" on the CD "The Magic of Boney M" 



This is a complicated and difficult demonstration dance, that will never be on a social dance programme.  It makes no sense to write cribs, list all formations or calculate dance intensity; those dancing it will always use the original instructions only.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14520, '2012-07-22 13:18:50.555921+00', '2018-04-03 00:07:47.81402+00', 'Gateway to the World', 'GATEWAY TO THE WORLD', 1, 32, NULL, 1, 3, 42, 44, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15624, '2014-09-28 20:29:43.608235+00', '2014-09-28 20:53:12.42817+00', 'Reading St. Andrew''s 60th Anniversary', 'READING ST ANDREWS 60TH ANNIVERSARY', 3, 32, NULL, 1, 4, 11, 3647, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15628, '2014-09-28 20:45:00.303515+00', '2014-09-28 20:59:57.3481+00', '60 Years of Scottish Country Dancing', '60 YEARS OF SCOTTISH COUNTRY DANCING', 3, 32, NULL, 1, 4, 1, 3647, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15629, '2014-09-28 20:45:55.810318+00', '2014-09-28 20:45:55.810318+00', 'Helen and Murdo''s Wedding', 'HELEN AND MURDOS WEDDING', 1, 32, NULL, 1, 3, 42, 3647, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18595, '2018-09-15 19:28:00.470734+00', '2018-09-15 19:33:05.295917+00', 'Slow train to Sixty', 'SLOW TRAIN TO SIXTY', 2, 48, NULL, 1, 4, 1, 10799, NULL, 'Devised to mark the occasion of John Smith''s 60th Birthday



Story

1-8     Passengers on platform waiting for train

9-16   John getting up ''steam''

17-24 John making up his train

25-40 Train joumey

41-48 John being shunted into a siding!



Tune The Runaway Train', 70, '8888/8000/8000/8440/8448/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13225, '2007-01-11 23:00:00+00', '2019-02-04 10:04:39.20865+00', 'Werf Reel', 'WERF REEL', 1, 32, 9999, 1, 3, 42, 227, NULL, 'Named for the "De Werf" community centre where the Thistle Club of Eindhoven used to dance in the 1990s.', 47, '802  888  802  808', 0, 1, 1, 0, 62);
INSERT INTO 'dance' VALUES (15693, '2014-11-02 21:29:04.894155+00', '2014-11-02 21:29:23.286902+00', 'Mukilteo Helix', 'MUKILTEO HELIX', 3, 32, NULL, 1, 4, 2, 3593, NULL, 'A dance for the loyal and friendly dancers in Mukilteo, we have had many good times and laughed a lot, thank you all for making it fun.   It’s important.   Thank you too for helping to make these dances work.', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15719, '2015-01-07 14:38:41.953028+00', '2018-04-03 00:08:00.140519+00', 'Loch Leathan', 'LOCH LEATHAN', 3, 40, 9999, 1, 3, 42, 3549, '2004-09-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13645, '2011-01-15 23:00:00+00', '2019-04-03 20:31:24.59576+00', 'Tobias Hünger''s Welcome to Hude', 'TOBIAS HUNGERS WELCOME TO HUDE', 2, 32, NULL, 1, 4, 2, 228, '2011-01-07', '', 75, '8008/8888/8448/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (280, '1998-04-04 22:00:00+00', '2020-10-01 13:00:58.517679+00', 'Auchindoun Castle', 'AUCHINDOUN CASTLE', 1, 160, 9999, 4, 119, 3, 108, '1992-09-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15583, '2014-08-26 21:10:27.761633+00', '2021-07-30 08:22:59.358085+00', 'Hunter House Mill', 'HUNTER HOUSE MILL', 3, 32, NULL, 1, 100, NULL, 308, '2006-08-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15595, '2014-08-31 14:42:23.631644+00', '2020-10-10 20:59:11.82809+00', 'Away to the Hills', 'AWAY TO THE HILLS', 2, 32, NULL, 1, 4, 2, 9998, NULL, '', 81, '8008/8888/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20507, '2021-10-09 08:43:45.686557+00', '2021-10-09 08:43:45.686557+00', 'Arresting', 'ARRESTING', 2, 32, NULL, 1, 4, 15, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15626, '2014-09-28 20:41:05.762132+00', '2020-10-11 17:42:37.21651+00', 'Newbury''s 50th Anniversary', 'NEWBURYS 50TH ANNIVERSARY', 3, 32, NULL, 3, 5, 7, 3647, NULL, '', 85, '84844/88888/88888/84844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15627, '2014-09-28 20:42:34.994409+00', '2020-10-11 17:48:17.7453+00', 'Purley''s 30th Anniversary', 'PURLEYS 30TH ANNIVERSARY', 3, 32, NULL, 1, 4, 1, 3647, NULL, '', 81, '4664/8888/4888/0888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15690, '2014-11-02 21:15:51.699333+00', '2020-10-14 11:08:08.480936+00', 'Just in Time', 'JUST IN TIME', 2, 32, NULL, 1, 3, 42, 3593, '2002-02-01', 'The dance is for Ruth Jappy whose phrasing is excellent, she is always just in time, never late.  ', 53, '880/822/888/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15586, '2014-08-26 21:50:58.431544+00', '2020-12-30 21:36:18.740835+00', 'Light Hearted Una', 'LIGHT HEARTED UNA', 1, 32, 9999, 4, 5, 6, 3618, '2003-02-01', 'The video and Minicrib were the sources used for this entry', 50, '80808/08088/04048/42442', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14017, '2011-08-25 22:00:00+00', '2021-06-16 13:45:48.642139+00', 'Chris Ronald''s Strathspey', 'CHRIS RONALDS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 401, NULL, '', 47, '840/822/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15579, '2014-08-26 20:00:04.597726+00', '2021-07-30 08:17:09.963088+00', 'Dora Connolly''s Jig', 'DORA CONNOLLYS JIG', 2, 40, NULL, 1, 4, 2, 308, '2008-09-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15587, '2014-08-26 22:06:49.580215+00', '2021-10-03 15:24:28.295067+00', 'Oh Canada', 'OH CANADA', 1, 32, 9999, 4, 5, 35, 1727, '2014-07-01', 'Devised for dancing in Stanley Park on Canada Day, July 1st, 2014.



Final 8-bar progression as described by Sue Petyt and Jane Gammon in Fisherman''s Reel.', 50, '80808/08880/04840/44442', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14259, '2011-09-02 22:00:00+00', '2014-10-28 14:22:30.166874+00', 'Trip to Geldermalsen', 'TRIP TO GELDERMALSEN', 2, 32, NULL, 1, 3, 42, 10478, NULL, 'The author, Wil van den Berg, has withdrawn this dance; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13567, '2010-04-14 22:00:00+00', '2014-10-28 14:26:54.301368+00', 'Road to Girvan, The', 'ROAD TO GIRVAN', 3, 32, NULL, 2, 3, 17, 10383, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15678, '2014-10-19 22:27:48.187968+00', '2014-11-09 00:29:37.478004+00', 'Waterfall Welcome', 'WATERFALL WELCOME', 2, 32, NULL, 5, 1, 4, 2169, NULL, '', 100, '100/', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15717, '2015-01-07 14:23:50.830298+00', '2015-01-07 14:30:07.460624+00', 'Gremlin''s Carrousel, The', 'GREMLINS CARROUSEL', 3, 40, 9999, 3, 5, 7, 3549, '2000-03-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15758, '2015-01-10 14:10:37.616502+00', '2015-01-10 14:10:37.616502+00', 'Snowdrops', 'SNOWDROPS', 2, 32, 9999, 2, 3, 17, 993, NULL, 'for Children', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15761, '2015-01-10 14:39:05.576888+00', '2015-01-10 14:39:05.576888+00', 'Surge of the Sea', 'SURGE OF THE SEA', 3, 32, 9999, 5, 2, 30, 993, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15762, '2015-01-10 16:17:12.965384+00', '2015-03-15 21:53:23.584135+00', 'Thresher Round', 'THRESHER ROUND', 3, 32, 9999, 5, 56, 30, 210, NULL, 'Danced as strathspey or reel', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15679, '2014-10-28 11:28:06.379046+00', '2015-06-04 11:38:07.717202+00', 'Eddy West''s Compliments to Ruth and Grant Oldfield', 'EDDY WESTS COMPLIMENTS TO RUTH AND GRANT OLDFIELD', 2, 32, 9999, 1, 3, 42, 411, '2009-01-01', 'Suggested music:

Dance of Diamonds: London Highland Club Diamond Jubilee - Andrew Rankine', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14790, '2013-04-07 19:51:46.232311+00', '2015-07-16 20:40:09.611344+00', 'Rambling Rose, The', 'RAMBLING ROSE', 3, 32, NULL, 2, 3, 17, 3183, '2008-01-02', '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15630, '2014-09-28 20:46:57.279802+00', '2014-09-28 21:00:57.206626+00', 'Admire the Ladies', 'ADMIRE THE LADIES', 3, 32, NULL, 2, 3, 17, 3647, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18761, '2018-10-05 06:30:46.038802+00', '2018-10-05 06:30:46.038802+00', 'Follow the Leader', 'FOLLOW THE LEADER', 1, 32, NULL, 1, 3, 42, 2766, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14365, '2011-12-16 23:00:00+00', '2020-12-28 20:04:34.471251+00', 'Four Double Six Six Four Jig', 'FOUR DOUBLE SIX SIX FOUR JIG', 2, 64, NULL, 1, 4, 1, 10585, '2008-07-01', 'Devised by Heather McBurnie and Andrew Hodgson (andrew [at] hodgson.za.net), Cape Town, July 2008 in honour of Nelson Mandela on the occasion of his 90th birthday. First danced on Saturday 18th July 2009, the inaugural Mandela day. You can learn more about Mandela day by visiting http://mandeladay.com



Suitable CD recording: Peggy''s Wedding, Twelve Modern Scottish Country Dances from Book 22 by David Cunningham and his Scottish Dance Band.



Bars 25-40 of the text in Forty Years On have been revised since the dance was originally published on the Eight by Thirty Two website.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15573, '2014-08-20 12:25:29.199543+00', '2020-02-08 13:49:45.527224+00', 'Falling Leaves', 'FALLING LEAVES', 3, 32, 9999, 2, 3, 4, 10913, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15589, '2014-08-28 10:14:39.93552+00', '2021-03-11 01:00:00.929132+00', 'Montreal/Entrelac Tees', 'MONTREAL/ENTRELAC TEES', 3, 32, NULL, 2, 3, 17, 10568, '2013-04-01', 'Montreal/Entrelac Tees is the correct spelling; the spelling Montreal Entrelac Tees in the Table of Contents is a mistake.', 75, '880/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15685, '2014-10-30 07:10:32.05119+00', '2020-06-25 05:25:02.373332+00', 'Lagavulin', 'LAGAVULIN', 3, 32, NULL, 3, 5, 7, 10336, '2014-05-19', '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2664, '1997-04-03 22:00:00+00', '2020-08-05 11:38:20.811303+00', 'Green Lochan, The', 'GREEN LOCHAN', 7, 64, 5, 107, 51, 54, 1343, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (535, '1998-07-08 22:00:00+00', '2020-08-23 11:47:01.374348+00', 'Black Black Oil, The', 'BLACK BLACK OIL', 1, 32, 9999, 3, 5, 7, 108, '1971-01-01', 'Drewry lists the preferred tune as "Fitful Head" (Tom Georgeson). This tune is often attributed to Tom Anderson, which is incorrect.

', 70, '80800  88888  84884  82842', 1, 1, 0, 1, 70);
INSERT INTO 'dance' VALUES (15645, '2014-10-01 23:12:24.293791+00', '2020-08-24 18:59:16.486647+00', 'About Time', 'ABOUT TIME', 2, 32, 9999, 1, 3, 42, 518, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (645, '1997-08-28 22:00:00+00', '2020-08-29 12:39:11.064722+00', 'Bonnie Charlie''s Strathspey', 'BONNIE CHARLIES STRATHSPEY', 3, 96, 9999, 1, 4, 3, 706, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9936, '2001-06-05 22:00:00+00', '2020-09-09 13:09:42.142611+00', 'Moira''s Majority', 'MOIRAS MAJORITY', 1, 32, 9999, 1, 3, 42, 101, NULL, 'For Moira Fallas''s 21st birthday.', 55, '886/844/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10150, '2001-10-22 22:00:00+00', '2020-09-10 10:40:03.386683+00', 'Young at Heart', 'YOUNG AT HEART', 1, 32, 9999, 1, 3, 42, 1084, NULL, '', 53, '880/844/866/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13136, '2006-12-05 23:00:00+00', '2020-09-16 22:14:46.449834+00', 'Shinkansen', 'SHINKANSEN', 1, 32, 9999, 1, 3, 42, 104, NULL, '', 58, '808/864/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15339, '2014-02-15 21:14:40.935503+00', '2020-10-08 10:24:31.543119+00', 'Algarve Way, The', 'ALGARVE WAY', 2, 32, NULL, 1, 3, 42, 3717, NULL, '', 50, '800/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15610, '2014-09-03 15:30:27.264959+00', '2020-10-10 22:03:18.418052+00', 'Boatman, The', 'BOATMAN', 3, 32, NULL, 1, 100, 2, 135, NULL, 'Stub entry; source = Minicrib. Please inform the editors if you can supply further information, in particular an original description.', 69, '8008/0880/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15643, '2014-10-01 22:25:44.138435+00', '2020-10-12 16:25:48.745126+00', 'Athens of the North', 'ATHENS OF THE NORTH', 3, 32, 9999, 1, 3, 42, 11013, NULL, '', 63, '880/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15644, '2014-10-01 22:37:34.496313+00', '2020-10-12 16:36:36.107853+00', 'Trip to Edinburgh, A', 'TRIP TO EDINBURGH', 1, 32, 9999, 4, 4, 13, 11014, NULL, '', 62, '8080/0808/8080/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15647, '2014-10-01 23:24:33.436125+00', '2020-10-12 16:40:44.443485+00', 'Ravelston Rant, The', 'RAVELSTON RANT', 1, 32, 9999, 1, 2, 76, 10643, NULL, '', 60, '62/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15590, '2014-08-29 21:41:45.359298+00', '2022-04-10 16:32:02.024055+00', 'Medley for Maimie, A', 'MEDLEY FOR MAIMIE', 4, 240, 10032, 2, 3, 17, 1848, '2014-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15658, '2014-10-08 06:42:07.411105+00', '2022-08-15 14:24:52.353264+00', 'Lullaby for Prince George, A', 'LULLABY FOR PRINCE GEORGE', 3, 48, 9999, 1, 4, 1, 11023, '2013-07-22', 'Devised by Mary Hart, Hugh and Joyce Porteous, on behalf of the Sheffield Caledonian Society, for the Duke and Duchess of Cambridge on the birth of their first child, Prince George of Cambridge.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18745, '2018-10-04 18:10:43.027183+00', '2022-08-17 20:59:48.977028+00', 'End to End', 'END TO END', 1, 32, NULL, 1, 3, 42, 2766, '2010-03-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15574, '2014-08-23 10:50:18.543555+00', '2022-12-16 21:23:18.543004+00', 'Thistle Dubh', 'THISTLE DUBH', 1, 32, NULL, 8, 6, 67, 308, '2008-10-01', '', 79, '822822/888888/888888/844844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15236, '2013-11-12 18:55:24.468209+00', '2021-02-03 12:52:05.591402+00', 'Flight of the Teale, The', 'FLIGHT OF THE TEALE', 1, 32, NULL, 1, 3, 42, 518, NULL, 'Devised for David Teale, on his 60th birthday.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14384, '2011-12-17 23:00:00+00', '2017-11-11 19:42:06.732804+00', 'Ginger Sharks', 'GINGER SHARKS', 1, 32, NULL, 1, 3, 42, 1167, '2011-09-21', 'Suggested music: "Kiss Me Quick, My Mither''s Coming" - 7 Favourite Scottish Dances Vol. 4, George Stirrat''s Band or "Mrs Leslye Buchanan" - Dancing Fingers 2, Muriel Johnstone



Devised 21 September 2011 by Peter M Price (peter.price1672 [at] gmail.com) and dedicated to Rudi and Bugs, ginger cats who, at the opening of the front door, my sitting in the living room rocker, or the sound of a can being opened, come circling. When sitting in the rocker often only the tip of their tails are visible.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15605, '2014-09-03 15:00:36.371754+00', '2016-12-27 01:18:55.515057+00', 'Argo Pond Strathspey / Reel', 'ARGO POND STRATHSPEY / REEL', 3, 32, NULL, 1, 3, 42, 10934, NULL, 'Deviser''s note: This dance canbe danced as either a strathspey or a reel as preferred.



Dedicated to the Ann Arbor SCD Group', 62, '880/844/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18780, '2018-10-05 12:32:33.593857+00', '2018-10-05 12:32:33.593857+00', 'Gordion Knot, The', 'GORDION KNOT', 3, 32, NULL, 4, 4, NULL, 2766, '2012-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18782, '2018-10-05 13:08:45.146796+00', '2018-10-05 13:08:45.146796+00', 'Hanging From the Rafters', 'HANGING FROM THE RAFTERS', 2, 32, NULL, 1, 3, 42, 2766, '2011-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3441, '1998-01-05 23:00:00+00', '2019-04-15 23:57:13.533798+00', 'Kenora Reel, The', 'KENORA REEL', 1, 32, 9999, 1, 3, 42, 108, '1992-01-01', '', 62, '888/808/888/844', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (15601, '2014-09-03 13:39:38.450845+00', '2019-07-03 17:27:20.590376+00', 'All Round Will''s Mother''s', 'ALL ROUND WILLS MOTHERS', 1, 32, NULL, 1, 3, 42, 3597, '2001-04-01', 'The title comes from an expression used by a friend when someone takes a roundabout route to somewhere!



', 50, '800/880/888/808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15600, '2014-09-02 22:59:11.602+00', '2019-08-07 17:26:48.768837+00', 'Sunshine in Lagos', 'SUNSHINE IN LAGOS', 2, 32, NULL, 1, 3, 42, 729, '2014-01-01', '', 63, '888/888/484/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15623, '2014-09-15 20:59:51.500573+00', '2014-09-15 21:54:52.670788+00', 'Scotland United', 'SCOTLAND UNITED', 2, 32, NULL, 1, 4, 2, 550, '2014-09-11', 'Iain Brockbank: Again there''s the shape of the Saltire - it''s not just separatists who are Scottish - and this dance has top and bottom working together, dancing with the dancers on the sides.  A good traditional tune as well, keeping the links with our history. ', 75, '8008/8668/8668/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5386, '1997-04-03 22:00:00+00', '2014-09-16 20:55:35.396363+00', 'Ptarmigan Reel, The', 'PTARMIGAN REEL', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 56, '822/888/844/866', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15619, '2014-09-09 13:44:04.331476+00', '2018-04-02 23:56:34.458175+00', 'Farewell to Forty-Nine', 'FAREWELL TO FORTYNINE', 1, 32, NULL, 1, 3, 42, 11001, '2014-09-06', '“A dance for people on the more interesting side of fifty, devised by members of the Bonn and Cologne Scottish Country Dance groups to commemorate Martina Müller-Franz'' fiftieth birthday and her splendid dance party on September 6, 2014.”', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12335, '2005-04-27 22:00:00+00', '2014-09-17 21:13:12.257723+00', 'Nineteen Sixty-Four', 'NINETEEN SIXTYFOUR', 3, 32, 9999, 4, 4, 1, 1, NULL, 'With congratulations to Joan and Geoff Bradbury on their 40th wedding anniversary

', 81, '8080/8888/8888/8484', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15696, '2014-11-02 21:39:29.735376+00', '2014-11-02 21:41:48.849198+00', 'Portland 35', 'PORTLAND 35', 3, 32, NULL, 1, 4, 2, 3593, '2014-04-01', 'For the Portland Branch on the occasion of their 35th annual weekend workshop 



', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15680, '2014-10-28 11:29:24.131222+00', '2018-04-17 07:13:09.714178+00', 'Mr Pye''s Steak and Kidney Pie', 'MR PYES STEAK AND KIDNEY PIE', 2, 32, NULL, 1, 3, 42, 411, '2009-01-01', 'Terence, who sadly died in 2009, loved to treat his friends to a dinner party, often including a steak and kidney pie, and always with all home grown vegetables.', 63, '880/880/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9287, '2000-01-16 23:00:00+00', '2019-02-09 10:35:47.685675+00', 'Ballantine House', 'BALLANTINE HOUSE', 2, 32, 9999, 1, 3, 42, 501, '1990-01-01', 'Ballantine House was originally built for a Newark (New Jersey) beer master. It is now part of Newark Museum and is being restored.', 53, '800/866/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3536, '1997-09-07 22:00:00+00', '2014-09-28 12:24:11.570196+00', 'Kith and Kin', 'KITH AND KIN', 3, 32, 9999, 1, 4, 1, 179, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18598, '2018-09-15 20:04:22.999436+00', '2018-09-15 20:04:58.754573+00', 'There''s Life in the Old Girls Yet!', 'THERES LIFE IN THE OLD GIRLS YET', 1, 48, NULL, 3, 5, 7, 10799, NULL, 'The Dance Devised In honour Of The Septogenerians In The Kelso Ladies CIub', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15694, '2014-11-02 21:31:45.820762+00', '2014-11-02 21:31:45.820762+00', 'Newtonmore Lassie, The', 'NEWTONMORE LASSIE', 2, 32, NULL, 1, 3, 42, 3593, NULL, 'For Gladys Gilbert, a true highlander from Newtonmore, in the centre of the Grampians.  With thanks for all the willing help and friendship given to the Seattle Branch over many years.   Also thanks for being ‘my  tcheuchter pal’', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12528, '2005-08-29 22:00:00+00', '2019-02-28 22:11:27.336952+00', 'Trip to Coupar Angus, A', 'TRIP TO COUPAR ANGUS', 1, 96, 9999, 4, 4, 3, 3477, NULL, '', 75, '8888/8080/8080/8888/8080/0808/0808/8888/0808/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15592, '2014-08-30 23:23:44.322697+00', '2020-10-10 10:29:03.554604+00', '75 Years On', '75 YEARS ON', 2, 32, NULL, 1, 100, 2, 10996, NULL, '', 69, '8008/8888/8448/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15635, '2014-09-29 13:26:44.2953+00', '2020-08-09 21:37:21.925363+00', 'Dance for Ann, A', 'DANCE FOR ANN', 2, 40, NULL, 1, 3, 42, 3319, '2002-11-01', 'Original version Nov. 2002; modified 05 Nov. 2014  



In honour of Ann Prior, one of the founding teachers of the Bridport Scottish Dancers.', 55, '800/888/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15667, '2014-10-19 16:12:33.117546+00', '2020-10-13 09:00:24.653775+00', 'Sealed with a Kiss', 'SEALED WITH A KISS', 3, 32, NULL, 2, 3, 17, 10800, '2013-01-01', 'Presented to Mary-Beth Beirne and Scott McDonald, on the occasion of their marriage, by their friends from Scots on The Rocks.', 88, '888/888/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15593, '2014-08-31 00:17:09.060898+00', '2020-10-10 10:49:21.617285+00', 'Age of Aquarius', 'AGE OF AQUARIUS', 1, 32, NULL, 1, 3, 42, 10997, NULL, 'Devised by Sandra Carroll and “Dedicated to Barbara Monahan whose birthday falls under Aquarius and who executes two hand turns in pas de basque with great ease much to the frustration of others”.





', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15596, '2014-08-31 14:51:41.84337+00', '2020-10-10 21:16:36.377322+00', 'Betty Thompson of Newtonbrook', 'BETTY THOMPSON OF NEWTONBROOK', 2, 32, NULL, 1, 4, 1, 11985, NULL, 'Devised for Betty Thompson founder of the Newtonbrook group in Toronto. See also <<http://www.dancescottish.ca/archives-set&link_files/2007-November-Set%26Link.pdf#page=2>> and <<http://www.dancescottish.ca/archives-set&link_files/2009-Nov-Set%26Link.pdf#page=4>>.

', 75, '8008/8044/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15636, '2014-09-29 13:34:01.171114+00', '2020-10-12 11:35:13.046339+00', 'Patricia''s Make-up', 'PATRICIAS MAKEUP', 4, 64, 5, 2, 3, 17, 11008, '2003-02-01', '', 67, '888/800/844/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20110, '2020-10-04 14:17:33.459999+00', '2020-10-04 14:17:33.459999+00', 'Dancing Feet', 'DANCING FEET', 1, 88, NULL, 107, 115, 3, 952, '2008-08-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5422, '1998-04-19 22:00:00+00', '2022-08-13 17:16:04.531567+00', 'Queen Victoria''s Visit Quadrilles', 'QUEEN VICTORIAS VISIT QUADRILLES', 10, 184, 9999, 4, 4, 3, 9998, NULL, 'This dance is sometimes billed as a 200-bar dance. This confusion arises from the question of whether in Figures 1 and 2, bars 1-8 (»honouring« partners and corners) are part of the »repetition« done with 2nd and 4th couples leading, which would lead to an extra 16 bars altogether. The most recent versions of this dance description make it clear that the »honouring« is *not* part of the repetition, hence 184 bars.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1609, '2002-07-21 22:00:00+00', '2021-06-15 11:42:54.85332+00', 'Carola''s Reel', 'CAROLAS REEL', 1, 32, 9999, 1, 2, 76, 558, '1993-01-01', 'For Carola Tress, Kuckucksnest 1993.', 61, '84/88/88/84', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14672, '2013-01-21 23:53:18.637203+00', '2015-04-03 18:41:16.426005+00', 'RossKay Strathspey, The', 'ROSSKAY STRATHSPEY', 3, 32, NULL, 2, 3, 17, 3593, '2009-02-01', 'For Ross and Kay Morrison to recognize all the willing help given, over many years, by this generous couple to the Seattle Branch of RSCDS.  We presented this along with the tune on their 50th Wedding Anniversay.', 71, '484  484  444  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (9292, '2000-01-16 23:00:00+00', '2018-04-03 00:07:56.379002+00', 'Jolly John', 'JOLLY JOHN', 3, 32, 9999, 1, 3, 42, 501, '1990-01-01', 'According to the book, the dance was devised 1982-1990. Thus, the final date was chosen.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15991, '2015-02-06 15:14:14.428099+00', '2018-04-02 23:56:37.171953+00', 'Redhead Hall', 'REDHEAD HALL', 2, 32, 9999, 1, 3, 42, 703, '2010-11-01', 'Devised for "The Goddesses" of Greensboro, North Carolina in November. 2010. A fun and feisty dance is in order for them! The hall where the annual Greensboro St. Andrews Dance is "Redhead Hall. "', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6052, '2002-04-03 22:00:00+00', '2019-03-10 16:06:57.097875+00', 'Ship O'' Grace', 'SHIP O GRACE', 3, 40, 9999, 1, 4, 1, 248, '1955-01-01', 'Symbolic meaning (from the original description)



1 - 8 	The lifeboat is launched.

9 - 16	Rescue equipment ..

17 - 24	The wheel.

25 - 30	Over the waves to the boat in distress.

31 - 32	The knot between the two boats is tied.

33 - 40	Back to safety towing the rescued boat.

', 57, '8000  8888  8888  8224  8008', 1, 1, 1, 1, 57);
INSERT INTO 'dance' VALUES (15720, '2015-01-07 14:46:39.912845+00', '2015-01-07 14:48:44.906701+00', 'Mountain House', 'MOUNTAIN HOUSE', 3, 32, 9999, 2, 3, 17, 3549, '2004-06-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15618, '2014-09-05 07:03:21.817089+00', '2015-05-06 12:22:28.616632+00', 'Ceilidh Reel, The', 'CEILIDH REEL', 1, 32, NULL, 2, 3, 17, 11129, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15613, '2014-09-03 22:28:00.133177+00', '2016-02-04 14:49:29.768073+00', 'Burdens of Bude, The', 'BURDENS OF BUDE', 1, 32, NULL, 1, 4, 11, 2634, '2002-11-01', 'Devised for Dawn and Les Burden who plan, run, provide music, and even cater for, the Bude Weekend School. The dance has 2 dancing couples in recognition of the fact that there must surely be 2 of each of them or else how do they manage it ?!

With acknowledgement to Bob Grant for the hands across chain figure from his dance ''Whisky & Mac''.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15606, '2014-09-03 15:06:40.05954+00', '2016-10-19 22:44:34.958184+00', 'Autumn Breeze', 'AUTUMN BREEZE', 2, 32, NULL, 1, 3, 42, 3694, NULL, '', 56, '888/800/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13806, '2011-08-04 22:00:00+00', '2017-11-15 03:33:16.284753+00', 'Blethering Ghillie, The', 'BLETHERING GHILLIE', 3, 32, NULL, 1, 3, 42, 1113, '2008-01-01', 'Devised: 2008

The Blethering Ghillie is the deviser’s pub, located in the basement of his home in Beavercreek, Ohio, USA. Much blethering has transpired there over the years, especially at afters parties following dance events.', 44, '880/880/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15607, '2014-09-03 15:09:47.664745+00', '2020-10-10 21:54:41.942542+00', 'Balgowan House', 'BALGOWAN HOUSE', 3, 32, NULL, 1, 4, 15, 10995, NULL, 'Balgowan House is a very elegant Edwardian Guest House in Dundee. The very size of the spaces and the décor makes one want to swirl and twirl. So that’s what this dance needs... bold dancing and style! That’s what this dance attempts to portray', 69, '4444/4444/4884/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15612, '2014-09-03 22:24:09.733746+00', '2020-10-11 16:51:41.659366+00', 'Bunty Wilson''s Strathspey', 'BUNTY WILSONS STRATHSPEY', 3, 32, NULL, 1, 100, 2, 9998, NULL, 'Strathspeys do not all come from Strathspey! They should be slowly and gracefully

(according to Jeanie Milligan, “as if at the Court of France”!)', 75, '2882/6446/4884/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15615, '2014-09-03 22:36:16.156502+00', '2020-10-11 17:22:06.069131+00', 'Cairn of the Claise', 'CAIRN OF THE CLAISE', 3, 32, NULL, 1, 4, 1, 11986, NULL, 'Stub entry; source = Minicrib. Please inform the editors if you can supply further information, in particular an original description and the full name of the author (we could have made an error).

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15616, '2014-09-05 06:54:04.453872+00', '2021-02-12 17:14:34.527151+00', 'Calgary 88', 'CALGARY 88', 1, 32, NULL, 1, 4, 1, 591, NULL, 'Stub entry; source = Minicrib. Please inform the editors if you can supply further information, in particular an original description (the full name of the author was kindly supplied by Susan Eisley in <<https://my.strathspey.org/dd/issue/2225/|issue 2225>>).



', 52, '8080/8888/8000/8002', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15617, '2014-09-05 06:58:55.838532+00', '2020-10-11 17:36:25.212953+00', 'Cardross Jig', 'CARDROSS JIG', 2, 32, NULL, 5, 2, 76, 11987, NULL, 'Stub entry; source = Minicrib. Please inform the editors if you can supply further information, in particular an original description.', 100, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15641, '2014-10-01 22:18:43.387571+00', '2020-10-12 16:20:44.008245+00', 'Golden Eagle, The', 'GOLDEN EAGLE', 3, 32, 9999, 1, 3, 42, 11012, NULL, '', 56, '844/844/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15648, '2014-10-01 23:27:02.125249+00', '2020-10-12 16:52:29.386918+00', 'Royal Edinburgh', 'ROYAL EDINBURGH', 2, 32, 9999, 1, 3, 42, 11015, NULL, '', 66, '888/888/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15604, '2014-09-03 14:57:29.253641+00', '2021-01-10 12:55:52.077352+00', 'Arbroath Abbey', 'ARBROATH ABBEY', 1, 40, NULL, 4, 4, 13, 11268, NULL, '4th of the 7 New Dances for Beginners', 60, '8080/0808/8080/0808/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10367, '2002-07-21 22:00:00+00', '2021-03-27 18:45:19.275689+00', 'Earl and Countess of Wessex, The', 'EARL AND COUNTESS OF WESSEX', 1, 40, 9999, 1, 3, 42, 2992, '1999-01-01', 'This dance was devised by Joan and Hugh Ferguson to mark the occasion of the wedding of the Prince Edward to Miss Sophie Rhys-Jones in Windsor Castle on 19th of June 1999. The different parts of the dance are meant to represent the stages of meeting, flirtation, aspects of living separate busy lives but returning to be together, and at the end the ring symbolising the marriage union.   



', 50, '800  800  844  888  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (15687, '2014-11-02 21:02:10.208811+00', '2014-11-02 21:02:10.208811+00', 'Blue Mountain Rubies', 'BLUE MOUNTAIN RUBIES', 1, 32, NULL, 1, 3, 42, 3593, '1993-06-22', 'For the 40th wedding anniversary of my good friends Barbara and Frank Phipps, Georgetown, Ontario, 22nd June 1993', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15688, '2014-11-02 21:07:18.096285+00', '2014-11-02 21:07:18.096285+00', 'Campbells of Oakville, The', 'CAMPBELLS OF OAKVILLE', 3, 32, NULL, 2, 3, 17, 3593, '1995-11-01', 'This is my tribute to Bob and Dorothy Campbell, for being supportive and never making a new teacher feel inadequate no matter how often her tongue got tied in knots, not to mention the dancers.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1, '1998-07-08 22:00:00+00', '2018-04-03 00:07:29.167635+00', '100 Queen Street North', '100 QUEEN STREET NORTH', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15847, '2015-01-18 16:05:39.489672+00', '2020-12-30 10:52:20.361515+00', 'Tuesday Tryst, The', 'TUESDAY TRYST', 3, 32, 9999, 2, 3, 17, 1582, '2010-03-01', '', 69, '888/448/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13984, '2011-08-24 22:00:00+00', '2022-09-19 06:40:04.712699+00', 'Raptors'' Rapture', 'RAPTORS RAPTURE', 1, 32, NULL, 1, 3, 42, 2701, '2007-04-29', 'Note:  This dance was devised for Peter Radcliff to celebrate his 75th birthday, April 29, 2007. Dotty Ueber, Peter''s friend and companion, requested a dance to also celebrate Peter''s love of birdwatching. The fIrst half of the dance suggests the courtship displays of certain raptors, hence the name. Bars 1-8 are from The Breakdown by John Mitchell.-TW', 56, '800/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1145, '2001-06-05 22:00:00+00', '2023-02-17 18:32:46.800613+00', 'Chairman, The', 'CHAIRMAN', 1, 32, 9999, 1, 3, 42, 101, '1995-01-01', 'In fond memory of Donnie Muirhead.', 56, '800  888  888  844', 1, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (15614, '2014-09-03 22:33:27.087493+00', '2023-01-30 00:04:46.082215+00', 'Burns - 250 Years', 'BURNS  250 YEARS', 2, 32, NULL, 1, 3, 42, 3589, '2009-01-01', 'Dance devised by Marion Young in January 2009 to celebrate the 250th anniversary of the birth of Robert Burns', 50, '800/866/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15625, '2014-09-28 20:39:04.949322+00', '2014-09-28 20:56:32.538852+00', 'Glenmore', 'GLENMORE', 7, 96, 42, 105, 55, 30, 11004, NULL, 'A Simple Highland Demonstration Dance for 3 Men and 2 Ladies

The Dancers stand in a line all facing the front numbered from the left

1st Man, 1st Lady, 2nd Man, 2nd Lady and 3rd Man.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15972, '2015-02-05 12:57:03.414713+00', '2018-04-02 23:56:37.931924+00', 'Swinging Sixty', 'SWINGING SIXTY', 2, 32, 9999, 1, 3, 42, 11065, NULL, 'Devised in 2011 by Angelika Schmidkonz for Jane Ross, a member of the Munich Scottish Association, for her special birthday. The first eight bars symbolize a six, the last eight bars a zero which gives –just like the title– a little hint as to which birthday it was ;-) Jane is a very enthusiastic and joyful dancer and we hope that she will keep on dancing for a long time!', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8930, '1999-10-14 22:00:00+00', '2014-11-11 00:40:52.561021+00', 'Edmonton Snowball', 'EDMONTON SNOWBALL', 2, 32, 9999, 1, 4, 1, 10976, '1986-02-01', 'May be danced as a Reel (Author''s statement)



Warning: some cribs distributed before 2014 had errors.', 61, '4444/4444/8620/8886', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14350, '2011-12-13 23:00:00+00', '2017-11-13 10:28:50.629822+00', 'Spice it Up', 'SPICE IT UP', 2, 32, NULL, 2, 3, 18, 10579, NULL, 'This dance has an unusual progression. This dance can be danced unmodified in a 4C longwise set.  In a 4C set, the lead couples are successively 1c, 3c, 2c, 4c.  ', 56, '800/888/448/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18600, '2018-09-15 20:12:43.21322+00', '2018-09-15 20:12:43.21322+00', 'Three Score', 'THREE SCORE', 3, 32, NULL, 4, 4, 1, 10799, '2005-01-01', 'Dance devised for the occasion of Ruth’s 60th birthday, January 2005', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18601, '2018-09-15 20:14:58.2235+00', '2018-09-15 20:14:58.2235+00', 'Sheena''s Secret', 'SHEENAS SECRET', 3, 32, NULL, 6, 3, NULL, 10799, NULL, 'For Sheena''s 70th Birthday', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15681, '2014-10-28 11:31:00.935191+00', '2019-08-19 08:19:50.313132+00', 'One Good Turn Deserves Another', 'ONE GOOD TURN DESERVES ANOTHER', 3, 32, NULL, 2, 3, 17, 411, '1999-01-01', '', 71, '880/888/822/808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18602, '2018-09-15 20:17:19.828439+00', '2019-06-24 14:09:44.310256+00', 'Lorraine''s 40th', 'LORRAINES 40TH', 1, 48, NULL, 1, 4, 1, 10799, NULL, '', 67, '8000/8088/8888/8000/8088/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15282, '2013-12-07 21:22:29.643548+00', '2014-10-17 22:41:58.276014+00', 'Penny Whistle Hornpipe, The', 'PENNY WHISTLE HORNPIPE', 1, 32, NULL, 1, 3, 42, 1760, '2006-09-01', 'Bars  9 -16 are also known as ‘Push Me Pull You Reels’, and were devised by Terry Glasspool.



Devised for Ron Wallace. A great teacher, dancer, piper, player of the whistle and friend. Late for his 50th birthday, (September 2004),  with lots of love.', 56, '880/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15746, '2015-01-10 11:15:02.873526+00', '2015-01-10 11:15:02.873526+00', 'Taste of Scotch, A', 'TASTE OF SCOTCH', 1, 32, 9999, 2, 3, 17, 993, '2006-01-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15638, '2014-09-29 13:45:39.714953+00', '2020-02-12 16:34:52.667403+00', 'Sarah''s Wedding Strathspey', 'SARAHS WEDDING STRATHSPEY', 3, 40, NULL, 2, 3, 18, 11010, '2004-06-01', 'Note: Each figure spells out one letter of SARAH.



Devised by Martine Guilbert and other members of Scots Bonnets from St Quay-Perros, Brittany, France, to celebrate the marriage of Sarah Prone and John Ashby of Bridport Scottish Dancers on 3rd June 2004. ', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15652, '2014-10-04 00:24:39.198324+00', '2020-02-12 16:37:10.105593+00', 'Bramley House Strathspey', 'BRAMLEY HOUSE STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11007, NULL, 'Devised by John Ashby to mark the move by Bill and Kathleen Allan to their new home in Bramley House, Bridport - The dance incorporates ''Macdonald of the Isles'' reels which Bill enjoyed as he could gaze into his

partner''s eyes - and a nice slow turn at the end for Kathleen.



Tune:  Wells House', 56, '880/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15653, '2014-10-04 00:34:03.645629+00', '2020-02-12 16:38:24.848513+00', 'Playing the Field', 'PLAYING THE FIELD', 2, 96, NULL, 4, 4, 3, 10735, '2008-01-01', 'Three parts of 32 bars.



Devised by Sue Tyler in 2008 at the request of Bridport Scottish Dancers in memory of Bill Allan, who enjoyed the company of the lady dancers, but always returned home to his wife, Kathleen.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15611, '2014-09-03 15:32:37.547195+00', '2020-10-11 16:45:41.831837+00', 'Bracknell''s 50th Anniversary', 'BRACKNELLS 50TH ANNIVERSARY', 1, 32, NULL, 1, 3, 42, 3647, NULL, 'Original accessible at http://www.bracknellreelclub.org.uk/douglas/rodneycelebration.html', 56, '800/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15695, '2014-11-02 21:34:19.651984+00', '2020-10-14 11:11:45.185474+00', 'Olympic Treasure', 'OLYMPIC TREASURE', 3, 48, NULL, 4, 4, 1, 3593, '2004-04-01', '', 83, '8888/8888/8888/8080/0808/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5628, '1997-04-03 22:00:00+00', '2020-12-17 22:12:02.55854+00', 'Robert Fitchet', 'ROBERT FITCHET', 1, 32, 9999, 1, 3, 42, 129, NULL, 'Publication is © 1954, James S. Kerr, Music Publishers, Berkeley Street, Glasgow', 56, '822  888  888  822', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (18599, '2018-09-15 20:07:58.933592+00', '2021-01-04 15:33:30.900879+00', 'Lyn''s Legacy', 'LYNS LEGACY', 3, 40, NULL, 1, 3, 42, 10799, NULL, 'FOR LYN BRYCE TO CELEBRATE HER 60th BIRTHDAY NOVEMBER 2001', 55, '880/880/888/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6689, '1997-04-03 22:00:00+00', '2021-02-07 10:07:46.20905+00', 'Treasurer, The', 'TREASURER', 2, 32, 9999, 1, 3, 42, 346, '1990-01-01', 'Devised in 1990 by Miss A N (Nana) Shearer, in honour of Mrs. Rachael Prentice, retiring treasurer of 25 years, of Stirlingshire Branch of the RSCDS.', 44, '800/844/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13884, '2011-08-22 22:00:00+00', '2014-10-19 14:14:33.31984+00', 'On Bended Knee', 'ON BENDED KNEE', 2, 32, NULL, 1, 3, 42, 44, '2006-01-03', 'Presented to Miriam Dose and Duncan Laidlaw to celebrate their engagement. Duncan went down ‘on bended knee’ and proposed to Miriam on Sunday 1st January 2006 after the completion of the midnight ceremonies at the 2005-2006 New Zealand Branch Summer School in Auckland.



Devised over Monday and Tuesday the 2nd and 3rd January 2006. 	Not having my dances with me, I was having trouble devising a suitable dance until Noeline O’Connor suggested including ‘M’s for Miriam - bars 5-6 and bars 13-14.







', 42, '551/551/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15659, '2014-10-11 20:34:02.155986+00', '2022-04-12 11:46:14.954583+00', 'Dancer''s Dream, A', 'DANCERS DREAM', 3, 32, NULL, 2, 3, 17, 2874, NULL, '“For Christiane Trefz and Ralf Bolte on the occasion of the marriage on July 26, 2014. On their engagement, Christiane said that it was a dream to have found a partner who dances, hence the name of the dance!” (Avril Quarrie)', 75, '800/888/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10298, '2002-01-08 23:00:00+00', '2017-06-15 22:35:06.326374+00', 'Jim''s Haberdashery', 'JIMS HABERDASHERY', 2, 40, 9999, 1, 3, 42, 246, '1990-01-01', 'The original version for [33-40] was:

33-36 1W and 2W turn right hand while 1M and 2M turn left hand

37-40 1s dance down between the third couple and turn them, ladies left

hand, and men right hand.



The author wrote on "Strathspey": This finish seemed to cause difficulty for many dancers who appeared unable to phrase it correctly and I reluctantly changed it to a more conventional finish:

33-36   1st couple, with nearer hands joined, dance to the top, and cast off.   37-40. All turn partner RH



The dance was written for the retiral of Jimmy Taylor as RSCDS Stirling Branch Chairman in 1990 after 25 years of service to the branch. The title ''Jim’s Haberdashery'' was the name affectionately given to the Society’s shop, originally ''Strathspey Sales,'' which, as finance convener, Jimmy instigated.', 57, '880/840/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16117, '2015-02-25 14:35:17.417111+00', '2018-04-03 00:07:29.481022+00', 'Abbotsleigh', 'ABBOTSLEIGH', 2, 40, 9999, 1, 3, 42, 10995, '2013-01-01', '10-bar jig (in 10-bar phrases)



Suggested recorded music: The Wee Cooper of Fife played by Deirdre Adamson



The aim was to create a dance which gave the lead pair lots of opportunity for covering and synchronisation, culminating in the final birl at the end of “Hello-Goodbye” setting. This last figure needs 10 bar music, and, luckily, Diedre Adams music uses a number of different tunes!



J Johnston’s dances in Minicrib provided the seed crystals from which this dance was developed, and my delight in them, the inspiration.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15721, '2015-01-07 14:55:19.360303+00', '2015-01-07 14:55:19.360303+00', 'North Gate', 'NORTH GATE', 3, 40, 9999, 1, 4, 1, 3549, '2004-06-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12412, '2005-05-01 22:00:00+00', '2015-01-31 00:37:19.167586+00', 'Wood Duck, The', 'WOOD DUCK', 5, 32, 9999, 5, 2, NULL, 2426, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15701, '2014-11-14 21:10:55.485477+00', '2015-04-10 21:47:38.171688+00', 'Charles Cyril Hendrickson', 'CHARLES CYRIL HENDRICKSON', 3, 32, NULL, 1, 100, 2, 1167, '2005-02-09', 'unpublished', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (28, '1997-08-28 22:00:00+00', '2018-04-03 00:07:29.556536+00', 'Across The 45th Parallel', 'ACROSS THE 45TH PARALLEL', 2, 32, 9999, 1, 3, 42, 604, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15682, '2014-10-28 11:35:42.17302+00', '2016-02-15 08:10:31.383438+00', 'Waipu Dominie, The', 'WAIPU DOMINIE', 2, 32, NULL, 1, 4, NULL, 411, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10031, '2001-09-02 22:00:00+00', '2018-04-03 00:07:39.197963+00', 'Come Ashore', 'COME ASHORE', 1, 32, 9999, 1, 3, 42, 9, NULL, 'Devised: March 1996', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (57, '1998-01-05 23:00:00+00', '2018-04-03 00:07:29.774234+00', 'Airlie House', 'AIRLIE HOUSE', 1, 32, 9999, 1, 3, 42, 51, NULL, 'This dance was devised while returning home from several crisp fall days at Airlie House, a conference center in lovely rural country near Warrenton, Virginia. The dance was presented to Susanna MacInnis of Allentown, Pennsylvania, on the occasion of her 60th birthday.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18783, '2018-10-05 13:14:34.573751+00', '2018-10-05 13:14:34.573751+00', 'Happy Harrison', 'HAPPY HARRISON', 2, 32, NULL, 1, 3, 42, 2766, '2008-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15702, '2014-11-18 15:41:50.831661+00', '2019-08-12 15:51:29.482481+00', 'Mrs Ellen McRanor (of Parrish)', 'MRS ELLEN MACRANOR OF PARRISH', 1, 32, NULL, 1, 3, 42, 1167, '2004-07-25', 'unpublished', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12128, '2005-04-10 22:00:00+00', '2018-04-03 00:07:29.974715+00', 'Alexander Gordon Esslemont Strathspey', 'ALEXANDER GORDON ESSLEMONT STRATHSPEY', 3, 32, 9999, 1, 3, 42, 135, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18199, '2017-12-27 19:54:52.321954+00', '2020-09-29 03:19:11.832866+00', 'After the Ball is Over', 'AFTER THE BALL IS OVER', 3, 32, NULL, 1, 3, 42, 44, '2000-10-13', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15666, '2014-10-19 16:01:25.550493+00', '2020-10-13 08:55:14.829265+00', 'Calanais Stones, The', 'CALANAIS STONES', 1, 32, NULL, 1, 4, 11, 10800, '2013-01-01', 'Devised following a visit to the stones in 2013. The Callanais (or Callanish) Stones are on the Isle of Lewis in the Outer Hebrides and are estimated to have been erected 4,000 to 5,000 years ago', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15699, '2014-11-12 14:04:16.800273+00', '2020-10-14 11:19:18.882401+00', 'How Does It Start?', 'HOW DOES IT START', 2, 64, NULL, 1, 4, 1, 2627, '2009-05-01', 'Written especially for Donald McKay, who wondered how long it would be before a dance appeared with this title!', 55, '8400/8880/8040/8880/8000/8088/8004/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15700, '2014-11-12 17:23:04.415864+00', '2020-10-14 11:25:36.759227+00', 'One in the Millennium', 'ONE IN THE MILLENNIUM', 3, 48, NULL, 2, 3, 17, 3444, NULL, 'Source: Dancers’ Choice 2 CD Insert', 72, '800/888/800/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12905, '2006-10-12 22:00:00+00', '2021-01-05 21:14:08.275381+00', 'Tribute to Talent, A', 'TRIBUTE TO TALENT', 2, 96, 9999, 4, 4, 3, 146, NULL, '', 66, '8080  4444  0808  4444  8484  8484  4848  4848  4444  4444  7777  8888', 0, 1, 0, 0, 65);
INSERT INTO 'dance' VALUES (68, '1998-01-11 23:00:00+00', '2021-04-18 10:06:55.405146+00', 'Alder Burn, The', 'ALDER BURN', 2, 32, 9999, 1, 3, 42, 108, '1978-01-01', 'Devised in 1978 for Simon Fraser of Courage Farm, Nairn 



The nearest village to Courage Farm is Auldearn. The name "Auldearn" is said by some authorities to mean the "Burn of the Alder Tree" - Hence the name of this dance. The name "Nairn" means "The Alder Tree". W.J.Watson in his book "The History of the Celtic Place Names of Scotland" says that "Auldearn" derives from the Gaelic "Alit Eireann" and means "Ireland''s Burn", ', 56, '16,12,12/844/844', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (15730, '2015-01-08 15:26:50.576536+00', '2021-03-14 18:36:59.377181+00', 'Shinkansen, The', 'SHINKANSEN', 1, 32, 9999, 1, 3, 42, 2474, '1991-10-21', '', 56, '800/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13631, '2010-11-10 23:00:00+00', '2018-04-03 00:07:30.535357+00', 'Andy''s Wedding Day', 'ANDYS WEDDING DAY', 4, 32, 8, 1, 3, 42, 10289, '2002-07-06', 'A Note from "The Vienna Book":  

This dance was devised to honour the occasion of the wedding of Andy and Gerlinde on 6 July 2002. It is customary in Austria to “abduct” the bride (usually to a nearby pub); the groom and his best man have to find her and get her back (by paying the bill).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (413, '2003-01-30 23:00:00+00', '2014-10-27 20:57:09.576423+00', 'Barmkin, The', 'BARMKIN', 1, 88, 9999, 4, 4, 3, 146, NULL, '<<imgt:smailholm.jpg|Smailholm Tower|200x200:right>>

A »barmkin« is a part of a castle or fortified manor, commonly behind

an outer wall, used, e.g., to protect cattle from reivers. The

photograph shows Smailholm Tower near Kelso in the Borders; the

barmkin''s wall can be seen in the foreground.



The online *Dictionary of the Scots Language* places the earliest

known appearance of the word »barmkin« in 1460; it is apparently

derived from »barbican«.

', 59, '8080  8080  0808  0808    8080  8080  0808  0808    6666  6666  8888', 1, 1, 1, 1, 59);
INSERT INTO 'dance' VALUES (15716, '2015-01-07 14:11:26.901511+00', '2015-01-07 14:11:52.812382+00', 'Eagle Peak', 'EAGLE PEAK', 3, 32, 9999, 1, 2, NULL, 3549, '2005-07-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5179, '1998-04-19 22:00:00+00', '2016-11-15 11:01:04.022787+00', 'Path Of Life, The', 'PATH OF LIFE', 2, 32, 9999, 1, 3, 42, 227, '1990-09-01', 'Advanced level.



It is clear that my Path of Life was very much influenced by the Duke of Perth and Mr John Drewry.  Many thanks to both gentlemen.



Music:  To be composed to suit everybody''s path of life.', 47, '800  822  844  888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (15677, '2014-10-19 19:59:56.622491+00', '2017-04-01 19:21:14.621963+00', 'Katoomba Mist', 'KATOOMBA MIST', 1, 32, NULL, 1, 3, 42, 74, '2013-03-01', 'First danced at the Sydney Branch Katoomba weekend March, 2013.  At the time, the dance was unwritten and un-named. In the Blue Mountains at Katoomba that weekend, it was very damp and misty, so the name represents the environment at that time. ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15835, '2015-01-18 14:13:03.484678+00', '2020-12-30 21:29:38.438859+00', 'North to Gothenburg', 'NORTH TO GOTHENBURG', 2, 32, 9999, 1, 3, 42, 1582, '2010-09-01', '', 47, '800/804/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17516, '2017-01-04 17:51:05.633301+00', '2018-08-19 17:49:28.518171+00', 'Girl in Every Port, A', 'GIRL IN EVERY PORT', 2, 40, NULL, 4, 4, 4, 11110, '2005-05-15', '"I was asked to write a dance with a nautical theme. As Portsmouth is a naval base with sailors visiting from all over the world, the title for the dance just came into my mind.  

The sailors eye the girls up, they chase and catch the one they fancy, then move on to the next port where they meet someone new." (Kathy Lawson)  ', 80, '8888/8080/8080/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10824, '2002-10-22 22:00:00+00', '2018-11-28 15:50:31.653201+00', 'Fear an Taigh', 'FEAR AN TAIGH', 3, 32, 9999, 1, 4, 2, 671, '2002-01-01', 'Dedicated to the memory of Iain Stuart Robertson who, among his many talents, was for many years the spendid fear an taigh - or master of ceremonies - at the first-fortnight ceilidhs at St. Andrews. ', 69, '8448  8448  8008  8448', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (19008, '2018-10-17 13:06:39.920814+00', '2018-10-17 13:06:39.920814+00', 'Val''s Circle', 'VALS CIRCLE', 3, 32, NULL, 1, 100, 2, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (215, '1997-04-03 22:00:00+00', '2018-04-03 00:07:31.103448+00', 'Argyll Assembly, The', 'ARGYLL ASSEMBLY', 1, 32, 9999, 1, 3, 42, 146, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15748, '2015-01-10 12:21:18.990533+00', '2015-01-10 12:25:59.656572+00', 'Beattie Place', 'BEATTIE PLACE', 3, 32, 9999, 2, 3, 17, 993, '2007-12-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15749, '2015-01-10 12:59:01.406904+00', '2015-01-10 12:59:01.406904+00', 'Clarinda', 'CLARINDA', 3, 40, 9999, 1, 4, 1, 993, '2008-01-19', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15675, '2014-10-19 19:50:44.367949+00', '2020-07-12 15:54:02.366782+00', 'Sùilean', 'SUILEAN', 3, 32, NULL, 2, 3, 17, 11030, '2013-01-01', 'Sùilean (pronounced Soo Lurn) is the Scottish Gaelic word for Eyes. Eye contact with your partner and the other dancers is important for maintaining the phrasing and the essence of the dance.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13440, '2009-11-16 23:00:00+00', '2021-01-02 13:37:49.676548+00', 'Belles of St Mary''s, The', 'BELLES OF ST MARYS', 3, 32, 9999, 1, 3, 42, 10394, NULL, 'Published in the Diamond Jubilee Collection of the RSCDS Inverness and District Branch: http://my.strathspey.org/dd/publ/1027/', 52, '880/860/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (578, '1998-09-30 22:00:00+00', '2021-07-01 22:53:15.383426+00', 'Blithest Lass that ever was seen, The', 'BLITHEST LASS THAT EVER WAS SEEN', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 44, '800  888  844  800', 1, 1, 0, 1, 58);
INSERT INTO 'dance' VALUES (3067, '1997-04-03 22:00:00+00', '2021-04-08 11:29:05.884202+00', 'Illawarra Strathspey, The', 'ILLAWARRA STRATHSPEY', 3, 32, 9999, 2, 3, 17, 191, NULL, 'This dance was devised by grateful Scottish Country Dancers and dedicated to William Crawford Scott on 1st December, 1985 to celebrate 35 years of Scottish Country Dancing in the Illawarra and symbolises the three Dance Groups then active in the area.', 63, '800/888/800/848', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2223, '1997-09-29 22:00:00+00', '2021-04-18 09:43:53.939704+00', 'Flight of the Sand-Martins, The', 'FLIGHT OF THE SANDMARTINS', 1, 48, 9999, 2, 110, 17, 251, NULL, 'Starts with 1st couple on the opposite sides.



Various versions of this dance exist.  In March 2007 there was a discussion on the Strathspey List

(messages <<sspey-thread:48324>>, <<sspey-thread:48328>>, <<sspey-thread:48344>>)

of a variant in a 3C/4L set,  8 x 48.  In that version, on [45-48],  each couple turns to the correct side to proceed.



In alternative versions the bars  [9-16] and [17-24] can be interchanged, then 1W starts through and down on bar 9.



The version given in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/02/Reel-018-May-1954.pdf#page=3|The Reel, issue 18>> is the 40 bar version but it is attributed to <<ddp:Bankart, Patrick#908>> and entered in the database as <<ddd:#16959>>. See discussion in <<https://my.strathspey.org/dd/issue/2369/|issue 2369>>.', 54, '660  880  555  555   12 12 12   444', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (7316, '2006-03-22 23:00:00+00', '2018-04-03 00:18:02.405723+00', 'Return to Broadford Bay', 'RETURN TO BROADFORD BAY', 1, 32, 9999, 2, 2, 76, 3718, '2004-01-01', '“Having spent a fortnight climbing in the Cuillins in the mid-fifties, the return visit some forty years later brought back happy memories. This dance is a two couple variation on the excellent dance ''Broadford Bay'', but be warned it is strenuous, particularly when executed as a four couple set, as each couple dances three times.”



Amongst the several versions of the description, some claim that this is a “6×32 bar Reel – a 2-couple dance in a 4-couple set”. However, even with 1s and 3s starting simultaneously, the 1st and 2nd couples get three turns as the dancing couple, but 3rd and 4th couples get just one, which is most unfair. It makes most sense to do the dance six times through in a three-couple set, or else eight times through in a four-couple set.', 75, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15707, '2014-11-25 16:15:37.310005+00', '2014-11-25 16:15:37.310005+00', 'Practice Dance for Ladies'' Chain and Allemande (working title)', 'PRACTICE DANCE FOR LADIES CHAIN AND ALLEMANDE WORKING TITLE', 3, 32, NULL, 2, 3, 18, 228, '2014-11-25', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18997, '2018-10-17 12:48:13.686217+00', '2019-01-29 00:18:15.584732+00', 'Karaoke Jig, The', 'KARAOKE JIG', 2, 32, NULL, 1, 3, 42, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15698, '2014-11-10 20:36:03.672628+00', '2017-11-13 16:21:50.186227+00', 'Gentle Lady', 'GENTLE LADY', 3, 40, NULL, 2, 3, 17, 11032, NULL, '', 67, '840|880|888|804|808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15412, '2014-04-03 08:27:16.539154+00', '2017-11-09 10:07:42.95656+00', 'Road to Scurdie Ness, The', 'ROAD TO SCURDIE NESS', 1, 40, NULL, 1, 4, 1, 10944, '2013-11-30', 'Composed to celebrate the 60th anniversary of the East Angus Branch of RSCDS on 30th November 2013. Some features of the route out through Ferryden to Scurdie Ness and around the base of the lighthouse might be recognised.', 92, '8888  8888  8888  8888  8444', 1, 1, 1, 0, 115);
INSERT INTO 'dance' VALUES (3300, '2000-09-20 22:00:00+00', '2018-07-06 23:55:24.493089+00', 'Trip to Gatlinburg', 'TRIP TO GATLINBURG', 2, 32, 9999, 1, 3, 42, 382, '1994-01-01', 'On Dec 16, 2017, Becky Sager <bsager3@juno.com> wrote:



I don''t know if the dance was ever published on paper. Shengzhang was living in Birmingham, AL and dancing with us in Atlanta,GA when he devised it so it has always been popular here. The online instructions linked to SCDDB are correct. The back story is that the dance was inspired by a mishap during an innovative interpretation of Waverley at the annual Ball which was held in Gatlinburg, Tennessee for many years in conjunction with the Smoky Mountain Games. I''m sure many would agree that Waverley could benefit from a little spicing up and in those days weaving in and out during the chases was common practice here. Mr. Tang witnessed an inadvertent lead change in his set and thought it would make a cool progression!

', 50, '880  444  444  888', 1, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (18790, '2018-10-05 13:54:30.318779+00', '2018-10-05 13:54:30.318779+00', 'Horn of Plenty', 'HORN OF PLENTY', 1, 32, NULL, 1, 3, 42, 2766, '2015-11-01', 'Written the weekend of Thanksgiving.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19009, '2018-10-17 13:09:11.255024+00', '2018-10-17 13:09:11.255024+00', 'Wandering Windsors, The', 'WANDERING WINDSORS', 3, 32, NULL, 2, 3, 18, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15708, '2014-12-03 02:47:53.962025+00', '2014-12-17 16:36:01.447819+00', 'Chuck''s Strathspey', 'CHUCKS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11034, '2013-02-01', 'The dance is in memory of Chuck Olsen of the RSCDS Orange County Branch', 53, '862/822/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15428, '2014-05-07 22:25:52.895725+00', '2017-06-21 10:12:22.492021+00', 'Granite City Reel, The', 'GRANITE CITY REEL', 1, 32, 9999, 5, 56, NULL, 10953, '2014-05-01', '> 1 - 8		Advance and retire, repeat but middle 2 set in middle

> 9 - 16		Middles solo while outsides dance R&Ls

> 17 - 24	Reels of 3 across, RSH to R

> 25 - 32	All turn opp RH 11/2 to new pl, set, cross RH to face new 3

', 100, '88/88/88/88', 0, 0, 1, 0, -1);
INSERT INTO 'dance' VALUES (595, '1997-04-03 22:00:00+00', '2018-07-24 21:08:25.658573+00', 'Blue Mountain Reel, The', 'BLUE MOUNTAIN REEL', 1, 32, 9999, 1, 3, 42, 173, '1991-05-18', '', 50, '844/844/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20379, '2021-07-13 15:04:45.382235+00', '2021-07-13 15:04:45.382235+00', 'Sharon''s Medley', 'SHARONS MEDLEY', 4, 64, 5, 2, 3, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (322, '2002-04-25 22:00:00+00', '2022-11-07 17:33:36.650434+00', 'Awa Wi Your Witchcraft', 'AWA WI YOUR WITCHCRAFT', 2, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15709, '2014-12-03 04:43:36.195822+00', '2014-12-03 05:12:25.896146+00', 'Diamonds and Rubies', 'DIAMONDS AND RUBIES', 4, 64, 5, 1, 3, 42, 2680, '2013-07-01', 'Dedicated to the dancers at Pinewoods SS I on their 60th Anniversary and SS II on their 40th Anniversary ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14693, '2013-01-29 14:11:36.44083+00', '2014-12-03 05:28:21.273276+00', 'Eliza Emily''s Reel', 'ELIZA EMILYS REEL', 3, 32, 9999, 2, 3, 17, 3610, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13727, '2011-07-09 22:00:00+00', '2019-10-21 08:09:17.474609+00', 'Paisley Weavers, The', 'PAISLEY WEAVERS', 3, 32, NULL, 2, 104, 17, 175, NULL, '', 67, '800  888  880  844', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (5842, '2002-03-03 23:00:00+00', '2014-12-03 07:42:00.060097+00', 'Saint Martin''s Strathspey', 'SAINT MARTINS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 146, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11763, '2004-08-24 22:00:00+00', '2014-12-03 18:03:17.841978+00', 'Crathes Castle', 'CRATHES CASTLE', 3, 48, 9999, 2, 3, 17, 3444, '1999-01-01', 'In <<ddpub:The Highlander Collection Vol 1>>  this dance is named "One for the Millennium". We keep this as an unofficial alias because an official alias would show up in the RSCDS Dance Index, which would be confusing.', 72, '800  888  800  888  844  888', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (15711, '2014-12-04 21:12:14.832866+00', '2014-12-04 21:12:14.832866+00', 'Kirrie March, The', 'KIRRIE MARCH', 50, 16, NULL, 5, 1, 54, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10392, '2002-03-11 23:00:00+00', '2021-02-09 12:18:46.118041+00', 'Ruby Watson''s Reel', 'RUBY WATSONS REEL', 1, 32, 9999, 5, 2, NULL, 2926, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15697, '2014-11-05 11:14:28.272016+00', '2021-09-23 20:48:53.292393+00', 'Margaret Mitchell''s Rant', 'MARGARET MITCHELLS RANT', 2, 32, NULL, 1, 4, 2, 2701, '2011-01-01', 'Tune: A free-spirited jig with some swing 



Note: Margaret Mitchell has been a mainstay of several branch event committees in her many years of dancing. Oftentimes, she is the first person to arrive at these events, the last to leave, and the go-to person for directions. I’ve called the dance a “rant” as a tongue-in-cheek reference to her customary good grace and teamwork. That’s not to say that she doesn’t rave—but she usually keeps the ranting to a minimum. 



Revised November 3, 2011.  ©2011 by Tim Wilson. All rights reserved. Permission is granted for verbatim reproduction and non-profit distribution of this leaflet, provided that this notice remains intact.

', 69, '8008/8888/8448/8008', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15314, '2013-12-21 23:02:09.02688+00', '2014-12-16 14:31:01.661517+00', 'Farewell to Chandi', 'FAREWELL TO CHANDI', 3, 32, NULL, 1, 3, 42, 10909, '2007-04-09', 'Devised to mark the occasion of Chandi McCracken’s graduation and written as a farewell gift to her shortly before she moved to Minnesota. It was first danced by the Portland branch of the Royal Scottish Country Dance Society at the 100th Portland Rose Festival, June 2, 2007.', 47, '888  822  820  822', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12147, '2005-04-11 22:00:00+00', '2018-04-03 00:07:34.383323+00', 'Blue Triangles', 'BLUE TRIANGLES', 2, 32, 9999, 1, 3, 42, 3488, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8482, '1997-12-28 23:00:00+00', '2018-04-03 00:07:50.341472+00', 'Haar on Skye, The', 'HAAR ON SKYE', 3, 32, 9999, 1, 3, 42, 872, NULL, '', 50, '880/800/880/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10962, '2002-11-18 23:00:00+00', '2015-01-01 18:11:56.555899+00', 'Alba Place', 'ALBA PLACE', 1, 32, 9999, 1, 4, 1, 3226, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15405, '2014-03-27 23:58:28.67449+00', '2015-01-02 18:14:30.206883+00', 'Bethankit', 'BETHANKIT', 2, 32, NULL, 1, 3, 42, 370, NULL, 'Dedicated to June Foreman, a wonderful cook and a good friend for many years', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15713, '2015-01-07 13:13:07.468409+00', '2015-01-07 13:13:07.468409+00', 'Friday Harbor Strathspey', 'FRIDAY HARBOR STRATHSPEY', 3, 40, 9999, 2, 3, 18, 2419, '2007-06-16', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13430, '2009-11-15 23:00:00+00', '2015-01-07 13:25:54.154746+00', 'Duffus Lassie', 'DUFFUS LASSIE', 1, 48, 9999, 4, 4, NULL, 2419, '2008-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13429, '2009-11-15 23:00:00+00', '2015-01-07 13:33:59.954922+00', 'Homecoming 2009, The', 'HOMECOMING 2009', 1, 32, 9999, 1, 4, 1, 2419, '2007-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15714, '2015-01-07 13:58:37.67984+00', '2015-01-07 13:58:37.67984+00', 'Count Robert', 'COUNT ROBERT', 3, 40, 9999, 2, 3, NULL, 3549, '2002-02-28', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15715, '2015-01-07 14:05:38.757168+00', '2015-01-07 14:05:38.757168+00', 'Curry Point', 'CURRY POINT', 3, 32, 9999, 1, 4, 1, 3549, '2004-02-28', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15718, '2015-01-07 14:33:49.453501+00', '2015-01-07 14:33:49.453501+00', 'Loch Fada', 'LOCH FADA', 3, 32, 9999, 1, 4, 1, 3549, '2004-09-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6709, '1997-04-03 22:00:00+00', '2016-07-15 05:34:30.383653+00', 'Trip Down the Rhine, A', 'TRIP DOWN THE RHINE', 1, 32, 9999, 1, 4, 1, 352, '1993-06-21', '', 66, '8840/8804/8804/8844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15176, '2013-09-28 20:02:49.031454+00', '2019-03-11 19:44:32.68001+00', 'Zwillinge, Die', 'ZWILLINGE', 4, 32, 3, 2, 3, 17, 3101, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11483, '2003-09-22 22:00:00+00', '2015-01-08 09:52:44.527221+00', 'Flight to Melbourne', 'FLIGHT TO MELBOURNE', 1, 32, 9999, 4, 4, 13, 511, NULL, 'There is nothing particularly noteworthy about the name of the dance.  The Leicester-Branch deviser Shirley Campbell spent many years in Australia and simply wrote the dance on the long flight back to Melbourne for a return visit.', 88, '8080  8888  8888  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (15738, '2015-01-09 15:51:21.65326+00', '2018-04-03 00:18:02.061907+00', 'Dame Elizabeth''s Reel', 'DAME ELIZABETHS REEL', 1, 32, 9999, 2, 2, 76, 3694, '2009-05-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8264, '1998-12-02 23:00:00+00', '2015-01-08 14:59:12.650244+00', 'Origami Crane, The', 'ORIGAMI CRANE', 3, 40, 9999, 1, 4, NULL, 2476, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15727, '2015-01-08 14:53:44.435892+00', '2018-06-04 12:42:23.446285+00', 'Niji No Sato', 'NIJI NO SATO', 2, 32, 9999, 1, 3, 42, 2474, '1992-03-19', '', 44, '800/833/833/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15732, '2015-01-09 14:21:51.428322+00', '2018-04-02 23:56:35.059807+00', 'Guy''s Seven Berry Jelly', 'GUYS SEVEN BERRY JELLY', 2, 32, 9999, 1, 3, 42, 3694, '2009-05-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15731, '2015-01-08 15:41:35.016963+00', '2015-01-08 15:41:35.016963+00', 'Nihon De Waltz', 'NIHON DE WALTZ', 5, 32, 9999, 7, 113, NULL, 1385, '2009-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15734, '2015-01-09 14:54:02.87743+00', '2018-04-02 23:56:35.184985+00', 'Hip Op Jig, The', 'HIP OP JIG', 2, 32, 9999, 1, 3, 42, 3694, '2009-05-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15729, '2015-01-08 15:20:07.823492+00', '2019-02-04 09:58:52.935698+00', 'Shin Kobe Eki', 'SHIN KOBE EKI', 3, 32, 9999, 1, 3, 42, 2474, '1992-05-28', '', 60, '844/844/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14740, '2013-03-16 13:34:08.853106+00', '2018-04-03 00:07:36.269256+00', 'Buttercup, The', 'BUTTERCUP', 2, 40, NULL, 1, 3, 42, 10777, NULL, '', 45, '800/800/880/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15866, '2015-01-20 15:34:36.853246+00', '2022-01-29 16:17:49.450979+00', 'Return to Saint Martins', 'RETURN TO SAINT MARTINS', 3, 40, 9999, 1, 4, 2, 3618, '2011-01-01', '', 80, '8008/0880/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15712, '2015-01-02 17:23:36.209184+00', '2022-01-20 22:57:37.166924+00', 'Iberian Gathering, The', 'IBERIAN GATHERING', 4, 128, 2, 4, 4, 3, 11037, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15609, '2014-09-03 15:27:11.173981+00', '2022-04-26 01:47:48.062289+00', 'Belle of the Ball', 'BELLE OF THE BALL', 3, 32, NULL, 1, 3, 42, 2766, '2011-02-01', 'This dance is for my cat Belle. Belle was a pure-bred American Shorthair in silver and black and had gorgeous tabby markings.', 63, '880/888/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8526, '1998-02-08 23:00:00+00', '2022-08-13 09:36:14.64666+00', 'Tap the Barrel', 'TAP THE BARREL', 1, 32, 9999, 2, 3, 17, 2076, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15728, '2015-01-08 15:14:22.41476+00', '2022-09-13 17:15:20.210661+00', 'Shabu Shabu', 'SHABU SHABU', 1, 128, 9999, 4, 4, 3, 2474, '1991-10-21', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2228, '1998-04-12 22:00:00+00', '2023-01-27 20:14:09.973314+00', 'Flirtation Hornpipe, The', 'FLIRTATION HORNPIPE', 1, 32, 9999, 1, 4, 1, 400, '1985-01-01', '[Note from 2015]  My name is Jane Smarzik, formerly Wallace. I live in Ottawa. I devised this dance when I listened to the lovely and talented Elma Grech play " The Flirtation Hornpipes". It was presented to her at Gala day in Toronto many years ago. ', 53, '4440  4440  6222  8888', 1, 1, 1, 1, 53);
INSERT INTO 'dance' VALUES (15735, '2015-01-09 15:12:45.052534+00', '2015-01-09 15:12:45.052534+00', 'Florentine Lass, The', 'FLORENTINE LASS', 1, 32, 9999, 1, 4, 2, 3694, '2009-05-31', 'Errata



Bars 1-8 At the end of set and rotate first & third men stay facing out.

From bars 9-24 all the bar numbering is on the wrog lines so that 1-8 and 25-32 are correct, but the bar numbers then refer to each following phrase below.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15736, '2015-01-09 15:26:37.772729+00', '2015-01-09 15:43:25.758041+00', 'Nicola''s Saxophone Reel', 'NICOLAS SAXOPHONE REEL', 1, 96, 9999, 4, 4, 54, 3694, '2009-05-31', 'Errata



Please note bars 33-40 the second time through should read ALL SET.

 

2s and 4s half rights and lefts while 1s and 3s turn right hand, ALL SET', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15744, '2015-01-10 11:02:36.346712+00', '2018-04-02 23:56:35.827682+00', 'Lass from Lewis, A', 'LASS FROM LEWIS', 4, 32, 1, 1, 3, 42, 9, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15739, '2015-01-09 16:00:46.163899+00', '2015-01-09 16:00:46.163899+00', 'Dickie''s Dilemma', 'DICKIES DILEMMA', 3, 32, 9999, 2, 3, 17, 3694, '2009-05-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15755, '2015-01-10 13:53:30.889981+00', '2018-04-02 23:56:37.180265+00', 'Redwood Park Reel', 'REDWOOD PARK REEL', 1, 32, 9999, 1, 3, 42, 11041, '2005-12-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15741, '2015-01-09 16:39:12.550978+00', '2015-01-09 16:39:12.550978+00', 'Grumpy''s Wife', 'GRUMPYS WIFE', 3, 40, 9999, 1, 4, 1, 3694, '2009-05-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15745, '2015-01-10 11:08:17.973821+00', '2015-01-10 11:08:17.973821+00', 'Reel for Ron, A', 'REEL FOR RON', 1, 32, 9999, 1, 4, 1, 993, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15742, '2015-01-10 10:44:48.422039+00', '2015-01-10 10:44:48.422039+00', 'Foursome Jig, A', 'FOURSOME JIG', 2, 32, 9999, 1, 4, 11, 3572, '2009-02-28', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15743, '2015-01-10 10:53:21.598337+00', '2015-01-10 10:53:21.598337+00', 'Jig For Margaret, A', 'JIG FOR MARGARET', 2, 32, 9999, 1, 3, 42, 3572, '2009-02-28', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18603, '2018-09-15 20:21:48.443412+00', '2020-11-17 20:25:16.141243+00', 'Intellectual Interlude, An', 'INTELLECTUAL INTERLUDE', 1, 32, NULL, 3, 5, 7, 10799, '2007-09-01', 'For Liz on her 60th birthday, September 2007', 55, '80800/88888/80800/80800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15406, '2014-03-28 09:21:32.474312+00', '2020-12-30 21:45:09.139594+00', 'Out of Thin Air', 'OUT OF THIN AIR', 3, 32, NULL, 2, 3, 17, 10943, NULL, '', 34, '800/822/800/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15726, '2015-01-08 14:47:03.433304+00', '2021-01-06 00:01:40.616191+00', 'Mishima Onsen', 'MISHIMA ONSEN', 3, 32, 9999, 1, 3, 42, 2474, '1992-05-28', '', 38, '800/822/800/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14680, '2013-01-23 01:46:49.473788+00', '2021-03-15 21:25:39.777503+00', 'Tokyo Flyer', 'TOKYO FLYER', 2, 40, 9999, 2, 3, 17, 2474, '1991-10-21', '', 83, '800/888/800/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15750, '2015-01-10 13:04:45.633362+00', '2015-01-10 13:04:45.633362+00', 'Dance to Your Shadow', 'DANCE TO YOUR SHADOW', 1, 40, 9999, 5, 2, 30, 993, '2003-11-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15751, '2015-01-10 13:33:16.349861+00', '2015-01-10 13:33:16.349861+00', 'Early Spring', 'EARLY SPRING', 1, 32, 9999, 1, 4, 1, 993, '2004-02-29', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15752, '2015-01-10 13:38:31.400631+00', '2015-01-10 13:38:31.400631+00', 'Eoropie Sands', 'EOROPIE SANDS', 2, 40, 9999, 1, 4, 1, 993, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15753, '2015-01-10 13:42:52.885079+00', '2015-01-10 13:42:52.885079+00', 'Hang On', 'HANG ON', 1, 32, 9999, 1, 4, 1, 993, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15754, '2015-01-10 13:47:22.470694+00', '2015-01-10 13:47:22.470694+00', 'Lang May Ye Dance', 'LANG MAY YE DANCE', 1, 32, 9999, 1, 4, 1, 993, '2006-09-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15756, '2015-01-10 14:00:26.062063+00', '2015-01-10 14:00:26.062063+00', 'Rossmore Court', 'ROSSMORE COURT', 3, 32, 9999, 1, 3, 42, 11041, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (702, '1997-04-03 22:00:00+00', '2018-04-03 00:07:35.13174+00', 'Border Reel', 'BORDER REEL', 2, 32, 9999, 1, 3, 42, 198, NULL, 'The SC Dancer April 2009, page 7, gives the following information:

In the original versions of Book 12 (1st. edition in 1938) this dance was published as follows:

1-8   	First and second men dance the figure of eight round their partners

9-16  	First and second women do the same

17-18	First man sets to second woman while first woman sets to second man 

19-20	First man and second woman change places while first woman and second man set again

21-22	First woman and second man change places

23-24	Second couple giving right hands cross over to own side at the top of the dance while first couple giving right hand lead down and turn into third place ready for poussette.  Third couple move up and join for poussette

25-32	First and third couples poussette.

', -1, '', 0, 1, 0, 0, 90);
INSERT INTO 'dance' VALUES (8453, '1998-01-04 23:00:00+00', '2017-02-22 14:26:39.866136+00', 'Bridge of Allan', 'BRIDGE OF ALLAN', 3, 32, 9999, 1, 3, 42, 352, '1996-04-30', '', 69, '880/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7104, '1997-04-03 22:00:00+00', '2017-11-09 00:07:21.864356+00', 'Whistlin'' In The Kitchen', 'WHISTLIN IN THE KITCHEN', 1, 32, 9999, 1, 3, 42, 127, NULL, 'Dance devised for Kathy Reid.



Kathy''s parents live in County Mayo in the West of Ireland so needless to say Kathy does a bit of tin-whistlin'', and most of her practice is done in the kitchen while waiting for the kettle or some cooking utensil to boil. In the last 8 bars of the dance I have tried to portray the steam coming from the kettle as it comes to the boil (I have a keen imagination!)', 75, '888  888  888  888', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (15767, '2015-01-11 13:30:17.401112+00', '2018-12-23 14:31:50.12529+00', 'Executive Reel, The', 'EXECUTIVE REEL', 1, 32, 9999, 1, 3, 42, 440, '2003-12-17', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13299, '2007-06-22 22:00:00+00', '2015-01-11 12:47:00.894967+00', 'Music and the Dance, The', 'MUSIC AND THE DANCE', 3, 32, 9999, 1, 3, 42, 440, '2007-06-01', '', 62, '800  888  888  888', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (16133, '2015-02-27 12:05:32.033171+00', '2019-06-20 21:57:54.381041+00', 'Ruby Wedding, The', 'RUBY WEDDING', 1, 40, 9999, 1, 3, 42, 3358, '1993-02-01', '', 58, '800/866/888/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15777, '2015-01-11 15:40:23.519769+00', '2015-01-11 15:40:23.519769+00', 'Dancer''s Delight', 'DANCERS DELIGHT', 7, 104, 9999, NULL, 51, NULL, 401, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15779, '2015-01-11 15:55:19.178568+00', '2015-01-11 15:55:19.178568+00', 'Hielan'' Laddie', 'HIELAN LADDIE', 7, 136, 9999, NULL, 51, NULL, 401, '1991-01-01', 'Notes prepared by Ron Wallace, 1991



Sources:

Hebridean Solo Dances, Jack McConachie

Highland and Traditional Scottish Dances, D.G. MacLennan

National Dance Book of the Scottish Dance Teachers Alliance', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15780, '2015-01-11 16:45:39.163549+00', '2015-01-11 16:45:39.163549+00', 'Jo''s Delight', 'JOS DELIGHT', 7, 68, 9999, NULL, 51, NULL, 3469, NULL, 'Dance devised by Magaret Zadworny, 1977



Notes Prepared by Ron Wallace, 1988



Recording:  Step Dances, Vol. 3, Muriel Johnstone', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15783, '2015-01-11 19:08:56.17736+00', '2015-01-11 19:08:56.17736+00', 'Peaceful Maiden, The', 'PEACEFUL MAIDEN', 7, 64, NULL, NULL, NULL, NULL, 401, '1988-12-01', 'Dance devised by Ron Wallace, 1988



Notes prepared by Ron Wallace, 1988



Recording:  Step Dance Volume 3, Muriel A. Johnstone

                 Dancers Dream, Hood, Wink & Swagger', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3616, '1998-09-30 22:00:00+00', '2015-01-11 23:09:27.061313+00', 'Lady Lucy Ramsay', 'LADY LUCY RAMSAY', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 56, '888  888  800  880', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (15770, '2015-01-11 14:05:24.876032+00', '2018-04-02 23:56:33.255354+00', 'Bye Bye, Barbara', 'BYE BYE BARBARA', 2, 32, 9999, 1, 3, 42, 440, '2006-02-11', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (161, '1997-04-03 22:00:00+00', '2015-01-11 23:22:38.127125+00', 'Anna''s Strathspey', 'ANNAS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 173, '1972-04-04', 'Preferred Music: Grant''s Reel", by Bobby Crowe on "Music for book 14".  The lead tune is given below.', 69, '880  888  888  888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (16298, '2015-05-08 19:26:03.428221+00', '2018-04-02 23:56:33.297143+00', 'Camel, The', 'CAMEL', 1, 48, 9999, 1, 3, 42, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16299, '2015-05-08 19:31:20.633911+00', '2018-04-02 23:56:33.372415+00', 'Carols a Plenty', 'CAROLS A PLENTY', 2, 32, 9999, 1, 3, 42, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16005, '2015-02-08 17:08:32.664247+00', '2015-02-08 17:08:32.664247+00', 'Mrs Stella Fogg', 'MRS STELLA FOGG', 3, 32, 9999, 2, 3, 18, 703, '2012-03-23', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16129, '2015-02-27 10:45:17.488833+00', '2015-02-27 10:45:17.488833+00', 'Trinity Gold', 'TRINITY GOLD', 2, 32, 9999, 3, 5, 7, 3471, '1997-10-03', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15763, '2015-01-10 16:38:59.027408+00', '2015-03-15 21:58:33.084971+00', 'Treeple Bob, The', 'TREEPLE BOB', 2, 32, 9999, 5, 53, 30, 210, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3052, '1997-04-03 22:00:00+00', '2022-07-31 10:51:40.09696+00', 'Iain Dubh', 'IAIN DUBH', 3, 32, 9999, 1, 3, 42, 393, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12533, '2005-08-29 22:00:00+00', '2022-09-19 09:58:06.189096+00', 'Summer of ''94', 'SUMMER OF 94', 3, 32, 9999, 1, 3, 42, 3629, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21240, '2023-01-04 23:14:44.255157+00', '2023-01-04 23:14:44.255157+00', 'Cosmic Chaos', 'COSMIC CHAOS', 3, 32, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15782, '2015-01-11 17:28:21.170115+00', '2015-01-11 17:28:21.170115+00', 'New Claret', 'NEW CLARET', 7, 112, 9998, NULL, 99, NULL, 3469, NULL, 'Dance deviced by Margaret Zadworny



Notes prepared by Ron Wallace 1988



Recording: Step Dances Vol 1, Muriel A. Johnstone

                Dancers Dream, Hood, Wink & Swagger ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6566, '1998-09-29 22:00:00+00', '2016-09-06 09:17:35.088921+00', 'Three Bonnie Maidens, The', 'THREE BONNIE MAIDENS', 3, 32, 9999, 1, 3, 42, 9998, NULL, 'Official Alias: The Graces ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15827, '2015-01-18 13:07:13.855482+00', '2018-04-02 23:56:34.466671+00', 'Farewell to Kingussie', 'FAREWELL TO KINGUSSIE', 1, 32, 9999, 1, 3, 42, 1582, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (73, '1998-04-21 22:00:00+00', '2020-12-27 12:49:12.584623+00', 'Ale is Dear, The', 'ALE IS DEAR', 4, 32, 1, 5, 56, NULL, 44, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16300, '2015-05-08 19:38:57.762918+00', '2020-12-29 12:29:26.618795+00', 'Chatham Chase', 'CHATHAM CHASE', 2, 32, 9999, 1, 3, 42, 11133, '2010-01-01', '', 56, '800/888/888/826', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16297, '2015-05-08 19:18:06.250438+00', '2020-12-29 12:32:38.443412+00', 'Bonnie Donovans', 'BONNIE DONOVANS', 4, 64, 5, 1, 3, 42, 11133, '2010-01-01', '', 50, '440/840/888/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12729, '2006-04-27 22:00:00+00', '2021-01-09 21:44:05.870132+00', 'Dancing Bells, The', 'DANCING BELLS', 2, 32, 9999, 1, 3, 42, 440, '2004-10-01', '', 56, '800/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15766, '2015-01-11 13:18:47.000464+00', '2021-03-18 22:16:42.242359+00', 'Elizabeth''s Jig', 'ELIZABETHS JIG', 2, 32, 9999, 1, 3, 42, 440, '2003-01-30', '', 38, '840/840/440/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15771, '2015-01-11 14:19:20.973689+00', '2021-03-25 13:15:22.68947+00', 'I Cannot Dance Alone', 'I CANNOT DANCE ALONE', 3, 32, 9999, 2, 3, 17, 440, '2006-10-31', 'When she was asked to illustrate a figure during the advanced technique class I heard Jean Noble exclaim

"I cannot dance alone. (In the dance there are only two bars where the first couple is not holding hands

with somebody."', 83, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15776, '2015-01-11 15:13:08.92105+00', '2021-03-24 22:18:36.258394+00', 'Fiddling Preacher, The', 'FIDDLING PREACHER', 1, 32, 9999, 1, 3, 42, 440, '2007-10-13', 'Devised for Ed Elliotson.  

Ed, as well as playing the fiddle, is now learning to be a lay preacher.', 44, '800/844/822/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10048, '2001-09-02 22:00:00+00', '2015-01-11 23:33:00.812875+00', 'Well Done, Bernard!!', 'WELL DONE BERNARD', 2, 32, 9999, 1, 3, 42, 2927, '1999-01-01', 'To Dr. Bernard Kaiman on receiving the RSCDS Scroll of Honour in july 1999, and presented at English Mountain Weekend 1999



The elements of this dance have the following symbolic associations:

1-8      the pattern danced on the floor is a mirrored "B" for Bernard

9-16    _crown_ triangles for the _Royal_ Scottish Country Dance Society

17-24  depicts the fellowship and fun of SCD, which Bernard always epitomized

25-32  symbolizes the worldwide family of dancers to which we all belong

', 53, '800  866  844  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (15789, '2015-01-15 16:03:28.027219+00', '2018-04-02 23:56:32.899733+00', 'Auld Rigg, The', 'AULD RIGG', 3, 32, 9999, 1, 3, 42, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15798, '2015-01-15 18:40:31.820091+00', '2018-04-02 23:56:33.70706+00', 'Dance o'' Hoochs', 'DANCE O HOOCHS', 2, 32, 9999, 1, 3, 42, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15801, '2015-01-16 11:43:34.091882+00', '2018-04-02 23:56:37.45572+00', 'Run-Deil Dance, The', 'RUNDEIL DANCE', 1, 32, 9999, 1, 3, 42, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17897, '2017-07-16 12:12:34.27562+00', '2018-08-19 22:34:30.318821+00', 'Holyrood Strathspey', 'HOLYROOD STRATHSPEY', 3, 32, NULL, 1, 3, 42, 347, '2015-09-01', 'The deviser is very fond of Edinburgh and its architecture.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17744, '2017-05-10 08:21:39.54489+00', '2018-08-20 00:16:47.759351+00', 'Fay''s New Reel', 'FAYS NEW REEL', 1, 32, NULL, 1, 3, 42, 3698, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15788, '2015-01-15 15:54:02.32033+00', '2015-01-15 15:54:02.32033+00', 'Lang Rigg, The', 'LANG RIGG', 2, 32, 9999, 2, 3, 17, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9900, '2001-06-04 22:00:00+00', '2019-03-04 13:34:48.040447+00', 'Unfancy Bean Shee', 'UNFANCY BEAN SHEE', 1, 48, 9999, 3, 5, 7, 2895, NULL, '', 75, '88888/88880/82842/88888/84844/80800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15800, '2015-01-16 11:38:44.08634+00', '2018-04-03 00:07:40.932806+00', 'Dance o'' Vowels', 'DANCE O VOWELS', 3, 32, 9999, 1, 3, 42, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15797, '2015-01-15 18:36:49.398569+00', '2016-04-19 13:06:03.931674+00', 'Lilt It Pair on Pair', 'LILT IT PAIR ON PAIR', 3, 32, 9999, 1, 3, 42, 210, NULL, 'Danced as strathspey or reel', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15793, '2015-01-15 18:08:24.522803+00', '2015-01-15 18:08:24.522803+00', 'Follow the Knowes', 'FOLLOW THE KNOWES', 3, 32, 9999, 2, 3, 17, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15794, '2015-01-15 18:14:10.263861+00', '2015-01-15 18:14:10.263861+00', 'Hanle the Feet', 'HANLE THE FEET', 2, 32, 9999, 2, 3, 17, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15795, '2015-01-15 18:23:26.712745+00', '2015-01-15 18:23:26.712745+00', 'Foreoars Lilt, The', 'FOREOARS LILT', 3, 32, 9999, 2, 3, 17, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15796, '2015-01-15 18:28:54.085572+00', '2015-01-15 18:28:54.085572+00', 'Rantin'' Kirn, The', 'RANTIN KIRN', 2, 40, 9999, 2, 3, 17, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15799, '2015-01-15 18:53:52.912741+00', '2015-01-15 18:53:52.912741+00', 'Cockledum Ditt the Feet', 'COCKLEDUM DITT THE FEET', 2, 64, 9999, 1, 4, 11, 210, NULL, '2nd and 4th couples start on opposite sides', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15828, '2015-01-18 13:25:31.475786+00', '2016-01-13 11:35:18.096086+00', 'Jig for Nethybridge Dancers, A', 'JIG FOR NETHYBRIDGE DANCERS', 2, 32, 9999, 1, 4, 1, 1582, '2010-03-01', 'Can be danced in three couple set', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15803, '2015-01-16 12:37:50.084425+00', '2015-01-16 12:37:50.084425+00', 'Dinna Haud the Cannle', 'DINNA HAUD THE CANNLE', 3, 32, 9999, 1, 4, 1, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15804, '2015-01-16 12:43:09.330096+00', '2015-01-16 12:43:09.330096+00', 'Treeple on the Square', 'TREEPLE ON THE SQUARE', 2, 32, 9999, 1, 4, 1, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15806, '2015-01-16 12:56:26.616585+00', '2015-01-16 12:56:26.616585+00', 'Rigadown-Daisy', 'RIGADOWNDAISY', 1, 32, 9999, 1, 4, 2, 210, NULL, '2nd & 4th couples start on opposite sides', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1600, '1998-11-02 23:00:00+00', '2015-01-18 10:16:52.593962+00', 'Decimus', 'DECIMUS', 2, 32, 9999, 3, 5, 16, 394, '1990-01-01', 'Devised for the 10th anniversary of the Kingston Ontario Branch (may 1990)', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16006, '2015-02-08 17:18:03.681065+00', '2020-03-14 08:10:09.075343+00', 'St John''s Road', 'SAINT JOHNS ROAD', 1, 32, 9999, 1, 3, 42, 703, '2012-03-23', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7065, '1997-04-03 22:00:00+00', '2020-08-07 10:36:12.750486+00', 'Wha''ll Be King But Charlie?', 'WHALL BE KING BUT CHARLIE', 2, 32, 9999, 1, 3, 42, 129, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15311, '2013-12-19 10:51:52.564974+00', '2020-08-31 16:16:23.265566+00', 'Two Gray Cats, The', 'TWO GRAY CATS', 1, 40, 9999, 1, 3, 42, 10907, '2010-06-01', '', 55, '880/888/800/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15768, '2015-01-11 13:39:03.11723+00', '2021-08-10 18:18:49.48953+00', 'Marriage Made in Dancing, A', 'MARRIAGE MADE IN DANCING', 3, 32, 9999, 1, 3, 42, 440, '2006-05-12', 'Ann Campbell devised this dance for the 2006 marriage of Rob Lockhart and Teresa Kowalczyk, who met while "stooging" for Teacher Candidates. It was the first dance at their wedding reception.', 56, '800/888/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18510, '2018-08-19 18:49:30.683966+00', '2020-10-13 20:06:18.822216+00', 'Four Candles', 'FOUR CANDLES', 2, 32, NULL, 1, 100, 2, 1228, '2018-05-01', 'Bars 9-12 represent four candles, and the reels represent a fork handle.', 75, '8008/8888/8888/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15829, '2015-01-18 13:32:16.784625+00', '2020-10-12 12:05:09.828353+00', 'Lauren''s Strathspey', 'LAURENS STRATHSPEY', 3, 32, 9999, 1, 2, 76, 1582, '2006-09-01', '', 60, '88/88/80/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15786, '2015-01-15 15:40:10.295729+00', '2021-01-04 15:43:34.315809+00', 'Barley Rigg, The', 'BARLEY RIGG', 3, 32, 9999, 2, 3, 17, 210, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15805, '2015-01-16 12:49:09.778375+00', '2021-01-04 17:37:07.396038+00', 'Hilkadans, The', 'HILKADANS', 3, 32, 9999, 4, 4, 13, 210, NULL, '', 88, '8080/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15802, '2015-01-16 12:30:10.233124+00', '2021-01-06 15:47:47.380372+00', 'All Glint and Glisk', 'ALL GLINT AND GLISK', 2, 32, 9999, 2, 3, 17, 210, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9320, '2000-01-16 23:00:00+00', '2020-06-03 22:19:15.184035+00', 'August in the Antipodes', 'AUGUST IN THE ANTIPODES', 2, 32, 9999, 1, 4, 2, 3590, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14972, '2013-07-03 19:18:04.449228+00', '2020-10-03 18:32:27.44883+00', 'Woodside', 'WOODSIDE', 2, 32, NULL, 1, 3, 42, 3699, NULL, '', 59, '884/884/844/848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15775, '2015-01-11 15:02:20.271208+00', '2021-03-19 00:36:41.775436+00', 'She Wouldn''t Be Shooshed', 'SHE WOULDNT BE SHOOSHED', 1, 32, 9999, 1, 3, 42, 440, '2005-04-12', 'I devised this dance after learning the figure Set & Rotate at Keith and Deirdre Bark''s class. The name comes from a conversation between Jean Noble and Josie Chisamore at the April monthly dance.', 56, '800/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8085, '1997-09-18 22:00:00+00', '2021-03-22 12:41:41.107275+00', 'Susan Scott of San Rafael', 'SUSAN SCOTT OF SAN RAFAEL', 1, 32, 9999, 1, 3, 42, 1393, '1993-01-01', 'The devsier, David Newett of the San Francisco Branch, notes that Susan Scott is a dancer in the Bay Area (quite obviously from San Rafael) and that "she has that kind of wonderful smile that makes it fun to be dancing in the same set with her."  ', 44, '800  888  800  880', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (15772, '2015-01-11 14:27:45.371932+00', '2021-03-25 17:43:54.162735+00', 'Valerie''s Reel', 'VALERIES REEL', 1, 32, 9999, 1, 3, 42, 440, '2008-04-06', 'This was a "thank you" to Valerie Fisher for securing the Toronto French School as a venue for the makeup

dance of April 17, the March monthly dance having been cancelled due to a snow storm.', 59, '822/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15765, '2015-01-11 13:11:23.265777+00', '2021-03-25 10:10:47.467459+00', 'It''s Bobby''s Fault', 'ITS BOBBYS FAULT', 1, 32, 9999, 1, 3, 42, 440, '2003-06-01', 'On the way home from dancing in the park, listening to Bobby''s music and thinking up figures, I found

myself suddenly going north on Highway 409 instead of west on 401!', 56, '800/888/888/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6931, '1998-01-05 23:00:00+00', '2021-04-03 19:17:36.447696+00', 'Washington''s Ways', 'WASHINGTONS WAYS', 1, 48, 9999, 1, 3, 42, 23, NULL, 'From the original instructions "Devised as a surprise for Harry Ways, and first danced in 1973. Harry was ''founding father'' and first Chairman of the Scottish Country Dance Society of Washington, and is now the first President of the Washington, D. C. Branch, RSCDS. And well deserves a dance."', 60, '800/822/888/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16009, '2015-02-09 13:31:13.755506+00', '2015-02-09 13:31:13.755506+00', 'Lakeside Reel', 'LAKESIDE REEL', 1, 32, 9999, 1, 4, 1, 11070, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15791, '2015-01-15 16:15:46.029346+00', '2016-04-18 23:07:39.579746+00', 'Barman''s Jig', 'BARMANS JIG', 2, 32, 9999, 1, 2, NULL, 210, NULL, '2 couple dance in 3 or 4 couple set', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15784, '2015-01-15 15:18:39.742472+00', '2016-04-18 23:08:25.580296+00', 'Cantily Lilt It', 'CANTILY LILT IT', 3, 40, 9999, 1, 2, NULL, 210, NULL, '2 couple dance in 3 or 4 couple set', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15785, '2015-01-15 15:26:31.997394+00', '2016-04-18 23:23:00.996156+00', 'Reill O'' Life', 'REILL O LIFE', 1, 32, 9999, 1, 2, NULL, 210, NULL, '2 couple dance in 3 or 4 couple set', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7313, '2006-03-07 23:00:00+00', '2017-03-09 16:11:10.055009+00', 'Summer Rain', 'SUMMER RAIN', 2, 32, 9999, 1, 3, 42, 3661, '2002-01-01', '', 53, '800/888/888/822', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15814, '2015-01-18 09:08:17.415104+00', '2018-04-02 16:43:27.792584+00', 'Burning the Piper''s Hut', 'BURNING THE PIPERS HUT', 7, 64, 9999, NULL, 51, NULL, 401, NULL, 'Dance devised by Ron Wallace, 1992-4



Notes prepared by Ron Wallace



Recording:  Swinging on a Gate, Tony Elman, AC003

                 Dancers Dream, Hood, Wink & Swagger, HWSCD001', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15807, '2015-01-17 09:59:28.100145+00', '2015-01-17 09:59:28.100145+00', 'Dance Your Heart Intil You Feet', 'DANCE YOUR HEART INTIL YOU FEET', 1, 32, 9999, 1, 4, 2, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15808, '2015-01-17 10:18:53.700115+00', '2015-01-17 10:18:53.700115+00', 'Keep Yer Ribbons Reelin''', 'KEEP YER RIBBONS REELIN', 3, 32, 9999, 1, 4, 22, 210, NULL, 'It''s shadow setting to corners and partners', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15809, '2015-01-17 10:23:49.284928+00', '2015-01-17 10:23:49.284928+00', 'Twalsome Reel', 'TWALSOME REEL', 1, 32, 9999, 4, 6, 30, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15815, '2015-01-18 09:20:29.203593+00', '2018-04-02 16:43:55.916838+00', 'Dancer''s Dream, A', 'DANCERS DREAM', 7, 112, 9998, NULL, 51, NULL, 401, NULL, 'Solo Step Dance for Women





Dance devised by Ron Wallace



Notes prepaired by Ron Wallace



At Pinewoods English Scottish Session (ESS) 1992, Muriel Johnstone and Ron Wallace auctioned an original dance with original music in support of ESS. Thanks to Norah Link and her generosity, A Dancer''s Dream became reality.



Recording:   Dancers Dream, Hood, Wink & Swagger, HWSCD001', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15811, '2015-01-17 10:34:32.010062+00', '2015-01-17 10:34:32.010062+00', 'Toronto Waltz', 'TORONTO WALTZ', 5, 16, 9999, 7, 1, NULL, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15816, '2015-01-18 09:31:54.949042+00', '2018-04-02 16:44:40.552442+00', 'Favourite of the Ladies, A', 'FAVOURITE OF THE LADIES', 7, 128, 9999, NULL, 54, NULL, 238, NULL, 'A Highland Step Dance for Four Women





Dance devised by Phyllis MacCulloch, Ottawa Branch of the Royal Scottish Country Dance Society, 1988



Notes prepared by Ron Wallace



Recording:    "Fiddle" The Cape Breton Symphony, Polka March CSPS-1834

                     Dancers Dream, Hood, Wink & Swagger, HWSCD001', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3487, '1997-04-03 22:00:00+00', '2016-05-10 22:50:20.069321+00', 'King of Sweden, The', 'KING OF SWEDEN', 7, 128, 9999, 107, 51, NULL, 319, NULL, 'Solo Step Dance for Women



Source:   Four Step Dances, Frederick Hill''s Book of Quadrilles and Country Dances 22nd March, 1841,

              RSCDS 1053



Taken from "Four Step Dances" published by the RSCDS and other sources



Notes prepared by Ron Wallace, 1994



Recording:  Step Dances, Muriel Johnstone, RSCDS

                 Dancers Dream, Hood, Wink & Swagger, HWSCD001', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15817, '2015-01-18 09:56:57.720649+00', '2018-04-02 16:45:06.681129+00', 'Lassie''s Farewell, The', 'LASSIES FAREWELL', 7, 96, 21, NULL, 51, NULL, 2792, NULL, 'Solo Step Dance





Dance devised by Vicky Goodloe, 1990



Notes prepared by Ron Wallace, 1994



Recording:   Farewell to the North from "in Strict tempo" The Lothian Scottish Dance Band LILP 5112

                   Dancers Dream, Hood, Wink & Swagger, HWSCD001', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15810, '2015-01-17 10:30:18.488443+00', '2016-05-11 14:05:54.690866+00', 'Reel Dozen', 'REEL DOZEN', 1, 40, 9999, 107, 115, 30, 210, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8750, '1998-10-15 22:00:00+00', '2018-04-02 16:45:26.431535+00', 'Miss Forbes', 'MISS FORBES', 7, 80, 9999, NULL, 51, NULL, 9998, NULL, 'Solo Step Dance for Women





Reconstructed from Highland and Traditional Scottish Dances, D G MacLennan



Reconstructed by Ron Wallace with kind help of the dancers in the Wednesday night advanced step class.



The popular reconstruction uses for its music "Man at the Loom" which is quite lively,

whereas the MacLennan book uses "Miss Forbes Farewell to Banff" which is smooth and stately.



Recording:  Dancers Dream, Hood, Wink & Swagger, HWSCD001', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18669, '2018-09-30 16:05:35.52038+00', '2019-07-07 22:16:45.516147+00', 'Hoy Head, The', 'HOY HEAD', 1, 32, NULL, 3, 5, 7, 374, NULL, '', 68, '80800/88880/84884/84844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18668, '2018-09-30 15:45:42.708479+00', '2018-11-09 18:21:17.853412+00', 'Taunton Capers', 'TAUNTON CAPERS', 2, 32, NULL, 1, 3, 42, 11722, NULL, '', 62, '880/888/888/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15819, '2015-01-18 10:22:01.274806+00', '2018-04-02 16:46:00.42667+00', 'Miss Rowan Davies', 'MISS ROWAN DAVIES', 7, 128, 9999, NULL, 51, NULL, 11045, NULL, 'Solo Step Dance for Women





Written by Barbara Campbell, Vancouver, B.C. 1993



Notes prepared by Ron Wallace, 1994



Suitable Recording by Blackthorn



Recording:   Dancers Dream, Hood, Wink & Swagger, HWSCD001', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15823, '2015-01-18 12:30:21.410935+00', '2015-01-18 12:37:31.978506+00', 'Away Tae Kilcreggan', 'AWAY TAE KILCREGGAN', 2, 32, 9999, 2, 3, 17, 1582, '2009-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15812, '2015-01-17 18:09:25.982908+00', '2018-04-02 16:46:19.383319+00', 'Piper in the Meadow', 'PIPER IN THE MEADOW', 7, 60, 9999, NULL, 51, NULL, 11044, NULL, 'Solo Dance for Ladies', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15818, '2015-01-18 10:07:26.173098+00', '2016-05-12 07:34:38.846772+00', 'Meg Mackie', 'MEG MACKIE', 7, 80, 9999, 107, 1, NULL, 11045, NULL, 'Duet for a Man and a Woman



Written by:  Barbara campbell, Vancouver, B.C.



Recording:   Dancers Dream, Hood, Wink & Swagger, HWSCD001

                  Suitable recording by New England Chestnuts', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18604, '2018-09-15 20:28:12.52577+00', '2022-08-13 22:02:25.057144+00', 'John''s on the Fiddle', 'JOHNS ON THE FIDDLE', 4, 48, 11, 4, 4, 3, 10799, '2010-02-01', 'To A Budding Ron Gonnella, February 2010.



', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15821, '2015-01-18 10:35:39.270746+00', '2018-04-02 16:46:36.7014+00', 'Scully''s Reel', 'SCULLYS REEL', 7, 64, 9999, NULL, 51, NULL, 401, NULL, 'Solo Hard Shoe Step Dance





Dane devised by Ron Wallace, 1993 for Colleen Put from Nova Scotia who is a wonderful inspiration and provides countless hours of great dancing and playing at Pinewoods.



Notes prepared by Ron Wallace, 1994



Recording:   Third Time Around, Jim Fyhrie  JPF624-C

                  Dancers Dream, Hood, Wink & Swagger, HWSCD001', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15813, '2015-01-17 18:19:58.039869+00', '2018-04-02 16:47:02.333287+00', 'Tulloch Gorm', 'TULLOCH GORM', 7, 48, 9999, NULL, 51, NULL, 401, NULL, 'A simple Hebridean Solo Dance for Men or Women



Notes prepared by Ron Wallace, 1988



Source:        Charlie Mill, principal of thr C.H. Mill School of Dancing

                   Habridean Solo Dances, Jack McConachie



Recording:    Step Dances Vol 2, Muriel A Johnstone, or 

                   Dances Frae O''er the Border, Stan Watts Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14422, '2012-05-01 12:50:45.752936+00', '2020-09-28 18:59:42.219712+00', 'Hamburg Medley, The', 'HAMBURG MEDLEY', 4, 128, 13, 4, 4, 4, 1582, '2008-09-01', 'Devised for Hamburg Weekend Course, September 2008', 88, '8888/8888/4444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15320, '2013-12-22 23:17:34.045752+00', '2020-10-07 16:29:21.798154+00', 'Secrets of the Fire Swamp', 'SECRETS OF THE FIRE SWAMP', 2, 32, NULL, 1, 3, 42, 10593, '2012-12-01', '', 56, '888/880/440/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18667, '2018-09-30 14:46:39.837504+00', '2020-11-19 19:31:20.086588+00', 'Sea Dog Bamse', 'SEA DOG BAMSE', 4, 96, 11, 4, 4, 3, 11721, NULL, '', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6912, '1997-12-07 23:00:00+00', '2020-11-30 22:31:51.996756+00', 'Wallace, The', 'WALLACE', 3, 32, 9999, 1, 3, 42, 108, '1986-01-01', '', 69, '880/888/888/888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (12279, '2005-04-25 22:00:00+00', '2020-12-25 12:32:21.808863+00', 'Ice Cream with Chopsticks', 'ICE CREAM WITH CHOPSTICKS', 2, 32, 9999, 1, 3, 42, 1582, NULL, '', 42, '600  888  800  844', 0, 1, 1, 0, 56);
INSERT INTO 'dance' VALUES (15820, '2015-01-18 10:29:44.676027+00', '2018-04-02 16:47:49.842004+00', 'My Love She''s But a Lassie Yet', 'MY LOVE SHES BUT A LASSIE YET', 7, 136, 9999, NULL, 51, NULL, 2792, NULL, 'A Ladies Solo Step Dance





Dance devised by Vicky Goodloe for the choreography competition at Great Smoky Mountains, Gatlinburg Highland Games, Gatlinburg, Tennessee, May 1084



Notes prepared by Vicky Goodloe', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15822, '2015-01-18 12:23:18.613227+00', '2018-04-02 23:56:32.643641+00', 'Amber Light, The', 'AMBER LIGHT', 1, 32, 9999, 1, 3, 42, 1582, '2010-10-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15839, '2015-01-18 15:06:48.212789+00', '2015-01-18 15:06:48.212789+00', 'Picnic in the Rain', 'PICNIC IN THE RAIN', 1, 32, 9999, 1, 100, 2, 1582, '2004-07-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15840, '2015-01-18 15:19:26.036842+00', '2015-01-18 15:19:26.036842+00', 'Pools of the Spey, The', 'POOLS OF THE SPEY', 3, 48, 9999, 1, 4, 1, 1582, '2006-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15841, '2015-01-18 15:24:07.302405+00', '2015-01-18 15:24:07.302405+00', 'Red House Jig', 'RED HOUSE JIG', 2, 32, 9999, 2, 3, 17, 1582, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15851, '2015-01-20 11:17:18.326977+00', '2018-04-02 23:56:34.87587+00', 'Glasgow Flower, The', 'GLASGOW FLOWER', 1, 32, 9999, 1, 3, 42, 2625, '2005-11-22', 'Any good reel



such as "Sandy''s New Chanter" played by Marian Anderson on "St Bernard''s Waltz" CD - HRMCD102', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15845, '2015-01-18 15:52:38.105318+00', '2015-01-18 15:52:38.105318+00', 'Southward Bound', 'SOUTHWARD BOUND', 1, 32, 9999, 3, 5, 7, 1582, '2009-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15831, '2015-01-18 13:45:05.04392+00', '2018-05-01 09:24:37.320072+00', 'Margaret Martin of North Berwick', 'MARGARET MARTIN OF NORTH BERWICK', 3, 32, 9999, 2, 3, 17, 1582, '2009-02-01', 'Written as a tribute to Margaret Martin, RSCDS East Lothian Branch, on her 80th birthday, February 2009', 83, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15844, '2015-01-18 15:44:37.545939+00', '2018-05-01 23:57:21.622529+00', 'Seamless Jig, The', 'SEAMLESS JIG', 2, 32, 9999, 2, 3, 17, 1582, '2011-02-01', 'Devised for Duncan Brown (To be danced with aplomb!), February 2011', 71, '800/888/866/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7715, '1998-10-26 23:00:00+00', '2015-01-18 17:44:20.744176+00', 'Fifty Golden Years', 'FIFTY GOLDEN YEARS', 3, 128, 9999, 4, 4, 3, 403, '1993-04-28', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14542, '2012-08-19 17:29:23.537807+00', '2015-01-19 21:41:02.693632+00', 'Snow on the Roof', 'SNOW ON THE ROOF', 3, 32, NULL, 1, 3, 42, 515, '2012-01-01', 'Dedicated to Margo Priestley on her retirement as Summer School director (2010 - 2012).

', 56, '880  800  888  888', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (15848, '2015-01-20 10:48:20.652059+00', '2015-01-20 10:48:20.652059+00', 'Knaresborough Welcome', 'KNARESBOROUGH WELCOME', 11, 16, 9999, 5, 113, 4, 2625, '1999-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15834, '2015-01-18 14:03:29.361759+00', '2018-05-01 14:59:21.053949+00', 'Nadine''s Celebration', 'NADINES CELEBRATION', 1, 32, 9999, 2, 3, 17, 1582, '2009-01-01', 'Devised for Nadine Wharton January 2009.', 83, '888/888/808/484', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15217, '2013-10-15 10:39:28.511738+00', '2019-02-04 09:57:54.473448+00', 'MacPhail''s Rant', 'MACPHAILS RANT', 1, 32, 9999, 1, 3, 42, 80, '2002-01-01', '', 53, '800  444   12 12 12   822', 0, 1, 1, 0, 70);
INSERT INTO 'dance' VALUES (15853, '2015-01-20 12:04:59.991622+00', '2015-01-20 12:04:59.991622+00', 'Brenda''s Breenge', 'BRENDAS BREENGE', 11, 32, 9999, 5, 113, 4, 2625, '2000-01-01', 'Tune:  any good march  (but not too fast)

          eg "Auld Town March" as on the "Music of the Highlands"  CD - CD6228', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15849, '2015-01-20 10:58:17.654732+00', '2018-04-02 23:56:35.267601+00', 'Imperial Eagle, The', 'IMPERIAL EAGLE', 1, 32, 9999, 1, 3, 42, 11047, '2003-06-18', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15855, '2015-01-20 12:31:22.043428+00', '2015-01-20 12:31:22.043428+00', 'Hallowe''en Spell, A', 'HALLOWEEN SPELL', 11, 32, 9999, 5, 2, NULL, 11047, '2001-10-01', 'This can be walked, as a ceilidh/warm-up dance, or danced as jig



For this dance 1''s face 2''s; 1''s are facing clockwise, 2''s anti-clockwise,

gentlemen with partners on their right.





Tune:  Any good march (if walking) or jig (if dancing).

          I normally use "Four-Fours) as played by Royal Scots Dragoon Gards on their CD

          "Flower Of Scotland" - CD MFP6198 - pipe music seems to add to aura of Hallowe''en', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15856, '2015-01-20 12:56:46.802293+00', '2015-01-20 12:56:46.802293+00', 'Atholl Gathering', 'ATHOLL GATHERING', 1, 32, 9999, 3, 5, 7, 2625, '2007-12-01', 'Music: Any good reel such as "Water of Dryfe" as played by Colin Dewar on his

          "Special Requests Vol4"  CD - SRCD004, track 12.





Can also be danced in any longer set with an odd number of couples (eg 7 or 9)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15857, '2015-01-20 14:14:19.723257+00', '2015-01-20 14:14:19.723257+00', 'Caleb Pike Jig, The', 'CALEB PIKE JIG', 2, 32, 9999, 5, 2, 30, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15858, '2015-01-20 14:23:28.020146+00', '2015-01-20 14:23:28.020146+00', 'Calgary Homecoming, The', 'CALGARY HOMECOMING', 3, 80, 9999, 4, 4, 3, 3618, '2003-09-01', 'Recomended Music:   The Robertson Rant', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15859, '2015-01-20 14:29:18.4242+00', '2015-01-20 14:29:18.4242+00', 'Ganges Gathering, The', 'GANGES GATHERING', 1, 32, 9999, 1, 4, 1, 3618, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15862, '2015-01-20 14:48:14.953882+00', '2015-01-20 14:48:14.953882+00', 'Imperial Topaz, The', 'IMPERIAL TOPAZ', 3, 32, 9999, 1, 4, 2, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15864, '2015-01-20 15:20:56.876296+00', '2015-01-20 15:20:56.876296+00', 'Mabel Abercrombie''s Jig', 'MABEL ABERCROMBIES JIG', 2, 48, 9999, 1, 100, 2, 3618, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15865, '2015-01-20 15:26:25.928192+00', '2018-04-02 23:56:37.163871+00', 'Real Half Reel, The', 'REAL HALF REEL', 1, 32, 9999, 1, 3, 42, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15860, '2015-01-20 14:35:17.471574+00', '2018-04-03 00:07:50.274779+00', 'Gulf Island Reel, The', 'GULF ISLAND REEL', 1, 32, 9999, 1, 3, 42, 3618, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15863, '2015-01-20 14:52:18.834735+00', '2018-04-03 00:07:56.495768+00', 'Joy''s Jig', 'JOYS JIG', 2, 32, 9999, 1, 3, 42, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15850, '2015-01-20 11:07:09.469376+00', '2018-04-03 00:07:57.434555+00', 'King James'' Brogues', 'KING JAMES BROGUES', 3, 32, 9999, 1, 3, 42, 2625, '2004-10-04', 'Music:  Thom''s Highland Fling by David Cunningham on "All Set" CD - TRCD9801', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15838, '2015-01-18 14:58:29.925039+00', '2019-02-26 00:02:24.956011+00', 'Peter''s Jig', 'PETERS JIG', 2, 32, 9999, 1, 4, 1, 1582, '1998-01-01', '', 59, '8000/8088/8880/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13458, '2009-11-17 23:00:00+00', '2020-04-12 21:44:05.438596+00', 'Pitlochry Tryst, The', 'PITLOCHRY TRYST', 3, 32, NULL, 2, 3, 17, 1582, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15832, '2015-01-18 13:51:16.96917+00', '2020-12-30 21:32:18.327883+00', 'Matthew''s Jig', 'MATTHEWS JIG', 2, 32, 9999, 1, 4, 1, 1582, '2000-01-01', '', 59, '8888/8000/6420/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12228, '2005-04-17 22:00:00+00', '2021-01-15 11:54:23.9593+00', 'Fort Langley Hornpipe', 'FORT LANGLEY HORNPIPE', 1, 32, 9999, 1, 4, 1, 80, NULL, 'Music: John Ellis Highland Band - Side 1 - Track 6 - The Fife Hunt Set', 66, '8888/0808/8080/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12206, '2005-04-16 22:00:00+00', '2021-01-15 11:58:47.904022+00', 'Emerald Isle, The', 'EMERALD ISLE', 3, 32, 9999, 1, 3, 42, 80, '2004-01-01', '" AN DANNSA N''EI''REANN"



Inscribed to JUNE & BRIAN McFADDEN from Ulster



Music - Bobby Brown  "Miss Irene Fiddler"', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15867, '2015-01-20 15:55:14.340211+00', '2015-01-20 15:55:14.340211+00', 'St Giles Reel, The', 'SAINT GILES REEL', 1, 32, 9999, 1, 4, 2, 3618, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15868, '2015-01-20 16:06:32.052397+00', '2015-01-20 16:06:32.052397+00', 'Tir Aluinn', 'TIR ALUINN', 3, 80, 9999, 4, 4, 3, 3618, '2010-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15869, '2015-01-20 16:13:41.831772+00', '2015-01-20 16:13:41.831772+00', 'Tucson Twosome, The', 'TUCSON TWOSOME', 3, 32, 9999, 1, 4, 1, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15870, '2015-01-21 09:45:09.182439+00', '2015-01-21 09:45:09.182439+00', 'Margaret''s Wish', 'MARGARETS WISH', 3, 40, 9999, 2, 3, 17, 11048, '2012-04-01', 'Suggested tunes as used for the dance Kurazukuri (Cherry Blossom Time CD by Gordon Shand & his Band)



George Carmichael''s Strathspey - A Cameron

Claymore Strathspey - A Cameron

Nancy Barrowman''s Fancy - M Phillip', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15872, '2015-01-21 10:27:05.972987+00', '2015-01-21 10:27:05.972987+00', 'Square Bashing', 'SQUARE BASHING', 1, 32, 9999, 1, 4, 1, 352, '2007-03-21', 'Suitable Music: Lord McDonald''s Quadrille

Recording: Dances with a Difference 1 - Muriel Johnstone  SICD02', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9441, '2002-08-29 22:00:00+00', '2018-09-30 19:07:04.639083+00', 'Chase', 'CHASE', 1, 32, 9999, 1, 3, 42, 558, '1992-01-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15875, '2015-01-21 13:43:08.718356+00', '2015-01-21 13:43:08.718356+00', 'Honey House, The', 'HONEY HOUSE', 1, 32, 9999, 1, 4, 1, 352, '2010-08-10', 'Suitable Music:  Selection of Reels/Marches

Recording: Celtic Fire in the Music - Bobby Brown BRG024-CD (Tr10 CD#2)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15877, '2015-01-21 14:20:47.845227+00', '2015-01-21 14:20:47.845227+00', 'Guard of Honour', 'GUARD OF HONOUR', 3, 32, 9999, 1, 4, 1, 352, '2010-11-11', 'Suitable Music: The George Washington Bridge Strathspey

Recording: Celtic Fire in the Music - Bobby Brown BRG024-CD  (Tr6 CD#2)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15879, '2015-01-21 15:06:35.305199+00', '2015-01-21 15:06:35.305199+00', 'Rolling Waves', 'ROLLING WAVES', 2, 32, 9999, 1, 4, 5, 352, '2003-09-09', 'Suitable Music: The Moffat Weavers

Recording: The Colin Dewar trio - Special Requests 1   SRCD001', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15881, '2015-01-22 12:04:30.97646+00', '2015-01-22 12:04:30.97646+00', 'Dancing Friends', 'DANCING FRIENDS', 2, 32, 9999, 1, 4, 2, 3694, '2005-10-01', 'Suggested Music The Chocolate Factory recorded by George Meikle and the Lothian Band on CD for the Birmingham Diamond Jubilee Dance Book', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15882, '2015-01-22 12:16:32.537043+00', '2015-01-22 12:16:32.537043+00', 'Shin Kai Tei', 'SHIN KAI TEI', 3, 32, 9999, 2, 3, 17, 3694, '2005-10-01', 'Suggested music Furth O Clyde recorded by George Meikle and the Lothian Band on the CD for thr Birmingham Diamond Jubilee Dance Book', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15885, '2015-01-22 12:39:28.427635+00', '2015-01-22 12:39:28.427635+00', 'Christine''s Wish', 'CHRISTINES WISH', 3, 32, 9999, 1, 4, 1, 3694, '2006-11-01', 'Suggested Music: Montparnasse recorded by George Meikle and the Lothian Band on the CD Reel Friends 3', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15888, '2015-01-22 12:58:56.865761+00', '2015-01-22 12:58:56.865761+00', 'Elizabeth''s Reel', 'ELIZABETHS REEL', 1, 32, 9999, 3, 5, 16, 3694, '2007-01-01', 'Suggested Music: Tak Tent recorded by Sandy Nixon on CD The Luckenbooth Brooch', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15890, '2015-01-22 16:32:11.307085+00', '2015-01-22 16:32:11.307085+00', 'Catherine de Barnes', 'CATHERINE DE BARNES', 3, 96, 9999, 4, 4, NULL, 3694, '2007-06-01', 'Suggested music: Dream catcher recorded by George Meikle and the Lothian Band for RSCDS Book45', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15878, '2015-01-21 14:34:20.174807+00', '2018-04-02 23:56:33.213474+00', 'Broken Link, The', 'BROKEN LINK', 1, 32, 9999, 1, 3, 42, 352, '2010-08-23', 'Suitable Music: Miss Burn''s Reel

Recording: RSCDS Music for Book30', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13450, '2009-11-17 23:00:00+00', '2018-01-13 23:00:31.431494+00', 'Forget Me Knot', 'FORGET ME KNOT', 3, 32, 9999, 2, 3, 17, 10295, '1999-06-01', 'Brian Youngman devised "Forget Me Knot" for his wife Barbara Youngman, who is a dance teacher in North Carolina.   The full description can be found at the URL.



From a Strathspey messages of 11 jan 2011:  

''Forget Me Knot'' was written for me for our 30th Anniversary in 1999. I commissioned Dave Wiesler to write the tune for it to present to Brian at the Silver Thistle Ball in 2003 which landed on our 34th Anniversary. The name of the tune for the dance is ''Our Someday''.      Barbara Youngman

', 48, '800  866  866  806', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15893, '2015-01-29 10:58:38.049861+00', '2018-04-02 23:56:33.69873+00', 'Dance of the Unicorn', 'DANCE OF THE UNICORN', 3, 32, 9999, 1, 3, 42, 3349, '2009-06-23', 'Suggested Music: Where Friends Meet on CD Magic Medicine by Sandy Nixon and his Scottish Dance Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9725, '2002-02-13 23:00:00+00', '2015-01-27 23:22:15.739701+00', 'Saint Valentine''s Day', 'SAINT VALENTINES DAY', 1, 32, 9999, 1, 3, 42, 2827, '1998-01-01', '', 50, '800  888  800  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (15874, '2015-01-21 13:11:34.207505+00', '2018-04-02 23:56:34.483209+00', 'Feijoa and Ginger Jam', 'FEIJOA AND GINGER JAM', 1, 32, 9999, 1, 3, 42, 352, '2006-03-29', 'Suitable Music:  The Hyperactive Reel

Recording: RSCDS - Music for A Second Book of Graded SC Dances CD69 (Track11 on CD#2)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5667, '1997-11-27 23:00:00+00', '2015-01-28 22:50:05.994515+00', 'Rose of Glamis', 'ROSE OF GLAMIS', 4, 64, 5, 4, 4, 28, 108, '1990-01-01', 'For the Queen Mother’s 90th birthday, 1990', 70, '8080  8282  8888  8888    8080  8080  8888  8888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (15873, '2015-01-21 10:41:09.767421+00', '2018-04-02 23:56:37.305635+00', 'Ritchie Rant, The', 'RITCHIE RANT', 3, 32, 9999, 1, 3, 42, 352, '2010-08-20', 'Suitable Music: Lady Peak''s Strathspey

Recording: Special Requests Vol 5 - Colin Dewar   SRCD005', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15876, '2015-01-21 14:10:14.147751+00', '2018-04-02 23:56:37.890145+00', 'Sunday''s Child', 'SUNDAYS CHILD', 1, 32, 9999, 1, 3, 42, 352, '2010-07-05', 'Suitable Music: Memory Lane

Recording: Memory Lane - TAC005CD Tr1', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15883, '2015-01-22 12:24:40.529751+00', '2018-04-02 23:56:38.490938+00', 'Week-end in Ostend, A', 'WEEKEND IN OSTEND', 1, 32, 9999, 1, 3, 42, 3694, '2005-10-01', 'Suggested Music: Miss Murray of Lintrose recorded by Frank Thomson and his SCD Band for RSCDS Book 27', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15894, '2015-01-29 11:04:33.189732+00', '2015-01-29 11:14:38.037584+00', 'TEACHER''S CHOICE: to be selected later', 'TEACHERS CHOICE TO BE SELECTED LATER', 99, 0, NULL, NULL, NULL, NULL, 9998, NULL, 'This is not a real dance, but a "stub" that can be used in making dance lists, to reserve a place where the teacher will later put a dance of his/her choice.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15924, '2015-01-31 17:55:57.901+00', '2015-01-31 17:55:57.901+00', 'Daughter of the Empire, A', 'DAUGHTER OF THE EMPIRE', 2, 32, 9999, 1, 4, 2, 11053, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15871, '2015-01-21 10:13:01.225083+00', '2021-06-17 00:59:44.096094+00', 'Smitten', 'SMITTEN', 1, 32, 9999, 1, 3, 42, 352, '2010-08-09', 'Written for Kayley, who when I introduced her to dancing became "smitten" with the dancing bug.', 56, '800/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15891, '2015-01-27 15:06:27.128651+00', '2020-10-14 11:36:02.579825+00', 'Smiling at Ulrike', 'SMILING AT ULRIKE', 4, 128, 2, 4, 4, 3, 11142, NULL, '', 86, '7777/4444/8888/8888/8888/8888/4444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15889, '2015-01-22 13:08:59.865036+00', '2020-12-30 10:47:37.364168+00', 'Poplar Brides, The', 'POPLAR BRIDES', 2, 32, 9999, 1, 3, 42, 3694, '2007-04-01', 'Suggested Music: Vive La Danse recorded by George Meikle and the Lothian Band on CD Reel Friends 3', 50, '800/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15880, '2015-01-21 15:18:03.352145+00', '2021-06-17 14:22:04.061329+00', 'No Rest for the Wicked', 'NO REST FOR THE WICKED', 1, 32, 9999, 1, 3, 42, 352, '2010-08-20', 'The dance is not difficult but for first couple there really is "No Rest for the Wicked".', 61, '844/844/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15886, '2015-01-22 12:45:26.051891+00', '2021-02-13 10:33:10.318264+00', 'Cyprus Delight', 'CYPRUS DELIGHT', 1, 32, 9999, 1, 3, 42, 3694, '2007-01-01', 'For all the dancers who enjoyed a holiday in Cyprus at the Atlantica Bay Hotel in January 2007 organised by JAG. Instead of Turkish Delight we had to buy Cyprus Delight which came in a great range of flavours.  



Suggested Music: Little Leigh recorded by George Meikle and the Lothian Band on CD Reel Friends 3', 59, '864/888/802/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15899, '2015-01-29 13:00:53.670106+00', '2018-04-02 23:56:38.357269+00', 'Virgo''s Day Out', 'VIRGOS DAY OUT', 2, 32, 9999, 1, 3, 42, 3349, '2009-06-01', 'Suggested music: "The Rover Rant" on CD "Haste Ye Back" by Muriel Johnstone''s Scottish Dance Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15907, '2015-01-29 14:10:11.021882+00', '2018-04-02 23:56:33.230158+00', 'Bubbly Jock', 'BUBBLY JOCK', 1, 32, 9999, 1, 3, 42, 3349, '2009-07-31', 'Suggested music:

"Miss C.M. Barbour" on "In Strict Tempo" by Sandy Nixon and his Scottish Dance Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15900, '2015-01-29 13:12:15.801984+00', '2018-04-02 23:56:34.792523+00', 'Gallant Libra, The', 'GALLANT LIBRA', 2, 32, 9999, 1, 3, 42, 3349, '2009-06-23', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9231, '2002-04-29 22:00:00+00', '2015-01-30 22:04:37.712749+00', 'Coat''s Ceilidh Calypso', 'COATS CEILIDH CALYPSO', 1, 32, 9999, 2, 3, 17, 108, '1997-03-01', 'For Alex Coats of Kenora, who sang a calypso devised in March 1997 at the ceilidh in Winnipeg. 

Many of the dancers at the weekend school received amusing mention in the calypso.



Drewry added these NOTES: 



1. This dance should not be taken too seriously.



2. I nearly gave the dance the alternative title "Coates Crescent" but feared that such a name for a light-hearted dance might upset too many people in high places.', 92, '888/808/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15904, '2015-01-29 13:51:04.311224+00', '2018-04-02 23:56:35.640214+00', 'Katy Da Maty', 'KATY DA MATY', 1, 32, 9999, 1, 3, 42, 3349, '2009-06-25', 'Suggested music.

"All for Mary" on CD "Haste Ye Back" by Muriel Johnstone''s Scottish Dance Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15901, '2015-01-29 13:24:20.576778+00', '2018-04-02 23:56:36.412183+00', 'Miss Scorpio', 'MISS SCORPIO', 2, 32, 9999, 1, 3, 42, 3349, '2009-02-28', 'Suggested music: Shakin'' the Bottle on CD Magic Medicine by Sandy Nixon and his Scottish Dance Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15898, '2015-01-29 12:52:09.862387+00', '2018-04-02 23:56:36.470533+00', 'Morning Rose, The', 'MORNING ROSE', 3, 32, 9999, 1, 3, 42, 3349, '2009-06-07', 'Suggested music: "Campsie Glen" on CD From Scotia''s Shores We''re Noo Awa'' by Bobby Brown and the Scottish Accent', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10975, '2002-11-19 23:00:00+00', '2015-01-31 01:05:46.879843+00', 'Reel Bruce Miller, The', 'REEL BRUCE MILLER', 1, 32, 9999, 1, 3, 42, 3231, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15906, '2015-01-29 14:03:45.696451+00', '2018-04-02 23:56:37.389004+00', 'Rose Brier, The', 'ROSE BRIER', 1, 32, 9999, 1, 3, 42, 3349, '2009-07-10', 'Suggested music:

"Riggs of Corn" on CD "From Scotia''s Shores We''re Noo Awa'' " by Bobby Brown and The Scottish Accent', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7446, '1997-09-07 22:00:00+00', '2015-01-31 01:18:26.132171+00', 'Langlaw Fort', 'LANGLAW FORT', 3, 40, 9999, 4, 5, 35, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10952, '2002-11-14 23:00:00+00', '2015-01-31 01:20:29.000958+00', 'Planxty Plankton', 'PLANXTY PLANKTON', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15902, '2015-01-29 13:34:16.479332+00', '2018-04-02 23:56:37.472472+00', 'Sagittarius Sign, The', 'SAGITTARIUS SIGN', 3, 32, 9999, 1, 3, 42, 3349, '2009-06-01', 'Suggested music:

For All the Ladies on Repeat Prescription by Sandy Nixon and his Band

or

Peggy''s Strathspey on RSCDS Millenium Dances by David Cunningham and his Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15911, '2015-01-31 12:31:41.032986+00', '2015-01-31 12:31:41.032986+00', 'Trip to Croatia, A', 'TRIP TO CROATIA', 4, 128, 2, 1, 4, 2, 10568, '2009-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15895, '2015-01-29 11:30:01.195259+00', '2018-04-02 23:56:38.182122+00', 'Tutor, The', 'TUTOR', 3, 32, 9999, 1, 3, 42, 3349, '2009-06-16', 'Suggested Music: From Scotia''s Shores We''re Noo Awa'' on Album  From Scotia''s Shores We''re Noo Awa'' by Bobby Brown and the Scottish Accent', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8684, '2001-07-30 22:00:00+00', '2015-04-15 09:56:11.200665+00', 'Kuckucksnest', 'KUCKUCKSNEST', 2, 96, 9999, 4, 4, 3, 2113, '1988-01-01', 'The "Other" steps are Stamp and Polka.', 100, '12 times 8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15897, '2015-01-29 12:43:37.116485+00', '2015-06-06 17:23:35.871852+00', 'Glasgow Connection, The', 'GLASGOW CONNECTION', 4, 64, 5, 1, 4, 54, 3349, '2009-06-26', 'Suggested music: 

"Glasgow Assembly" on CD From Scotia''s Shores We''re Noo Awa'' by Bobby Brown and the Scottish Accent ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15896, '2015-01-29 12:29:05.729499+00', '2018-04-02 23:56:38.624479+00', 'Yorkshire Lass, A', 'YORKSHIRE LASS', 3, 32, 9999, 1, 3, 42, 3349, '2009-07-10', 'Suggested music: wells House on Haste Ye Back by Muriel Johnstone''s Scottish Dance Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2212, '2000-06-12 22:00:00+00', '2015-11-01 18:03:50.108374+00', 'Fivesome Reel, The', 'FIVESOME REEL', 1, 96, 9999, 105, 55, 3, 1231, NULL, 'set: Line W W M W W', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (817, '1997-04-03 22:00:00+00', '2018-04-03 00:07:35.82682+00', 'Britannia Strathspey, The', 'BRITANNIA STRATHSPEY', 3, 40, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15918, '2015-01-31 15:17:23.33845+00', '2018-04-03 00:18:02.153998+00', 'English Dance Master, The', 'ENGLISH DANCE MASTER', 3, 32, 9999, 2, 2, 76, 10568, '2010-11-01', 'Music: Susanne''s Strathspey (Vintage Goldring with Muriel Johnstone and Keith Smith SSCD16 track#5)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15916, '2015-01-31 14:42:49.841603+00', '2015-01-31 14:42:49.841603+00', 'With a Flourish', 'WITH A FLOURISH', 3, 32, 9999, 2, 3, 18, 10568, '2010-01-01', 'TAC 2010', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15917, '2015-01-31 14:55:20.697572+00', '2015-01-31 14:55:20.697572+00', 'Sandy''s Solo', 'SANDYS SOLO', 1, 32, 9999, 4, 54, 1, 10568, NULL, 'DEVISED:2010', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15925, '2015-01-31 18:04:27.558458+00', '2018-04-02 23:56:32.652087+00', 'Antler River', 'ANTLER RIVER', 1, 32, 9999, 1, 3, 42, 11053, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15920, '2015-01-31 15:34:55.644341+00', '2015-01-31 15:34:55.644341+00', 'Ninety Years Young', 'NINETY YEARS YOUNG', 2, 32, 9999, 1, 4, 2, 10568, NULL, 'Original Version: 32Jig for four couples in a four couple set (advanced)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15922, '2015-01-31 16:37:13.264642+00', '2015-01-31 16:37:13.264642+00', 'Cuppa Joe', 'CUPPA JOE', 3, 32, 9999, 1, 4, 2, 11051, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15956, '2015-02-01 21:07:02.087111+00', '2018-12-07 18:05:28.706923+00', 'Royal George on the Tay', 'ROYAL GEORGE ON THE TAY', 3, 32, NULL, 1, 3, 42, 10623, '2014-11-08', 'Devised at RSCDS AGM 2014 watching a man in canoe trying to paddle against the current on the Tay.', 66, '880/888/12,12,12/440', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4873, '1997-04-03 22:00:00+00', '2020-08-07 04:42:44.996472+00', 'My Tocher''s the Jewel', 'MY TOCHERS THE JEWEL', 2, 32, 9999, 1, 3, 42, 129, NULL, '', 41, '440/880/444/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10183, '2001-10-23 22:00:00+00', '2020-09-10 18:55:05.148463+00', 'Medley for Margaret', 'MEDLEY FOR MARGARET', 4, 104, 36, 4, 4, 3, 272, NULL, '', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15914, '2015-01-31 14:02:48.02664+00', '2020-12-30 10:28:39.277013+00', 'That Pinewoods!', 'THAT PINEWOODS', 4, 288, 10002, 7, 113, NULL, 10568, '2009-12-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15912, '2015-01-31 12:42:20.777302+00', '2020-12-30 10:33:15.236752+00', 'Catherine Stewart''s Reel', 'CATHERINE STEWARTS REEL', 4, 32, 1, 1, 3, 42, 10568, '2009-12-01', '', 59, '888/840/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15910, '2015-01-31 12:23:24.897657+00', '2020-12-30 10:36:42.868738+00', 'Smiling all the While', 'SMILING ALL THE WHILE', 3, 32, 9999, 1, 3, 42, 10568, '2009-04-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15909, '2015-01-31 12:16:01.476903+00', '2020-12-30 10:41:08.445222+00', 'Montreal Dancer, The', 'MONTREAL DANCER', 2, 32, 9999, 1, 3, 42, 10568, '2009-03-01', '', 44, '505/505/840/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15908, '2015-01-31 12:07:38.093049+00', '2020-12-30 10:43:42.883425+00', 'Carry On Carruthers', 'CARRY ON CARRUTHERS', 3, 32, 9999, 1, 2, 76, 10568, '2009-01-01', '', 69, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8338, '2002-04-08 22:00:00+00', '2021-03-20 19:32:02.934804+00', 'Pete and Marilynn''s Welcome Home', 'PETE AND MARILYNNS WELCOME HOME', 2, 32, 9999, 1, 3, 42, 2677, NULL, '', 50, '800/888/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4799, '2001-03-30 22:00:00+00', '2021-03-26 17:13:42.617599+00', 'Zytglogge', 'ZYTGLOGGE', 1, 32, 9999, 1, 3, 42, 2809, '2000-01-01', 'The Zytglogge is a clock tower in the centre of Berne with clockwork figures which come into life every hour.', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (15913, '2015-01-31 13:42:08.165893+00', '2021-04-13 18:50:08.615451+00', 'Calm Before Storm', 'CALM BEFORE STORM', 3, 32, NULL, 1, 3, 42, 10648, NULL, 'This is a strathspey version of the reel <<ddd:East Neuk Storm>>', 66, '880/888/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1607, '1997-06-30 22:00:00+00', '2021-06-16 06:48:23.160277+00', 'Deeside Lilt, The', 'DEESIDE LILT', 7, 128, 9999, 107, 1, NULL, 319, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15926, '2015-01-31 18:13:45.966123+00', '2015-01-31 18:13:45.966123+00', 'At the Forks of the Thames', 'AT THE FORKS OF THE THAMES', 2, 64, 9999, 6, 3, 17, 2927, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12071, '2005-02-27 23:00:00+00', '2022-08-18 08:55:50.494627+00', 'Orcadian Strip the Willow', 'ORCADIAN STRIP THE WILLOW', 2, 16, 9999, 103, 98, 8, 9998, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15923, '2015-01-31 16:50:27.977245+00', '2019-07-05 21:21:23.614777+00', 'Holly''s Hobby', 'HOLLYS HOBBY', 2, 32, 9999, 1, 3, 42, 11052, '2010-12-01', 'For Holly Boyd to honour a special birthday, December 2010.', 63, '888/844/484/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15921, '2015-01-31 16:08:34.086906+00', '2019-07-05 21:42:29.663841+00', 'Busy Mary', 'BUSY MARY', 1, 32, 9999, 1, 3, 42, 10568, '2011-02-01', '', 75, '888/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15933, '2015-02-01 09:02:52.175953+00', '2015-02-01 09:02:52.175953+00', 'London Trillium', 'LONDON TRILLIUM', 3, 32, 9999, 6, 3, 18, 2927, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15934, '2015-02-01 09:24:03.739985+00', '2015-02-01 09:24:03.739985+00', 'McLennan Saturday Night', 'MACLENNAN SATURDAY NIGHT', 1, 48, 9999, 1, 4, 1, 11058, NULL, 'Suitable tunes: The Solvay Reel; the Distillery Reel (Colin Dewar)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15935, '2015-02-01 09:32:52.001883+00', '2015-02-01 09:32:52.001883+00', 'Peonies in the Forest', 'PEONIES IN THE FOREST', 2, 40, 9999, 4, 4, 4, 11055, '2007-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15937, '2015-02-01 10:10:57.883496+00', '2015-02-01 10:10:57.883496+00', 'Strathspey for Sandra', 'STRATHSPEY FOR SANDRA', 3, 96, 9999, 4, 4, 3, 11055, '2007-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15939, '2015-02-01 10:51:49.659137+00', '2015-02-01 10:51:49.659137+00', 'Welcome Back, Elfriede!', 'WELCOME BACK ELFRIEDE', 1, 32, 9999, 5, 56, 30, 2927, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15940, '2015-02-01 10:57:57.020745+00', '2015-02-01 10:57:57.020745+00', 'We''re 50', 'WERE 50', 3, 32, 9999, 1, 4, 2, 11053, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14388, '2011-12-29 23:00:00+00', '2015-02-01 12:17:13.049526+00', 'Eternal Friendship', 'ETERNAL FRIENDSHIP', 1, 32, NULL, 1, 4, 2, 10595, '2010-12-01', '', 69, '4004  8008  4224  8228  8888', 0, 0, 0, 0, 68);
INSERT INTO 'dance' VALUES (15942, '2015-02-01 12:37:00.17631+00', '2015-02-01 12:37:00.17631+00', 'Lilly''s Celtic Knots', 'LILLYS CELTIC KNOTS', 3, 32, 9999, 4, 4, 13, 10595, '2007-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15944, '2015-02-01 12:57:45.782597+00', '2015-02-01 12:57:45.782597+00', 'Malcolm''s Princess Bride', 'MALCOLMS PRINCESS BRIDE', 3, 32, 9999, 1, 4, 2, 10595, '2009-07-18', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15947, '2015-02-01 13:45:38.670619+00', '2015-02-01 13:45:38.670619+00', 'Duncan Dubh', 'DUNCAN DUBH', 3, 32, 9999, 2, 3, 17, 10595, '1990-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15948, '2015-02-01 13:55:19.242559+00', '2015-02-01 13:55:19.242559+00', 'Goodnight Margaret', 'GOODNIGHT MARGARET', 4, 128, 10020, 4, 4, 1, 10595, '2010-08-06', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15954, '2015-02-01 14:37:08.715362+00', '2015-02-01 14:54:47.10242+00', 'Five Times Through, Thank You Bobby', 'FIVE TIMES THROUGH THANK YOU BOBBY', 1, 32, 9999, 3, 5, 7, 10595, '2011-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15927, '2015-01-31 18:23:29.141063+00', '2018-04-02 23:56:33.364115+00', 'Carmichaels of Coldstream', 'CARMICHAELS OF COLDSTREAM', 1, 40, 9999, 1, 3, 42, 2927, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15929, '2015-02-01 00:38:23.878433+00', '2015-02-01 20:49:34.866688+00', 'Caledonian Sleeper, The', 'CALEDONIAN SLEEPER', 1, 32, NULL, 1, 3, 42, 10623, NULL, '', 47, '822/888/880/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15928, '2015-01-31 18:34:53.399091+00', '2018-04-02 23:56:33.623562+00', 'Creegan''s Jig', 'CREEGANS JIG', 2, 32, 9999, 1, 3, 42, 11054, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15943, '2015-02-01 12:49:16.050019+00', '2018-04-02 23:56:34.032726+00', 'Duffer''s Dilemma', 'DUFFERS DILEMMA', 2, 32, 9999, 1, 3, 42, 10595, '2007-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15949, '2015-02-01 14:02:27.632937+00', '2018-04-02 23:56:34.066052+00', 'Dundee Gold', 'DUNDEE GOLD', 1, 32, 9999, 1, 3, 42, 10595, '2010-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15946, '2015-02-01 13:18:05.030332+00', '2018-04-02 23:56:34.074386+00', 'Dundee Wheeler, The', 'DUNDEE WHEELER', 1, 32, 9999, 1, 3, 42, 10595, '2005-09-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15950, '2015-02-01 14:07:17.620234+00', '2018-04-02 23:56:34.091157+00', 'Durham Dram, A', 'DURHAM DRAM', 2, 32, 9999, 1, 3, 42, 10595, '2005-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15952, '2015-02-01 14:23:46.812739+00', '2018-04-02 23:56:34.550174+00', 'First Footer, The', 'FIRST FOOTER', 2, 32, 9999, 1, 3, 42, 10595, '2006-12-25', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15931, '2015-02-01 08:40:53.81844+00', '2018-04-02 23:56:34.859311+00', 'George Emmerson Rant', 'GEORGE EMMERSON RANT', 2, 40, 9999, 1, 3, 42, 737, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15932, '2015-02-01 08:54:04.599079+00', '2018-04-02 23:56:35.90307+00', 'Life with Linda', 'LIFE WITH LINDA', 1, 32, 9999, 1, 3, 42, 11056, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15919, '2015-01-31 15:26:01.762175+00', '2018-04-02 23:56:36.704492+00', 'Ninety Years Young', 'NINETY YEARS YOUNG', 2, 32, 9999, 1, 3, 42, 10568, NULL, 'Easier Version for three couples in a longwise set', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15941, '2015-02-01 12:12:10.611741+00', '2018-04-02 23:56:37.263798+00', 'Retiring Chairman, The', 'RETIRING CHAIRMAN', 2, 40, 9999, 1, 3, 42, 10595, '2011-04-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15953, '2015-02-01 14:28:12.498527+00', '2018-04-02 23:56:37.981984+00', 'That''s the Ticket', 'THATS THE TICKET', 1, 32, 9999, 1, 3, 42, 10595, '2009-04-26', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15945, '2015-02-01 13:08:35.910292+00', '2018-04-02 23:56:38.215421+00', 'Twa Bettys', 'TWA BETTYS', 3, 32, 9999, 1, 3, 42, 10595, '2006-03-26', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15938, '2015-02-01 10:16:46.204009+00', '2018-04-02 23:56:38.382349+00', 'Warbler Woods', 'WARBLER WOODS', 2, 32, 9999, 1, 3, 42, 11055, '2008-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10664, '2002-07-21 22:00:00+00', '2018-04-03 00:07:36.903041+00', 'Captain Jimmy''s Jig', 'CAPTAIN JIMMYS JIG', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1042, '1997-08-31 22:00:00+00', '2018-04-03 00:07:37.078526+00', 'Carnival of the Animals, The', 'CARNIVAL OF THE ANIMALS', 2, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6644, '1998-01-05 23:00:00+00', '2016-03-18 20:17:19.514014+00', 'Tommy Ford''s Fancy', 'TOMMY FORDS FANCY', 1, 32, 9999, 1, 3, 42, 108, '1971-01-01', '', 62, '888/808/844/888/', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9050, '2002-10-28 23:00:00+00', '2015-02-02 00:44:14.84126+00', 'Dodgems and Waltzers', 'DODGEMS AND WALTZERS', 2, 32, 9999, 1, 3, 42, 635, '1993-01-01', 'This dance was devised for T Ticia Clark after she made me go on the waltzers after the dodgems at the Lammas Fair in St Andrews in 1993.', 56, '808/888/822/848', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14244, '2011-08-29 22:00:00+00', '2017-06-08 20:51:54.995581+00', 'Trip Around Salt Spring, A', 'TRIP AROUND SALT SPRING', 1, 40, 9999, 2, 3, 18, 10476, '2009-06-14', '', 80, '888  888  808  484  844', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (16019, '2015-02-09 17:07:24.277654+00', '2018-04-02 23:56:32.505509+00', 'Across the Rimutakas', 'ACROSS THE RIMUTAKAS', 2, 32, 9999, 1, 3, 42, 11073, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15964, '2015-02-03 17:57:40.240451+00', '2016-09-26 10:45:39.712367+00', 'She''s a Fine Wee Lass', 'SHES A FINE WEE LASS', 2, 32, 9999, 1, 3, 42, 2904, NULL, '', 53, '880/808/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (109, '2000-05-04 22:00:00+00', '2020-09-07 14:18:25.489561+00', 'Alltshellach', 'ALLTSHELLACH', 3, 32, 9999, 1, 2, 76, 143, NULL, '##>>

*The Dictionary of Scottish Place Names and the elements that go to make them up* gives:  

Allt (also ‘uillt’): a stream; burn or brook  

-shellach (as a suffix): anglicised form of ‘seilach’, a willow tree



No example has been found in any gazetteer of a stream or burn of this name. The only well-known use of the name other than the dance is Alltshellach House in Onich, near Fort William. This was built in the 1850s as the residence of the Episcopal Bishop of Argyll and the Isles and is now a well-known hotel.

##<<', 69, '88  88  88  88', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (15960, '2015-02-03 16:59:31.611472+00', '2020-12-06 00:19:43.954365+00', 'East Lothian Flourish', 'EAST LOTHIAN FLOURISH', 1, 40, 9999, 1, 4, 1, 11059, '2012-01-01', 'Devised by Sheila Chambers for the 60th anniversary of RSCDS in East Lothian in 2012.', 75, '8682/6828/4804/4884/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (162, '1997-04-03 22:00:00+00', '2020-12-27 19:06:12.140705+00', 'Annan Welcome', 'ANNAN WELCOME', 2, 32, 9999, 1, 3, 42, 212, NULL, '', 47, '844/800/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10012, '2001-10-23 22:00:00+00', '2021-02-13 15:44:01.366049+00', 'Apple Tea', 'APPLE TEA', 3, 32, 9999, 2, 3, 17, 108, '2000-01-01', '', 92, '888/888/888/088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15936, '2015-02-01 09:41:47.694746+00', '2021-06-06 13:37:38.441971+00', 'Still Young at Heart', 'STILL YOUNG AT HEART', 1, 48, 9999, 1, 3, 42, 11057, '2010-03-06', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15951, '2015-02-01 14:18:50.162578+00', '2021-08-10 16:59:23.95529+00', 'Sir Barry Pipes', 'SIR BARRY PIPES', 1, 32, 9999, 1, 3, 42, 10595, '2006-05-17', 'Barry Pipes wrote a series of articles for the Toronto RSCDS branch newsletter "Set and Link" under the title "What''s in a Name?". These have now been collected into a PDF booklet which is available at <<https://www.dancescottish.ca/books_files/What%27s%20In%20A%20Name%20canon.pdf>>.', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15962, '2015-02-03 17:30:00.4142+00', '2015-02-03 17:30:00.4142+00', 'Tantallon Castle', 'TANTALLON CASTLE', 1, 64, 9999, 4, 4, 1, 2889, '2008-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15967, '2015-02-03 18:31:48.517204+00', '2019-04-22 19:39:51.376671+00', 'Spring Fling', 'SPRING FLING', 2, 32, 9999, 1, 3, 42, 2889, NULL, '', 56, '880/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16014, '2015-02-09 14:41:39.788203+00', '2019-05-27 09:52:48.021104+00', 'At The Bottom Of The Garden', 'AT THE BOTTOM OF THE GARDEN', 1, 32, 9999, 1, 3, 42, 44, '1999-03-17', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15955, '2015-02-01 14:43:53.059337+00', '2022-08-14 11:51:31.246385+00', 'Alliston Ambler, The', 'ALLISTON AMBLER', 1, 32, 9999, 5, 2, 30, 10595, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16015, '2015-02-09 14:49:15.648397+00', '2019-05-27 09:56:32.795374+00', 'Come, Play Us A Tune', 'COME PLAY US A TUNE', 2, 32, 9999, 1, 3, 42, 44, NULL, 'DIVISED:2004', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16020, '2015-02-09 17:14:06.598157+00', '2015-02-09 17:14:06.598157+00', 'Little Bit More to the Left, A', 'LITTLE BIT MORE TO THE LEFT', 3, 32, 9999, 1, 4, 1, 11074, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16004, '2015-02-08 16:57:52.195655+00', '2015-02-08 16:57:52.195655+00', 'Continental, The', 'CONTINENTAL', 2, 32, 9999, 1, 4, 11, 703, '2012-03-23', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15966, '2015-02-03 18:17:58.239869+00', '2018-04-02 23:56:36.211819+00', 'Martha''s Legacy', 'MARTHAS LEGACY', 1, 32, 9999, 1, 3, 42, 2904, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16012, '2015-02-09 14:01:12.75381+00', '2018-04-02 23:56:36.804684+00', 'On the Incoming Tide', 'ON THE INCOMING TIDE', 2, 32, 9999, 1, 3, 42, 44, '2003-06-27', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16021, '2015-02-09 17:22:03.344735+00', '2018-04-02 23:56:37.29722+00', 'Rimutaka Incline', 'RIMUTAKA INCLINE', 1, 32, 9999, 1, 3, 42, 11075, '2005-10-01', 'Suggested music: Wedderburn''s Reel or Anderson''s Rant', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16016, '2015-02-09 14:58:03.46862+00', '2018-04-02 23:56:38.4324+00', 'Way Out of the Woods, The', 'WAY OUT OF THE WOODS', 3, 32, 9999, 1, 3, 42, 44, '1987-10-12', 'modified January 1991', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16022, '2015-02-09 17:36:57.026257+00', '2015-02-09 17:36:57.026257+00', 'Twiddle for Michael, A', 'TWIDDLE FOR MICHAEL', 3, 48, 9999, 2, 3, 17, 11073, NULL, 'Suggested music: Robert Whitehead & Danelaw Country Dance Band "Strictly Scottish Vol1 Track 6"', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16024, '2015-02-09 18:04:37.756467+00', '2015-02-09 18:04:37.756467+00', 'Mrs Sarah Wilson''s Strathspey', 'MRS SARAH WILSONS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 689, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15957, '2015-02-01 21:25:37.60192+00', '2015-09-05 21:18:58.466069+00', 'Macnab''s Fancy', 'MACNABS FANCY', 2, 32, NULL, 1, 3, 42, 10623, NULL, 'Devised in appreciation of the warm welcome given to Toronto dancers who visit the “White Cockade Social Group” Hamilton  Ontario  held at MacNab Presbyterian Church.', 57, '888/840/880/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16018, '2015-02-09 15:41:16.494185+00', '2017-01-30 22:51:41.657225+00', 'Grandma''s Mandolin', 'GRANDMAS MANDOLIN', 3, 32, 9999, 1, 3, 42, 2932, NULL, '', 50, '880/800/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16017, '2015-02-09 15:24:26.422387+00', '2017-01-30 22:53:15.509088+00', 'Wye Oak Reel, The', 'WYE OAK REEL', 1, 80, 9999, 4, 4, 3, 11072, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15983, '2015-02-06 13:48:15.858677+00', '2018-04-02 23:56:33.564899+00', 'Common Sense', 'COMMON SENSE', 2, 32, 9999, 1, 3, 42, 703, '2009-09-22', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15987, '2015-02-06 14:25:49.326323+00', '2018-04-02 23:56:35.159999+00', 'Highland Road, The', 'HIGHLAND ROAD', 1, 32, 9999, 1, 3, 42, 703, '2010-07-31', 'Devised for Rochelle Altholz of Richmond, Virginia on July 31, 20l0for her monumental

birthday, the tour of Scotland and its celebration at the RSCDS 2010 Summer School in St. Andrews.

Rochelle loved dancing so much that she brought her daughter, Zoe, to class a few months after

starting and they have never looked back.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15969, '2015-02-05 12:21:24.369951+00', '2015-02-05 12:21:24.369951+00', 'Auf Wiedersehen, Susanne!', 'AUF WIEDERSEHEN SUSANNE', 2, 48, 9999, 1, 4, 1, 11062, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15971, '2015-02-05 12:44:57.552937+00', '2015-02-05 12:44:57.552937+00', 'Toast to Tina', 'TOAST TO TINA', 3, 32, 9999, 2, 3, NULL, 11064, NULL, 'DEVISED:2009', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15975, '2015-02-05 13:33:27.392407+00', '2018-04-02 23:56:35.323102+00', 'I R I S - "The Four-Letter-Dance"', 'I R I S  THE FOURLETTERDANCE', 3, 32, 9999, 1, 3, 42, 11068, NULL, 'Devised by Rita Reil in 2012 to celebrate a special birthday of Iris Müller from the Pfaffenhofen dance group, who often takes part in Munich dance events. Daniela Kneidl, another member of the Pfaffenhofen group, came up with the name.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15974, '2015-02-05 13:21:51.455035+00', '2015-02-05 13:25:00.737926+00', 'From Munich to Vienna', 'FROM MUNICH TO VIENNA', 1, 40, 9999, 1, 4, 1, 671, NULL, 'DEVISED:2010', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15989, '2015-02-06 14:55:18.447237+00', '2018-04-02 23:56:35.786097+00', 'Lade Braes Walk', 'LADE BRAES WALK', 2, 32, 9999, 1, 3, 42, 703, '2010-07-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15999, '2015-02-06 17:25:09.454887+00', '2018-04-02 23:56:38.165417+00', 'Turn S Reel, The', 'TURN S REEL', 1, 32, 9999, 1, 3, 42, 703, '2012-10-08', 'Devised for Ellen Ternes of the Maryland/Pennsylvania area for her birthday on October 8,

2012. With lots of energy and zeal for dancing, with just a hint of flirting, the dance represents

"M-hat she brings to the dance floor. Happy Birthday!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15973, '2015-02-05 13:11:37.50942+00', '2018-04-03 00:07:54.452587+00', 'Ismaning Cabbage', 'ISMANING CABBAGE', 2, 32, 9999, 1, 3, 42, 11066, NULL, 'DEVISED:2010', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15976, '2015-02-06 09:39:51.943864+00', '2015-02-06 09:39:51.943864+00', 'Dish Ran Away with the Spoon', 'DISH RAN AWAY WITH THE SPOON', 2, 32, NULL, 1, 2, NULL, 108, '1998-01-01', 'Leaflet	1998



This is a stub entry.  Information source: A catalogue of Drewry dances supplied by Jean Martin, feb. 2015

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15977, '2015-02-06 09:43:34.146834+00', '2015-02-06 09:43:46.455926+00', 'Dix-On Dix-Off', 'DIXON DIXOFF', 1, 48, NULL, 1, 3, 42, 108, '2003-01-01', 'Leaflet	2003



This is a stub entry.  Information source: A catalogue of Drewry dances supplied by Jean Martin, feb. 2015

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12916, '2006-10-19 22:00:00+00', '2020-04-12 21:28:10.954597+00', 'Cary Cemeteries, The', 'CARY CEMETERIES', 3, 32, 9999, 1, 3, 42, 3583, '2006-02-01', 'for Barbara Youngman, who baked delicious fly cemeteries (currant slices) from her grandmother’s recipe to serve at the Afters-Party for the Cary Valentine’s Dance in 2006', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15, '2001-11-22 23:00:00+00', '2020-05-01 07:36:01.698061+00', 'Abernethy Lassies', 'ABERNETHY LASSIES', 1, 32, 9999, 1, 2, 76, 9998, NULL, 'From *Scotland Dances*, by Jeannie Callander Sharp:



Abernethy is a small town about eight miles southeast of Perth,

not far from the place where the river Earn flows into the Tay

on its way to the sea. Its importance in early Scottish history is,

no doubt, due to its location, so close to navigable water.

The Romans were there and so were the Picts, who made it

one of their capitals. Next came the religious. First, at the end

of the 8th century, the Culdees, the “Friends of God”, an Anchorite

order, came from Ireland to settle at Abernethy as well as at

St. Andrews, Monymusk, Brechin, Dornoch, Bute, and on St. Serf''s Island

in Loch Leven. Filled with good works and fanatical thoughts of

independence from Rome, they practiced their primitive Christianity

for several centuries until they gradually became less pure and more

worldly and, after having been chastised by the sainted Queen Margaret,

they faded completely out of Scottish history by the beginning of the

15th century. Next came the Augustinians who took over St Bridget''s

Monastery and that was the end of the “Friends of God” in Abernethy.



The Pictish round tower still dominates the village as it did from the

8th century onwards when it served as a belfry and a refuge in time

of danger. While fairly common in Ireland, there are only two other

such towers in Scotland: one at Brechin in Angus and the other in

Orkney, at Egilsay, the “church isle”.



In 1072 another great historical event occurred at Abernethy.

The ships of William the Conqueror came up the River Tay

to meet William and his invading army and Malcolm III, the fierce

Malcolm Canmore or “Big Head”, hastened to Abernethy to treat

with the Conqueror. There, Malcolm submitted to William''s demands

to become his vassal and his son, later Duncan II, was taken to the

Norman-English court as a hostage. Seven years later Malcolm

broke the so-called Treaty of Abernethy and the fighting resumed

along the ill-defined Border, leaving Duncan to fend for himself

in England.', 52, '80  88  80  88', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (18284, '2018-04-18 21:15:11.289511+00', '2020-09-22 15:36:41.686959+00', 'New Dutchess, The', 'NEW DUTCHESS', 3, 32, NULL, 1, 100, 2, 11232, '2017-12-16', 'For Margaret Lambourne on the occasion of her 70th birthday on 16th December 2017.  The name of the dance was inspired by her obtaining her Dutch citizenship earlier in the year.



The pattern of the dance reflects the differences between the UK and continental Europe, and can be interpreted in several ways: moving from one side of the Channel to the other; driving on the right or the left side of the road; switching between the native language and the language of the new country, etc.', 87, '8888/8448/8448/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9840, '2001-05-20 22:00:00+00', '2021-02-18 11:30:30.225801+00', 'Argyll Delight', 'ARGYLL DELIGHT', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 53, '844/844/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16013, '2015-02-09 14:32:27.196398+00', '2021-06-06 19:29:37.356244+00', 'By The Light Of The Moon', 'BY THE LIGHT OF THE MOON', 1, 32, 9999, 1, 3, 42, 44, '1999-04-12', 'Given to Jeanette Watson and Peter Beaumont.', 50, '800/844/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15979, '2015-02-06 09:53:04.804407+00', '2015-02-06 09:53:04.804407+00', 'Roy''s Reel', 'ROYS REEL', 1, 32, NULL, 1, 4, NULL, 108, '2007-01-01', 'Leaflet	2007



This is a stub entry.  Information source: A catalogue of Drewry dances supplied by Jean Martin, feb. 2015



', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10247, '2001-11-25 23:00:00+00', '2018-10-06 08:41:16.59044+00', 'Lovely Hall, A', 'LOVELY HALL', 3, 32, 9999, 1, 3, 42, 2766, '2001-01-01', 'This dance is named for how Mady Newfield describes the Baker Center in St. Charles, Illinois, where the Silk and Thistle class hold their annual Frolic on the Fox.', 53, '800/844/866/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15978, '2015-02-06 09:48:15.477628+00', '2019-02-09 13:40:33.184847+00', 'Muckle-Fiddle Plucker, The', 'MUCKLEFIDDLE PLUCKER', 2, 32, NULL, 1, 3, 42, 108, '1979-01-01', 'For John Sinton who plays the bass in Jim Macleod''s Band at Dunblane Hydro



', 63, '800/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15996, '2015-02-06 16:53:32.847398+00', '2016-09-06 20:32:22.287958+00', 'Spring Equinox', 'SPRING EQUINOX', 1, 32, 9999, 2, 3, 17, 703, '2010-03-21', 'Devised/or Melissa Ramsey Drumeller, formerly of Richmond, Virginia in March 2010 to celebrate her 30th birthday, which happens to be on March 21, the first full day a/Spring', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16041, '2015-02-11 15:45:49.061037+00', '2016-12-12 20:54:29.07594+00', 'Bristol''s Welcome', 'BRISTOLS WELCOME', 1, 40, 9999, 4, 4, 4, 3694, '2010-05-01', '', 90, '8888/6666/8888/6666/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1466, '1999-08-09 22:00:00+00', '2018-04-03 00:07:40.396785+00', 'Cuckoo''s Nest, The', 'CUCKOOS NEST', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 31, '800/800/800/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15982, '2015-02-06 13:39:57.488478+00', '2016-09-06 20:06:11.113996+00', 'Come and Follow Me', 'COME AND FOLLOW ME', 2, 32, 9999, 2, 3, 17, 703, '2004-06-01', 'Devised for Pat Pennington of Little Rock, Arkansas in June, 2004 by Sandy Gallamore. Pat has exuberance and joy for dancing that cannot be compared. During the candidate class at Thistle School 2003, Pat was always in the background making sure that everything went along, as if she was dancing along in the shadows. This is a subtle appreciation for a woman who doesn''t like the spotlight, but enjoys the dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15995, '2015-02-06 16:44:35.990442+00', '2016-09-06 20:30:50.451337+00', 'Shepherdess, The', 'SHEPHERDESS', 3, 32, 9999, 2, 3, 17, 703, '2009-02-18', 'Devised for Laurel Hayward of Richmond, Virginia in honour of a significant birthday on

February 18, 2009. Laurel has a passion for all types of dancing and shares her joy on the dance

floor. Recently, her new found joy is her German Shepherd, Ozzy, whom she loves to take around

town and show off. Thus, she is the Shep', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15994, '2015-02-06 16:32:33.07748+00', '2017-02-09 17:03:53.374917+00', 'Rose of Greenock, The', 'ROSE OF GREENOCK', 3, 32, 9999, 2, 3, 17, 703, '2004-08-01', 'Devised for Rose Snow, originally of Greenock, Scotland and now living in Jackson, MS in

August, 2004. I knew of Rose''s name for years on the Atlanta branch membership list, but didn''t

meet until candidate class at Thistle in 2003. And to think of all the years missed knowing a fun

dancer!', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15993, '2015-02-06 16:23:31.85147+00', '2016-09-06 20:34:30.431657+00', 'Renaissance Woman, The', 'RENAISSANCE WOMAN', 3, 32, 9999, 2, 3, 18, 703, '2007-10-01', 'Devised for Trish Nunley of Richmond, Virginia in October, 2007. Trish started Scottish

country dancing in 2000 but loves all genres, from German to Flamenco. The title describes her

diverse interests in life and the dance expresses her passion for dance, dancing with others, and the

Poussette.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16000, '2015-02-06 17:34:00.125651+00', '2016-09-06 20:37:31.40344+00', 'Two Fiddle Jig, The', 'TWO FIDDLE JIG', 2, 32, 9999, 1, 4, 1, 703, '2007-01-01', 'Devised for Debbie Morris and Nora Garver in January, 2007. Debbie and Nora live in the

Winston-Salem area and are avid fiddlers. When the two are together, they make lovely music,

either behind the music stands or on the dance floor. They are a delight to have in the Southeast!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15980, '2015-02-06 13:17:36.593912+00', '2016-09-06 20:59:06.141204+00', 'Amaidi Bheag', 'AMAIDI BHEAG', 1, 32, 9999, 1, 2, NULL, 703, '2006-09-01', 'Devised for An Phillips o/Greensboro, North Carolina in September, 2006. An is a true Gaelic enthusiast and an avid dancer. The title translates to "sweet nothings" which describes her playful dancing!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15981, '2015-02-06 13:25:59.301247+00', '2016-09-23 20:14:20.139681+00', 'Black Mountain Delight', 'BLACK MOUNTAIN DELIGHT', 4, 32, 1, 1, 3, 42, 703, '2000-08-01', 'Devised for Peter and Laurie Knight in August, 2000 for their engagement. They met in Black Mountain, North Carolina and it was love at first sight. Last reported, happiness still continues!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15970, '2015-02-05 12:31:58.811803+00', '2017-06-09 16:50:40.455529+00', 'MM60', 'MM60', 1, 32, 9999, 5, 2, NULL, 11063, NULL, 'Devised by Lilo Cresswell in 2004 to celebrate the 60th birthday of Michael Müller', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16026, '2015-02-10 12:23:14.952192+00', '2015-02-10 12:33:17.250872+00', 'Fuddling Cup, The', 'FUDDLING CUP', 2, 32, 9999, 6, 118, 18, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16028, '2015-02-11 12:19:58.320892+00', '2018-06-03 05:22:52.789596+00', 'Margaret Wilson''s Hornpipe', 'MARGARET WILSONS HORNPIPE', 1, 32, 9999, 1, 3, 42, 3694, '2012-07-17', 'A Hornpipe for three couples in a four couple set.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16037, '2015-02-11 15:11:08.37477+00', '2018-04-02 23:56:32.966713+00', 'Belwell Jig, The', 'BELWELL JIG', 2, 32, 9999, 1, 3, 42, 3694, '2009-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16042, '2015-02-11 15:54:28.472978+00', '2018-04-02 23:56:33.970198+00', 'Dodman Point', 'DODMAN POINT', 1, 32, 9999, 1, 3, 42, 3694, '2008-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12848, '2006-09-12 22:00:00+00', '2015-02-11 02:14:47.502044+00', 'Ecclefechan Feline', 'ECCLEFECHAN FELINE', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', 50, '800  888  800  888', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (16029, '2015-02-11 12:28:29.172716+00', '2018-06-03 05:57:25.206255+00', 'Maggie and Johnny''s Reel', 'MAGGIE AND JOHNNYS REEL', 1, 32, 9999, 1, 100, 1, 3694, '2012-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16036, '2015-02-11 13:31:55.945206+00', '2018-08-07 08:32:07.558444+00', 'Romantic Ruin, The', 'ROMANTIC RUIN', 3, 32, 9999, 1, 4, 2, 3694, NULL, 'The romantic ruin is the old bridge which used to lead into Warwick Castle but when a new road and bridge were built further up the river it fell into disrepair hence the name.', 94, '8448/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16032, '2015-02-11 12:54:16.447975+00', '2018-08-06 16:00:36.185133+00', 'Gold Rings to Rubies', 'GOLD RINGS TO RUBIES', 2, 32, 9999, 1, 3, 42, 3694, '2012-03-01', 'For Chris and Sheila Spiller in celebration of their ruby wedding anniversary in March 2012', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16035, '2015-02-11 13:22:55.719641+00', '2018-08-07 18:57:32.07823+00', 'Moonbeams Kiss the Sea', 'MOONBEAMS KISS THE SEA', 3, 48, 9999, 2, 3, 17, 3694, NULL, 'The dance was inspired by a quote from a poem by Shelley. “And sunlight clasps the earth and moonbeams kiss the sea, what are all these kisses if thou kissed not me”', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8692, '2002-04-23 22:00:00+00', '2018-09-30 23:37:03.851875+00', 'Munsters', 'MUNSTERS', 2, 32, 9999, 4, 4, 13, 558, '1995-01-01', '', 69, '4444/4444/6666/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16039, '2015-02-11 15:27:51.475846+00', '2015-02-11 15:27:51.475846+00', 'Get a Wriggle on', 'GET A WRIGGLE ON', 2, 32, 9999, 1, 4, 1, 3694, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16043, '2015-02-11 16:24:32.469189+00', '2015-02-11 16:24:32.469189+00', 'Retiring Doctor, The', 'RETIRING DOCTOR', 1, 96, 9999, 4, 4, 3, 3694, '2008-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14582, '2012-10-02 09:40:57.564264+00', '2015-02-12 23:46:32.546354+00', 'Axum Tribute', 'AXUM TRIBUTE', 3, 32, NULL, 1, 4, 11, 1415, NULL, '', 94, '8008/8888/8888/4884', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18791, '2018-10-05 14:41:22.468079+00', '2018-10-05 20:37:47.281109+00', 'Dancing in the Streets', 'DANCING IN THE STREETS', 1, 32, NULL, 1, 2, 76, 227, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13025, '2006-11-01 23:00:00+00', '2015-02-13 00:59:36.457025+00', 'Round Tower of Abernethy, The', 'ROUND TOWER OF ABERNETHY', 4, 128, 13, 4, 4, NULL, 619, NULL, 'See <<ddd:Abernethy Lassies>> for background information on Abernethy.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (463, '1997-08-28 22:00:00+00', '2020-08-02 23:20:10.062558+00', 'Belle of the Ball', 'BELLE OF THE BALL', 2, 96, 9999, 1, 4, 3, 685, NULL, '', 67, '8000/8220/8860/4004/0880/8888/8888/8008/8888/0880/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16034, '2015-02-11 13:13:51.512673+00', '2016-04-17 14:34:54.622599+00', 'Mermaid''s Choice, The', 'MERMAIDS CHOICE', 3, 32, 9999, 1, 3, 42, 3694, NULL, 'Crib derived from video.', 69, '888/484/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16038, '2015-02-11 15:20:47.689236+00', '2018-04-02 23:56:36.963189+00', 'Patricia''s Happy Returns', 'PATRICIAS HAPPY RETURNS', 2, 32, 9999, 1, 3, 42, 3694, '2011-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13757, '2011-07-12 22:00:00+00', '2018-04-03 00:07:37.796162+00', 'Central Park', 'CENTRAL PARK', 2, 32, NULL, 1, 3, 42, 2973, '2008-12-01', 'Devised in December 2008. 



The figure on bars 9 to 16 first appeared – as far as I know – in The Peat Fire Flame in The Bon Accord Book, by John Drewry (1968). It can be quite a flirty figure, so I sometimes call it ―set and flirt‖. The whole dance is quite flirty, actually, as 1st couple can maintain eye contact almost throughout. Central Park seemed a fitting name for such a dance - one often sees young couples in Central Park having wedding photos taken.



Music

Any good jig. A suitable recording is ''Jean‘s Jig'', on the Silver Thistle Collection, David Cunningham and his Scottish Dance Band, track 1.', 56, '840  822  888  888', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (16030, '2015-02-11 12:41:20.753371+00', '2022-01-01 06:31:42.118194+00', 'Tricycle Reel, The', 'TRICYCLE REEL', 1, 32, 9999, 3, 5, 7, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15023, '2013-08-01 20:08:18.69765+00', '2022-04-26 15:00:48.950102+00', 'Janet''s Cup of Tea', 'JANETS CUP OF TEA', 3, 32, 9999, 1, 100, 11, 515, '2010-05-01', 'This dance is inscribed for Janet Johnston who does like a good cup of tea!', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11356, '2003-06-11 22:00:00+00', '2018-04-03 00:07:41.007793+00', 'Dance Then Wherever You May Be', 'DANCE THEN WHEREVER YOU MAY BE', 2, 32, 9999, 1, 3, 42, 1185, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7377, '2002-11-26 23:00:00+00', '2018-04-03 00:07:41.041132+00', 'Dancie''s Delight', 'DANCIES DELIGHT', 4, 32, 1, 1, 3, 42, 2792, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10105, '2001-10-04 22:00:00+00', '2018-04-03 00:07:41.199607+00', 'Dancing On', 'DANCING ON', 1, 32, 9999, 1, 3, 42, 146, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1611, '1997-04-03 22:00:00+00', '2018-04-03 00:07:41.725111+00', 'Delaney''s Drummers', 'DELANEYS DRUMMERS', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7670, '1998-04-21 22:00:00+00', '2019-05-27 09:55:05.725621+00', 'Dancing On The Ramparts', 'DANCING ON THE RAMPARTS', 1, 48, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16045, '2015-02-13 09:35:45.417911+00', '2015-02-13 09:39:12.450651+00', 'Deja 10 Ans', 'DEJA 10 ANS', 4, 64, 2, 4, 4, NULL, 11066, '2013-11-01', '', 81, '8484 8080 8888 8888 4848 0808 8888 8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13909, '2011-08-22 22:00:00+00', '2018-04-19 12:34:37.588789+00', 'Friends For Reel', 'FRIENDS FOR REEL', 1, 32, NULL, 1, 3, 42, 64, '2005-08-01', 'Devised by Irene van Maarseveen, Pretoria, August 2005.  



In honour of Malcolm and Helen Brown. with best wishes from the Pretoria Branch of the RSCDS where friends are made for reel.  



Note:  

The square reel of six forms a Ceftic knotwork pattern. Each dancer reels the whole way round the square. 1st couple dance round each of their 4 corner positions in turn moving anticlockwise round the set, passing corners alternately by the right shoulder and the left shoulder. Between each pair of ½ reels, 1st couple should pass partner closely in the middle of the set i.e. not finish in the line of the reels except at the end of bar 32.', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16048, '2015-02-13 13:28:46.995814+00', '2015-02-13 13:28:46.995814+00', 'Great Auk, The', 'GREAT AUK', 4, 160, 10, 4, 4, 3, 3694, NULL, 'Suggested music: Stepping Hill on the Vallin Suite Four CD by Colin Dewar', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13906, '2011-08-22 22:00:00+00', '2018-04-19 18:32:07.36152+00', 'Faradh nam Fidhlearan', 'FARADH NAM FIDHLEARAN', 1, 32, NULL, 1, 4, 2, 3179, '2007-01-01', 'Devised by Wouter Joubert, Pretoria. Finalised in 2007.  



The dance was devised in honour of Keith Smith, Fiddler extraordinaire.  



The Gaelic title is translated in the tune title and is pronounced: far-aghh nam fee-lar-an.', 75, '8008/8888/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11228, '2003-03-09 23:00:00+00', '2015-02-13 17:43:23.092099+00', 'Romance at Raddery', 'ROMANCE AT RADDERY', 1, 40, 9999, 1, 4, 1, 3312, NULL, '', 43, '8000/8220/8002/8000/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16053, '2015-02-14 00:35:50.356502+00', '2015-10-30 16:26:34.645187+00', 'Dandelion Picker, The', 'DANDELION PICKER', 1, 32, NULL, 1, 3, 42, 21, NULL, 'Entry derived from Minicrib 25-02.



At a dance in Perth on 2012-10-23 Ian stated it was written for Evelyn Wake.

', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14962, '2013-07-03 18:37:15.790261+00', '2015-02-13 17:58:18.619582+00', 'Catching Helen', 'CATCHING HELEN', 1, 32, NULL, 1, 3, 42, 10800, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15665, '2014-10-19 15:54:22.350411+00', '2015-02-13 20:01:07.267079+00', 'Curry and Spice', 'CURRY AND SPICE', 2, 32, NULL, 1, 3, 42, 11028, '2014-01-01', 'Govin is well known for his cooking of Curry and Spice dishes', 50, '844/844/844/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1981, '1997-04-03 22:00:00+00', '2018-04-03 00:07:44.527575+00', 'Enchanted Castle, The', 'ENCHANTED CASTLE', 1, 32, 9999, 1, 3, 42, 44, '1974-03-17', 'Devised on Saturday 17th March, 1974. The title was suggested by a book of Irish fairy tales Noeline had been given for her previous birthday.



Suitable recorded music is Peter White''s "The Garple Burn".



Recommended tune "R. D. Hunter ''s Reel" composed by Peter White.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16023, '2015-02-09 17:50:03.338921+00', '2015-02-15 12:16:18.627545+00', 'Standing Stones, The', 'STANDING STONES', 1, 32, 9999, 4, 4, 13, 11073, '2005-01-01', 'Stonehenge Aotearoa east of Carterton is a brillant open-sky observatory, built on the same scale as Stonehenge on Salisbury Plain, but more detailed as it combines modern science with ancient knowledge.



Suggested music: "The Standing Stones" by Chris Duncan

                          Recorded by Jim McLeod and his Band - Gay Gordons, 3rd tune.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16059, '2015-02-14 14:17:50.645237+00', '2018-04-02 23:56:37.906836+00', 'Sunrise on Craig Bay', 'SUNRISE ON CRAIG BAY', 3, 32, 9999, 1, 3, 42, 80, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16107, '2015-02-22 22:35:50.753554+00', '2015-02-23 21:25:02.698308+00', 'Copper Beech Tree, The', 'COPPER BEECH TREE', 2, 32, NULL, 1, 3, 42, 2623, NULL, '', 50, '888/800/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9459, '2002-04-28 22:00:00+00', '2021-02-24 10:02:49.147578+00', 'Copycat Suite - Prelude', 'COPYCAT SUITE  PRELUDE', 2, 32, 9999, 1, 3, 42, 108, '2000-01-01', 'For the first 16 bars, 1st man copies his partner''s path 2 bars behind.', 46, '700/800/888/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11891, '2004-11-04 23:00:00+00', '2021-07-30 08:12:39.093369+00', 'Sparks Fly', 'SPARKS FLY', 2, 32, 9999, 1, 3, 42, 308, '2004-01-01', '', 63, '888/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13756, '2011-07-11 22:00:00+00', '2015-02-14 02:14:41.490733+00', 'Piping with the Highlanders', 'PIPING WITH THE HIGHLANDERS', 1, 32, 9999, 2, 3, 17, 2625, '2003-01-01', 'Devised: 2003-01

Published in The Leeds Branch Newsletter, Issue 31, August 2003 (http://www.rscdsleeds.org.uk/newsletters.htm).  



The introduction reads: Graeme Baranyai has piped for the Knaresborough Class since its inception.  On the 10th July he played solo for The Tewit Band''s performance of "Highland Cathedral" in a national competition at The Festival Hall, where they came 2nd in their class.   We devised this for him as an eighteenth birthday present at the beginning of the year.   Ann Baranyai & Malcolm Fros



There is a Note: Bars 9-16 require considerable flight. In particular, the 1st lady should be starting to cross up between the 2nd couple at the end of bar 12 so that she does not impede her partner who has to be in 2nd place, in the middle of the set on bar 16, with sufficient time to adjust his balance to start the poussette', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16058, '2015-02-14 13:51:01.179917+00', '2018-03-05 19:53:47.817051+00', 'S-Cool Master', 'SCOOL MASTER', 2, 40, 9999, 1, 3, 42, 3783, NULL, 'For Kazuo Murata, who was schoolmaster for many years.



Mr Murata was the schoolmaster of a public high school in Chiba prefecture. He often invited dancers to his school and showed Scottish Country Dances to his students.



S-Cool rhymes with school. "S" in the title of this dance means "slip", because he often slips in a

very cool way while dancing.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15037, '2013-08-02 19:18:28.060665+00', '2019-02-26 17:36:48.985951+00', 'Jacqui Watson''s Strathspey', 'JACQUI WATSONS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 10820, NULL, '', 100, '888/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13479, '2009-11-20 23:00:00+00', '2015-02-14 13:24:29.421001+00', 'Pink Panda''s Picnic', 'PINK PANDAS PICNIC', 2, 32, 9999, 1, 100, 2, 3783, NULL, '', 81, '8008  8888  8888  8448', 0, 0, 0, 0, 81);
INSERT INTO 'dance' VALUES (13477, '2009-11-20 23:00:00+00', '2015-02-14 13:36:20.568706+00', 'Spring in Shinjuku', 'SPRING IN SHINJUKU', 3, 32, 9999, 3, 5, 7, 3783, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18605, '2018-09-15 20:31:34.18003+00', '2018-09-15 20:31:36.777159+00', 'Bow farm Fiddlers'' Reel, The', 'BOW FARM FIDDLERS REEL', 1, 32, NULL, 1, 3, 42, 10799, '2012-01-01', 'For The Fiddlers: Marion Stirling, John Platt', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13487, '2009-11-20 23:00:00+00', '2018-04-02 23:56:32.978728+00', 'Better Half, The', 'BETTER HALF', 1, 32, 9999, 1, 3, 42, 3783, '2007-10-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16046, '2015-02-13 10:22:58.282788+00', '2017-02-09 23:06:50.807815+00', 'Lyon Rosette', 'LYON ROSETTE', 2, 32, NULL, 1, 3, 42, 154, '2015-01-01', '', 47, '800 880 844 866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16056, '2015-02-14 13:27:40.840519+00', '2023-01-22 19:52:46.603356+00', 'Kirkcudbright Castle', 'KIRKCUDBRIGHT CASTLE', 3, 32, NULL, 2, 3, 18, 635, NULL, '', 75, '800/888/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1643, '1998-04-08 22:00:00+00', '2023-02-10 15:12:15.084096+00', 'Diamond Celebration, The', 'DIAMOND CELEBRATION', 2, 32, 9999, 1, 3, 42, 771, '1990-01-01', 'Devised to celebrate the 60th birthday of his wife, Diana.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16047, '2015-02-13 13:02:27.579054+00', '2018-04-02 23:56:34.917662+00', 'Golden Beaches, The', 'GOLDEN BEACHES', 1, 32, 9999, 1, 3, 42, 3694, '2008-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16083, '2015-02-20 17:18:54.544794+00', '2018-04-02 23:56:35.621165+00', 'Justin''s Jig', 'JUSTINS JIG', 2, 32, 9999, 1, 3, 42, 3554, '2010-04-01', 'Justin is Maggie and Doug''s first Grandson born Feb 2009', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16050, '2015-02-13 13:40:46.02178+00', '2018-04-02 23:56:38.148774+00', 'Troon Wedding, The', 'TROON WEDDING', 3, 32, 9999, 1, 3, 42, 3694, '2011-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13083, '2006-11-10 23:00:00+00', '2019-01-24 13:29:27.828052+00', 'Dancing Girls', 'DANCING GIRLS', 2, 32, 9999, 1, 3, 42, 884, '2006-01-01', 'A dance for my wife, Christine and daughters, Michelle and Helen.', 56, '844/844/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16055, '2015-02-14 03:34:46.864015+00', '2019-02-26 00:01:03.411652+00', 'Four Cities', 'FOUR CITIES', 1, 64, NULL, 1, 4, 1, 635, '2014-07-01', 'This dance is 4 times 64 bars, but the repeats are not identical: for bars 9-16 and 41-48, each of the dancing couples has its own two formations.  



Specified: 4 very different Tunes.', 59, '8000/8880/8660/8880/8000/8044/8444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5555, '1998-09-29 22:00:00+00', '2015-02-14 14:18:49.655768+00', 'Reverend John MacFarlane, The', 'REVEREND JOHN MACFARLANE', 1, 32, 9999, 1, 4, 1, 275, '1990-01-01', 'This dance commemorates the 150th anniversary of the founding in Wellington of New Zealand''s first Scots Church, later known as St. Andrews.', 66, '8880  8004  8008  8888', 0, 1, 1, 0, 65);
INSERT INTO 'dance' VALUES (16061, '2015-02-14 15:13:51.722432+00', '2018-03-31 18:32:30.194295+00', 'Brodick Castle', 'BRODICK CASTLE', 2, 32, NULL, 5, 56, 4, 635, NULL, 'For warming up: steps: 3 times walking – 3 times running', 94, '888/888/666/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5296, '1998-11-12 23:00:00+00', '2016-09-04 20:43:14.923179+00', 'Plantation Reel, The', 'PLANTATION REEL', 1, 32, 9999, 3, 5, 7, 636, NULL, 'Dedicated to Andrew Rankine for his contributions to Scottish Country Dancing.', 72, '80800/88880/88888/84844', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (16065, '2015-02-14 18:01:25.332574+00', '2018-04-02 23:56:35.719132+00', 'Kingussie Rant', 'KINGUSSIE RANT', 1, 40, 9999, 1, 3, 42, 815, '2007-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16131, '2015-02-27 11:29:36.43308+00', '2015-02-27 11:29:36.43308+00', 'Kelso Ladies'' Punchbowl', 'KELSO LADIES PUNCHBOWL', 2, 48, 9999, 1, 4, 1, 3528, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15308, '2013-12-19 10:42:50.727222+00', '2018-07-18 17:31:34.230683+00', 'May''s 100', 'MAYS 100', 2, 32, 9999, 1, 3, 42, 884, '2011-04-11', 'For Mrs May Brown on the occasion of her 100th birthday, 22 April 2011.



Sadly. May subsequently died peacefully on 14 June 2011.  May was a life member of the RSCDS Western Australia Branch and the deviser of several dances, including the McCulloch Strathspey published as a leaflet by the RSCDS in 1966', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16063, '2015-02-14 16:40:50.299753+00', '2015-02-14 16:40:50.299753+00', 'Qualicum Bairns Hornpipe, The', 'QUALICUM BAIRNS HORNPIPE', 1, 32, 9999, 1, 4, 1, 80, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18606, '2018-09-15 20:34:03.156248+00', '2019-07-24 09:32:01.907139+00', 'John & Ruth''s Ruby Wedding', 'JOHN AND RUTHS RUBY WEDDING', 3, 80, NULL, 4, 4, 3, 10799, '2016-11-01', 'To mark the occasion of John & Ruth''s Ruby Wedding', 90, '8888/8080/0808/8888/8888/8888/8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16066, '2015-02-14 18:09:57.649207+00', '2015-02-14 18:09:57.649207+00', 'John and J''ina Celebrate 40 Years', 'JOHN AND JINA CELEBRATE 40 YEARS', 3, 32, 9999, 2, 3, 17, 11081, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15670, '2014-10-19 16:27:13.34996+00', '2015-02-15 07:47:28.618819+00', 'Morrisons'' Fancy', 'MORRISONS FANCY', 3, 88, NULL, 4, 4, 3, 11029, NULL, 'The dance was inspired by dancing in the home of John and Jenita Morrison whose lounge room has a wooden floor and a large bow window the width of the room.  Hence the square set which will sit well within the bowed end of the room.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4943, '1997-08-25 22:00:00+00', '2018-04-02 23:56:36.646103+00', 'Newcastleton Reel, The', 'NEWCASTLETON REEL', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 50, '800  888  800  888', 0, 0, 0, 0, 66);
INSERT INTO 'dance' VALUES (16132, '2015-02-27 11:53:10.465661+00', '2015-02-27 11:53:10.465661+00', 'Marmion Strathspey', 'MARMION STRATHSPEY', 3, 32, 9999, 2, 3, 17, 11106, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8334, '2002-12-07 23:00:00+00', '2015-02-15 08:31:47.731499+00', 'It''s Not Rocket Science', 'ITS NOT ROCKET SCIENCE', 2, 32, 9999, 1, 3, 42, 2872, NULL, 'This dance was written for the Scottish dancers of Bryn Mawr and Haverford Colleges. It

takes its name from the phrase made (in)famous by Carleta McCain, the teacher of that class.', 56, '880/880/808/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16064, '2015-02-14 17:49:32.684437+00', '2018-04-02 23:56:36.696264+00', 'Nine Glens of Antrim, The', 'NINE GLENS OF ANTRIM', 2, 32, 9999, 1, 3, 42, 80, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16068, '2015-02-15 08:46:57.120491+00', '2015-02-15 08:53:23.466403+00', 'Friends Awa''', 'FRIENDS AWA', 1, 32, NULL, 1, 3, 42, 74, '2009-07-01', 'Dance devised by Brian Charlton, July 2009, for Anne Welsh on her return to Canada after twelve months in Sydney visiting her daughter and family. Caringbah Club members were delighted to have her dance with them on Friday evening', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16062, '2015-02-14 15:27:44.48272+00', '2016-07-15 12:54:10.879272+00', 'Welcome to Vladimir', 'WELCOME TO VLADIMIR', 11, 32, NULL, 5, 2, 76, 635, NULL, '', 100, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16067, '2015-02-15 08:16:54.109036+00', '2015-02-17 11:29:47.731123+00', 'Auld Lang Syne to Anne', 'AULD LANG SYNE TO ANNE', 1, 32, NULL, 1, 4, 1, 1049, '2014-09-01', 'Dance devised for Anne Goudriaan  on her retirement after 17 years of teaching the Delft Branch of the RSCDS, September 2014

', 61, '8008/0880/8888/8222', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1982, '1997-08-26 22:00:00+00', '2021-06-11 20:40:33.718802+00', 'Enchanted Garden, The', 'ENCHANTED GARDEN', 3, 32, 9999, 1, 3, 42, 44, '1986-01-01', '', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (16105, '2015-02-21 18:16:54.500818+00', '2015-02-21 18:16:54.500818+00', 'New Galloway Reel', 'NEW GALLOWAY REEL', 1, 32, 9999, 1, 4, 1, 11092, NULL, 'Devised by Tony Lambert and dedicated to his mother, Elsie Lambert, who loved the Galloway district of Scotland.



Suitable recorded music:

"Burns Hornpipe" by Muriel Johnstone and Keith Smith on Delaware Valley - Live from the Spring Ball 2003, Track 7.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16168, '2015-03-17 14:05:00.690895+00', '2018-04-03 00:07:29.749053+00', 'After th'' Exam Was Over', 'AFTER TH EXAM WAS OVER', 1, 32, NULL, 1, 3, 42, 3694, '2012-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16108, '2015-02-22 22:54:04.246691+00', '2015-02-22 23:21:44.445153+00', 'Stephen''s Web', 'STEPHENS WEB', 3, 40, NULL, 2, 3, 17, 11094, '2014-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12759, '2006-05-21 22:00:00+00', '2018-08-20 10:14:24.319367+00', 'Chairman''s Strathspey, The', 'CHAIRMANS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3682, NULL, 'For Derek Cochrane who had the (rnis)fortune of being Chairman in our 80th year.', 50, '800/844/448/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16127, '2015-02-26 14:42:38.976664+00', '2015-02-26 14:42:38.976664+00', 'Walkers of Avonlea, The', 'WALKERS OF AVONLEA', 3, 32, 9999, 1, 4, 1, 553, '2003-01-01', 'This dance was devised by Heather Knox in 2003, to celebrate the joint 60th Birthdays of Jim and Elspeth Walker. Sadly, Jim died shortly before his birthday and Elspeth now wishes that his dance be published in his memory and as tribute to Jim.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16130, '2015-02-27 11:00:41.199076+00', '2015-02-27 11:00:41.199076+00', 'Mrs McKinven''s Strathspey', 'MRS MACKINVENS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 11105, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16134, '2015-02-27 12:21:56.283381+00', '2015-02-27 12:21:56.283381+00', 'Valleys and Rivers of Ettrick and Yarrow', 'VALLEYS AND RIVERS OF ETTRICK AND YARROW', 2, 40, 9999, 1, 4, 1, 11107, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16135, '2015-02-27 12:42:56.319799+00', '2015-02-27 12:42:56.319799+00', 'Sundays at Gattonside', 'SUNDAYS AT GATTONSIDE', 3, 32, 9999, 2, 3, 17, 11108, '2002-03-01', 'Devised by Preliminary Teacher''s Certificate Class 2002 to celebrate their class held in Gattonside Village Hall October 2001 - March 2002.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16076, '2015-02-20 14:48:02.709915+00', '2018-04-02 23:56:35.894703+00', 'Lieutenant Hadley''s Hornpipe', 'LIEUTENANT HADLEYS HORNPIPE', 1, 32, 9999, 1, 3, 42, 11083, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16077, '2015-02-20 14:52:23.330691+00', '2018-04-02 23:56:36.261935+00', 'Meeting House Jig, The', 'MEETING HOUSE JIG', 2, 40, 9999, 1, 3, 42, 11083, NULL, 'Devised in honor of the Friends Meeting of Eugene, Oregon.

We danced at their house for many years.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16071, '2015-02-17 14:45:20.414355+00', '2018-04-02 23:56:36.453904+00', 'More than a Spring Fling', 'MORE THAN A SPRING FLING', 1, 32, NULL, 1, 3, 42, 3342, '2010-01-01', 'DEVISED:2010



Authors'' dedication: “For Zsuzsa and Zsolt on the occasion of their wedding in Budapest, 3 April 2010. They met at a Spring Fling in Glasgow, which turned out to be more than just that!”', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2956, '2001-09-13 22:00:00+00', '2019-01-27 20:05:27.270059+00', 'Hollin Buss, The', 'HOLLIN BUSS', 2, 32, 9999, 1, 2, 76, 9998, NULL, 'The Pilling diagram in the 8th edition is in error, see the supplement to the 8th edition for the correct one.', 56, '88  88  80  84', 0, 1, 1, 0, 81);
INSERT INTO 'dance' VALUES (250, '1998-01-05 23:00:00+00', '2019-09-20 19:39:10.248707+00', 'Glenalmond Gamekeeper, The', 'GLENALMOND GAMEKEEPER', 1, 40, 9999, 1, 3, 42, 108, '1995-01-01', '', 60, '888  808  880  888  880', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (10920, '2002-11-12 23:00:00+00', '2015-02-18 21:38:17.517644+00', 'Scott Meikle', 'SCOTT MEIKLE', 1, 32, 9999, 1, 4, 1, 2673, NULL, 'The Pilling diagram in the 8th edition is in error, see the supplement to the 8th edition for the correct one.', 56, '8000  8080  8888  8008', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (16079, '2015-02-20 15:21:26.705487+00', '2018-04-02 23:56:36.846454+00', 'Our Tutor, John', 'OUR TUTOR JOHN', 3, 32, 9999, 1, 3, 42, 3599, '2010-01-25', 'Suggested music: "Braes O''Forbes" on "Celtic Fire in the Musik" by Bobby Broen', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16073, '2015-02-20 14:27:14.406804+00', '2015-02-20 14:27:14.406804+00', 'Home Is Where Your Heart Is', 'HOME IS WHERE YOUR HEART IS', 3, 32, 9999, 1, 4, 1, 11082, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16074, '2015-02-20 14:32:22.553152+00', '2018-04-02 23:56:37.564213+00', 'Shamrock Shores', 'SHAMROCK SHORES', 1, 32, 9999, 1, 3, 42, 11082, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16078, '2015-02-20 15:10:58.823321+00', '2015-02-20 15:10:58.823321+00', 'Mountains of Mourne, The', 'MOUNTAINS OF MOURNE', 3, 32, 9999, 1, 4, 1, 80, '2007-03-17', 'Inscribed to: June & Brian McFadden from Ulster', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6964, '2002-10-10 22:00:00+00', '2015-02-21 01:16:00.370248+00', 'Silver Strathspey, The', 'SILVER STRATHSPEY', 3, 32, 9999, 1, 3, 42, 370, '1989-01-01', 'The Pilling diagram in the 8th edition is in error, see the supplement to the 8th edition for the correct one.', 62, '844  888  844  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (16080, '2015-02-20 16:44:32.917015+00', '2015-02-20 16:44:32.917015+00', 'Bonnie Annetta Morrison', 'BONNIE ANNETTA MORRISON', 2, 32, 9999, 2, 3, 17, 11084, NULL, 'Devised by Mary Rose Young for the wedding celebration of Annetta Morrison and Blake Golder.



Music used - Bonnie Anne', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16081, '2015-02-20 16:56:44.784047+00', '2015-02-20 16:56:44.784047+00', 'Cutting the Diamond', 'CUTTING THE DIAMOND', 1, 32, 9999, 1, 4, 2, 11084, NULL, 'Devised by Mary Rose Young to reinforce petronella movement for inexperienced dancers.

Music used - Jimmy Shand Junior and Band



A set of reels  Allistair of the Den, Highland Donald, The Hopeful Lover', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16082, '2015-02-20 17:06:47.967867+00', '2015-02-20 17:06:47.967867+00', 'February Frolic', 'FEBRUARY FROLIC', 2, 40, 9999, 7, 113, 4, 11084, NULL, 'Devised by Mary Rose Young for a group of aviation students, only one of whom had done S.C.D. before.



Music used: The Macadians Band   Anne Fraser McKenzie, My Own Lass, Leaving Port Askaig', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16095, '2015-02-21 14:44:52.778843+00', '2015-02-21 14:44:52.778843+00', 'Sophia''s Charm', 'SOPHIAS CHARM', 2, 32, 9999, 2, 3, 17, 1269, '2012-12-01', 'Suggested music:

Frank Reid - Just for You, Chippy''s Rant', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16096, '2015-02-21 14:55:28.745832+00', '2015-02-21 14:55:28.745832+00', 'Shona''s Fancy', 'SHONAS FANCY', 1, 32, 9999, 2, 3, 17, 1269, NULL, 'Suggested music:

Bobby Frew - HISCD, Smashing Set of Reels



NOTE

This dance can be danced in four couple set. 

On bars 25-32 fourth couple follow third couple.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16097, '2015-02-21 15:25:11.557435+00', '2015-02-21 15:25:11.557435+00', 'Ardbrae Friendships', 'ARDBRAE FRIENDSHIPS', 3, 32, 9999, 1, 4, 1, 11087, NULL, 'Devised by Gary MacLean and dedicated to the many friendships which have developed over 50 years of the Ardbrae Dancers of Ottawa. The enjoyment of Scottish Country Dancing has and will continue to bring together many of us who otherwise may never have met.



Suitable recorded music:

"Mr. Yasumuro''s Strathspey" by Bill Clement on "Dance to the Piper", Track 4', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16070, '2015-02-16 21:37:05.593875+00', '2020-10-14 22:06:26.874069+00', 'Hurlingham Quadrangle, The', 'HURLINGHAM QUADRANGLE', 4, 128, 2, 4, 4, 54, 218, NULL, '', 88, '8888/8080/0808/8888/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11771, '2004-09-02 22:00:00+00', '2021-01-20 10:18:14.484551+00', 'Cocket Hat, The', 'COCKET HAT', 2, 40, 9999, 1, 3, 42, 2789, NULL, 'The Pilling diagram in the 8th edition is in error, see the supplement to the 8th edition for the correct one.', 60, '800  888  866  866  888', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (2080, '1998-01-05 23:00:00+00', '2018-04-03 00:07:45.178265+00', 'Farewell the Bonnie Banks of Ayr', 'FAREWELL THE BONNIE BANKS OF AYR', 1, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15930, '2015-02-01 08:29:54.651592+00', '2018-04-03 00:07:45.320097+00', 'Farmer''s Strathspey', 'FARMERS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 11055, '2007-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16084, '2015-02-20 17:43:02.561354+00', '2015-02-20 17:43:02.561354+00', 'River Tay Strathspey, The', 'RIVER TAY STRATHSPEY', 3, 32, 9999, 3, 5, 16, 11085, '2010-11-01', 'Suggested music: Anita''s Dance by George Meikle and the Lothian Dance Band from The Royal Scottish Country Dance Society (Birmingham) Diamond Jubilee Dance Book 1946-2006, or any good 5x32 Strathspey.



The River Tay (Gaelic name Tatha), a famous Salmon River, flows down from the Highlands through Strathtay in the centre of Scotland and on through Perth in the Firth of Tay, south of Dundee. It is the longest river in Scotland with five different names. It begins as the River Connonish, then becomes the River Fillan, then the River Dochart, after which it flows into Loch Tay, then emerges from Loch Tay to become the River Tay.



The five couples reflect the five different names of the river. The Rondels signify the river flowing under the many bridges. The six hands round and back symbolizes Loch Tay, and the mirror wending suggest the very long heanderring river as it flows from the Highlands southward to its final destination.



The dance was inspired by a picture in one of Duncan MacKenzie''s newsletters.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16085, '2015-02-20 17:58:14.363418+00', '2015-02-20 17:58:14.363418+00', 'Lass frae Baie D''Urfé, The', 'LASS FRAE BAIE DURFE', 2, 32, 9999, 1, 102, 2, 3554, '2003-02-01', 'Devised by Doug Kean in honour of Barbara Morrison reaching a significant birthday.



Suggested lead tune: Fete Champetre (The Teddy Bears Picnic)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18607, '2018-09-15 20:37:04.687915+00', '2018-09-15 20:37:19.039713+00', 'Quarter Day Bairn, The', 'QUARTER DAY BAIRN', 3, 32, NULL, 1, 4, NULL, 10799, NULL, 'To commemorate John Platt''s Birthday on the First Quarter Day, 80 Years ago', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16086, '2015-02-20 18:08:06.972154+00', '2018-04-02 23:56:34.50001+00', 'Fiddler''s Wife, The', 'FIDDLERS WIFE', 3, 32, 9999, 1, 3, 42, 740, '2009-01-01', 'The Minister kissed the fiddler''s wife, An'' could na preach for thinkin'' o''t.

Robert Burns - My Love she''s but a Lassie yet', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18608, '2018-09-15 20:41:53.280221+00', '2018-09-15 20:43:28.773796+00', 'Woodturner, The', 'WOODTURNER', 3, 32, NULL, 1, 4, 2, 10799, NULL, 'For Raymond Watson to celebrate his 65th Birthday', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16090, '2015-02-21 13:58:17.504498+00', '2015-11-01 18:15:19.921542+00', 'Windsor Medley, The', 'WINDSOR MEDLEY', 4, 48, 10033, 99, 55, 3, 11086, '2013-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16101, '2015-02-21 17:14:42.684544+00', '2018-04-02 23:56:35.660666+00', 'Keep It Going', 'KEEP IT GOING', 2, 32, 9999, 1, 3, 42, 11089, NULL, 'Suitable recorded music:

"Lassies of Dunse" by Bobby Brown and the Scottish Accent on Ready...And!, Track 6', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16104, '2015-02-21 17:57:08.661269+00', '2018-04-02 23:56:36.583878+00', 'Munro of Glengarry', 'MUNRO OF GLENGARRY', 1, 32, 9999, 1, 3, 42, 11091, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (750, '1997-08-31 22:00:00+00', '2019-09-14 20:37:54.451658+00', 'Braes of Glenshiel, The', 'BRAES OF GLENSHIEL', 3, 32, 9999, 1, 3, 42, 28, NULL, '', 56, '800/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16075, '2015-02-20 14:39:22.379466+00', '2022-04-28 09:10:23.116011+00', 'Hidden Valley', 'HIDDEN VALLEY', 3, 32, 9999, 2, 3, 17, 11083, NULL, 'Hidden Valley is a lovely, quiet box canyon in California''s Joshua Tree National Park', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1758, '2002-01-06 23:00:00+00', '2015-02-21 00:32:57.12309+00', 'Drumelzier', 'DRUMELZIER', 3, 32, 9999, 1, 4, 1, 33, NULL, 'Drumelzier (pronounced Drum-ell-yer) is a small village in Peeblesshire and the reputed burial

place of Merlin the Wiz.ard of Arthurian Legend.



Confusion seems to arise over the correct spelling of the name of the village as some signposts

show Drummelzier but here the more common version has been used.', 87, '8888  8888  4444  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (8158, '2002-02-16 23:00:00+00', '2015-02-21 00:54:21.715667+00', 'Suzuki Circle, The', 'SUZUKI CIRCLE', 1, 40, 9999, 7, 113, 54, 9998, NULL, '', 90, '8  4  8  8  8', 0, 1, 1, 0, 90);
INSERT INTO 'dance' VALUES (15689, '2014-11-02 21:13:40.269156+00', '2015-02-21 13:02:32.880993+00', 'It''s Not a Slip Jig', 'ITS NOT A SLIP JIG', 1, 32, NULL, 1, 4, 2, 3593, '2003-12-31', 'For Edna MacKinnon who broke her ankle while playing golf in December 2003.   Muriel wrote the tune, so the dance just had to be.   On being presented with the tune Edna’s comment was “it should be a slip jig” hence the title ', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16088, '2015-02-21 13:38:45.904005+00', '2015-02-21 13:38:45.904005+00', 'Windsor Chase, The', 'WINDSOR CHASE', 2, 32, 9999, 2, 3, NULL, 11086, '2010-10-01', 'Suggested music:

Bobby Brown and the Scottish Accent - Celtic Fire in the Music (disc 1), #10 - Selection of Jigs', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16087, '2015-02-21 13:31:46.874968+00', '2018-04-02 23:56:38.616089+00', 'Windsor Ladies, The', 'WINDSOR LADIES', 2, 32, 9999, 1, 3, 42, 11086, '2008-01-01', 'Suggested music:

Bobby Brown and the Scottish Accent - Celtic Fire in the Music (disc 2), #11 - Set of Jigs', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16091, '2015-02-21 14:14:28.69906+00', '2015-02-21 14:14:28.69906+00', 'Meet You at the Forks', 'MEET YOU AT THE FORKS', 2, 32, 9999, 2, 3, 17, 1269, '2012-10-01', 'Suggested music:

The Music Makars - Jig for Joy, #7 - The Dancing Master', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16092, '2015-02-21 14:22:02.130115+00', '2015-02-21 14:22:02.130115+00', 'Windsor Knot, The', 'WINDSOR KNOT', 1, 32, 9999, 4, 55, 16, 11086, '2013-01-01', 'Suggested music:

Bobby Brown and the Scottish Accent - Any Good Dance Any Good Tuns, #3 - Selection of Reels', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16093, '2015-02-21 14:28:51.914456+00', '2015-02-21 14:28:51.914456+00', 'Windsor Threesome, The', 'WINDSOR THREESOME', 2, 32, 9999, 6, 53, 17, 1269, '2012-10-01', 'Suggested music:

Green Ginger - Miss Orgilvie''s Fancy, #11 - 3x32 Jigs', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16812, '2015-10-28 19:52:40.807836+00', '2015-10-28 19:52:40.807836+00', 'Spinning Jenny, The', 'SPINNING JENNY', 1, 48, NULL, 1, 4, NULL, 2419, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11773, '2004-09-02 22:00:00+00', '2020-09-15 08:33:18.052931+00', 'Festival Fling', 'FESTIVAL FLING', 1, 32, 9999, 1, 3, 42, 94, '1998-01-01', 'The Pilling diagram in the 8th edition is in error, see the supplement to the 8th edition for the correct one.', 41, '800  466  866  800', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (6104, '2001-10-30 23:00:00+00', '2020-12-17 22:27:15.751972+00', 'Singing Sands, The', 'SINGING SANDS', 3, 32, 9999, 2, 3, 17, 313, NULL, 'The Pilling diagram in the 8th edition is in error, see the supplement to the 8th edition for the correct one.



For Diana and Bill Dagnall on their leaving Sutton Coldfield.



The dry white sands on the north-west side of the Isle of Eigg are said to produce a musical sound when walked upon.', 75, '880  844  844  888', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (15443, '2014-05-09 22:37:11.492646+00', '2021-08-10 18:53:11.641624+00', 'Father to Son', 'FATHER TO SON', 1, 32, 9999, 1, 3, 42, 1089, NULL, 'This dance is dedicated to the memory of the great Bobby Brown and “The Scottish Accent” band and to his son Laird Brown who continues the wonderful music for us, with his band “Scotch Mist”.', 69, '880/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16098, '2015-02-21 16:35:02.286148+00', '2015-02-21 16:35:02.286148+00', 'Capital Lassie, A', 'CAPITAL LASSIE', 3, 32, 9999, 4, 4, 4, 11088, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16099, '2015-02-21 16:54:14.068564+00', '2015-02-21 16:54:14.068564+00', 'Confederation Square', 'CONFEDERATION SQUARE', 1, 88, 9999, 4, 4, 3, 488, '1988-11-01', 'This dance may be danced by eight men to symbolize the fathers of confederation. Read left-hand man for man and right-hand man for woman.



Suitable recorded music:

"Oh, My America" by Bobby Brown and the Scottish Accent on Grandfather Mountain Gala, Track1.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16102, '2015-02-21 17:40:40.430891+00', '2015-02-21 17:40:40.430891+00', 'Lady Spencer''s Wedding', 'LADY SPENCERS WEDDING', 3, 32, 9999, 1, 4, 1, 11090, '2001-01-01', 'Devised by Elaine Hoag and Michael Hoffman in 2001 to celebrate the marriage of Ardbrae members, Miachael Hoffman and Rosalind Spencer, and presented by Michael to Rosalind.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16094, '2015-02-21 14:34:56.346752+00', '2016-04-16 17:22:37.671584+00', 'Esplanade, The', 'ESPLANADE', 1, 32, 9999, 1, 2, NULL, 11086, '1998-01-01', 'Suggested music:

Muriel Johnstone''s Scottish Dance Band - Haste Ye Back, #1 - All for Mary', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16089, '2015-02-21 13:48:19.10365+00', '2016-04-18 23:20:05.010233+00', 'Winnie''s Home', 'WINNIES HOME', 1, 32, 9999, 1, 2, NULL, 11086, '2014-01-01', 'Suggested music:

Bobby Brown and the Scottish Accent - Any Good Dance Any Good Tune, #15 - Selection of Reels', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11586, '2003-11-27 23:00:00+00', '2015-02-23 22:27:27.352785+00', 'Trip to Gretna Green', 'TRIP TO GRETNA GREEN', 2, 32, 9999, 1, 3, 42, 9998, NULL, 'There was a long discussion on Strathspey in 2003-2004, trying to identify the author.  In July 2011 Andrew Aitken of the "Wichita Scottish Country Dancers" wrote to DD : I first came across this dance in a dance gala posting from the Lees McRae College Banner Elk, North Carolina program back in July 1988.  Unfortunately, the program does not list the authors.  This is one of my all time favorites. 



A crib was received showing the name "B.L. Barnes" in the title. 2 august 2011: this might be Elizabeth (Betty) Lee Barnes, of Washington DC.  30 August 2013: Betty Lee Barnes has denied being the author.  The mystery continues.



From Strathspey List, Wed, 15 Jan 2014 20:37:48 -0800:

I was assured by Mel Briscoe when he taught it at Pinewoods many years ago that it had never been published and exists only as people''s notes.  If you''d like I have the notes he sent me afterwards.

Bruce Herbold,  Oakland.

', 53, '844  844  888  822', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (16109, '2015-02-24 00:26:13.674721+00', '2015-02-24 00:28:02.214724+00', 'Seattle Rubies', 'SEATTLE RUBIES', 2, 32, NULL, 1, 3, 42, 3593, '2014-01-01', '', 64, '886/444/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16110, '2015-02-24 07:52:43.405325+00', '2015-02-24 08:12:46.71086+00', 'Marengo Blue', 'MARENGO BLUE', 3, 48, NULL, 104, 2, NULL, 11095, '2005-09-17', 'Brian Charlton writes: Marengo Blue was written by a member of Sydney Branch, Maurice Harcombe, who moved back to his origins when he retired. The village he came from is called Murringo, but it''s original name was Marengo, after a battle in Napoleonic times. Maurice started a Class in the village and held an annual Dance for many years. Marengo Blue was first danced at one of these dances.

', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16125, '2015-02-25 16:04:07.17968+00', '2018-04-02 23:56:33.305471+00', 'Cameron Highlanders, The', 'CAMERON HIGHLANDERS', 1, 32, 9999, 1, 3, 42, 11099, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2509, '1997-09-03 22:00:00+00', '2018-04-02 23:56:34.884288+00', 'Glen Devon', 'GLEN DEVON', 3, 32, 9999, 1, 3, 42, 108, '1983-01-01', 'Glen Devon is in the Ochil Hills to the south of Gleneagles in Scotland.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16111, '2015-02-24 09:41:42.510598+00', '2018-04-03 00:18:02.380529+00', 'Purdy Pink Shoes', 'PURDY PINK SHOES', 2, 32, 9999, 2, 2, 76, 11093, NULL, '32-bar jig for two couples in a three or four-couple longwise set.



Devised by Elaine Hoag and dedicated to Ardbrae member, Deborah Connors, who dances in "purdy" hot pink shoes and brings so much energy and joy to her dancing.



Suitable music (6x32bars):

"Purdy Pink Band Shoes" by The Music Makars on Catch the Wind, Track 9', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16114, '2015-02-24 16:06:51.26102+00', '2015-02-24 16:06:51.26102+00', 'Marian Visits Gleneagles', 'MARIAN VISITS GLENEAGLES', 3, 32, 9999, 1, 4, 2, 1089, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16115, '2015-02-24 16:11:27.783331+00', '2015-02-24 16:11:27.783331+00', 'Such Beauty', 'SUCH BEAUTY', 2, 32, 9999, 1, 4, 2, 1089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16144, '2015-02-27 16:44:18.91466+00', '2018-04-02 23:56:35.936332+00', 'Little Hush, A', 'LITTLE HUSH', 3, 32, 9999, 1, 3, 42, 10568, '2008-08-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3402, '1998-04-12 22:00:00+00', '2022-07-31 11:31:15.012228+00', 'Kate McFarlan', 'KATE MACFARLAN', 3, 32, 9999, 1, 3, 42, 9998, '1740-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21104, '2022-09-18 22:06:58.674871+00', '2022-09-19 08:42:31.516366+00', 'Et voilà !', 'ET VOILA ', 4, 160, 10, 4, 119, NULL, 11643, '2022-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4010, '2002-04-19 22:00:00+00', '2015-02-24 16:41:40.155443+00', 'MacArthur Park', 'MACARTHUR PARK', 3, 32, 9999, 1, 4, 1, 1089, '1981-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18609, '2018-09-15 21:38:54.001249+00', '2018-09-15 21:38:57.80784+00', 'Three Reel Four', 'THREE REEL FOUR', 1, 32, NULL, 5, 56, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16116, '2015-02-24 16:37:24.682564+00', '2018-04-02 23:56:35.134852+00', 'Hellen', 'HELLEN', 1, 32, 9999, 1, 3, 42, 1089, '2010-06-04', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1002, '1997-04-03 22:00:00+00', '2015-02-24 17:15:36.083678+00', 'Capilano Run, The', 'CAPILANO RUN', 3, 32, 9999, 1, 100, 2, 108, '1983-01-01', 'The Capilano Run is the salmon run in the Capilano River in West Vancouver BC. The run was interrupted by the building of a dam. A salmon hatchery has been established at the foot of the dam in a very successful venture to maintain the stock of Capilano fish. John and Simon Scott visited the hatchery when he was in Vancouver in 1983.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16112, '2015-02-24 14:04:45.020614+00', '2018-04-02 23:56:37.623113+00', 'Skippin'' Barfit Thro'' the Heather', 'SKIPPIN BARFIT THRO THE HEATHER', 2, 32, 9999, 1, 3, 42, 740, '2014-09-01', 'While the traditional song tune is not a jig, I thought that jig tempo suited my image of "skipping barefoot through the heather".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16118, '2015-02-25 14:49:21.247908+00', '2015-02-25 14:49:21.247908+00', 'Tapadh leibh', 'TAPADH LEIBH', 3, 32, 9999, 2, 3, 18, 10333, '2013-01-01', '"Tapadh leibh" (pronounced tapah leyv) means thank you in Scottish Gaelic.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16120, '2015-02-25 15:08:38.286593+00', '2015-02-25 15:08:38.286593+00', 'Lochcarron Loom', 'LOCHCARRON LOOM', 2, 32, 9999, 1, 4, 1, 1043, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16121, '2015-02-25 15:19:42.962268+00', '2015-02-25 15:19:42.962268+00', 'Golden Annings, The', 'GOLDEN ANNINGS', 3, 40, 9999, 2, 3, 17, 11097, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16122, '2015-02-25 15:25:39.816801+00', '2018-04-02 23:56:38.107189+00', 'Triggs Lock', 'TRIGGS LOCK', 1, 40, 9999, 1, 3, 42, 10338, '2013-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16119, '2015-02-25 14:57:20.036888+00', '2018-04-02 23:56:38.30728+00', 'Union of the Crowns Reel, The', 'UNION OF THE CROWNS REEL', 1, 32, 9999, 1, 3, 42, 347, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13261, '2007-02-27 23:00:00+00', '2018-04-03 00:07:45.837245+00', 'Findhorn Bay', 'FINDHORN BAY', 6, 32, 9999, 1, 3, 42, 2419, NULL, '»The lovely village of Findhorn on the Moray Coast is situated in the north east of Scotland and is a favourite haunt for visitors. The advance and retire in the dance depicts the ebb and flow of the sea.«



HORNPIPE

DEVISED:2006-03', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14616, '2012-12-17 23:42:04.983861+00', '2015-03-03 22:20:24.202582+00', 'Keys and Codes at St. Peter''s School', 'KEYS AND CODES AT ST PETERS SCHOOL', 2, 32, NULL, 2, 3, 18, 3597, '2011-12-01', 'To show the difficulty of entering St. Peter''s School without setting off the alarms', 83, '800  888  888  888', 1, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (16123, '2015-02-25 15:42:45.887701+00', '2017-05-14 00:35:06.216615+00', 'Ambidextrous', 'AMBIDEXTROUS', 2, 32, 9999, 1, 3, 42, 11098, '2013-01-01', 'Repeat, having passed a couple, with genders temporarily re-assigned*.

As each couple begin their second turn of the dance, on bars 5-8 the new 3rd couple, and also the

standing couple at the top of the set, giving right hands to partners, change places and set.



*Note: on bars 1-6 of the repeat, the original men (now dancing as women) should cross in front of

their partners.



Dedicated to all those ladies who frequently have to dance as men.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16124, '2015-02-25 15:53:42.358897+00', '2016-06-06 00:32:56.069621+00', 'Alister MacLeay', 'ALISTER MACLEAY', 3, 32, 9999, 1, 100, 2, 11266, NULL, 'Devised in memory of the late Alister MacLeay, Life President of Tadley Scottish Country Dancers.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13908, '2011-08-22 22:00:00+00', '2018-04-21 15:52:09.720253+00', 'Four Score Square', 'FOUR SCORE SQUARE', 3, 80, NULL, 4, 4, 3, 64, '2003-09-01', 'Devised by Irene van Maarseveen, Pretoria, September 2003.  



For Shirley Lloyd, 80 years young on 13 November 2003.  



Many of the formations in the dance are in the shape of an 8 or an 0.  



Tunes: An Tè Liath and lrene''s Piece played as follows:  

An Tè Liath ABAB, lrene''s Piece AABB, An Tè Liath AB; total 80 bars. 

', 80, '8080/8080/0808/0808/8888/8888/8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13810, '2011-08-04 22:00:00+00', '2018-04-27 11:53:18.139571+00', 'Falls of Lana, The', 'FALLS OF LANA', 1, 32, NULL, 1, 3, 42, 2245, '2009-01-01', 'Recommended recorded music: "Shetland Reels," Track 2 from Steppin'' Out by John Taylor and Andrew Imbrie  



The Falls of Lana are near Salisbury, Addison County, Vermont, USA and are easily accessible if you don''t mind scrambling over some rocks uphill along a pipeline. The view is worth the trouble, as is Silver Lake if you continue up the trail for another hour or so and 500+ feet elevation.  See photos of the Falls of Lana at http://www.northeastwaterfalls.com/waterfall.php?num=128&p=0.  



- Bars 1-8 represent the trail to Silver Lake,

- 9-16 greeting other hikers on the trail,

- 17-24 the tumbling and roiling waters of Sucker Creek over the falls,

- 25-32 is Silver Lake at the top.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16146, '2015-02-27 18:00:40.30654+00', '2018-04-02 23:56:33.439345+00', 'Charm of Goldfinches, A', 'CHARM OF GOLDFINCHES', 2, 32, 9999, 1, 3, 42, 1309, '2002-08-10', 'Suggested music: "Miss Hannah''s Jig" on Hanneke Cassel & Dave Wiesler, Many Happy Returns', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13586, '2010-08-08 22:00:00+00', '2018-09-08 10:47:43.06297+00', 'Bonnie Tree, The', 'BONNIE TREE', 3, 32, NULL, 1, 3, 42, 59, NULL, '', 53, '800  888  822  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (16151, '2015-02-27 18:38:18.596115+00', '2015-02-27 18:40:35.154017+00', 'Rock Wren, The', 'ROCK WREN', 2, 32, 9999, 2, 3, 17, 1309, '2008-09-01', 'Suggested music: "Rockside" on Muriel Johnstone & Keith Smith, Vintage Goldring', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (342, '1997-09-29 22:00:00+00', '2018-04-03 00:07:31.905206+00', 'Bagshaw Jig', 'BAGSHAW JIG', 2, 32, 9999, 1, 3, 42, 153, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16142, '2015-02-27 16:32:17.938049+00', '2018-04-02 23:56:33.995366+00', 'Doolittle Dale', 'DOOLITTLE DALE', 2, 32, 9999, 1, 3, 42, 10568, '2008-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16148, '2015-02-27 18:18:06.394184+00', '2015-02-27 18:48:24.216087+00', 'Dipper, The', 'DIPPER', 1, 32, 9999, 2, 3, 17, 1309, '2000-06-01', 'Suggested music: 3x32R:"The Ruby Hornpipe" on Muriel Johnstone, Dancing Fingers 5

8x32R: any good reel', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15201, '2013-10-14 14:25:51.640371+00', '2017-01-20 23:41:43.56334+00', 'Flirtez !', 'FLIRTEZ ', 1, 32, NULL, 5, 2, 30, 10872, NULL, 'Written for Scottish Chanterelle, Lyon, whose catchphrase is "Flirtez !"', 75, '88/80/08/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16139, '2015-02-27 14:17:19.553034+00', '2019-02-22 01:49:39.267474+00', 'So It Goes', 'SO IT GOES', 3, 32, 9999, 1, 100, 2, 10568, '2007-05-01', '1s and 4s being ''top'' couples to start.', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16152, '2015-02-28 12:12:13.605363+00', '2015-02-28 12:12:13.605363+00', 'Bow Tie, The', 'BOW TIE', 1, 32, NULL, 1, 4, 2, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16145, '2015-02-27 17:55:11.965153+00', '2018-10-24 20:52:52.850158+00', 'Birding on the Beach', 'BIRDING ON THE BEACH', 2, 32, 9999, 1, 4, 1, 1309, '2008-11-01', 'Suggested music: "The Ornithologist"(Boston Two Step) on Gordon Patullo, Ceiligh Dance Party.



Written about birding on Asilomar State Beach in the mornings. Inspired by attending the Asilomar Weekend.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16141, '2015-02-27 16:23:55.156512+00', '2019-03-20 23:54:08.841916+00', 'TMR Schiehallion Shenanigans', 'TMR SCHIEHALLION SHENANIGANS', 1, 88, 9999, 4, 4, 3, 10568, '2007-12-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16138, '2015-02-27 14:06:46.790877+00', '2019-02-22 02:02:46.205933+00', 'Reel Men Wear Plaid', 'REEL MEN WEAR PLAID', 2, 32, 9999, 2, 3, 17, 10568, '2007-05-01', 'Music: The Duke of Atholl''s Reel



(lf you do it in a 4 couple set, change 25 - 32 to 1/2 figure 8 around 3rd couple, then 1/2

figure 8 around 2nd couple and 1s start again from 2nd place. Second time, 1s continue

down to 4th place as 4s step up.)', 58, '880/844/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16143, '2015-02-27 16:39:32.638313+00', '2019-02-23 01:52:36.975508+00', 'Monsieur Albert Longtain', 'MONSIEUR ALBERT LONGTAIN', 1, 32, 9999, 1, 3, 42, 10568, '2008-04-01', '', 44, '880/800/808/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16150, '2015-02-27 18:35:16.423389+00', '2018-04-02 23:56:36.929812+00', 'Owl and the Chickadees, The', 'OWL AND THE CHICKADEES', 4, 32, 1, 1, 3, 42, 1309, '2008-11-20', 'Suggested music: "The Maine Medley" on Celebrate 50 Years of Dancing with the Boston Branch', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2602, '1998-07-08 22:00:00+00', '2015-03-02 23:48:13.502098+00', 'Golden Years, The', 'GOLDEN YEARS', 3, 48, 9999, 1, 102, 2, 21, '1988-01-01', '', 100, '8888  8888  8888  8888  8888  8888', 0, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (16149, '2015-02-27 18:28:48.344816+00', '2015-11-01 18:18:40.02012+00', 'Ducks in a Row', 'DUCKS IN A ROW', 2, 32, 9999, 4, 55, NULL, 1309, '2008-04-08', 'Suggested music: "Sgurr Alasdair" on Muriel Johnstone & Keith Smith, Vintage Goldring', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10113, '2001-10-14 22:00:00+00', '2017-01-22 00:25:13.987452+00', 'Albatrosses and Shearwaters', 'ALBATROSSES AND SHEARWATERS', 3, 32, 9999, 2, 3, 17, 1309, '2000-11-01', '"Set of Strathspeys (Pastoral)" on Bobby Brown & the Scottish Accent, Any Good Dance, Any Good Time', 75, '888  080  484  888', 0, 0, 0, 0, 75);
INSERT INTO 'dance' VALUES (696, '2001-11-20 23:00:00+00', '2018-04-03 00:07:35.067348+00', 'Border Bridge, The', 'BORDER BRIDGE', 1, 32, 9999, 1, 3, 42, 388, '1982-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (731, '1997-04-03 22:00:00+00', '2018-04-03 00:07:35.326025+00', 'Brackenbraes Strathspey', 'BRACKENBRAES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12404, '2005-04-28 22:00:00+00', '2021-01-15 00:37:12.462189+00', 'Boozle Plant', 'BOOZLE PLANT', 1, 32, 9999, 1, 3, 42, 3591, '1998-01-01', '', 63, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (893, '1998-11-14 23:00:00+00', '2021-04-18 10:13:55.517503+00', 'Bydand', 'BYDAND', 3, 32, 9999, 1, 3, 42, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Stephen W. Gordon of London, formerly of Falkirk. "Bydand", meaning abiding or lasting, is the motto of Clan Gordon.', 69, '888  880  888  888', 0, 1, 0, 1, 91);
INSERT INTO 'dance' VALUES (1280, '1998-09-29 22:00:00+00', '2021-06-20 10:10:24.427123+00', 'College Hornpipe, The', 'COLLEGE HORNPIPE', 1, 32, 9999, 1, 3, 42, 457, '1797-01-01', '', 53, '888  888  800  822', 1, 1, 0, 1, 70);
INSERT INTO 'dance' VALUES (819, '1998-09-29 22:00:00+00', '2021-06-28 10:19:36.615099+00', 'British Grenadiers, The', 'BRITISH GRENADIERS', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 59, '444  888  888  880', 1, 1, 0, 1, 79);
INSERT INTO 'dance' VALUES (596, '1998-01-05 23:00:00+00', '2021-07-01 22:43:17.277572+00', 'Blue Tartan', 'BLUE TARTAN', 1, 40, 9999, 1, 3, 42, 21, NULL, 'Inscribed "for The Lothian Scottish Dance Band."', 60, '866/888/822/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3735, '1998-09-29 22:00:00+00', '2018-04-03 08:45:34.111772+00', 'Lassies of Dunse, The', 'LASSIES OF DUNSE', 2, 32, 9999, 1, 3, 42, 453, '1750-01-01', 'The Society’s version of this dance can be traced to Rutherford’s first collection of about 1755 where it is given as *The Lasses of Dunce*. ', 25, '440  440  800  800', 1, 1, 1, 1, 33);
INSERT INTO 'dance' VALUES (6191, '2000-07-02 22:00:00+00', '2015-03-03 22:38:20.208725+00', 'Something Old, Something New', 'SOMETHING OLD SOMETHING NEW', 2, 48, 9999, 1, 4, NULL, 244, '1963-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14278, '2011-10-15 22:00:00+00', '2015-03-03 22:59:15.062504+00', 'Cheerful Duck, The', 'CHEERFUL DUCK', 3, 32, NULL, 2, 3, 18, 1445, NULL, 'For Tiny Pot who cheerfully travels in her bright yellow "ugly duckling" car to teach us in Eindhoven.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15905, '2015-01-29 13:56:15.277494+00', '2018-04-02 23:56:36.011547+00', 'Madame Pisces', 'MADAME PISCES', 1, 32, 9999, 1, 3, 42, 3349, '2008-09-16', 'Suggested music:

"Society Piper" on CD "Haste Ye Back" by Muriel Johnstone''s Scottish Dance Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1969, '1998-04-15 22:00:00+00', '2018-04-02 23:56:34.349762+00', 'Elphinstone Jig, The', 'ELPHINSTONE JIG', 2, 32, 9999, 1, 3, 42, 108, '1981-01-01', 'Devised: 1981

First published in The Deeside Book Part 2', 58, '646  888  808  860', 1, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (8593, '1998-01-13 23:00:00+00', '2018-09-15 22:22:15.515837+00', 'Four Handed Reel', 'FOUR HANDED REEL', 4, 128, 2, 104, 2, NULL, 2018, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16157, '2015-03-11 10:08:49.589239+00', '2018-04-02 23:56:37.038393+00', 'Poule au Romance', 'POULE AU ROMANCE', 3, 32, NULL, 1, 3, 42, 11112, '2014-09-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12800, '2006-07-02 22:00:00+00', '2015-03-12 00:40:51.619068+00', 'New Dixon Quadrille', 'NEW DIXON QUADRILLE', 1, 32, 9999, 4, 4, NULL, 3696, NULL, 'Devised by Frances Richardson and dedicated to her friends, Peter and Wendy Dixon, who produced quadruplets on 1st April - all girls, no joke! The dance is designed to provide opportunities for four identical girls to confuse their male partners, particularly as the men progress round the square rather than the ladies.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1775, '1999-08-09 22:00:00+00', '2015-04-13 23:58:38.673488+00', 'Duchess of Gordon''s Fancy, The', 'DUCHESS OF GORDONS FANCY', 3, 32, 9999, 1, 2, NULL, 9998, NULL, '', 52, '80/80/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16162, '2015-03-17 13:55:57.295433+00', '2018-04-03 00:07:30.083562+00', 'Alix and the Lion', 'ALIX AND THE LION', 2, 32, NULL, 1, 3, 42, 3694, '2009-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16155, '2015-03-07 18:14:50.587349+00', '2015-03-07 22:11:15.526681+00', 'Our Leading Lady', 'OUR LEADING LADY', 3, 32, NULL, 1, 4, 1, 3183, '2013-12-01', 'Devised for Norah Dunn''s 100th birthday in December 2013. She is the Honorary President of The Helensburgh & District Branch of the RSCDS. ', 50, '880/808/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16165, '2015-03-17 14:00:31.575493+00', '2018-04-03 00:07:30.677582+00', 'Anna''s Farewell to Sutton Coldfield', 'ANNAS FAREWELL TO SUTTON COLDFIELD', 1, 40, NULL, 1, 3, 42, 3694, '2014-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16154, '2015-03-04 22:10:16.301127+00', '2015-03-08 08:53:03.408738+00', 'It''s Time to ...', 'ITS TIME TO ', 2, 32, NULL, 5, 113, 4, 10451, '2015-03-03', 'Devised by Carola Fischer, Tobias Huenger and Silke Grosholz.  Carola writes "It is only a simple little dance borne out of the need to squeeze as many dancers as possible onto our dance floor for the final dance of an evening!"  The title was originally ''Time for a Beer'' but Tobias uses it as warm-up as well and therefore prefers "It'' Time to ..."

', 75, '80/08/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13557, '2010-01-19 23:00:00+00', '2015-03-08 23:16:51.627174+00', 'Wellingtonia Reel, The', 'WELLINGTONIA REEL', 1, 32, NULL, 1, 3, 42, 347, NULL, 'This dance was inspired by the magnificent Wellingtonia trees near Finchampstead, Berkshire which I regularly travel past on the way to class.', 47, '840/888/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16164, '2015-03-17 13:59:14.194421+00', '2018-04-03 00:08:04.460377+00', 'Miss Jenny Davison', 'MISS JENNY DAVISON', 2, 32, NULL, 1, 3, 42, 3694, '2012-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4836, '2003-01-10 23:00:00+00', '2018-04-03 00:08:06.920685+00', 'Muriel''s Reel', 'MURIELS REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16156, '2015-03-09 23:54:24.281884+00', '2015-03-14 17:18:02.336222+00', 'Charming Frenchman, The', 'CHARMING FRENCHMAN', 2, 32, NULL, 1, 3, 42, 11111, '2015-01-01', 'Dedicated to the Guillaume Legrand, the “Charming Frenchman” in the Kuckucksnest group.', 53, '888/800/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15272, '2013-12-03 23:50:45.57061+00', '2017-09-29 22:52:57.567532+00', 'Gordon''s Cider Press', 'GORDONS CIDER PRESS', 1, 32, NULL, 4, 5, 6, 3593, '2011-05-01', 'For Gordon Hutchinson, with thanks for the cider and all the other organic fruits he brings to functions. 

This dance has been submitted to the RSCDS for Book 49.



When Irene Paterson taught the dance for the first time at a workshop in Portland it was different:  the switching of couples started with 4c, and finished with 1c, the progression being (2,3,4,5,1).  Irene subsequently changed the ending, starting the switching with 1c, and leading to the progression (5,3,4,1,2).', 50, '40408/80808/08088/42442', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16159, '2015-03-13 16:22:27.71188+00', '2015-03-16 13:53:09.044329+00', 'Yes - I do', 'YES  I DO', 4, 192, 3, 2, 3, 18, 10612, '2014-10-04', 'Written for Mascha and Markus on their wedding day, 4th October 2014', 56, '800/880/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5016, '1998-01-05 23:00:00+00', '2015-03-16 23:52:53.432261+00', 'O''er the Forth to Fife', 'OER THE FORTH TO FIFE', 1, 40, 9999, 1, 4, 1, 678, NULL, 'Bars 5-16 represent the Forth Road Bridge, and bars 21-36 the Forth Railway Bridge.', 75, '16,16,16,8/4,4,4,0/3,5,5,5/3,5,5,5/4,4,4,4', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16161, '2015-03-13 16:40:03.93435+00', '2019-04-04 11:39:38.035492+00', 'Toast to Meike, A', 'TOAST TO MEIKE', 4, 64, 5, 1, 3, 42, 10759, '2014-01-01', 'Devised for Meike Droenner to celebrate her 60th Birthday in 2014.', 56, '800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14438, '2012-05-09 13:54:08.825188+00', '2022-04-26 01:54:06.945305+00', 'David''s Delight', 'DAVIDS DELIGHT', 3, 32, 9999, 1, 3, 42, 1502, '2004-12-20', 'Dance devised for Bernadene Langer and David Reiger on the occasion of their marriage on December 20th, 2004. 



', 50, '880/808/844/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21106, '2022-09-19 08:01:42.756564+00', '2022-09-19 09:21:32.646699+00', 'Spot on', 'SPOT ON', 1, 32, NULL, 7, 113, NULL, 11927, '2022-07-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21241, '2023-01-04 23:16:03.137952+00', '2023-01-04 23:16:03.137952+00', 'Cuairt-Shruth', 'CUAIRTSHRUTH', 3, 40, NULL, 2, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15483, '2014-06-27 20:55:13.842986+00', '2019-10-15 01:37:40.159557+00', 'Waterloo Welcome', 'WATERLOO WELCOME', 2, 32, NULL, 1, 2, 76, 10971, NULL, 'Ray Dugan confirms that the first published original description had an error in [31-32].  Eric''s crib is correct.  



This dance is very similar to <<ddd:The Caledonian Step>>

', 69, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16153, '2015-03-03 23:20:58.625039+00', '2015-10-10 22:11:16.715672+00', 'Sleeping In', 'SLEEPING IN', 1, 32, NULL, 1, 3, 18, 10910, '2014-01-01', 'Source: Found on YouTube



Published : Betwixt and Between Scottish Dance and Ceilidh, December 28, 2014

Holly, Martin, Liza, Tom, Susan, John, Linda Mae, Patrick.', 62, '822/888/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16167, '2015-03-17 14:03:15.777524+00', '2018-04-03 00:08:03.734782+00', 'Minstrels'' Reel, The', 'MINSTRELS REEL', 1, 32, NULL, 1, 3, 42, 3694, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16171, '2015-03-17 14:09:05.690346+00', '2015-03-17 14:09:05.690346+00', 'Sutton Park', 'SUTTON PARK', 3, 32, NULL, 1, 4, 1, 3694, '2014-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16172, '2015-03-17 14:10:19.411247+00', '2015-03-17 14:10:19.411247+00', 'Wendy''s Strathspey', 'WENDYS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 3694, '2014-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16586, '2015-08-26 14:26:12.084012+00', '2018-04-02 23:56:35.577334+00', 'Just for June', 'JUST FOR JUNE', 1, 32, 9999, 1, 3, 42, 11179, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16158, '2015-03-11 23:47:50.163745+00', '2020-10-14 22:13:41.372327+00', 'St Magnus Quadrille', 'SAINT MAGNUS QUADRILLE', 1, 96, NULL, 4, 4, 3, 374, NULL, 'Can also be a Jig', 88, '8484/4848/8080/0808/8888/8888/8888/8888/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13230, '2007-01-25 23:00:00+00', '2021-01-04 16:04:30.679551+00', 'Broken River Reel', 'BROKEN RIVER REEL', 1, 32, 9999, 1, 3, 42, 3757, NULL, '', 62, '844/844/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8741, '2001-01-25 23:00:00+00', '2021-03-14 20:58:21.247791+00', 'Dillsburg Jig, The', 'DILLSBURG JIG', 2, 32, 9999, 1, 3, 42, 382, '1996-01-01', '', 62, '800  888  888  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (2267, '1998-09-29 22:00:00+00', '2021-06-07 08:35:57.381394+00', 'Follow Me Home', 'FOLLOW ME HOME', 2, 32, 9999, 1, 3, 42, 508, NULL, '', 50, '800/844/844/888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (16174, '2015-03-17 14:13:00.785673+00', '2018-04-03 00:07:31.479244+00', 'Audrey''s Strathspey', 'AUDREYS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 3694, '2012-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16178, '2015-03-20 14:59:48.912919+00', '2016-05-10 22:24:10.491917+00', 'Cockney Jocks', 'COCKNEY JOCKS', 7, 6, 9999, 107, 51, 3, 1231, '1975-08-01', '', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12767, '2006-05-21 22:00:00+00', '2015-03-19 13:18:23.314829+00', 'V-C Jig, The', 'VC JIG', 2, 32, 9999, 1, 3, 42, 3682, NULL, '', 56, '888/800/888/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16515, '2015-07-26 10:19:50.329122+00', '2018-04-03 00:07:38.730862+00', 'Clockwork, The', 'CLOCKWORK', 3, 32, NULL, 1, 3, 42, 3355, '2012-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16176, '2015-03-19 23:56:39.057999+00', '2015-03-20 21:02:52.896763+00', 'Flowers of Ildikó', 'FLOWERS OF ILDIKO', 1, 32, NULL, 5, 2, NULL, 11114, '2015-02-01', '"a simple but funny dance for beginners."  One of the most common female names in our club is Ildikó. We celebrate their name day (10th February) with this dance. Music: ''Catch the Wind'' is a good choice to have great fun! ', 87, '88/44/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16179, '2015-03-21 13:22:08.687026+00', '2015-03-21 13:22:08.687026+00', 'Maureen Daniel''s Strathspey', 'MAUREEN DANIELS STRATHSPEY', 3, 32, NULL, 1, 102, 2, 640, '2010-01-01', 'Inscribed to Maureen Daniel of Bridge of Weir', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16180, '2015-03-21 13:24:10.823088+00', '2015-03-21 13:24:10.823088+00', 'Dick Daniel''s Hornpipe', 'DICK DANIELS HORNPIPE', 1, 32, NULL, 1, 100, 2, 640, '2010-01-01', 'Inscribed to Dick Daniel of Bridge of Weir', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11830, '2004-10-31 23:00:00+00', '2019-06-09 23:30:37.395872+00', 'Well Met in Paris', 'WELL MET IN PARIS', 1, 32, 9999, 1, 3, 42, 2677, '2004-01-01', 'These former URLs are dead:



http://home.roadrunner.com/~glasshall/Paris%202003.pdf



http://home.roadrunner.com/~glasshall/WellMetinParis.html', 61, '860/880/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16177, '2015-03-20 00:26:56.422312+00', '2015-03-23 16:48:39.788099+00', 'Metro4', 'METRO4', 2, 40, NULL, 1, 4, 2, 3661, '2015-03-01', '4  10-bar phrases', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13088, '2006-11-12 23:00:00+00', '2018-09-30 23:56:05.257616+00', 'Hans im Glück', 'HANS IM GLUCK', 1, 32, 9999, 1, 3, 42, 558, '2003-01-01', 'Devised by Rudolf Spägele for Hans Willberg to his 90th birthday, May 2003 ', 44, '800/844/800/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18684, '2018-10-02 01:10:06.58506+00', '2018-10-02 01:10:06.58506+00', 'Bonnie''s Reel', 'BONNIES REEL', 1, 32, NULL, 1, 3, 42, 2766, '2013-08-01', 'Bonnie likes lively dances and liked the figure in bars 1-8. She also loves to twirl while dancing diagonal reels.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16182, '2015-03-25 14:03:51.045322+00', '2015-03-25 14:03:51.045322+00', 'Camberley Reel, The', 'CAMBERLEY REEL', 1, 32, NULL, 1, 4, 2, 2052, '2000-09-01', 'The Camberley Reel was devised by our President from 1989 to 2002, Jim Adams, to commemorate the 40th anniversary of Camberley Reel Club, which was celebrated in September 2000. 



A check is needed if the "Jim Adams" is the same person as the "J.E. Adams" here listed as deviser (for lack of a Jim Adams)



Description Published on the Camberley website.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2439, '1997-09-03 22:00:00+00', '2015-04-20 11:20:53.0514+00', 'Geordie Hinnie', 'GEORDIE HINNIE', 1, 112, 9999, 4, 4, NULL, 94, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16181, '2015-03-24 22:53:46.458641+00', '2019-01-26 05:14:04.373883+00', 'Tulips from Edinburgh', 'TULIPS FROM EDINBURGH', 1, 32, NULL, 1, 4, 2, 10478, '2015-01-01', 'First danced in Geldermalsen, spring 2015.

', 62, '8080/8080/8080/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16583, '2015-08-26 14:03:09.177292+00', '2015-08-26 14:03:09.177292+00', 'In the Clover', 'IN THE CLOVER', 1, 32, 9999, 6, 3, 17, 11178, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16175, '2015-03-17 14:14:27.810805+00', '2017-05-31 11:07:32.404957+00', 'Wye Celebration, The', 'WYE CELEBRATION', 3, 32, NULL, 1, 4, 1, 3694, '2012-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16214, '2015-04-20 13:40:37.540755+00', '2018-04-02 23:56:32.954194+00', 'Belatedly or Nachträglich', 'BELATEDLY OR NACHTRAGLICH', 2, 32, 9999, 1, 3, 42, 3324, '2001-03-24', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9815, '2001-10-22 22:00:00+00', '2015-03-28 00:58:03.082887+00', 'Miss A O Cumming', 'MISS A O CUMMING', 1, 32, 9999, 1, 3, 42, 2852, NULL, 'Annie O Cumming was Honorary Secretary of the Aberdeen Branch for many years and a large part ofher life was devoted to Scottish Country Dancing and to the Branch. Affectionately known as "Annie O", she was undoubtedly one of Aberdeen''s characters whose rather brusque exterior masked a caring and understanding personality.', 59, '844/844/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16954, '2016-05-24 08:06:54.052197+00', '2018-04-02 23:56:38.590992+00', 'Wilde Thing', 'WILDE THING', 4, 64, 5, 1, 3, 42, 316, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16184, '2015-04-01 17:18:16.44722+00', '2015-04-01 17:22:29.708682+00', 'Cambusdoon', 'CAMBUSDOON', 3, 32, NULL, 1, 4, 2, 687, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16185, '2015-04-05 07:52:39.726104+00', '2015-04-06 12:49:22.993368+00', 'Farewell to Leven', 'FAREWELL TO LEVEN', 3, 32, NULL, 2, 3, 18, 9998, NULL, '', 75, '484/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13497, '2009-11-21 23:00:00+00', '2020-09-18 08:29:08.353835+00', 'Moray Firth Hornpipe, The', 'MORAY FIRTH HORNPIPE', 1, 32, 9999, 1, 3, 42, 1269, '2007-01-01', '', 59, '884/866/866/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9843, '2001-06-28 22:00:00+00', '2021-02-18 11:27:37.315674+00', 'Cell Phone Jig, The', 'CELL PHONE JIG', 2, 32, 9999, 1, 3, 42, 2862, NULL, 'Holding a mobile phone with your left hand to your ear.



This dance was published (as a joke) on Strathspey as <<sspey:22026|Message 22026>> on 29 Jul 2000, but has actually appeared on programmes, including the Essen Ball on 13 Jan 2001 and in Luxemburg on 1 June 2012.', 34, '800  840  804  822', 0, 1, 0, 0, 45);
INSERT INTO 'dance' VALUES (3403, '2002-09-22 22:00:00+00', '2021-07-30 08:41:22.72505+00', 'Kate''s Travels', 'KATES TRAVELS', 3, 40, 9999, 1, 4, 1, 308, '1995-01-01', 'Mrs  Kate  Gibson  is  a  long  standing  member  of  Scunthorpe  Scottish  Country  Dance Club, who for many years has attended regularly and helped to keep the club alive. ', 75, '4884/8448/8448/4884/0888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15285, '2013-12-07 21:38:09.915095+00', '2022-08-14 11:46:06.553792+00', 'Tine''s Jig', 'TINES JIG', 2, 32, NULL, 1, 3, 42, 1760, '2007-01-01', 'DATE:2007-01  Originally, [25-32] was "hands round - 6 - and back", but this was modified by the deviser in the final publication.



Inscribed "for Tine MacKay, dancer, teacher and friend (Tine is pronounced Tina, her mum is Norwegian)".

', 47, '800/822/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1075, '2001-06-12 22:00:00+00', '2021-01-14 20:39:47.935709+00', 'Castle Wynd', 'CASTLE WYND', 3, 32, 9999, 1, 109, 76, 531, '1984-01-01', 'In Strathspey message 67265 of Wed, 25 Mar 2015, Alasdair Graham wrote:



I have recently acquired two Edinburgh Branch publications which both

contain a Strathspey - Castle Wynd - by Bob Grant - listed in the Strathspey

Database as a 2/4L shape.



The first publication is the Diamond Jubilee Dances 1984 book which lists

this dance as two couples dancing in a four couple set.  This printing says

"When all four couples are dancing the middle couples should dance round

each other during the allemandes."



The second publication is Five Anniversary Dances  in 1999 (75th).  The same

dance is printed here and it states the dance is a Strathspey for three

couples.  This printing says  "When all are dancing couples should dance

round the couple they face (even in the next set) at the start of the

allemande."



The same music is printed in both publications.



Does anyone know if the dance was changed from a four couple set to a three

couple set or if it is an error in the second printing?



Alasdair Graham

Dumbarton, Scotland

', 69, '88/88/88/88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (4965, '1998-04-19 22:00:00+00', '2021-04-30 11:10:19.843115+00', 'Noah''s Ark', 'NOAHS ARK', 2, 32, 9999, 1, 2, 76, 227, '1992-02-01', 'Level: intermediate/advanced



Devised 1 February 1992 for the Nunspeet weekend, bearing in mind that in one set you may have two Scots, two Germans, two Belgians, etc.', 58, '80  88  88  86', 1, 1, 0, 1, 84);
INSERT INTO 'dance' VALUES (2437, '2002-04-19 22:00:00+00', '2018-04-03 00:07:47.973938+00', 'Gentleman, The', 'GENTLEMAN', 3, 32, 9999, 1, 3, 42, 462, '1986-01-01', '##>>

The title is a tribute by the deviser, Roz Scott Huxley, to her father, the late Group Captain David Huxley who was very active in the Society and is best remembered as MC at Summer School ceilidhs in what used to be the second fortnight. His trademark as MC was an ancient umbrella dangling from his wrist which gave rise to the name of the original tune for the dance – *The Ceilidh Umbrella*. The umbrella is preserved at HQ.

##<<', 47, '860/804/846/880', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (2291, '1997-04-03 22:00:00+00', '2018-04-29 10:33:22.165824+00', 'Fort Qu''Appelle Breakdown', 'FORT QUAPPELLE BREAKDOWN', 2, 32, 9999, 1, 3, 42, 204, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16212, '2015-04-20 13:20:01.377421+00', '2016-05-12 23:09:47.269646+00', 'Milestones', 'MILESTONES', 7, 96, 9999, 107, 51, 3, 11118, '1999-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8879, '1998-12-16 23:00:00+00', '2015-04-05 10:36:03.364855+00', 'Rin the Reel', 'RIN THE REEL', 1, 40, 9999, 4, 4, NULL, 2018, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16183, '2015-03-29 23:31:46.920022+00', '2018-06-25 16:44:53.925239+00', '40 Years Together', '40 YEARS TOGETHER', 3, 40, NULL, 1, 4, 2, 3517, '2005-08-07', 'Dance devised by Helen Beaney to celebrate the Ruby Wedding Anniversary on 7th August 2005 of her parents, Jill Down and Frank Bonar, who first met through Scottish Country Dancing.

Music composed by John Barnes of the Dublin Scottish Country Dance Club.

', 87, '8228/8888/8888/8448/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18613, '2018-09-17 16:57:39.71932+00', '2019-05-01 08:21:41.051358+00', 'Chasing Dreams', 'CHASING DREAMS', 3, 80, NULL, 4, 4, 3, 3632, '2010-10-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16516, '2015-07-26 10:20:40.532186+00', '2017-05-31 10:58:28.448337+00', 'Reel for Joy, A', 'REEL FOR JOY', 1, 32, NULL, 2, 3, NULL, 3355, '2014-01-01', 'In memory of Joy Edgar', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8705, '1999-07-24 22:00:00+00', '2017-10-10 11:16:57.069011+00', 'Seattle in the Fall', 'SEATTLE IN THE FALL', 4, 64, 22, 1, 4, NULL, 479, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4252, '1998-01-05 23:00:00+00', '2018-09-17 12:48:56.836251+00', 'McClintock Rant, The', 'MACCLINTOCK RANT', 1, 40, 9999, 1, 3, 42, 636, NULL, 'Dedicated to Iain and Betsy Goddard on their Wedding Day.    



First printed in The Tartan Times, Vol. XVII, No.1, Sept., 1972', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17094, '2016-06-26 16:51:10.18787+00', '2016-06-26 16:51:10.18787+00', 'Yaratina', 'YARATINA', 1, 40, NULL, 1, 3, 42, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17096, '2016-06-26 16:53:39.627069+00', '2016-06-26 16:53:39.627069+00', 'Platinum Reel', 'PLATINUM REEL', 1, 32, NULL, 1, 3, 42, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17110, '2016-06-30 21:13:11.065769+00', '2016-06-30 21:13:11.065769+00', 'Reel Friends', 'REEL FRIENDS', 1, 40, NULL, 3, 5, 4, 11290, '2005-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17111, '2016-06-30 21:16:29.330029+00', '2016-06-30 21:16:29.330029+00', 'Roddie''s Rant', 'RODDIES RANT', 4, 96, 11, 4, 4, 54, 11289, '2005-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17115, '2016-06-30 21:28:31.867928+00', '2016-06-30 21:28:31.867928+00', 'Southsea Castle', 'SOUTHSEA CASTLE', 1, 32, NULL, 4, 5, NULL, 11283, '2005-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16213, '2015-04-20 13:31:25.52319+00', '2015-04-20 13:31:25.52319+00', 'Moss Park', 'MOSS PARK', 2, 96, 9999, NULL, 99, 3, 11118, '1995-10-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17210, '2016-09-03 16:48:38.226745+00', '2016-09-03 16:48:38.226745+00', 'Rapunzel', 'RAPUNZEL', 3, 32, NULL, 2, 3, NULL, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17215, '2016-09-03 16:56:34.259085+00', '2016-09-03 16:56:34.259085+00', 'Court Circular, The', 'COURT CIRCULAR', 2, 32, NULL, 4, 4, NULL, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10327, '2002-01-13 23:00:00+00', '2017-09-26 00:58:17.560542+00', 'OXO Reel', 'OXO REEL', 1, 32, 9999, 8, 6, 9, 9998, NULL, 'This is a simplified version of the Opera Reel, an ECD dance



Heiko Schmidt has made an extensive study of 3 text descriptions and 15 YouTube videos of this dance.  It became clear that questions like ‘What is the correct description?’ or ‘What is the correct title?’ cannot be answered with any certainty.



The sources use three names: “OXO Reel” (13 times), “The OXO Reel” (4 times) and “OXO Dance” (once).

For this dance a plethora of variants seems to have evolved and are being danced in various communities.  The 18 sources show 12 different variants.  No ‘official description'', if it ever existed, could be found.



All variants have two common elements:  on bars [1-4] ‘All Advance and Retire’, and on bars [17-24] the middle two couples dance ‘Right Hands Across, Left Hands Across’, while both ends dance 4 Hands Round Left, then Right (OXO figure).  That is certainly the reason for the OXO Reel’s name.



Other figures that occur in various combinations are ‘All change sides (Men make arches)’; ‘All turn RH then LH’; ‘All dance Back to Back (R shoulder or L sh); One (or two) couples slip to the bottom, or back to the top, or cast off; ‘All dance up through the first couple’s arch at the bottom’.  The most common progression is (2,3,4,5,6,1), but (3,4,5,6,1,2) also occurs.



The “Minicrib” and “Eric’s crib” for this dance show just two of the variants.



All the variants that Heiko found are listed down below.  Each is designated by a letter.  A digit following the lettter denotes other sources for that variant.   There is no clearly supported variant, but variant d has 4 sources, variants b, f and g have two each.



The lists below give the details of each of the 18 sources (3 texts [b2, d1, d4] + 15 videos) with URL, source type, title and an optional note.

  



(b1) https://www.youtube.com/watch?v=Dd1XJsyComw [video 2]             "Oxo Reel" 

(b2) http://www.mts.net/~jinks/fd/oxoreel.htm [text]             “Oxo Reel” (on ‘Folk Dancing is Fun’) 

  



(c) https://www.youtube.com/watch?v=qD6BpyHrSAA [video 1]             “A Ceilidh in Skye, The OXO Reel” 

  



(d1) http://my.strathspey.org/dd/dance/10327/ [text]             “OXO Reel” (MiniCrib – SCDDB) 



(d2) https://www.youtube.com/watch?v=SZqk6BNBdZo [video 4]             "Bedcote Ceilidh Band - Oxo Reel" 



(d3) https://www.youtube.com/watch?v=sxLzNKFnXQI [video 5]             “OXO Reel - Still Reeling Ceilidh Band” 



(d4) http://www.ceilidhcalling.co.uk/danceviewpage.php?view=1&id=30 [text]             “OXO Reel” (John Brown Ceilidh Caller) 

  



(e) https://www.youtube.com/watch?v=GpdCZQKYAKQ [video 5]             "The Oxo Reel!" (at a wedding) 

  



(f1) https://www.youtube.com/watch?v=nT8RLmEA-tw [video 7]             Tiger Moth (1989) 20 (dance) OXO Reel and Free Polka 



(f2) https://www.youtube.com/watch?v=P52z-ZF_sdo [video 8]             The OXO Reel, Terri''s Memorial Ceilidh 



  

(g1) https://www.youtube.com/watch?v=bsPM6fR_u88 [video 9]             "The traditional English folk dance: The OXO Reel" 



(g2) https://www.youtube.com/watch?v=a81yG8QwuCc [video 3]             "OXO dance with The Garsdale Street Band" 



  

(h) https://www.youtube.com/watch?v=rqtu3xDfYho [video 10]             "Oxo Reel" 

  



(i) https://www.youtube.com/watch?v=1wIpA_wUUgY [video 11]             "Gergel School OXO Reel" 

  



(j) https://www.youtube.com/watch?v=PfdPFWh0F_A [video 12]             "NBprojects - OXO Reel" (workshop with professional dancers for the modern dance) 

  



(k) https://www.youtube.com/watch?v=f4oQ8tV_hWs [video 13]             "The OXO Reel" The OXO Reel as performed at the Lonach Hall Burns Celebration 2009

  



(l) https://www.youtube.com/watch?v=DIsM45omNQ4 [video 14]             "Oxo Reel.MPG" 

  



(m) https://www.youtube.com/watch?v=C2PJ6gCP1T4 [video 15]             "Ceilidh OXO Reel at St Andrew''s in Froideville Switzerland” 





Here are the figures appearing in each of the 12 variants (b-m), arranged per 8-bar phrase: 





------------------ 

bars 1-8:      



            Adv+Ret, B2B RSh                                       (b+c+g+h) 



            Adv+Ret, 1s slip-step to the bottom (to 234561)        (d+e+f) 



            Adv+Ret twice                                          (i+m) 



            Adv+Ret, swap sides (M make arches, W pass under       (j+k) 



            Adv+Ret, TR                                            (l) 



  

————— 





bars 9-16:    



            all cpls TR+TL                                              (b+c+i+m)

 

            Adv+Ret, 2s slip-step to the bottom (to 345612)             (d+e+f) 



            Adv+Ret, B2B RSh                                            (g) 



            Adv+Ret, B2B LSh                                            (h) 



            Adv+Ret,in pairs: swap sides (M make arches, W pass under   (j+k) 



            Adv+Ret, TR                                                 (l) 



  

————— 



bars 17-24: 



            OXO (1+2 and 5+6  ‘4H round+back’; 3+4 ‘RHA+LHA’)      (b+c+d+e+f+g+h+i+j+k+l) 

  

————— 





bars 25-32: 



25-28 



            1s slip-step to the bottom                                         (b+g) 



            1s+2s slip-step to the bottom                                      (c+i) 



            2s slip-step to the top (to 234561)                                (d) 



            1s+2s slip-step to the top and…                                    (e+f) 



            1s swing turn to the bottom                                        (g+h) 



            1s+2s slip-step to the bottom, 3s+4s+5s+6s slip-step to the top    (j) 



            1s slip-step down for 2 up for 2                                   (k) 



            1s cast off to bottom, while all others swing/turn for 4 bars      (l) 



  

29-32 



            all TR (or swing)                                                  (b+c+d+g+j) 



            … 1s+2s cast off to the end (to 345621)                            (e) 



            … 1s cast off to the end (to 234561) while all other swing turn    (f) 



            … continue swing turn to the bottom                                (h) 



            stand for 4 bars                                                   (i) 



            1s followed by the others cast off to bottom, make arch, All others dance up through the arch                   (k) 



            … continue 1s cast off to bottom, while others swing/turn for 4 bars   (l) 

', 90, '888888  888888  888888  844444', 0, 1, 1, 0, 68);
INSERT INTO 'dance' VALUES (11757, '2004-07-27 22:00:00+00', '2018-10-05 13:11:42.159649+00', '''Hans''ome Dancer, The', 'HANSOME DANCER', 1, 32, 9999, 4, 4, 1, 2766, '2004-01-01', 'This dance was written in honor of Bryan Luce’s dearly beloved dachshund Hans, who left us at the age of 16 in December 2003. The men start out active in this dance, to reflect a man and his male dog playing happily together.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17108, '2016-06-30 21:06:01.171388+00', '2018-11-11 07:41:05.233151+00', 'Misty Vale', 'MISTY VALE', 3, 40, NULL, 1, 4, 1, 11292, '2005-01-01', '', 78, '8888/8440/8004/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8837, '2000-06-04 22:00:00+00', '2018-11-18 19:43:40.452044+00', 'Jessie Wiseman''s Reel', 'JESSIE WISEMANS REEL', 2, 32, 9999, 1, 3, 42, 2419, NULL, '', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (16187, '2015-04-08 15:20:38.698482+00', '2018-04-02 23:56:33.171771+00', 'Bridesmen and Groomsmaids', 'BRIDESMEN AND GROOMSMAIDS', 3, 32, 9999, 1, 3, 42, 10612, '2010-12-14', 'If danced in a Longwise - 3 set, 1st couple twirl out to 3rd place on the last 2 bars', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15968, '2015-02-04 07:03:05.700907+00', '2015-04-10 22:03:58.204834+00', 'Maggieknockater Revisited', 'MAGGIEKNOCKATER REVISITED', 2, 32, NULL, 1, 100, 2, 228, '2015-02-03', 'For Ulrike Köppler, whose Internet domain name is “maggieknockater.de”.



This dance is obviously inspired by <<ddp:Drewry, John>>''s <<ddd:The Bees of Maggieknockater>>.

The dancing couples'' movements during bars 9–25 are identical to those in that dance.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16188, '2015-04-11 17:01:14.912462+00', '2015-04-11 17:01:14.912462+00', 'Hin-Kat Chase', 'HINKAT CHASE', 1, 64, 9999, 1, 4, 1, 10612, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16192, '2015-04-11 18:02:57.953575+00', '2015-04-11 18:02:57.953575+00', 'Gliding into the Sixties', 'GLIDING INTO THE SIXTIES', 3, 128, 9999, 8, 6, NULL, 10612, '2012-01-01', 'New top couples start on bars 21!

Final 4 bars (125-128) all couples turn both hands', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5110, '1997-09-10 22:00:00+00', '2015-04-12 07:10:40.387025+00', 'Oregon Trail, The', 'OREGON TRAIL', 3, 32, 9999, 1, 4, 2, 1183, NULL, 'The dance may be interpreted to suggest the Oregon Trail thusly: 



 Bars 



 1-8    Wagon wheels. 



 9-20   Forming wagon trains and crossing the plains. 



21-28   Helping   one   another   to    cross  mountains and rivers.

 

29-32   Circling the wagons for safety. ', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14631, '2012-12-18 13:32:17.982748+00', '2018-04-03 00:08:19.012765+00', 'Summer Dreams', 'SUMMER DREAMS', 1, 32, NULL, 1, 3, 42, 1089, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17181, '2016-08-21 22:52:37.688606+00', '2020-10-22 20:37:48.190354+00', 'Dancer''s Road, The', 'DANCERS ROAD', 1, 40, NULL, 1, 3, 42, 11317, '2016-01-01', '', 50, '800/888/800/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17205, '2016-09-03 16:37:44.141436+00', '2020-11-28 11:18:58.316562+00', 'Hadron Collider', 'HADRON COLLIDER', 1, 32, NULL, 1, 3, 42, 10995, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16200, '2015-04-12 16:55:12.966975+00', '2020-12-29 18:37:37.14975+00', 'Fairy Pools of Skye, The', 'FAIRY POOLS OF SKYE', 2, 32, 9999, 1, 3, 42, 10612, '2009-01-01', '', 72, '866/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2513, '1997-09-18 22:00:00+00', '2021-06-17 21:44:54.887064+00', 'Glen Erin Jig', 'GLEN ERIN JIG', 2, 32, 9999, 1, 3, 42, 80, '1993-01-01', '', 56, '800/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17112, '2016-06-30 21:22:05.294626+00', '2022-12-04 13:09:40.016865+00', 'Round Tower, The', 'ROUND TOWER', 3, 32, NULL, 4, 5, 95, 11288, '2005-01-01', '', 60, '88888/60608/06068/42442', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1541, '1997-04-03 22:00:00+00', '2021-08-02 20:00:20.78253+00', 'Dancing in the Dark', 'DANCING IN THE DARK', 3, 32, 9999, 1, 4, 1, 411, '1983-01-01', 'Dedicated to the friends who joined me on a series of annual caving trips held on the weekend of the Te Awamutu Ball.', 88, '8888/8888/8888/8242', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16193, '2015-04-12 15:00:59.402062+00', '2015-04-12 15:02:27.310491+00', '60 Candles! Dance the Cake!', '60 CANDLES DANCE THE CAKE', 1, 40, 9999, 5, 113, 4, 10759, NULL, '(ideally for 30 couples)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16195, '2015-04-12 15:29:28.447615+00', '2015-04-12 15:29:49.237483+00', 'Diamonds on the Soles of her Shoes', 'DIAMONDS ON THE SOLES OF HER SHOES', 1, 32, 9999, 1, 102, 2, 11117, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16199, '2015-04-12 16:20:14.634046+00', '2015-04-12 16:20:14.634046+00', 'Erika''s Way', 'ERIKAS WAY', 2, 40, 9999, 5, 113, 4, 10759, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16201, '2015-04-12 17:08:25.091465+00', '2015-04-12 17:08:25.091465+00', 'Hands Across with Hude', 'HANDS ACROSS WITH HUDE', 4, 128, 2, 4, 4, 3, 635, '2010-01-01', 'Music: Schiehallion or something similar', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16203, '2015-04-12 17:22:36.514997+00', '2015-04-12 17:22:36.514997+00', 'Norden Circle', 'NORDEN CIRCLE', 2, 32, 9999, 5, 113, 4, 10612, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16205, '2015-04-15 09:58:55.715078+00', '2015-04-15 09:58:55.715078+00', 'Kramermarkt Reel', 'KRAMERMARKT REEL', 1, 32, 9999, 5, 113, 4, 10759, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16207, '2015-04-15 10:25:39.765455+00', '2015-04-15 10:25:39.765455+00', 'Feline Friends', 'FELINE FRIENDS', 1, 32, 9999, 5, 113, NULL, 10759, '2011-11-28', 'Not for beginners. The dance is intentnded to be used as an exercise for "Set & Rotate"', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16208, '2015-04-15 10:45:03.886795+00', '2015-04-15 10:45:03.886795+00', 'Feline Friends Reloaded', 'FELINE FRIENDS RELOADED', 1, 32, 9999, 5, 113, NULL, 10759, '2011-11-28', 'For intermediate dancers.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16209, '2015-04-15 10:56:38.37289+00', '2015-04-15 10:56:38.37289+00', 'Hummingbirds in Oldenburg', 'HUMMINGBIRDS IN OLDENBURG', 2, 40, 9999, 5, 113, NULL, 10759, '2011-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16211, '2015-04-15 11:15:12.1086+00', '2015-04-15 11:15:12.1086+00', 'Hogmanay Rebels', 'HOGMANAY REBELS', 1, 40, 9999, 5, 2, NULL, 10759, '2012-12-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (358, '1998-11-25 23:00:00+00', '2019-03-19 23:01:35.497309+00', 'Balgeddie Reel', 'BALGEDDIE REEL', 1, 32, 9999, 3, 5, 7, 50, '1974-01-01', 'According to a tradition of unknown origin and authority, the men have hands on hips while setting on bars 1-4.', 57, '40400  80800  88888  84844', 0, 1, 0, 0, 57);
INSERT INTO 'dance' VALUES (16190, '2015-04-11 17:29:21.578707+00', '2019-03-24 11:32:03.147896+00', 'Potter''s Pairs, The', 'POTTERS PAIRS', 1, 32, 9999, 1, 4, 2, 11115, '2007-01-01', '', 88, '8008/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9224, '2001-12-17 23:00:00+00', '2015-04-17 19:52:42.638216+00', 'Ann of Gleneagles', 'ANN OF GLENEAGLES', 2, 32, 9999, 1, 4, 2, 108, '1997-03-01', 'for Ann Ferries of Vancouver, B.C.  Ann is a member of the Gleneagles Class in Vancouver', 81, '4444/8888/8448/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16198, '2015-04-12 16:11:34.033362+00', '2016-07-15 22:39:55.266711+00', 'Hudeln!', 'HUDELN', 1, 32, 9999, 5, 2, 76, 10759, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16216, '2015-04-21 22:07:18.629592+00', '2015-04-21 22:07:18.629592+00', 'President''s Strathspey, The', 'PRESIDENTS STRATHSPEY', 3, 80, NULL, 4, 4, 3, 11119, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16279, '2015-05-06 14:02:01.006331+00', '2018-04-02 23:56:33.422621+00', 'Center Street Assembly, The', 'CENTER STREET ASSEMBLY', 3, 32, 9999, 1, 3, 42, 361, '2010-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16240, '2015-05-01 12:30:20.855144+00', '2015-05-01 12:30:20.855144+00', 'Symmetry', 'SYMMETRY', 3, 32, 9999, 2, 3, 18, 84, '2011-07-20', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16233, '2015-05-01 11:30:15.958284+00', '2018-04-02 23:56:35.301813+00', 'Inquisitress, The', 'INQUISITRESS', 1, 32, 9999, 1, 3, 42, 84, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16249, '2015-05-01 15:57:42.540985+00', '2018-04-02 23:56:35.911275+00', 'Link with the Past', 'LINK WITH THE PAST', 1, 32, 9999, 1, 3, 42, 352, '2005-07-20', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16237, '2015-05-01 11:52:12.959479+00', '2018-04-02 23:56:36.249654+00', 'Meeting at Montpellier', 'MEETING AT MONTPELLIER', 3, 32, 9999, 1, 3, 42, 84, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16242, '2015-05-01 13:34:41.021115+00', '2018-04-02 23:56:38.373938+00', 'Visit to Orkney, A', 'VISIT TO ORKNEY', 1, 32, 9999, 1, 3, 42, 84, '2013-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16246, '2015-05-01 15:18:39.279572+00', '2015-09-05 22:52:07.200515+00', 'Active Duty', 'ACTIVE DUTY', 1, 32, 9999, 1, 4, 1, 352, '2002-12-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8144, '1997-12-06 23:00:00+00', '2015-04-28 16:01:05.00064+00', 'Circle Waltz', 'CIRCLE WALTZ', 5, 32, 9999, 7, 113, 4, 1993, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1989, '1997-09-01 22:00:00+00', '2015-04-29 23:04:45.008675+00', 'Enniskillen Dragoons', 'ENNISKILLEN DRAGOONS', 2, 32, 9999, 1, 4, 1, 877, NULL, '', 50, '8000/8484/8080/8008', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16226, '2015-05-01 09:56:25.736336+00', '2015-05-01 09:56:25.736336+00', 'Canadian Ladies', 'CANADIAN LADIES', 3, 32, 9999, 4, 4, 13, 84, '2013-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18286, '2018-04-22 13:43:34.402079+00', '2018-04-23 13:37:27.190699+00', 'Centenary Reel', 'CENTENARY REEL', 1, 32, NULL, 3, 5, 7, 3414, NULL, 'Note:  

The last 4 bars makes the figure "100".', 69, '80800/84884/84864/84884', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16229, '2015-05-01 10:23:01.727394+00', '2015-05-01 10:23:01.727394+00', 'EIEIO', 'EIEIO', 3, 32, 9999, 2, 3, 17, 84, '2014-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16294, '2015-05-07 09:32:29.910516+00', '2018-10-01 17:13:07.763489+00', 'Big Banff Critter', 'BIG BANFF CRITTER', 2, 32, NULL, 1, 3, 42, 2766, '2010-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16276, '2015-05-06 12:48:27.275256+00', '2015-05-06 12:48:27.275256+00', 'Love Weaves the Web', 'LOVE WEAVES THE WEB', 3, 40, 9999, 2, 3, 18, 2719, '1995-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16230, '2015-05-01 10:29:28.952554+00', '2020-01-11 23:47:03.991247+00', 'Ellen''s Strathspey', 'ELLENS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 84, '2013-05-01', 'Bars 25-32 have the Left Hand Switch', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16232, '2015-05-01 10:52:41.102571+00', '2020-01-11 23:44:28.406228+00', 'Gillie''s Jig', 'GILLIES JIG', 2, 32, 9999, 1, 3, 42, 84, '2006-01-01', 'Bars 25-32 have the Right Hand Switch', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16218, '2015-04-21 22:19:29.271912+00', '2020-10-15 08:40:25.707677+00', 'Diamond 96', 'DIAMOND 96', 2, 32, NULL, 1, 4, 1, 11121, '1996-01-01', '', 69, '8080/6666/8888/8080', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16219, '2015-04-21 22:25:11.278392+00', '2020-10-15 08:52:48.80689+00', 'Medley for Maisie & Nellie', 'MEDLEY FOR MAISIE AND NELLIE', 4, 128, 2, 4, 4, 3, 2741, '1996-01-01', '', 62, '8888/8080/8080/8080/0808/0808/0808/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9742, '2002-08-29 22:00:00+00', '2020-11-15 13:06:58.207382+00', 'Mary H., The', 'MARY H', 1, 32, 9999, 1, 4, 1, 1346, '1997-01-01', '', 100, '8888  8888  8888  8888', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (18614, '2018-09-17 17:09:33.129497+00', '2020-11-18 09:53:56.867511+00', 'Christine''s Bannocks', 'CHRISTINES BANNOCKS', 1, 32, NULL, 1, 3, 42, 3632, '2011-04-23', '', 38, '800/844/822/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7494, '1997-07-15 22:00:00+00', '2021-03-26 22:39:19.671767+00', 'Question?, The', 'QUESTION', 3, 64, 9999, 4, 4, 8, 154, NULL, '', 80, '8000  8080  8080  8888    {8880  8888  8888  8888}x3    0808  0808  0808  8888', 0, 1, 0, 0, 200);
INSERT INTO 'dance' VALUES (16197, '2015-04-12 15:59:58.28563+00', '2021-01-18 23:51:10.580459+00', 'ToBe FoTy', 'TOBE FOTY', 1, 32, 9999, 1, 4, 15, 10612, '2012-09-01', 'A dance for my friend Tobias Hünger''s 40th Birthday.', 67, '8000/8888/8222/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16227, '2015-05-01 10:05:09.717986+00', '2021-06-06 11:38:50.604397+00', 'Cheltenham Races', 'CHELTENHAM RACES', 1, 32, 9999, 3, 5, 7, 84, '2007-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16196, '2015-04-12 15:42:55.721365+00', '2021-07-04 20:41:43.723423+00', 'JuhuuubiThirty 3(xxx)0', 'JUHUUUBITHIRTY 3XXX0', 1, 32, 9999, 2, 3, 17, 10612, '2012-01-01', 'A dance for Judith’s 30th Birthday.



Can also be danced as a Medley 3x(S32+R32), see video 1 made by the author.', 56, '800/880/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3566, '2002-08-29 22:00:00+00', '2021-07-30 07:48:07.773367+00', 'Lack o'' Men', 'LACK O MEN', 1, 40, 9999, 2, 101, 30, 308, '1995-03-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16202, '2015-04-12 17:14:17.731272+00', '2021-10-27 11:20:43.986418+00', 'Hu''de Hell', 'HUDE HELL', 1, 32, 9999, 4, 4, 4, 10612, NULL, 'Although a square set this is described as an 8x32 reel: all finally ending back with original partner in original places.', 72, '8080/0808/7777/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16228, '2015-05-01 10:16:04.496652+00', '2018-09-27 22:38:32.566339+00', 'Cotswold Cross', 'COTSWOLD CROSS', 3, 64, 9999, 107, 4, 3, 84, '2009-01-01', 'A 64 bar strathspey for four couples in the form of a cross.

The men begin on the inside of the set at arm''s length, facing anti-clockwise, right hands joined with their partners who are facing clockwise.', 100, '8888/8888/8888/8888/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16223, '2015-04-26 01:31:00.87535+00', '2018-10-05 15:57:39.675172+00', 'Knot Cross', 'KNOT CROSS', 3, 32, 9999, 1, 3, 42, 2766, '2010-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1949, '1998-11-29 23:00:00+00', '2022-09-22 10:35:07.898599+00', 'Elizabeth II', 'ELIZABETH II', 1, 32, 9999, 1, 3, 42, 868, NULL, '', 53, '800/888/866/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16236, '2015-05-01 11:46:45.295283+00', '2015-05-01 11:46:45.295283+00', 'Lionkop Strathspey', 'LIONKOP STRATHSPEY', 3, 32, 9999, 2, 3, 18, 84, '2013-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16301, '2015-05-08 19:44:58.815883+00', '2019-01-30 01:12:23.704878+00', 'Cooking up a Storm', 'COOKING UP A STORM', 1, 32, 9999, 1, 4, 2, 11133, '2010-01-01', '', 75, '8888/8888/8008/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16238, '2015-05-01 11:56:43.255733+00', '2015-05-01 11:56:43.255733+00', 'Montpellier Gardens', 'MONTPELLIER GARDENS', 3, 32, 9999, 2, 3, 17, 84, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16239, '2015-05-01 12:03:24.852836+00', '2015-05-01 12:03:24.852836+00', 'Roundabout', 'ROUNDABOUT', 1, 40, 9999, 2, 3, 17, 84, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4890, '1998-09-29 22:00:00+00', '2019-10-13 19:58:39.120388+00', 'Neidpath Castle', 'NEIDPATH CASTLE', 3, 32, 9999, 2, 3, 17, 175, NULL, '##>>

The Castle overlooks the River Tweed about one mile west of Peebles in the Borders. There are numerous websites dedicated to the history of the Castle which is currently owned by the Earl of Wemyss.

##<<', 77, '888/888/810/845', 1, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (16245, '2015-05-01 14:28:21.635371+00', '2015-05-01 14:28:21.635371+00', 'Twist of Thistle, A', 'TWIST OF THISTLE', 3, 32, 9999, 1, 4, 1, 352, '2007-03-15', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16247, '2015-05-01 15:27:42.210073+00', '2015-05-01 15:27:42.210073+00', 'Crossing Over', 'CROSSING OVER', 2, 32, 9999, 1, 4, 1, 352, '2003-06-26', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16248, '2015-05-01 15:46:46.940688+00', '2015-05-01 15:46:46.940688+00', 'Dance if You Dare', 'DANCE IF YOU DARE', 3, 32, 9999, 1, 4, 1, 352, '2006-03-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16250, '2015-05-01 16:12:29.085036+00', '2015-05-01 16:12:29.085036+00', 'Lost in the Dance', 'LOST IN THE DANCE', 2, 32, 9999, 1, 4, 2, 352, '2003-12-14', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16251, '2015-05-01 16:21:14.187905+00', '2015-05-01 16:21:14.187905+00', 'Mist on Manaia', 'MIST ON MANAIA', 1, 32, 9999, 1, 4, 11, 352, '2006-10-26', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16252, '2015-05-01 16:33:20.365607+00', '2015-05-01 16:33:20.365607+00', 'Northland Reel', 'NORTHLAND REEL', 1, 32, 9999, 1, 4, 1, 352, '2003-06-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16253, '2015-05-01 16:43:15.501661+00', '2015-05-01 16:43:15.501661+00', 'Split Tack', 'SPLIT TACK', 3, 32, 9999, 4, 4, NULL, 352, '2004-08-26', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16254, '2015-05-01 16:47:21.967279+00', '2015-05-01 16:47:21.967279+00', 'Retirement Reel', 'RETIREMENT REEL', 2, 32, 9999, 1, 4, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16224, '2015-05-01 09:42:33.571173+00', '2016-03-27 15:20:26.127785+00', 'Bergvliet Jig, The', 'BERGVLIET JIG', 2, 32, 9999, 1, 3, 18, 84, '2006-01-01', 'Bergvliet (pronounced Berg-fleet).  The Bergvliet Scottish Country Dancers are a groups affiliated to the Cape Town RSCDS.

', 62, '888/040/12 12 12/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16263, '2015-05-04 13:45:43.724674+00', '2018-04-02 23:56:33.012071+00', 'Big 50, The', 'BIG 50', 2, 32, 9999, 1, 3, 42, 488, '1991-04-14', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16265, '2015-05-04 14:17:10.740935+00', '2018-04-02 23:56:33.037246+00', 'Black Archie''s Reel', 'BLACK ARCHIES REEL', 1, 32, 9999, 1, 3, 42, 488, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15861, '2015-01-20 14:42:45.676927+00', '2015-05-02 23:02:59.286526+00', 'Hat Trick, The', 'HAT TRICK', 3, 32, 9999, 1, 4, 2, 3618, '2004-10-01', 'Devised by Bob Anderson in October 2004 for the October workshop in Medicine Hat, Alberta ', 87, '8888/8888/8888/8008', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16268, '2015-05-04 14:42:02.316144+00', '2018-04-02 23:56:33.414337+00', 'Celtic Band, The', 'CELTIC BAND', 2, 32, 9999, 1, 3, 42, 488, '1990-05-07', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16256, '2015-05-04 08:14:05.42399+00', '2015-05-04 08:14:05.42399+00', 'First Dance', 'FIRST DANCE', 1, 32, NULL, 5, 113, 30, 11127, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9911, '2002-01-08 23:00:00+00', '2015-05-04 10:22:06.120427+00', 'Mairi''s Divorce', 'MAIRIS DIVORCE', 1, 40, 9999, 1, 3, 42, 2865, '1998-01-01', 'In “Mairi’s Wedding” some dancing couples prefer to pass Rsh for [9-24], against James Cosh’s emphatically clear instructions to pass LEFT shoulder. Dance ''devised'' [tongue in cheek] with this (nick)name by Angus Henry, 1998.



For videos, please go to "Mairi''s Wedding". In fact, most of the videos show the R shoulder variant.', 55, '800/844/844/888/888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (16260, '2015-05-04 13:08:39.449286+00', '2015-05-04 13:08:39.449286+00', 'Kenandflo Reel, The', 'KENANDFLO REEL', 1, 32, 9999, 5, 2, NULL, 488, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16262, '2015-05-04 13:39:31.984212+00', '2015-05-04 13:39:31.984212+00', 'Where the Rivers Meet', 'WHERE THE RIVERS MEET', 2, 32, 9999, 1, 4, 1, 488, '1997-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18617, '2018-09-17 18:07:06.249833+00', '2019-02-23 18:54:38.131785+00', 'Fairgrieve''s Fancy', 'FAIRGRIEVES FANCY', 1, 40, NULL, 1, 4, 1, 2990, NULL, '', 75, '4884/8448/8440/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16271, '2015-05-06 11:38:19.004184+00', '2015-05-06 11:38:19.004184+00', 'Twenty at First', 'TWENTY AT FIRST', 3, 32, 9999, 3, 5, 7, 361, '2010-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16272, '2015-05-06 11:43:12.196315+00', '2015-05-06 11:43:12.196315+00', 'Northampton Welcome, A', 'NORTHAMPTON WELCOME', 1, 32, 9999, 5, 2, NULL, 2719, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16274, '2015-05-06 12:05:55.69889+00', '2015-05-06 12:05:55.69889+00', 'Daisy Chain', 'DAISY CHAIN', 3, 32, 9999, 4, 4, 1, 3099, '2010-05-06', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16291, '2015-05-06 22:55:00.439577+00', '2020-05-30 23:56:53.564543+00', 'Away and Back Again', 'AWAY AND BACK AGAIN', 1, 32, NULL, 1, 3, 42, 2766, '2009-07-01', '', 56, '804/888/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16235, '2015-05-01 11:41:10.921422+00', '2020-01-11 23:48:17.989733+00', 'Korrie Deukit', 'KORRIE DEUKIT', 1, 32, 9999, 1, 3, 42, 84, '2006-01-01', 'Bars 17-24 have the Left Hand Switch', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16289, '2015-05-06 22:43:26.781351+00', '2020-05-15 07:33:32.156538+00', 'Afternoon Nap', 'AFTERNOON NAP', 1, 32, NULL, 1, 3, 42, 2766, '2009-06-01', 'This dance was came to me during an afternoon nap.', 53, '888/800/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16220, '2015-04-21 22:34:13.83527+00', '2020-10-15 21:30:50.701572+00', 'Golden Jubilee Reel, The', 'GOLDEN JUBILEE REEL', 1, 192, NULL, 4, 4, 3, 11122, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4432, '1997-04-03 22:00:00+00', '2020-08-07 03:44:21.239074+00', 'Miss Betsy Robertson', 'MISS BETSY ROBERTSON', 3, 32, 9999, 1, 3, 42, 129, NULL, 'Dance devised for Mrs. Gordon of Wishaw', 40, '840/804/844/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18616, '2018-09-17 18:04:14.514368+00', '2020-11-18 12:53:15.760903+00', 'Danger Is Sweet', 'DANGER IS SWEET', 1, 32, NULL, 1, 3, 42, 10715, '2002-08-01', '', 63, '888/888/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18615, '2018-09-17 17:59:10.86168+00', '2020-11-18 12:55:58.842419+00', 'Crannog Gathering, The', 'CRANNOG GATHERING', 1, 32, NULL, 7, 113, 4, 11707, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16217, '2015-04-21 22:12:57.709928+00', '2020-11-28 11:22:57.432844+00', 'Diamonds for the Ladies', 'DIAMONDS FOR THE LADIES', 1, 96, NULL, 4, 4, 4, 11120, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16296, '2015-05-08 19:09:14.28798+00', '2020-12-29 12:36:45.77265+00', 'At the Henderson Hearth', 'AT THE HENDERSON HEARTH', 3, 32, 9999, 2, 3, 17, 11133, '2010-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16258, '2015-05-04 10:52:33.246295+00', '2020-12-29 12:39:50.105539+00', 'Eighteen Years On', 'EIGHTEEN YEARS ON', 1, 32, 9999, 1, 3, 42, 11128, '2008-01-31', '', 59, '800/888/888/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10441, '2002-03-27 23:00:00+00', '2021-01-04 17:46:55.356182+00', 'Royal Tunbridge Wells', 'ROYAL TUNBRIDGE WELLS', 3, 32, 9999, 1, 100, 2, 84, '2001-01-01', '', 81, '5555/8888/8888/8228', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11189, '2003-02-16 23:00:00+00', '2021-05-26 21:48:03.239485+00', 'Piper and the Penguin, The', 'PIPER AND THE PENGUIN', 1, 88, 9999, 4, 4, 3, 146, '2002-01-01', 'For more information and a photo see <<https://rscdsvancouver.org/resources/the-white-cockade/antarctic-hero/|this article>> on the Vancouver branch website (<<https://rscdsvancouver.org/resources/the-white-cockade/antarctic-hero/>>).', 54, '4444  4444  4444  4444  8080  8080  0808  0808  4444  4444  8888', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (16286, '2015-05-06 15:05:07.681104+00', '2021-06-06 11:35:06.415014+00', 'Draught Dance, The', 'DRAUGHT DANCE', 2, 32, 9999, 1, 3, 42, 11129, '2006-01-01', '', 50, '800/808/888/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16293, '2015-05-07 09:26:09.082882+00', '2018-10-01 23:58:19.425552+00', 'Bicycle Chain', 'BICYCLE CHAIN', 1, 32, NULL, 3, 5, 26, 2766, '2010-03-01', '', 40, '80008/84048/40804/00800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16267, '2015-05-04 14:34:05.170513+00', '2018-04-02 23:56:34.951091+00', 'Golden Mile, The', 'GOLDEN MILE', 3, 32, 9999, 1, 3, 42, 488, '1994-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16281, '2015-05-06 14:14:13.158531+00', '2015-05-06 14:14:13.158531+00', 'Whirligig Jig', 'WHIRLIGIG JIG', 2, 32, 9999, 2, 3, 18, 3099, '2010-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14930, '2013-05-30 22:44:22.293796+00', '2015-05-06 14:17:08.545108+00', 'Spring Fever', 'SPRING FEVER', 3, 32, 9999, 2, 3, 17, 1394, '1995-05-22', '', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16261, '2015-05-04 13:22:24.665532+00', '2018-04-02 23:56:35.393589+00', 'Jack''s Rant', 'JACKS RANT', 1, 32, 9999, 1, 3, 42, 488, '1986-05-05', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16280, '2015-05-06 14:08:23.412453+00', '2018-04-02 23:56:36.328655+00', 'Minister of Paradise, The', 'MINISTER OF PARADISE', 1, 32, 9999, 1, 3, 42, 3099, '2010-03-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16283, '2015-05-06 14:42:23.779855+00', '2022-08-18 09:15:43.574635+00', 'Ghosts & Goblins', 'GHOSTS AND GOBLINS', 2, 32, 9999, 1, 4, 1, 3099, '2003-10-03', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16270, '2015-05-04 15:00:48.982214+00', '2018-04-03 00:08:12.399941+00', 'Reel in the Twenty-First', 'REEL IN THE TWENTYFIRST', 1, 32, 9999, 1, 3, 42, 488, '1999-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16278, '2015-05-06 13:45:00.690217+00', '2018-04-02 23:56:36.729605+00', 'Northampton Jig', 'NORTHAMPTON JIG', 2, 32, 9999, 1, 3, 42, 361, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14394, '2012-01-06 23:00:00+00', '2017-02-07 12:47:52.534012+00', 'Courtney Jane', 'COURTNEY JANE', 2, 32, NULL, 2, 3, 17, 2865, '2010-02-01', 'Commissioned for the anniversary of 10 years of SC dancing in Kununurra, W. Australia, and dedicated to the memory of Courtney Jane Kuiper.



The dance can be adapted for a 4C set; 4C stpes up on bares 1-2; progression 2341.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16284, '2015-05-06 14:52:51.39911+00', '2018-04-02 23:56:37.272172+00', 'Rev. Peter Ives, The', 'REV PETER IVES', 3, 32, 9999, 1, 3, 42, 361, '2010-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16282, '2015-05-06 14:25:47.859579+00', '2018-04-02 23:56:37.639869+00', 'Sleepless Reel', 'SLEEPLESS REEL', 1, 32, 9999, 1, 3, 42, 11131, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16275, '2015-05-06 12:31:55.281946+00', '2018-04-02 23:56:38.023631+00', 'Through the Looking Glass', 'THROUGH THE LOOKING GLASS', 2, 32, 9999, 1, 3, 42, 11130, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16264, '2015-05-04 14:07:58.702906+00', '2018-04-02 23:56:38.115548+00', 'Trilliums and Roses', 'TRILLIUMS AND ROSES', 3, 32, 9999, 1, 3, 42, 488, '1990-05-20', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16273, '2015-05-06 11:58:22.733149+00', '2018-04-02 23:56:38.348932+00', 'Virginia Jig, The', 'VIRGINIA JIG', 2, 32, 9999, 1, 3, 42, 361, '2010-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16269, '2015-05-04 14:50:58.372906+00', '2018-04-02 23:56:38.557673+00', 'Whistle Through the Glens, A', 'WHISTLE THROUGH THE GLENS', 3, 32, 9999, 1, 3, 42, 488, '1991-01-07', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16266, '2015-05-04 14:26:12.866361+00', '2018-04-03 00:07:43.677038+00', 'Dylan''s Dance', 'DYLANS DANCE', 1, 32, 9999, 1, 3, 42, 488, '1992-10-21', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16302, '2015-05-08 19:50:41.359006+00', '2015-05-08 19:50:41.359006+00', 'Dance of the Dinwoodie', 'DANCE OF THE DINWOODIE', 1, 32, 9999, 1, 4, 1, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16311, '2015-05-09 11:19:10.509812+00', '2018-04-03 00:18:02.170784+00', 'Flight of the Jays', 'FLIGHT OF THE JAYS', 2, 32, 9999, 2, 2, 76, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16304, '2015-05-08 20:08:05.267743+00', '2015-05-08 20:08:05.267743+00', 'Don''t Pick on Me', 'DONT PICK ON ME', 1, 32, 9999, 6, 53, 17, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16335, '2015-05-10 13:13:22.840033+00', '2018-04-02 23:56:33.347432+00', 'Caringbah Lass, The', 'CARINGBAH LASS', 2, 32, 9999, 1, 3, 42, 10433, '2011-06-06', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16310, '2015-05-09 11:04:41.046403+00', '2015-05-09 11:04:41.046403+00', 'Flawless Lady, The', 'FLAWLESS LADY', 2, 32, 9999, 2, 3, 17, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16303, '2015-05-08 20:01:31.598001+00', '2018-04-02 23:56:33.936817+00', 'Delicate Sheila, A', 'DELICATE SHEILA', 3, 32, 9999, 1, 3, 42, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16305, '2015-05-08 20:12:36.382331+00', '2018-04-02 23:56:34.007742+00', 'Doralyn''s Assembly', 'DORALYNS ASSEMBLY', 1, 32, 9999, 1, 3, 42, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16314, '2015-05-09 11:34:23.145164+00', '2015-05-09 11:34:23.145164+00', 'Gentlemen with Sass', 'GENTLEMEN WITH SASS', 2, 32, 9999, 2, 3, 17, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16307, '2015-05-09 10:20:39.970164+00', '2018-04-02 23:56:34.316421+00', 'Elizabeth''s Hornpipe', 'ELIZABETHS HORNPIPE', 1, 32, 9999, 1, 3, 42, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16316, '2015-05-09 12:31:45.148016+00', '2015-05-09 12:31:45.148016+00', 'Harland Hustle, The', 'HARLAND HUSTLE', 1, 32, 9999, 4, 55, 16, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16318, '2015-05-09 12:43:09.118399+00', '2015-05-09 12:43:09.118399+00', 'Lady Lorraine''s Strathspey', 'LADY LORRAINES STRATHSPEY', 3, 32, 9999, 1, 4, 2, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9443, '2002-04-23 22:00:00+00', '2018-10-01 00:17:26.804991+00', 'Lady, The', 'LADY', 3, 32, 9999, 1, 3, 42, 2764, '1994-01-01', 'devised by R. Spägele and C. Rembold for Karin Schnabl Schwäbisch Gmünd, July 1994', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16320, '2015-05-09 12:57:20.18595+00', '2015-05-09 12:57:20.18595+00', 'Martt Bagatelle, The', 'MARTT BAGATELLE', 3, 32, 9999, 1, 4, NULL, 11133, '2010-01-01', 'Bars 9-16 2s+1s and 4s+3s dance linked gypsy ladies chains up and down the set, 1M and 4M passing Lsh on bars 1-2 and 5-6 of the phrase, all turns with no hands.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18633, '2018-09-18 20:34:08.499762+00', '2018-10-01 10:11:14.759764+00', 'Hadrian''s Wall Strathspey', 'HADRIANS WALL STRATHSPEY', 3, 32, NULL, 2, 3, 17, 3617, '1996-10-01', '', 91, '888/888/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16322, '2015-05-09 15:26:13.115702+00', '2015-05-09 15:26:13.115702+00', 'McNair if You Dare', 'MACNAIR IF YOU DARE', 1, 48, 9999, 2, 3, 17, 11133, '2010-01-01', 'This dance incorporates both quicktime and strathspey steps, though it is danced to a reel. Steps are

assumed to be danced in quicktime unless otherwise stated as S STEP. One strathspey step takes up the

same amount of time as 2 quicktime steps.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16323, '2015-05-09 15:37:59.098099+00', '2015-05-09 15:37:59.098099+00', 'Moore the Merrier, The', 'MOORE THE MERRIER', 2, 32, 9999, 3, 5, 16, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16308, '2015-05-09 10:24:18.524167+00', '2018-04-02 23:56:34.404316+00', 'Everyday Joe', 'EVERYDAY JOE', 1, 32, 9999, 1, 3, 42, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16326, '2015-05-09 15:56:24.852048+00', '2015-05-09 15:56:24.852048+00', 'Scotch in August', 'SCOTCH IN AUGUST', 3, 32, 9999, 2, 3, 17, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16309, '2015-05-09 10:59:19.31386+00', '2018-04-02 23:56:34.604755+00', 'Flair McNair', 'FLAIR MACNAIR', 1, 32, 9999, 1, 3, 42, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16328, '2015-05-09 17:47:44.292032+00', '2015-05-09 17:47:44.292032+00', 'Stiles of Tartan', 'STILES OF TARTAN', 3, 32, 9999, 2, 3, 17, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16329, '2015-05-09 17:54:35.514653+00', '2015-05-09 17:54:35.514653+00', 'Sweet Treat from Our Feet to Dave Peet, A', 'SWEET TREAT FROM OUR FEET TO DAVE PEET', 2, 32, 9999, 7, 113, 4, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16330, '2015-05-09 18:00:05.701255+00', '2015-05-09 18:00:05.701255+00', 'Toast to the Galbraiths', 'TOAST TO THE GALBRAITHS', 1, 32, 9999, 1, 4, 2, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16331, '2015-05-09 18:06:25.61501+00', '2015-05-09 18:06:25.61501+00', 'Ye of Liddle Faith', 'YE OF LIDDLE FAITH', 1, 48, 9999, 4, 4, 13, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18618, '2018-09-17 18:09:52.165693+00', '2019-05-01 08:04:56.80323+00', 'Flitting Forever', 'FLITTING FOREVER', 2, 40, NULL, 1, 3, 42, 10240, '2012-07-01', '', 60, '888/844/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16333, '2015-05-09 20:22:07.040825+00', '2015-05-09 20:22:07.040825+00', 'Wind in the Reids', 'WIND IN THE REIDS', 3, 32, 9999, 2, 3, 17, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16317, '2015-05-09 12:36:47.999708+00', '2018-04-02 23:56:35.752569+00', 'Klemmer Clan, The', 'KLEMMER CLAN', 1, 32, 9999, 1, 3, 42, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16339, '2015-05-12 14:35:14.507007+00', '2018-04-02 23:56:35.886219+00', 'Licence to Reel', 'LICENCE TO REEL', 1, 32, NULL, 1, 3, 42, 11134, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16388, '2015-05-23 16:26:57.625095+00', '2015-05-23 16:26:57.625095+00', 'Ross Creek Mixer', 'ROSS CREEK MIXER', 2, 32, 9999, 5, 2, NULL, 2018, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16334, '2015-05-10 13:03:25.895088+00', '2018-04-02 23:56:38.1571+00', 'Turmoil', 'TURMOIL', 1, 32, 9999, 1, 3, 42, 10433, '2011-06-06', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16376, '2015-05-21 13:47:47.236412+00', '2015-05-21 13:47:47.236412+00', 'Hielan'' Padyane, The', 'HIELAN PADYANE', 3, 32, 9999, 3, 5, 7, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16377, '2015-05-21 13:54:59.646744+00', '2015-05-21 13:54:59.646744+00', 'Fair O'' Feir', 'FAIR O FEIR', 1, 32, 9999, 3, 5, 7, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16344, '2015-05-17 10:43:37.007998+00', '2018-04-03 00:18:02.439165+00', 'See a Man Sae Happy', 'SEE A MAN SAE HAPPY', 3, 32, 9999, 2, 2, 76, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16345, '2015-05-17 10:48:11.78807+00', '2018-04-03 00:18:02.481047+00', 'They Reel''d & Set', 'THEY REELD AND SET', 1, 32, 9999, 2, 2, 76, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16380, '2015-05-21 14:24:40.680961+00', '2015-05-21 14:24:40.680961+00', 'Moorburn', 'MOORBURN', 2, 32, 9999, 3, 5, 16, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16383, '2015-05-21 14:45:37.194676+00', '2015-05-21 14:45:37.194676+00', 'Wee Butt and Ben for Colleen, A', 'WEE BUTT AND BEN FOR COLLEEN', 3, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16381, '2015-05-21 14:30:46.463617+00', '2016-04-18 22:46:28.328712+00', 'River Jumped O''er the Mountain, The', 'RIVER JUMPED OER THE MOUNTAIN', 2, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16312, '2015-05-09 11:26:02.304268+00', '2022-04-25 20:21:50.937993+00', 'Gentleman Jenson''s Double Birl Strathspey', 'GENTLEMAN JENSONS DOUBLE BIRL STRATHSPEY', 3, 32, 9999, 2, 3, 17, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16287, '2015-05-06 15:14:53.56311+00', '2022-04-26 09:15:07.379355+00', 'Lyman Hall Reel', 'LYMAN HALL REEL', 3, 32, 9999, 1, 3, 42, 361, '2010-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16277, '2015-05-06 13:35:57.430876+00', '2022-08-14 15:21:47.264919+00', 'Rick''s Delight', 'RICKS DELIGHT', 1, 32, 9999, 1, 3, 42, 2719, '2003-01-03', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16285, '2015-05-06 15:00:12.702758+00', '2022-08-14 15:23:17.369963+00', 'Reel for Rick, A', 'REEL FOR RICK', 1, 32, 9999, 1, 3, 42, 3099, '2003-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2242, '1998-09-28 22:00:00+00', '2017-06-14 01:49:14.506624+00', 'Flower o'' the Quern, The', 'FLOWER O THE QUERN', 3, 32, 9999, 1, 100, 2, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Alistair Reid of Muchall''s Castle near Stonehaven.



Elsewhere the remark has been made that this dance should be called "Flour o'' the Quern" as a Quern is a grinding stone.



Ron Russell wrote the following:



As I understand it (although not a Gaelic speaker), a quern (pronounced ''kern'') is Gaelic for ''hollow''.



A verse is included as a dedication in James Scott Skinner’s original sheet music (see <<http://www.abdn.ac.uk/scottskinner/display.php?ID=JSS0750>>):



The flowers grow fair on the lowland vales, <BR>

an’ green grow the wids on the braes, <BR>

an’ saft an’ low sing the scented gales <BR>

in the lang, lang simmer days; <BR>

But dearer to me are the mountains blue <BR>

where grow the heath an’ fern, <BR>

an’ the bonniest flo’er is the ane I lo’e <BR>

that blooms ‘mang the braes o’ the Quern.



I believe this verse is by J. Gordon Phillips', 81, '8888  8008  8888  8448', 0, 1, 1, 0, 81);
INSERT INTO 'dance' VALUES (16319, '2015-05-09 12:47:25.481403+00', '2018-04-02 23:56:35.961563+00', 'Logan''s Ferry', 'LOGANS FERRY', 1, 32, 9999, 1, 3, 42, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16321, '2015-05-09 15:10:03.410504+00', '2018-04-02 23:56:36.228422+00', 'McClelland''s Mix-Up Reel', 'MACCLELLANDS MIXUP REEL', 1, 32, 9999, 1, 3, 42, 11133, '2010-01-01', 'Each couple will dance one turn of the dance as their original gender and then a second as the opposite gender.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16324, '2015-05-09 15:43:40.229216+00', '2018-04-02 23:56:36.571167+00', 'Mum''s the Ward', 'MUMS THE WARD', 1, 32, 9999, 1, 3, 42, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16336, '2015-05-10 13:22:56.910845+00', '2018-04-02 23:56:38.420347+00', 'Warren and Alice''s Strathspey', 'WARREN AND ALICES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 10433, '2011-06-06', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16332, '2015-05-09 20:16:30.992023+00', '2018-04-02 23:56:38.49914+00', 'Weia of the Thistle', 'WEIA OF THE THISTLE', 3, 32, 9999, 1, 3, 42, 11133, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5054, '1997-08-24 22:00:00+00', '2015-05-14 22:20:56.813098+00', 'Old Grey Cat, The', 'OLD GREY CAT', 1, 32, 9999, 1, 3, 42, 108, '1970-01-01', '', 44, '880/808/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16379, '2015-05-21 14:16:51.445136+00', '2018-04-02 23:56:32.744512+00', 'Armit Wi'' A''', 'ARMIT WI A', 1, 40, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16340, '2015-05-17 09:59:00.536802+00', '2015-05-17 09:59:00.536802+00', 'Wing''d Wi Pleasure', 'WINGD WI PLEASURE', 3, 32, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16341, '2015-05-17 10:04:12.152666+00', '2015-05-17 10:04:12.152666+00', 'Get Up and Rin', 'GET UP AND RIN', 1, 32, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16342, '2015-05-17 10:30:56.488795+00', '2015-05-17 10:30:56.488795+00', 'Mettle in Their Heels', 'METTLE IN THEIR HEELS', 3, 32, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16343, '2015-05-17 10:36:56.934198+00', '2015-05-17 10:36:56.934198+00', 'Quick & Quicker Flew', 'QUICK AND QUICKER FLEW', 1, 32, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16378, '2015-05-21 14:03:42.473269+00', '2018-04-02 23:56:33.000225+00', 'Bide Awhile', 'BIDE AWHILE', 3, 32, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16368, '2015-05-21 10:17:45.951411+00', '2018-04-02 23:56:34.742521+00', 'Frisk O''er the Drum', 'FRISK OER THE DRUM', 2, 32, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16386, '2015-05-21 15:01:32.831371+00', '2018-04-02 23:56:34.826095+00', 'Ganemountis, The', 'GANEMOUNTIS', 1, 40, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16356, '2015-05-19 17:32:36.826083+00', '2018-04-02 23:56:37.556015+00', 'See This', 'SEE THIS', 2, 32, 9999, 1, 3, 42, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16348, '2015-05-17 11:11:03.49919+00', '2015-05-17 11:11:03.49919+00', 'Fain to Follow', 'FAIN TO FOLLOW', 3, 40, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16349, '2015-05-17 11:13:30.040137+00', '2015-05-17 12:30:33.369478+00', 'As Bees Flee Hame', 'AS BEES FLEE HAME', 2, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16350, '2015-05-17 12:41:46.958183+00', '2015-05-17 12:41:46.958183+00', 'Souple Jade, A', 'SOUPLE JADE', 3, 32, 9999, 1, 4, 1, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16351, '2015-05-17 12:48:13.420952+00', '2015-05-17 12:48:13.420952+00', 'Sich a Caper', 'SICH A CAPER', 2, 32, 9999, 1, 4, 1, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16352, '2015-05-17 12:54:24.184044+00', '2015-05-17 12:54:24.184044+00', 'Toss Your Head', 'TOSS YOUR HEAD', 3, 32, 9999, 4, 4, 1, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16353, '2015-05-17 12:58:13.468254+00', '2015-05-17 12:58:13.468254+00', 'Frae Many a Blunder Free Us', 'FRAE MANY A BLUNDER FREE US', 1, 32, 9999, 4, 4, 1, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16354, '2015-05-19 17:19:28.9559+00', '2015-05-19 17:19:28.9559+00', 'Gie Us the Gift', 'GIE US THE GIFT', 3, 32, 9999, 1, 4, 2, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16355, '2015-05-19 17:26:03.598558+00', '2015-05-19 17:26:03.598558+00', 'Tread Ye Lightly', 'TREAD YE LIGHTLY', 1, 32, 9999, 1, 4, 14, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16358, '2015-05-19 17:46:53.98943+00', '2015-05-19 17:46:53.98943+00', 'Lades o''Treasure', 'LADES OTREASURE', 2, 32, 9999, 3, 5, 16, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16359, '2015-05-19 17:51:57.913783+00', '2015-05-19 17:51:57.913783+00', 'Wing''d Minute, The', 'WINGD MINUTE', 3, 32, 9999, 3, 5, 16, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16360, '2015-05-19 17:57:01.529009+00', '2015-05-19 17:57:01.529009+00', 'Like Snow on the River', 'LIKE SNOW ON THE RIVER', 3, 32, 9999, 3, 5, 16, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16361, '2015-05-19 19:42:05.515536+00', '2015-05-19 19:42:05.515536+00', 'Borealis Race, The', 'BOREALIS RACE', 1, 32, 9999, 3, 5, 16, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16362, '2015-05-19 19:59:20.345484+00', '2015-05-19 19:59:20.345484+00', 'Three''s a Crowd', 'THREES A CROWD', 3, 32, 9999, 6, 3, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16363, '2015-05-19 20:04:30.886549+00', '2015-05-19 20:04:30.886549+00', 'Jig Along Home', 'JIG ALONG HOME', 2, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16364, '2015-05-19 20:10:22.858853+00', '2015-05-19 20:10:22.858853+00', 'Remembering Abbotsford', 'REMEMBERING ABBOTSFORD', 3, 32, 9999, 4, 4, 4, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16365, '2015-05-21 10:03:16.80495+00', '2015-05-21 10:03:16.80495+00', 'Dinna Fash', 'DINNA FASH', 3, 32, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16366, '2015-05-21 10:09:00.016741+00', '2015-05-21 10:09:00.016741+00', 'Keik Ben', 'KEIK BEN', 2, 32, 9999, 5, 2, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11659, '2004-01-14 23:00:00+00', '2015-05-21 10:51:45.012067+00', 'Shake da Foot', 'SHAKE DA FOOT', 3, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16370, '2015-05-21 11:44:10.579337+00', '2015-05-21 11:49:21.810241+00', 'Shauchlin Doon', 'SHAUCHLIN DOON', 3, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17551, '2017-01-20 04:04:49.684174+00', '2019-06-10 00:14:34.341409+00', 'Four Winds, The', 'FOUR WINDS', 1, 32, 9999, 4, 4, NULL, 2677, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16338, '2015-05-10 23:20:16.620975+00', '2020-02-26 18:47:06.903531+00', 'Bastringue, La', 'BASTRINGUE', 1, 32, NULL, 5, 1, 4, 9998, NULL, 'Traditional from French Canada.



This dance uses a walking step, and a "buzz step" for the turns ', 100, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16337, '2015-05-10 23:08:37.250399+00', '2020-12-29 14:04:12.413662+00', 'Millbrae Station', 'MILLBRAE STATION', 3, 32, NULL, 1, 2, 76, 10934, NULL, 'Dedicated to Tom Senior and Barbara Cool of Chicago, IL and is mis-named for the Scottish-sounding METRA station nearest their house that I could never quite remember.', 60, '44/88/88/88', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16347, '2015-05-17 10:59:53.069416+00', '2021-06-06 11:32:20.649841+00', 'Like Ane Bewitch''d', 'LIKE ANE BEWITCHD', 1, 32, 9999, 2, 2, 76, 2018, NULL, 'The title comes from Burns: *And how Tam stood, like ane bewitch’d, And thought his very een enrich’d.*



May be danced in a 3 or 4 couple set.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16369, '2015-05-21 11:38:22.728995+00', '2015-05-21 11:50:52.206168+00', 'Trippit Cantily', 'TRIPPIT CANTILY', 1, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16372, '2015-05-21 11:58:59.919393+00', '2015-05-21 11:58:59.919393+00', 'Fidgin Fain', 'FIDGIN FAIN', 3, 32, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16373, '2015-05-21 12:04:17.856026+00', '2015-05-21 12:04:17.856026+00', 'Bladderskate, The', 'BLADDERSKATE', 2, 32, 9999, 5, 56, NULL, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16374, '2015-05-21 13:35:22.409267+00', '2015-05-21 13:35:22.409267+00', 'Flaff Roon', 'FLAFF ROON', 3, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16375, '2015-05-21 13:42:21.359203+00', '2015-05-21 13:42:21.359203+00', 'Dinna Kittl Me', 'DINNA KITTL ME', 1, 40, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16357, '2015-05-19 17:40:00.608693+00', '2022-08-05 17:09:52.998259+00', 'Deil Confound Me, The', 'DEIL CONFOUND ME', 3, 32, 9999, 2, 2, 76, 2018, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16371, '2015-05-21 11:48:54.502871+00', '2022-08-14 15:31:34.146885+00', 'Tuther Gait', 'TUTHER GAIT', 1, 32, 9999, 2, 3, 17, 2018, NULL, 'The title means "The other way".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16389, '2015-05-23 16:31:35.987173+00', '2015-05-23 16:31:35.987173+00', 'Tribute to Barb Bolin', 'TRIBUTE TO BARB BOLIN', 3, 32, 9999, 5, 2, NULL, 2018, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16390, '2015-05-23 16:37:03.15632+00', '2015-05-23 16:37:03.15632+00', 'Circle Strathspey', 'CIRCLE STRATHSPEY', 3, 32, 9999, 7, 113, 4, 2018, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11434, '2003-09-14 22:00:00+00', '2018-04-24 04:46:13.236259+00', 'Poor Molly', 'POOR MOLLY', 3, 32, 9999, 1, 2, 76, 3371, '2003-01-01', 'Recommended music: "Sweet Molly" (recording: Bobby Frew version of John McAlpin has "Sweet Molly" as a tune).  



This dance devised as a teaching dance for reels of four.', 42, '84/88/82/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16428, '2015-06-04 09:58:39.67836+00', '2018-04-02 23:56:32.840966+00', 'Auckland Region', 'AUCKLAND REGION', 1, 32, 9999, 1, 3, 42, 3350, '2004-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16393, '2015-05-23 16:53:11.119678+00', '2015-05-23 16:56:27.653899+00', 'Knockwalloch', 'KNOCKWALLOCH', 2, 32, 9999, 2, 3, 17, 2018, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16394, '2015-05-23 17:01:35.882884+00', '2015-05-23 17:01:35.882884+00', 'Double Eights', 'DOUBLE EIGHTS', 3, 40, 9999, 2, 3, NULL, 2018, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16397, '2015-05-23 17:24:31.467874+00', '2015-05-23 17:24:31.467874+00', 'Balmae Reel', 'BALMAE REEL', 3, 64, 9999, 1, 102, 2, 2018, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16398, '2015-05-23 17:30:35.499237+00', '2015-05-23 17:30:35.499237+00', 'Cairnsmore of Fleet', 'CAIRNSMORE OF FLEET', 3, 32, 9999, 2, 3, 17, 2018, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16399, '2015-05-23 17:33:52.689758+00', '2015-05-23 17:34:10.290938+00', 'Auchencairn', 'AUCHENCAIRN', 2, 32, 9999, 2, 3, 17, 2018, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13282, '2007-05-17 22:00:00+00', '2015-05-29 00:06:29.018963+00', 'Spirit of the Dance, The', 'SPIRIT OF THE DANCE', 3, 32, 9999, 1, 3, 42, 3593, NULL, '»Devised by Irene Paterson of Mukilteo, Washington State, in memory of Bob Blackie, a wonderful friend, dancer, and teacher.«', 50, '880  800  12 12 12  400', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (14288, '2011-10-26 22:00:00+00', '2015-05-29 15:51:00.780214+00', 'Blue Lights of Pizza Express, The', 'BLUE LIGHTS OF PIZZA EXPRESS', 3, 32, 9999, 4, 4, 4, 10496, '2008-03-01', 'Devised by Kirsten Ferguson, who was asked for direction to a restaurant during the 2008 Inter Varsity Folk Dance Festival (IVFDF) in Sheffield. Friends were told to look for "The Blue Lights of Pizza Express" as their rendezvous point, and having enjoyed a very good pizza, Kirsten wrote this dance. [information taken from the 2nd Aurora Book of SCDs]



As music the author suggests "any good traditional Strathspey".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14282, '2011-10-26 22:00:00+00', '2015-05-29 15:55:17.243211+00', 'There''s Nae Enough Bodies', 'THERES NAE ENOUGH BODIES', 1, 32, 9999, 1, 2, NULL, 10491, '2008-01-01', 'As music the author suggests "any full-bodied reel".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16400, '2015-05-30 11:41:04.534661+00', '2015-05-30 11:41:04.534661+00', 'Cromach, The', 'CROMACH', 3, 40, 9999, 5, 56, NULL, 2018, '2011-01-01', 'Could be danced in strathspey or reel time', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16401, '2015-05-30 16:37:58.802784+00', '2015-05-30 16:37:58.802784+00', 'Reel Wheel Chase, A', 'REEL WHEEL CHASE', 2, 32, 9999, 5, 2, NULL, 2018, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16402, '2015-05-30 16:47:32.046288+00', '2015-05-30 16:47:32.046288+00', 'Rigg, The', 'RIGG', 1, 32, 9999, 5, 2, NULL, 2018, '2011-01-01', 'Could be danced as reel or jig', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16427, '2015-06-02 14:51:44.157047+00', '2018-04-02 23:56:32.936808+00', 'Beechgrove Garden, The', 'BEECHGROVE GARDEN', 3, 32, 9999, 1, 3, 42, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16429, '2015-06-04 10:08:03.122194+00', '2018-04-02 23:56:33.380894+00', 'Cartwheels in the Snow', 'CARTWHEELS IN THE SNOW', 2, 32, 9999, 1, 3, 42, 3491, '2009-08-01', 'Suggested music:

Jubilee Jig: Track 5: Clashmadin Volume 1

Nicol McLaren and the Glencraig Scottish Dance Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11989, '2005-01-20 23:00:00+00', '2018-04-02 23:56:34.28291+00', 'Eileen Watson', 'EILEEN WATSON', 2, 32, 9999, 1, 3, 42, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16395, '2015-05-23 17:07:26.441675+00', '2018-04-02 23:56:35.760866+00', 'Knocked Sideways', 'KNOCKED SIDEWAYS', 3, 40, 9999, 1, 3, 42, 2018, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16407, '2015-05-30 17:26:23.266596+00', '2015-05-30 17:26:23.266596+00', 'Dinna Gang Aglae (Awry)', 'DINNA GANG AGLAE AWRY', 2, 32, 9999, 1, 4, 1, 2018, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16422, '2015-06-02 13:17:14.941761+00', '2018-04-02 23:56:36.712844+00', 'Nonstop', 'NONSTOP', 1, 32, 9999, 1, 3, 42, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16410, '2015-05-30 17:58:17.148664+00', '2015-05-30 17:58:17.148664+00', 'Around the Cabot Trail', 'AROUND THE CABOT TRAIL', 2, 48, 9999, 1, 4, 1, 2018, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16396, '2015-05-23 17:14:01.02154+00', '2018-04-02 23:56:37.205324+00', 'Reel for Rajiv', 'REEL FOR RAJIV', 1, 32, 9999, 1, 3, 42, 2018, '2008-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16413, '2015-05-30 18:30:37.874384+00', '2015-05-30 18:30:37.874384+00', 'Round the Set', 'ROUND THE SET', 1, 32, 9999, 1, 4, 1, 2018, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16414, '2015-05-30 18:41:25.881925+00', '2015-05-30 18:41:25.881925+00', 'Over the Heather', 'OVER THE HEATHER', 2, 32, 9999, 7, 4, 4, 2018, '2011-01-01', '4-couple double circle, men with back to centre', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11679, '2004-02-08 23:00:00+00', '2018-04-02 23:56:37.464093+00', 'Rutherford Reel, The', 'RUTHERFORD REEL', 1, 32, 9999, 1, 3, 42, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16391, '2015-05-23 16:43:46.770345+00', '2018-04-03 00:07:42.550906+00', 'Doon the Brae', 'DOON THE BRAE', 3, 32, 9999, 1, 3, 42, 2018, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16417, '2015-06-02 11:40:47.32541+00', '2015-06-02 11:41:44.032816+00', 'Da Fairy Reel', 'FAIRY REEL', 1, 32, 9999, 1, 102, 2, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16419, '2015-06-02 12:17:34.576427+00', '2015-06-02 12:17:34.576427+00', 'Rovin'' Boy, The', 'ROVIN BOY', 4, 64, 60, 4, 4, 4, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16420, '2015-06-02 12:33:27.277364+00', '2015-06-02 12:33:27.277364+00', 'Hush Up!', 'HUSH UP', 2, 32, 9999, 1, 4, 1, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16421, '2015-06-02 13:12:24.433672+00', '2015-06-02 13:12:24.433672+00', 'Banchory Strathspey, The', 'BANCHORY STRATHSPEY', 3, 32, 9999, 2, 3, 17, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16424, '2015-06-02 14:23:45.252226+00', '2015-06-02 14:23:45.252226+00', 'Twice Through Once', 'TWICE THROUGH ONCE', 1, 64, 9999, 1, 4, NULL, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16425, '2015-06-02 14:32:11.68716+00', '2015-06-02 14:32:11.68716+00', 'Hill of Fare, The', 'HILL OF FARE', 3, 32, 9999, 1, 102, 1, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18619, '2018-09-17 18:13:06.179643+00', '2020-11-18 12:59:36.034314+00', 'Fours To The Fore', 'FOURS TO THE FORE', 1, 40, NULL, 1, 4, 13, 3632, '2009-05-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16418, '2015-06-02 12:00:28.559336+00', '2015-06-02 14:58:30.446691+00', 'Broom o'' the Cowdenknowes, The', 'BROOM O THE COWDENKNOWES', 3, 32, 9999, 1, 4, 1, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15903, '2015-01-29 13:43:27.523408+00', '2015-06-04 10:01:25.885409+00', 'Capricorn''s Dance', 'CAPRICORNS DANCE', 1, 32, 9999, 1, 4, 1, 3349, '2009-06-23', 'Suggested music:

Maskelia on CD "From Scotia''s Shores We''re Noo Awa'' " by Bobby Brown and The Scottish Accent', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16430, '2015-06-04 10:23:17.833629+00', '2015-06-04 10:23:17.833629+00', 'Cat''s Cradle Dance', 'CATS CRADLE DANCE', 3, 32, 9999, 1, 4, 11, 3491, '2009-10-10', 'Suggested music: Our Lady of the Snows: No.12:

Highlander Music Scottish Dances Volume 6



The suggested music has 2 chords. Dancers should achnowledge partners on the first chord and the neighbouring couple on the second.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16431, '2015-06-04 10:39:02.146711+00', '2015-06-04 10:39:02.146711+00', 'Clouded Moon', 'CLOUDED MOON', 3, 32, 9999, 1, 4, 1, 3350, '2007-05-03', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16392, '2015-05-23 16:50:42.052328+00', '2016-04-18 23:10:20.931497+00', 'Da Fiddle Moves Me', 'FIDDLE MOVES ME', 1, 32, 9999, 1, 2, NULL, 2018, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16405, '2015-05-30 17:07:29.769471+00', '2016-04-18 23:13:30.06869+00', 'Get the Feet A''Frisking', 'GET THE FEET AFRISKING', 2, 32, 9999, 1, 2, NULL, 2018, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16403, '2015-05-30 16:52:42.5711+00', '2016-04-18 23:21:02.012878+00', 'Oot and Aboot', 'OOT AND ABOOT', 2, 32, 9999, 1, 2, NULL, 2018, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16404, '2015-05-30 16:58:47.98202+00', '2016-04-18 23:27:41.874469+00', 'Wi'' Cutty Steps', 'WI CUTTY STEPS', 3, 32, 9999, 1, 2, NULL, 2018, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16416, '2015-05-30 19:09:55.444899+00', '2016-05-11 23:04:59.980698+00', 'Diamond Reel, The', 'DIAMOND REEL', 1, 48, 9999, 4, 5, 16, 2018, '2011-01-01', '5-couple dance in 4-couple diamond with one couple in middle', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16409, '2015-05-30 17:49:13.192539+00', '2016-09-26 14:52:23.418949+00', 'Rabbie''s Rant', 'RABBIES RANT', 1, 32, 9999, 2, 3, 17, 2018, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16433, '2015-06-04 11:23:55.257539+00', '2015-06-04 11:23:55.257539+00', 'Dancing in the Heat', 'DANCING IN THE HEAT', 1, 32, 9999, 8, 6, 9, 11139, '2008-07-01', 'Suggested music:

Todlen Hame: No. 1: Todlen Hame - Muriel Johnstone & Keith Smith', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16435, '2015-06-04 11:51:31.079496+00', '2015-06-04 11:51:31.079496+00', 'Eye of the Storm', 'EYE OF THE STORM', 1, 128, 9999, 4, 4, NULL, 3350, '2009-02-26', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16436, '2015-06-04 12:04:14.597191+00', '2015-06-04 12:04:14.597191+00', 'Homeward Bound', 'HOMEWARD BOUND', 1, 32, 9999, 1, 4, 1, 3354, '2009-01-01', 'Suggested music:

The Lads of Saltcoats

Track 11: Dancing Through the Miscellanies Part 1

This piece of music goes through 8 times so each couple has 2 turns.

Alternatively use a 4 x 32 Reel selection.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16438, '2015-06-05 09:49:11.515391+00', '2015-06-05 09:49:11.515391+00', 'Luna Rosa', 'LUNA ROSA', 1, 32, 9999, 6, 3, 17, 3350, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16432, '2015-06-04 11:09:19.023004+00', '2018-04-02 23:56:33.740549+00', 'Dancing Geometry', 'DANCING GEOMETRY', 1, 32, 9999, 1, 3, 42, 3491, '2009-04-06', 'Suggested music:

Broadford Bay: Track 4: Scottish Dances Volume 6

Drummond Cook''s Scottish Country Dance Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16441, '2015-06-05 10:19:36.476956+00', '2015-06-05 10:19:36.476956+00', 'November the Fifth', 'NOVEMBER THE FIFTH', 1, 48, 9999, 4, 4, 1, 3354, '2009-03-01', 'Suggested music:

Neil Gow''s Farewell to Whisky:

Lorne Choice of Scottish Country Dances

Alastair Hunter & the Lorne Scottish Dance Band



Or The Earl of Mansfield on Highlander Music Vol 3, also on Special requests Vol 4



Or Lady Sophia Anne of Bute on Road to Forfar by Deirdre Adamson

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16434, '2015-06-04 11:31:43.301268+00', '2018-04-02 23:56:33.770045+00', 'Dancing with a Fiddler', 'DANCING WITH A FIDDLER', 1, 40, 9999, 1, 3, 42, 11139, '2008-07-09', 'Suggested Music:

The Dalesman: Track 8: 

Haste Ye Back - Muriel Johnstone and her Scottish Dance Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16730, '2015-09-03 21:03:42.835346+00', '2019-02-25 23:50:47.568301+00', 'Mrs Ruth Housden', 'MRS RUTH HOUSDEN', 1, 40, NULL, 1, 4, 4, 11197, '2014-01-01', 'Ruth Housden has been the teacher at the Aboyne Scottish Country Dance Group on Royal Deeside since 2001.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16444, '2015-06-06 16:33:55.011627+00', '2015-06-06 16:33:55.011627+00', 'Ride Across the Moon', 'RIDE ACROSS THE MOON', 2, 32, 9999, 1, 4, 2, 3350, '2008-09-28', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17513, '2017-01-04 17:29:49.45157+00', '2019-06-28 12:28:47.647885+00', 'Dancing Waves, The', 'DANCING WAVES', 1, 32, NULL, 3, 5, 7, 11110, '2006-01-01', 'The idea for this dance came to me while walking along the seafront at Southsea and seeing the white crests of the waves.', 78, '88888/84844/82842/80888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16446, '2015-06-06 16:54:20.786171+00', '2015-06-06 16:54:20.786171+00', 'Snakes and Ladders', 'SNAKES AND LADDERS', 2, 32, 9999, 1, 4, 1, 3491, '2009-11-13', 'Suggested music:

Rothesy Rant: Track 13: Lassie Come and Dance Wi'' Me

- Ian Cruickshank and His Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16447, '2015-06-06 17:00:20.70346+00', '2015-06-06 17:00:20.70346+00', 'Spell of the Rising Moon', 'SPELL OF THE RISING MOON', 3, 32, 9999, 1, 4, 1, 3350, '2009-08-03', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16448, '2015-06-06 17:09:04.459751+00', '2015-06-06 17:09:04.459751+00', 'Straverner''s Strathspey', 'STRAVERNERS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 3349, '2008-08-26', 'Suggested music:

The Flower o'' the Quern: The London Highland Club Diamond Jubilee:

Andrew Rankine



Also on Scottish Dance Favourites Vol. 1: Andrew Rankine', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17515, '2017-01-04 17:31:42.11249+00', '2019-06-28 14:25:57.613042+00', 'Jig for Joan, A', 'JIG FOR JOAN', 2, 96, NULL, 4, 4, NULL, 11110, '2002-10-01', 'In memory of Joan Foster who was a member of Southsea Reel Club.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17517, '2017-01-04 17:54:15.452429+00', '2019-06-28 14:34:19.140131+00', 'Moat House, The', 'MOAT HOUSE', 3, 32, NULL, 2, 2, 76, 11110, '2005-12-23', 'This dance was devised during a Christmas break at the Moat House Hotel in Stoke on Trent.', 100, '88/88/88/88', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16451, '2015-06-06 17:44:05.166353+00', '2015-06-06 17:44:05.166353+00', 'Moonrakers, The', 'MOONRAKERS', 3, 40, 9999, 4, 4, 1, 3350, '2008-02-18', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16450, '2015-06-06 17:29:22.493023+00', '2018-04-02 23:56:35.235135+00', 'Horsham Jig, The', 'HORSHAM JIG', 1, 32, 9999, 1, 3, 42, 3349, '2009-03-28', 'Suggested music:

Hamish Smith''s Reel: Magic Medicine - Sandy Nixon and His Scottish Dance Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15892, '2015-01-29 10:50:32.130954+00', '2018-04-02 23:56:35.285137+00', 'Indian Warrior Reel, The', 'INDIAN WARRIOR REEL', 1, 32, 9999, 1, 3, 42, 3349, '2009-06-23', 'Suggested Music: "Bill Hendry''s Reel" on CD "Magic Medicine" by Sandy Nixon and his Scottish Dance Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16455, '2015-06-06 20:33:43.315919+00', '2015-06-06 20:33:43.315919+00', 'Winter Schools', 'WINTER SCHOOLS', 1, 32, 9999, 3, 5, 7, 3350, '2004-01-01', '2 chords - 1st, 3rd & 5th couples start on opposite sides. If the music chosen has a second chord, they can cross on the second chord.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16437, '2015-06-05 09:42:18.414627+00', '2018-04-02 23:56:35.456593+00', 'Jeannie with the Light Brown Hair', 'JEANNIE WITH THE LIGHT BROWN HAIR', 3, 32, 9999, 1, 3, 42, 3354, '2009-08-01', 'Suggested music:

Mr Robert H. Mackay: Track 7:

Cairngorms Selection - Muriel Johnstone & Keith Smith', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16452, '2015-06-06 18:15:09.046721+00', '2015-06-06 20:08:13.490601+00', 'Moon''s Dance, The', 'MOONS DANCE', 3, 128, 9999, 4, 4, 3, 3350, '2004-03-26', 'Suggested music: Mrs. Milne of Kinneff

The Royal Scottish Dance Society - 75th Anniversary Dances



Also on: Highlander Music Scottish Dances Volume 6', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16453, '2015-06-06 20:18:22.428002+00', '2015-06-06 20:18:22.428002+00', 'Moon''s Halo, The', 'MOONS HALO', 3, 40, 9999, 3, 5, 7, 3350, '2007-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16442, '2015-06-06 16:15:20.358338+00', '2018-04-02 23:56:36.762932+00', 'Old Scotch Lace', 'OLD SCOTCH LACE', 3, 32, 9999, 1, 3, 42, 3491, '2009-08-01', 'Suggested music:

Up in the Air: Track 10: Clashmadin Volume 1

Nicol McLaren and the Glencraig Scottish Dance Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16426, '2015-06-02 14:44:41.806424+00', '2021-06-06 12:09:35.216576+00', 'Tilted Kirk, The', 'TILTED KIRK', 1, 32, 9999, 1, 4, 1, 165, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16443, '2015-06-06 16:23:09.322808+00', '2018-04-02 23:56:37.146777+00', 'Rangitoto Reel', 'RANGITOTO REEL', 3, 32, 9999, 1, 3, 42, 3491, '2009-02-26', 'Suggested music:

Alltshellach: Track 11

Cairngorms - Muriel Johnstone and Keith Smith', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1430, '1997-04-03 22:00:00+00', '2015-06-09 13:53:30.696292+00', 'Crombie Hall', 'CROMBIE HALL', 3, 40, 9999, 2, 3, 17, 108, '1971-01-01', '', 67, '886  844  888  888  868', 1, 1, 1, 1, 90);
INSERT INTO 'dance' VALUES (16440, '2015-06-05 10:07:56.214717+00', '2016-07-10 12:11:03.338563+00', 'Moonshine', 'MOONSHINE', 3, 48, 9999, 3, 5, 16, 3350, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16454, '2015-06-06 20:24:26.688774+00', '2018-04-02 23:56:37.673355+00', 'Solitary Strathspey, The', 'SOLITARY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3349, '2009-03-29', 'Suggested music.

For All the Ladies:

Repeat Prescription - Sandy Nixon and His Scottish Dance Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16449, '2015-06-06 17:17:36.600441+00', '2018-04-02 23:56:37.861461+00', 'Strong Arm Moll', 'STRONG ARM MOLL', 1, 40, 9999, 1, 3, 42, 3491, '2009-03-16', 'Suggested music:

The Ladies of Dunse:

Track 13: Cairngorms CD

 - Keith Smith and Muriel Johnstone', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16445, '2015-06-06 16:44:33.500838+00', '2018-04-03 00:08:16.102266+00', 'Sharps and Flats', 'SHARPS AND FLATS', 1, 32, 9999, 1, 3, 42, 3354, '2009-04-01', 'Suggested music:

The Whistling Wind: Come Forth to the Scottish Country Dance

- The Deirdre Adamson Quartet', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17525, '2017-01-05 09:26:23.105368+00', '2017-01-05 09:26:23.105368+00', 'Six Times S', 'SIX TIMES S', 4, 64, 5, 100, 4, NULL, 572, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13829, '2011-08-05 22:00:00+00', '2018-04-24 04:53:30.032064+00', 'Steve Mangan Jig, The', 'STEVE MANGAN JIG', 2, 32, NULL, 2, 3, 17, 3371, '2006-09-25', 'Suggested Recording: 3 x 32 Jigs, Track 11 on the album “Miss Ogilvie''s Fancy” by Green Ginger  



On September 25th, 2006 the Flying Ghillies Scottish Country Dancers started a Scottish Country Dancing FUNdamentals class offered on the same night as the general class at the Mangan Banquet Center. Patty Lindsay taught this as the first dance in that class as a thank-you to Steve Mangan for working with us so that now the Flying Ghillies have a great hall to dance in with rooms for two classes.', 50, '800/880/800/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5255, '1997-04-03 22:00:00+00', '2018-04-26 16:37:22.483816+00', 'Pig Town', 'PIG TOWN', 1, 48, 9999, 4, 119, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16458, '2015-06-12 08:46:38.099048+00', '2015-06-12 08:46:38.099048+00', 'Sleepless in Greeley', 'SLEEPLESS IN GREELEY', 3, 32, NULL, 1, 2, NULL, 11133, NULL, '“A gift to Ron Wallace from the Candidate Class of T.A.C. 2014”', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16439, '2015-06-05 09:57:27.67925+00', '2022-08-07 11:29:05.056922+00', 'Lunar Eclipse', 'LUNAR ECLIPSE', 3, 48, 9999, 1, 4, 1, 3350, '2007-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10906, '2002-11-02 23:00:00+00', '2022-12-22 18:26:48.608076+00', 'Howard McNally''s Favourite', 'HOWARD MACNALLYS FAVOURITE', 3, 32, 9999, 1, 4, 1, 725, '1997-01-01', '', 81, '8888/8888/8888/8000', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21249, '2023-01-05 11:44:22.034891+00', '2023-01-05 11:44:22.034891+00', 'Lews Castle', 'LEWS CASTLE', 1, 32, NULL, 1, 4, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21252, '2023-01-05 11:47:33.343661+00', '2023-01-05 11:47:33.343661+00', 'Linking Fun', 'LINKING FUN', 1, 32, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1453, '1999-08-22 22:00:00+00', '2018-02-27 21:24:35.706242+00', 'Crown of King''s, The', 'CROWN OF KINGS', 3, 96, 9999, 6, 3, 3, 108, '1971-01-01', 'The name refers to King''s College, University of Aberdeen, which has an ornate entry porch with a top like a crown.

If the dance is performed on a stage, 1st couple should stand at the back facing the audience, while the other two couples stand near the front of the stage with their backs to the audience.

', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3821, '1997-09-08 22:00:00+00', '2018-04-03 00:07:59.623511+00', 'Linda''s Long Jig', 'LINDAS LONG JIG', 2, 48, 9999, 1, 3, 42, 1085, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16306, '2015-05-09 09:14:28.07399+00', '2017-05-31 10:37:32.077763+00', 'Octogenarian, The', 'OCTOGENARIAN', 2, 32, NULL, 1, 3, 42, 316, '2009-01-01', 'This dance was devised for Gwen Kebble of Ribble Valley Branch RSCDS on the occasion of her 80th birthday.', 56, '800/888/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12320, '2005-04-27 22:00:00+00', '2015-06-13 07:09:03.678259+00', 'Miss Kenyon''s Strathspey', 'MISS KENYONS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 87, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16460, '2015-06-19 15:32:32.05713+00', '2019-06-04 15:03:30.229314+00', 'Scottish Roulette', 'SCOTTISH ROULETTE', 1, 32, NULL, 5, 113, 4, 11114, '2014-01-01', 'A fun dance for beginners.



"The roulette is symbolised by the two circles. If you are the winner you will get a new partner after every turn!"', 100, '88/88/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8792, '1998-10-21 22:00:00+00', '2015-06-18 22:19:15.27291+00', 'Tantalus Jig, The', 'TANTALUS JIG', 2, 32, 9999, 4, 55, 6, 2364, '1998-01-01', 'Eric''s Crib and the Minicrib use the RSCDS standard position numbering (1,2,3,4 clockwise, 5 in the middle).  The original text uses a different numbering: 1 in the middle (like a Baseball pitcher) and 2,3,4,5 counterclockwise (at 1st, 2nd, 3rd, 4th base).  ', 50, '88008/80808/80044/04840', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5122, '1998-07-08 22:00:00+00', '2018-02-27 21:54:07.226568+00', 'Our Lady of the Snows', 'OUR LADY OF THE SNOWS', 3, 32, 9999, 1, 100, 2, 108, '1994-12-01', 'Devised: 1994-12



1. The church of "Our Lady of the Snows" was founded by Bishop William Elphinstone in 1497. Today only a small section of the burial ground remains - tucked behind the houses on the west side of College Bounds, near Johnstone Hall.

In the 4th century, John the Patrician had a vision in which the Virgin Mary directed him to build a church on a patch of snow which he would find at the height of summer on the Esquiline Hill in Rome. The truth of this story was confirmed by Pope Pius II in 1497.

The information comes from "City by the grey North Sea" by Fenton Wyness.

2. The wheels on the corners during bars 9-16 can be thought of as snow flakes even though they have only three-fold, rather than six-fold, symmetry.', 75, '8008/8448/8448/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16465, '2015-07-07 13:17:55.607049+00', '2018-03-14 22:32:31.776897+00', 'Chased Lovers', 'CHASED LOVERS', 2, 32, 9999, 1, 3, 42, 2701, '2013-08-01', 'Music: Fun, flirty jigs with flight.



Note: You may notice that 1st couple do not actually touch in this dance. I liked the play on words with "chased" and "chaste", and tried to incorporate both ideas. The dance was first taught to the combined class at the 2013 International Branch Weekend in Killarney, Ireland.



', 44, '800/844/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16459, '2015-06-19 11:11:54.836024+00', '2018-03-23 18:35:06.423093+00', 'Dr. Stocker''s Hornpipe', 'DR STOCKERS HORNPIPE', 1, 40, NULL, 4, 4, 13, 10714, '2014-10-01', 'The premiere of this dance was performed at the RSCDS‐San Francisco Branch, Asilomar weekend ceilidh, November 7, 2014.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2445, '1997-04-03 22:00:00+00', '2018-04-03 00:07:48.022538+00', 'George Keith', 'GEORGE KEITH', 3, 32, 9999, 1, 3, 42, 108, '1995-01-01', 'Devised: 1994-05

A dance to mark the foundation of Marischal College by George Keith, the 4th Earl of Marischal in 1593.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8128, '1998-04-24 22:00:00+00', '2015-06-25 08:07:36.043639+00', 'Far Islands, The', 'FAR ISLANDS', 3, 32, 9999, 6, 3, 17, 1445, '1995-01-01', 'In the original description, the couples are numbered counterclockwise.  Eric''s crib uses the RSCDS convention of clockwise numbering.', 96, '866/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4179, '1997-04-03 22:00:00+00', '2018-04-03 00:08:02.208759+00', 'Marischal College', 'MARISCHAL COLLEGE', 2, 32, 9999, 1, 3, 42, 108, '1967-01-01', 'Devised: 1967

This dance was first published in "The Rondel Book" in 1967.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18291, '2018-04-24 18:13:41.774041+00', '2018-05-10 13:32:01.662696+00', 'Reach For The Stars', 'REACH FOR THE STARS', 1, 32, NULL, 1, 3, NULL, 44, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18295, '2018-04-24 18:21:04.222096+00', '2018-05-10 13:32:30.420919+00', 'Hillside In Bloom, The', 'HILLSIDE IN BLOOM', 1, 32, NULL, 1, 3, NULL, 44, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5443, '1997-08-19 22:00:00+00', '2020-12-15 19:46:50.032133+00', 'Quincentenary Jig, The', 'QUINCENTENARY JIG', 2, 32, 9999, 3, 5, 7, 108, NULL, 'Devised: 1994

A dance to mark 500 years since the foundation of the Universityof Aberdeen by Bishop Elphinstone.', 67, '88880  80880  88808  80822', 1, 1, 1, 1, 67);
INSERT INTO 'dance' VALUES (17523, '2017-01-05 09:06:35.028245+00', '2021-06-08 09:47:51.659394+00', 'Young at Heart', 'YOUNG AT HEART', 2, 32, NULL, 1, 3, 42, 11436, NULL, '"The title reflects the enthusiasm of [Belfast] Branch members."', 50, '822/822/866/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16457, '2015-06-12 08:41:26.635983+00', '2018-04-03 00:08:16.110728+00', 'Shasta Scottish Dancers, The', 'SHASTA SCOTTISH DANCERS', 3, 32, NULL, 1, 3, 42, 401, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (713, '1997-08-27 22:00:00+00', '2016-07-15 12:36:40.152906+00', 'Borrowdale Exchange, The', 'BORROWDALE EXCHANGE', 1, 32, 9999, 6, 3, 4, 175, '1991-01-01', 'Music: "Any good reel.  Try a Square Dance medley".



 .... 



This is a ''Scotization'' of a party dance, first seen at an English Barn Dance in Cumbria.', 100, '888  888  888  888', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (16325, '2015-05-09 15:47:55.768984+00', '2018-04-02 23:56:36.821321+00', 'Organist''s Rabbit, The', 'ORGANISTS RABBIT', 2, 32, 9999, 1, 3, 42, 11133, '2010-01-01', 'for William Ogburn in celebration of Easter.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16462, '2015-06-25 21:41:46.724269+00', '2015-06-25 21:49:30.535696+00', 'D.J.''s Jig', 'DJS JIG', 2, 40, NULL, 1, 3, 18, 11110, '2012-03-12', 'This dance is dedicated to my grandson Dillon Joseph Hoddle.  Dillon is helping at Southsea Reel Club at present as part of his Duke of Edinburgh''s Award', 60, '888/400/888/400/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18290, '2018-04-24 18:12:05.576765+00', '2018-04-24 18:12:05.576765+00', 'Vive La Danse!', 'VIVE LA DANSE', 1, 48, NULL, 3, 5, 7, 44, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (190, '1997-05-17 22:00:00+00', '2018-04-03 00:07:30.902986+00', 'Another Edinburgh Fancy', 'ANOTHER EDINBURGH FANCY', 3, 40, 9999, 1, 3, 42, 108, '1967-01-01', 'To Miss Allie Anderson, of Edinburgh, and the members of the Edinburgh Branch Demonstration Team, who danced two of my dances ("Bon Accord" and "A Trip to Tobermory") at "An Edinburgh Fancy" in 1966.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16475, '2015-07-07 16:41:27.361378+00', '2017-04-08 21:12:39.963454+00', 'O''er the Border', 'OER THE BORDER', 3, 32, 9999, 2, 3, 17, 1582, '2014-01-01', '', 67, '800/888/808/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16464, '2015-07-01 12:39:19.94083+00', '2022-08-14 15:53:04.950675+00', 'Old Vineyard Jig, The', 'OLD VINEYARD JIG', 2, 32, NULL, 5, 2, 76, 3645, '2015-07-01', 'Beginners may prefer to dance the half circles of [17-25] in slip-step instead of in skip-change.', 87, '66/66/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16463, '2015-06-28 09:52:07.155856+00', '2022-12-02 21:24:46.710279+00', 'Silver-gilt', 'SILVERGILT', 3, 96, NULL, 4, 4, 3, 234, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10905, '2002-11-02 23:00:00+00', '2022-12-22 18:27:37.160927+00', 'Lochiel Strathspey, The', 'LOCHIEL STRATHSPEY', 3, 32, 9999, 1, 4, 1, 725, '1998-01-01', 'Ruary writes: 

Ladies set, cross Rsh round partner and turn RH 

Men repeat Lsh and LH 

Down the middle and cast back up 

1st cpl turn and cast to the bottom and turn both hands', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6597, '1997-04-03 22:00:00+00', '2018-04-03 00:08:21.047527+00', 'Tibbie''s Jig', 'TIBBIES JIG', 2, 32, 9999, 1, 3, 42, 108, '1967-01-01', 'Miss Alison Laing is Mrs. Cramb''s niece, and sister to Miss Janet Laing, whose Strathspey appeared in Book 22.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1672, '1997-05-17 22:00:00+00', '2015-06-28 20:11:36.547629+00', 'Don House', 'DON HOUSE', 3, 40, 9999, 1, 2, NULL, 108, '1967-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (178, '1997-04-03 22:00:00+00', '2015-06-28 20:20:31.079054+00', 'Annie Shand Scott''s Strathspey', 'ANNIE SHAND SCOTTS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 108, '1967-01-01', 'Miss Annie Shand Scott, or "Scottie" as she is affectionately known, is a pianist and one of the leading exponents of Scottish Country Dance Music in Aberdeen. This dance was composed as a little birthday gift for her.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18292, '2018-04-24 18:16:47.058527+00', '2018-04-24 18:16:47.058527+00', 'Roll Back The Carpet', 'ROLL BACK THE CARPET', 3, 32, NULL, 1, 3, NULL, 44, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18293, '2018-04-24 18:18:51.002608+00', '2018-04-24 18:18:51.002608+00', 'Harbour Capital, The', 'HARBOUR CAPITAL', 2, 32, NULL, 1, 3, NULL, 44, '2012-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18294, '2018-04-24 18:20:04.688755+00', '2018-04-24 18:20:04.688755+00', 'Harbour Lights', 'HARBOUR LIGHTS', 3, 32, NULL, 1, 4, NULL, 44, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13869, '2011-08-22 22:00:00+00', '2015-09-29 14:27:18.35474+00', 'Val''s Juniper Strathspey', 'VALS JUNIPER STRATHSPEY', 3, 40, NULL, 2, 3, 17, 10399, NULL, 'Written for Val Woodward after discussion about wanting a dance written for her and what she would call it. ', 92, '888/888/484/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18296, '2018-04-24 18:22:37.210024+00', '2018-05-10 13:32:48.978941+00', 'Sign Of The Times, A', 'SIGN OF THE TIMES', 3, 32, NULL, 2, 3, NULL, 44, '2015-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7020, '1997-04-03 22:00:00+00', '2021-04-17 21:48:24.208108+00', 'Welcome to Dunblane', 'WELCOME TO DUNBLANE', 1, 40, 9999, 1, 3, 42, 108, '1967-01-01', 'To Mrs. J. Prentice, of Causeway Head, Stirling.

(Dance devised for the Weekend School at Dunblane Hydro, 11-12.2.67)', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5403, '1998-11-14 23:00:00+00', '2021-11-14 23:10:01.303665+00', 'Quaich, The', 'QUAICH', 3, 32, 9999, 1, 3, 42, 108, '1967-01-01', 'This dance is dedicated with permission to Miss J.C. Milligan. It illustrates her connection with the R.S.C.D.S. right from its inception (Petronella is Book 1 No. 1) up to the present. The "Rondel" my new progression, which Miss Milligan herself named, is due to appear officially this year in Book 23 in the dance "Mrs. Hamilton of Wishaw".', 66, '888  884  888  880', 1, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (18298, '2018-04-24 18:26:49.507966+00', '2018-04-24 18:27:32.968308+00', 'Spanish Man-of-War, The', 'SPANISH MANOFWAR', 3, 32, NULL, 1, 3, NULL, 44, '2013-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16498, '2015-07-20 15:58:50.374799+00', '2018-04-26 22:47:35.292475+00', 'Wake Up Ones', 'WAKE UP ONES', 2, 32, 9999, 3, 5, 35, 10123, '2015-01-01', '', 75, '08844/44808/88880/88888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16472, '2015-07-07 15:33:15.667333+00', '2018-02-22 01:52:01.40596+00', 'Just One More', 'JUST ONE MORE', 1, 32, 9999, 1, 100, 2, 2874, NULL, 'For Marian Anderson and Max Ketchin for a memorable night after the Geneva spring dance in 2012.



The Bees of Maggieknockater Reels appeared in the dance of the same name by John Drewry, published in his Canadian Book of Scottish Country Dances.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16476, '2015-07-07 16:52:31.178904+00', '2018-04-02 23:56:37.138737+00', 'Rampant Lion-After 10am', 'RAMPANT LIONAFTER 10AM', 1, 32, 9999, 1, 3, 42, 11152, NULL, 'Written for the 70th birthday of Leon Œstergaard of Copenhagen.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16508, '2015-07-21 14:44:27.933725+00', '2016-03-15 22:58:51.681473+00', 'Twenty-three Two Ninety', 'TWENTYTHREE TWO NINETY', 3, 32, NULL, 2, 3, 18, 11164, '2015-02-23', '“This dance combines some of our favourite figures while allowing the lead couple to dance together most of the time. This seemed apt for a dance devised to celebrate our 25th wedding anniversary in February 2015.”', 67, '880/800/888/880', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16519, '2015-07-26 12:41:06.484933+00', '2018-04-02 23:56:38.254486+00', 'Two Little Girls from Jersey', 'TWO LITTLE GIRLS FROM JERSEY', 2, 32, NULL, 1, 3, 42, 9998, NULL, 'Stub entry. If you have more information about this dance, please let us know.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17858, '2017-06-23 09:00:24.630073+00', '2018-04-03 00:07:30.886243+00', 'AnnTony''s Delight', 'ANNTONYS DELIGHT', 1, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16503, '2015-07-21 09:01:20.622308+00', '2015-07-21 09:01:20.622308+00', 'Three Quarter Jig', 'THREE QUARTER JIG', 2, 32, 9999, 4, 119, 1, 11162, '2015-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16506, '2015-07-21 09:34:39.960245+00', '2018-11-26 00:48:53.976034+00', 'Turn the Corner', 'TURN THE CORNER', 2, 32, 9999, 1, 3, 42, 11162, '2015-01-01', '', 44, '800/444/444/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16501, '2015-07-21 08:29:16.482593+00', '2018-11-28 11:47:05.805857+00', 'Bootleg Dram', 'BOOTLEG DRAM', 2, 32, 9999, 1, 2, NULL, 11162, '2015-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17834, '2017-06-22 17:24:45.328204+00', '2018-04-03 00:07:37.579141+00', 'Ceilidh for Ken, A', 'CEILIDH FOR KEN', 1, 40, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16504, '2015-07-21 09:12:24.463178+00', '2018-11-29 05:15:00.748098+00', 'Keep Moving', 'KEEP MOVING', 2, 32, 9999, 1, 3, 42, 11162, '2015-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (224, '1998-10-31 23:00:00+00', '2018-12-15 11:58:04.924483+00', 'Argylls'' Farewell To Stirling', 'ARGYLLS FAREWELL TO STIRLING', 1, 40, 9999, 1, 4, 1, 103, NULL, 'The footnote to the original dance states that it was written to mark the Argyll and Sutherland Highlanders leaving Stirling castle.', 57, '6886  8880  8800  8040  8004', 0, 1, 1, 0, 57);
INSERT INTO 'dance' VALUES (17518, '2017-01-04 17:55:26.658054+00', '2019-06-28 14:47:45.409661+00', 'Regis Strathspey, The', 'REGIS STRATHSPEY', 3, 40, NULL, 1, 100, 2, 11110, '2004-01-01', 'This dance was devised for the day of Dance held in Bognor Regis on March 27th 2004. Invited teachers taught their own dances.', 93, '8888/8888/8888/8228/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17520, '2017-01-04 17:57:04.123525+00', '2019-06-28 15:06:15.234244+00', 'Rowan Square, The', 'ROWAN SQUARE', 2, 32, NULL, 4, 4, 4, 11110, '2004-04-01', 'In April each year I organize a Ceilidh in aid of the Rowans Hospice. This dance was written as a simple Ceilidh dance that everyone could join in and the progression of the ladies round the set adds to the sociability. This is also a dance suitable for beginners to Scottish dancing.', 69, '8080/0808/6666/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16507, '2015-07-21 14:40:46.214359+00', '2019-08-16 13:06:49.076525+00', 'Gerry''s Jig', 'GERRYS JIG', 2, 48, NULL, 1, 100, 2, 10961, '2012-06-01', '“Devised to celebrate Geraldine [Schuckelt]''s 49th birthday in June 2012.”', 75, '8008/0880/8888/8888/8008/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16471, '2015-07-07 15:15:09.857854+00', '2018-04-03 00:07:56.504065+00', 'Joy''s Undulations', 'JOYS UNDULATIONS', 3, 32, 9999, 1, 3, 42, 872, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16511, '2015-07-25 23:30:41.526413+00', '2018-04-03 00:08:17.244892+00', 'Skimming the Waves', 'SKIMMING THE WAVES', 1, 32, NULL, 1, 3, 42, 3703, NULL, 'From the book "Strathsbabes" by Pam Stephens and Ellen Ternes.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16502, '2015-07-21 08:54:39.940967+00', '2015-08-13 09:14:53.607111+00', 'Whisky Mixer, The', 'WHISKY MIXER', 1, 40, 9999, 1, 100, 2, 11162, '2015-01-01', '', 60, '4444/4444/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16500, '2015-07-21 08:23:07.774616+00', '2016-04-18 23:28:08.895537+00', 'Twist and Twirl', 'TWIST AND TWIRL', 2, 32, 9999, 1, 2, NULL, 11162, '2015-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16496, '2015-07-20 15:47:00.683258+00', '2017-05-15 13:59:54.729378+00', 'Swirling and Twirling Leaves', 'SWIRLING AND TWIRLING LEAVES', 2, 32, 9999, 1, 3, 42, 11161, '2015-01-01', '', 37, '480/408/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16477, '2015-07-07 16:58:20.168911+00', '2017-05-20 06:07:35.983456+00', 'Rider Hall, The', 'RIDER HALL', 3, 32, 9999, 2, 3, 17, 381, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16497, '2015-07-20 15:53:19.12618+00', '2017-05-15 16:17:03.054071+00', 'Toddle wi'' Joy', 'TODDLE WI JOY', 1, 40, 9999, 1, 3, 42, 11157, '2015-01-01', '', 56, '820/888/844/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10879, '2002-10-23 22:00:00+00', '2022-12-22 18:32:31.404096+00', 'Win Thompson''s Chase', 'WIN THOMPSONS CHASE', 1, 40, 9999, 4, 4, 46, 725, '2002-02-26', '', 45, '4444/4444/4444/4444/8000', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17527, '2017-01-05 09:34:20.528723+00', '2017-05-31 10:36:47.683717+00', 'Wardrobe, The', 'WARDROBE', 1, 32, NULL, 1, 3, 42, 2126, NULL, '', 47, '800/822/12 12 12/400', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16486, '2015-07-20 12:25:53.310694+00', '2018-04-02 23:56:32.660546+00', 'Apple for the Teacher, An', 'APPLE FOR THE TEACHER', 1, 64, 9999, 1, 3, 42, 1042, '2001-11-07', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16482, '2015-07-19 12:59:49.710142+00', '2016-05-18 08:41:46.839843+00', 'Gretna Green', 'GRETNA GREEN', 3, 48, 9999, 107, 3, 17, 1042, '2002-07-19', 'Danced in a square-like shape with 3 couples set up as follows: 1st man at top, 2nd couple next round clockwise, 1st lady in ''3rd place'', and 3rd couple next position opposite 2nd couple.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18299, '2018-04-24 18:28:28.006083+00', '2018-05-10 13:34:43.092095+00', 'Scarlet And Gold', 'SCARLET AND GOLD', 2, 32, NULL, 1, 3, NULL, 44, '2012-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11627, '2003-12-08 23:00:00+00', '2015-07-15 03:42:46.347938+00', 'Cath', 'CATH', 3, 32, 9999, 2, 3, 17, 3183, '2001-04-01', 'Devised for Cath Twigg on her retiral as teacher of the Helensburgh Scottish Country Dance Club.', 67, '800/888/880/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17528, '2017-01-05 09:45:17.147207+00', '2017-01-25 23:58:02.002098+00', 'Set in Roosendaal', 'SET IN ROOSENDAAL', 4, 128, 10040, 4, 4, 13, 10387, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16510, '2015-07-25 23:21:27.006477+00', '2020-10-15 21:36:15.214249+00', 'Pawling Mermaid, The', 'PAWLING MERMAID', 2, 32, NULL, 1, 3, 42, 1167, NULL, '', 50, '800/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16495, '2015-07-20 15:33:56.252448+00', '2020-12-29 12:25:26.26895+00', 'Swings and Roundabouts', 'SWINGS AND ROUNDABOUTS', 4, 64, 17, 1, 3, 42, 11157, '2015-01-01', '', 56, '800/888/888/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16513, '2015-07-26 10:17:26.294238+00', '2021-01-04 04:15:10.498054+00', 'Inspiration', 'INSPIRATION', 3, 32, NULL, 1, 3, 42, 3355, '2013-01-01', 'Devised for Peter Meier and Sylvia Nyffeler  



I had given up dancing and teaching completely because of a foot problem. When Peter joined the Zurich Scottish Country Dance Club as a beginner, he wanted help with his technique, so Sylvia got a little group together in her home and asked me to teach them. I am grateful, this has certainly prevented me from retiring and also keeps my brain active.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16518, '2015-07-26 10:25:15.872393+00', '2021-01-03 16:12:10.406791+00', 'Helping Hand, The', 'HELPING HAND', 2, 32, NULL, 1, 3, 42, 3355, '2005-01-01', 'Devised for Wilma Menzies-Sommer who always gives a helping hand.', 44, '800/822/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16505, '2015-07-21 09:29:34.353255+00', '2021-01-23 21:55:42.025352+00', 'Whirlwind, The', 'WHIRLWIND', 2, 32, 9999, 1, 3, 42, 11162, '2015-01-01', '<<scddb-not-identical:12789;13179;13729;20205>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14793, '2013-04-07 20:05:04.978999+00', '2015-07-15 22:30:51.313408+00', 'Home to Helensburgh', 'HOME TO HELENSBURGH', 1, 40, NULL, 1, 4, 1, 3183, '2008-04-01', 'Devised for Sue Smith who celebrated her 60th birthday by travelling to South America, visiting the Galapagos Islands and coming back “Home to Helensburgh.”', 62, '8000/8080/8888/8004/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13113, '2006-11-19 23:00:00+00', '2015-07-16 20:21:03.903861+00', 'Magic of Music, The', 'MAGIC OF MUSIC', 3, 32, 9999, 1, 4, 2, 3183, NULL, 'Devised by Anne Thorn for Mrs Mary McIntosh – an inspirational teacher of Scottish Country Dancing who always tried to find the best recorded music for the dances she taught.



Suggested alternative music: recorded music such as “Sarona” (J.S.Skinner), “Annie Laurie” (Lady J Scott), “The Lea Rig(Trad)”, “Rose Acre (J.S.Skinner)”, “The Cradle Song” (J.S.Skinner)', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16480, '2015-07-19 12:08:07.857396+00', '2015-07-19 12:08:07.857396+00', 'Camberley Rant, The', 'CAMBERLEY RANT', 2, 64, 9999, 1, 4, 22, 1042, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16483, '2015-07-20 07:37:27.085626+00', '2018-04-02 23:56:35.710744+00', 'Key of the Door, The', 'KEY OF THE DOOR', 1, 64, 9999, 1, 3, 42, 1042, '1960-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14566, '2012-09-08 09:08:20.681061+00', '2018-04-03 00:07:40.80768+00', 'Dance for Dorothy, A', 'DANCE FOR DOROTHY', 1, 32, NULL, 1, 3, 42, 3183, NULL, 'This dance was devised by Anne Thorn in June 2007 to celebrate the life of Mrs Dorothy Capstick who was Assistant Secretary of Helensburgh and District Branch of the RSCDS and secretary of both the Tuesday SCD Club and the Thursday Ladies SCD Club. For over 35 years Dorothy was an active dancer and supporter of SCD in the local area. Even though her husband did not dance he became Dorothy’s “secretary” due to his expertise with computers.



Bars 9-16 represent the support her husband Gordon gave to Dorothy in all of her

secretarial roles.



Bars 17-24 represent the close links Dorothy made with other dancers in the local area

and further afield whilst she was out dancing and Gordon was left at home.



Bars 25-32 – it is traditional in the Helensburgh area to finish off the programme with

a dance containing a circle.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18300, '2018-04-24 18:29:19.589718+00', '2018-04-24 18:29:19.589718+00', 'Auld Year''s Nicht', 'AULD YEARS NICHT', 1, 32, NULL, 1, 4, NULL, 44, '2013-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16484, '2015-07-20 07:46:33.786574+00', '2015-07-20 07:46:33.786574+00', 'Posthorn Gallop, The', 'POSTHORN GALLOP', 2, 32, 9999, 5, 113, NULL, 1042, '2001-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16485, '2015-07-20 07:50:19.734701+00', '2015-07-20 12:13:01.019388+00', 'Musicians, The', 'MUSICIANS', 2, 40, 9999, 1, 4, 1, 1042, '2001-06-24', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18303, '2018-04-25 21:58:47.892317+00', '2018-04-25 21:58:47.892317+00', 'Hertford Exchange', 'HERTFORD EXCHANGE', 3, 32, NULL, 2, 3, 30, 11629, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16487, '2015-07-20 12:58:23.512408+00', '2015-07-20 12:58:45.63629+00', 'Dance for Rhoda', 'DANCE FOR RHODA', 2, 32, 9999, 1, 4, 1, 1042, '2002-01-01', '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18304, '2018-04-25 22:08:12.841504+00', '2018-04-25 22:08:12.841504+00', 'Dance Around Hertford', 'DANCE AROUND HERTFORD', 3, 48, NULL, 2, 3, 17, 10629, '2008-01-01', 'To celebrate the 50th anniversary of South East Herts Scottish Country Dance Society', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16490, '2015-07-20 14:26:02.316284+00', '2017-05-14 20:21:44.276555+00', 'Fàilte gu Alba', 'FAILTE GU ALBA', 1, 40, 9999, 1, 3, 42, 11159, '2015-01-01', '', 95, '844/888/888/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16481, '2015-07-19 12:36:30.186732+00', '2016-05-18 08:43:32.640443+00', 'All on a Monday Morning', 'ALL ON A MONDAY MORNING', 3, 32, 9999, 107, 3, 17, 1042, NULL, 'Danced in a square-like shape with 3 couples set up as follows: 1st man at top, 2nd couple next round clockwise, 1st lady in ''3rd place'', and 3rd couple next position opposite 2nd couple.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16492, '2015-07-20 14:44:33.106702+00', '2017-05-14 22:15:05.000456+00', 'Potter''s Wheel, The', 'POTTERS WHEEL', 1, 32, 9999, 1, 4, 1, 11160, '2015-01-01', '', 72, '0880/4884/8888/8444', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18308, '2018-04-25 22:40:41.994782+00', '2018-04-27 11:30:57.181064+00', 'Botany Gate, The', 'BOTANY GATE', 3, 32, NULL, 1, 4, 11, 11630, '2018-01-01', 'Devised for the South East Herts Scottish Country Dance Society Diamond Jubilee in 2018.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16488, '2015-07-20 13:46:54.605598+00', '2017-08-09 11:49:42.196543+00', 'Cream Tea', 'CREAM TEA', 3, 32, 9999, 2, 3, 18, 11157, '2015-01-01', '', 92, '400/12 12 12/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18301, '2018-04-25 21:49:30.954411+00', '2018-05-03 17:26:30.930077+00', 'Hertford Castle', 'HERTFORD CASTLE', 3, 32, NULL, 1, 4, 1, 11628, '1963-01-01', 'Dedicated to Sue and Peter Day on the occasion of their departure to Ohio', 75, '8888/8448/8080/4848', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11617, '2003-12-04 23:00:00+00', '2018-05-10 13:34:27.538002+00', 'Wind On The Heath, The', 'WIND ON THE HEATH', 1, 32, 9999, 1, 3, 42, 44, '1997-01-01', '', 44, '800  888  800  880', 1, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (16491, '2015-07-20 14:36:06.716151+00', '2017-05-14 00:32:01.827393+00', 'Hope Valley Reel, The', 'HOPE VALLEY REEL', 1, 40, 9999, 1, 3, 42, 11160, '2015-01-01', '', 60, '888/800/808/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16493, '2015-07-20 15:12:26.719193+00', '2017-05-14 23:38:37.288034+00', 'Sheffield Castle', 'SHEFFIELD CASTLE', 4, 128, 10034, 1, 100, 2, 10821, '2015-01-01', '', 81, '8668/8888/8668/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16494, '2015-07-20 15:21:28.801167+00', '2017-05-15 13:36:35.605985+00', 'Silverdale Strathspey', 'SILVERDALE STRATHSPEY', 3, 32, 9999, 1, 102, 2, 10123, '2015-01-01', '', 100, '8888/8888/8888/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16489, '2015-07-20 13:56:44.402267+00', '2017-05-14 19:55:08.69729+00', 'Damflask Strathspey, The', 'DAMFLASK STRATHSPEY', 3, 32, 9999, 2, 3, 18, 11158, '2015-01-01', '', 75, '686/686/484/448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18302, '2018-04-25 21:54:00.462595+00', '2022-12-04 13:25:02.156726+00', 'To Gill and Nigel', 'TO GILL AND NIGEL', 3, 32, NULL, 1, 4, 13, 826, '1983-01-01', 'Dedicated to Gill and Nigel Pollard on their Silver Wedding.', 62, '0008/0008/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19040, '2018-10-27 21:55:41.554894+00', '2019-03-03 09:36:23.271533+00', 'Good Dance, The', 'GOOD DANCE', 1, 32, NULL, 1, 3, 42, 3165, NULL, 'Deviser uncertain (source just says "Wright").', 50, '800/880/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12512, '2005-08-21 22:00:00+00', '2018-04-26 21:09:16.091471+00', 'Elinor''s Dozen', 'ELINORS DOZEN', 4, 128, 13, 4, 98, 3, 3618, '1998-06-01', '12 dancers: four W+M+W in a square.

Devised for Elinor Vandegrift and her 12 teacher candidates.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17521, '2017-01-04 17:58:06.18784+00', '2019-06-28 15:16:59.786361+00', 'Spitbank Fort', 'SPITBANK FORT', 3, 96, NULL, 4, 4, 3, 11110, '2005-09-01', 'Spitbank Fort is in the Solent between Portsmouth and the Isle of Wight. One summer evening Southsea Reel Club went out by ferry to the Fort and held a Ceilidh. Figs 1 and 3 represent the ferry journey showing the currents and eddies in the sea and around the fort. Fig 2 represents the Ceilidh and dancing on the Fort.', 92, '8484/8888/8888/8484/8888/8888/8888/8888/8484/8888/8888/8484', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16585, '2015-08-26 14:19:35.858515+00', '2018-04-02 23:56:35.477028+00', 'Jig for June, A', 'JIG FOR JUNE', 2, 32, 9999, 1, 3, 42, 403, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17529, '2017-01-05 09:51:56.40107+00', '2018-03-20 20:49:42.40644+00', 'Rainbow''s End', 'RAINBOWS END', 1, 32, NULL, 1, 3, 42, 11437, '1996-01-01', '', 44, '800/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16520, '2015-07-26 13:54:40.595507+00', '2018-07-27 09:48:12.379377+00', 'Ladies of Banffshire, The', 'LADIES OF BANFFSHIRE', 3, 32, NULL, 2, 3, 17, 384, NULL, '', 70, '880/888/822/808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16587, '2015-08-26 14:45:18.909115+00', '2018-04-02 23:56:35.77753+00', 'Lad and His Lassies, A', 'LAD AND HIS LASSIES', 3, 32, 9999, 1, 3, 42, 11175, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16521, '2015-07-31 01:40:55.203983+00', '2018-04-03 00:07:46.379579+00', 'Flyping Out of Portland', 'FLYPING OUT OF PORTLAND', 2, 32, NULL, 1, 3, 42, 1167, '2015-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18685, '2018-10-02 01:16:59.367803+00', '2018-10-02 01:16:59.367803+00', 'Borne on the Breeze', 'BORNE ON THE BREEZE', 2, 32, NULL, 1, 3, 42, 2766, '2010-04-01', 'This dance was inspired by watching our cats breathing in the scents from outside when we had the doors open in the spring.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16535, '2015-07-31 14:31:02.890241+00', '2018-10-14 06:57:07.080139+00', 'John Cass', 'JOHN CASS', 2, 32, 9999, 3, 5, 16, 2788, '2012-04-01', 'Dedicated to John Cass on his 90th birthday, April 2012.



John proposes that, on [29-32] of 5th time through,  all couples make the R elbow grip pivot turn.



', 55, '80000/84444/84444/80000', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16522, '2015-07-31 13:58:46.569638+00', '2019-04-02 20:50:41.425642+00', 'Neil M Grant', 'NEIL M GRANT', 2, 32, 9999, 1, 3, 42, 11166, '2012-02-01', 'For Neil Grant on his 70th birthday, February 2012.', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14712, '2013-02-04 00:58:42.573561+00', '2015-08-12 14:11:51.25594+00', 'Sunshine and Sweetie''s Jig', 'SUNSHINE AND SWEETIES JIG', 2, 32, NULL, 1, 3, 42, 347, '2012-02-01', 'To celebrate the arrival, in December 2011,  of two Chinese pandas on long term loan to Edinburgh Zoo.



In the final version, published in book 48, bars 25-32 have been modified.  Don''t use earlier "originals".', 50, '880  844  844  844', 1, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (18767, '2018-10-05 08:25:56.825257+00', '2018-10-05 08:25:56.825257+00', 'Frozen Falls', 'FROZEN FALLS', 2, 32, NULL, 1, 3, 42, 2766, '2014-03-01', 'This dance was inspired by a news story of Niagara Falls frozen over.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15459, '2014-06-09 15:30:36.882517+00', '2019-05-22 12:19:36.069021+00', 'Kilts and Posh Frocks', 'KILTS AND POSH FROCKS', 3, 32, NULL, 4, 4, 1, 11813, '2012-02-01', 'Devised to commemorate the Chiswick Scottish Dancing Club’s 10th Anniversary.  It is dedicated to the club’s founder, Kay Senior.', 94, '8888/8484/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16533, '2015-07-31 14:23:15.016989+00', '2018-10-14 05:45:46.724254+00', 'Flora''s Fancy', 'FLORAS FANCY', 2, 32, 9999, 1, 3, 42, 11168, NULL, 'The dance is based on ideas by the youngest dancer in the class, 10-year-old Katie Oftedahl, who chose the title.', 50, '844/880/844/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16526, '2015-07-31 14:07:25.66019+00', '2019-02-13 13:49:47.233626+00', 'Miss Eleanor', 'MISS ELEANOR', 3, 32, 9999, 2, 3, 18, 104, NULL, 'Miss Eleanor is Ann Dix''s granddaughter.', 83, '888/800/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16538, '2015-08-05 10:38:41.622663+00', '2015-08-05 10:38:41.622663+00', 'Verona''s 100th', 'VERONAS 100TH', 3, 40, NULL, 2, 3, 17, 10951, '2015-08-02', 'Devised for the 100th birthday of Verona Rose, 2 August 2015', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12124, '2005-04-09 22:00:00+00', '2015-08-12 14:16:33.258966+00', 'Lady in Red', 'LADY IN RED', 2, 32, 9999, 3, 5, 7, 1089, NULL, 'Dedicated to Leslie Dawes of Gleneagles Scottish Country Dance Club, West Vancouver and

Vancouver Branch.



Misprint. The dance description in the Highlander Collection vol 1 says that this is a Strathspey, but the music is a Jig.   ETF 30 oct 2011



Malcolm Brown writes on the Strathspey List:



"The dance was first published in the Vancouver Branch Ruby Collection in

2005, where the accompanying tune is Gentle Shepherd.



It was then published in Simon''s own collection of dances as part of the

Branxholm Hall Suite / Lady in Red Collection in 2007, where again the tune

is Gentle Shepherd, and where Simon says "the dance was inspired by, and

written to the beautiful tune The Gentle Shepherd as recorded on St Andrews

Ball by Ron Kerr", and where it is also described as a "32 bar slow jig"."



(As slow jigs go, the Ron Kerr recording in question is not particularly slow.)', 80, '88888  08080  88888  84884', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (14741, '2013-03-16 13:37:12.293304+00', '2015-08-12 23:06:54.783523+00', 'Swan and the Tay, The', 'SWAN AND THE TAY', 3, 32, NULL, 2, 3, 18, 10688, NULL, 'The Perth & Perthshire Branch Newsletter "The Highland Gateway" for January 2011 has the following text:



"From locally here in Perth, Scotland, the links spread internationally to Perth, Western Australia where the RSCDS Branch was asked to contribute a reel and a strathspey in honour of the Perth 800 anniversary. The dances “The Swan and the Tay” (which represents the two city rivers) and “Perth meets Perth” (representing dancers crossing the world to join together in the dance) were submitted. Appropriately their tunes “Mo Rutherford’s compliments to Frank Thomson” and Jim Johnston’s “The Carse of Gowrie” were arranged by Mo Rutherford, former RCDS Musical Director, and of course one of Perth‘s best known musicians."



So this dance comes from Perth (Australia), but was published in Scotland in the RSCDS booklet "Perth 800".

', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16582, '2015-08-26 13:55:01.700493+00', '2015-08-26 13:55:01.700493+00', 'Feel the Music', 'FEEL THE MUSIC', 3, 40, 9999, 1, 4, 1, 11177, NULL, 'Suggested recorded music: 

Strathmore, Take Your Partners Vol.1 by Luke Brady', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16584, '2015-08-26 14:14:15.288818+00', '2015-08-26 14:14:15.288818+00', 'Hamilton Diamond Medley, The', 'HAMILTON DIAMOND MEDLEY', 4, 96, 11, 4, 4, 3, 3668, NULL, 'Suggested recorded music:

The Nor'' Loch, HRMCD503 #9 by David Cunningham', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17859, '2017-06-23 09:00:55.006632+00', '2017-06-23 09:00:55.006632+00', 'Cool and Crisp', 'COOL AND CRISP', 1, 32, NULL, 2, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16580, '2015-08-26 13:16:02.746886+00', '2018-04-02 23:56:33.790665+00', 'Darling Buds of June', 'DARLING BUDS OF JUNE', 1, 32, 9999, 1, 3, 42, 11175, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7161, '1997-04-03 22:00:00+00', '2018-04-26 22:46:56.057136+00', 'William Elphinstone', 'WILLIAM ELPHINSTONE', 3, 32, 9999, 3, 5, 6, 108, '1994-01-01', 'Devised: 1994

A dance to mark 500 years since the foundation of the Universityof Aberdeen by Bishop Elphinstone.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16539, '2015-08-18 15:21:23.654594+00', '2015-08-18 15:21:23.654594+00', 'An Cala', 'CALA', 3, 32, NULL, 2, 3, 17, 370, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16540, '2015-08-18 15:22:48.039479+00', '2015-08-18 15:22:48.039479+00', 'Ben Merrick', 'BEN MERRICK', 3, 64, NULL, 4, 4, 54, 370, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16524, '2015-07-31 14:04:44.374632+00', '2022-05-03 11:57:03.01679+00', 'Midsummer Common', 'MIDSUMMER COMMON', 3, 32, 9999, 1, 3, 42, 11167, NULL, '', 43, '800/844/844/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21250, '2023-01-05 11:45:30.018655+00', '2023-01-05 11:45:30.018655+00', 'Life Cycle, The', 'LIFE CYCLE', 3, 32, NULL, 1, 4, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21253, '2023-01-05 11:48:25.394759+00', '2023-01-05 11:48:25.394759+00', 'Mary''s Lamb', 'MARYS LAMB', 2, 32, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21256, '2023-01-05 11:51:08.337242+00', '2023-01-05 11:51:08.337242+00', 'Oran Na Mara', 'ORAN NA MARA', 3, 40, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21259, '2023-01-05 11:53:34.012495+00', '2023-01-05 11:53:34.012495+00', 'Platinum Joy', 'PLATINUM JOY', 1, 32, NULL, 1, 4, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21263, '2023-01-05 12:31:43.01366+00', '2023-01-05 12:31:43.01366+00', 'Tandem-onium', 'TANDEMONIUM', 1, 40, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16057, '2015-02-14 13:45:09.629952+00', '2018-04-26 22:53:41.159172+00', 'Jubilee Stars', 'JUBILEE STARS', 1, 40, 9999, 3, 5, 6, 3783, NULL, 'I devised this dance as an alternative to John Drewry''s "Five Stars", which is a really challenging dance and which I feel is a little bit too difficult for ordinary dancers.



Bars 9-24 are based on another John Drewry''s dance "Recumbent Stone". Therefore I owe this

dance doubly to John Drewry.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16543, '2015-08-18 15:27:06.542791+00', '2015-08-18 15:27:06.542791+00', 'Galloway Homecoming', 'GALLOWAY HOMECOMING', 1, 96, NULL, 4, 4, 3, 370, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16544, '2015-08-18 15:28:55.460327+00', '2015-08-18 15:28:55.460327+00', 'Kirkcudbright', 'KIRKCUDBRIGHT', 3, 32, NULL, 1, 4, 1, 370, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16545, '2015-08-18 15:30:11.509309+00', '2015-08-18 15:30:11.509309+00', 'Marney''s Wee Jaunt', 'MARNEYS WEE JAUNT', 1, 32, NULL, 2, 3, 17, 370, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16581, '2015-08-26 13:32:03.163429+00', '2018-04-02 23:56:34.057879+00', 'Dundas Valley Reel, The', 'DUNDAS VALLEY REEL', 1, 32, 9999, 1, 3, 42, 11176, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16550, '2015-08-18 15:55:37.244188+00', '2015-08-18 15:55:37.244188+00', 'Happy Days', 'HAPPY DAYS', 1, 32, NULL, 1, 2, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18769, '2018-10-05 08:32:48.091599+00', '2018-10-05 08:32:48.091599+00', 'Gear Shift', 'GEAR SHIFT', 2, 32, NULL, 8, 105, 12, 2766, '2014-08-01', 'The last figure reminds me of gears and 1C and 6C shift sets each time through the dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18778, '2018-10-05 12:28:58.188826+00', '2018-10-05 12:28:58.188826+00', 'Gold Ring, The', 'GOLD RING', 3, 32, NULL, 1, 3, 42, 2766, '2007-09-01', 'This dance is in honor of Roy Goldring, who writes dances dancers love to dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18788, '2018-10-05 13:42:01.028789+00', '2018-10-05 13:42:01.028789+00', 'Hogwarts Express', 'HOGWARTS EXPRESS', 1, 32, NULL, 1, 3, 42, 2766, '2015-03-01', 'This dance is written especially for a Harry Potter themed dance night.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16566, '2015-08-22 17:32:07.73962+00', '2020-10-13 20:03:37.088994+00', 'Ruby Wilkinson''s Farewell to Cranshaws', 'RUBY WILKINSONS FAREWELL TO CRANSHAWS', 3, 32, NULL, 1, 100, 2, 1415, '2015-08-01', '', 75, '8008/8888/8008/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16560, '2015-08-18 22:56:53.25554+00', '2018-04-03 00:07:37.228698+00', 'Castle McClennan', 'CASTLE MACCLENNAN', 1, 32, NULL, 1, 3, 42, 1144, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18789, '2018-10-05 13:52:44.516357+00', '2018-10-05 13:52:44.516357+00', 'Honor the Lady', 'HONOR THE LADY', 1, 32, NULL, 1, 3, 42, 2766, '2009-08-01', 'This dance was written for Mary Helen Polensky on a "special" birthday.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16552, '2015-08-18 16:14:46.303537+00', '2019-02-05 23:56:27.422295+00', 'Fairfield', 'FAIRFIELD', 2, 32, NULL, 1, 3, 42, 370, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16561, '2015-08-18 22:58:38.776128+00', '2015-08-18 22:58:38.776128+00', 'Garlieston', 'GARLIESTON', 2, 32, NULL, 1, 4, 2, 1144, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16541, '2015-08-18 15:24:18.665099+00', '2018-04-03 00:07:41.691863+00', 'Dee Walk', 'DEE WALK', 1, 32, NULL, 1, 3, 42, 370, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16576, '2015-08-26 09:40:25.150439+00', '2019-02-25 23:57:39.952626+00', 'Primrose Path', 'PRIMROSE PATH', 3, 32, NULL, 2, 3, 17, 234, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16564, '2015-08-18 23:03:12.426116+00', '2015-08-18 23:05:25.047359+00', 'Norwegian Tryst', 'NORWEGIAN TRYST', 1, 32, NULL, 1, 4, 1, 11170, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16551, '2015-08-18 16:12:57.36501+00', '2018-04-03 00:07:46.462976+00', 'For Auld Acquaintance', 'FOR AULD ACQUAINTANCE', 3, 32, NULL, 1, 3, 42, 370, '2006-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16547, '2015-08-18 15:50:54.649978+00', '2018-04-03 00:07:49.257478+00', 'Golden Jig, A', 'GOLDEN JIG', 2, 32, NULL, 1, 3, 42, 1144, '2014-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16542, '2015-08-18 15:25:37.900387+00', '2018-04-03 00:07:53.660576+00', 'Invercaimbe', 'INVERCAIMBE', 2, 32, NULL, 1, 3, 42, 370, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16571, '2015-08-26 09:08:37.338184+00', '2017-11-07 23:09:55.766427+00', 'Vefa''s Strathspey', 'VEFAS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11181, '2015-02-18', 'Devised for Vefa Balac''s birthday, 28th February 2015. Vefa is the nickname for Genovefa, which is the Breton translation of the name Geneviève.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16553, '2015-08-18 16:17:12.061434+00', '2018-04-03 00:07:56.145618+00', 'John Gordon', 'JOHN GORDON', 4, 32, 1, 1, 3, 42, 370, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16554, '2015-08-18 16:21:34.76862+00', '2018-04-03 00:07:59.82365+00', 'Littles of St Andrews, The', 'LITTLES OF ST ANDREWS', 3, 32, NULL, 1, 3, 42, 370, '2002-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16559, '2015-08-18 22:28:28.55713+00', '2017-05-31 11:00:28.479018+00', 'Twelvesome, A', 'TWELVESOME', 1, 88, NULL, 4, 119, 3, 370, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16562, '2015-08-18 22:59:53.362223+00', '2017-05-31 12:36:42.72236+00', 'Sheiling, The', 'SHEILING', 1, 80, NULL, 4, 4, 3, 370, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16563, '2015-08-18 23:01:57.675703+00', '2017-05-31 12:48:28.356242+00', 'Munro Baggers'' Rant, The', 'MUNRO BAGGERS RANT', 1, 32, NULL, 4, 4, 1, 11170, '2006-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16549, '2015-08-18 15:54:25.034186+00', '2017-05-31 12:53:04.733+00', 'Determined Young Man, The', 'DETERMINED YOUNG MAN', 1, 32, NULL, 1, 4, 1, 370, '2014-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16548, '2015-08-18 15:52:49.908427+00', '2018-04-03 00:08:24.95838+00', 'We Twa Goes Golden', 'WE TWA GOES GOLDEN', 3, 32, NULL, 1, 3, 42, 11170, '2014-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16546, '2015-08-18 15:31:14.855493+00', '2018-02-18 09:57:44.780578+00', 'Meeting and Greeting', 'MEETING AND GREETING', 3, 32, NULL, 1, 4, 2, 370, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16555, '2015-08-18 16:25:43.08867+00', '2018-04-03 00:08:01.074487+00', 'Macdonald''s Hornpipe', 'MACDONALDS HORNPIPE', 1, 32, NULL, 1, 3, 42, 370, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16565, '2015-08-18 23:04:44.8519+00', '2018-04-03 00:08:09.337655+00', 'OSCDG', 'OSCDG', 3, 32, NULL, 1, 3, 42, 370, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16557, '2015-08-18 22:22:43.322854+00', '2018-04-03 00:08:10.681875+00', 'Pink Ribbon, The', 'PINK RIBBON', 1, 40, NULL, 1, 3, 42, 1144, '2004-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16689, '2015-08-29 14:34:00.197525+00', '2018-04-29 04:33:38.479484+00', 'St Andrews Sea', 'SAINT ANDREWS SEA', 3, 32, 9999, 1, 3, 42, 11187, NULL, 'The modified corners pass and turn was suggested by Mrs. Kazuko Hasegawa.  



This dance was inspired when I was looking at irregular patterns of waves and ripples on the suiface of the sea from the castle ruin in St. Andrews. ', 38, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16618, '2015-08-27 10:20:52.743783+00', '2018-04-11 01:32:09.89314+00', 'Drums of Duntulm Castle, The', 'DRUMS OF DUNTULM CASTLE', 1, 32, NULL, 1, 3, 42, 10961, '2013-01-01', 'This dance was written by Holger in January 2013.  

The drum solo in "The Magic of Merrill" reminded him of the crashing of the waves around Duntulm Castle at the northern coast of the Isle of Skye.', 44, '800/888/844/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16588, '2015-08-26 14:57:50.551612+00', '2018-04-02 23:56:36.270143+00', 'Memories of June', 'MEMORIES OF JUNE', 3, 32, 9999, 1, 3, 42, 11178, NULL, 'Suggested recorded music:

Ladykirk Bridge, Silver Thistle Collection by David Cunningham', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16592, '2015-08-26 15:44:24.387154+00', '2015-08-26 15:44:24.387154+00', 'There''ll Be Another Chord', 'THERELL BE ANOTHER CHORD', 1, 32, 9999, 1, 4, 1, 172, NULL, 'Suggested recorded music:

Charlie''s Silver Jubilee, Reels and Wheels by Gordon Shand', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18773, '2018-10-05 09:26:43.483697+00', '2018-10-05 09:26:43.483697+00', 'Gift Wrapped', 'GIFT WRAPPED', 1, 32, NULL, 1, 3, 42, 2766, '2016-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16589, '2015-08-26 15:06:40.510818+00', '2018-04-02 23:56:36.671213+00', 'New Year''s Days at Victoria Avenue', 'NEW YEARS DAYS AT VICTORIA AVENUE', 2, 32, 9999, 1, 3, 42, 172, NULL, 'Suggested recorded music:

January Jig, The Silver Collection by David Cunningham

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16572, '2015-08-26 09:36:14.809814+00', '2022-12-02 21:38:47.389731+00', 'Sleekit Beastie', 'SLEEKIT BEASTIE', 3, 32, NULL, 2, 3, 17, 234, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16573, '2015-08-26 09:37:20.010198+00', '2022-12-02 21:40:41.099029+00', 'Penannular', 'PENANNULAR', 1, 32, NULL, 1, 3, 42, 234, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16574, '2015-08-26 09:38:10.493545+00', '2022-12-02 21:43:27.118618+00', 'Wildwood', 'WILDWOOD', 3, 32, NULL, 2, 3, 17, 234, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16575, '2015-08-26 09:39:32.433492+00', '2022-12-02 21:45:20.650329+00', 'Green and Gold', 'GREEN AND GOLD', 2, 32, NULL, 1, 3, 42, 234, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16577, '2015-08-26 09:41:33.681275+00', '2022-12-02 21:50:48.08124+00', 'Green Diamond', 'GREEN DIAMOND', 2, 64, NULL, 4, 4, 13, 234, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16578, '2015-08-26 09:42:34.630559+00', '2022-12-02 21:55:41.069997+00', 'Frozen in Scarborough', 'FROZEN IN SCARBOROUGH', 3, 32, NULL, 2, 3, 17, 234, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18775, '2018-10-05 12:19:33.812689+00', '2018-10-05 12:19:33.812689+00', 'Glen Iris Inn', 'GLEN IRIS INN', 3, 32, NULL, 1, 3, 42, 2766, '2009-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16637, '2015-08-27 16:38:41.359645+00', '2019-07-09 23:43:38.719737+00', 'Esther Naomi MacDonald Boyd', 'ESTHER NAOMI MACDONALD BOYD', 1, 32, NULL, 1, 3, 42, 10568, '2013-10-01', 'For my mother, who was always on the go. I miss her.', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16558, '2015-08-18 22:26:10.253907+00', '2020-10-15 21:38:51.818704+00', 'Trip to Moscow, A', 'TRIP TO MOSCOW', 1, 32, NULL, 1, 3, 42, 370, '2001-05-01', '', 53, '880/888/804/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2402, '1997-04-03 22:00:00+00', '2021-06-05 11:45:37.432228+00', 'Gardener''s Delight', 'GARDENERS DELIGHT', 2, 40, 9999, 1, 3, 42, 3590, '1993-08-01', 'For Peter Le Mesurier on his retirement, August 1993.', 48, '800/804/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16594, '2015-08-26 15:54:19.255421+00', '2018-04-02 23:56:38.516022+00', 'We''ll Meet Again', 'WELL MEET AGAIN', 1, 40, 9999, 1, 3, 42, 11180, NULL, 'Suggested music:

Kingussie Flower, as played by Stan Hamilton', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16601, '2015-08-26 18:56:41.662885+00', '2019-09-18 13:56:52.899479+00', 'In the Frame', 'IN THE FRAME', 4, 128, 10034, 4, 4, 13, 3183, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16633, '2015-08-27 16:34:07.940498+00', '2018-04-03 00:07:29.305072+00', '23 Earl Bank Avenue', '23 EARL BANK AVENUE', 3, 32, NULL, 1, 3, 42, 10568, '2012-09-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16609, '2015-08-26 19:08:52.596154+00', '2015-08-26 19:08:52.596154+00', 'Welcome One and All', 'WELCOME ONE AND ALL', 1, 32, NULL, 5, 56, NULL, 3183, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16634, '2015-08-27 16:35:14.806979+00', '2018-04-03 00:07:30.242256+00', 'All the Right Moves', 'ALL THE RIGHT MOVES', 2, 32, NULL, 1, 3, 42, 10568, '2014-08-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16567, '2015-08-25 22:24:18.505815+00', '2015-08-27 02:15:58.137448+00', 'Snow White Strathspey', 'SNOW WHITE STRATHSPEY', 3, 32, NULL, 2, 3, 17, 10961, NULL, '', 58, '844/800/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16616, '2015-08-26 19:16:35.50334+00', '2018-04-03 00:07:48.898249+00', 'Glen Shira', 'GLEN SHIRA', 1, 32, NULL, 1, 3, 42, 3183, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16621, '2015-08-27 11:21:28.646959+00', '2015-08-27 11:21:28.646959+00', 'Suitor, The', 'SUITOR', 3, 32, NULL, 2, 3, 17, 10961, '2013-08-01', '', 50, '800/888/880/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16622, '2015-08-27 11:27:14.406949+00', '2015-08-27 11:27:14.406949+00', 'Standing Stones of Calanais, The', 'STANDING STONES OF CALANAIS', 2, 32, NULL, 4, 4, 4, 10961, '2013-11-01', '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16599, '2015-08-26 18:54:36.579881+00', '2018-04-03 00:07:49.482661+00', 'Gracefully Gliding', 'GRACEFULLY GLIDING', 3, 32, NULL, 1, 3, 42, 3183, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16602, '2015-08-26 18:58:02.954112+00', '2018-04-03 00:08:01.708217+00', 'Making Links', 'MAKING LINKS', 3, 32, NULL, 1, 3, 42, 3183, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16606, '2015-08-26 19:00:38.054988+00', '2018-04-03 00:08:05.327587+00', 'Morino Magic', 'MORINO MAGIC', 1, 32, NULL, 1, 3, 42, 3183, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16607, '2015-08-26 19:01:17.273575+00', '2018-04-03 00:08:06.962462+00', 'Musically Marvellous', 'MUSICALLY MARVELLOUS', 1, 32, NULL, 1, 3, 42, 3183, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16620, '2015-08-27 10:33:41.271822+00', '2015-08-28 13:33:12.549985+00', 'Proud Lotus of the East', 'PROUD LOTUS OF THE EAST', 1, 32, NULL, 1, 3, 42, 10961, '2013-07-01', 'For Asmita.', 50, '800/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16590, '2015-08-26 15:14:12.993622+00', '2016-04-18 23:21:43.035706+00', 'Polar Vortex, The', 'POLAR VORTEX', 1, 32, 9999, 1, 2, NULL, 3667, NULL, 'Suggested recorded music: a slower reel such as

The Cast''n Reel, Moments in Time by Jim Lindsay, Keith Smith and Muriel Johnstone', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16614, '2015-08-26 19:14:31.538067+00', '2016-09-25 13:18:08.567847+00', 'Piper and the Fiddle, The', 'PIPER AND THE FIDDLE', 3, 32, NULL, 2, 3, 17, 3183, '2012-03-01', 'Devised for Richard Maudsley, a keen player of Northumbrian pipes and the violin

', 50, '880/800/888/808', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16613, '2015-08-26 19:13:15.759945+00', '2016-10-12 21:07:02.673294+00', 'Sanquhar''s Cornet Lass', 'SANQUHARS CORNET LASS', 2, 32, NULL, 1, 3, 42, 3183, '2011-09-01', 'Devised for Anna Moffat, a Sanquhar Lass, for a special birthday in September 2011.', 44, '800/844/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1940, '1997-04-03 22:00:00+00', '2018-04-29 10:46:09.317637+00', 'Elders In The Kirk, The', 'ELDERS IN THE KIRK', 2, 32, 9999, 1, 4, NULL, 413, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16660, '2015-08-27 17:57:09.129988+00', '2018-04-02 23:56:36.838152+00', 'Our Plattsburg Connection', 'OUR PLATTSBURG CONNECTION', 1, 32, NULL, 1, 3, 42, 10568, '2013-12-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16644, '2015-08-27 16:45:56.069093+00', '2018-04-03 00:07:50.166355+00', 'Guardian of the Purse', 'GUARDIAN OF THE PURSE', 1, 32, NULL, 1, 3, 42, 10568, '2014-04-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16647, '2015-08-27 17:42:38.629912+00', '2018-04-03 00:07:51.959185+00', 'Hermann''s Jig', 'HERMANNS JIG', 2, 32, NULL, 1, 3, 42, 10568, '2015-02-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16651, '2015-08-27 17:47:59.38028+00', '2015-08-27 17:47:59.38028+00', 'Lee-Lee', 'LEELEE', 3, 32, NULL, 2, 3, NULL, 10568, '2013-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16646, '2015-08-27 16:48:09.086486+00', '2019-09-01 21:38:23.416263+00', 'Heavenly, Merry Dancers, The', 'HEAVENLY MERRY DANCERS', 3, 32, NULL, 3, 5, 7, 10568, '2012-10-01', '32 bar strathspey for three/five couples in a three couple/five couple set.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16652, '2015-08-27 17:48:57.590638+00', '2018-04-03 00:08:00.757664+00', 'Lost in Manoa Marketplace', 'LOST IN MANOA MARKETPLACE', 1, 32, NULL, 1, 3, 42, 10568, '2014-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16653, '2015-08-27 17:49:56.259184+00', '2018-04-03 00:08:01.791681+00', 'Manderley', 'MANDERLEY', 1, 32, NULL, 1, 3, 42, 10568, '2013-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16662, '2015-08-27 17:58:55.220557+00', '2018-04-03 00:08:10.848696+00', 'Piping Plovers, The', 'PIPING PLOVERS', 3, 32, NULL, 1, 3, 42, 10568, '2013-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16665, '2015-08-27 18:01:47.497202+00', '2018-04-03 00:08:15.059979+00', 'Saxonia', 'SAXONIA', 2, 32, NULL, 1, 3, 42, 10568, '2014-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16676, '2015-08-27 20:36:33.806425+00', '2018-07-01 23:18:04.280914+00', 'Saxonia Express, The', 'SAXONIA EXPRESS', 2, 32, NULL, 1, 3, 42, 10961, '2014-09-01', 'For Keith Paterson.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16661, '2015-08-27 17:57:57.681553+00', '2019-10-16 00:36:39.597674+00', 'Picton Tartan Tea Dance', 'PICTON TARTAN TEA DANCE', 1, 32, NULL, 1, 3, 42, 10568, '2013-04-01', 'I wrote this after a lovely weekend at the Prince Edward County Scottish Country Dancers Tartan Tea Weekend Workshop and Tea Dance.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16666, '2015-08-27 18:02:37.926402+00', '2015-08-27 18:02:37.926402+00', 'Seventy in Copenhagen', 'SEVENTY IN COPENHAGEN', 2, 32, NULL, 1, 4, NULL, 10568, '2015-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16667, '2015-08-27 18:03:25.756231+00', '2015-08-27 18:03:25.756231+00', 'Skating on Mount Royal', 'SKATING ON MOUNT ROYAL', 3, 32, NULL, 2, 3, NULL, 10568, '2014-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16668, '2015-08-27 18:04:52.484839+00', '2015-08-27 18:04:52.484839+00', 'Sweet Home Alabama', 'SWEET HOME ALABAMA', 4, 128, 2, 1, 4, NULL, 10568, '2013-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13887, '2011-08-22 22:00:00+00', '2020-09-24 12:52:35.899235+00', 'Smiling Sally', 'SMILING SALLY', 2, 32, NULL, 1, 3, 42, 2788, NULL, '', 47, '820/820/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16625, '2015-08-27 13:40:13.343811+00', '2020-10-15 21:43:22.274772+00', 'Slow Simmer', 'SLOW SIMMER', 2, 32, NULL, 1, 3, 42, 3703, NULL, '', 63, '888/888/880/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16663, '2015-08-27 18:00:06.906622+00', '2020-10-15 21:49:29.004898+00', 'Red and White Poppies, The', 'RED AND WHITE POPPIES', 1, 32, NULL, 1, 3, 42, 10568, '2012-11-01', '', 56, '800/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16635, '2015-08-27 16:36:22.759099+00', '2022-04-25 17:06:14.645014+00', 'Aloha Kekokia', 'ALOHA KEKOKIA', 3, 32, NULL, 1, 3, 42, 10568, '2013-02-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16659, '2015-08-27 17:56:14.130597+00', '2022-08-13 20:31:18.71208+00', 'Off to Thailand', 'OFF TO THAILAND', 1, 32, NULL, 1, 3, 42, 10568, '2013-08-01', 'The notes say "This was written to say ''au revoir'' to Kachina, Alex and Orion as they head off on a new adventure. They have promised to come back!"', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16600, '2015-08-26 18:55:19.283619+00', '2022-12-03 18:35:26.151308+00', 'Hillbrook House', 'HILLBROOK HOUSE', 3, 32, NULL, 2, 3, 17, 3183, '2014-05-01', 'Inscribed "for Douglas Thomson’s 70th birthday in May 2014."', 79, '888/840/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16603, '2015-08-26 18:58:43.6332+00', '2022-12-03 18:53:04.640402+00', 'Marian Anderson''s Strathspey', 'MARIAN ANDERSONS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 3183, '2014-03-01', '', 79, '880/888/844/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16611, '2015-08-26 19:11:27.458112+00', '2022-12-03 19:04:20.643935+00', 'Silver Bells', 'SILVER BELLS', 3, 40, NULL, 6, 3, 17, 3183, '2011-01-01', 'The notes say this was "devised by Anne Thorn for her silver wedding anniversary in 2011."', 90, '888/888/822/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21289, '2023-01-12 16:06:52.35887+00', '2023-01-12 16:06:52.35887+00', 'Sailors'' Knot, The', 'SAILORS KNOT', 6, 160, NULL, 2, 3, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21310, '2023-01-17 22:45:20.412199+00', '2023-01-17 22:45:20.412199+00', 'Reunions', 'REUNIONS', 1, 32, NULL, 1, 3, NULL, 12254, '2019-09-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16632, '2015-08-27 13:50:04.270625+00', '2021-02-26 23:14:59.230527+00', 'Somewhere in America', 'SOMEWHERE IN AMERICA', 2, 32, NULL, 1, 3, 42, 2932, NULL, 'Devised by Ellen Ternes for Anne and Ewen MacAskill on their leaving America witlwut our permission.', 50, '800/844/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2430, '1998-01-05 23:00:00+00', '2021-01-10 08:54:53.329077+00', 'Geneva Alliance, The', 'GENEVA ALLIANCE', 1, 32, 9999, 1, 3, 42, 361, '1989-04-01', 'Dedicated to Ann Lindsey and John Lockhart on the occasion of their marriage.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16627, '2015-08-27 13:43:06.713818+00', '2021-02-26 23:03:58.863497+00', 'Return to Paisley', 'RETURN TO PAISLEY', 3, 32, NULL, 2, 3, 17, 2932, NULL, 'Devised by Ellen Ternes for Lilian Mitchell of Paisley on her 60th birthday.', 83, '880/888/888/484', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16640, '2015-08-27 16:42:05.91894+00', '2021-03-27 09:59:00.080396+00', 'Four Leaf Clover, The', 'FOUR LEAF CLOVER', 2, 32, NULL, 1, 3, 42, 10568, '2015-03-01', 'Something easy for the A&P class to help learn corner pass and turn and prepare for Montreal Rendezvous.', 47, '800/804/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16629, '2015-08-27 13:46:36.499768+00', '2021-02-27 09:42:42.216574+00', 'Swirls and Eddies', 'SWIRLS AND EDDIES', 3, 32, NULL, 1, 3, 42, 3703, NULL, '', 47, '880/808/808/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2049, '1997-04-03 22:00:00+00', '2021-04-05 11:14:11.684925+00', 'Fairy Rings', 'FAIRY RINGS', 2, 32, 9999, 1, 3, 42, 352, '1993-04-17', '', 44, '880/800/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16678, '2015-08-29 06:51:59.564786+00', '2018-12-07 18:07:35.695551+00', '"Lady" Paulien''s Fancy', 'LADY PAULIENS FANCY', 1, 88, NULL, 4, 4, 3, 3120, NULL, '', 82, '8080/8080/8888/0808/0808/8888/8888/8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16670, '2015-08-27 18:06:30.763465+00', '2015-08-27 18:06:30.763465+00', 'Walden Puppy', 'WALDEN PUPPY', 3, 32, NULL, 2, 3, NULL, 10568, '2014-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16641, '2015-08-27 16:43:10.53019+00', '2015-12-21 23:00:22.792345+00', 'Frost and Fire', 'FROST AND FIRE', 1, 32, NULL, 2, 3, 17, 10568, '2013-04-01', 'Note: bar 20 - 1M end is 2L''s place.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16669, '2015-08-27 18:05:50.397782+00', '2018-04-03 00:08:20.447161+00', 'Thank You, Fred', 'THANK YOU FRED', 2, 32, NULL, 1, 3, 42, 10568, '2014-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16673, '2015-08-27 19:30:34.932438+00', '2015-08-27 19:30:34.932438+00', 'Promenade on the Brühl Terrace', 'PROMENADE ON THE BRUHL TERRACE', 3, 32, NULL, 1, 4, 1, 11163, '2014-03-01', 'The Brühl Terrace is in Dresden', 62, '8800/8888/8000/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16674, '2015-08-27 20:19:38.131464+00', '2015-08-27 20:19:38.131464+00', 'Gingerbread Man, The', 'GINGERBREAD MAN', 1, 32, NULL, 1, 3, 42, 11164, '2014-07-01', 'Refers to the legend of the Gingerbread Boy in the town of Pulsnitz', 56, '880/848/844/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16675, '2015-08-27 20:29:19.421991+00', '2015-08-27 20:29:19.421991+00', 'Free Mountain Jig', 'FREE MOUNTAIN JIG', 2, 32, NULL, 1, 3, 42, 10961, '2014-06-01', '', 50, '800/888/844/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16677, '2015-08-27 20:47:39.809514+00', '2015-08-27 20:47:39.809514+00', 'Sixty-String Harp, The', 'SIXTYSTRING HARP', 1, 32, NULL, 1, 3, 42, 11164, '2014-11-01', 'For Marilyn Hartley in Chester', 58, '640/844/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16569, '2015-08-26 06:45:48.615459+00', '2015-08-28 06:18:27.747943+00', 'Celebrating 50 Golden Years', 'CELEBRATING 50 GOLDEN YEARS', 2, 32, NULL, 1, 3, 42, 872, '2015-05-01', 'Devised in May 2015  by Marilyn Watson, to celebrate 50 years since Bournemouth became a Branch of the Royal Scottish Country Dance Society on 6th August 1965.', 56, '880/844/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16623, '2015-08-27 11:29:11.89717+00', '2015-08-29 18:51:40.840706+00', 'Advance but no Retire', 'ADVANCE BUT NO RETIRE', 1, 32, NULL, 1, 3, 42, 11164, '2014-03-20', '', 52, '864/888/800/844', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16639, '2015-08-27 16:41:01.328653+00', '2015-12-21 22:46:03.478656+00', 'Fare Thee Well, Peter White', 'FARE THEE WELL PETER WHITE', 1, 32, NULL, 1, 100, 2, 10568, '2013-03-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16679, '2015-08-29 12:36:49.805677+00', '2018-02-05 00:13:54.162866+00', 'Amisfield Dancie, The', 'AMISFIELD DANCIE', 1, 40, 9999, 1, 3, 42, 11183, '2009-01-01', '', 50, '800/844/844/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16642, '2015-08-27 16:44:14.164115+00', '2015-12-21 23:09:00.372217+00', 'Golden Anniversary Jig', 'GOLDEN ANNIVERSARY JIG', 2, 32, NULL, 2, 3, 18, 10568, '2014-04-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16643, '2015-08-27 16:45:07.766909+00', '2015-12-21 23:16:22.999785+00', 'Greta''s Daughter', 'GRETAS DAUGHTER', 1, 48, NULL, 1, 4, 15, 10568, '2013-09-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16648, '2015-08-27 17:44:20.21774+00', '2016-05-12 09:50:53.693571+00', 'jacqui', 'JACQUI', 3, 32, NULL, 4, 54, 1, 10568, '2013-03-01', 'For four people in a diamond shaped set', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16649, '2015-08-27 17:45:29.560337+00', '2015-12-24 16:22:57.90367+00', 'Jacqui 2', 'JACQUI 2', 3, 32, NULL, 4, 4, NULL, 10568, '2014-04-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16650, '2015-08-27 17:47:07.120799+00', '2015-12-24 20:43:04.423503+00', 'Kingston Kindness', 'KINGSTON KINDNESS', 2, 40, NULL, 1, 2, NULL, 10568, '2014-04-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16657, '2015-08-27 17:54:17.651193+00', '2016-07-15 18:15:31.23808+00', 'My Cousin Heather', 'MY COUSIN HEATHER', 3, 32, NULL, 1, 100, 2, 10568, '2014-10-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16683, '2015-08-29 13:14:33.567153+00', '2015-08-29 13:14:33.567153+00', 'Hannah''s Waltz', 'HANNAHS WALTZ', 5, 32, 9999, 5, 109, 30, 11182, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16748, '2015-09-19 17:47:37.424417+00', '2018-04-02 23:56:35.151601+00', 'Highland Park', 'HIGHLAND PARK', 1, 32, 9999, 1, 3, 42, 595, NULL, '8x32 Hornpipe for Three Couples', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16698, '2015-08-31 09:40:12.698891+00', '2018-04-02 23:56:37.0801+00', 'Putting the Cherry on the Cake', 'PUTTING THE CHERRY ON THE CAKE', 3, 32, NULL, 1, 3, 42, 347, '2013-11-01', 'In memory of Ann Dix who would say when teaching, “Putting the Cherry on the Cake”. The dance gives lot of opportunities to cover, a teaching point Ann would stress.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16749, '2015-09-19 17:52:45.827539+00', '2018-04-02 23:56:37.739863+00', 'Springbank', 'SPRINGBANK', 1, 32, 9999, 1, 3, 42, 595, NULL, '8x32 Hornpipe for Three Couples', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16691, '2015-08-29 15:09:44.239352+00', '2015-08-29 15:09:44.239352+00', 'Geometry Class, A', 'GEOMETRY CLASS', 3, 32, 9999, 105, 53, NULL, 11189, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16693, '2015-08-29 15:28:20.707565+00', '2015-08-29 15:28:20.707565+00', 'Sakura', 'SAKURA', 4, 128, 2, 4, 4, 3, 11187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16695, '2015-08-29 15:37:17.784269+00', '2015-08-29 15:37:17.784269+00', 'Maze in the Mirror, A', 'MAZE IN THE MIRROR', 2, 32, 9999, 2, 3, 18, 11187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16688, '2015-08-29 14:26:16.675821+00', '2018-04-02 23:56:38.566022+00', 'White Dragon, The', 'WHITE DRAGON', 2, 32, 9999, 1, 3, 42, 11187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16692, '2015-08-29 15:14:59.604227+00', '2015-08-29 15:55:24.366507+00', 'Masquerade, A', 'MASQUERADE', 3, 32, 9999, 2, 3, 17, 11187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16687, '2015-08-29 14:20:32.736616+00', '2018-04-29 06:28:46.312567+00', 'Happy Tartan (3C/4L version)', 'HAPPY TARTAN 3C/4L VERSION', 1, 32, 9999, 1, 3, 42, 11187, NULL, 'This dance was devised to assist a new lady member of Tartan Club to dance a reel of three without difficulty.', 38, '800/844/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8079, '1997-09-18 22:00:00+00', '2015-08-31 19:29:19.492991+00', 'Tam o'' Shanter', 'TAM O SHANTER', 1, 32, 9999, 1, 3, 42, 929, '1986-01-01', 'Note: This dance was specifically designed for brand new dancers, or situations where

you are asked to provide "audience participation." (PB)', 62, '888/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6449, '1998-01-12 23:00:00+00', '2015-08-31 19:51:06.681751+00', 'Tam o'' Shanter', 'TAM O SHANTER', 2, 32, 9999, 5, 2, NULL, 210, NULL, '', 100, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16694, '2015-08-29 15:32:34.12977+00', '2018-04-28 17:58:13.375082+00', 'Renaissance Dance, A', 'RENAISSANCE DANCE', 3, 32, 9999, 1, 2, 76, 11187, NULL, '', 38, '88/80/80/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16690, '2015-08-29 14:58:23.549535+00', '2019-04-20 08:47:11.730715+00', 'Chasing an Elf', 'CHASING AN ELF', 2, 40, 9999, 2, 2, 76, 11187, NULL, '', 40, '80/44/88/80/80', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18547, '2018-08-28 20:15:32.44032+00', '2018-09-23 21:47:53.353367+00', 'Falls of Dochart, The', 'FALLS OF DOCHART', 1, 32, NULL, 2, 3, 17, 3481, NULL, 'The Falls of Dochart are in the beautiful Perthshire village of Killin. The deviser came across them unexpectedly last summer and felt they deserved a dance named after them. The first figure represents the movement of the falls.', 46, '840/880/880/808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16713, '2015-09-03 13:53:18.78443+00', '2015-11-03 13:48:35.493896+00', 'Roeder Rant, The', 'ROEDER RANT', 1, 32, 9999, 4, 55, 21, 10995, '2007-01-01', 'music "Earlston Loch" by Jim McLeod', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16714, '2015-09-03 14:00:26.989886+00', '2015-11-03 13:48:35.527177+00', 'Echoes of Baudy', 'ECHOES OF BAUDY', 1, 32, 9999, 4, 55, 35, 10995, '2007-01-01', 'music "Water of Dryfe" by Colin Dewar', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16712, '2015-09-03 13:46:08.511014+00', '2015-11-03 13:48:35.485485+00', 'Reel of the Emperor''s Egg', 'REEL OF THE EMPERORS EGG', 1, 32, 9999, 4, 55, 38, 10995, '2007-01-01', 'music "Sailor" by Jim McLeod', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16696, '2015-08-29 15:41:56.963264+00', '2022-04-28 09:09:09.834114+00', 'El Toreador', 'TOREADOR', 3, 32, 9999, 2, 2, 76, 11187, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16654, '2015-08-27 17:51:07.849227+00', '2021-03-11 09:06:22.187104+00', 'Montreal Australian Lady, The', 'MONTREAL AUSTRALIAN LADY', 2, 40, NULL, 1, 4, 2, 10568, '2013-05-01', 'I wrote this for Kachina Allen, who has confirmed my suspicion that Australians are all crazy and a lot of fun!', 85, '8008/8448/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6394, '1998-04-14 22:00:00+00', '2021-06-06 19:25:22.685644+00', 'Sunnyside, The', 'SUNNYSIDE', 2, 32, 9999, 1, 3, 42, 108, '1989-01-01', 'For David Eastwood who lived, for a few years, at Sunnyside, Newmachar. "To say thank you for all his help with my dances."', 63, '880/888/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16619, '2015-08-27 10:26:32.758842+00', '2021-08-10 20:35:08.365993+00', 'Loch Snizort Beag', 'LOCH SNIZORT BEAG', 3, 32, NULL, 1, 4, 1, 10961, '2013-01-01', 'Lord Snizort Beag is a sea loch in the NW of the Isle of Skye.', 73, '8000/8888/8446/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16671, '2015-08-27 18:07:24.436282+00', '2021-11-23 01:23:59.488073+00', 'While We Were Waiting', 'WHILE WE WERE WAITING', 1, 32, NULL, 6, 53, 18, 10568, '2012-10-01', '', 100, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16684, '2015-08-29 13:20:41.843728+00', '2019-01-22 13:18:00.059023+00', 'Miss Graham of Dykeside', 'MISS GRAHAM OF DYKESIDE', 3, 32, 9999, 1, 3, 42, 11182, NULL, 'For my wife Linda and the place we call home.', 69, '826/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16725, '2015-09-03 20:37:51.548815+00', '2019-02-25 23:52:51.124872+00', 'Tullynessle and Forbes Hall', 'TULLYNESSLE AND FORBES HALL', 3, 32, NULL, 2, 3, 17, 11194, '2008-01-01', 'Tullynessle and Forbes Hall was refurbished and was reopened by Prince Edward on November 16th 2008', 81, '886/880/808/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1038, '1997-04-03 22:00:00+00', '2019-06-30 13:45:43.025637+00', 'Carlin''s Cairn', 'CARLINS CAIRN', 2, 32, 9999, 1, 3, 42, 13, NULL, 'Carlin''s Cairn is the second highest of the four hills which comprise the Rhinns of Kells in Galloway.', 62, '888/800/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1537, '1998-09-17 22:00:00+00', '2018-01-27 14:59:07.838501+00', 'Dancing Dolphins', 'DANCING DOLPHINS', 2, 32, 9999, 1, 3, 42, 352, NULL, 'Only the animation video shows the reel correctly - the dancer videos do not! The "tandem" dancers should stay PARALLEL to the side lines/center axis of the set. That is:- When they cut the center of the reel they should be side by side as they cross the side line, not one following the other.', 37, '800  844  844  800', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (14246, '2011-09-02 22:00:00+00', '2015-09-05 21:15:38.169889+00', 'Argyll''s Fantasy', 'ARGYLLS FANTASY', 2, 48, NULL, 3, 5, 16, 10478, NULL, 'The author, Wil van den Berg, has withdrawn this dance; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14405, '2012-03-04 20:38:06.230765+00', '2015-09-05 21:17:09.59585+00', 'David''s Double Trouble', 'DAVIDS DOUBLE TROUBLE', 1, 32, NULL, 3, 5, 7, 10607, '2008-05-01', 'The dance was inspired by the music written for David by Philippe Kocian. The dance was named at an informal gathering of dancers in Ardèche, May 2008

', 70, '84840  88888  84884  80800', 1, 1, 1, 0, 70);
INSERT INTO 'dance' VALUES (16819, '2015-11-06 11:13:02.927528+00', '2016-05-25 21:37:42.712905+00', 'Up and Doon the Doldenhorn', 'UP AND DOON THE DOLDENHORN', 2, 32, NULL, 107, 3, NULL, 2419, NULL, 'Start in "Ruthven Formation": 1c face 3c on midline, 1c is on opposite side; 2c in 2pl.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16685, '2015-08-29 13:34:03.034753+00', '2017-03-03 21:33:50.079561+00', 'P.I.P.', 'PIP', 2, 32, 9999, 1, 3, 42, 11182, NULL, '', 67, '888/886/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16727, '2015-09-03 20:58:06.073277+00', '2017-05-31 12:57:58.962292+00', 'Librarian''s Daughter, The', 'LIBRARIANS DAUGHTER', 3, 40, NULL, 1, 4, 1, 11196, '2011-01-01', 'Devised for Alexa Conacher whose father was County Librarian for Banffshire', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16702, '2015-09-03 12:29:45.150994+00', '2018-04-26 22:29:41.698946+00', 'Light as Thistledown', 'LIGHT AS THISTLEDOWN', 2, 32, 9999, 4, 55, 41, 10995, '2007-01-01', 'music "Ship in Full Sail" by Nicol McLaren', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7282, '2001-11-21 23:00:00+00', '2015-09-02 12:28:23.66329+00', 'Swiss Lassie', 'SWISS LASSIE', 1, 32, 9999, 1, 3, 42, 38, NULL, 'In memory of Judith Binder





The following corrections were included on a loose sheet "Notes on Dances by Bob Grant June 1996", when Book 39 was first sold in the Summer School bookshop:



9-16  2nd man & 1st woman need to be beginning to dance out at end of reel



17-20  2nd woman and 1st man should dance to end of reel before following partners', 50, '840  880  884  484', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (17129, '2016-07-04 19:45:02.465403+00', '2018-04-30 15:34:38.858107+00', 'Lochranza Ferry, The', 'LOCHRANZA FERRY', 3, 32, NULL, 1, 4, 1, 10578, NULL, 'Narrative:  

1 – 8: Cars arrive in turn at the terminal at Lochranza  

9 – 16: Cars load up on the ferry to Claonaig  

17 – 24: Waves and slightly choppy sea crossing the Kilbrannan Sound  

25 – 32: Ferry ties up and cars roll off at Claonaig.', 84, '8642/8888/8888/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16701, '2015-09-03 12:21:08.225073+00', '2015-11-03 13:48:35.220121+00', 'Muckle Beck', 'MUCKLE BECK', 2, 40, 9999, 4, 55, 37, 10995, '2007-01-01', 'music "Muckle Burn" by R Whitehead', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12768, '2006-05-21 22:00:00+00', '2018-08-21 06:23:42.61387+00', 'Luke Brady''s Magical Music', 'LUKE BRADYS MAGICAL MUSIC', 1, 32, 9999, 1, 3, 42, 3682, NULL, 'For Luke Brady, who got me into this in the first place! I have to admit. working on this book was good fun and I can now say I''ve met someone younger than me that likes Scottish dance music as much as l do.  And we''ve even made a dancer out of him!  

Thanks to Bruce Wallace for writing the tune for this dance. it made Luke''s day.', 56, '888/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16290, '2015-05-06 22:48:09.951013+00', '2018-10-01 11:04:30.400134+00', 'Alaina''s Bus Stop Jig', 'ALAINAS BUS STOP JIG', 2, 32, NULL, 1, 2, 76, 2766, '2010-06-01', '', 44, '800/800/866/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18793, '2018-10-05 14:43:35.937552+00', '2018-10-05 14:43:35.937552+00', 'Interlocking Wheels', 'INTERLOCKING WHEELS', 1, 32, NULL, 1, 3, NULL, 2766, '2016-07-01', 'I like the flow of this dance and it reminds me of interlocking wheels.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5696, '1998-04-19 22:00:00+00', '2015-09-03 14:51:04.475597+00', 'Rossington Strathspey, The', 'ROSSINGTON STRATHSPEY', 3, 32, 9999, 6, 3, 18, 1140, '1990-01-01', 'This dance was devised for, and dedicated to, Mrs. Ethel Mary Moss, mother of John Moss who was an honorary member of the Moncton Scottish Country Dance Group. It was presented and first danced at the celebration of her ninety-seventh birthday at The Auld Farm, Cap Pele, New Brunswick, Canada on October 13, 1990.



Rossington Strathspey was published in ‘Island Games’ to commemorate the 1991 Canada Winter Games playing in Charlottetown, PEI that year. It was published that same year.', 87, '888/888/444/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16703, '2015-09-03 12:38:05.557399+00', '2015-11-03 13:48:35.301831+00', 'Supping Honey', 'SUPPING HONEY', 2, 32, 9999, 4, 55, 57, 10995, '2007-01-01', 'music "Inchmickery" by Keith Smith & Muriel Johnstone', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16704, '2015-09-03 12:44:17.515026+00', '2015-11-03 13:48:35.394496+00', 'Fiona''s Fancy', 'FIONAS FANCY', 2, 32, 9999, 4, 55, 21, 10995, '2007-01-01', 'music "Miller of Sesnie" by Muriel Johnstone''s Band', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16705, '2015-09-03 12:52:22.110377+00', '2015-11-03 13:48:35.427595+00', 'Pandora''s Box', 'PANDORAS BOX', 2, 32, 9999, 4, 55, 35, 10995, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16707, '2015-09-03 13:01:50.802456+00', '2015-11-03 13:48:35.435956+00', 'Mayfly, The', 'MAYFLY', 2, 32, 9999, 4, 55, 38, 10995, '2007-01-01', 'music "Lady in Red" by Marian Anderson', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16708, '2015-09-03 13:11:06.039087+00', '2015-11-03 13:48:35.444267+00', 'Blue Bell-bottoms', 'BLUE BELLBOTTOMS', 2, 32, 9999, 4, 55, 21, 10995, '2007-01-01', 'music "Celtic Crossing" by Nicol McLaren', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16710, '2015-09-03 13:19:03.348359+00', '2015-11-03 13:48:35.452614+00', 'Reel for Five Dancers', 'REEL FOR FIVE DANCERS', 2, 40, 9999, 4, 55, 6, 10995, '2007-01-01', 'music "Wee Cooper of Fife" by D Cunningham', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16711, '2015-09-03 13:35:53.531788+00', '2015-11-03 13:48:35.477181+00', 'Groombridge Waiter, The', 'GROOMBRIDGE WAITER', 1, 32, 9999, 4, 55, 35, 10995, '2007-01-01', 'music "Folksy Fivesome" by R Whitehead', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12450, '2005-06-05 22:00:00+00', '2022-05-18 09:38:56.931015+00', 'Terrace Loggers'' Jig', 'TERRACE LOGGERS JIG', 2, 32, 9999, 1, 4, 1, 2888, NULL, 'There is a 24-bar variant of this dance, bars [25-32] being omitted.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16726, '2015-09-03 20:44:51.288189+00', '2022-08-14 21:28:03.576023+00', 'Jollity', 'JOLLITY', 2, 32, NULL, 1, 4, 22, 11195, '2014-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16697, '2015-08-29 15:50:34.583725+00', '2021-01-05 15:31:29.154231+00', 'Happy Tartan (5C version)', 'HAPPY TARTAN 5C VERSION', 1, 32, 9999, 3, 5, 7, 11187, NULL, '', 60, '80800/84884/84884/80800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16717, '2015-09-03 14:43:47.090811+00', '2015-11-03 13:48:35.726864+00', 'Strathspey Sandwich, The', 'STRATHSPEY SANDWICH', 4, 120, 15, 4, 55, 38, 10995, '2007-01-01', 'Reel/Strathspey/Reel  music "One of a Kind" by Marian Anderson



Medleys are always a problem as suitable music is hard to find.

This dance was inspired by Marian''s music so fits exactly!

Of course it can be also danced as a straight Reel or Strathspey

 ... ...

but be warned, 5 times as a reel will test stamina!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16719, '2015-09-03 15:04:01.349703+00', '2015-11-03 13:48:35.802365+00', 'Memories of Marian', 'MEMORIES OF MARIAN', 3, 40, 9999, 4, 55, 35, 10995, '2007-01-01', 'music "Avon Valley Strathspey" by Marian Anderson', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16720, '2015-09-03 15:15:15.898268+00', '2015-11-03 13:48:35.810692+00', 'High Five', 'HIGH FIVE', 3, 32, 9999, 4, 55, 38, 10995, '2007-01-01', 'music "GGS1" by Green Ginger', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16721, '2015-09-03 15:24:59.080342+00', '2015-11-03 13:48:35.819021+00', 'Fleur de Lise', 'FLEUR DE LISE', 3, 32, 9999, 4, 55, 55, 10995, '2007-01-01', 'music "Miss Catherine Anne" by Scottish Measure



This dance requires a flowing SSpey.. The really great music suggested is absolutely

ideal but repeats just 3 times so not everyone will dance all positions.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16722, '2015-09-03 15:32:57.63825+00', '2015-11-03 13:48:35.827362+00', 'Lucy Serena''s Strathspey', 'LUCY SERENAS STRATHSPEY', 3, 32, 9999, 4, 55, 57, 10995, '2007-01-01', 'music "Strathspey 1" by Green Ginger', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16723, '2015-09-03 15:41:19.415724+00', '2015-11-03 13:48:35.835774+00', 'Land of Dreams, The', 'LAND OF DREAMS', 3, 32, 9999, 4, 55, 38, 10995, '2007-01-01', 'music "Susana''s Strathspey" by Keith Smith/Muriel Johnstone', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16709, '2015-09-03 13:15:03.600172+00', '2015-11-09 14:46:22.599585+00', 'John Gibson''s Jig', 'JOHN GIBSONS JIG', 2, 32, NULL, 1, 3, 42, 3517, '2011-01-01', '', 44, '800/888/800/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16718, '2015-09-03 14:56:46.050479+00', '2018-02-18 02:42:33.48079+00', 'Bayham Abbey', 'BAYHAM ABBEY', 3, 32, 9999, 4, 55, 30, 10995, '2007-01-01', 'The original instructions, both text and diagrams, clearly specify the progression as (25431).  That must be in error: 3c and 4c just switch places, and never get a turn in the centre.  The progression has therefore been classified as "other". 



It would be easy to restore a god progression by moving the starting direction one place clw or cclw each time through. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16706, '2015-09-03 12:59:29.978812+00', '2017-03-18 21:41:14.972886+00', 'Mrs McGinley''s Strathspey', 'MRS MACGINLEYS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11193, '2012-11-16', 'To celebrate the Wedding of Helen Beaney and Jack McGinley on 16th November 2012.', 50, '880/808/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16747, '2015-09-19 17:42:49.891719+00', '2018-04-02 23:56:35.99488+00', 'MacAllan, The', 'MACALLAN', 1, 32, 9999, 1, 3, 42, 595, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14419, '2012-03-25 22:06:40.787059+00', '2015-09-05 21:18:20.460354+00', 'Irene Bennett''s Strathspey', 'IRENE BENNETTS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 99, NULL, '

', 62, '800  888  844  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (16731, '2015-09-07 00:17:22.692929+00', '2018-04-03 00:07:43.043027+00', 'Driving Through Eutaw', 'DRIVING THROUGH EUTAW', 2, 32, NULL, 1, 3, 42, 11200, '2013-02-01', 'The music used in the video is "Ye Banks and Braes" - Marian Anderson -  CD of Robert Burns music.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15826, '2015-01-18 12:58:59.663546+00', '2018-05-01 01:21:21.357033+00', 'Compliment Returned, A', 'COMPLIMENT RETURNED', 1, 32, 9999, 1, 3, 42, 1582, '2009-07-01', 'Devised for Jim Rae, July 2009.  Since Jim is often writing dances for other people, here is one for him.', 64, '888/842/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10339, '2002-02-12 23:00:00+00', '2015-09-08 22:08:29.100718+00', 'Sound of Iona, The', 'SOUND OF IONA', 4, 64, 5, 5, 56, 30, 2664, NULL, '', 83, '888/484/484/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15825, '2015-01-18 12:45:14.199178+00', '2018-05-01 00:59:28.636132+00', 'Budapest May Moon, The', 'BUDAPEST MAY MOON', 2, 32, 9999, 1, 4, 1, 1582, '2007-05-01', 'Devised on the coach journey from a ranch in Domony Valley outside Budapest, when the moon seemed to travel all the way round us!', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17067, '2016-06-26 14:17:24.647106+00', '2018-09-08 21:51:44.059762+00', 'Dronten Reel, The', 'DRONTEN REEL', 1, 32, NULL, 5, 109, 76, 10478, '1994-11-28', '', 87, '88/88/44/88', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15846, '2015-01-18 16:01:11.605839+00', '2018-05-01 21:07:44.690513+00', 'Stuck in the Broomielaw', 'STUCK IN THE BROOMIELAW', 3, 32, 9999, 1, 3, 42, 1582, '2008-01-01', '', 63, '880/800/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15140, '2013-09-20 16:52:06.85224+00', '2015-09-08 21:53:40.964489+00', 'Miss Baker''s Welcome', 'MISS BAKERS WELCOME', 3, 40, 9999, 1, 4, 1, 3453, NULL, 'Devised: 2001', 80, '8888/8888/8008/8044/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18798, '2018-10-05 15:08:27.436096+00', '2018-10-05 15:08:27.436096+00', 'Jig and a Hollar, A', 'JIG AND A HOLLAR', 2, 32, NULL, 1, 3, 42, 2766, '2007-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18800, '2018-10-05 15:19:16.289191+00', '2018-10-05 15:19:16.289191+00', 'Just a Little Rant', 'JUST A LITTLE RANT', 1, 32, NULL, 1, 3, 42, 2766, '2013-08-01', 'This dance was written after a very bad day at work.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18802, '2018-10-05 15:51:07.668026+00', '2018-10-05 15:51:07.668026+00', 'Kilt Flip', 'KILT FLIP', 1, 32, NULL, 1, 3, 42, 2766, '2009-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15492, '2014-06-27 21:01:08.870443+00', '2019-01-22 23:21:40.519826+00', 'Sussy''s Wedding', 'SUSSYS WEDDING', 3, 32, NULL, 2, 2, 76, 10971, NULL, 'For "Sussy," on her wedding day.', -1, '88/88/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16716, '2015-09-03 14:14:16.128096+00', '2020-02-14 17:43:38.408866+00', 'Henneker Reel, The', 'HENNEKER REEL', 1, 32, 9999, 4, 55, 48, 10995, '2007-01-01', 'music "Miss Johnstone of Ardrossan" by Colin Dewar



This dance started as a Strathspey to give more time with unfamiliar orientations. 

It is better as a reel, and the specified music helps by not being too fast!', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1977, '1997-04-03 22:00:00+00', '2020-08-30 09:42:51.593933+00', 'Emmie''s Delight', 'EMMIES DELIGHT', 2, 32, 9999, 1, 3, 42, 377, NULL, 'Written for Emmie Warrior who was the teacher of the Ruislip District Caledonian Society class.', 53, '862/826/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16700, '2015-09-03 11:25:21.592773+00', '2020-10-15 21:57:04.056717+00', 'Dublin''s Delights', 'DUBLINS DELIGHTS', 2, 48, 9999, 4, 4, 13, 10595, '2013-09-27', '', 81, '8484/4848/8080/8888/7777/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6066, '1997-10-27 23:00:00+00', '2020-10-13 18:52:49.986754+00', 'Sidlaw Hills (Whetherly 12)', 'SIDLAW HILLS WHETHERLY 12', 3, 32, 9999, 1, 102, 2, 270, '1983-01-01', 'As Mitchell has published two 4-couple 32-bar strathspeys with the name "Sidlaw Hills" (in Whetherly Books 7 and 12), a note has been appended to each name to reduce the confusion.', 73, '8008/8778/8448/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2084, '1998-09-29 22:00:00+00', '2020-12-06 11:13:37.175727+00', 'Farewell To Crumlin', 'FAREWELL TO CRUMLIN', 2, 32, 9999, 1, 4, 1, 492, '1982-01-01', '''Crumlin'' was until 1980 the Clackmannan home of SCD teacher Doris Forster', 91, '8844/8888/8888/6868', 1, 1, 1, 1, 90);
INSERT INTO 'dance' VALUES (5575, '1998-01-12 23:00:00+00', '2021-01-23 23:38:35.717344+00', 'Rifleman, The', 'RIFLEMAN', 1, 32, 9999, 1, 4, 53, 210, NULL, '<<scddb-not-identical:5574>>



This dance is a North Country dance adapted for Scottish Country dancing. One long set, men with partners on their right hand side facing another couple across the set as on the 2nd chord of the Glasgow Highlanders.', 100, '8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18799, '2018-10-05 15:14:10.537552+00', '2021-01-20 03:01:07.279359+00', 'John Barleycorn', 'JOHN BARLEYCORN', 1, 32, NULL, 1, 3, 42, 2766, '2008-11-01', '', 47, '844/800/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5823, '1997-09-14 22:00:00+00', '2021-05-11 10:23:20.483332+00', 'Sidlaw Hills (Whetherly 7)', 'SIDLAW HILLS WHETHERLY 7', 3, 32, 9999, 1, 4, 1, 270, NULL, 'As Mitchell has published two 4-couple 32-bar strathspeys with the name "Sidlaw Hills" (in Whetherly Books 7 and 12), a note has been appended to each name to reduce the confusion.



The 2021 edition has revised bars 25-32.', 81, '8888/8888/8888/8000', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16732, '2015-09-07 16:18:08.283602+00', '2022-12-19 11:30:03.839339+00', 'Rerr Terr Jig', 'RERR TERR JIG', 2, 40, NULL, 1, 3, 42, 2723, NULL, '', 47, '440/880/880/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16986, '2016-06-07 17:02:06.301448+00', '2016-06-07 17:02:06.301448+00', 'Salute to Candidates, A', 'SALUTE TO CANDIDATES', 3, 32, 9999, 1, 3, 42, 2723, '2014-11-01', '', 65, '820 880 844 866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17058, '2016-06-23 22:44:47.044829+00', '2016-06-23 23:11:22.13245+00', 'Traprain Law Reel, The', 'TRAPRAIN LAW REEL', 1, 32, NULL, 1, 3, 42, 525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9711, '2000-11-13 23:00:00+00', '2017-12-13 18:05:27.34468+00', 'Amazing Grace', 'AMAZING GRACE', 3, 32, 9999, 107, 8, 1, 2821, '1997-01-01', 'Dance for two adjacent 4C sets.



Progression: each set has progression (2341), and each time through the sets swap places.  Danced 4 times through.



Devised to exploit the linkage between sets at a Dancing party, and dedicated, with affection, to our teacher at the Pinelands Caledonian S.C. Dancers, Grace Lofthouse', 69, '8844/8844/8888/8000', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16893, '2016-03-05 15:29:08.013028+00', '2016-12-05 05:53:17.094258+00', 'Curia Strathspey', 'CURIA STRATHSPEY', 3, 32, NULL, 1, 4, 2, 11225, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15504, '2014-06-27 21:08:32.621331+00', '2019-01-23 00:14:54.988843+00', 'Snowbirds'' Strathspey', 'SNOWBIRDS STRATHSPEY', 3, 40, NULL, 1, 4, 1, 10971, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15515, '2014-06-27 21:15:27.479985+00', '2019-01-24 10:31:08.927943+00', 'Derek''s Dance', 'DEREKS DANCE', 1, 40, NULL, 1, 3, 42, 10971, NULL, 'Inscribed to Derek Carroll.

', 45, '800/800/822/866/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15128, '2013-09-18 08:21:06.937336+00', '2015-09-09 22:47:48.454999+00', 'Three Score and Ten', 'THREE SCORE AND TEN', 3, 32, NULL, 1, 4, 2, 10321, NULL, '"A celebration of Torf''s 70th birthday and his favorite SCD formations"



Published in the Houston & District 30th Anniversary Collection [p14-15] with "Harriman, Sarah & Torf" as authors.



The text published in "Fun''raising Scottish Country Dances" on p12-13 is the same dance; but only Sarah Harriman is named as author.', 94, '8888  8448  8888  8888', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (16744, '2015-09-19 17:25:20.439554+00', '2018-04-03 00:18:02.246357+00', 'Lagavulin', 'LAGAVULIN', 3, 32, 9999, 2, 2, 76, 595, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14604, '2012-12-09 21:15:14.6605+00', '2015-09-12 12:59:14.370538+00', 'Reverend Ron Lewis, The', 'REVEREND RON LEWIS', 1, 40, NULL, 1, 3, 42, 10454, NULL, 'Received from the RSCDS Cheshire Branch''s New Year Ball 2013, via Andrew Locke.



The dance has only been published as a Manuscript (Typewritten) sheet.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16743, '2015-09-19 17:20:47.750065+00', '2018-04-02 23:56:33.615063+00', 'Cragganmore', 'CRAGGANMORE', 3, 32, 9999, 1, 3, 42, 595, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16735, '2015-09-14 21:57:12.033994+00', '2015-10-11 22:44:01.057636+00', 'Bavarian Nights', 'BAVARIAN NIGHTS', 1, 32, NULL, 1, 3, 42, 3645, '2015-01-01', 'Source: Eindhoven Matinee Cribs 17 oct 2015', 50, '844/844/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15842, '2015-01-18 15:28:10.728582+00', '2018-05-02 06:59:03.554126+00', 'Red House Square', 'RED HOUSE SQUARE', 2, 32, 9999, 4, 4, 4, 1582, '1996-01-01', 'Written for the children’s club at Red House School, Norton, Tees-side but useful as a warm up dance using walking step throughout.', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10309, '2002-01-08 23:00:00+00', '2015-09-18 19:53:46.993592+00', 'Claire Campbell', 'CLAIRE CAMPBELL', 3, 32, 9999, 1, 3, 42, 534, NULL, 'For a lassie I may first have set eyes on some years ago at a Southport Festival although she was in a junior team and we were probably up in the bar preparing for our own demonstration in the usual way. Happily reclaimed for the dancing world via the dentist’s chair.



', 56, '800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9980, '2001-10-23 22:00:00+00', '2015-09-18 20:28:41.518647+00', 'Eastern Promise', 'EASTERN PROMISE', 3, 32, 9999, 1, 4, 2, 108, '2000-01-01', 'Author''s NOTE:: Fry''s chocolate-coated Turkish Delight is advertised as being "Full of Eastern Promise".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16739, '2015-09-19 16:59:07.791553+00', '2018-04-02 23:56:34.900873+00', 'Glenkinchie', 'GLENKINCHIE', 2, 32, 9999, 1, 3, 42, 595, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16741, '2015-09-19 17:12:10.282335+00', '2018-04-02 23:56:37.430708+00', 'Royal Lochnagar', 'ROYAL LOCHNAGAR', 2, 40, 9999, 1, 3, 42, 595, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16746, '2015-09-19 17:37:16.725721+00', '2018-04-02 23:56:37.965243+00', 'Talisker', 'TALISKER', 1, 32, 9999, 1, 3, 42, 595, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2769, '1997-08-28 22:00:00+00', '2015-09-21 06:19:24.802227+00', 'Happy Couple, The', 'HAPPY COUPLE', 4, 64, 9999, 1, 4, NULL, 377, NULL, 'Devised for Mike and Anita''s wedding 1983-10-29.



See the original text for details and possible variants.', 87, '8888/6666/6666/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16758, '2015-09-20 16:00:39.207817+00', '2016-01-05 01:56:50.888862+00', 'I Mind Hid Fine', 'I MIND HID FINE', 4, 32, 5, 1, 3, 42, 11207, NULL, 'Each couple dance 32 bars in strathspey time and repeat in reel time



The dance is dedicated to friendships made through Scottish country dancing.  

"I mind hid fine" is Orcadian for "I remember it well."

', 46, '800/833/833/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13362, '2009-08-02 22:00:00+00', '2016-04-18 07:13:33.402216+00', 'Montréal Anniversary Jig', 'MONTREAL ANNIVERSARY JIG', 2, 32, NULL, 1, 100, 2, 10568, NULL, 'Written to celebrate the RSCDS Montréal Branch 50th anniversary.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16760, '2015-09-20 16:47:59.539982+00', '2016-06-15 10:50:43.428128+00', 'Vancouver Cherry Blossoms', 'VANCOUVER CHERRY BLOSSOMS', 3, 96, 9999, 102, 5, 3, 11208, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17069, '2016-06-26 14:30:54.836609+00', '2016-06-26 14:31:11.788049+00', 'NVS-Jubilaris', 'NVSJUBILARIS', 3, 32, NULL, 7, 1, NULL, 2110, '2001-03-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17074, '2016-06-26 15:10:34.354239+00', '2020-10-19 09:49:21.704787+00', 'Dab of Gold', 'DAB OF GOLD', 1, 32, NULL, 1, 3, 42, 2887, NULL, '', 50, '822/804/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2979, '2003-01-30 23:00:00+00', '2021-05-27 21:32:14.539471+00', 'Hooper''s Jig', 'HOOPERS JIG', 2, 32, 9999, 1, 3, 42, 9998, NULL, '##>>

This cannot be attributed to a specific person.  

Some sources suggest ‘hooper’ is merely an old form of ‘cooper’, a barrel maker, while others suggest that it was the specialist function of making and fitting the metal hoops on barrels as opposed to the making of the wooden staves.

##<<', 41, '804  840  706 880', 1, 1, 1, 1, 55);
INSERT INTO 'dance' VALUES (16742, '2015-09-19 17:16:41.740749+00', '2022-04-28 09:08:06.684523+00', 'Clynelish', 'CLYNELISH', 3, 32, 9999, 1, 3, 42, 595, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16737, '2015-09-16 12:08:24.852603+00', '2022-06-10 22:15:59.332656+00', 'Jubilee', 'JUBILEE', 1, 32, NULL, 1, 3, 42, 411, '2007-01-01', 'Devised after attending the 50th anniversary Labour Weekend School. Remembering the Auckland Region 50th anniversary.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4641, '2002-08-29 22:00:00+00', '2017-07-07 12:51:02.536026+00', 'Montgomeries'' Rant, The', 'MONTGOMERIES RANT', 1, 32, 9999, 1, 3, 42, 339, '1749-01-01', '##>>

The source of this dance, *The Menzies Manuscript*, is part of the Atholl Collection. In the manuscript, the name of the dance is unequivocally The Montgomerie’s Rant ie referring to the Head of the Montgomerie family. Why the change was made is unknown.



In 1749, the date of the manuscript, Alexander Montgomerie had been 10th Earl of Eglinton for twenty years. He was prominent in London Society and a close friend of James Boswell, Samuel Johnson’s literary assistant. His main claim to fame is that he was shot to death on his estate by an exciseman claiming the right to carry arms on the estate, effectively claiming a right to hunt, or poach, depending on your point of view.

##<<



', 50, '800  888  822  866', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (10038, '2001-09-02 22:00:00+00', '2015-09-19 22:16:04.402435+00', 'Scotland''s Road of Romance', 'SCOTLANDS ROAD OF ROMANCE', 3, 32, 9999, 1, 3, 42, 9, NULL, '''Scotlands Road of Romance'' is the title of a book written by Augustus Muir describing the flight of Bonnie Prince Charlie to France after the battle of Culloden. The route took the Pretender through Doune and many of the places of refuge identified by the author I have used as titles for some of the dances in the Doune -Collections Vols. 1 & 2.  Muir''s book, published in the 1930''s is unfortunately now out of print.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18312, '2018-05-02 18:04:37.103158+00', '2018-05-02 18:04:54.211791+00', 'Balmoral Celebration', 'BALMORAL CELEBRATION', 1, 48, NULL, 3, 5, NULL, 11139, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16755, '2015-09-20 15:24:22.765733+00', '2015-09-20 15:24:22.765733+00', 'Deep Cove Strathspey, A', 'DEEP COVE STRATHSPEY', 3, 32, 9999, 2, 3, 17, 11205, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16757, '2015-09-20 15:49:22.659862+00', '2015-09-20 15:49:22.659862+00', 'Paisley Girl, The', 'PAISLEY GIRL', 3, 40, 9999, 1, 4, 11, 955, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16751, '2015-09-20 14:50:52.263425+00', '2018-04-02 23:56:37.898572+00', 'Sunny Sunday, A', 'SUNNY SUNDAY', 1, 32, 9999, 1, 3, 42, 11203, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16759, '2015-09-20 16:29:01.848869+00', '2015-09-20 16:29:01.848869+00', 'It''s an "L" of a 50', 'ITS AN L OF A 50', 1, 48, 9999, 3, 5, 7, 3572, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16753, '2015-09-20 15:06:54.869042+00', '2015-09-20 17:05:26.862536+00', 'Tribute to Mary', 'TRIBUTE TO MARY', 3, 32, 9999, 4, 4, 1, 1727, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2182, '1997-04-03 22:00:00+00', '2015-09-21 06:33:43.022411+00', 'Fiona''s Medley', 'FIONAS MEDLEY', 4, 80, 9999, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3247, '1998-07-08 22:00:00+00', '2015-09-21 06:38:35.860179+00', 'Jessie''s Strathspey', 'JESSIES STRATHSPEY', 3, 32, 9999, 1, 4, 2, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16738, '2015-09-16 21:45:10.764799+00', '2019-01-30 11:38:31.081759+00', 'Captain George Vancouver', 'CAPTAIN GEORGE VANCOUVER', 2, 32, NULL, 1, 100, 2, 1089, NULL, '', 87, '8888/8888/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16772, '2015-09-27 20:37:02.998541+00', '2015-09-27 20:41:36.500808+00', 'Macdonald of the Oceans', 'MACDONALD OF THE OCEANS', 3, 32, NULL, 3, 5, 31, 2973, '2006-08-01', 'Adapted from Macdonald of the Isles by Derek Haynes, August 2006.  ', 67, '48884/48884/86420/44088', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18313, '2018-05-02 18:07:01.597156+00', '2018-05-02 18:07:01.597156+00', 'Chocks Away', 'CHOCKS AWAY', 3, 96, NULL, 4, 4, NULL, 11139, '2010-03-22', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18314, '2018-05-02 18:08:06.344302+00', '2018-05-02 18:08:06.344302+00', 'Experts, The', 'EXPERTS', 1, 40, NULL, 1, 4, NULL, 11139, '2012-10-04', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16897, '2016-03-06 10:22:06.048027+00', '2018-04-03 00:07:55.495091+00', 'Jig for Joan, A', 'JIG FOR JOAN', 2, 32, NULL, 1, 3, 42, 11239, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6143, '1997-09-14 22:00:00+00', '2019-03-10 15:37:04.495457+00', 'Skylark''s Reel, The', 'SKYLARKS REEL', 1, 32, 9999, 2, 104, 17, 48, NULL, '', 92, '888/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12845, '2006-09-12 22:00:00+00', '2015-09-28 19:41:58.661839+00', 'Asilomar Frantic', 'ASILOMAR FRANTIC', 2, 32, 9999, 1, 2, NULL, 2961, '2005-10-29', 'Note: Devised on the spot in less than 10 minutes at 2005 Asilomar Workshop. My original plan required more dancers than I had. So, it would seem that need is the mother of invention', 60, '88/88/80/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17988, '2017-09-26 22:58:38.838911+00', '2019-09-06 21:51:36.051954+00', 'Old New Year', 'OLD NEW YEAR', 3, 32, 9999, 1, 4, 2, 11528, NULL, '', 78, '8448/8888/4224/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16762, '2015-09-22 18:50:53.016457+00', '2020-10-16 22:04:45.940559+00', 'Monica''s Return', 'MONICAS RETURN', 2, 32, NULL, 5, 2, 76, 11210, NULL, 'Source: A Portland (OR) Ball program.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16763, '2015-09-22 18:59:17.056908+00', '2020-10-16 22:09:41.947079+00', 'Discounted Suit, The', 'DISCOUNTED SUIT', 1, 32, NULL, 1, 3, 42, 10909, NULL, 'Source: A Portland (OR) Ball program.



Note: This is a variant of The De’il Amang the Tailors.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16767, '2015-09-22 19:28:36.086942+00', '2020-10-16 22:17:06.907247+00', 'Unstoppable Kate', 'UNSTOPPABLE KATE', 1, 32, NULL, 1, 3, 42, 3110, NULL, 'Source: A Portland (OR) Ball program.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16768, '2015-09-22 20:33:16.47979+00', '2020-10-16 22:22:35.753505+00', 'Wither turns the Wedderburn', 'WITHER TURNS THE WEDDERBURN', 1, 32, NULL, 1, 3, 42, 11211, NULL, '', 41, '800/822/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17974, '2017-09-25 20:59:12.430696+00', '2021-02-07 17:22:16.054485+00', 'Reel Fun', 'REEL FUN', 1, 32, NULL, 1, 3, 42, 10568, '2016-03-01', 'Inspired by a lovely little dance called The Aviator by Carola Fischer which has the half reel, reel/turn figure. Written to celebrate TAC 2016.', 50, '800/864/866/864', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7267, '1998-11-14 23:00:00+00', '2021-02-06 12:53:03.255376+00', 'Ythanside', 'YTHANSIDE', 3, 32, 9999, 1, 3, 42, 108, '1985-01-01', 'Variant:



According to information from the SC Dictionary,  Drewry also wrote a variant where 2c+3c make a full turn on the sides on [23-24], and 2W & 3M lead the break on [28] into the Circle6, and the progression becomes (3,1,2)



The MiniCrib shows this variant, the e-crib and diagram show the 3/4L version.', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (16752, '2015-09-20 14:59:57.406137+00', '2021-05-23 11:00:10.676251+00', 'West Coast Magic', 'WEST COAST MAGIC', 3, 32, 9999, 2, 3, 17, 11204, NULL, '', 92, '888/888/888/088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16765, '2015-09-22 19:16:31.849806+00', '2016-07-10 12:16:12.29565+00', 'Oslo Waltz, The', 'OSLO WALTZ', 5, 32, NULL, 7, 1, NULL, 9998, NULL, 'Source: A Portland (OR) Ball program.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16750, '2015-09-20 14:45:22.204486+00', '2017-02-04 15:58:27.696158+00', 'Evergreen Line, The', 'EVERGREEN LINE', 2, 32, 9999, 2, 3, 18, 10588, NULL, '', 75, '444/888/444/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16894, '2016-03-05 15:47:12.111252+00', '2016-09-19 18:45:19.537186+00', 'Ron''s Favourite', 'RONS FAVOURITE', 3, 40, NULL, 1, 4, 1, 11150, NULL, '', 65, '8400/8840/8888/8800/8484', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17860, '2017-06-23 09:01:46.083916+00', '2017-06-23 09:01:46.083916+00', 'Diana''s Delight', 'DIANAS DELIGHT', 2, 32, NULL, 7, 113, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17987, '2017-09-26 22:05:18.589168+00', '2017-09-26 22:09:04.014914+00', 'Quick Scotch', 'QUICK SCOTCH', 1, 32, 9999, 1, 3, 42, 11527, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11219, '2003-02-24 23:00:00+00', '2015-09-29 12:48:19.812558+00', 'Last Way to Hanale''i, The', 'LAST WAY TO HANALEI', 1, 32, 9999, 1, 3, 42, 2677, '2000-01-01', 'Author''s Notes: The trick to the one-way reel is to make a point of passing right shoulders at the ends of

the half reel, both to get in and to get out. The tracks danced by second couple, for

example, are:



2M passes 2W with RS, 3W with LS, 1W with RS, then dances up the men''s side to finish

in the center facing down.



2W passes 2M with RS, dances down the women''s side and into the center facing up,

passes 1M with RS and 3M with LS to finish facing her partner.



Warning to teachers: From the outside, especially from the side, this reel looks wrong.

Many times I have stopped a walk through to straighten things out only to be told (by

everyone) that the figure had been working.', 69, '888  888  888  844', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (16756, '2015-09-20 15:40:27.342557+00', '2015-09-30 06:23:00.938446+00', 'Shopping Mall Scamble', 'SHOPPING MALL SCAMBLE', 2, 40, 9999, 1, 3, 42, 11206, NULL, 'An error has been found in the dance "Shopping Mall Scramble" in the Vancouver Golden Anniversary collection. Bars 27-28 should read: 

 

27-28  3rd woman with 1st woman, 3rd man with 2nd woman, and 1st man with 2nd man, giving right hands, cross over.

 

Rosemary Coupe', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2533, '1997-04-03 22:00:00+00', '2015-10-01 10:26:21.767854+00', 'Glenfeshie', 'GLENFESHIE', 2, 80, 9999, 4, 4, NULL, 94, NULL, 'Glen Feshie is a wild remote valley deep in the Scottish Highlands along the lower reaches of the northward-flowing River Feshie, a tributary of the River Spey.  The River Feshie rises from the ridgeline of the north watershed of the thousand-meter  (about 3,300 feet) Grampian Mountains.  The river first flows down through  the dense Glenfeshie Forest and eventually enters the more open glen in  question.  About 1½ miles below the tiny village of Feshiebridge it flows  into the River Spey at a point considerably above the broad valley called Strathspey.

 

While the river itself is somewhat longer, the  glen with the magnificent 4,000-foot Cairngorm Mountains towering to its east is  only about ten miles long.  One stretch of the  river are particularly "braided," i.e. divided into multiple interlocking  channels.



(Robb Quint)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16776, '2015-10-02 14:15:49.241156+00', '2018-04-10 17:11:40.253428+00', 'Reel for Mary, A', 'REEL FOR MARY', 1, 40, 9999, 1, 3, 42, 11220, '2012-06-01', 'A Youthful fling for Mary Lister on the occasion of her fiftieth birthday. Lang may your lum reek!', 51, '820/844/866/822/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18315, '2018-05-02 18:10:20.330612+00', '2018-05-02 18:10:20.330612+00', 'Fiona''s Favourite', 'FIONAS FAVOURITE', 3, 32, NULL, 1, 3, NULL, 11139, '2014-04-20', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12579, '2005-11-01 23:00:00+00', '2015-10-19 13:38:04.02458+00', 'As You Wish', 'AS YOU WISH', 3, 32, 9999, 2, 3, 18, 2961, '1998-01-01', 'Note: The dance was written as a request from my fellow teacher, Paula Jacobson, who thought it would be a nice change to include a short 3 times through strathspey in class.



Do not confuse with the dance by Linda Mae Dennis (2012), originally published as "As You Wish, PBC" or even "As You Wish", the suffix having been added to avoid to avoid confusion with the Bob McMurtry dance, and now renamed to "Aas Yooou Wiiissshhh" for the same reason.', 85, '828/888/888/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11764, '2004-08-24 22:00:00+00', '2015-10-29 00:43:24.368836+00', 'Morpeth Rant', 'MORPETH RANT', 1, 32, 9999, NULL, NULL, NULL, 9998, NULL, 'It is likely that this is an English Country Dance, as it is on Jimmy Shand''s English Folk Dances LP from 1973. On searching, there are 3 versions  of it as an English Country Dance available, all for 2 couples and 32 bars and reel time (one says 2/4 meter and Rant Steps). It was published in Kennedy''s Community Dances Manual, the EFDSS Community Dance Manual and included with the recording Folkcraft 337-011A. All the descriptions are the same formations, though differently described.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13270, '2007-03-13 23:00:00+00', '2015-10-29 15:25:51.690458+00', 'City of Stirling Reel', 'CITY OF STIRLING REEL', 1, 32, 9999, 1, 3, 42, 146, '2006-01-01', 'City of Stirling Reel was given to the Branch by Roy Goldring after he taught at a very successful day school in 2005. Stirling was given city status as one of the 6 new millennium cities hence the name given to the dance. The tune, The Nether Bailey, was composed for the dance by Nicol McLaren of the Glencraig Band. The Nether Bailey is thought to be the oldest part of Stirling Castle.

	', 52, '886  833  833  844', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (16898, '2016-03-06 10:28:08.280536+00', '2018-01-31 02:12:55.585586+00', 'Cornish Hospitality', 'CORNISH HOSPITALITY', 1, 32, NULL, 1, 3, 42, 872, '2005-01-01', 'Devised by Marilyn Watson to celebrate the first weekend school run by the Cornwall Branch of the Royal Scottish Country Dance Society March 18th to 20th 2005', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16778, '2015-10-06 00:40:06.997942+00', '2015-10-06 00:40:06.997942+00', 'Coach & Four', 'COACH AND FOUR', 2, 32, NULL, 1, 4, NULL, 10995, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16780, '2015-10-06 00:45:53.158242+00', '2015-10-06 00:45:53.158242+00', 'Grimesmoor', 'GRIMESMOOR', 3, 32, NULL, 1, 4, 1, 10995, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16781, '2015-10-06 00:48:04.436256+00', '2015-10-06 00:48:04.436256+00', 'Pigott''s Jig', 'PIGOTTS JIG', 2, 32, NULL, 4, 4, 4, 10995, '2007-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16779, '2015-10-06 00:42:43.827966+00', '2020-10-17 15:08:22.926365+00', 'Lucy Serena''s Jig', 'LUCY SERENAS JIG', 2, 32, NULL, 1, 3, 42, 10995, '2007-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16775, '2015-10-01 10:55:56.561525+00', '2020-12-28 20:41:31.789879+00', 'DAN: The Dancing Rhino', 'DAN THE DANCING RHINO', 1, 32, 9999, 5, 2, 76, 11219, '2014-11-28', '', 100, '88/88/88/88 ', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16783, '2015-10-06 00:55:35.76012+00', '2015-10-06 00:55:35.76012+00', 'Mrs Parkhill''s Reel', 'MRS PARKHILLS REEL', 1, 32, NULL, 1, 3, 42, 10995, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3202, '1998-07-08 22:00:00+00', '2019-04-20 09:08:54.366111+00', 'Janet Robb''s Fancy', 'JANET ROBBS FANCY', 1, 32, 9999, 3, 4, 30, 270, NULL, 'Special progression.  The top 4 couples dance first.  Their progression is (2,1,4,3).  Then the bottom four couples (1,4,3,5) dance.  The positions after twice through are then (2,4,1,5,3).  Danced ten times through in all.', 63, '8080/8888/8888/8282', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7878, '1997-09-10 22:00:00+00', '2015-10-10 14:32:23.459461+00', 'Osgood MacKenzie of Inverewe', 'OSGOOD MACKENZIE OF INVEREWE', 1, 32, 9999, 1, 4, 1, 1184, NULL, 'Can be a Jig also.



Michael Block originally designated this dance as a reel but he had also written some jig tunes which were arranged by Ian Robertson and played for the dance by Sound Company at a Newbury and District Caledonian Society''s Annual Dance in the late 1990s.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16786, '2015-10-10 13:54:58.405102+00', '2015-10-12 06:58:43.239662+00', 'C. W. Pimlott', 'C W PIMLOTT', 3, 32, NULL, 1, 100, 2, 1184, NULL, 'Michael Block dedicated this dance to C. W. Pimlott (affectionately known as "Pim") who was designated the "Convenor of Scottish Country Dancing" in the early days of the Newbury and District Caledonian Society. Pim was the prime mover in the transition of that Society from a group of ex-patriates into a group of Scottish Country Dancers.', 94, '8888/8888/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16899, '2016-03-06 10:42:11.117316+00', '2019-10-31 07:15:24.221248+00', 'Cornwall Revisited', 'CORNWALL REVISITED', 3, 80, NULL, 4, 4, 3, 872, '2006-01-01', 'Devised by Marilyn Watson on her return visit to Perranporth for the second weekend school

run by the Cornwall Branch of the R.S.C.D.   March 24th to 26th 2006.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16785, '2015-10-08 08:56:12.94847+00', '2015-11-09 13:15:00.170626+00', 'Perth City Charter', 'PERTH CITY CHARTER', 2, 32, NULL, 1, 3, 42, 3517, '2010-01-01', 'Bars 1-8 represent the old city walls of Perth; the next eight bars represent the ribbon tied around the charter; and the last 16 bars represent the number 800.



Dance devised January 2010 by Helen Beaney to celebrate the 800th anniversary of the granting of the Royal Burgh Charter to Perth by King William the Lion. It is an octocentenary gift to the children of Oakbank SCD Club in Perth, who were the first to dance it all the way through, and their teacher Marilyn Healy.', 37, '880/800/800/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2563, '2000-04-25 22:00:00+00', '2015-12-26 16:29:22.485978+00', 'Glens Of Antrim, The', 'GLENS OF ANTRIM', 3, 32, 9999, 1, 3, 42, 359, NULL, 'Dedicated to Miss Nan Shaw, a founder member of the Belfast Branch, and a member of the 1938

committee of the Belfast Scottish Country Dance Society - a forerunner of the Branch.', 58, '808/888/828/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3489, '1998-04-21 22:00:00+00', '2016-05-11 01:45:52.97941+00', 'King of the Fairies, The', 'KING OF THE FAIRIES', 3, 104, 9999, 4, 4, NULL, 44, '1969-12-11', 'Completed on the 31st December, 1969. The tune is that of an Irish step dance. 

A pleasant variation is to play the repeat of the tune in E minor. 



Unfortunately, no suitable recorded music exists.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16987, '2016-06-07 17:10:30.008884+00', '2016-06-07 17:10:30.008884+00', 'Salute to Marianne, A', 'SALUTE TO MARIANNE', 3, 40, 9999, 1, 3, 42, 2723, '1986-07-01', '', 70, '880 880 888 804 880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3298, '1997-04-03 22:00:00+00', '2018-04-03 00:07:56.001924+00', 'Joan Warren''s Reel', 'JOAN WARRENS REEL', 1, 32, 9999, 1, 3, 42, 196, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2758, '1999-01-05 23:00:00+00', '2018-04-03 00:07:50.633445+00', 'Hand Of Friendship, The', 'HAND OF FRIENDSHIP', 2, 32, 9999, 1, 3, 42, 2529, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8064, '1997-09-18 22:00:00+00', '2018-11-15 00:50:03.697375+00', 'Lord Selkirk', 'LORD SELKIRK', 3, 32, 9999, 1, 3, 42, 758, '1997-01-01', 'Lord Selkirk was the founder of Winnipeg, where Jo Hamilton''s parents settled around the beginning of the 20th century', 47, '404/880/844/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16817, '2015-11-05 10:22:51.26565+00', '2019-05-04 12:48:32.926365+00', 'Dancing Fiddler, The', 'DANCING FIDDLER', 3, 32, NULL, 2, 3, 17, 11223, '2015-08-01', 'Inscribed to Ruth Cheney, an enthusiastic member of the St Margaret’s Ilkley Scottish Country Dance class, who sadly passed away in July 2015.  She was formerly a professional viola player, and her spirit was lifted by the performance of traditional music by such fiddlers as Keith Smith and Alasdair Fraser.', 79, '888/484/880/848', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16798, '2015-10-14 16:10:02.524428+00', '2015-10-14 17:24:31.744968+00', 'Road To Mod, The', 'ROAD TO MOD', 4, 128, 10035, 1, 4, NULL, 2682, NULL, 'Devised with the help of my wife Kristin, 12 October, 2014. Modified 14th

October, 2014. This dance came from listening to an old record by Jim Macleod,

called “Lassie come and dance with me.” Track 6 of side 2 is called “The Road

to Mod” and has this intriguing medley with bow chords. So I guess at some

time there must have b een a danc e for this m edley. In spite of many enquiries, I

could not find the dance so to ok on the challenge to devise a dance to this music.

I chose a demonstration dance, and one the emphasised “big figures” and some

highland ste ps over complexity. The waltz was particularly challenging as we

have few standard desc riptions, and this particular Gaelic waltz is quite lyrical,

meaning finding figures sympathetic to the tune was tricky. Kristin help ed a

lot here. After comments by Glenna and Iain Matcham, I mo dified this on the

14th Octob er.



A Mo d is a traditional Scottish Gaelic festival of arts, including the Royal

National Mo d. A mo d includes comp etition for p o etry, music, choral events,

and many other asp ects of traditional Scottish culture. Macleo d was a wonderful

pip er and p erhaps he was talking of the national mo d piping comp etition when

naming this collection of tunes.



(On the record cover: “The Gaelic Mo d held annually in Scotland is the last

surviving remnant of the great Clan gathe rings, but apart from the comp etitive

asp ect of the Mo d the so cial spirit (in every sense) is in great abundance.”)



Clearly the recommended music is “The Road to Mo d”, from “La ssie Come and

Dance with Me” by Jim Macleo d and his Band. (Phillips, LP 6382 072, and

Fontana / T L 5353 (1966)).



Since this is more or less unobtainable, on my home page is an mp3 of the

recording. (At least while the record is not re-released.)



The tunes are 32 bars of the following: (Reel/March) Bratach Bana, (Waltz)

Morag of Dunvegan, (Schottis che) Larach do Thacaidean (Moulin Dhu-Black

Mill), (Reel) After the B attle . All are traditional. Thanks to Peter Elmes, Iain

Boyd and Michael Laidlaw for helping find the names of the tunes', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13747, '2011-07-11 22:00:00+00', '2018-04-03 00:07:50.866921+00', 'Hard Drive, The', 'HARD DRIVE', 1, 32, 9999, 1, 3, 42, 2973, '2003-03-01', 'Devised in March 2003 to celebrate the 10th Anniversary of the Strathspey Server. The name of the dance recalls a vital part of the computer, used by all „strathspeyers‟. The name also alludes to the spirited character of the dance and the music: a great driving reel (The Fairy Dance).', 45, '844  802  844  844', 0, 0, 0, 0, 60);
INSERT INTO 'dance' VALUES (3002, '1997-09-04 22:00:00+00', '2018-04-03 00:07:53.018389+00', 'Howqua Valley Strathspey, The', 'HOWQUA VALLEY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 42, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16800, '2015-10-17 10:25:15.328958+00', '2020-12-28 19:52:33.528399+00', 'Nine Decades', 'NINE DECADES', 1, 32, NULL, 4, 111, 72, 2831, '2012-01-01', 'Written by Alex Frew in celebration of the 90th

Anniversary of the RSCDS in 2012.', 92, '888888888/888888888/888888888/888666222', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10504, '2002-04-29 22:00:00+00', '2020-01-15 18:33:27.21729+00', 'Gypsy Silver', 'GYPSY SILVER', 3, 32, 9999, 1, 3, 42, 3110, '1999-01-01', 'Former weblink, now dead http://www.opendoor.com/heatherandrose/dances_brookeandchris.html#gypsy (found on web archive).', 56, '800  844  888  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (16777, '2015-10-06 00:35:19.68009+00', '2020-10-17 15:06:21.090524+00', 'Bridesmaid''s Posy', 'BRIDESMAIDS POSY', 1, 32, NULL, 1, 4, 1, 10995, '2006-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16782, '2015-10-06 00:51:30.544681+00', '2020-10-17 15:10:57.140421+00', 'Down By Salley Gardens', 'DOWN BY SALLEY GARDENS', 3, 32, NULL, 1, 4, 2, 10995, '2008-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13449, '2009-11-17 23:00:00+00', '2021-03-27 21:52:53.736344+00', 'Caerlaverock Castle', 'CAERLAVEROCK CASTLE', 3, 32, NULL, 2, 3, 17, 146, '2002-01-01', 'This dance is identical to the dance Bruce''s Men (The Scotia Suite of SCD [5]).', 75, '880  844  844  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14118, '2011-08-25 22:00:00+00', '2021-07-04 09:04:00.318763+00', 'Waverley Whispers', 'WAVERLEY WHISPERS', 2, 32, NULL, 1, 3, 42, 10433, NULL, 'This dance is dedicated to the ‘Waverley Whispers’ editorial team – Jean Deacon and Margaret and Ross Gawler. The monthly broadsheet ‘Waverley Whispers’ is required reading for all members of the Waverley Scottish Society and any other dancer lucky enough to get their hands (or their eyes) on a copy.', 56, '800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14892, '2013-05-23 07:59:51.352783+00', '2015-11-03 01:43:44.488465+00', 'Forty-Five Years Together', 'FORTYFIVE YEARS TOGETHER', 1, 32, NULL, 1, 4, 1, 1049, '2007-05-11', 'Dance devised for Dick and Henny Mackay, on the occasion of their 45th wedding anniversary, May 11, 2007





', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10950, '2002-11-14 23:00:00+00', '2015-11-09 14:52:28.728516+00', 'Lacemaker''s Lilt, The', 'LACEMAKERS LILT', 2, 72, 9999, 105, 2, 3, 2488, '1995-01-01', 'Written for the Cath Du Dancers of Minneapolis/Saint Paul in J995.



This is a demonstration dance, for practiced teams only.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18487, '2018-07-29 04:47:04.780413+00', '2018-07-29 07:20:37.082656+00', 'Moving to Paris', 'MOVING TO PARIS', 3, 40, NULL, 1, 4, 1, 11181, '2018-07-29', 'Dedicated to Nicolas, my son, Séverine, his wife, and Elian, Véia, Aloïs and Siloé, their 4 children, moving definitely in August 2018 from Lyon to Paris', 86, '8888/8888/8282/8888/8088', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16797, '2015-10-14 16:04:40.431825+00', '2016-05-31 00:25:26.169427+00', 'Pangolin, The', 'PANGOLIN', 3, 48, NULL, 2, 3, 17, 2682, NULL, 'In quick time, bars 1 and 2 should be danced in pas de Basque, and 5-8 using

the right hand.



Devised 12th October, 2015. The name follows a suggestion of John Patterson. Recommended music is the Sidlaw Hills (James Watson), played ABABAB, and a suitable recording is “Sey of Tunes Suitable for Morya Rant” by the Sound Company. A suitable alternative tune would be “Partans in his Creel” by Allie Windwick and a suitable recording is to be found d in \Strictly Scottish Vol.  1, by Robert Whitehead and the Danelaw Band in \Strictly Scottish Vol. 1, by Robert Whitehead and the Danelaw Ban

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14358, '2011-12-14 23:00:00+00', '2017-11-12 00:31:49.210757+00', 'Lairds'' Chain, The', 'LAIRDS CHAIN', 3, 32, NULL, 1, 2, NULL, 2983, '2003-01-01', 'Devised by Peter McClure (joptmc [at] cc.umanitoba.ca), Winnipeg, March 2003, for Rena and Adam Laird . This dance can be used to introduce relatively new dancers to the reel of four. It is a variation of "The Lairds'' Diamond," the reel of four is central to Scottish country dancing, just as Rena and Adam Laird have been central to the local Scottish cultural community for as long as we have known them.



The dance could also be done as a jig; in that case, we suggest skip-change-of-step for the two hand turns at bars 19-20. That may not be according to current RSCDS convention, but it will make the flow into the circle more pleasant. Finally, it could be done as a medley, 32 bars strathspey followed by 32 bars jig for each couple in a three couple set. ', 69, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18795, '2018-10-05 14:52:36.511034+00', '2018-10-05 14:52:36.511034+00', 'It''s About Timing', 'ITS ABOUT TIMING', 3, 32, NULL, 1, 3, 42, 2766, '2014-07-01', 'This dance was written to emphasize timing in dancing similar pieces of figures.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18797, '2018-10-05 14:59:05.350114+00', '2018-10-05 14:59:05.350114+00', 'Jack Pumpkinhead', 'JACK PUMPKINHEAD', 1, 32, NULL, 1, 3, 42, 2766, '2010-12-01', 'Jack Pumpkinhead is a character in the OZ books by L. Frank Baum.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12064, '2005-02-23 23:00:00+00', '2016-05-24 19:17:03.449245+00', 'Swirling Five / Churning Five', 'SWIRLING FIVE / CHURNING FIVE', 2, 32, 9999, 99, 55, NULL, 3514, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16821, '2015-11-11 23:18:45.076057+00', '2015-11-11 23:18:45.076057+00', 'Jamie Berg', 'JAMIE BERG', 3, 32, 9999, 2, 3, 17, 401, '2015-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3312, '1997-09-05 22:00:00+00', '2018-04-03 00:07:56.05372+00', 'Johan''s and Robert''s Visit to Hunter Valley', 'JOHANS AND ROBERTS VISIT TO HUNTER VALLEY', 3, 32, 9999, 1, 3, 42, 109, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16823, '2015-11-16 23:22:44.35309+00', '2015-11-17 00:17:35.463688+00', 'Stannary Jig', 'STANNARY JIG', 2, 32, NULL, 1, 3, 42, 3654, NULL, '', 59, '880/877/877/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16848, '2016-01-18 15:32:20.92622+00', '2020-12-28 11:44:43.018497+00', 'In Sickness & In Health', 'IN SICKNESS AND IN HEALTH', 1, 32, 9999, 1, 4, 1, 11035, '2014-07-01', '', 59, '8800/8800/8880/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12852, '2006-09-12 22:00:00+00', '2022-09-19 09:43:54.451184+00', 'Hearth and Harp', 'HEARTH AND HARP', 3, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12486, '2005-07-24 22:00:00+00', '2022-08-17 18:34:18.213315+00', 'Jubilee Red', 'JUBILEE RED', 1, 32, 9999, 1, 3, 42, 2766, '2005-07-01', 'This dance is named for one of the types of tomatoes we planted in our yard this season.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16204, '2015-04-12 17:31:14.160093+00', '2015-10-20 19:52:04.95156+00', 'Transition Teacher', 'TRANSITION TEACHER', 2, 32, 9999, 1, 3, 42, 11116, '2010-08-05', 'The dance is dedicated to Patricia Houghton and was devised by Janneke Mitschker & Tobias Huenger on 05.08.2010. We enjoyed Summer School Week 1 + 2 in St Andrews. Tobias has been taught by Pat in Unit 2 + 3 and to say „Thank You“; there came the idea to devise a dance. Janneke suggested the last 8 bars to have all steps in quick time to have as many transitions as possible. I suggested the Ladies'' Chain to have the opportunity to waggle with the kilt that has often been commented on by Pat (to avoid it in Unit 2 exam dances) - in this case, waggle as much as you can to start the Ladies'' Chain - and not at the end due to the transition to the next figure', 56, '800/880/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1708, '2000-12-10 23:00:00+00', '2015-10-21 10:32:55.708819+00', 'Double Sixsome, The', 'DOUBLE SIXSOME', 1, 64, 9999, 8, 105, 25, 50, '1971-01-01', '', 71, '888888  888888  888888  800008  088880  800008  800008  888888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (18319, '2018-05-02 18:16:49.578633+00', '2018-05-02 18:16:49.578633+00', 'Madam President', 'MADAM PRESIDENT', 1, 64, NULL, 1, 4, NULL, 11139, '2011-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3198, '2001-05-21 22:00:00+00', '2018-04-03 00:07:55.011416+00', 'Jan Wilson''s Strathspey', 'JAN WILSONS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1994-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15475, '2014-06-17 01:16:03.445167+00', '2018-04-03 00:07:55.203193+00', 'Jenny Sharp''s Century', 'JENNY SHARPS CENTURY', 2, 32, 9999, 1, 3, 42, 246, '2009-01-01', 'Jenny Sharp is the oldest and longest serving member of the Branch being a member from around its start in 1927. The dance was written for her by Alan Macpherson and performed and presented to her by a team from RSCDS Stirling at Fairview Care home where she now lives, for her 100th Brithday, 4th August 2009.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18320, '2018-05-02 18:17:48.26158+00', '2018-05-02 18:17:48.26158+00', 'Maroon Dance', 'MAROON DANCE', 1, 48, NULL, 1, 4, NULL, 11139, '2012-01-03', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10090, '2001-09-20 22:00:00+00', '2018-04-03 00:07:55.395043+00', 'Jig for Bette, A', 'JIG FOR BETTE', 2, 32, 9999, 1, 3, 42, 619, '1998-01-01', 'Inscribed to Miss Beatrice Nairn, former Secretary/Treasurer of Perth & Perthshire Branch of RSCDS ', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3269, '1997-04-03 22:00:00+00', '2018-04-03 00:07:55.603437+00', 'Jiggle Joggle Jump', 'JIGGLE JOGGLE JUMP', 2, 32, 9999, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16806, '2015-10-28 19:47:55.264883+00', '2016-10-30 21:48:07.140931+00', 'Jennie''s Strathspey', 'JENNIES STRATHSPEY', 3, 32, NULL, 107, 104, 17, 2419, NULL, 'Start in "Ruthven Formation": 1c face 3c on midline, 1c is on opposite side; 2c in 2pl. ', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12508, '2005-08-21 22:00:00+00', '2019-09-03 21:32:07.95122+00', '"Deer" Friends', 'DEER FRIENDS', 3, 32, 9999, 1, 3, 42, 3618, '2000-04-01', 'For Una Lennam to teach at a workshop in Red Deer, Alberta, Canada', 50, '800/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16807, '2015-10-28 19:48:47.668336+00', '2015-10-28 19:48:47.668336+00', 'Buchanan Street Strathspey', 'BUCHANAN STREET STRATHSPEY', 3, 32, NULL, 2, 3, NULL, 2419, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16808, '2015-10-28 19:49:35.742905+00', '2015-10-28 19:49:35.742905+00', 'Fingal''s Cave', 'FINGALS CAVE', 3, 32, NULL, 2, 3, NULL, 2419, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18947, '2018-10-12 14:35:27.04884+00', '2020-11-22 10:59:37.022677+00', 'Margarita''s Trip to Italy', 'MARGARITAS TRIP TO ITALY', 3, 32, NULL, 1, 3, 42, 11035, NULL, '', 44, '800/822/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16801, '2015-10-23 09:00:53.161115+00', '2020-12-29 12:21:32.257706+00', 'Morris Dancer', 'MORRIS DANCER', 1, 32, NULL, 1, 4, 1, 11221, '2015-08-01', '', 78, '8484/8080/8888/4888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9532, '2002-09-22 22:00:00+00', '2021-07-30 08:27:07.804036+00', 'Three Square Strathspey, The', 'THREE SQUARE STRATHSPEY', 3, 32, 9999, 107, 3, 17, 308, NULL, 'First and third couples stand as for a normal square set.  Second lady stands in second couple''s place, and second man stands in fourth couple''s place.', 92, '888/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16813, '2015-10-28 19:53:55.681135+00', '2015-10-28 19:53:55.681135+00', 'Fingal''s Cave (The Storm)', 'FINGALS CAVE THE STORM', 1, 48, NULL, 1, 4, NULL, 2419, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16814, '2015-10-28 19:56:01.033557+00', '2015-10-28 19:56:01.033557+00', 'Alpine Strathspey, The', 'ALPINE STRATHSPEY', 3, 32, NULL, 2, 3, NULL, 2419, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3466, '1997-04-03 22:00:00+00', '2015-10-31 00:40:13.603849+00', 'Killilan Reel, The', 'KILLILAN REEL', 1, 48, 9999, 1, 3, 42, 108, '1982-01-01', 'The tune should be played ABABAB.', 50, '880/880/844/844/844/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5503, '2002-04-08 22:00:00+00', '2015-10-29 22:39:39.533534+00', 'Red Rose And White', 'RED ROSE AND WHITE', 1, 32, 9999, 1, 3, 42, 13, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14191, '2011-08-26 22:00:00+00', '2015-11-01 18:15:57.456204+00', 'Two Up Down Under', 'TWO UP DOWN UNDER', 2, 40, NULL, 99, 55, NULL, 10462, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16805, '2015-10-28 19:46:36.185522+00', '2016-05-25 21:37:28.743389+00', 'Strathspey for Kenny Thomson', 'STRATHSPEY FOR KENNY THOMSON', 3, 32, NULL, 107, 3, NULL, 2419, NULL, 'Start in "Ruthven Formation": 1c face 3c on midline, 1c is on opposite side; 2c in 2pl.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16810, '2015-10-28 19:50:57.399842+00', '2016-05-25 21:37:52.127516+00', 'Union Street Strathspey', 'UNION STREET STRATHSPEY', 3, 32, NULL, 107, 3, NULL, 2419, NULL, 'Start in "Ruthven Formation": 1c face 3c on midline, 1c is on opposite side; 2c in 2pl.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8987, '1999-05-09 22:00:00+00', '2016-09-16 18:43:32.08331+00', 'Take Five', 'TAKE FIVE', 2, 32, 9999, 4, 55, 21, 1309, '1999-01-01', 'The dance was devised by Martha Morrison Veranth as a variation on her dance "Three''s the Charm".', 52, '00008/08088/40408/88488', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9151, '1999-11-07 23:00:00+00', '2017-04-07 22:55:38.369227+00', 'Three-Legged Cat, The', 'THREELEGGED CAT', 2, 32, 9999, 1, 3, 42, 2675, '1991-07-01', 'Dedicated to Tripod, a tortoiseshell and white female cat, who lost her front right leg in a motor vehicle accident. Hence, first woman does not use her right hand.



Just a note for anyone planning to do this dance in future: After the advance and retire, the first couple should be not so much simply dancing around each other as dancing a close ''gypsy turn''.  The deviser writes: "The first couple are dancing the interactions between Tripod and Pinky, so dancing around is up close and glaring!"  So just think of warring cats!

', 41, '800/480/888/800', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16815, '2015-11-02 13:01:29.587155+00', '2017-05-31 12:52:45.999342+00', 'Kentish Ruby, The', 'KENTISH RUBY', 2, 40, NULL, 1, 4, 1, 186, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7149, '1997-09-17 22:00:00+00', '2017-09-19 16:43:19.092236+00', 'Wild Mountain Thyme', 'WILD MOUNTAIN THYME', 3, 24, 9999, 1, 3, 42, 44, '1988-01-01', '', 42, '800/808/880', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1358, '2002-02-26 23:00:00+00', '2015-11-08 21:55:09.559617+00', 'Corstorphine Fair', 'CORSTORPHINE FAIR', 2, 40, 9999, 1, 4, 1, 796, '1963-01-01', 'As the original leaflet is no longer in print, the description is reproduced here.  This text will be removed at once if the copyright holder so requests.



1–8::

  All four couples circle and back



9–16::

  First couple cast off on own side followed by second, third

  and fourth couples crossing over at foot of the dance and dancing up the wrong side.

  (Phrasing – Cast off for 3, first couple cross over on bar 4, second on bar 5,

  third on bar 6, fourth on bar 7, each woman crossing in front of partner.

  On bar 8, all should be in two straight lines, facing up.



17–24::

  All four couples facing top slip 4 steps to centre of dance,

  women passing in front of men.  Join nearer hands or link arms with partners

  and dance two steps forward then two steps backward (Skip, change). 

  Then 4 slip steps to side lines.  Women again pass in front of men.



25–32::

  First woman changes places with second man giving right hands;

  with third woman giving left hands; with fourth man giving right hands;

  and on bars 7 and 8 all four couples turn on spot with 2 pas de basques,

  clapping hands on bar 7.



33–40::

  First man changes places with second woman giving left hands;

  with third man giving right hands; with fourth woman giving left hands

  and on bars 7 and 8 all four couples turn on spot with 2 pas de basques,

  clapping hands on bar 7.



The leaflet also contains the sheet music for the tunes.



From a Strathspey message on 2012-09-21:  Corstorphine (a suburb of Edinburgh) is pronounced much like the word  endorphin.

', 77, '8888  8888  8888  5333  5333', 1, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (3483, '1997-04-03 22:00:00+00', '2015-11-11 11:34:50.151608+00', 'Kind Robin', 'KIND ROBIN', 3, 32, 9999, 1, 2, NULL, 108, '1982-01-01', '"For Margaret Charles of Bournemouth"', 64, '84/88/88/88', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5590, '1997-04-03 22:00:00+00', '2018-07-17 11:18:21.605588+00', 'River City Strathspey, The', 'RIVER CITY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 129, NULL, 'This dance was devised for the Glendarroch Scottish Country Dance Club, Wanganui (The River City), New Zealand.', 49, '440/880/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14025, '2011-08-25 22:00:00+00', '2015-11-18 23:51:06.882727+00', 'Shetland Shepherdess, The', 'SHETLAND SHEPHERDESS', 2, 32, NULL, 1, 3, 42, 401, NULL, 'This title was inspired by a trip to Oslo to teach SCD, where the deviser met Caroline Nicol, a

Shetlander shepherding in Norway! The dance and music are dedicated to Susan Hagen, Ron''s

hostess, and all the fine folk in Oslo SCD Group', 53, '800/888/822/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16834, '2015-12-15 14:52:38.16344+00', '2019-02-23 22:53:55.948755+00', 'Salute to Alison', 'SALUTE TO ALISON', 3, 32, NULL, 2, 3, 17, 11155, NULL, '', 92, '888/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16837, '2015-12-15 15:11:46.28372+00', '2020-08-24 18:55:22.194906+00', 'Mystery of the Star Sapphire, The', 'MYSTERY OF THE STAR SAPPHIRE', 1, 32, NULL, 1, 3, 42, 44, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (797, '1997-08-31 22:00:00+00', '2021-06-28 14:27:18.439961+00', 'Bridge Over The Glen', 'BRIDGE OVER THE GLEN', 3, 32, 9999, 2, 3, 17, 542, NULL, 'The instructions give the dates 1869 - 1974 after the title.', 79, '888/888/804/808', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16803, '2015-10-25 12:58:52.526584+00', '2020-11-10 20:45:09.938971+00', 'Fair Enough', 'FAIR ENOUGH', 2, 32, NULL, 1, 4, 11, 11222, '2014-07-01', '“Devised for a performance at the Clark County Fair in Vancouver, Washington, USA.”



DEVISED:2014-07', 75, '8888/0880/8008/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16822, '2015-11-16 09:46:01.553191+00', '2021-01-02 23:30:49.114003+00', 'Panta Rhei', 'PANTA RHEI', 3, 32, NULL, 1, 3, 42, 558, '2014-01-01', 'Dedicated to Silvia Hillebrand for her 50th birthday.', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15437, '2014-05-09 22:17:04.65567+00', '2021-08-10 18:50:09.684434+00', 'Trip to Crinan, A', 'TRIP TO CRINAN', 2, 32, NULL, 1, 3, 42, 10958, NULL, 'Crinan is a small village at the Atlantic end of the Crinan Canal in Argyllshire. The Crinan Canal was opened in 1801 as a shortcut for boats from Loch Fyne to the Sound of Jura. Crinan was a childhood playground of Mairi’s, and we visit whenever we go over.', 50, '444/444/888/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13119, '2006-11-22 23:00:00+00', '2016-03-19 12:10:45.645297+00', 'Cass'' Capers, The', 'CASS CAPERS', 1, 40, 9999, 1, 3, 42, 3134, '2003-06-01', 'Devised by Marion Peutherer (with assistance from the Newcastle University Tuesday night class) to celebrate the 1st wedding anniversary of Ginette & Peter Cass on 1st June 2003.', 50, '800/844/844/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13269, '2007-03-04 23:00:00+00', '2015-12-20 16:55:55.487082+00', 'Campbell''s Welcome', 'CAMPBELLS WELCOME', 2, 24, 9999, 5, 2, NULL, 3772, NULL, 'Campbell Tyler writes: This dance was first named "Campbell''s Fancy". I subsequently renamed this dance Campbell''s Welcome as I use it so often as the first dance in a programme, especially a ceilidh dance.  

', 100, '88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (13117, '2006-11-22 23:00:00+00', '2016-03-19 18:45:36.021063+00', 'Fair-le-Small Reel, The', 'FAIRLESMALL REEL', 1, 32, 9999, 1, 4, NULL, 3134, '1998-01-01', 'This dance was devised for Diana Fair and Sandy Small and presented to them on the occasion of their wedding in Birmingham on October 24th, 1998', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13931, '2011-08-22 22:00:00+00', '2016-09-09 09:33:17.481404+00', 'Highveld Storm', 'HIGHVELD STORM', 1, 32, NULL, 1, 4, 1, 146, NULL, 'Wouter Joubert of Pretoria, the publisher, adds (in Strathspey message 67356): The reels in bars 1-8 are across 1st and 3rd place respectively, 1st couple with 2nd woman who dances up the side to 1st woman''s place (a bit of a curve to the right) and 3rd couple with 2nd man who likewise dances down into 3rd man''s place.

', 56, '8880/8080/8800/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16826, '2015-12-08 11:10:16.957997+00', '2015-12-08 11:10:16.957997+00', 'Betty and Gordon Page''s Reel', 'BETTY AND GORDON PAGES REEL', 1, 32, NULL, 1, 100, 2, 11225, '2015-11-01', 'Devised as a thank you to Betty and Gordon Page of Wellingborough whose collection of dance books was passed on to the Lisbon (Lapa) Scottish Country Dance Group at the SCD Weekend at Curia, Portugal, in December 2015 by Jan Jones through the International Branch.', 91, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18322, '2018-05-02 18:19:24.592801+00', '2019-03-13 11:39:47.271537+00', 'Music From The Heart', 'MUSIC FROM THE HEART', 2, 32, NULL, 1, 3, 42, 11139, '2013-09-30', '', 47, '888/800/844/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18411, '2018-07-17 16:10:24.47805+00', '2018-07-17 16:10:24.47805+00', 'Triangulation', 'TRIANGULATION', 1, 32, NULL, 6, 118, NULL, 1848, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16733, '2015-09-09 13:47:20.509922+00', '2018-04-03 00:07:44.118974+00', 'Eggemoggin Reach', 'EGGEMOGGIN REACH', 2, 32, NULL, 1, 3, 42, 1167, '2013-11-09', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9317, '2000-01-16 23:00:00+00', '2018-04-03 00:07:56.1789+00', 'Johnnie Notions', 'JOHNNIE NOTIONS', 1, 32, 9999, 1, 3, 42, 35, NULL, 'John Williamson was born in 1740 at Esha Ness and received no formal education. He was shy and studious and frequently dabbled in mechanical inventions, thus earning the nickname "Johnnie Notions." He spent 30 years tramping around the 45 inhabited Shetland Isles inoculating crofters against smallpox, the scourge that plagued mankind for 2 000 years, with a serum of his own invention. Its composition was a guarded secret, but it was reliably reported after his death in 1803, that to obtain it, he had inoculated a Shetland pony with pus from a smallpox patient. While Englishman. Edward Jenner, is generally credited with the first successful inoculations in 1802, and in spite of the fact that the medical profession was eagerly waiting to put him on trial as an unqualified practitioner, they acknowledged that not one of his patients died. 



While he was a weaver by trade, and also became the local bone-setter, blacksmith, carpenter and clock-repairer, he must have had a talent for sculpting. A sculpture he did in wood, of the head of a man is at the Shetland County Museum, his model being his first patient, who had a look of intense relief on his face. 

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12793, '2006-06-25 22:00:00+00', '2015-12-12 23:19:26.73558+00', 'Eileen Watt''s Reel', 'EILEEN WATTS REEL', 1, 32, 9999, 2, 3, 18, 515, '2005-01-01', 'Eileen Watt was on the staff at RSCDS headquarters for 17 years, and retired in 2005. She was beloved by those who knew her.  She had the added distinction of then being the only member of staff who danced! ', 75, '800  466  888  888', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (18413, '2018-07-17 16:12:46.476136+00', '2018-07-17 16:12:46.476136+00', 'Tigger Dance for Linda, A', 'TIGGER DANCE FOR LINDA', 1, 32, NULL, 3, 5, 6, 10424, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16836, '2015-12-15 14:56:27.519899+00', '2019-02-23 22:49:45.207909+00', 'Haywards Hill', 'HAYWARDS HILL', 3, 32, NULL, 2, 3, 17, 1798, NULL, '', 58, '880/808/822/804', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3354, '1997-04-03 22:00:00+00', '2018-04-03 00:07:56.445763+00', 'Journalist''s Rant, The', 'JOURNALISTS RANT', 1, 32, 9999, 1, 3, 42, 209, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16824, '2015-11-27 08:27:17.616694+00', '2016-11-12 23:36:09.226496+00', 'Drooney''s Reel', 'DROONEYS REEL', 1, 32, NULL, 1, 4, 2, 316, '2015-01-01', 'This is a very provisional entry, derived from the video only.  Please tell me of errors.  Eric Ferguson.', 94, '8888/8888/4884/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3384, '1997-09-05 22:00:00+00', '2018-04-03 00:07:56.804241+00', 'Just Because', 'JUST BECAUSE', 3, 32, 9999, 1, 3, 42, 366, '1989-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16852, '2016-01-18 16:25:48.181384+00', '2020-12-28 11:27:43.195239+00', 'River Hutt, The', 'RIVER HUTT', 3, 32, 9999, 1, 3, 42, 11035, '2014-04-07', '', 69, '888/888/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14854, '2013-05-19 10:29:33.863334+00', '2018-04-03 00:07:58.022105+00', 'Ladies & their Lads, The', 'LADIES AND THEIR LADS', 2, 32, 9999, 1, 3, 42, 17, '1996-01-01', 'This is a variant to Martin Sheffield''s "Ladies First", differing in the first 8 bars.



In his older 140 Dances Collection the dance was named "Ladies & Lads", but has the title "The Ladies & their Lads" in the Modern Country Dances in the Scottish Tradition Collection from 2017.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16830, '2015-12-15 14:41:41.615885+00', '2020-10-17 15:18:48.570061+00', 'Dancing Butterflies', 'DANCING BUTTERFLIES', 1, 32, NULL, 1, 3, 42, 11226, NULL, '', 44, '880/800/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16831, '2015-12-15 14:46:04.160825+00', '2020-10-17 15:22:45.361181+00', 'Sparkle in her Eyes', 'SPARKLE IN HER EYES', 1, 32, NULL, 1, 3, 42, 11227, NULL, '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16833, '2015-12-15 14:51:35.85715+00', '2020-10-17 19:38:29.733432+00', 'Autumn Tidings', 'AUTUMN TIDINGS', 2, 32, NULL, 1, 3, 42, 11211, NULL, '', 55, '800/888/860/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16829, '2015-12-15 10:37:36.762095+00', '2020-12-29 12:17:03.824078+00', 'Narcissisity', 'NARCISSISITY', 2, 32, 9999, 1, 3, 42, 2766, '2007-07-01', '', 50, '888/660/660/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11308, '2003-05-15 22:00:00+00', '2021-01-24 11:48:50.047235+00', 'My Love She''s but a Lassie yet', 'MY LOVE SHES BUT A LASSIE YET', 1, 32, 9999, 5, 109, 76, 9998, NULL, '<<scddb-not-identical:4862>>



', 100, '88/88/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12877, '2006-10-08 22:00:00+00', '2019-03-04 19:26:52.394284+00', 'Every Witch Way', 'EVERY WITCH WAY', 3, 32, 9999, 6, 3, 18, 777, '2004-10-16', 'The Capital District Fall Frolic always is scheduled for the weekend closest to Halloween, which is why Dale Birdsall wrote a dance with this title for that occassion.



This dance contains Schiehallion Reels reverse for six dancers (denoted reel of six), that means men start facing out to cast and ladies dance across the set to their left.', 100, '888/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16841, '2016-01-01 20:14:45.105371+00', '2018-04-03 00:07:35.559785+00', 'Brenda Morris', 'BRENDA MORRIS', 2, 32, NULL, 1, 3, 42, 3177, '2015-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16911, '2016-04-15 16:23:14.503901+00', '2018-10-03 00:34:29.03377+00', 'Celtic Ghost, The', 'CELTIC GHOST', 1, 32, NULL, 3, 5, 7, 2766, '2009-06-01', 'Suggested music is Hoedown Reel Set from Music Makars or The McDonald Saunter from Dances with a Difference.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16804, '2015-10-26 20:50:52.059267+00', '2018-04-03 00:07:51.133725+00', 'Hazel''s Salute to the Seventies', 'HAZELS SALUTE TO THE SEVENTIES', 1, 32, NULL, 1, 3, 42, 3517, NULL, 'The music for this dance was composed by John Barnes and the dance devised by Helen Beaney in celebration of the 70th birthday of Hazel Convery of the Dublin Scottish Country Dance Club.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14557, '2012-09-03 23:59:47.825342+00', '2016-01-01 11:19:53.765402+00', 'Alice and Malcolm''s Golden Wedding', 'ALICE AND MALCOLMS GOLDEN WEDDING', 3, 32, NULL, 1, 3, 42, 3517, '2008-02-17', 'The music for this dance was composed by John Barnes and the dance was devised by Helen Beaney. They were presented to Alice and Malcolm Kincaid on the occasion of their Golden Wedding Anniversary, 17th February 2008, with very best wishes from all their friends in the Dublin Scottish Country Dance Club.



Here is the original description, sent by Helen Beaney with the covering text "Please find attached my latest dance for your databases."



Alice and Malcolm’s Golden Wedding



8x32 Strathspey



1-4    	1C cross giving RH and cast off 2 places, 2C and 3C stepping up on bars 3-4



5-8    	1C cross giving RH and cast up to 2nd place, 3C stepping down on bars 7-8



9-10  	2C, 1C, with nearer hands joined, set on the sides



11-12 	2C, 1C dance RH across half way around



13-14 	2C, 1C, with nearer hands joined, set on the sides



15-16  	2C, 1C dance LH across half way around



17-20 	1M and 3L turn BH



21-24 	1L and 3M turn BH



25-32 	2C, 1C, 3C circle six hands round to left and back



Repeat, having passed a couple.

', 44, '800  880  404  888', 1, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (18323, '2018-05-02 18:21:15.950178+00', '2018-05-02 18:21:15.950178+00', 'New Zealand Summer', 'NEW ZEALAND SUMMER', 4, 32, 5, 1, 2, NULL, 11139, '2014-02-22', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14392, '2012-01-06 23:00:00+00', '2016-01-01 11:42:15.644596+00', 'Campbells of Crannagh, The', 'CAMPBELLS OF CRANNAGH', 2, 32, NULL, 1, 3, 42, 3517, '2008-07-26', 'Presented to Pam and Forbes Campbell on the occasion of their Golden Wedding Anniversary, 26th July 2008, with very best wishes from all their friends in the Dublin Scottish Country Dance Club.  The title was thought of by Hazel Convery as Forbes and Pam live in Crannagh Park, Dublin.



The track of 1st Lady in bars 1-7 represents the figure 5 (her partner’s track is a mirror image) and bars 9-16 represents the figure 0.  Diagonal Rights and Lefts is Pam’s favourite formation.

', 56, '800  888  888  844', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (8371, '1997-12-28 23:00:00+00', '2019-05-16 06:04:40.381931+00', 'Ruby Reel, The', 'RUBY REEL', 2, 40, 9999, 1, 3, 42, 27, '1997-01-01', 'The dance was devised at the request of the Farnham (Surrey) ScotUsh Country Dance Club, where it was known as the Farnham Ruby Reel, to celebrate its 40th anniversary.



Over the years due perhaps to the town''s'' proximity to ALdershot - ''The Home of the British Army'', a number of soldiers were and are members of the Club - hence the suggested tune "SoLdiers Dance".', 60, '822/888/822/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16843, '2016-01-13 23:29:57.066287+00', '2016-01-14 10:47:27.207872+00', 'Dance in the Park', 'DANCE IN THE PARK', 1, 32, NULL, 5, 2, NULL, 11232, '2015-07-01', 'Devised for the dancers joining the Dance in the Park sessions on Fridays in July and August in Park Georges-Henri in Woluwe-Saint-Lambert, Brussels.', 100, '88/88/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5274, '1997-09-11 22:00:00+00', '2016-02-06 20:58:55.415043+00', 'Piper Jock Kerr', 'PIPER JOCK KERR', 2, 48, 9999, 4, 4, NULL, 270, NULL, 'According to the instructions, this is a 48 bar progressive jig for 3 couples in a 4-couple square set. One couple acts as markers for the other three who actually dance parts of the dance in a triangular formation. The "marker" couple changes each time through the dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16816, '2015-11-05 08:03:02.326664+00', '2016-02-25 22:03:36.73116+00', 'Lin''s Legacy', 'LINS LEGACY', 3, 32, NULL, 2, 3, 17, 3504, '2015-06-01', 'The name of this dance was changed from "Method Madness" to "Lin''s Legacy" in February 2016', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16840, '2016-01-01 13:19:02.706516+00', '2016-03-24 17:51:08.42478+00', 'Rosalie''s Birthday Reel', 'ROSALIES BIRTHDAY REEL', 1, 88, 9999, 4, 4, 3, 11231, '2004-05-01', 'Devised by Hazel Convery for Rosalie Parker on the occasion of a "rather special birthday" may 4004 and amended 2015', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16913, '2016-04-15 16:31:56.500857+00', '2018-10-04 08:54:56.189299+00', 'Double Duty 2', 'DOUBLE DUTY 2', 3, 32, NULL, 1, 3, 42, 2766, '2010-03-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18326, '2018-05-02 18:24:42.318992+00', '2018-05-02 18:24:42.318992+00', 'Saint Andrews Summer', 'SAINT ANDREWS SUMMER', 4, 32, 1, 1, 2, NULL, 11139, '2013-06-13', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18327, '2018-05-02 18:25:39.982927+00', '2018-05-02 18:25:39.982927+00', 'Secret Life of a Librarian, The', 'SECRET LIFE OF A LIBRARIAN', 2, 32, NULL, 1, 3, NULL, 11139, '2012-01-28', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16914, '2016-04-15 16:34:54.2732+00', '2018-10-06 04:59:36.466497+00', 'Lake Louise', 'LAKE LOUISE', 3, 32, NULL, 1, 3, 42, 2766, '2010-04-01', 'Suggested music is Bill Little''s Strathspey from The March Hare.  

Lake Louise is a beautiful glacial lake just west of Banff.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16839, '2016-01-01 11:40:39.20583+00', '2019-03-02 22:53:33.65861+00', 'Blaven Strathspey, The', 'BLAVEN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 11193, NULL, '', 50, '800/844/888/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14719, '2013-03-05 15:56:22.06107+00', '2019-03-28 00:18:01.378912+00', 'It''s Reel Life', 'ITS REEL LIFE', 1, 40, 9999, 2, 3, 18, 10759, '2012-08-26', 'For Bärbel Koch on her 60th birthday, 26 August 2012



The description as originally published had an omission on 17-20.  2nd lady and 3rd man set on [17-18], and only then do they [as written] "dance in, pulling back right shoulder, to finish back to back, facing the place they just left." [19-20].  Since December 2015 the "original" has been corrected.', 77, '880/822/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16849, '2016-01-18 15:39:09.522444+00', '2020-12-28 11:40:46.177622+00', 'Joshua''s Jig', 'JOSHUAS JIG', 2, 32, 9999, 1, 3, 42, 11035, '2011-06-01', '', 50, '800/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7310, '2002-01-08 23:00:00+00', '2020-12-18 20:43:47.060883+00', 'Let''s dance before it rains', 'LETS DANCE BEFORE IT RAINS', 2, 32, 9999, 1, 3, 42, 17, '1992-01-01', '', 62, '800  888  888  844', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (16917, '2016-04-15 16:47:13.071549+00', '2021-01-18 10:11:59.311169+00', 'Yin/Yang', 'YIN/YANG', 3, 32, NULL, 1, 4, 1, 2766, '2012-02-01', 'Suggested music is Double Diamond Strathspey from Vintage Goldring.

The shape of the figures of this dance remind me of the yin-yang symbol.', 81, '8080/8888/8888/8484', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4282, '1998-04-12 22:00:00+00', '2021-05-01 22:04:15.106511+00', 'McNeil of Barra', 'MACNEIL OF BARRA', 4, 112, 18, 107, 112, 3, 9998, NULL, '', -1, '', 1, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (16832, '2015-12-15 14:49:38.502154+00', '2021-05-23 10:37:52.526695+00', 'Snow Flurries', 'SNOW FLURRIES', 3, 32, NULL, 2, 3, 17, 11228, '2011-08-01', 'The notes say this dance was "devised to commemorate the amazing once-in-a-lifetime snowfall in the Hutt Valley and Wellington regions in August 2011. The dance depicts the gentle snow flurries which increased in intensity falling as streamers or ropes from the sky, creating a magical winter wonderland where we were enticed to play."', 100, '888/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10819, '2002-09-10 22:00:00+00', '2016-01-15 20:19:29.88724+00', 'New Fowlis Hall, The', 'NEW FOWLIS HALL', 2, 32, 9999, 1, 4, 2, 10721, '2002-01-01', 'Description, submitted by the deviser herself:



The New Fowlis Hall: 4x32 bar jig



Bars



1-4  1st couple with 2nd couple and 3rd couple with 4th couple dance right hands across.

2nd and 3rd couples finish on sidelines, 1st and 4th couple stay facing clockwise.



5-8  1st couple and 4th couple chase CW round outside of set half way to finish with 1st

couple at bottom on opposite sides facing 3rd couple and 4th couple at top on opposite

sides facing 2nd couple.



9-16  Right shoulder reels of four on the side. All finish facing up/down on sides.



17-24  All turn facing person right hand half-way (4L turns 2M; 4M turns 2L; 1L turns 3M;

1M turns 3L); 1st couple and 4th couple dance left hands across in the middle; 4th couple

and 1st couple retain hold of partner’s left hand on bar 22, cross left hand to own side

of the set to finish 2413.



25-32  Eight hands round and back.



Dance devised by Mary Cant to celebrate the opening of the new Fowlis Easter Village Hall in southwest Angus on June 22nd 2002.



The hall was designed by Iain Dunsire of Battledown Studio, Forgandenny, Perthshire, taking inspiration from paintings of Angus stackyards by the eminent landscape artist James McIntosh Patrick.



The formations in the dance reflect the architecture of the building. The wheels represent the round stacks of corn; the chase represents the passageways outside the main hall; the reel of four represents weaving in and out of the various rooms; and the dance finishes with a celebratory circle representing the main hall, comprised of the two largest stacks.





', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11259, '2003-03-17 23:00:00+00', '2016-01-17 00:10:30.426152+00', 'Balfron Belle, The', 'BALFRON BELLE', 1, 32, 9999, 1, 3, 42, 1341, NULL, '2016-01-17.  Spelling changed to Balfron, Belfron must be a misspelling as no place name Belfron exists anywhere in the UK.  Eric Ferguson.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1985, '1997-04-03 22:00:00+00', '2016-01-17 00:26:52.885395+00', 'Endrick Water', 'ENDRICK WATER', 1, 32, 9999, 3, 5, 7, 259, NULL, 'Endrick Water is the small river running through the bottom of the village of Balfron, where my cousin Olive McAllister lives. In past times, Tony Moretti has been known to fish in these waters.', 60, '80800/88880/80888/80800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15843, '2015-01-18 15:38:07.491524+00', '2018-04-29 06:13:23.506613+00', 'Rhubarb Reel, The', 'RHUBARB REEL', 1, 32, 9999, 3, 5, 7, 1582, '2006-09-01', 'Some earlier versions of the dance instructions mistakenly state that this dance is a Jig. It is not. It''s a Reel. (Source: the dance instructions)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18328, '2018-05-02 18:26:26.466561+00', '2018-05-02 18:26:26.466561+00', 'Why Knot?', 'WHY KNOT', 1, 48, NULL, 1, 3, NULL, 11139, '2010-03-22', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18414, '2018-07-17 16:14:03.88755+00', '2018-07-17 16:14:03.88755+00', 'Helen''s Fancy', 'HELENS FANCY', 3, 32, NULL, 1, 4, 2, 517, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16920, '2016-04-15 19:05:47.686352+00', '2018-08-12 14:39:34.488843+00', 'Hellbender', 'HELLBENDER', 3, 32, NULL, 2, 3, 18, 10640, NULL, '', 100, '888/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3972, '1998-09-29 22:00:00+00', '2018-04-03 00:08:00.849325+00', 'Lovers'' Knot, The', 'LOVERS KNOT', 3, 40, 9999, 1, 3, 42, 9998, NULL, 'For bars 9-12 some prefer to set in the middle, to make a more realistic "Lovers'' Knot", but the official revised text of 2014 does not mention this variant.', 37, '800/800/800/844/866', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (13189, '2006-12-11 23:00:00+00', '2018-10-04 18:13:38.01567+00', 'Engagement Ring, The', 'ENGAGEMENT RING', 3, 32, 9999, 4, 4, 1, 2766, '2005-12-01', 'This dance is for Marsha Hanson and Clay Spurlock, who announced their engagement this month.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16896, '2016-03-05 18:06:07.932834+00', '2016-06-03 14:04:19.191476+00', 'Roses for Johanna', 'ROSES FOR JOHANNA', 3, 32, NULL, 6, 3, 17, 228, '2016-03-04', 'For Johanna Leithoff of Erfurt, Germany, on the occasion of her wedding on 19 March 2016. Johanna danced with the Frankfurt Scottish Country Dance Club for many years, and taught there and at the “Narhalla Dancers” in Mainz, before moving to Erfurt to work at the university there.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16988, '2016-06-07 17:18:47.392387+00', '2016-06-07 17:18:47.392387+00', 'Stow''s Salute to Jeanetta McColl', 'STOWS SALUTE TO JEANETTA MACCOLL', 2, 32, 9999, 1, 3, 42, 2723, '2015-05-01', '', 75, '800 888 888 880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17070, '2016-06-26 14:39:22.948619+00', '2016-06-26 14:43:44.92664+00', 'Rowan Tree Dancers, The', 'ROWAN TREE DANCERS', 2, 32, NULL, 1, 102, 2, 11279, '2003-03-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10700, '2002-07-21 22:00:00+00', '2018-04-03 00:08:04.994008+00', 'Mist on the Heather', 'MIST ON THE HEATHER', 3, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16907, '2016-03-20 14:34:32.358632+00', '2018-04-03 00:08:07.804613+00', 'Nick the Trumpet', 'NICK THE TRUMPET', 1, 40, NULL, 1, 3, 42, 802, '2015-10-01', 'Devised by Lyn Wilson, South Wales, for Nick Dewhurst following an impressive “with my other hand” display of trumpet playing (he normally plays drums for dancing) at the RSCDS Cornwall residential weekend April 2015', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3812, '1998-04-21 22:00:00+00', '2020-08-31 14:49:25.243341+00', 'Lily In The Valley, The', 'LILY IN THE VALLEY', 3, 96, 9999, 1, 102, 3, 44, '1972-11-25', 'Completed on Saturday 25th November, 1972 but slightly modified twice since then. 



No specific recorded music exists but Stan Hamilton''s "The Saint John River " may be used if the dancers are patient enough to stand for 32 bars until the second tune begins.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16953, '2016-05-22 16:33:38.806129+00', '2020-10-17 20:56:00.848931+00', 'White and Purple Heather Jig, The', 'WHITE AND PURPLE HEATHER JIG', 2, 40, NULL, 1, 4, 1, 9998, NULL, 'Found on Minicrib, source unknown.  Unrelated to James Cosh''s "The White Heather Jig" and its  variants "The White and Purple Heather Jig" and "The Purple Heather Jig".', 85, '8888/8888/8888/8440/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17076, '2016-06-26 15:15:17.993964+00', '2020-10-19 09:53:38.016164+00', 'Imminent Eminent Vet, The', 'IMMINENT EMINENT VET', 1, 32, NULL, 2, 3, 46, 2887, NULL, '"Top" changes ends; 6 times through', 88, '884/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16854, '2016-01-18 16:46:46.59549+00', '2020-12-28 11:20:02.468395+00', 'Warm Me up Scottie', 'WARM ME UP SCOTTIE', 2, 32, 9999, 1, 3, 42, 11035, '2010-01-01', 'Warm up dance for the beginning of club nights or any session.', 50, '800/888/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16853, '2016-01-18 16:35:24.781949+00', '2020-12-28 11:23:21.116384+00', 'Surprising Hannah', 'SURPRISING HANNAH', 3, 32, 9999, 2, 3, 17, 11035, '2013-11-01', '', 75, '880/880/888/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16884, '2016-02-29 01:16:19.85405+00', '2023-01-14 12:33:30.900837+00', 'Gorgeous Gordons', 'GORGEOUS GORDONS', 3, 32, NULL, 1, 102, 11, 11237, '2015-01-01', 'For John Tyler and Daniel Capron, ten years after the foundation of the Gay Gordons in London.



NB bars 25-28 were revised in May 2017.

', 78, '8008/2882/8888/8888 ', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16888, '2016-02-29 15:02:04.894497+00', '2023-01-14 12:40:47.539341+00', 'Great Gable', 'GREAT GABLE', 1, 32, NULL, 4, 4, 1, 11237, '2016-01-01', '', 93, '8484 8888 8888 8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16846, '2016-01-18 14:42:52.270942+00', '2020-12-28 11:49:57.440654+00', 'Dave Macfarlane''s Reel', 'DAVE MACFARLANES REEL', 1, 32, 9999, 1, 3, 42, 11035, '2012-06-01', '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16844, '2016-01-18 14:19:01.622638+00', '2020-12-28 11:57:13.278806+00', 'Allemande to Go', 'ALLEMANDE TO GO', 1, 32, 9999, 1, 3, 42, 11035, '2011-05-01', '', 56, '880/880/880/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15275, '2013-12-07 20:39:56.131054+00', '2016-01-21 14:07:54.150067+00', 'Comeback Jig, The', 'COMEBACK JIG', 2, 32, NULL, 1, 3, 42, 1760, '2012-01-01', 'January 2012 - A gentle dance devised by Elaine Brunken to celebrate Maria Ward’s comeback

to dancing after major neck and spine surgery…….January 2012 also happened to be her 60th

birthday!', 62, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18746, '2018-10-04 18:21:20.790532+00', '2018-10-04 18:21:20.790532+00', 'Faithful Feline', 'FAITHFUL FELINE', 1, 32, NULL, 1, 3, 42, 2766, '2015-10-01', 'Every night my cat, Christopher, sleeps on my left arm.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16478, '2015-07-08 14:21:03.427742+00', '2018-09-13 13:14:22.958981+00', 'Portincaple Oak, The', 'PORTINCAPLE OAK', 4, 64, 5, 4, 4, 3, 3183, '2011-11-01', '', 100, '8888/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16858, '2016-01-30 14:56:34.329829+00', '2016-01-30 23:16:45.173224+00', 'Inland Sea', 'INLAND SEA', 4, 96, 11, 4, 4, 3, 10374, '2016-01-26', 'Demonstration dance.  No crib needed.



This dance was devised by Louis Emslie, one of the Kitchener-Waterloo Branch''s teachers, in honour of the 35th Anniversary of the Branch''s annual "Burns Supper" and was performed for the first time (as a demonstration) at this event on January 23, 2016.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16862, '2016-02-02 22:40:45.412871+00', '2016-02-02 22:40:45.412871+00', 'Stafford Five-Oh', 'STAFFORD FIVEOH', 1, 40, NULL, 3, 5, 7, 10998, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18408, '2018-07-16 23:47:11.568+00', '2018-07-17 22:00:07.156002+00', 'City Lights', 'CITY LIGHTS', 2, 32, NULL, 1, 3, 42, 11306, '2015-12-01', 'The dance was inspired by the excellent Charlie Chaplin film, City Lights.', 50, '800/844/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16866, '2016-02-02 22:57:54.759723+00', '2016-02-02 22:57:54.759723+00', 'Hunting Bob', 'HUNTING BOB', 1, 96, NULL, 1, 4, 3, 10998, NULL, 'Three times 32, but with slight changes each time.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4788, '1997-09-10 22:00:00+00', '2016-02-06 00:36:27.084834+00', 'Mrs Margaret Henderson', 'MRS MARGARET HENDERSON', 4, 128, 9999, 4, 4, NULL, 272, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12002, '2005-01-30 23:00:00+00', '2018-10-05 21:04:10.866773+00', 'Solway Sailor, The', 'SOLWAY SAILOR', 4, 128, 2, 1, 4, 54, 692, NULL, '', 84, '8888/7777/7777/8888/8080/0808/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16861, '2016-02-02 22:36:23.513234+00', '2017-05-31 12:46:17.40359+00', 'Pleasures of the Town, The', 'PLEASURES OF THE TOWN', 3, 32, NULL, 2, 3, NULL, 10998, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18948, '2018-10-12 14:44:44.233862+00', '2019-03-03 09:41:47.970451+00', 'Twister, The', 'TWISTER', 1, 32, NULL, 1, 3, 42, 2673, NULL, '', 56, '888/800/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17852, '2017-06-23 07:54:49.270638+00', '2018-04-03 00:07:38.905956+00', 'Coast Road, The', 'COAST ROAD', 3, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6612, '1998-11-25 23:00:00+00', '2020-08-07 09:52:06.979283+00', 'Tinker''s Reel, The', 'TINKERS REEL', 1, 48, 9999, 1, 4, 1, 82, NULL, 'The Ormskirk Memorial Edition, edited by Bob Donald, has a final page of "Notes for teachers".  On this dance it says:



In THE TINKER''S REEL, the tune is given as "Rosin the Beau". This is a JIG but the dance is given as a REEL. I have no explanation for this error, which is quite uncharacteristic of Roy. I do not feel qualified to make an alternative choice of recommended tune. Teachers should therefore make their own choice, informed by competant musicians where possible.    Bob Donald', 75, '8888  8888  8888  8888  8000  8000', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (18416, '2018-07-17 16:17:42.646626+00', '2020-08-15 09:23:40.021829+00', 'Lairig Ghru, The', 'LAIRIG GHRU', 2, 48, NULL, 6, 3, 18, 11667, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7637, '1998-01-04 23:00:00+00', '2020-09-01 15:13:40.856459+00', 'Carrick Castles', 'CARRICK CASTLES', 3, 32, 9999, 6, 118, 4, 753, NULL, 'Set shape: Triangle of three trios WMW.



Devised by Penny Gay to celebrate the 30th Anniversary of Falmouth White Heather Club in 1991 and is published in their 30th anniversary Dances booklet. The castles of Pendennis and St Mawes are situated on the headlands on either side of the Carrick Roads, the busy waterway that leads to the port of Falmouth.', 100, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18949, '2018-10-12 15:37:45.953815+00', '2020-11-22 11:03:28.181347+00', 'Howgate Reel', 'HOWGATE REEL', 1, 32, NULL, 1, 3, 42, 11726, NULL, '', 56, '800/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16867, '2016-02-02 22:59:31.607422+00', '2020-10-17 20:24:52.296953+00', 'Petit Suisse', 'PETIT SUISSE', 1, 32, NULL, 1, 4, 1, 10998, '2000-01-01', '', 62, '8000/8448/4884/0888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9563, '2001-11-21 23:00:00+00', '2021-06-29 09:33:21.614021+00', 'Roselath Cross, The', 'ROSELATH CROSS', 2, 32, 9999, 1, 3, 42, 2791, '1998-01-01', 'The Roselath Cross was devised by Henrietta Vosper of RSCDS Cornwall Branch in 1998 and is published in the RSCDS Millenium Dance Book 41 in 2000. The Roselath Cross is an old preaching cross near Lanlivery on the Saints Way which runs from Padstow on the north coast of Cornwall across the county to Fowey on the south coast. The Tune, The Roselath Cross, was composed by Kerrell Garner also of the RSCDS Cornwall Branch.



The following article by Val and John Thorne was published in London Branch''s The Reel, No 235 in February 2001:



ROSELATH CROSS



Recorded in ‘Stone Crosses in Mid Cornwall’ by Andrew Langdon and ‘Ancient Crosses of Cornwall’ by Mary Henderson as the TRETHEW CROSS, LANLIVERY. Circa 11th C. Map reference SX 07345880



WHAT is The Roselath Cross, the inspiration for the dance of that name that appears in the Millennium Book 41?



These Ancient Granite Crosses were placed as markers or prayer stops at hilltops, track junctions, etc., by early Celtic Christian Pilgrims from Ireland and Wales who crossed the Bristol Channel to the North Cornish Coast, and then walked South to Fowey where they embarked on ships for France and thence over the Pyrenees to Spain. This ancient 26 mile track across Cornwall now known as ‘THE SAINT’S WAY’ was used by Bronze and Iron Age Traders who preferred the land route from Padstow to Fowey rather than risk the dangerous waters off Lands End.



Roselath or Trethew was on Church Path between the main church at Lanlivery via the farms of Roselath and Gready to the Priory of Tywardreath a few miles from Fowey. This hilltop cross stands on the public footpath ½ mile South West of Roselath Farm.



In the early 1900s the Vicar of Lanlivery. the Rev’d W.E. Wynne discovered the head of the granite cross lying near the original base, and this was illustrated by Langdon in 1906. Despite searches in the area by various historians the shaft of the cross could not be found and was probably ‘recycled’ as a gatepost or lintel. It was considered that a new shaft would detract from the character of such an ancient cross, and therefore when it was re-erected on 11th October 1941 the Head was cemented onto the Base.



Father Wynne, who had also been responsible for the restoration of another cross in the area, visited the Trethew Cross the following day and on his return wrote:- ‘The view from the stile at Trethew repaid me for climbing the hill. The distant hills in the evening sunshine looked very beautiful, so that I was glad and elevated – in every meaning of the word’.



Access: The easiest route is to follow the signs from the A30 or A39 to the ‘EDEN PROJECT’. This is about 2 miles west of Luxulyan. Follow signs to Luxulyan and Lanlivery. One mile after Luxulyan Church the road bends sharp left, and facing you is a track, the entrance to Trethew farm, and a footpath sign ‘Lanlivery ¾ mile’. (Limited parking available at this point). Follow the waymarked footpath alongside the hedge to a stile over the Cornish bank (overgrown, secateurs useful), then cross the next field alongside the hedge, to ‘The Roselath Cross’. Continuing on towards Lanlivery the stile in the immediate area of the cross is very overgrown, and there are many brambles on the path side of the wire field fence. The stile at Roselath Farm is also somewhat overgrown, but the path improves soon after passing the Farm and the last section is well used and clear of obstructions, terminating at the road next to the pub in Lanlivery .



Roselath is the name of Henrietta Vosper’s home near Saltash (the dance devisor), but she does not know its origin.



Val and John Thorne

', 55, '886  844  844  888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (3336, '2002-02-26 23:00:00+00', '2021-01-08 21:28:17.239796+00', 'Johnnie Walker', 'JOHNNIE WALKER', 4, 128, 13, 4, 4, 3, 541, '1977-01-01', 'There used to be an online source at http://www.javastandrewsociety.com/Scottish%20Country%20Dances/johnniewalker.htm, but on checking today (2016-01-21) no SC dance descriptions could be found on that site.  Link removed.  Eric Ferguson



The correct spelling is "Johnnie Walker", but the common misspelling "Johnny Walker" has been added as an Alias.', 81, '8888  8888  8080  0808  6666  6666  8888  8888  Repeat', 1, 1, 1, 1, 40);
INSERT INTO 'dance' VALUES (95, '2002-04-19 22:00:00+00', '2018-04-03 00:07:30.183948+00', 'All Kinds of Everything', 'ALL KINDS OF EVERYTHING', 3, 32, 9999, 1, 3, 42, 44, '1978-10-01', 'Devised during October, 1978 and given to Noeline prior to her trip to Europe in 1979. The title is that of a modern song sung by the Irish folk singer Rosemary Brown. 



The ''all round poussette'' should be danced as originally described in Book 19 - see " TAC Notes on RSCDS Dances", third edition, 1986, page 3.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2355, '1998-04-21 22:00:00+00', '2018-04-03 00:07:47.155151+00', 'From The Court To The Cottage', 'FROM THE COURT TO THE COTTAGE', 4, 32, 8, 1, 3, 42, 44, '1973-01-30', 'Devised on Tuesday 30th January, 1973. The title is that of an Irish jig . 



Noeline and Iain both enjoy "Sugar Candie" from which bars 9-16 was developed.

Iain felt the name suited a medley.



Recommended tunes: 

"The Bobby Harvey Strathspey" composed by Angus Fitchet ("The Newcastle Collection of Dance Tunes", page 12), 

"A Trip to Galway" ("Dance Music of Ireland 1001 Gems " edited by Captain Francis O''Neill, page 71 , number 345), 

"Auld Luckie" ("Kerr''s Third Collection of Merry Melodies ", page 15 , number 123),

"Taladh" ("Kerr''s Third Collection of Merry Melodies ", page 31 , number 290).

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4469, '1997-04-03 22:00:00+00', '2018-04-03 00:08:04.109943+00', 'Miss Emma Cobden''s Reel', 'MISS EMMA COBDENS REEL', 1, 32, 9999, 1, 3, 42, 92, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4110, '1997-09-08 22:00:00+00', '2022-12-03 19:42:33.775555+00', 'Make Up The Quarrel', 'MAKE UP THE QUARREL', 3, 32, 9999, 1, 3, 42, 475, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9064, '1999-07-24 22:00:00+00', '2022-06-17 12:10:03.485318+00', 'Ruby Wedding, The', 'RUBY WEDDING', 2, 32, 9999, 1, 100, 2, 815, NULL, 'Devised for the occasion of Molly and Albert William’s Ruby Wedding Anniversary in York, April 1993.', 75, '8888/8008/8448/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16890, '2016-02-29 15:08:36.408449+00', '2023-01-14 16:08:14.617736+00', 'Real Gem, A', 'REAL GEM', 3, 32, NULL, 4, 4, 1, 11237, '2015-06-01', 'Dedicated to Patrick Brunskill



', 87, '8080/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16895, '2016-03-05 16:12:05.819292+00', '2016-03-06 21:08:42.984511+00', 'Crimson Clover', 'CRIMSON CLOVER', 3, 32, NULL, 2, 3, 17, 3110, NULL, 'This dance is also known as an English Country Dance, and published in the authors'' volume "Impropriety Volume lV".1', 79, '840/888/448/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18329, '2018-05-03 08:12:58.081134+00', '2018-05-20 06:34:41.058874+00', 'Wild Heather', 'WILD HEATHER', 2, 32, NULL, 1, 3, 42, 11139, '2014-02-21', 'The dance has been written in recognition of the Wild Heather Band. The musicians are Sharlene Penman, Lynne Scott, Anne-Marie Forsyth and Mary McDonald.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16922, '2016-04-15 19:29:09.664888+00', '2018-08-12 14:48:23.721228+00', 'Smoke and Mirrors', 'SMOKE AND MIRRORS', 1, 32, NULL, 1, 2, 76, 10640, NULL, '', 68, '88/88/88/88', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16923, '2016-04-15 19:38:09.152488+00', '2018-08-12 14:53:27.100195+00', 'St Vincents Close', 'SAINT VINCENTS CLOSE', 1, 32, NULL, 1, 100, 2, 10640, NULL, '', 93, '8448/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16924, '2016-04-15 19:46:06.70856+00', '2018-08-12 14:59:41.77896+00', 'Welcome to Cambridge', 'WELCOME TO CAMBRIDGE', 3, 32, NULL, 1, 3, 42, 10640, NULL, '', 49, '840 804 880 888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16938, '2016-04-26 11:36:26.112533+00', '2016-04-27 14:19:49.360976+00', 'Julia and Bob''s Petal Dance', 'JULIA AND BOBS PETAL DANCE', 1, 48, 9999, 4, 5, 38, 11249, '1996-07-01', 'The dance was devised for the wedding of Julia Kelemen and Robert Finan on 14/07/1996 in Dundee.



According to the memories of those involved, the petals reels are danced right shoulder to maximise flow.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14593, '2012-10-13 20:58:47.563594+00', '2016-05-10 22:20:47.349665+00', 'Two for Three', 'TWO FOR THREE', 4, 128, 2, 107, 1, NULL, 228, '2005-07-29', 'Anselm says: »Written for the wedding of Kirsten Lubach and Marco Schütz, in Vienna, on 30 June 2005. Eva Schiedrum and I were originally going to perform <<ddd:Triple Treat>> but the third person had to cancel on very short notice due to a family emergency – hence we had to rewrite that dance in a hurry to work with only two people! We performed it again on two other occasions within two months, hence the title, ›Two for Three‹ (two dancers for three audiences).«', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11715, '2004-04-01 22:00:00+00', '2016-05-18 08:08:58.318288+00', 'Nifty Fifty', 'NIFTY FIFTY', 3, 32, 9999, 107, 3, 17, 1042, '2003-01-01', 'Danced in a square-like shape with 3 couples set up as follows: 1st man at top, 2nd couple next round clockwise, 1st lady in ''3rd place'', and 3rd couple next position opposite 2nd couple.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3008, '2003-04-02 22:00:00+00', '2016-05-18 16:23:32.819803+00', 'Bowling Ball Reel, The', 'BOWLING BALL REEL', 1, 64, 9999, 107, 126, NULL, 3333, '2003-01-01', 'Dance for 11 persons. 10 pins and one ball.

While this dance has been devised as a joke, there has been sufficient thought in its construction to merit it being listed here.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16259, '2015-05-04 11:06:18.208168+00', '2016-05-18 16:26:31.964776+00', 'Copthorne Steamie, The', 'COPTHORNE STEAMIE', 2, 40, 9999, 107, 111, 2, 2865, '2012-01-01', 'A 40-bar jig for 4½ couples in a longwise set.  (the ½ stands at the top of the set as the “Umbrella” with a small part-filled laundry basket )', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16927, '2016-04-15 22:18:33.6045+00', '2018-12-06 16:23:37.548326+00', 'Marja''s Buns', 'MARJAS BUNS', 4, 96, 11, 4, 6, 3, 10648, '2013-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16926, '2016-04-15 20:58:42.019318+00', '2019-08-25 20:37:35.39858+00', 'Bottoms Up!', 'BOTTOMS UP', 1, 32, NULL, 1, 3, 30, 108, '2006-02-01', '2s, 3s & 4s begin. After 32 bars order is 1243. 1s, 2s & 4s repeat finishing 1432 and 1s & 4s change places to 4132 and 1s, 3s and 2s begin 3rd time through.', 63, '888/888/008/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16886, '2016-02-29 01:34:24.439967+00', '2018-12-17 11:18:33.275695+00', 'Pentamime', 'PENTAMIME', 2, 32, NULL, 3, 5, 16, 11237, '2015-04-01', '', 80, '82842/88808/84884/88888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16868, '2016-02-10 14:01:30.671906+00', '2016-02-10 14:05:55.649143+00', 'Dance for Helen, A', 'DANCE FOR HELEN', 4, 32, 5, 1, 3, 42, 316, NULL, 'Video found on Youtube; this is up to now the only source for this dance entry.  Probably the dance has been published as a leaflet



Danced from first place as Strathspey, from second as Reel.  4 times through.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4489, '1997-04-03 22:00:00+00', '2020-08-07 03:46:03.53256+00', 'Miss Grant of Elchies', 'MISS GRANT OF ELCHIES', 3, 32, 9999, 1, 3, 42, 129, NULL, '', 56, '800/880/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14294, '2011-11-03 23:00:00+00', '2020-09-27 09:12:13.593313+00', 'Miss Jeanetta McColl', 'MISS JEANETTA MACCOLL', 1, 32, 9999, 1, 3, 42, 316, '2007-07-01', 'This dance and tune, devised as an auction item at Pinewoods camp 2007, is dedicated to Miss Jeanetta McColl who has been central to the life and growth of Boston Branch RSCDS over many years.', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2632, '2000-06-12 22:00:00+00', '2021-04-07 20:29:22.717067+00', 'Grampian Strathspey, The', 'GRAMPIAN STRATHSPEY', 3, 32, 9999, 4, 4, 46, 9998, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16925, '2016-04-15 19:57:11.222377+00', '2021-07-30 06:16:31.209088+00', 'Marian''s Reel', 'MARIANS REEL', 1, 32, NULL, 1, 3, 42, 308, '2009-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7559, '1997-12-03 23:00:00+00', '2016-02-12 22:27:57.134277+00', 'Lowpin Lizards', 'LOWPIN LIZARDS', 2, 32, 9999, 1, 3, 42, 63, '2003-07-29', 'Dedicated to Gordon and Ria Skilling on the occasion of their Silver Wedding Anniversary, 29 July 2003.



The author tells us:  I originally named the dance »Leapin'' Lizards« after an outcry habitually uttered by an ancient cowboy hero in the »Eagle« comic paper which I used to get as a kid.  I later changed the name to »Lowpin Lizards« on a recommendation by Jennifer Wilson; »lowpin« (without an apostrophe) means »jumping« in Scotch.



Note:  If danced in a 3 couples longways set, on bars 25 – 28, couples 3 and 1 set and dance half right hands across, while 2nd couple set and cross over right hands. Finish with the normal bars 29-32 [circle halfway to the left].', 56, '844/880/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8666, '1998-03-31 22:00:00+00', '2016-02-12 23:24:50.96146+00', 'Dundee Lassie', 'DUNDEE LASSIE', 1, 32, 9999, 1, 3, 42, 2107, '1993-06-01', 'Devised as a farewell dance for Anne Scobie (she''s originally from Dundee) upon her move from Washington DC to Oslo, Norway.', 56, '888/800/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2833, '1997-09-03 22:00:00+00', '2016-03-18 23:06:55.937917+00', 'Heather Ale', 'HEATHER ALE', 3, 32, 9999, 2, 3, 18, 313, NULL, 'Text printed at the top of the instruction page





"From the bonny bells of heather



They brewed a drink long-syne,



Was sweeter far than honey,



Was stronger far than wine."', 71, '262/622/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4681, '1998-01-05 23:00:00+00', '2018-04-03 00:08:05.527981+00', 'Mount Gravatt Reel', 'MOUNT GRAVATT REEL', 1, 32, 9999, 1, 3, 42, 275, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16872, '2016-02-16 22:20:43.485545+00', '2016-03-05 20:26:25.143948+00', 'Triple Gold', 'TRIPLE GOLD', 2, 40, NULL, 3, 5, 16, 2789, '2006-01-01', 'Note:



This dance was devised by Ken Jones for the three 2006 Golden Wedding Anniversaries enjoyed by long time supporters of the Sheffield Branch RSCDS.



Our best wishes in dance to:



	Margaret and Brian McAteer



	Paul and Dulcie Bond



	Elsie and Gordon Burnside

', 56, '88888/04840/44844/44844/80000', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10610, '2002-06-30 22:00:00+00', '2016-02-20 12:58:46.674565+00', 'Her''st, The', 'HERST', 2, 40, 9999, 1, 3, 42, 27, '1999-01-01', '', 60, '888/888/880/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10609, '2002-06-30 22:00:00+00', '2016-02-20 13:25:01.218462+00', 'Miss Duncan''s Reel', 'MISS DUNCANS REEL', 3, 32, 9999, 2, 3, 17, 27, '1999-01-01', '', 50, '800/080/808/448', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12177, '2005-04-13 22:00:00+00', '2016-05-10 22:24:32.189911+00', 'Come Ashore Jolly Tar', 'COME ASHORE JOLLY TAR', 7, 128, 9999, 107, 51, NULL, 175, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16933, '2016-04-18 11:18:55.910515+00', '2016-04-18 11:18:55.910515+00', 'Lacing o'' the Ghillies', 'LACING O THE GHILLIES', 1, 40, NULL, 3, 5, NULL, 1848, '2008-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16921, '2016-04-15 19:16:09.024014+00', '2022-08-14 21:41:58.798727+00', 'Mayflower Jig', 'MAYFLOWER JIG', 2, 32, NULL, 1, 3, 42, 10640, NULL, '', 53, '800/822/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5788, '1997-09-13 22:00:00+00', '2022-11-12 12:21:02.456097+00', 'Safe Anchorage', 'SAFE ANCHORAGE', 2, 32, 9999, 3, 5, 7, 697, NULL, 'This dance was devised for a demonstration at ''The Anchorage'', Mudeford. 1982, in aid of the

R.B.L.I.', 60, '88880/80800/80800/80888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6584, '1997-11-25 23:00:00+00', '2016-05-14 21:45:43.518905+00', 'Threesome Of Don, The', 'THREESOME OF DON', 4, 80, 4, 105, 53, NULL, 28, NULL, '1 man between 2 women, all facing up', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8619, '1998-01-13 23:00:00+00', '2016-05-19 23:03:38.497478+00', 'Milngavie Circle', 'MILNGAVIE CIRCLE', 3, 32, 9999, 7, 113, 4, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4987, '1997-09-10 22:00:00+00', '2016-05-24 19:56:11.055591+00', 'North Star, The', 'NORTH STAR', 4, 192, 10036, 101, 3, 3, 270, NULL, 'A sixty four bar strathspey, sixty four bar reel & sixty four bar strathspey medley for three couples in a hexagonal set. The dancers form up as in a normal longwise set. On the second chord the second couple cross over giving right hand to finish on the opposite aide slightly outside the line of the set. At the same time the first man and third lady turn to face each other, and first lady and third man do the same.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16989, '2016-06-07 17:26:09.733005+00', '2016-06-07 17:26:09.733005+00', 'Vickery''s Pleasure', 'VICKERYS PLEASURE', 3, 32, 9999, 1, 4, 1, 2723, '1983-07-01', '', 94, '8880 8888 8888 8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16990, '2016-06-07 17:40:49.059935+00', '2016-06-07 17:40:49.059935+00', 'Virginia and Earl''s Reel', 'VIRGINIA AND EARLS REEL', 1, 48, 9999, 1, 3, 42, 2723, '1984-08-04', '', 74, '880 880 888 820 880 888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16991, '2016-06-07 17:52:57.329159+00', '2016-06-07 17:52:57.329159+00', 'Weekapaug Jig, The', 'WEEKAPAUG JIG', 2, 96, 9999, 4, 4, 3, 2723, '1981-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16992, '2016-06-07 18:00:26.384397+00', '2016-06-07 18:00:26.384397+00', 'Yankee Delight', 'YANKEE DELIGHT', 2, 40, 9999, 1, 3, 42, 2723, NULL, '', 67, '888 800 800 844 888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16985, '2016-06-07 16:51:52.629105+00', '2016-06-07 18:22:42.064484+00', 'Sackville Circle, The', 'SACKVILLE CIRCLE', 3, 48, 9999, 3, 5, 16, 2723, '2013-08-01', '', 76, '88882 88088 48884 48884 81111 88888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16994, '2016-06-07 19:10:59.075775+00', '2016-06-07 19:10:59.075775+00', 'Pompositticut Strathspey, The', 'POMPOSITTICUT STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2723, NULL, '', -1, '888 888 880 880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16998, '2016-06-07 21:34:34.996584+00', '2016-06-07 21:35:01.481262+00', 'Celestial Perturbations', 'CELESTIAL PERTURBATIONS', 1, 32, NULL, 2, 3, 17, 2408, NULL, 'Devised: 2016-05



Devised May 2016 by Lara Friedman-Shedlov for Audrey Salo, a Twin Cities dancer and lover of astronomy, on the occasion of her leaving Minneapolis to attend college at the University of California, Berkeley.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4719, '1997-04-03 22:00:00+00', '2018-04-03 00:08:05.944632+00', 'Mr Piping', 'MR PIPING', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16870, '2016-02-12 20:31:19.564911+00', '2018-09-19 09:43:16.601661+00', 'Belt ''n Braces', 'BELT N BRACES', 2, 32, NULL, 1, 2, NULL, 63, '2000-01-01', '', 100, '88/88/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12669, '2006-02-02 23:00:00+00', '2019-02-05 22:09:52.443681+00', 'Kamo Karousel', 'KAMO KAROUSEL', 2, 32, 9999, 1, 3, 42, 411, '2004-01-01', '', 62, '844/844/888/888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (14435, '2012-05-09 13:32:57.360291+00', '2018-04-03 00:07:36.077067+00', 'Buckie Loon, The', 'BUCKIE LOON', 1, 32, 9999, 1, 3, 42, 2672, NULL, 'Dance devised by Bill Zobel and Muriel Johnstone as a tribute to Alex Jappy of Delta, Vancouver, who has provided music for Ruth and given pleasure to so many dancers over a great many years. It has to be said however that the elocution lessons have had no effect whatever ~ Alex still sounds very much a ''Buckie Loon''.', 56, '844/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10535, '2002-10-15 22:00:00+00', '2018-10-22 05:56:02.871391+00', 'Napier''s Index', 'NAPIERS INDEX', 2, 40, 9999, 1, 3, 42, 74, '2001-01-01', '##>>

This dance is dedicated to Keith Napier of Australia who, for many years, has maintained a computerised index of Scottish Country Dances. This index was one of the original building blocks of Alan Paterson’s Dance Data which is now incorporated in the Strathspey website.

##<<', 55, '800  844  888  844  888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (16883, '2016-02-25 00:54:25.012194+00', '2020-10-17 20:44:12.491875+00', 'Jessie Stuart of Dufftown', 'JESSIE STUART OF DUFFTOWN', 1, 32, NULL, 1, 3, 42, 3379, NULL, 'Jessie, originally from Dufftown, is known all over the world for teaching both Scottish Country and Old Time Dancing.', 53, '800/844/866/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16891, '2016-03-01 00:16:13.466525+00', '2020-10-17 20:51:19.605999+00', 'Silver Dancers, The', 'SILVER DANCERS', 1, 40, NULL, 3, 5, 35, 11238, '2007-06-01', '', 67, '08008/48848/48848/48848/28228', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16874, '2016-02-25 00:23:17.801246+00', '2016-02-25 00:23:17.801246+00', 'Borough Briggs', 'BOROUGH BRIGGS', 1, 32, NULL, 3, 5, 10, 3379, NULL, 'For the Elgin City Dance Club who met at Borough Briggs,

the home of Elgin City Football Club.







Bars		Description



1 – 8	2nd and 4th couples petronella turn to face partners up and down the set; set to partners and turn right hand once round to finish with 2nd woman facing 1st woman, 2nd man facing 3rd man, 4th woman facing 3rd woman and 4th man facing 5th man.  2nd man and 4th woman are back to back.



9 – 16	2nd woman dances a reel of three with 1st couple as 4th man dances a reel of three with 5th couple while 2nd man and 4th woman dance a reel of four with 3rd couple.  All pass right shoulders to begin the reels.  2nd man and 4th woman pass right shoulders on bars 15 and 16.



17 – 18	2nd and 4th couples pass the person they are facing right shoulder and cast off or up to original places (man cast up, women cast off).



19 – 22	2nd and 4th couples turn right hand once round.



23 – 24	2nd and 4th couples cast off once place.  3rd and 5th couples step up.



25 – 30	1st and 3rd couples together and 2nd and 5th couples together dance ¾ rights and lefts and stay facing out.



31 – 32	3rd, 1st, 5th and 2nd couples set while pulling right shoulder back to finish facing in.  Finish 3, 1, 5, 2, 4.





Repeat from new positions.



', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16875, '2016-02-25 00:26:53.320732+00', '2016-02-25 00:26:53.320732+00', 'Jimmy Allan''s Rant', 'JIMMY ALLANS RANT', 4, 32, 5, 2, 3, 17, 3379, NULL, 'To celebrate the 90th birthday of Jimmy Allan of Westhill





Bars		Description



1 – 8	1st and 2nd couples set, cross over giving right hands and dance on two places clockwise to finish 2, 1, 3.  1st man stays facing out in second place.



9 – 12	2nd, 1st and 3rd couples dance half a reel of three on the sides.  To begin 1st and 2nd couples pass right shoulders.



13 – 16	3rd, 1st and 2nd couples set then turn partners rights hand to finish in the middle of the set facing up.



17 – 24	3rd, 1st and 2nd couples dance a three couple allemande.  On bars 23 and 24 the 1st couple cast off to third place while the 3rd couple dance up to second place.



25 – 32	2nd, 3rd and 1st couples advance, retire and turn partners with the right hand once round.  Finish 2, 3, 1.





Dance three times through in Strathspey time

then three times through in Reel time.



', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16060, '2015-02-14 14:53:16.488106+00', '2016-05-10 23:28:26.581129+00', 'Ruby Wedding', 'RUBY WEDDING', 3, 64, 9999, 1, 4, 1, 11079, NULL, 'Devised by Richard Donaldson, Victoria Branch, and dedicated to his wife, Elaine, to celebrate their 40th wedding anniversary.



Dance either all 64 bars, or repeat bars 1-32 having passed a couple.  In that case the dance becomes S 3/4L with progression is (213).

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16160, '2015-03-13 16:34:28.677884+00', '2017-05-31 10:39:17.443517+00', 'Mayor and Her Secretary, The', 'MAYOR AND HER SECRETARY', 2, 32, NULL, 1, 3, 42, 10612, '2014-01-01', 'Devised  for the retirement celebration of Elke Szepanski, Mayor of Hatten from 2006 till 2014 having joined the “Potters Pairs” in 2013.



In the original form, the lead-change Fig8 for bars 1-8 was too tight in a crowded hall.  After some discussion Martin McWilliam wrote to me on 2016-02-23 : "Hi Eric, We have made a decision : ) . The best is just to scrap the "lead change parallel", so that 1M leads 1W all through the Fig8.  Then it all works very well."  At Martin''s request both crib and diagram now show the "no lead change" Fig8.





', 34, '800/822/822/822', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16903, '2016-03-09 08:46:13.236079+00', '2017-05-31 12:47:43.220214+00', 'Hoy Tensome, The', 'HOY TENSOME', 1, 40, NULL, 4, 5, 6, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16905, '2016-03-16 19:38:34.498654+00', '2018-04-02 23:56:36.94652+00', 'Palisades Mermaid', 'PALISADES MERMAID', 1, 32, NULL, 1, 3, 42, 1167, '2015-06-07', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5989, '1997-09-17 22:00:00+00', '2016-03-16 23:16:15.888784+00', 'See You Again', 'SEE YOU AGAIN', 1, 32, 9999, 5, 2, NULL, 1265, '1984-01-01', 'Reel or Jig: the instructions say this dance can be danced as either.

', 75, '88/80/08/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16880, '2016-02-25 00:43:29.785586+00', '2016-02-25 00:43:29.785586+00', 'Hippies, The', 'HIPPIES', 1, 32, NULL, 1, 3, 42, 3379, NULL, 'Devised for all those from the ‘swinging sixties’ who are now having hip replacements!





Bars		Description



1 – 8	1st and 2nd couples set and dance right hands across half way.  1st couple turn right hand to join up in balance in line position with first corners.



9 – 16	1st couple and 1st corners balance in line then 1st couple turn 1st corners with the left hand.  1st couple dance half a figure of eight with 1st woman dancing down between 3rd couple and 1st man dancing up between 2nd couple.  1st couple come in to join left hand with partner and right hand with 4th corners.



17 – 24	1st couple and 4th corners balance in line then 1st couple turn 4th corners with the right hand.  1st couple dance half a figure of eight with 1st woman dancing down between 3rd couple and 1st man dancing up between 2nd couple.



25 – 32	1st and 2nd couples dance half a double figure of eight.  To begin 1st couple cross up and 2nd couple dance down.  1st man turns 3rd man right hand once round while 1st woman turns 3rd woman left hand once round.





Repeat having passed a couple.





Note – At the end of the second time through the 1st couple turn the 3rd couple one and a half times to take them to the end of the set.



', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11384, '2003-07-06 22:00:00+00', '2018-04-03 00:08:07.946459+00', 'Norah''s Gold Stars', 'NORAHS GOLD STARS', 3, 32, 9999, 1, 3, 42, 48, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16879, '2016-02-25 00:40:59.793757+00', '2021-03-30 19:50:51.847988+00', 'Fotheringhame Fling, The', 'FOTHERINGHAME FLING', 1, 32, NULL, 1, 4, 1, 3379, NULL, '

Devised for Billy and Lana Fotheringhame to thank them for all their hospitality and friendship during the Orkney Ceilidh Weekend.









Bars	Description



1 – 8	All 4 couples dance 8 hands round and back.



9 – 16	1st couple dance in front of the 2nd couple, behind the 3rd couple, in front of the 4th couple then dance up behind their own lines back to place.



17 - 24       	1st and 2nd couples dance half right hands across (1st woman stay facing out); 1st and 3rd couples dance half left hands across (1st woman stay facing out); 1st and 4th couple dance half right hands across; all 4 couples cross over right hand.



25 - 32       	All 4 couples advance for 2 and retire for 2.  All 4 couples put right hands round partrer''s waist and join left hands above heads and spin partners for 4 bars.





Repeat with a new top couple.



', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16885, '2016-02-29 01:27:57.298768+00', '2021-05-06 23:30:53.74443+00', 'Ompredena', 'OMPREDENA', 2, 32, NULL, 1, 102, 11, 11237, '2014-05-01', '', 93, '8888 8888 8888 4884 ', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4800, '2002-04-19 22:00:00+00', '2021-07-28 08:13:10.054645+00', 'Mrs Shore''s Strathspey', 'MRS SHORES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 595, '1989-01-01', 'This dance is inscribed to Mrs. Jone Shore, in gratitude for her dedication to teaching Scottish Country Dance, and most of all for sharing with us her joy of life.  

Devised by Charles Ryer, March 1989.  

Recommended Music: The MacPhersons of Edinburgh. "Scottish Dance Time", Volume 3.', 50, '880/880/088/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14643, '2013-01-05 07:35:55.288746+00', '2016-02-28 11:41:08.680291+00', 'General Murray''s Reel', 'GENERAL MURRAYS REEL', 1, 32, NULL, 1, 3, 42, 1500, '2010-01-01', 'Recommended Tune: Duke John, by Niel Gow. Written for John Murray (1729-1774) who became the 3rd Duke of Atholl; he was the eldest son of Lord George Murray.



Devised to commemorate the 250th anniversary of the death of General Lord George Murray, a Scottish Jacobite general, most noted for his 1745 campaign under Bonnie Prince Charlie into England. Born 4 October 1694, he was the sixth son of John Murray, 1st Duke of Atholl. 



After the defeat at Culloden in 1745 he escaped to the European continent where he lived in numerous places. The last few years of his life he lived in Medemblik, Holland where he died on 11 October 1760. He is buried in the Church of St. Boniface in Medemblik.    

', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (18311, '2018-05-01 20:08:47.353758+00', '2018-05-03 00:04:43.836827+00', 'To Friends', 'TO FRIENDS', 3, 32, NULL, 4, 4, 13, 10371, '2014-01-01', 'Devised by Irene Townshend - My gratitude and thanks to Tim Wilson for help in pulling this dance together also to Ruth Jappy and Tim for secretly testing out the dance.  



In honour of special friends Louise Lattimore and Linda McGaw, two vibrant members of the Edmonton Caledonian Branch, in celebrating their special birthdays this year.  



Presented at the Edmonton Caledonian Workshop February 2014. ', 88, '8080/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16946, '2016-05-15 20:33:02.995358+00', '2018-04-03 00:07:50.50827+00', 'Halswell Reel', 'HALSWELL REEL', 1, 40, NULL, 1, 3, 42, 11258, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16944, '2016-05-15 20:24:07.327743+00', '2016-05-15 20:24:07.327743+00', 'Diamond Quail', 'DIAMOND QUAIL', 1, 40, NULL, 1, 4, 1, 11257, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16948, '2016-05-15 20:42:30.160017+00', '2018-04-03 00:08:05.627752+00', 'Mr David Deans', 'MR DAVID DEANS', 1, 32, NULL, 1, 3, 42, 11259, NULL, 'Dedicated to Mr David Deans on his 80th birthday.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8745, '1998-10-15 22:00:00+00', '2016-05-12 23:22:26.666671+00', 'Seann Triubhas', 'SEANN TRIUBHAS', 7, 32, 9999, 107, 51, NULL, 9998, NULL, 'Pronounced (approximately) “Shorn Troos”.



See the “Extra Info” on <<ddd:Seann Triubhas Willichan>> for a discussion of the spelling of “Triubhas” vs. “Truibhas”. (TL;DR: “Triubhas” is correct.)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16942, '2016-05-15 20:14:28.402164+00', '2016-05-15 20:14:39.994708+00', 'Avenues, The', 'AVENUES', 3, 32, NULL, 4, 4, 1, 11255, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16943, '2016-05-15 20:18:29.05036+00', '2016-05-15 20:18:29.05036+00', 'Dean Castle', 'DEAN CASTLE', 3, 32, NULL, 1, 3, 42, 11256, NULL, 'Dean Castle in Kilmarnock, Ayrshire is the ancestral home of the Boyd family.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16945, '2016-05-15 20:28:10.807886+00', '2016-05-15 20:28:10.807886+00', 'Downing Street', 'DOWNING STREET', 2, 32, NULL, 1, 3, 42, 11256, NULL, 'This refers to Downing Street in Christchurch, New Zealand', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2705, '1997-09-03 22:00:00+00', '2018-05-03 08:05:01.401047+00', 'Gunn Of Kilearnan', 'GUNN OF KILEARNAN', 3, 32, 9999, 1, 3, 42, 275, NULL, '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16947, '2016-05-15 20:36:48.88436+00', '2016-05-15 20:36:48.88436+00', 'Hoons of Hay, The', 'HOONS OF HAY', 2, 40, NULL, 1, 4, 1, 3261, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16950, '2016-05-15 20:58:11.869536+00', '2016-05-15 20:58:11.869536+00', 'Riccarton House', 'RICCARTON HOUSE', 3, 32, NULL, 1, 4, 1, 3260, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16951, '2016-05-15 21:00:31.657554+00', '2016-05-15 21:00:31.657554+00', 'Ten Years On', 'TEN YEARS ON', 3, 32, NULL, 1, 3, 42, 11259, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16949, '2016-05-15 20:55:55.074675+00', '2016-05-15 20:55:55.074675+00', 'Pigeon Pie', 'PIGEON PIE', 2, 32, NULL, 1, 3, 42, 3260, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1802, '1998-04-08 22:00:00+00', '2016-05-15 23:14:14.954057+00', 'Dumfries Flirtation, The', 'DUMFRIES FLIRTATION', 4, 96, 11, 105, 53, NULL, 200, NULL, 'Medley for one man and two women, starting with the man between the women, ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16901, '2016-03-06 11:20:10.47454+00', '2019-07-31 21:43:51.082934+00', 'Lass from Brittany, The', 'LASS FROM BRITTANY', 1, 40, NULL, 1, 3, 42, 11239, '2013-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (928, '1997-04-03 22:00:00+00', '2016-05-19 23:11:40.730432+00', 'Calabria', 'CALABRIA', 1, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16415, '2015-05-30 18:49:20.504251+00', '2018-04-03 00:18:02.472671+00', 'Summer Festival', 'SUMMER FESTIVAL', 3, 32, 9999, 2, 2, 76, 2018, '2011-01-01', 'Could be danced in strathpey or reel time', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10698, '2002-07-21 22:00:00+00', '2020-07-17 19:12:20.663704+00', 'Last Exit to Soquel', 'LAST EXIT TO SOQUEL', 2, 32, 9999, 1, 3, 42, 2961, '1999-01-01', 'Note: The name Soquel is usually mispronounced (it''s pronounced Sokell). The tongue-in-cheek title refers

to the one and only exit from the freeway to Soquel.  Down that road a bit, you can find the Soquel Class

most Friday nights. This dance was devised with fellow teacher Paula Jacobson as a good way to teach reels

to beginnen.', 44, '800/888/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10699, '2002-07-21 22:00:00+00', '2020-09-11 08:54:59.063594+00', 'Lover''s Track', 'LOVERS TRACK', 2, 32, 9999, 1, 3, 42, 2961, '1994-01-01', 'Dance Notes: Bars 7 & 8 will help new men or women dancers dancing as men to think of the direction

needed to travel into a ladies'' chain.', 52, '820/880/888/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16784, '2015-10-06 00:59:44.10959+00', '2020-10-17 15:16:41.95281+00', 'Tutsham Mill', 'TUTSHAM MILL', 2, 40, NULL, 1, 4, 1, 10995, '2008-01-01', 'All couples dance twice, from the top, so the dance is 8 x 40. ', 55, '8000/8800/8880/8880/8440', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12364, '2005-04-27 22:00:00+00', '2021-01-15 10:52:29.308873+00', 'Ogden of Greenhow', 'OGDEN OF GREENHOW', 1, 32, 9999, 1, 3, 42, 223, NULL, 'Published in The Leeds Branch Newsletter, Issue 36, 2004 (http://www.rscdsleeds.org.uk/newsletters.htm)', 53, '800/888/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4366, '1998-04-12 22:00:00+00', '2021-05-08 20:07:31.688348+00', 'Midsummer Madness', 'MIDSUMMER MADNESS', 2, 32, 9999, 1, 3, 42, 108, '1994-06-01', 'For the midsummer "Day of Dance" at Causewayhead, Stirling in 1994.', 63, '880/880/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3787, '1998-01-04 23:00:00+00', '2021-05-15 11:30:10.452435+00', 'Let''s Meet Again', 'LETS MEET AGAIN', 1, 32, 9999, 1, 3, 42, 59, NULL, 'Devised by Romaine Butterfield for the Tawa Scottish Country Dance CIub.', 38, '840/804/800/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6242, '1997-08-25 22:00:00+00', '2018-05-03 17:42:37.110263+00', 'Spinney Strathspey, The', 'SPINNEY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 530, '1983-01-01', 'This dance has also been published in Dunedin Dances Book 1.', 66, '888/884/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5069, '2003-01-30 23:00:00+00', '2018-04-03 00:08:08.646961+00', 'Old Tram Car, The', 'OLD TRAM CAR', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8775, '1998-10-20 22:00:00+00', '2016-03-22 22:06:19.261026+00', 'Founders'' Reel', 'FOUNDERS REEL', 1, 48, 9999, 1, 4, 1, 50, '1998-01-01', '"A 48 bar reel for three couples. This dance was devised to honor the founders of the Los Angeles Branch.

RSCDS at its Silver Anniversary. David B. Brandon was the organiser and Founding Chairman. C. Stewart

Smith was the inspiration and teacher extraordinaire."



The official description tells 1c to finish in 4pl and 3c+4c to step up (2,3,4,1).  That makes it a 4C dance, contradicting the initial statement above.  ', 49, '8000/8640/8880/8440/8000/8444', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11298, '2003-05-06 22:00:00+00', '2018-07-08 01:39:54.894168+00', 'Pat''s Piano', 'PATS PIANO', 1, 40, 9999, 1, 3, 42, 734, '1994-01-01', 'Devised approximately ten years ago by Junior Member, Lesley Higgs, for Pat Clark and included in this book with grateful thanks, for all the beautiful music she has produced to compliment these dances.  



Music for this dance composed by 16yr old Lyndsey Walsham', 53, '888/880/800/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16919, '2016-04-15 18:56:10.588659+00', '2019-09-15 00:14:07.704262+00', 'Do Not Apologise', 'DO NOT APOLOGISE', 2, 32, NULL, 1, 3, 42, 10640, NULL, '', 62, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18410, '2018-07-17 00:14:31.288961+00', '2018-07-18 03:18:12.287703+00', 'Ysobel Stewart of Fish Hoek', 'YSOBEL STEWART OF FISH HOEK', 3, 32, NULL, 1, 3, 42, 347, '2016-10-01', 'In 1955, Mrs Ysobel Stewart (co-founder of the RSCDS) moved to South Africa, where she found the climate more agreeable to her rheumatism. During a trip to Cape Town, the deviser visited the suburb of Fish Hoek (also known as Vishoek) where Mrs Stewart lived.

', 53, '880/844/844/866', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16918, '2016-04-15 17:20:59.466149+00', '2018-08-12 14:28:15.092309+00', 'Cherry Blossom Season', 'CHERRY BLOSSOM SEASON', 2, 32, NULL, 1, 3, 42, 10640, NULL, '', 49, '888/800/888/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16908, '2016-04-08 01:47:42.89288+00', '2016-04-08 01:53:42.36282+00', 'Elegant Cranes Strathspey', 'ELEGANT CRANES STRATHSPEY', 3, 32, NULL, 2, 3, 18, 651, NULL, '', 92, '888/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3071, '1997-09-04 22:00:00+00', '2016-04-14 08:27:52.370862+00', 'In Acadia', 'IN ACADIA', 2, 32, 9999, 1, 2, NULL, 108, '1986-01-01', 'Devised for Jean Paul Bourgeois, currently of Montreal formerly of New Brunswick.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16912, '2016-04-15 16:24:17.985393+00', '2018-10-03 10:03:21.502019+00', 'Covered By Autumn Leaves', 'COVERED BY AUTUMN LEAVES', 1, 32, NULL, 1, 3, 42, 2766, '2009-10-01', 'Suggested music is The Cumbrae Reel from Scottish Country Dance Favourites, Volume 2.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12382, '2005-04-28 22:00:00+00', '2016-05-12 23:21:24.22145+00', 'Royal Highland Fusilier, The', 'ROYAL HIGHLAND FUSILIER', 7, 96, 9999, 107, 51, NULL, 175, NULL, 'Also published by Scottish Dance Archives in September 1973 as dance H2', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16773, '2015-09-29 10:25:56.213803+00', '2016-06-03 14:03:21.455513+00', 'One of the Best', 'ONE OF THE BEST', 3, 32, NULL, 1, 2, 76, 228, '2015-09-29', 'For Gisela Koehne of Ettlingen, Germany, on the occasion of her significant birthday in October, 2015.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16910, '2016-04-14 13:28:53.924327+00', '2017-12-17 16:44:06.471692+00', 'Austin Quicksilver', 'AUSTIN QUICKSILVER', 1, 32, NULL, 3, 5, 7, 2924, '2001-01-01', 'This is a quicktime variant of Austin Silver.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8856, '1998-11-26 23:00:00+00', '2016-04-15 23:03:46.627955+00', 'Kuckucksnest Special', 'KUCKUCKSNEST SPECIAL', 1, 32, 9999, 3, 5, NULL, 2113, '1998-06-01', 'This dance was devised in Summer 1998 by Carola Fischer (once Tress) to celebrate the tenth anniversary of the Kuckucksnest (Cuckoo''s Nest - <<http://www.kuckucksnest.com/engl/>>).



In this dance couples 2 and 4 are the dancing couples. The dance ''changes sides'' every second time through. That means, the 2nd and 4th time though top and bottom changes, people start from the opposite side and performing every movement with the left shoulder, left hand, etc. Just the 5-couple poussette is danced the same way, changing the (original) top couple to the bottom. 



The 5-couple poussette is described as follows:

Couples 2 to 5 dance the 2nd couple''s part of a poussette, 1st couple dance out and turn on bar 1, dance down on bars 2-4, down and turn on 5, then all turn half way round on bar 6. On bars 7 + 8 pass right shoulders and dance out to opposite sides with two skip-change. (Except in the 5th time through, where couples dance a ''normal'' fall back.)



As music the deviser suggests recordings of The Plantation Reel.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16936, '2016-04-18 12:44:31.686691+00', '2018-09-19 09:59:21.894966+00', 'Snod''s Edge', 'SNODS EDGE', 2, 32, NULL, 3, 5, NULL, 550, '2006-09-01', 'Written for the wedding of Geraldine McIvor and Gordon “Snod” Simpson in Edinburgh on 16th September, 2006.  Snod’s Edge is a village in the North East of England.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16346, '2015-05-17 10:54:41.620396+00', '2018-04-03 00:18:02.078758+00', 'Dance She Grac''d, A', 'DANCE SHE GRACD', 3, 32, 9999, 2, 2, 76, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16934, '2016-04-18 11:46:46.217062+00', '2022-12-16 11:14:35.748349+00', 'Go West', 'GO WEST', 1, 32, NULL, 5, 2, NULL, 11248, NULL, '', 100, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15747, '2015-01-10 11:23:25.430081+00', '2022-04-28 09:07:35.577057+00', 'Bragar Lass', 'BRAGAR LASS', 3, 32, 9999, 2, 2, 76, 11041, '2008-03-31', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3776, '1997-04-03 22:00:00+00', '2022-12-10 19:25:46.377307+00', 'Leprechaun, The', 'LEPRECHAUN', 2, 32, 9999, 1, 3, 42, 44, '1969-04-06', 'Devised for Noeline on Sunday 6th April, 1969 during a weekend school in Christchurch conducted by Alec Hay.



Suitable recorded music is the 32 bar <<http://my.strathspey.org/dd/recording/2949/|Jig medley>> on Bobby MacLeod''s "<<http://my.strathspey.org/dd/album/273/|Complete Scottish Dance Master>>".', 44, '800/840/804/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16932, '2016-04-18 11:07:30.868422+00', '2022-08-01 20:44:07.240846+00', 'Toggled', 'TOGGLED', 2, 32, NULL, 1, 3, 42, 558, '2006-04-25', 'Dedicated to Gundula Barth for her 30th birthday', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14655, '2013-01-05 11:19:00.732154+00', '2022-12-19 19:29:00.168515+00', 'Shuttlecock, The', 'SHUTTLECOCK', 2, 32, NULL, 1, 3, 42, 1043, '1990-01-01', 'From unknown source:  This dance may have been published in a Leaflet "The Davies Jubilee Dance". ', 62, '888/888/880/844', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (3174, '1997-09-04 22:00:00+00', '2022-12-26 00:37:52.750416+00', 'Jacaranda Tree, The', 'JACARANDA TREE', 1, 32, 9999, 1, 4, 1, 359, '1986-05-01', '', 47, '8080/4444/8044/8400', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16408, '2015-05-30 17:34:50.730526+00', '2016-04-19 06:18:23.665929+00', 'Triomphe, La', 'TRIOMPHE', 1, 24, 9999, 1, 4, 1, 2018, '2011-01-01', 'The devisers call this a 2 couple dance, as only 1c+2c are actually dancing.  But as 1c casts to the bottom at the end, the progression is (2341), and this has to be classified as a 4 couple dance in the database.  ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3170, '2000-08-01 22:00:00+00', '2018-02-27 11:34:49.888829+00', 'Izayoi', 'IZAYOI', 3, 32, 9999, 1, 3, 18, 843, '1993-10-01', 'After the second time through the positions are (3,4,1,2); 1c then steps down to (3,4,2,1).  8 times through in all finishes in (1,2,3,4)', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11436, '2003-09-14 22:00:00+00', '2016-04-20 06:02:05.437423+00', 'Road to Montgomery, The', 'ROAD TO MONTGOMERY', 2, 32, 9999, 2, 3, 17, 3371, '2003-01-01', 'This dance was devised to teach reels of four.  The deviser wrote it to be danced either in a 3-couple set (as shown here) or in a 4-couple set (4C/4L), four times through. For that, on [27-28] 1c cast off to 4pl (4c up).  Progression 2341.', 50, '800/844/844/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8446, '1997-12-28 23:00:00+00', '2016-05-10 20:31:43.912735+00', 'Orange and Blue', 'ORANGE AND BLUE', 3, 32, 9999, 1, 4, 1, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16937, '2016-04-18 15:08:16.918331+00', '2018-04-03 00:07:55.411714+00', 'Jig for Doris, A', 'JIG FOR DORIS', 2, 32, NULL, 1, 3, 42, 3626, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11087, '2002-12-05 23:00:00+00', '2018-04-03 00:08:10.278574+00', 'Penkill Castle', 'PENKILL CASTLE', 2, 32, 9999, 1, 3, 42, 3117, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18333, '2018-05-04 22:33:27.824438+00', '2019-02-19 15:49:02.150179+00', 'Glenburn Strathspey, The', 'GLENBURN STRATHSPEY', 3, 32, NULL, 1, 3, 42, 3699, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1227, '1997-04-03 22:00:00+00', '2018-05-29 18:02:10.6996+00', 'Clatteringshaws', 'CLATTERINGSHAWS', 1, 32, 9999, 1, 2, 76, 129, NULL, '', 55, '44/66/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16931, '2016-04-18 10:53:15.094262+00', '2018-08-12 15:07:52.304946+00', 'World Turned Upside Down, The', 'WORLD TURNED UPSIDE DOWN', 2, 32, NULL, 1, 110, 30, 11245, NULL, '', 49, '800/888/844/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18332, '2018-05-04 22:27:11.391474+00', '2019-01-30 11:36:29.453887+00', 'Nan''s Jig', 'NANS JIG', 2, 32, NULL, 1, 4, 2, 3699, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8222, '1997-12-28 23:00:00+00', '2018-04-03 00:07:29.740593+00', 'After the Trial', 'AFTER THE TRIAL', 2, 32, 9999, 1, 3, 42, 35, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10575, '2002-12-05 23:00:00+00', '2016-05-04 21:44:45.492536+00', 'Small Gym Romp', 'SMALL GYM ROMP', 1, 32, 9999, 3, 5, 16, 3283, '1999-01-01', 'This dance was devised by Peter Cass & Marion Peutherer to commemorate the 50th anniversary of Newcastle University Scottish Country Dance Society in 1999.  The Small Gym, in the King''s Walk Sports Centre, has been the home of the club for many years.  Such a shame that the University SCD Society folded in 2003 due to lack of participants.



Ian Thow very kindly provided a signature tune for the dance.





', 95, '88888/88888/48884/88888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6448, '1998-11-14 23:00:00+00', '2017-07-09 23:22:00.277379+00', 'Tam o'' Shanter', 'TAM O SHANTER', 1, 48, 9999, 1, 3, 42, 313, NULL, '', 50, '800/844/800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5957, '1998-07-08 22:00:00+00', '2016-05-03 20:38:37.165356+00', 'Scottish Heritage', 'SCOTTISH HERITAGE', 2, 48, 9999, 1, 4, 2, 108, '1983-01-01', '"for Jim and Mary Murray of Heritage Boulevard, Vancouver B.C."



Note (by Drewry) - I have always felt that, although the beginning of "Holyrood House" was very good, the rest of the dance failed to live up to the initial promise. Perhaps this is explained by the fact that the dance, like the camel, was "a horse designed by a committee". This dance is an attempt !o improve the ending of "Holyrood House". At first, I thought of calling this dance "Rizzio''s Revenge - or the Murder of Holyrood House", but, later, had a more poetic inspiration. Jim and Mary used to l1ve beside Holyrood Park during their days in Edinburgh.', 69, '6006/8448/6006/8448/8888/8668', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9607, '2000-09-04 22:00:00+00', '2016-05-11 14:28:14.974819+00', 'Grand Portage Reel', 'GRAND PORTAGE REEL', 1, 96, 9999, 107, 56, NULL, 693, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2292, '1997-09-28 22:00:00+00', '2016-05-11 22:38:15.805272+00', 'Fort Worden Pentangle', 'FORT WORDEN PENTANGLE', 3, 96, 9999, 102, 5, NULL, 922, '1984-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5856, '1997-09-13 22:00:00+00', '2016-05-11 23:23:02.379421+00', 'Salisbury Caledonians', 'SALISBURY CALEDONIANS', 4, 64, 5, 107, 56, NULL, 94, NULL, 'Line dance for 3 couples (One man between two ladies on each side)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12547, '2005-10-11 22:00:00+00', '2016-05-11 23:24:26.516949+00', 'Lone Star, The', 'LONE STAR', 1, 32, 9999, 102, 5, NULL, 3636, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8236, '1998-01-05 23:00:00+00', '2016-05-11 23:33:43.009189+00', 'Eastshore Reel', 'EASTSHORE REEL', 1, 32, 9999, 1, 4, 1, 3571, NULL, 'Devised in hnour of the RSCDS Lyndhurst Group  April 1995', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3693, '1997-09-07 22:00:00+00', '2016-05-12 09:06:04.416461+00', 'Land Of The Southern Cross', 'LAND OF THE SOUTHERN CROSS', 4, 96, 10037, 103, 124, NULL, 1060, NULL, 'Medley for 10 couples in a longwise set.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17037, '2016-06-11 22:26:39.035994+00', '2017-02-24 23:38:54.213024+00', 'Dance for Maisondieu, A', 'DANCE FOR MAISONDIEU', 2, 32, NULL, 1, 4, 1, 11268, NULL, 'Devised by Mary Gardner for the pupils of Maisondieu Primary School, Brechin.



3rd of the 7 New Dances for Beginners', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6715, '1997-04-03 22:00:00+00', '2016-05-29 21:16:53.258057+00', 'Trip To Buffalo Gap', 'TRIP TO BUFFALO GAP', 1, 32, 9999, 1, 2, NULL, 382, '1993-09-01', '', 60, '80/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4975, '1997-04-03 22:00:00+00', '2020-02-21 07:46:31.779668+00', 'Norman Whitelaw', 'NORMAN WHITELAW', 1, 32, 9999, 1, 2, 76, 129, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4716, '1997-04-03 22:00:00+00', '2020-10-03 12:36:15.364306+00', 'Mr Morison', 'MR MORISON', 2, 32, 9999, 1, 2, 76, 129, '1968-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18807, '2018-10-05 21:23:05.81254+00', '2020-10-03 19:50:16.372633+00', 'Laced Threads', 'LACED THREADS', 2, 32, NULL, 1, 3, 42, 2766, '2016-04-01', 'This dance celebrates my return to trying to learn bobbin lace.', 56, '844/484/808/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16929, '2016-04-18 10:14:32.409604+00', '2021-04-13 18:51:43.936683+00', 'East Neuk Storm', 'EAST NEUK STORM', 1, 32, NULL, 1, 3, 42, 10648, NULL, 'This is a reel-time version of the strathspey <<ddd:Calm Before Storm>>', 66, '880/888/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16327, '2015-05-09 17:41:31.394864+00', '2016-05-14 21:42:04.757847+00', 'Shall We Dance Again', 'SHALL WE DANCE AGAIN', 1, 32, 9999, 107, 1, NULL, 11133, '2010-01-01', 'Dancers begin on their appropriate side of the dance and will finish one place CCW (2nd turn L is center up and M is center down) and will dance the next round from that orientation', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12596, '2005-11-01 23:00:00+00', '2016-05-25 14:54:24.439866+00', 'Sally Dee', 'SALLY DEE', 3, 32, 9999, 1, 2, NULL, 2961, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16915, '2016-04-15 16:38:51.26202+00', '2022-04-26 09:25:27.645626+00', 'Piece o'' Cake', 'PIECE O CAKE', 3, 32, NULL, 1, 3, 42, 2766, '2009-02-01', 'Suggested music is Sauchie Haugh from Taylor and Imbrie Live.', 56, '880/888/844/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15422, '2014-04-16 10:14:52.511715+00', '2022-08-14 11:48:05.333372+00', 'Double Trouble', 'DOUBLE TROUBLE', 1, 48, NULL, 3, 5, 7, 2626, NULL, '', 75, '80844/84884/80800/88888/88888/84844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16935, '2016-04-18 12:21:43.612861+00', '2022-12-16 08:33:37.094139+00', 'Turning Hands', 'TURNING HANDS', 4, 96, 11, 4, 4, 54, 11246, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18331, '2018-05-04 22:13:23.042107+00', '2022-08-15 00:35:58.538963+00', 'Glenburn''s Welcome', 'GLENBURNS WELCOME', 2, 32, NULL, 1, 3, 42, 3699, NULL, 'Devised for the Glenburn Club.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12754, '2006-05-11 22:00:00+00', '2022-12-22 18:20:11.637393+00', 'Artillery Port', 'ARTILLERY PORT', 2, 24, 9999, 2, 3, 17, 3679, '1995-01-01', 'Danced 6 times through.', 67, '800/088/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7967, '1998-04-24 22:00:00+00', '2022-12-18 19:19:49.189699+00', 'Dance No. 1 (Reel)', 'DANCE NO 1 REEL', 1, 128, 9999, 107, 4, NULL, 181, NULL, 'A Set dance for 4 couples, beginning in tbe position of the Cross of St. Andrew.

The original title is as shown, basically just a number and the type of dance. The editorial team came up with an unofficial alias name for this dance for better search reference.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10102, '2001-09-20 22:00:00+00', '2016-05-04 10:08:32.406213+00', 'Elusive Muse, The', 'ELUSIVE MUSE', 2, 32, 9999, 2, 3, 18, 2701, '2003-01-01', 'Official Alias: Easily Led



For Bruce Herbold on the occasion of his 50th birthday. A wonderful teacher, fellow dance devisor, and fish biologist, I had intended to surprise him with a dance on his 49th birthday but the muse was too elusive. This time she stayed just long enough. This dance pays homage to two of his fishy favorites: The Duran Ranger and The Salmonfield Poacher. “Easily Led” is a reference to one of his favorite teaching exercises which is to brief either the women or the men and have them lead their partners through a dance with non-verbal cues.



In the interesting discussion on the "Strathspey" list in november 2015, about bars 9-16 



(which read 9-16:  1st couple dance down the middle for 4 bars with nearer hands joined, on bars 13-14  1st woman dances under their raised arms and in front of her partner (as he dances below her) to switch places and face up, on bars 15-16 they dance up to third place to face 3rd woman.)



Tim Wilson wrote: 



"My short answer: the text of The Elusive Muse should stay as is. I believe the description

of the turning movement is clear. (Please correct me if I am wrong.) It is what I intended

when I wrote the dance.



My long answer for those who are interested.  Yes, the dance is a nod to The Duran Ranger and to the way I learned that movement which was before the clarifications had been published or were (as) widely known. The description of The Elusive Muse uses nearer hands because 1st couple is on opposite sides

to begin the turning movement...and because my own feeling about the movement (man dancing below his partner) is that it is more easily/gracefully accomplished when nearer hands are joined. 



As Duncan has noted, the movement seems to have an equal chance of going the right way and the "other right" way. Since it is only danced by 1st couple in The Elusive Muse, the most important thing is that 1st couple switch sides to face up without injury (and ideally with grace). :-)"', 56, '640  800  804  888', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (16221, '2015-04-22 22:52:07.394735+00', '2016-05-06 19:03:59.261525+00', 'New Rigged Hip, The', 'NEW RIGGED HIP', 2, 48, NULL, 1, 4, 1, 1862, '2015-04-22', 'THE NEW RIGGED HIP

J48

4-couple set



1-8      All dance eight hands round and back

9-16     All dance mirror reels of four on the sides (begin 1C facing 2C, 3C facing 4C, 1C+3C start in and down)

17-24    1C lead down and up

25-32    1C cross RH, cast off 3 places (others step up), cross RH

33-36    2M+3W, 4M+1W, set and turn RH

37-40    2W+3M, 4W+1M, set and turn RH

41-48    2C+3C, 4C+1C, diagonal reels of four (begin 2W+3M and 4W+1M passing partner RS)



note: suitable music [New Rigged Ship, J 4x48] was recorded many years ago by Jim Cameron and is available on iTunes (for 99 cents here in the US).', 67, '8888/8888/8000/8000/4444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10956, '2002-11-14 23:00:00+00', '2016-05-08 20:51:41.679817+00', 'Who Should Love Me', 'WHO SHOULD LOVE ME', 3, 32, 9999, 1, 3, 42, 2488, '1981-01-01', 'Composed in 1981 by Todd McCall, who has an affection for "story·telling" dances. In this dance, the first woman encourages her partner to overcome his shyness of the opposite sex.', 62, '844/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8403, '1998-01-05 23:00:00+00', '2016-05-10 19:32:41.551342+00', 'Porridge Drawer, The', 'PORRIDGE DRAWER', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8431, '1997-12-28 23:00:00+00', '2016-05-10 19:44:28.732582+00', 'Highland Gathering, The', 'HIGHLAND GATHERING', 2, 40, 9999, 1, 2, NULL, 173, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9088, '1999-07-25 22:00:00+00', '2016-05-10 20:58:09.293817+00', 'Saltire Medley, The', 'SALTIRE MEDLEY', 4, 96, 11, 107, 101, 3, 175, NULL, 'Starting position: as in DTr, four women as corners, two men facing up/down in the middle, no hands.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1133, '1997-08-31 22:00:00+00', '2016-05-10 22:23:38.198957+00', 'Celtic Reel, The', 'CELTIC REEL', 1, 16, 9999, 107, 53, NULL, 175, '1972-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8319, '1997-12-28 23:00:00+00', '2016-05-11 12:57:44.611287+00', 'Tribute to the Isles', 'TRIBUTE TO THE ISLES', 3, 32, 9999, 6, 53, NULL, 1391, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10208, '2001-11-06 23:00:00+00', '2016-05-11 13:44:58.549985+00', 'Saint Ann''s Twasome', 'SAINT ANNS TWASOME', 3, 64, 9999, 107, 1, NULL, 2018, NULL, 'ST. ANN''S TWASOME 

64 bar Strathspey 	 

1 couple, woman on man''s right hand side facing audience 	



Featured Formation:  Glasgow Highlanders Setting 



BARS 



 1-4	1/2 GLASGOW HIGHLANDERS SETTING & CHASE HALFWAY TO THE LEFT: couple set to each other with Glasgow Highlanders setting step (2 bars) & then dance to the left halfway around a circle to change places with 2 travelling steps (left & right); 



5-8	1/2 GLASGOW HIGHLANDERS SETTING & CHASE HALFWAY TO THE RIGHT: couple set to each other with Glasgow Highlanders setting step starting to the left (2 bars) & then dance to the right halfway around a circle back to original places; 



9-16	SET & 1/2 TURN TWICE: set to each other & turn halfway with right hands, then set & turn halfway with right hands ending in allemande hold facing audience; 



17-24	ALLEMANDE: dance a complete allemande; 



25-32	CAST, 1/2 TURN & TWIRL, CHASE: pull back right shoulder & cast 1/4 around a circle (2 bars), then turn halfway with right hands (2 bars), twirl (with right hands still joined dance towards each other & then, pulling back right shoulders cast out (2 bars) & chase clockwise to original places (2 bars); 



33-40	TURN, SET & PETRONELLA: turn each other once round with both hands (4 bars), set & petronella to the right ending facing each other; 



41-48	REPEAT bars 33-40 to end in each other''s places; 



49-52	SET & 1/2 JIP: set to each other & then passing each other by the right shoulder, end facing each other in ballroom hold; 



53-56	HIGHLAND SCHOTTISCHE SETTING starting to the man''s left; 



57-60	1/2 REEL OF 4: pulling back right shoulders, cast into a right shoulder reel of 4 halfway (with imaginary end people), on bar 60 spin once around to the left; 



61-64	1/2 .REEL OF 4: dance a left shoulder reel of4 halfway, but end with a left hand turn halfway (instead of passing right shoulders). 



Bow/Curtsey to each other and then to audience 





', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13774, '2011-07-14 22:00:00+00', '2016-05-11 14:16:53.521311+00', 'Exercise for Beginners', 'EXERCISE FOR BEGINNERS', 1, 64, NULL, 103, 113, 8, 227, '1988-01-01', 'Can be danced as a reel or jig.



Longwise set of 8 couples or more



1c turn RH | cast off (2c up) ; turn LH | cast off (3c up)

continue to end.  New couple starts from top every 8 bars.



This is a very good exercise for phrasing and covering, keeping the set in shape, moving up, giving hands in quick turns, get the idea of dancing with quick turns and wide loops in the casting.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12482, '2005-07-24 22:00:00+00', '2021-04-09 15:19:28.072521+00', 'Auld Red Cat, The', 'AULD RED CAT', 3, 32, 9999, 1, 3, 42, 2766, '2005-06-01', 'This dance honors my old red cat, Cinnamon, who will be 18 years old in August of this year and who has weathered a host of potentially lethal diseases and still survives. (Cinny lived to be 19 years and 3 months before succumbing to old age.)', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11903, '2004-11-11 23:00:00+00', '2016-05-13 14:41:11.491613+00', 'Two Short', 'TWO SHORT', 2, 32, 9999, 107, 3, 17, 3468, NULL, 'TWO SHORT



Devised by Natalie Coviello	3x32 Jig



Three couples arranged in a square set.



[Here a figure shows the set.  1st and 3rd couples are placed as in a normal four-couple square set, 2nd lady is in the 2nd couple’s place, 2nd Man in the 4th couple’s place.] 



Bars

1-8		2nd lady and 1st man, 2nd and 3rd men turn right hands to original places.

	2nd and 3rd ladies, 2nd man and 1st lady turn left hands to original places



9-16		2nd couple set, half turn right hands to face 3rd couple, 2’s and 3’s dance half rights and lefts to change places. 3rd couple omits polite turn at the end to finish facing out



[Here a figure shows the right hands across for twice three dancers]



17-24		3rd man dances right hands across with 2nd couple (in 3rd place), 3rd lany dances right hands across with 1st couple.  3rd couple pass right shoulder to dance right hands across, 3rd man with first couple and 3rd lady with 2nd couple.  Finish in the “square” formation, 3rd man in 2nd place, 3rd lady in 4th place.



25-28	All half circle to the left.  3rd couple must control the half circle so that everybody finishes exactly half way, in new positions.



29-32	All three couples advance and retire. Finish 2nd couple in 1st place, 3rd lady in 2nd place, 1st couple in 3rd place and 3rd man in 4th place



Music used: 3x32 Jig from record “Grandfather Mountain”.









This text is an exact copy of the original text which was supplied as a JPG by the deviser. Two hand-drawn figures have been replaced by text describing their content.   Eric Ferguson, 9th feb 2016.

', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8207, '1998-01-05 23:00:00+00', '2016-05-13 15:01:00.372909+00', 'Beldon Twister, The', 'BELDON TWISTER', 1, 32, 9999, 1, 4, 1, 2014, '1987-05-01', 'A dance for 3,4 or 5 couples.  Entirely danced by the 1st couple.', 25, '800/800/800/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14855, '2013-05-19 10:52:18.781023+00', '2016-05-14 10:57:34.771301+00', 'Lost in the Cairngorms', 'LOST IN THE CAIRNGORMS', 1, 32, 9999, 4, 6, 4, 17, '2001-01-01', 'The description does not state whether in shall be danced as Reel or Jig.



Start in Square set with two couples in the middle facing side couples.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6170, '1997-09-14 22:00:00+00', '2016-05-25 20:52:42.350051+00', 'Snowflake Strathspey, The', 'SNOWFLAKE STRATHSPEY', 3, 96, 9999, 101, 6, 3, 270, NULL, 'Hexagonal: the six W stand Back to Back in the middle, facing their partners.

The dance has six 16-bar figures, each consisting of an 8-bar phrase plus a fixed 8-bar chorus, which moves everyone to a new partner.  ', 100, '16/16/16/16/16/16', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16904, '2016-03-15 00:52:18.345329+00', '2016-05-26 09:53:34.526047+00', 'Gymnasts'' Medley, The', 'GYMNASTS MEDLEY', 4, 32, 1, 4, 4, 4, 11164, '2015-08-01', 'Strathspey



1-6 1 st and 3rd couples dance half rights and lefts and set to finish facing in while 2nd and 4th couples set and dance half rights and lefts (2nd and 4th women twirl left) to finish facing out



7-8 2nd woman with 1 st man and 4th woman with 3rd man, giving left hands, turn halfway round while 3rd woman with 2nd man and 1 st woman with 4th man, giving right hands, turn halfway round to finish all facing in



9-10 4th woman with 2nd man and 2nd woman with 4th man, giving nearer hands, advance to meet own partners



11-16 2nd and 4th couples, giving nearer hands, dance out between side couples, part and cast up or down to form lines of four on the sides facing 1 st and 3rd couples (1 st and 3rd couples turn on the spot to face up or down on bar 14), and all set



Reel



17-24 All dance reels of four on sidelines, 1 st and 3rd couples pass right shoulders on bars 23-24 while 2nd and 4th couples dance slightly in to form a square set again, finishing all facing clockwise



25-32 4th woman with 2nd man, 1 st woman with 3rd man, 2nd woman with 4th man and 3rd woman with 1 st man chase clockwise halfway in tandem (women loop right to begin and follow the men who started behind) to finish all facing in and all set



On each repeat, the women move one place anticlockwise and the men one place clockwise. Newly formed couples repeat three times from new positions.', 100, '8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8740, '1998-09-20 22:00:00+00', '2018-04-03 00:07:59.723583+00', 'Link Across The Land', 'LINK ACROSS THE LAND', 3, 32, 9999, 1, 3, 42, 382, '1995-01-01', '', 50, '800/844/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16955, '2016-05-27 21:27:15.409224+00', '2019-02-19 23:08:16.57689+00', 'Avril''s Frolic', 'AVRILS FROLIC', 1, 32, NULL, 1, 3, 42, 11151, '2015-05-01', '', 55, '808/808/868/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14356, '2011-12-14 23:00:00+00', '2018-07-18 17:33:13.575378+00', 'Audrey & Peter''s Jubilee', 'AUDREY AND PETERS JUBILEE', 3, 48, NULL, 2, 3, 18, 884, NULL, 'Presented to Audrey and Peter Saunders on the occasion of their 50th wedding anniversary.



Suitable Music: CD Dancers’ Choice 2, Robert Whitehead & the Danelaw Dance Band, Track 6 ‘One for the Millenium’. 



However, in the meantime an official recording exists.', 71, '844  622  444  888  888  844', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (8028, '1997-12-03 23:00:00+00', '2016-05-28 14:44:15.105786+00', 'Five is Fun', 'FIVE IS FUN', 2, 64, 9999, 107, 55, 4, 1376, NULL, 'Set: 3 W and 2 M; standing in a 2 couple set with a lone W in 3rd place on the midline.  The W progress (3,1,2), the men do not change places.  Three times through.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16995, '2016-06-07 20:04:41.091512+00', '2016-06-07 20:25:05.698189+00', 'Boar''s Rock, The', 'BOARS ROCK', 1, 48, 9999, 4, 4, 13, 2525, '2007-04-10', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17038, '2016-06-11 22:29:35.518031+00', '2017-02-24 23:43:15.477608+00', 'May Blossom', 'MAY BLOSSOM', 2, 32, NULL, 4, 4, 1, 9998, NULL, '5th of the 7 New Dances for Beginners', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17040, '2016-06-11 22:33:01.855884+00', '2017-02-24 23:45:18.750934+00', 'Dosidosido', 'DOSIDOSIDO', 1, 32, NULL, 4, 4, 1, 9998, NULL, '7th of the 7 New Dances for Beginners', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5389, '2003-01-27 23:00:00+00', '2016-05-30 22:36:59.043858+00', 'Pulling Bracken', 'PULLING BRACKEN', 1, 32, 9999, 1, 3, 42, 57, NULL, 'It is suggested that at the end of their second time through the dance, the dancing couple finish in 3rd place and progress to the foot by again dancing bars 1-8 with the 4th couple, who will then flow naturally into the Grand Chain. [from the original SDA leaflet 68, 1975]



On 3 jan 2013 Angela Bulteel wrote on "Strathspey":   My husband Tony Bulteel wrote this dance, and whenever he was teaching it, he always taught the retiring 1s to reel with the 4s while the new 1s were doing their 1st reel across.  However, I am fairly certain this was not actually written into the dance at the time it was first published, I believe it was more of a suggestion added at the bottom of the instructions, and as such, I think it gets forgotten, which is rather a shame as it does look particularly good, especially when couples are covering well.  Tony is 85 now and did express the hope that dancers would continue to dance the extra reel to finish in 4th place. Hope this helps.



On 30 may 2016 Angela Bulteel wrote on "Strathspey":  My husband Anthony Bulteel, sadly now deceased, wrote Pulling Bracken and I couldn''t help noticing the request for instructions and sheet music.  I do not have the written instructions for his dance but would like to mention that it was written and titled Pulling Bracken because my husband loved the tune of the same name.   Some time after he wrote the dance someone wrote a piece of music which they decided to say was to be the original tune for  Tony''s dance. This was done  without asking or even seeking my husband''s approval or agreement.   May I just say that if this is to be danced by your group at an occasion where a live band is playing,  may I request that the original tune of the same name be played for the dance?  Although I do not have the sheet music, I''m sure there are many musicians out there who would be willing to supply a copy of this melody to you. May I also say it''s good to know this dance is still on many programmes.  Kindest regards Angela Bulteel.

', 59, '880  888  822  888', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (16930, '2016-04-18 10:34:29.605792+00', '2018-04-03 00:08:10.873691+00', 'Pirongia', 'PIRONGIA', 1, 32, NULL, 1, 3, 42, 11244, NULL, 'Pirongia is a small town in the Waikato region of New Zealand''s North Island. It is 12 km to the west of Te Awamutu, on the banks of the Waipa River, close to the foot of the 962m Mount Pirongia, which lies in a forest park to the west of the town, near to where Robert & Margaret Senior’s grandchildren live.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16961, '2016-05-30 22:54:58.024059+00', '2018-05-22 01:13:27.068444+00', 'Kitchen Faerie, The', 'KITCHEN FAERIE', 101, 32, NULL, 1, 2, NULL, 2682, '2016-04-03', 'Notes from The Johnsonville Collection:



Devised 3rd April 2016.  The dance is dedicated to Elizabeth Ngan, our club''s dedicated "kitchen faerie". According to the dictionary, a faery is a "A tiny, mischievous, imaginary being".  Ours is also the ruling Czar of the kitchen (and indispensible). 



Recommended music is "Colonel Hamilton''s Delight" by Joseph Reinagle, a traditional tune which is the lead tune for "Hamilton House" from Book 7.  I used the recording by Jimmy Shand in "O''er the Border"', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16984, '2016-06-07 16:31:45.651438+00', '2016-06-07 16:32:37.70326+00', 'Pheasant Lane', 'PHEASANT LANE', 3, 32, 9999, 1, 4, 1, 2723, NULL, '', 81, '8888 8008 8888 8884', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16996, '2016-06-07 20:10:54.650596+00', '2016-06-07 20:10:54.650596+00', 'Bonnie Lass and Her Beau, The', 'BONNIE LASS AND HER BEAU', 3, 32, 9999, 1, 2, 76, 2525, '2012-01-25', '', -1, '82 88 88 88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16997, '2016-06-07 20:20:57.029734+00', '2016-06-07 20:20:57.029734+00', 'Cock Robin''s Well', 'COCK ROBINS WELL', 1, 32, 9999, 1, 3, 42, 2525, '2012-10-01', '', 73, '864 844 822 888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16793, '2015-10-14 15:55:57.260551+00', '2018-12-07 18:08:51.035805+00', 'Summer Wedding', 'SUMMER WEDDING', 3, 40, NULL, 1, 4, 1, 2682, NULL, 'Notes. Devised 8 February 2015, with help from Kristin. First two figures

modified 3 March 2015. The dance is for Joshua Baker and Sarah Kennedy,

to commemorate their lovely wedding of January 10, 2015. The tourbillon

movement is due to Barry Priddey, and the half turn, hesitate, and cast away

movement (with two hands) is due to Alec Hay. The dance is vaguely symbolic,

which is why it finishes with the knot.



Recommended is “Link Him Doddie” (N. Gow) played ABABB which is the lead

tune for “The Lovers’ Knot”, and a suitable 4 × 40 recording is by Jim Macleod

and his Band, ”Music for Book 8” (LP). Suitable alternative recorded music

would include any reasonable recording of ”The New Scotland Strathspey,”

such as that by Colin Dewar and his Band in ”Special Requests Vol. 3”.

11', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17063, '2016-06-23 22:54:16.912498+00', '2016-06-23 22:54:16.912498+00', 'Portcullis, The', 'PORTCULLIS', 2, 32, NULL, 1, 4, 1, 525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17077, '2016-06-26 15:20:02.941318+00', '2016-06-26 15:20:02.941318+00', 'Ready .......... Stand', 'READY  STAND', 2, 32, NULL, 1, 4, NULL, 2887, NULL, 'Progression 4213.  Danced 3 times through.  2C does not move.  ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16044, '2015-02-11 22:21:48.005142+00', '2016-06-03 14:06:17.018263+00', 'Trip to the Highlands, A', 'TRIP TO THE HIGHLANDS', 1, 32, NULL, 1, 2, 76, 228, '2015-02-11', 'Devised for my teaching visit to St Petersburg in February, 2015.



I had a one-hour session to teach beginners some simple formations and dances and originally wanted to use <<ddd:Highland Fair>> from the <<ddpub:Graded Book>>. I didn''t want both dances for that class

to be jigs, so I tweaked that dance a little and changed the rhythm to “reel”.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11770, '2004-09-02 22:00:00+00', '2016-06-04 20:31:35.800065+00', 'Hand In Hand', 'HAND IN HAND', 1, 32, 9999, 1, 3, 42, 3355, '2002-06-14', 'For Julia and Kat, 14th June 2002.', 56, '800  844  888  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (9757, '2001-05-03 22:00:00+00', '2020-12-29 11:49:04.498765+00', 'Mrs Hume''s Strathspey', 'MRS HUMES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 228, '2000-01-01', 'Dedicated to the members of the First Fortnight Teacher''s Certificate Class, RSCDS Summer School 2000, St. Andrews. The ''Surge'' progression, in particular, is for Ralph Stoddard (and his tea-cup) and Blaine Peet. Having been written for candidates, the dance is probably most fun in a fairly large set.', 51, '808  810  880  888', 1, 1, 1, 1, 67);
INSERT INTO 'dance' VALUES (13301, '2007-07-22 22:00:00+00', '2021-01-03 12:54:40.889018+00', 'Miss Granger''s Strathspey', 'MISS GRANGERS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 228, '2007-01-01', '', 50, '800  888  880  880', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (11027, '2002-11-24 23:00:00+00', '2021-01-30 11:07:03.238789+00', '''Allo ''Allo', 'ALLO ALLO', 1, 32, 9999, 1, 3, 42, 1, NULL, '', 41, '880/808/800/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16964, '2016-05-31 00:35:06.832557+00', '2016-06-04 22:59:07.122275+00', 'Vishoek', 'VISHOEK', 1, 32, NULL, 1, 3, 42, 2682, '2016-05-17', 'Notes:  Devised 17/5/2016.  Vishoek or Fish Hoek is a lovely town on the Cape Town pensulia.  I taught a class there in one windy night 2011 and the group was a lot of fun.  I have been meaning to write a dance for them, and it occurred to me, that the La Spirale is a bit like a fish hook....



Recommended music is the set of Irish Reels by the Sound Company.  Another excellent alternative would be the Peter Elmes set for Mr William Brown''s Reel from "Thistle Hall," which could be described as "Bothy Ballads."  Otherwise a good driving reel in one of these styles.', 66, '888/880/888/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16966, '2016-06-07 14:03:00.267803+00', '2016-06-07 14:03:00.267803+00', 'Bampton Strathspey, The', 'BAMPTON STRATHSPEY', 3, 32, 9999, 1, 2, 76, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16967, '2016-06-07 14:10:35.390398+00', '2016-06-07 14:10:35.390398+00', 'Beth and Christine''s Reel', 'BETH AND CHRISTINES REEL', 1, 32, 9999, 1, 3, 42, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16977, '2016-06-07 15:21:56.110955+00', '2016-06-07 15:21:56.110955+00', 'Katarina''s Jig', 'KATARINAS JIG', 2, 40, 9999, 1, 3, 42, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16968, '2016-06-07 14:18:16.209191+00', '2016-06-07 14:18:16.209191+00', 'Burlington Jaunt, The', 'BURLINGTON JAUNT', 3, 32, 9999, 1, 3, 42, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16969, '2016-06-07 14:27:04.411971+00', '2016-06-07 14:27:04.411971+00', 'Burning Bush, The (Euonymus alatus)', 'BURNING BUSH THE EUONYMUS ALATUS', 1, 32, 9999, 1, 3, 42, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16970, '2016-06-07 14:31:41.609922+00', '2016-06-07 14:31:41.609922+00', 'Dance Mistress, The', 'DANCE MISTRESS', 2, 32, 9999, 1, 3, 42, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16971, '2016-06-07 14:40:32.40462+00', '2016-06-07 14:40:32.40462+00', 'Debbie''s Reel', 'DEBBIES REEL', 1, 48, 9999, 1, 3, 42, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16972, '2016-06-07 14:45:36.077054+00', '2016-06-07 14:45:36.077054+00', 'Fernigan', 'FERNIGAN', 3, 32, 9999, 1, 3, 42, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16973, '2016-06-07 14:53:19.910695+00', '2016-06-07 14:53:19.910695+00', 'Figures of Eight', 'FIGURES OF EIGHT', 1, 40, 9999, 1, 3, 42, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16974, '2016-06-07 14:58:19.760587+00', '2016-06-07 14:58:19.760587+00', 'Fine Companion, The', 'FINE COMPANION', 3, 40, 9999, 1, 3, 42, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16975, '2016-06-07 15:09:21.591386+00', '2016-06-07 15:10:21.261977+00', 'Hamiltons'' Delight, The', 'HAMILTONS DELIGHT', 2, 32, 9999, 1, 3, 42, 2723, '2014-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18316, '2018-05-02 18:13:11.670474+00', '2018-05-07 01:05:59.343567+00', 'Forty Years of Royal Oak Nights', 'FORTY YEARS OF ROYAL OAK NIGHTS', 1, 32, NULL, 1, 3, 42, 11139, '2013-06-21', 'Written in honour of the Royal Oak Scottish Country Dance Club for their 40th Anniversary celebrations in October 2014.  



The dance is for the current co-tutors Sue Crosbie and Jan Batten, and all past and present life and club members and tutors.', 47, '822/822/866/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10496, '2002-04-20 22:00:00+00', '2019-09-09 08:58:38.348524+00', 'Apple Wine & Georgia Peaches', 'APPLE WINE AND GEORGIA PEACHES', 3, 32, 9999, 1, 3, 42, 228, NULL, 'Devised: 1999-10', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16979, '2016-06-07 15:48:08.7164+00', '2016-06-07 15:48:08.7164+00', 'Lass from Glasgow, The', 'LASS FROM GLASGOW', 3, 32, 9999, 1, 3, 42, 2723, '1985-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16980, '2016-06-07 15:52:33.010365+00', '2016-06-07 15:52:33.010365+00', 'Laura''s Fancy', 'LAURAS FANCY', 1, 32, 9999, 1, 4, NULL, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16981, '2016-06-07 16:04:53.905808+00', '2016-06-07 16:04:53.905808+00', 'Long Voyage, The', 'LONG VOYAGE', 3, 32, 9999, 1, 3, 42, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16982, '2016-06-07 16:09:14.469182+00', '2016-06-07 16:09:14.469182+00', 'Middleton Rant, The', 'MIDDLETON RANT', 1, 32, 9999, 1, 3, 42, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16983, '2016-06-07 16:20:16.557119+00', '2016-06-07 16:20:16.557119+00', 'Patricia''s Strathspey', 'PATRICIAS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2723, '1982-08-01', '', -1, '880 888 800 880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3520, '2002-01-08 23:00:00+00', '2019-02-03 21:28:40.242534+00', 'Kirn, The', 'KIRN', 1, 64, 9999, 1, 4, 1, 287, NULL, 'A YouTube video states that the dance was devised by a Mrs. R. Hall', 81, '8888/8888/8888/8888/8800/8080/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16993, '2016-06-07 19:04:38.732861+00', '2016-06-07 19:04:38.732861+00', 'Piper''s Delight, The', 'PIPERS DELIGHT', 2, 32, 9999, 1, 3, 42, 2723, NULL, '', 46, '880 800 822 800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16978, '2016-06-07 15:40:05.263735+00', '2017-05-31 13:07:27.815392+00', 'Gaucherie, La', 'GAUCHERIE', 1, 32, 9999, 1, 3, 42, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18297, '2018-04-24 18:23:37.588595+00', '2018-05-10 13:33:40.926374+00', 'Moon At The Bottom Of The Sea, The', 'MOON AT THE BOTTOM OF THE SEA', 3, 32, NULL, 1, 3, NULL, 44, '2004-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16999, '2016-06-08 10:05:16.418309+00', '2016-06-08 10:05:16.418309+00', 'Farewell Gift, A', 'FAREWELL GIFT', 2, 32, 9999, 1, 3, 42, 2525, '2007-05-10', '', 54, '880 880 800 822', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17000, '2016-06-08 10:12:34.096369+00', '2016-06-08 10:12:34.096369+00', 'Friday Nighters, The', 'FRIDAY NIGHTERS', 1, 32, 9999, 1, 3, 42, 2525, '2007-03-17', '', 75, '860 888 800 880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17001, '2016-06-08 10:37:23.502254+00', '2016-06-08 10:37:23.502254+00', 'Invitation to the Ball, An', 'INVITATION TO THE BALL', 3, 32, 9999, 1, 3, 42, 2525, '2011-11-01', '', 94, '864 888 888 888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17002, '2016-06-08 10:43:27.560875+00', '2016-06-08 10:43:27.560875+00', 'It''s a Grand Night for Dancing', 'ITS A GRAND NIGHT FOR DANCING', 1, 32, 9999, 1, 3, 42, 2525, NULL, '', 73, '822 802 888 888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17003, '2016-06-08 11:05:43.153216+00', '2016-06-08 11:24:12.620084+00', 'Let''s Go Dancing', 'LETS GO DANCING', 2, 32, 9999, 1, 3, 42, 2525, '2011-11-01', '', 77, '808 888 808 864', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17004, '2016-06-08 11:35:35.600279+00', '2016-06-08 11:35:35.600279+00', 'Memorable Occasion, A', 'MEMORABLE OCCASION', 2, 40, 9999, 1, 3, 42, 2525, '2007-01-01', '', 62, '820 844 844 844 844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16976, '2016-06-07 15:16:22.327305+00', '2022-04-28 09:12:11.787029+00', 'Hermit Island Jig, The', 'HERMIT ISLAND JIG', 2, 32, 9999, 1, 3, 42, 2723, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17022, '2016-06-11 14:30:22.962238+00', '2023-01-14 15:43:41.414746+00', 'Large Hadron Collider, The', 'LARGE HADRON COLLIDER', 1, 32, NULL, 4, 4, 13, 11237, '2013-03-01', '', 81, '8000/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17005, '2016-06-08 11:42:32.311961+00', '2016-06-08 11:42:32.311961+00', 'Mistletoe and Holly', 'MISTLETOE AND HOLLY', 2, 32, 9999, 1, 3, 42, 2525, '2011-12-15', '', 77, '864 888 800 888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17009, '2016-06-08 15:22:40.324583+00', '2016-06-08 15:22:40.324583+00', 'Haughs of Dalnair', 'HAUGHS OF DALNAIR', 3, 32, 9999, 1, 3, 42, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (891, '1998-01-05 23:00:00+00', '2016-06-08 21:59:36.811237+00', 'By The Light Of the Harvest Moon', 'BY THE LIGHT OF THE HARVEST MOON', 1, 32, 9999, 1, 3, 42, 204, NULL, '', 36, '802/822/822/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17012, '2016-06-09 09:42:03.990326+00', '2016-06-09 09:42:03.990326+00', 'Ally Fletcher''s Reel', 'ALLY FLETCHERS REEL', 1, 32, 9999, 1, 3, 42, 1415, NULL, '', 79, '884 844 888 844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16952, '2016-05-16 21:40:50.184301+00', '2020-07-17 08:21:48.838647+00', 'Lady of Wallroth, The', 'LADY OF WALLROTH', 3, 32, NULL, 1, 3, 42, 11260, NULL, 'Devised for Anika Lange to celebrate her 40th birthday.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18317, '2018-05-02 18:14:17.253028+00', '2020-11-15 11:29:49.355477+00', 'Great Hall, The', 'GREAT HALL', 2, 32, NULL, 1, 3, 42, 11139, '2011-04-30', 'Written for Sue Crosbie, co-tutor of the Royal Oak Club, who at the time of writing

the dance, was following her dream of having a Ball in ‘The Great Hall’ of the

Auckland Town Hall.', 44, '880/880/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17020, '2016-06-10 10:27:15.111518+00', '2021-01-22 11:25:27.38499+00', '''Fasten Your Seat Belts!''', 'FASTEN YOUR SEAT BELTS', 1, 32, NULL, 1, 4, 2, 3645, '2016-01-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17006, '2016-06-08 12:06:06.512318+00', '2021-04-02 20:58:00.263315+00', 'Dianne''s Smile', 'DIANNES SMILE', 3, 48, 9999, 4, 4, 30, 2525, '2005-05-31', 'Suitable Music: "The Moray Rant"

(Only Drummond Cook''s version is 4x48 bars)', 100, '8888/8888/8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1770, '1998-01-04 23:00:00+00', '2021-05-04 12:51:29.949593+00', 'Drunken Parson, The', 'DRUNKEN PARSON', 1, 32, 9999, 1, 2, 76, 270, NULL, 'This is given as a reel in the original publication, but considering that the original tune is a jig this is probably a typo.', 69, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17013, '2016-06-09 09:53:08.196091+00', '2016-06-09 09:53:08.196091+00', 'Twirlpools', 'TWIRLPOOLS', 3, 32, 9999, 1, 4, 2, 1415, NULL, '', 75, '8888 8448 0880 8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17015, '2016-06-09 10:38:29.061857+00', '2016-06-09 10:38:29.061857+00', 'Axum Rose', 'AXUM ROSE', 3, 32, 9999, 1, 100, 2, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17010, '2016-06-08 15:58:01.431958+00', '2016-06-09 10:47:24.857989+00', 'Lazy Compass, The', 'LAZY COMPASS', 1, 32, 9999, 1, 3, 42, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17011, '2016-06-08 16:12:12.430103+00', '2016-06-09 10:48:21.337392+00', 'Loch Eriboll', 'LOCH ERIBOLL', 3, 40, 9999, 4, 4, 1, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17017, '2016-06-09 13:36:03.315876+00', '2019-06-09 18:07:25.845823+00', 'Bulliondale', 'BULLIONDALE', 1, 32, 9999, 1, 3, 42, 11267, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17029, '2016-06-11 22:03:26.257771+00', '2017-02-24 23:20:14.482128+00', 'Bruce Brymer of Brechin', 'BRUCE BRYMER OF BRECHIN', 2, 32, NULL, 3, 5, 10, 9998, NULL, '“Bruce Brymer, Butcher of Brechin”, rolls off the tongue as well as his splendid meat rolls off his knife!', -1, '', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (17007, '2016-06-08 15:05:49.243891+00', '2018-02-21 15:21:00.550255+00', 'Endrick Water', 'ENDRICK WATER', 3, 32, 9999, 2, 3, 17, 1415, NULL, 'This is the river that flows through Dalnair Farm.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11601, '2003-12-02 23:00:00+00', '2017-02-24 23:10:28.796795+00', 'Montrose Dancers', 'MONTROSE DANCERS', 4, 64, 5, 2, 3, 18, 2913, NULL, 'Montrose is a port at the mouth of the South Esk and lies between the North Sea and the Montrose Basin, a wild bird reserve which hosts most of the worlds pink footed geese in winter.', 93, '888/888/888/088', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17016, '2016-06-09 10:44:08.03345+00', '2018-04-03 00:07:34.446783+00', 'Bobberty Baird', 'BOBBERTY BAIRD', 2, 32, 9999, 1, 3, 42, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5485, '1997-11-27 23:00:00+00', '2018-04-03 00:08:12.158154+00', 'Ready, Steady, Go!', 'READY STEADY GO', 4, 32, 1, 1, 3, 42, 1029, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17018, '2016-06-09 13:46:18.766665+00', '2019-06-09 16:39:02.121546+00', 'Powdered Sugar', 'POWDERED SUGAR', 1, 32, 9999, 1, 3, 42, 3784, NULL, 'Dedicated to Susie Poskonka on the event of her birthday in 2010.', 47, '800/833/833/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17032, '2016-06-11 22:13:26.854374+00', '2017-02-24 23:27:12.0315+00', 'Minuet for a Ball', 'MINUET FOR A BALL', 50, 48, NULL, 4, 4, 1, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17033, '2016-06-11 22:16:04.172568+00', '2017-02-24 23:29:55.438692+00', 'Arbroath Eightsome March, The', 'ARBROATH EIGHTSOME MARCH', 11, 48, NULL, 1, 102, NULL, 9998, '2003-03-22', 'March or Reel.



Devised for The Scottish Country and Old Time Dancers of Arbroath (Site of the famous Abbey where the 14th Century “Declaration of Arbroath” confirmed Scottish independence from England).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17036, '2016-06-11 22:24:56.71908+00', '2017-02-24 23:37:45.222502+00', 'Gearbox', 'GEARBOX', 2, 32, NULL, 1, 4, NULL, 9998, NULL, '2nd of the 7 New Dances for Beginners', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17064, '2016-06-23 22:57:11.096812+00', '2016-06-23 22:57:11.096812+00', 'Forty Love', 'FORTY LOVE', 1, 40, NULL, 1, 4, 1, 525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17008, '2016-06-08 15:14:21.858858+00', '2017-01-24 00:02:26.89021+00', 'Catriona''s Ceilidh', 'CATRIONAS CEILIDH', 1, 32, 9999, 1, 4, 2, 1415, '2015-01-01', '', 75, '8008/8888/4884/4884', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17035, '2016-06-11 22:19:40.628774+00', '2017-02-24 23:37:02.176635+00', 'Grand Chain Reel', 'GRAND CHAIN REEL', 1, 32, NULL, 1, 4, 1, 9998, NULL, '1st of the 7 New Dances for Beginners', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16965, '2016-06-05 09:39:59.097642+00', '2016-06-13 08:37:12.074897+00', 'Nuernberg Castle', 'NUERNBERG CASTLE', 2, 32, NULL, 2, 3, 17, 11265, '2011-05-01', 'Dedicated to the Nürnberg Castle, see 



https://de.wikipedia.org/wiki/N%C3%BCrnberger_Burg 



https://en.wikipedia.org/wiki/Nuremberg_Castle

', 93, '888/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9401, '2000-04-18 22:00:00+00', '2016-06-13 14:10:50.998567+00', 'Tweedsmuir Tangle', 'TWEEDSMUIR TANGLE', 1, 40, 9999, 1, 3, 42, 2739, '2000-01-01', 'The description calls this a 4 couple reel in a longwise set, but only the first three couples dance, and the progression is (213), so it is obviously a 3C/4L dance', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17066, '2016-06-23 23:01:35.633888+00', '2016-06-23 23:01:35.633888+00', 'Geordies Jg', 'GEORDIES JG', 2, 32, NULL, 1, 4, 1, 525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17071, '2016-06-26 14:55:19.28783+00', '2016-06-26 14:58:43.616691+00', 'Who''s Afraid of Yellow and Gold?', 'WHOS AFRAID OF YELLOW AND GOLD', 2, 32, NULL, 1, 100, 11, 2110, '1996-02-01', 'The description is incomplete; bars 29-32 are missing', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17041, '2016-06-13 13:43:55.987687+00', '2016-06-14 00:53:45.665135+00', 'Salute to the Netherlands', 'SALUTE TO THE NETHERLANDS', 3, 48, NULL, 4, 4, 1, 10971, '2016-06-13', 'Written in September 2014 when Ray and Sylvia visited the Geldermalsen SCD group "White Heather".  The dance was revised and finalised in june 2016.



The full original description of "Schiehallion Link and set" is as follows:



	33-34	All four men dance one position round anti-clockwise into womens’ positions (1st man into 4th woman’s place, 4th man to 3rd woman’s place, 3rd man into 2nd woman’s place, 2nd man into 1st woman’s place.  At the same time all four women, pulling their right shoulder back dance into their own partner’s original position.  All face in.



	35-36	All set.



	37-38 All four women dance one position round anti-clockwise into womens’ positions (1st woman into 4th woman’s original place, 4th woman to 3rd woman’s place, 3rd woman into 2nd woman’s place, 2nd woman into 1st woman’s place.  At the same time all four men, pulling their right shoulder back dance into men’s position.  All face in. 



	39-40	All set. Couples will have progressed one position anti-clockwise round the set.

', 81, '8080/0808/8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17075, '2016-06-26 15:12:37.669606+00', '2016-06-26 15:12:37.669606+00', 'Highland Dabber, The', 'HIGHLAND DABBER', 3, 32, NULL, 4, 4, NULL, 2887, NULL, 'A Dabber is the local name for a person born and bred in Nantwich', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17079, '2016-06-26 15:24:02.78789+00', '2016-06-26 15:24:02.78789+00', 'Secretaries'' Reel, The', 'SECRETARIES REEL', 1, 32, NULL, 1, 4, 13, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17021, '2016-06-11 14:16:12.894787+00', '2022-04-26 01:50:34.042662+00', 'Creaky Floorboards', 'CREAKY FLOORBOARDS', 3, 32, NULL, 1, 3, 42, 11237, '2016-01-01', 'For Fiona and Michael and the warm hospitality of their creaky old house.

', 72, '884/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17024, '2016-06-11 15:57:25.266979+00', '2022-08-19 22:29:53.434833+00', 'Smouldering Teapots', 'SMOULDERING TEAPOTS', 3, 32, NULL, 1, 4, 2, 11237, '2012-06-01', '', 100, '8888/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17080, '2016-06-26 15:26:47.869004+00', '2016-06-26 15:26:47.869004+00', 'String of Pearls, A', 'STRING OF PEARLS', 4, 120, 15, 4, 4, 3, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17794, '2017-06-18 15:07:35.173256+00', '2017-06-27 23:13:52.404729+00', 'SandBJ', 'SANDBJ', 3, 32, NULL, 2, 3, 17, 11356, '2014-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17030, '2016-06-11 22:07:23.18896+00', '2021-01-06 00:09:43.627915+00', 'Angus Promenade, The', 'ANGUS PROMENADE', 3, 32, NULL, 1, 4, 2, 9998, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5529, '2002-01-08 23:00:00+00', '2021-12-04 23:42:28.756829+00', 'Reel of the Royal Scots, The', 'REEL OF THE ROYAL SCOTS', 1, 32, 9999, 1, 3, 42, 146, '1983-01-01', '##>>

A dance commissioned from the Society and devised by <<ddp:Goldring, Roy|Roy Goldring>> to celebrate the 350th anniversary in 1983 of Scotland’s oldest regiment. Along with all the other Scottish regiments, The Royal Scots have been merged into The Royal Regiment of Scotland with most of its traditions being carried on by the 1st Battalion of that regiment

##<<

', 61, '886  808  844  888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (14347, '2011-12-12 23:00:00+00', '2021-05-28 00:24:59.942299+00', 'Pumpking Baker, The', 'PUMPKING BAKER', 1, 32, NULL, 1, 3, 42, 2408, '2007-12-01', 'Devised by Craig Chamberlain and Lara Friedman-Shedlov in December 2007, based on a sequence of formations Craig thought he remembered doing before. We couldn''t find a dance that had the sequence, so we made one up. The word "pumpking" originated as a typo for the word pumpkin, but was subsequently given its own definition: "to gorge on deliciousness." ', 69, '888/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17078, '2016-06-26 15:22:06.472848+00', '2016-06-26 15:30:49.143994+00', 'Secretaties'' Gathering, The', 'SECRETATIES GATHERING', 1, 32, NULL, 3, 5, 7, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17081, '2016-06-26 15:34:28.831347+00', '2016-06-26 15:34:28.831347+00', 'Addressor, The', 'ADDRESSOR', 2, 32, NULL, 1, 4, 11, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17082, '2016-06-26 16:17:29.522653+00', '2016-06-26 16:17:29.522653+00', 'Ann''s Way', 'ANNS WAY', 3, 40, NULL, 2, 3, 18, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17083, '2016-06-26 16:19:11.823052+00', '2016-06-26 16:19:11.823052+00', 'Croquet OK Strathspey', 'CROQUET OK STRATHSPEY', 3, 32, NULL, 1, 4, 2, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17085, '2016-06-26 16:22:16.005649+00', '2016-06-26 16:22:16.005649+00', 'Double Delight, A', 'DOUBLE DELIGHT', 1, 48, NULL, 2, 3, 17, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17086, '2016-06-26 16:24:09.586511+00', '2016-06-26 16:24:09.586511+00', 'Happy to be Here', 'HAPPY TO BE HERE', 101, 32, NULL, 1, 3, 42, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17087, '2016-06-26 16:25:44.178097+00', '2016-06-26 16:25:44.178097+00', 'Norma''s Nippon Roving', 'NORMAS NIPPON ROVING', 1, 40, NULL, 1, 3, 42, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17088, '2016-06-26 16:28:13.110041+00', '2016-06-26 16:28:13.110041+00', 'OOPS!!', 'OOPS', 2, 32, NULL, 1, 3, 42, 2887, NULL, 'Unusual progression; 1c change sides on 2nd time through.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17089, '2016-06-26 16:30:26.453038+00', '2016-06-26 16:30:26.453038+00', 'Rosalind''s Diamond Delight', 'ROSALINDS DIAMOND DELIGHT', 1, 32, NULL, 1, 4, 2, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17090, '2016-06-26 16:32:44.107225+00', '2016-06-26 16:32:44.107225+00', 'Sheila and Michael''s Strathspey', 'SHEILA AND MICHAELS STRATHSPEY', 3, 32, NULL, 1, 100, 2, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17092, '2016-06-26 16:48:18.195574+00', '2016-06-26 16:48:18.195574+00', 'Belle Rosalind, La', 'BELLE ROSALIND', 1, 32, NULL, 1, 3, 42, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17093, '2016-06-26 16:49:55.429131+00', '2016-06-26 16:49:55.429131+00', 'Anita''s Engagement', 'ANITAS ENGAGEMENT', 3, 32, NULL, 4, 4, 1, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17097, '2016-06-26 16:57:56.756305+00', '2016-06-26 16:58:01.076896+00', 'Remembering Dora', 'REMEMBERING DORA', 3, 80, NULL, 2, 3, 3, 2887, NULL, 'Intro (8 bars) + 3 repeats of 24 bars.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17099, '2016-06-26 17:04:18.940895+00', '2016-06-26 17:04:18.940895+00', 'Gill''s Score and a Half', 'GILLS SCORE AND A HALF', 3, 32, NULL, 1, 4, 13, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17095, '2016-06-26 16:52:19.141446+00', '2016-06-26 17:07:20.845954+00', 'Exuberant Lass, The', 'EXUBERANT LASS', 1, 32, NULL, 1, 3, 42, 2887, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17117, '2016-06-30 21:32:36.380401+00', '2018-04-02 23:56:37.723289+00', 'Spinning Wheel, The', 'SPINNING WHEEL', 3, 32, NULL, 1, 3, 42, 11286, '2005-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17101, '2016-06-28 00:37:33.497622+00', '2016-06-28 00:39:02.109956+00', 'What Do I Do Now (Is It Up Or Down)?', 'WHAT DO I DO NOW IS IT UP OR DOWN', 1, 32, 9999, 3, 5, 7, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17118, '2016-06-30 21:36:06.263543+00', '2018-04-02 23:56:37.731661+00', 'Spirit of Gosport', 'SPIRIT OF GOSPORT', 1, 32, NULL, 1, 3, 42, 11285, '2005-09-21', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17098, '2016-06-26 17:00:51.113821+00', '2019-02-11 10:53:40.36823+00', 'Cath''s Crown of Pennies', 'CATHS CROWN OF PENNIES', 3, 32, NULL, 2, 3, 18, 2887, NULL, '', 75, '844/844/888/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17113, '2016-06-30 21:24:23.959941+00', '2018-11-04 12:54:15.321294+00', 'Southsea Bubble', 'SOUTHSEA BUBBLE', 1, 32, NULL, 1, 3, 42, 3590, '2005-05-01', '', 63, '880/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5660, '1997-04-03 22:00:00+00', '2018-04-03 00:08:13.534059+00', 'Rose Amang The Heather, The', 'ROSE AMANG THE HEATHER', 3, 40, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10911, '2002-11-03 23:00:00+00', '2018-04-03 00:08:13.871402+00', 'Royal Coachman, The', 'ROYAL COACHMAN', 2, 32, 9999, 1, 3, 42, 3206, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5777, '2001-03-13 23:00:00+00', '2018-04-03 00:08:14.217847+00', 'Russian River Reel', 'RUSSIAN RIVER REEL', 1, 32, 9999, 1, 3, 42, 401, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17102, '2016-06-30 09:40:46.126756+00', '2017-12-15 02:41:28.529992+00', 'After Eight Strathspey', 'AFTER EIGHT STRATHSPEY', 3, 32, NULL, 1, 4, 2, 11281, '2005-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5973, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.485365+00', 'Sea Crystal, The', 'SEA CRYSTAL', 1, 32, 9999, 1, 3, 42, 44, '1987-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17109, '2016-06-30 21:09:18.015621+00', '2017-05-31 10:57:09.085224+00', '''Real'' Celebration, A', 'REAL CELEBRATION', 1, 48, NULL, 1, 107, NULL, 11291, '2005-05-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17045, '2016-06-19 10:31:40.335566+00', '2018-10-25 09:58:43.343671+00', 'Hole in One, The', 'HOLE IN ONE', 1, 32, NULL, 1, 3, 42, 987, '1994-01-01', 'This dance was devised to celebrate the 60th birthday of the club’s President, Dr Roy Nelson. Roy is a keen golfer – the dance represents a successful round on the golf course!', 53, '800/844/8866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18334, '2018-05-12 20:43:53.783259+00', '2018-07-15 16:33:48.284007+00', 'Happy Together', 'HAPPY TOGETHER', 2, 32, NULL, 1, 3, 42, 11634, '2018-04-01', 'Devised by Alan Ip for Hamish Todd on the occasion of their 30th Anniversary.', 56, '800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17046, '2016-06-19 10:35:25.378319+00', '2018-10-25 01:05:52.644098+00', 'Half-Century, The', 'HALFCENTURY', 2, 40, NULL, 2, 3, 17, 987, '1992-01-01', 'Written for Lilian Morris who was 50 years young in May 1992.

Lilian was the Harwell Caledonian Society’s secretary at the time.', 50, '888/422/800/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13639, '2010-11-10 23:00:00+00', '2016-06-20 23:26:16.371648+00', 'Vienna Conspiracy, The', 'VIENNA CONSPIRACY', 1, 32, 9999, 1, 3, 42, 589, '1998-01-01', 'The first time through is lead by 1st man, the second time through in lead by 1st lady with figures reversed.



Though being a three couple dance only couples 1 and 2 are actually dancing. The standing 3rd couple represent the passive observers of the conspiracy.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17126, '2016-07-04 19:28:36.220862+00', '2020-10-19 10:03:27.313927+00', 'Forty Shades of Grey', 'FORTY SHADES OF GREY', 2, 40, NULL, 2, 3, 17, 11296, NULL, 'This dance was devised to provide a 3 couple jig, which is helpful for smaller dance groups. It does not contain setting and it does allow each of the couples an 8 bar rest at some stage of the dance, which can be helpful for the “greyheads” amongst us! The final circle round and back should also allow time to think ahead and neatly ties in with the fortieth anniversary.', 80, '880/808/088/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17116, '2016-06-30 21:30:53.359422+00', '2022-08-13 21:25:54.093042+00', 'Southsea''s Golden Year', 'SOUTHSEAS GOLDEN YEAR', 4, 128, 2, 4, 4, 54, 11287, '2005-01-01', 'Devised by Andrew Sharp and his mother Anthea to celebrate the many happy years and friendship

enjoyed while dancing at the Southsea Reel Club, 2005', 69, '8888/8888/8080/0808/4444/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17119, '2016-06-30 21:38:22.627988+00', '2022-12-04 13:15:34.261093+00', 'Teacher and the Music Man, The', 'TEACHER AND THE MUSIC MAN', 3, 40, NULL, 4, 4, 14, 11284, '2005-01-01', 'Inscribed "for Kathy and Trevor Lawman OUR teacher and Music Man on the Club''s 50th Anniversary, 2005".', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17105, '2016-06-30 20:59:49.92058+00', '2020-06-28 10:52:30.7504+00', 'Dusky Dolphins', 'DUSKY DOLPHINS', 2, 32, NULL, 3, 5, 59, 11295, '2005-01-01', '', 54, '82028/08480/80008/84846', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17051, '2016-06-23 21:18:57.755371+00', '2020-10-18 10:31:30.263975+00', 'Mr Forrester''s Strathspey', 'MR FORRESTERS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10254, NULL, '', 44, '844/880/800/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17053, '2016-06-23 21:30:14.88999+00', '2020-10-18 11:17:03.872492+00', 'Remembering Miss Cameron', 'REMEMBERING MISS CAMERON', 3, 32, NULL, 1, 4, 1, 11002, NULL, 'Miss Cameron was a beautiful dancer, and was the deviser''s first dancing teacher: she taught him when he was between the ages of seven and twelve years old', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17091, '2016-06-26 16:46:20.033648+00', '2020-10-19 09:57:48.848423+00', 'Golden Girl Reel, The', 'GOLDEN GIRL REEL', 1, 32, NULL, 4, 4, 1, 2887, NULL, '', 88, '8888/8888/4444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17084, '2016-06-26 16:20:30.324111+00', '2020-10-21 10:32:45.111098+00', 'Dancing Duo, The', 'DANCING DUO', 1, 32, NULL, 1, 4, 2, 2887, NULL, '', 75, '8888/8008/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17055, '2016-06-23 22:17:12.01455+00', '2016-06-23 22:17:23.322101+00', 'C.M. Jig, The', 'CM JIG', 2, 40, NULL, 2, 3, 18, 11275, NULL, 'Written for Christine Mair', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17056, '2016-06-23 22:22:16.702704+00', '2016-06-23 22:22:39.440764+00', 'Jimmy Boal Jig', 'JIMMY BOAL JIG', 2, 32, NULL, 1, 3, 42, 11276, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17057, '2016-06-23 22:26:25.606147+00', '2016-06-23 22:40:26.154021+00', 'Weaving Homewards', 'WEAVING HOMEWARDS', 1, 32, NULL, 1, 3, 42, 11277, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6008, '1997-04-03 22:00:00+00', '2018-04-03 00:08:15.710516+00', 'Set In The Sun', 'SET IN THE SUN', 3, 32, 9999, 1, 3, 42, 279, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17061, '2016-06-23 22:47:51.476132+00', '2016-06-23 22:47:51.476132+00', 'Beating the Bounds', 'BEATING THE BOUNDS', 2, 32, NULL, 1, 3, 42, 525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17062, '2016-06-23 22:52:19.696895+00', '2016-06-23 22:52:19.696895+00', 'Wallington Hall Medley', 'WALLINGTON HALL MEDLEY', 4, 128, 2, 1, 4, 3, 525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17065, '2016-06-23 23:00:31.28597+00', '2016-06-23 23:00:31.28597+00', 'Holy Loch Strathspey', 'HOLY LOCH STRATHSPEY', 3, 32, NULL, 3, 5, 7, 525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18417, '2018-07-19 09:51:41.137317+00', '2018-07-19 09:51:41.137317+00', 'Highland Room Hornpipe, The', 'HIGHLAND ROOM HORNPIPE', 6, 32, NULL, 1, 4, 22, 11668, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18418, '2018-07-19 09:54:27.563519+00', '2018-07-19 09:54:27.563519+00', 'Mrs MacLeod''s Ewe', 'MRS MACLEODS EWE', 7, 64, 5, 7, 117, NULL, 1751, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17044, '2016-06-19 10:27:45.216048+00', '2018-10-25 17:03:59.139414+00', 'Rimes Close', 'RIMES CLOSE', 3, 32, NULL, 2, 3, 17, 11271, '1991-01-01', 'Rimes Close was the home of Katie & Roy Nelson who hosted the club’s summer party for a number of years. In 1993 Roy was elected President of the Harwell Caledonian Society, a position he held until he was posted to Dounreay in 1997.', 83, '888/888/484/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17861, '2017-06-23 09:02:25.826237+00', '2018-04-03 00:07:56.837732+00', 'Just for Trisha', 'JUST FOR TRISHA', 2, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11165, '2003-02-10 23:00:00+00', '2018-04-03 00:08:17.077988+00', 'Sinister Haggis, The', 'SINISTER HAGGIS', 3, 40, 9999, 1, 3, 42, 27, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17123, '2016-07-04 15:00:13.952766+00', '2018-04-30 05:33:37.934838+00', 'All Roads Lead to York', 'ALL ROADS LEAD TO YORK', 2, 32, NULL, 1, 4, 2, 1582, NULL, '', 63, '8008/8808/8088/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17122, '2016-07-02 22:25:37.025059+00', '2018-07-17 00:21:42.448316+00', 'Triple Happiness', 'TRIPLE HAPPINESS', 3, 32, NULL, 2, 3, 18, 11140, '2016-01-01', 'The dance was written to celebrate the special ball of SCD group ’Mie SCDF’. ‘Mie’ is a prefecture name and means ‘Triple’.', 67, '800/880/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17127, '2016-07-04 19:35:05.064118+00', '2018-04-30 08:46:18.173461+00', 'Friday Class, The', 'FRIDAY CLASS', 3, 32, NULL, 2, 3, 18, 2623, NULL, '', 75, '800/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17128, '2016-07-04 19:39:12.733412+00', '2018-04-30 12:41:51.871563+00', 'Garrowby Hill', 'GARROWBY HILL', 2, 32, NULL, 1, 3, 42, 854, NULL, 'The dance is named after a hill east of Stamford Bridge on the York to Bridlington road, which I have strong memories of climbing slowly up in the car on the way to the various classes in Wetwang early in the Branch’s history.', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17124, '2016-07-04 15:05:01.893945+00', '2018-04-29 23:19:55.541812+00', 'Dancing for May', 'DANCING FOR MAY', 2, 32, NULL, 2, 3, 17, 11296, NULL, 'Written in memory of May Johnson, a loyal branch member who danced with us at classes,

dances, festivals and displays throughout the area', 81, '800/888/888/868', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8986, '2002-11-13 23:00:00+00', '2016-07-08 15:49:10.290832+00', 'Polka Dot Polka', 'POLKA DOT POLKA', 1, 32, 9999, 4, 55, 6, 11264, NULL, 'Five dancers in a square: head dancers 1+3, sides 2+4, 5 in centre facing 1.

Music: "Lively polka or rant".



On 8 july 2016 the author wrote to the SCDDB editors "A further update on the ''Polka Dot Polka. Although I was completely unaware at the time I made up the dance, I have been told very recently that there is actually a traditional 5 -hand reel dance mentioned in one of Thomas Hardy''s Wessex novels. As he was an accomplished fiddle player, playing for village dances, I suspect that the 5 hand reel was a genuine dance though whether it survived and the notation was ever ''collected'' I don''t know."

 ', 50, '80808/08088/80044/04840', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16842, '2016-01-11 10:29:18.343793+00', '2020-05-12 21:45:31.842485+00', 'Hillcrest''s Ruby Gem', 'HILLCRESTS RUBY GEM', 3, 32, NULL, 4, 4, 1, 10595, '2015-01-01', 'Devised for the occasion of Hillcrest’s 40th Anniversary Dance, Toronto, December 15, 2015



Published in the January 2016 issue of Set and Link by Toronto RSCDS', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17048, '2016-06-23 21:00:42.709762+00', '2020-10-18 10:22:33.904687+00', 'Dolphins in the Tay', 'DOLPHINS IN THE TAY', 1, 32, NULL, 1, 3, 42, 11002, NULL, 'The name of this dance is self-explanatory, and will strike a chord with anyone who lives by the Tay!', 67, '886/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17049, '2016-06-23 21:08:23.749763+00', '2020-10-18 10:29:04.660742+00', 'Genna''s Wedding', 'GENNAS WEDDING', 3, 32, NULL, 1, 4, 1, 11273, '2009-07-01', 'This dance was written to celebrate the wedding of Miss Genna Coutts to Mr Keith Simpson in July, 2009', 94, '6666/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17052, '2016-06-23 21:21:31.404682+00', '2020-10-18 10:34:26.738147+00', 'Miss Margaret Inglis', 'MISS MARGARET INGLIS', 1, 32, NULL, 1, 2, 76, 10254, NULL, 'Miss Margaret Inglis was the maiden name of the deviser''s mother. She was an infant teacher and musician, who tried very hard to teach her daughter the piano! She was also Stella''s first dance teacher.', 56, '80/88/84/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17072, '2016-06-26 15:07:21.817899+00', '2020-10-19 09:42:32.458323+00', 'Chester Reel of Gold', 'CHESTER REEL OF GOLD', 1, 32, NULL, 1, 3, 42, 2887, NULL, '', 59, '880/822/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17131, '2016-07-04 19:54:28.990913+00', '2020-10-19 10:10:50.264056+00', 'Strawberry Blonde', 'STRAWBERRY BLONDE', 3, 32, NULL, 2, 3, 18, 773, NULL, 'For Jessica, a graceful grand-daughter with strawberry blonde hair.', 85, '864/888/888/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17141, '2016-07-11 19:23:56.248182+00', '2022-01-30 20:21:04.509154+00', 'Trip to Applecross, A', 'TRIP TO APPLECROSS', 1, 32, NULL, 2, 2, 76, 11306, '2013-10-01', 'This dance was written on the way back from a trip to the Applecross peninsula in Scotland. The first eight bars recall the deviser wandering up and down, waiting, while her partner photographed the beautiful landscape.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17059, '2016-06-23 22:45:47.133633+00', '2020-12-06 23:19:16.095105+00', 'Peggy McAulay''s Reel', 'PEGGY MACAULAYS REEL', 1, 32, NULL, 1, 3, 42, 525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11642, '2004-01-14 23:00:00+00', '2021-01-04 17:51:50.478474+00', 'Going for a Spin', 'GOING FOR A SPIN', 2, 32, 9999, 5, 2, 76, 2018, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17132, '2016-07-04 20:00:31.25595+00', '2018-04-30 06:22:29.012268+00', 'Wetwang''s Wandering Piano', 'WETWANGS WANDERING PIANO', 1, 32, NULL, 1, 3, 42, 1415, NULL, 'The certificate training classes used to take place in the Wetwang village hall. The piano that was used was brought from another building in the village and was pulled on a trolley through the village to the hall.  As a young boy I tried to help, although I may have been more of a hindrance!', 50, '844/800/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10617, '2002-06-30 22:00:00+00', '2012-01-20 12:57:22.826999+00', 'Jig for John, A', 'JIG FOR JOHN', 2, 32, 9999, 1, 99, NULL, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11406, '2003-08-14 22:00:00+00', '2012-01-20 12:57:29.267577+00', 'Mary Grant''s Strathspey', 'MARY GRANTS STRATHSPEY', 3, 32, 9999, 1, 99, NULL, 153, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13012, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.150955+00', 'Samantha''s Delight', 'SAMANTHAS DELIGHT', 2, 32, 9999, 1, 99, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13013, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.157026+00', 'Elegant Betty Blair, The', 'ELEGANT BETTY BLAIR', 1, 32, 9999, 1, 99, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13014, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.16311+00', 'Emma''s Reel', 'EMMAS REEL', 2, 40, 9999, 1, 99, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13019, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.196248+00', 'Morag''s Reel', 'MORAGS REEL', 2, 48, 9999, 1, 99, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13020, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.202328+00', 'Mrs Arthur''s Reel', 'MRS ARTHURS REEL', 2, 40, 9999, 1, 99, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13021, '2006-11-01 23:00:00+00', '2012-01-20 12:57:43.208381+00', 'Elsie''s Jig', 'ELSIES JIG', 2, 40, 9999, 1, 99, NULL, 619, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17130, '2016-07-04 19:48:55.552087+00', '2018-09-04 13:20:34.049945+00', 'River Foss Reel', 'RIVER FOSS REEL', 1, 32, NULL, 1, 3, 42, 11297, NULL, '', 56, '888/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18419, '2018-07-19 09:57:14.441098+00', '2018-08-06 11:21:44.305156+00', 'New Scotland Beginners Strathspey and Reel Routine', 'NEW SCOTLAND BEGINNERS STRATHSPEY AND REEL ROUTINE', 7, 32, NULL, NULL, 51, NULL, 11669, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13316, '2007-08-15 22:00:00+00', '2017-02-28 21:27:25.728967+00', 'Trip to Lorient, A', 'TRIP TO LORIENT', 4, 128, 2, 1, 4, NULL, 550, '2007-01-01', 'Bars 1-4 of the RSCDS version has a single advance and retire.  Ian''s website, https://www.scottishdance.net/dances/Book/ATripToLorient.pdf has advance and retire twice.



Ian writes: I intended the strathspey to be advance for one, retire for one twice - I really like this dynamic figure, whereas advance for two retire for two always makes me believe the set is too narrow. Unfortunately during publication by the RSCDS these bars were set to the same as the corresponding bars of the quick time, and I missed this during proof-reading.



ln the quick time, it remains advance for two, retire for two once.

', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18335, '2018-05-12 21:18:15.480473+00', '2019-01-18 19:11:25.991932+00', 'Circuit of Sedbergh, A', 'CIRCUIT OF SEDBERGH', 4, 128, 2, 4, 4, 3, 11237, '2017-06-01', '', 100, '8888/8888/8888/8888/8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10623, '2002-06-30 22:00:00+00', '2018-10-18 15:08:11.816275+00', 'Twa Rigadoons', 'TWA RIGADOONS', 1, 32, 9999, 1, 2, 76, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10604, '2002-06-30 22:00:00+00', '2018-10-18 15:20:23.136154+00', 'Cherish The Ladies', 'CHERISH THE LADIES', 2, 32, 9999, 1, 3, 42, 27, '1997-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18956, '2018-10-13 19:30:16.365158+00', '2019-01-10 11:37:07.497356+00', 'Joyce MacLeod', 'JOYCE MACLEOD', 2, 32, NULL, 3, 5, 16, 11234, NULL, '', 50, '08880/04840/44844/82222', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6841, '1997-04-03 22:00:00+00', '2018-04-02 23:56:38.315583+00', 'Unravelled', 'UNRAVELLED', 1, 32, 9999, 1, 3, 42, 352, '1993-06-16', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8366, '2002-06-03 22:00:00+00', '2018-04-03 00:08:17.153086+00', 'Siwash Rock', 'SIWASH ROCK', 2, 32, 9999, 1, 3, 42, 108, '1996-01-01', 'Siwash Rock is a large rock outcrop in the Pacific Ocean at the west end of Stanley Park in Vancouver.

It is a prominent feature in the view from Simon Scott''s house. The Rock is connected in Indian Legend with the birth of a princess and the name "Sarah" also means "Princess".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17138, '2016-07-11 16:09:12.415216+00', '2018-10-14 14:01:22.629343+00', 'Mathilde is a Delight', 'MATHILDE IS A DELIGHT', 3, 32, NULL, 2, 3, 17, 11303, '2011-05-01', 'For Mathilde Tischmacher, also known as “Titisch"', 79, '888/800/888/884', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17139, '2016-07-11 19:16:02.482006+00', '2018-10-14 14:08:06.792561+00', 'Wandering Wallaby, The', 'WANDERING WALLABY', 2, 32, NULL, 1, 4, 1, 11304, '2014-11-01', 'The wallaby is a pest which eats the native vegetation where the deviser lives in rural New Zealand. It was introduced to the town as a present for a lady who lived there years ago.

', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17142, '2016-07-11 19:26:33.472484+00', '2018-10-10 20:58:22.659641+00', 'Dancing Spirit', 'DANCING SPIRIT', 2, 32, NULL, 1, 3, 42, 11139, '2014-06-01', '', 53, '822/822/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14507, '2012-07-04 13:01:49.670471+00', '2016-07-15 22:21:54.224451+00', 'Dress Parade', 'DRESS PARADE', 3, 32, NULL, 1, 4, 13, 3101, NULL, 'The dance begins with two couples on each side of a longwise set, men with partners on their right.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17143, '2016-07-11 19:30:43.386428+00', '2018-10-14 11:27:11.611004+00', 'Baratte your Way Home, La', 'BARATTE YOUR WAY HOME', 1, 40, NULL, 4, 4, 4, 11307, '2014-08-01', '', 80, '8080/0808/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12321, '2005-04-27 22:00:00+00', '2016-09-30 14:42:49.818811+00', 'Miss Lucy Clark', 'MISS LUCY CLARK', 1, 32, 9999, 1, 3, 42, 805, NULL, '', 66, '880/888/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2448, '1997-04-03 22:00:00+00', '2016-07-14 09:13:20.046736+00', 'George Square of Edinburgh', 'GEORGE SQUARE OF EDINBURGH', 2, 96, 9999, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17134, '2016-07-10 10:14:04.287374+00', '2020-10-21 20:01:34.567206+00', 'There''s Something about Thirty', 'THERES SOMETHING ABOUT THIRTY', 3, 32, NULL, 2, 3, 17, 11154, '2014-04-01', 'For Thomas Ibbotson’s 30th birthday.

', 67, '800/844/888/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17140, '2016-07-11 19:18:34.089432+00', '2020-10-21 20:07:24.88277+00', 'Double Trouble Triangles', 'DOUBLE TROUBLE TRIANGLES', 1, 48, NULL, 1, 4, 2, 10759, '2014-04-01', '', 74, '7007/8448/8448/8888/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10618, '2002-06-30 22:00:00+00', '2021-01-25 16:31:21.207821+00', 'Margaret''s Fancy', 'MARGARETS FANCY', 3, 32, 9999, 1, 99, NULL, 28, NULL, '<<scddb-not-identical:4158;13028>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17147, '2016-07-12 22:20:42.812404+00', '2021-08-16 08:16:53.576965+00', 'I Can''t Make It Any Easier', 'I CANT MAKE IT ANY EASIER', 3, 32, NULL, 1, 3, 42, 10333, NULL, 'For Bill Forbes on the occasion of his 90th birthday



"I can''t make it any easier" is something that Bill sometimes says when we at St. John''s are making a bit of a meal over picking up a dance that he is trying to teach.  Hopefully the description of this dance is easy to follow.', 59, '880/888/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15441, '2014-05-09 22:33:18.41509+00', '2020-12-29 19:33:23.102961+00', 'Phoenix Rising', 'PHOENIX RISING', 3, 32, 9999, 4, 4, 13, 2927, NULL, 'Dedicated to the memory of Bobby Brown who wrote the signature tune, Mrs. Francis Carol Brown, and in celebration of Laird’s leadership of his new band, Scotch Mist, into its bright future.', 88, '8080/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17149, '2016-07-12 23:34:39.757748+00', '2021-02-25 14:48:02.668506+00', 'De Walden Court', 'DE WALDEN COURT', 3, 32, NULL, 2, 3, 17, 3086, '2001-01-01', 'De Walden Court is in Eastbourne and the Strathspey was given as a gift to Elaine Montgomerie.  



This dance had its debut at the annual Tartan Ball in Sussex on May 12th, 2001.', 56, '880/808/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6337, '1998-04-19 22:00:00+00', '2016-09-09 22:42:49.109127+00', 'Strathclair', 'STRATHCLAIR', 3, 32, 9999, 1, 3, 42, 121, '1983-01-01', 'An original text has "(Ann Riley''s Strathspey) added in handwriting in the index.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17121, '2016-07-02 16:58:34.646982+00', '2022-04-15 22:30:33.859964+00', 'Forty and Counting', 'FORTY AND COUNTING', 1, 40, NULL, 1, 3, 42, 635, '2015-09-01', 'Danced at RSCDS York and North Humberside branch 40th anniversary ball, November

2015', 52, '800/888/822/888/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2447, '1997-09-03 22:00:00+00', '2016-07-14 09:14:27.991248+00', 'George Square of Edinburgh', 'GEORGE SQUARE OF EDINBURGH', 1, 96, 9999, 4, 119, 3, 86, NULL, 'The following text, contributed by a SCDDB user, gives more details than the text describing the dance.  I am searching for more information.  Eric



A)

1-8 All dance 8 bar right shoulder reels of 3 on own sides of square 

9-24 Wheels - All dance 3 hands across, R.H., then men move one place to the right - ladies change hands and all dance L.H. across - man leaves this wheel and dance on one place - ladies change hands and all dance R.H. across - Men leave this wheel and dance on one place - Ladies again change hands and all dance L.H. across 

25-32 All dance a left shoulder reel on own side of the square. (lady on the left has a change of direction to start this reel.) 



B)

1-8 Man, with R.H. lady face to the right, in promenade hold, while L.H. lady faces opposite direction - All dance half Grand Chain, couples dancing out and singles dancing in i.e. passing left shoulder to start. At half-way point dance R.H. across (man and his two ladies) 

9-16 Men keep dancing in same direction, but changing to L.H. lady in promenade hold, while R.H. lady dances chain movement back to own place and dance 3-hands across L.H. on own sides of the square. 

17-24 All right hand ladies dance Ladies'' Chain across and back, forming R.H. wheel in centre and turning opposite man, left hand etc. 

25-32 All left hand ladies repeat above formation : but dancing into centre to give L.H. across and turning opposite man, right hand. 



C) 

1-8 Sides 1 and 3 - turn opposite person by right hand (4 bars), set to each other (2 bars) and cast back to places by the right (2 bars) 

9-16 Sides 2 and 4 repeat above sequence

 17-24 All ladies advance (2), and join hands in circle, then retire (2) Advance again (2) joining hands in circle and set (2) (underlined section) WHILE Men set (2), Advance (2) and turn by the right and dance out to place (2) and start dancing round the outside of the square anti-clockwise 

25-32 Men continue dancing round the outside and finish facing own ladies WHILE ladies circle left with 12 slip steps and cast into own places on last 2 bars.



', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9674, '2000-09-18 22:00:00+00', '2016-07-15 17:30:58.301828+00', 'Rocky Road Reel, The', 'ROCKY ROAD REEL', 1, 32, 9999, 103, 113, 1, 1268, '1993-01-01', 'For as many couples as will.



Written in 1993 for the Minnetonka Ice Cream Social.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16658, '2015-08-27 17:55:21.528269+00', '2017-05-31 10:54:47.981954+00', 'Nova Scotia Tea Dance, A', 'NOVA SCOTIA TEA DANCE', 2, 32, NULL, 1, 4, 1, 10568, '2013-05-01', '*The progression in Miss Hadden ʼs Reel – what the TAC candidate class of 2012 called

ʻthe Flype ʼ. Lydia Hedge asked for a dance with the Flype in it.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17135, '2016-07-10 12:47:50.464849+00', '2016-07-23 19:39:52.737851+00', 'Fifty Roses for Eva', 'FIFTY ROSES FOR EVA', 3, 32, NULL, 1, 3, 42, 11164, '2016-07-01', 'DEVISED:2016-07



This dance was devised to celebrate the 50th birthday of Eva Schiedrum in 2016.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3406, '1998-01-05 23:00:00+00', '2018-04-03 00:07:56.996329+00', 'Kathy''s Double Celebration', 'KATHYS DOUBLE CELEBRATION', 1, 48, 9999, 1, 3, 42, 351, NULL, 'This dance is dedicated to a friend of mine, Miss Katherine Dressier (now Dr. Katherine Chino), who when it was devised had just survived her first year of medical school and had also just gotten engaged.  Bars 1-16 and 17-24 represent the precision required in medical study and a trip down the aisle; then come double wheels, double figure eights, and double triangles.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13827, '2011-08-05 22:00:00+00', '2016-07-27 18:50:49.519869+00', 'Reel Easy', 'REEL EASY', 1, 32, NULL, 1, 3, 42, 3371, NULL, 'This dance was devised to teach reels on the side. Setting before and after the reels prepares the dancers to start the reels and allows for a chance to regain orientation after completion

', 56, '880/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11388, '2003-07-06 22:00:00+00', '2019-03-16 14:52:20.635251+00', 'Robin Hood''s Quarterstaff', 'ROBIN HOODS QUARTERSTAFF', 1, 32, 9999, 2, 3, 18, 48, NULL, 'This is a demonstration dance for 3 couples in a longwise 3-couple set.

After 32 the set is rotated by 90 degrees. Despite the number of dancers, it is danced 4 times through to get back to the original orientation of the set. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6150, '2002-03-03 23:00:00+00', '2016-08-29 22:40:32.865792+00', 'Sleeping Warrior, The', 'SLEEPING WARRIOR', 3, 32, 9999, 1, 102, 2, 175, '1973-01-01', 'First published by the SD Archives january 1973



Note (by the deviser): On bars 15-16, of the Allemande, 1c and 4c may turn their P once round LH, into the Left Hands Across. ', 87, '8448  8888  8448  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (17151, '2016-08-08 00:10:27.002867+00', '2019-06-20 21:55:25.039752+00', 'Miss Gabrielle''s Reel', 'MISS GABRIELLES REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, 'Miss Gabrielle was the daughter of Victor Laidlaw who was the drummer for the Lothian Band for many years.

', 56, '800/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13516, '2009-11-29 23:00:00+00', '2016-08-05 14:55:35.432171+00', 'Pitcarnie Hornpipe, The', 'PITCARNIE HORNPIPE', 1, 32, 9999, 3, 5, 7, 2677, NULL, 'This dance was devised for Fred Moyes and Christine Basnett of London, Ontario.



(Source: a copy of this dances was published in the "Dance On!" magazine together with the above information.)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13545, '2009-12-16 23:00:00+00', '2016-08-05 14:56:35.192994+00', 'Northmuir Jig', 'NORTHMUIR JIG', 2, 32, 9999, 1, 4, 2, 11311, '1998-01-01', 'A copy of this dances was published in the "Dance On!" magazine.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12390, '2005-04-28 22:00:00+00', '2018-04-03 00:08:17.670173+00', 'Someplace Else', 'SOMEPLACE ELSE', 2, 32, 9999, 1, 3, 42, 3593, '1992-07-11', 'Dance devised in celebration of the wedding of my daughter Katrina to Derek Murphy, 11th July, 1992.   The reception was held at the Conference facility called Someplace Else.   This was only the second Saturday that didn’t rain that June and July, whew what a relief.



The music is recorded on the CD Hoogie as the first tune in the selection Good Morning Jigs;  Katrina has always been a morning person and full of life, so this was an obvious choice, even the cheery Good Morning on the recording could be her on Christmas Morning. ', -1, '', 1, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (17198, '2016-09-03 16:23:34.901186+00', '2019-09-13 20:40:38.978471+00', 'Mr Cosgill''s Delight TRANSFER LINKS TO DANCE 1342', 'MR COSGILLS DELIGHT TRANSFER LINKS TO DANCE 1342', 1, 16, NULL, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7604, '1998-04-29 22:00:00+00', '2016-09-04 20:59:28.171454+00', 'Banks Hornpipe', 'BANKS HORNPIPE', 1, 32, 9999, 1, 3, 42, 101, NULL, 'To Julie Smith, who made possible our first visit to Pinewoods.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18065, '2017-11-13 15:10:37.677949+00', '2017-11-13 15:10:37.677949+00', 'Tying the Knot', 'TYING THE KNOT', 1, 40, NULL, 1, 4, 1, 11032, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5426, '1998-10-26 23:00:00+00', '2021-02-14 17:39:53.844293+00', 'Queen''s Bridge', 'QUEENS BRIDGE', 1, 40, 9999, 1, 4, 1, 1213, '1960-01-01', 'According to the leaflet, the dance was devised by Mrs Anne Wishart and John Williamson and published by The Perth Branch of The Royal Scottish Country Dance Society to commemorate the 1960 Annual General Meeting.



The Music in the leaflet was composed and arranged by Derek Auld.

', 85, '8888/8888/8000/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17145, '2016-07-12 22:02:09.779673+00', '2021-08-16 10:22:27.017165+00', 'Nonagenarian, The', 'NONAGENARIAN', 2, 32, NULL, 1, 3, 42, 104, NULL, 'For Bill Forbes on the occasion of his 90th birthday  



Recommended Tune: The 1921 Jig by Alistair Forbes And recorded music: North American Jigs found on CD Free Spirit by Sound Company', 50, '844/822/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17150, '2016-07-28 22:23:49.704149+00', '2021-04-25 16:38:44.704752+00', 'Registrar, The', 'REGISTRAR', 3, 32, NULL, 1, 3, 42, 3703, NULL, 'Devised by Pam Stephens and friends to honor Fred Eustis, longtime registrar for Scottish Weekend and Scottish Weekend guru. Fred’s patience and hard work, his love of the music and dancing, and the friendship he brings to Scottish Weekend have made it a wonderful experience for all.', 53, '800/844/888/866', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17212, '2016-09-03 16:51:53.123556+00', '2016-09-03 16:51:53.123556+00', 'Starboard Homeward', 'STARBOARD HOMEWARD', 1, 32, NULL, 1, 3, 42, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17217, '2016-09-03 16:59:26.347508+00', '2016-09-03 16:59:26.347508+00', 'Quarry Triumphant, The', 'QUARRY TRIUMPHANT', 2, 32, NULL, 1, 3, 42, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17240, '2016-09-04 09:23:23.298363+00', '2016-09-04 09:29:40.512833+00', 'Among the Cheviot Hills', 'AMONG THE CHEVIOT HILLS', 2, 32, NULL, 2, 3, 17, 11325, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (812, '1997-04-03 22:00:00+00', '2016-09-04 21:08:41.547136+00', 'Bringing Home The Bride', 'BRINGING HOME THE BRIDE', 4, 32, 1, 1, 3, 42, 351, NULL, 'This dance should be for when a Scottish man marries a non-Scottish woman, but there have been no such weddings in the Boston Branch since I devised it! (The sexes are dictated by the standard direction for a two-hand tum.)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17192, '2016-08-22 14:15:11.831344+00', '2016-10-16 15:47:26.509626+00', 'Three Teapot Mix', 'THREE TEAPOT MIX', 1, 32, NULL, 3, 5, 7, 3066, '2016-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5569, '1998-04-19 22:00:00+00', '2016-08-13 15:39:39.104207+00', 'Riders Of Rohan, The', 'RIDERS OF ROHAN', 1, 40, 9999, 1, 3, 42, 44, '1971-01-01', 'Note by the deviser.



Devised during the last week of July, 1971.



This dance was originally devised after Noeline challenged me to devise a ''really real reel'' - a dance

consisting of reels only. Under the circumstances an alliterative title was unavoidable.



At the end of bar 78 (ie. at the end of the reel of three with comers during the second time through)

fourth couple finish in original places facing out. On bars 79-80 first couple lead down with left

hands and cross over between fourth couple while fourth couple dance up to third place.



Rohan (''Land-of-Horses'') was a realm of Men north of the White Mountains - originally a province

of Gondor. It was a fair country of vast grasslands - ideal for the rearing and breeding of horses.



The inhabitants were known in Gondor as the Rohirrim (''Masters-of-Horses'') - the Riders of Rohan much respected for their loyalty and bravery. A white horse upon green was the emblem of these people.', 78, '888/888/844/844/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (395, '1997-04-03 22:00:00+00', '2018-03-31 17:43:14.364734+00', 'Banks of the Dee, The', 'BANKS OF THE DEE', 5, 32, 9999, 1, 2, 76, 351, NULL, 'The name is a pun-D for Danube, of course.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18420, '2018-07-19 09:59:39.187174+00', '2018-07-19 09:59:39.187174+00', 'It takes a Village', 'IT TAKES A VILLAGE', 1, 32, NULL, 1, 4, NULL, 11670, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17194, '2016-08-22 16:55:08.574092+00', '2016-08-22 21:16:01.469855+00', 'Kristi''s Conundrum', 'KRISTIS CONUNDRUM', 2, 32, NULL, 1, 3, 42, 1331, '2016-01-01', 'Bruce Herbold adds:  



This dance is dedicated to and inspired by my friend Kristi Closser. Kristi went through the teacher training for Scottish country dance and I was one of her trainers.  One week Kristi was to teach Double Triangles and she started with a very normal exercise of setting and pivoting round, as the first couple does in the middle of Double Triangles; unfortunately she had people practice in the order, travel round, set, travel round and set. The next session she was to teach circle four hands round and back into Allemand; she taught very clearly to circle to the right and back to the left, only having to worry about one set of dancers who insisted circling to the left(!).  The resulting transition into Allemand went so smoothly that it wasn’t until the debriefing that she realized that most circles begin to the left.   It turns out that Kristi, Tim Wilson and I all went home that night and wrote dances to capture and celebrate this smoothly flowing variation.  This is my effort.

', 50, '880/880/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17213, '2016-09-03 16:52:56.065054+00', '2016-09-03 16:52:56.065054+00', 'Stockhill House', 'STOCKHILL HOUSE', 3, 32, NULL, 2, 3, NULL, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17241, '2016-09-04 09:36:01.817475+00', '2016-09-04 09:36:07.664761+00', 'Anniversary, The', 'ANNIVERSARY', 3, 32, NULL, 1, 4, 2, 11326, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17152, '2016-08-11 16:32:23.68064+00', '2019-04-26 13:39:11.970837+00', 'Altamont Fair', 'ALTAMONT FAIR', 1, 32, NULL, 1, 3, 42, 1167, NULL, '', 47, '800/888/822/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17193, '2016-08-22 14:17:06.2719+00', '2018-04-02 23:56:38.040365+00', 'Tiia the Trucker', 'TIIA THE TRUCKER', 2, 48, NULL, 1, 3, 42, 3286, '2011-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17186, '2016-08-22 07:54:39.912535+00', '2017-02-05 13:58:30.438589+00', 'Long John Diamond', 'LONG JOHN DIAMOND', 3, 32, NULL, 1, 100, 2, 10496, '2014-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17246, '2016-09-04 10:30:48.678036+00', '2016-09-04 10:31:32.858253+00', 'Four Branches, The', 'FOUR BRANCHES', 1, 32, NULL, 1, 4, 1, 11330, NULL, 'This dance celebrates the four RSCDS branches of Southern California, and the many memorable dances and workshops they collaborate to sponsor. Bars 9-16 are meant to resemble the branches of a tree sprouting up from the bottom of the set. Cooperation of the four “branches” helps to make this formation work. Bars 13-16 should be a smooth curving figure for couples 1, 2 and 3. When they reach the sideline, they should drop hands, then continue curving, cast off one place with the lower dancer of each couple leading the way and crossing to their own side. Their partners follow but don''t cross over. It should be a smooth, continuous curving 4-bar fig', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17245, '2016-09-04 10:21:05.238931+00', '2018-10-20 21:47:14.766415+00', 'Down Under, Hands Up!', 'DOWN UNDER HANDS UP', 2, 32, NULL, 1, 3, 42, 11740, NULL, 'This dance was inspired by a trip taken by several American dancers to Australia in April 2015. The first

8 bars represent us circling the airport parking area repeatedly to pick up a late arrival. The second

figure represents the "hands up" figure our Sydney instructor used. The final figure (and variations of it)

was the signature of Robert Templeton, from Tasmania, who introduced us to several of his dances.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4721, '1997-09-09 22:00:00+00', '2016-09-04 20:52:04.604333+00', 'Mr Scatterday''s Grace and Mrs Scatterday''s Glen', 'MR SCATTERDAYS GRACE AND MRS SCATTERDAYS GLEN', 4, 32, 1, 2, 3, 17, 480, NULL, 'To Grace and Glen Scatterday, on the occasion of their leaving Burlington for Dallas, Texas,

where they continue to be active in Scottish Country Dancing.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2852, '1997-09-03 22:00:00+00', '2016-09-04 20:55:00.513731+00', 'Helen & Russell''s Farewell to 10 1/2 Dan Court', 'HELEN AND RUSSELLS FAREWELL TO 10 1/2 DAN COURT', 4, 64, 5, 4, 4, NULL, 480, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17249, '2016-09-04 10:49:04.957851+00', '2018-09-13 21:11:07.773412+00', 'Janet Rennie''s Strathspey', 'JANET RENNIES STRATHSPEY', 3, 32, NULL, 1, 3, 42, 629, NULL, 'Janet Rennie (nee Bennet) was a Highland and country dancer as a girl in Scotland. She also played the fiddle in her father’s band. After immigrating to California in 1961 she became an active dancer in the Los Angeles Branch RSCDS often entertaining at ceilidhs with her fiddle.



', 56, '800/866/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6210, '1997-09-14 22:00:00+00', '2021-04-13 22:53:05.91068+00', 'South From Oban', 'SOUTH FROM OBAN', 2, 40, 9999, 1, 3, 42, 1103, NULL, '', 48, '550/550/880/808/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4875, '1997-09-10 22:00:00+00', '2021-05-03 09:18:05.746405+00', 'My Wife''s A Winsome Wee Thing', 'MY WIFES A WINSOME WEE THING', 2, 32, 9999, 1, 3, 42, 636, NULL, 'Dedicated to Betty Sweeney Moretti -- my own winsome wife.', 44, '800  888  800  844', 1, 1, 0, 1, 58);
INSERT INTO 'dance' VALUES (3387, '1998-01-05 23:00:00+00', '2021-05-22 19:13:49.423953+00', 'Just For Fun', 'JUST FOR FUN', 1, 32, 9999, 1, 3, 42, 259, '1970-01-01', 'This dance was first published in the Tartan Times, sometime around 1970', 53, '800/888/888/822', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17199, '2016-09-03 16:25:14.167357+00', '2019-09-13 20:52:01.824281+00', 'Mrs Booth''s Minuet TRANSFER LINKS TO DANCE 1484', 'MRS BOOTHS MINUET TRANSFER LINKS TO DANCE 1484', 50, 32, NULL, 1, 2, NULL, 9998, NULL, 'A Minuet', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6350, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.73768+00', 'Strathspey for Barbara', 'STRATHSPEY FOR BARBARA', 3, 32, 9999, 1, 3, 42, 1293, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7960, '1997-09-14 22:00:00+00', '2018-04-03 00:08:18.787718+00', 'Strathspey for Nan Main, A', 'STRATHSPEY FOR NAN MAIN', 3, 32, 9999, 1, 3, 42, 521, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17196, '2016-09-03 16:20:24.311072+00', '2019-09-13 21:07:33.732365+00', 'Drapers Maggot TRANSFER LINKS TO DANCE 1484', 'DRAPERS MAGGOT TRANSFER LINKS TO DANCE 1484', 5, 32, NULL, 1, 2, NULL, 9998, NULL, 'This dance is identical to the dance Mrs Booth''s Minuet in this same book (page 54), there are some minor differences in the wording.



', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18214, '2018-01-13 12:08:04.34376+00', '2019-04-29 22:29:29.480509+00', 'Back in the Day', 'BACK IN THE DAY', 2, 48, NULL, 1, 4, 1, 3491, '2016-05-01', 'Suggested music: ''Airdrie Lasses'' Track 8 on An Angus Welcome Deirdre Adamson Quartet.  



Devised by Jill Memory, May 2016.  



The name was suggested by thinking back to 1968 and the energy levels of youth. The Peter White movement with its casting behind just seemed to fit.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14533, '2012-08-15 08:57:44.258822+00', '2016-08-16 14:40:00.818691+00', 'Castle of Mey, The', 'CASTLE OF MEY', 1, 32, NULL, 1, 3, 42, 403, NULL, '»The Castle of Mey was Queen Elizabeth the Queen Mother''s residence in the far north of Scotland where she spent some time during each year. After her death it was opened to the public.«



Note (additional to the book and the Manual). collected by Helen Russell from staff teaching The Diamond Jubilee book at Summer School 2012. 



16	2nd couple finish the double figure of eight flat.



At Summer School the dance was taught and completed in the traditional way i.e. at the end of the second time through with 1st couple stepping out and down. The new 3rd couple entered the reels from 4m place this caused no problems.  



However we have since learned that the deviser intended that ... "1st couple on bars 7 -8 of the poussette would dance down nearer hands joined to fourth place, while 4th couple steps up ready for the reels", but it appears that these notes were not included in the script sent in for publication.







', 50, '888/880/800/880', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (13636, '2010-11-10 23:00:00+00', '2018-04-03 00:08:19.446506+00', 'Sweeney''s Farewell to Vienna, The', 'SWEENEYS FAREWELL TO VIENNA', 2, 32, 9999, 1, 3, 42, 10291, NULL, 'A Note from "The Vienna Book":  

This dance was devised by Robert Finan, Julia Kelemen and Beatrix Wepner for Ian (a.k.a. John) and Mairead Sweeney, who danced in Vienna while working at the British Embassy.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18421, '2018-07-19 10:00:31.130313+00', '2018-07-19 10:00:31.130313+00', 'Vizla Quadrille, The', 'VIZLA QUADRILLE', 2, 48, NULL, 4, 4, NULL, 11668, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1274, '1999-11-01 23:00:00+00', '2016-08-22 20:32:26.217704+00', 'Cold and Raw', 'COLD AND RAW', 2, 24, 9999, 1, 2, 76, 9998, '1718-01-01', 'Dancers should know that the text for bars 17-20 was changed in 2008.   

 

The original text in Playford (1718) specifes that for [9-12] the M pass their P Rsh, but for [17-20] only says "the women doing the like", leaving unclear which shoulder to use.



RSCDS book 5 (published in 1928), the Pocket Editions of 1954 and 1986, and the 2006 edition of book 5, use the wording “2nd and 1st man stand still while 1st woman dances round and below her partner into 2nd woman’s original place, and 2nd woman dances round and below her partner into 1st woman’s original place. (1st woman dances in front of 2nd woman).”  This is not unambiguous, but seems to imply that the women dance LEFT shoulder round their partner.  TACnotes (5th edition, 2008) says this explicitly.  



The revised “combined A5 edition” of Books 1–6, uses the wording “1st woman dances across the set below her partner, behind him and across to 2nd woman’s original place.  At the same time 2nd woman dances below her partner, behind him and across to  1st woman’s original place.  1st woman dances in front of 2nd woman to begin.” This makes explicit that the women dance RIGHT shoulder round their partner.  This flows far better into the hands round that follow.



This entry to SCDDB (Cribs and diagram) follows the currently official 2008 text.

', 57, '88/66/66', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (18624, '2018-09-17 18:56:41.774581+00', '2018-09-17 22:25:40.366211+00', 'All Right Bob', 'ALL RIGHT BOB', 3, 32, NULL, 2, 3, 17, 11270, '2010-01-01', 'This dance was composed in the autumn of 2010 following ‘an incident’ which left our treasurer (Bob) unable to take left hands with other dancers for some period.', 63, '800/864/846/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17202, '2016-09-03 16:32:50.775383+00', '2016-09-03 16:32:55.023487+00', 'Flick O'' The Kilt', 'FLICK O THE KILT', 1, 32, NULL, 2, 3, NULL, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17204, '2016-09-03 16:36:28.980616+00', '2016-09-03 16:36:32.054698+00', 'Glancing Eyes', 'GLANCING EYES', 3, 32, NULL, 2, 3, NULL, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17207, '2016-09-03 16:43:29.601127+00', '2016-09-03 16:43:33.004279+00', 'Jeannie''s Awa''', 'JEANNIES AWA', 3, 32, NULL, 1, 4, NULL, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17200, '2016-09-03 16:26:48.847373+00', '2019-09-13 23:09:28.955244+00', 'Richmond Ball TRANSFER LINKS TO DANCE 4712', 'RICHMOND BALL TRANSFER LINKS TO DANCE 4712', 1, 32, NULL, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17209, '2016-09-03 16:47:21.952737+00', '2016-09-03 16:47:21.952737+00', 'Lizzie Mickerys Reel', 'LIZZIE MICKERYS REEL', 1, 32, NULL, 1, 3, 42, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17197, '2016-09-03 16:22:08.582252+00', '2019-09-13 23:07:41.425082+00', 'Mr Beveridge''s Maggot TRANSFER LINKS TO DANCE 2012', 'MR BEVERIDGES MAGGOT TRANSFER LINKS TO DANCE 2012', 50, 16, NULL, 1, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17216, '2016-09-03 16:57:37.634366+00', '2016-09-03 16:57:37.634366+00', 'Powdered Quaker', 'POWDERED QUAKER', 3, 32, NULL, 2, 3, NULL, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14537, '2012-08-15 09:13:13.896176+00', '2020-10-01 20:57:06.858396+00', 'Burnaby at Forty', 'BURNABY AT FORTY', 3, 40, NULL, 4, 4, 1, 10644, NULL, 'Devised for the 40th anniversary of the Burnaby SCD Club.



Note (additional to the book and the Manual). Collected by Helen Russell from staff teaching The Diamond Jubilee book at Summer School 2012. 



21 - 24, 29 - 32, 33 - 40    Long steps to cross diagonally, shorter steps to cast.

', 80, '6666  6666  6666  6666  8888', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (12449, '2005-06-05 22:00:00+00', '2020-10-13 19:32:01.482042+00', 'Rocky Mountain Reel, The', 'ROCKY MOUNTAIN REEL', 1, 32, 9999, 1, 100, 2, 1727, NULL, '', 75, '8008/8888/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17175, '2016-08-19 20:12:02.710765+00', '2020-10-22 20:30:53.220827+00', 'Ken and Tula''s Reel', 'KEN AND TULAS REEL', 1, 32, NULL, 1, 3, 42, 2627, '2016-06-17', 'Devised for the wedding of Ken Martlew to Petula Allen, 3 September 2016.  Ken wanted a lively reel to fit the music he originally composed for Links to St Petersburg.  For a young and energetic 1st couple the crossing into the second half of the reel can become a birl, to make it even more lively.', 56, '844 866 822 888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17211, '2016-09-03 16:50:43.985274+00', '2020-10-23 08:57:31.70109+00', 'Rolverdon Reel', 'ROLVERDON REEL', 1, 32, NULL, 2, 2, 76, 10995, NULL, '', 54, '55/55/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17206, '2016-09-03 16:40:22.019625+00', '2021-04-03 11:06:49.062847+00', 'Itchen Abbas', 'ITCHEN ABBAS', 4, 192, 10009, 2, 3, 17, 10995, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17242, '2016-09-04 09:45:42.264458+00', '2016-09-04 09:46:47.293649+00', 'Any Which Way', 'ANY WHICH WAY', 2, 40, NULL, 1, 4, 2, 11327, NULL, 'The original description includes a version for a 3-couple set; bars 17-32 are modified.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18422, '2018-07-19 10:01:54.235702+00', '2018-07-19 10:01:54.235702+00', 'Give Yourself a Wee Shake', 'GIVE YOURSELF A WEE SHAKE', 3, 32, NULL, 1, 3, NULL, 518, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9615, '2000-09-05 22:00:00+00', '2016-09-03 19:19:57.308815+00', 'Right and a Wrong Way, A', 'RIGHT AND A WRONG WAY', 3, 32, 9999, 1, 4, 1, 35, NULL, 'Mrs. Ysobel Stewart of Fasnacloich, and Miss Jean C. Milligan of Glasgow, worked together to make SCD socially popular again. SCD was in a sorry, chaotic state. Dances were done differently in different areas, and the general tone was rough and anti-social. They succeeded in establishing standardized technique based on thorough research through old manuscripts. Then the first book of selected dances was published by Mr. Diack of Pattersons Publishing Company, free of charge, 6 chosen by Miss Milligan, and 6 by Mrs. Stewart, and a new era in SCD was begun. 



Now that SCD is so well supported, there is SCD in nearly every country, books of dances and a standard method of teaching so that technique is the same all over the world. Therefore, when travelling, one can walk into any class and be able to take part. Miss Milligan met a Japanese gymnast who was making a world-wide study of Physical Education. He proceeded to go SCD mad and from then on they say, he ran fantastic SCD classes in Japan. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17522, '2017-01-04 17:58:59.448189+00', '2019-06-28 15:27:07.85396+00', 'Welcome to the Ceilidh', 'WELCOME TO THE CEILIDH', 1, 32, NULL, 5, 56, NULL, 11110, '2003-02-01', 'For the Ceilidh in support of The Portsmouth Area Hospice.', 92, '888/484/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14532, '2012-08-15 08:23:20.65402+00', '2016-08-16 15:12:49.864393+00', 'Royal Patron, The', 'ROYAL PATRON', 1, 32, NULL, 1, 3, 42, 10643, NULL, '»Devised as a tribute to our gracious Patron Her Majesty Queen Elizabeth II and dedicated to Robert H Mackay who suggested the title and the original tune.«



There is a typo in the tune title in the book – the place is called »Ardnilly« according to the original publication by Wm. Marshall.



## The following notes were put forward by Andrew McConnell in the Fully Certificated Class at St Andrews Summer School 2012, Week 4:



##1-8:: 1st woman dances slightly in to begin to help phrasing. 1st couple should be dancing through women''s sidelines at end of bar 4 and covering until end of bar 8.  

##13-16:: 1st couple as they are turning are slightly below 3rd couple, but must finish facing 3rd couple. 1st woman must be careful to avoid finishing facing 4th man.

##25-32:: At the end of the half reel of four, 1st couple must finish reasonably far apart from each other. The left hand turn is a wide, slow turn. On bar 32, 1st and 2nd men and 1st and 2nd women should cover as they dance out to the sidelines. 1st woman stays facing out to begin next turn.



Note (additional to the book and the Manual). collected by Helen Russell from staff teaching The Diamond Jubilee book at Summer School 2012. 



4            1st couple should be on women''s sideline at the end of bar 4.



13 -16   To begin the turn, the man takes a long step down towards his partner. 1st couple finish shoulder to shoulder facing 3rd couple, not back to back, as stated in the original instructions.



21 -24   3rd couple need to remember to set and cross.



29 -32   This is a tum requiring short steps. At the end of this left hand turn the 1st woman may stay facing out ready to cast. 2nd couple need to remember to set and cross.



', 50, '800  888  808  880', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (18424, '2018-07-19 10:04:59.071315+00', '2018-07-19 10:04:59.071315+00', 'Wanderlust', 'WANDERLUST', 3, 32, NULL, 1, 4, 11, 11667, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17171, '2016-08-17 18:01:00.101788+00', '2018-04-03 00:08:09.072083+00', 'On the Promenade', 'ON THE PROMENADE', 1, 32, NULL, 1, 3, 42, 2823, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17182, '2016-08-22 07:45:00.02021+00', '2018-04-02 23:56:35.243447+00', 'How Does It Start?', 'HOW DOES IT START', 2, 40, NULL, 1, 3, 42, 11318, '2016-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18425, '2018-07-19 10:05:53.348032+00', '2018-07-19 10:05:53.348032+00', 'Bad Man of Badaquish, The', 'BAD MAN OF BADAQUISH', 2, 32, NULL, 1, 2, NULL, 10720, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17183, '2016-08-22 07:47:08.916963+00', '2018-04-02 23:56:35.348162+00', 'Isla', 'ISLA', 2, 40, NULL, 1, 3, 42, 10498, '2016-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18427, '2018-07-19 10:39:48.399+00', '2018-07-19 10:39:48.399+00', 'Cathy McLeod of Graceville', 'CATHY MACLEOD OF GRACEVILLE', 3, 40, NULL, 4, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17172, '2016-08-17 18:02:10.537163+00', '2018-04-03 00:07:39.297993+00', 'Computer Knight Errant, The', 'COMPUTER KNIGHT ERRANT', 1, 32, NULL, 1, 3, 42, 2823, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17161, '2016-08-17 17:50:38.086056+00', '2016-08-17 17:51:59.387429+00', 'Monkey''s Fist, The', 'MONKEYS FIST', 3, 32, NULL, 4, 4, NULL, 2823, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17158, '2016-08-17 17:45:42.882035+00', '2018-04-03 00:08:14.876574+00', 'Sandbox Sailor, The', 'SANDBOX SAILOR', 1, 32, NULL, 1, 3, 42, 2823, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17153, '2016-08-17 17:20:27.113843+00', '2018-04-03 00:07:46.004063+00', 'Fisherman''s Daughter, The', 'FISHERMANS DAUGHTER', 2, 32, NULL, 1, 3, 42, 2823, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17170, '2016-08-17 18:00:18.042386+00', '2016-08-17 18:00:18.042386+00', 'Norfolk Exchange, The', 'NORFOLK EXCHANGE', 3, 32, NULL, 2, 3, NULL, 2823, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17174, '2016-08-17 18:07:32.162129+00', '2016-08-17 18:07:32.162129+00', 'Colonel Mustard Reel', 'COLONEL MUSTARD REEL', 1, 32, NULL, 1, 4, NULL, 11315, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17163, '2016-08-17 17:53:40.818405+00', '2018-04-03 00:07:55.369971+00', 'Jig de Grivetti', 'JIG DE GRIVETTI', 2, 32, NULL, 1, 3, 42, 2823, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17154, '2016-08-17 17:32:07.531589+00', '2016-08-20 16:44:26.422884+00', 'Bexley Butterfly', 'BEXLEY BUTTERFLY', 1, 32, NULL, 1, 4, NULL, 2823, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17165, '2016-08-17 17:56:06.765959+00', '2018-04-03 00:08:05.043963+00', 'Misty Morn O''er the Susquehanna', 'MISTY MORN OER THE SUSQUEHANNA', 1, 32, NULL, 1, 3, 42, 2823, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17178, '2016-08-21 20:43:07.122915+00', '2016-08-21 20:43:07.122915+00', 'Are Ye Dizzy Yet?', 'ARE YE DIZZY YET', 1, 32, NULL, 2, 3, NULL, 11316, '2016-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17184, '2016-08-22 07:49:31.723987+00', '2016-08-22 07:49:31.723987+00', 'Irish Zim Jig', 'IRISH ZIM JIG', 2, 128, NULL, 4, 4, 54, 10425, '2016-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17168, '2016-08-17 17:58:28.364626+00', '2018-04-03 00:08:19.278104+00', 'Sunrise O''er the Susquehanna', 'SUNRISE OER THE SUSQUEHANNA', 2, 32, NULL, 1, 3, 42, 2823, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17189, '2016-08-22 14:07:15.872497+00', '2016-08-22 14:07:15.872497+00', 'Setting Around at Home', 'SETTING AROUND AT HOME', 2, 32, NULL, 1, 4, NULL, 11320, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17160, '2016-08-17 17:48:25.047242+00', '2018-04-03 00:08:19.296395+00', 'Sunset O''er the Susquehanna', 'SUNSET OER THE SUSQUEHANNA', 2, 32, NULL, 1, 3, 42, 2823, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17167, '2016-08-17 17:57:41.368674+00', '2018-04-03 00:08:19.313154+00', 'Sunshine O''er the Susquehanna', 'SUNSHINE OER THE SUSQUEHANNA', 1, 32, NULL, 1, 3, 42, 2823, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13623, '2010-10-13 22:00:00+00', '2016-08-29 12:48:29.107024+00', 'Tribute to Drummond Cook', 'TRIBUTE TO DRUMMOND COOK', 3, 32, 9999, 1, 100, 2, 1523, '2008-11-01', 'To honour over 50 years of Scottish Country Dance music in the North and East.   

Published by the Forres Branch RSCDS.', 71, '8668/8008/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2820, '1998-11-07 23:00:00+00', '2016-08-30 22:20:28.609761+00', 'Haymakers, The', 'HAYMAKERS', 2, 48, 9999, 1, 4, 1, 9998, NULL, 'According to the RSCDS book, this is a »variation on *Sir Roger de Coverley*, one of the oldest country dances, described in many 18th and 19th century publications.«', 37, '4004  4004  4004  4004  4004  8888', 1, 1, 1, 1, 37);
INSERT INTO 'dance' VALUES (17190, '2016-08-22 14:09:44.861244+00', '2017-05-31 12:35:46.605849+00', 'Square Mixer, The', 'SQUARE MIXER', 2, 96, NULL, 4, 4, 3, 3066, '2016-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17179, '2016-08-21 22:45:59.102551+00', '2017-05-31 12:41:32.953456+00', 'Bell Curve, The', 'BELL CURVE', 3, 32, NULL, 2, 3, NULL, 10425, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17164, '2016-08-17 17:54:39.920061+00', '2019-11-24 13:33:22.402072+00', 'Hayden''s Weave', 'HAYDENS WEAVE', 2, 32, NULL, 5, 2, 76, 2823, '2006-11-04', 'This dance came to me while I was leading the Ceilidh dancing at the Tartan Ball in Lafayette, IN 

', 75, '88/80/08/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17180, '2016-08-21 22:47:46.306938+00', '2020-10-22 20:34:40.418031+00', 'Burgie House', 'BURGIE HOUSE', 3, 48, NULL, 2, 3, 17, 10495, '2016-01-01', '', 75, '800/888/844/888/804/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17177, '2016-08-20 19:33:27.628745+00', '2020-01-26 15:26:37.315659+00', 'Crême de la Crême, La', 'CREME DE LA CREME', 2, 32, NULL, 2, 3, 18, 2863, NULL, '', 92, '888/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17185, '2016-08-22 07:52:18.631881+00', '2020-10-22 20:41:06.299408+00', 'Ladies First!', 'LADIES FIRST', 1, 32, NULL, 1, 100, 2, 3286, '2010-01-01', '', 81, '6666/6666/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17187, '2016-08-22 14:01:22.378023+00', '2020-10-22 20:45:04.704797+00', 'Marykirk Reel', 'MARYKIRK REEL', 1, 32, NULL, 4, 4, 54, 10425, '2009-01-01', '', 62, '8888/4400/0044/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17208, '2016-09-03 16:44:33.247894+00', '2020-10-23 08:25:57.925154+00', 'Lilileaze', 'LILILEAZE', 2, 32, NULL, 2, 3, 17, 10995, NULL, '', 38, '800/844/844/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17229, '2016-09-03 21:24:10.476876+00', '2020-10-24 09:54:03.02219+00', 'Born to Dance', 'BORN TO DANCE', 2, 32, NULL, 1, 3, 42, 11035, NULL, '', 59, '800/888/888/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17191, '2016-08-22 14:12:01.919416+00', '2021-11-22 18:18:37.353797+00', 'Sweet Sixteen', 'SWEET SIXTEEN', 1, 32, NULL, 1, 100, 2, 10496, '2010-01-01', '"The winning entry in our 2012 dance-writing competition, celebrating Aurora''s 16th Anniversary."', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17258, '2016-09-04 12:19:02.902028+00', '2016-09-04 12:19:02.902028+00', '30th Anniversary Ball, The', '30TH ANNIVERSARY BALL', 3, 32, NULL, 1, 4, 11, 11338, '2007-01-01', '"The dance was written to celebrate the 30th anniversary of the Los Angeles Branch and inspired by the visit of John Drewry"  (SCDDB Editor''s note: the 30th anniversary was in 1996!)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17257, '2016-09-04 12:12:12.323752+00', '2022-09-27 07:04:15.283336+00', 'Starry Night', 'STARRY NIGHT', 1, 40, NULL, 1, 3, 42, 11337, '2008-07-01', 'The dance was devised while dancing on Dianne Wilson’s patio, during the summer when the school where class was normally held was closed for its summer vacation.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17219, '2016-09-03 19:12:51.288887+00', '2016-09-03 19:26:16.438818+00', 'To Name A Few', 'TO NAME A FEW', 3, 32, NULL, 1, 4, 1, 35, NULL, 'Many Scotsmen distinguished themselves in the fields of science and medicine. For example, Dr. James Young Simpson, who was born at Bathgate in 1811 and, at the age of 14, was admitted to University, was the discoverer of chloroform as an anaesthetic agent. "For this triumph of science, he was rewarded with a prize of 2000 francs from the Paris Academy of Sciences, and was elected a member of the learned societies both in England and upon the continent of Europe." Sir James Whylie was physician to Nicholas, the late Czar of Russia; Dr. Matthew Bailie, whose monument is in Westminster Abbey, was a distinguished anatomist and physician to George III; Sir James Clark was physician to Queen Victoria and, by his writings on medical subjects and his merits as a skillful physician, earned the title of Baronet. 



-Scotland''s Share in Civilizing the World ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17220, '2016-09-03 19:46:36.214819+00', '2016-09-03 19:50:04.31625+00', 'What Could be Easier', 'WHAT COULD BE EASIER', 2, 32, NULL, 1, 4, 2, 9998, NULL, 'Before Anne Hueser taught Scottish Country Dancing in Jacksonville, Ron Gemmell was the instructor. He was noted for teaching complex dances then saying, “What could be easier?"', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17224, '2016-09-03 20:06:59.268882+00', '2016-09-03 20:08:01.969677+00', 'Jacksonville Reel', 'JACKSONVILLE REEL', 1, 32, NULL, 3, 5, NULL, 9998, NULL, 'This dance is for all those in the future who choose to enjoy the challenge, the delight and the music of Scottish Country Dance in Northeast Florida. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17222, '2016-09-03 19:58:56.069357+00', '2018-09-19 09:44:37.336475+00', 'Dyer''s Andover Hey', 'DYERS ANDOVER HEY', 3, 48, NULL, 1, 4, 1, 9998, NULL, 'Charles Dyer teaches English Country Dancing and publishes a website advertising dance events in Northeast Florida. A graduate of Andover and Yale University, Charles is largely responsible for the survival of English Country Dance in Jacksonville', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17225, '2016-09-03 20:11:08.809991+00', '2018-09-19 09:46:49.667892+00', 'Jolly Stewart''s No-Setting Jig', 'JOLLY STEWARTS NOSETTING JIG', 1, 32, NULL, 1, 3, 42, 9998, NULL, 'Bill Stewart is a long-time dancer and a piper for the Jacksonville Pipes and Drums who sometimes teaches dance class. He loves to move and dislikes setting steps. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17226, '2016-09-03 20:16:39.035885+00', '2018-09-19 09:49:43.775541+00', 'St. Paul''s Commons', 'SAINT PAULS COMMONS', 1, 32, NULL, 2, 3, 18, 9998, NULL, 'Anne Hueser attended boarding school at St. Pauls in New Hampshire and Columbia University. This dance reflects the busy days of her youth in a delightfully demanding atmosphere', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17227, '2016-09-03 20:21:52.234062+00', '2016-09-03 20:44:11.044552+00', 'Spring Fling, The', 'SPRING FLING', 3, 32, NULL, 2, 3, 17, 9998, NULL, 'In the spring of 2010, Anne attended the Sarasota ball and the Dunedin weekly class. She then drove across the state to take the Space Coast weekly class. A few weeks later, she assisted with the Scottish Country Dance demonstrations at the Northeast Florida Highland Games. Capping off her spring fling, she attended the Space Coast spring workshop, the Titusville class and the Orlando class ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18426, '2018-07-19 10:06:45.524921+00', '2018-07-19 10:06:45.524921+00', 'An Teallach', 'TEALLACH', 1, 32, NULL, 1, 4, 11, 10424, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18428, '2018-07-19 10:40:28.708724+00', '2018-07-19 10:40:28.708724+00', 'Daily Double, The', 'DAILY DOUBLE', 1, 40, NULL, 1, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12766, '2006-05-21 22:00:00+00', '2018-08-21 08:13:46.839995+00', 'Mary Currie''s Marryat Dances', 'MARY CURRIES MARRYAT DANCES', 1, 32, 9999, 1, 3, 42, 3682, NULL, 'Mary Currie has given so much time to promoting Scottish Country Dancing within Dundee over the years. It was Mary who started the Marryat Hall summer dancing many years ago. Therefore it seemed appropriate to incorporate this in the name of the dance.', 53, '800/844/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17233, '2016-09-03 21:43:02.399773+00', '2019-01-09 00:00:54.604826+00', 'Once Upon a Time', 'ONCE UPON A TIME', 1, 32, NULL, 1, 3, 42, 11035, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11779, '2004-09-08 22:00:00+00', '2018-10-13 15:47:20.688793+00', 'David Jones''s Locker', 'DAVID JONESS LOCKER', 1, 32, 9999, 2, 3, 18, 108, '2003-01-01', 'for David Jones of Newby, Cumbria', 75, '800/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17243, '2016-09-04 09:55:04.951745+00', '2016-09-04 09:55:04.951745+00', 'Catalina Express', 'CATALINA EXPRESS', 1, 80, NULL, 4, 4, 3, 11328, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4556, '1997-09-09 22:00:00+00', '2016-09-04 21:22:49.165324+00', 'Miss Milligan''s Travels', 'MISS MILLIGANS TRAVELS', 1, 32, 9999, 1, 3, 42, 371, NULL, 'This dance is dedicated to the memory of Miss Jean Milligan, who, in her many travels, seemed

always to be in motion, only occasionally seizing the opportunity to "set".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10833, '2002-09-25 22:00:00+00', '2016-09-04 21:25:00.073266+00', 'Pinewoods Return', 'PINEWOODS RETURN', 2, 32, 9999, 1, 3, 42, 555, '2000-07-05', 'A dance devised to mark the first Pinewoods Scottish Dance Camp of the Millennium (or the last

depending on your method of counting).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17482, '2016-11-26 16:48:59.956795+00', '2018-04-02 23:56:37.130082+00', 'R. A. Gregg', 'R A GREGG', 1, 32, NULL, 1, 3, 42, 1167, '2016-11-23', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17836, '2017-06-22 17:25:54.174015+00', '2018-10-14 00:26:21.547396+00', 'Emma Nixon Strathspey, The', 'EMMA NIXON STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17228, '2016-09-03 21:17:36.223161+00', '2020-10-24 09:48:27.49268+00', 'Bonjour-Au Revoir', 'BONJOURAU REVOIR', 1, 32, NULL, 1, 3, 42, 11035, NULL, '', 53, '800/822/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17231, '2016-09-03 21:31:46.63766+00', '2020-10-24 09:56:29.2067+00', 'GAGT''s Reel', 'GAGTS REEL', 1, 32, NULL, 1, 3, 42, 11035, NULL, '', 50, '800/880/880/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17235, '2016-09-03 22:09:32.068237+00', '2020-10-24 10:17:28.616235+00', 'Rondel in Waterloo', 'RONDEL IN WATERLOO', 3, 32, NULL, 1, 4, 1, 11035, NULL, '', 55, '8800/8440/8080/8068', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17236, '2016-09-03 22:12:13.586992+00', '2020-10-24 10:19:39.290514+00', 'Skip Change Only', 'SKIP CHANGE ONLY', 1, 32, NULL, 1, 3, 42, 11035, NULL, '', 50, '800/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17237, '2016-09-03 22:15:23.648075+00', '2020-10-24 10:33:27.612115+00', 'Sleepless in Normandale', 'SLEEPLESS IN NORMANDALE', 1, 40, NULL, 1, 4, 1, 11035, NULL, '', 70, '8440/8440/8880/8880/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17238, '2016-09-03 22:19:26.986416+00', '2020-10-24 10:42:58.906964+00', 'Stratton Street', 'STRATTON STREET', 3, 32, NULL, 1, 4, 2, 11035, NULL, '', 62, '8008/8008/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15959, '2015-02-03 00:35:24.853923+00', '2016-09-04 10:52:30.645792+00', 'Land of Enchantment, The', 'LAND OF ENCHANTMENT', 3, 32, NULL, 2, 3, 17, 3531, '2006-04-01', 'Dianne Wilson had some help in devising this dance, and thanks Jan Lauer, Janet Olsen, Shirley Saturensky and class members of The Orange County Branch.



This dance was inspired by a workshop held June 2-4, 2006, in Albuquerque, New Mexico. (New Mexico is “The Land of Enchantment” - Dianne Wilson)



Note: La Girandole figure is borrowed from Pat Clark’s Strathspey, devised by Jim Rae. La Girandole is French for a rotating display or a piece of jewelry having a large stone surrounded by smaller drops. La Girandole above is danced ‘à droite’: with right hand turns. It may also be danced ‘à gauche’: with left hand turns, in which case after the setting, 1st man and 2nd woman turn left hands while 1st woman and 2nd man cast right about into left hands across and left hand half turns. La Girandole may also be danced in reel or jig time.', 71, '822/888/880/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17252, '2016-09-04 11:08:15.751862+00', '2018-09-14 00:42:25.446845+00', 'Mr. B''s Jig', 'MR BS JIG', 2, 32, NULL, 1, 3, 42, 11334, NULL, 'Devised by Deresa Kenney for her friend Murray Bader, using some of their favorite dance figures', 69, '664/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18429, '2018-07-19 10:41:05.604191+00', '2018-09-19 09:45:14.25104+00', 'Felicity''s Fancy', 'FELICITYS FANCY', 2, 40, NULL, 1, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17256, '2016-09-04 12:08:48.240964+00', '2016-09-04 12:08:51.600217+00', 'Santa Monica Rag', 'SANTA MONICA RAG', 2, 32, NULL, 1, 102, 2, 236, NULL, 'Devised by the Los Angeles Branch Demonstration Team', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17232, '2016-09-03 21:38:08.410994+00', '2022-05-26 16:37:02.127702+00', 'Lonely Sunday', 'LONELY SUNDAY', 2, 32, NULL, 1, 3, 42, 12131, NULL, '', 38, '800/880/880/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5875, '1997-09-13 22:00:00+00', '2016-09-04 20:29:52.453617+00', 'Salute To The Tournee', 'SALUTE TO THE TOURNEE', 3, 40, 9999, 1, 3, 42, 351, NULL, 'This dance was in the Boston Branch demonstration team''s repertory for J978-1979. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4596, '1998-01-05 23:00:00+00', '2016-09-04 19:54:52.818661+00', 'Miss Williams'' Fancy', 'MISS WILLIAMS FANCY', 1, 32, 9999, 1, 3, 42, 608, NULL, 'Written for a good friend, in the hope that it will get her dancing more.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6670, '1997-09-16 22:00:00+00', '2016-09-04 20:32:47.369472+00', 'Towers, The', 'TOWERS', 1, 32, 9999, 1, 4, NULL, 259, '1973-01-02', 'Composed for and danced at the wedding ofCindy and Charles Tower, 18 November 1972.



First published in the Tartan Times for January 1973; also circulated in leaflet form.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12550, '2005-10-11 22:00:00+00', '2018-10-18 15:17:29.279168+00', 'Scottish Welcome to Texas', 'SCOTTISH WELCOME TO TEXAS', 1, 32, 9999, 5, 56, 76, 3639, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17250, '2016-09-04 10:57:35.361632+00', '2019-08-24 22:22:40.661262+00', 'Merry Bee', 'MERRY BEE', 1, 32, NULL, 2, 2, 76, 11332, '2015-04-20', 'Devised September 2013 (Revised, April 20, 2015) for Mary Brandon.', 50, '84/84/88/80', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5859, '1997-04-03 22:00:00+00', '2016-09-04 21:10:58.834388+00', 'Salt and Pepper', 'SALT AND PEPPER', 1, 32, 9999, 1, 3, 42, 351, NULL, 'One evening after a dance several of us went to our favorite restaurant. The service that night was much slower than usual, and while we were waiting two of our younger members gathered four pairs of salt and pepper shakers, and "walked through" some dances with them. So then I took a napkin and devised this dance for them. Unfortunately (or perhaps fortunately, as we were very hungry) the food finally arrived just then, and so it never did get done by the shakers it was devised for. However, Marianne Taylor kept the napkin and tried the dance in her workshop the next week, where it went over very well.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5272, '1997-09-11 22:00:00+00', '2020-06-21 09:25:17.059023+00', 'Piper Frap', 'PIPER FRAP', 3, 48, 9999, 1, 4, 22, 50, '1975-01-01', 'The dance was devised in honor of "Frap" Frappia of the RSCDS Hawaii Branch and of the Honolulu Pipes and Drums.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16610, '2015-08-26 19:10:26.97766+00', '2020-07-12 14:14:52.871661+00', 'Watercolourist, The', 'WATERCOLOURIST', 3, 32, NULL, 4, 4, 1, 3183, '2013-03-01', '', 69, '8000/0808/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18957, '2018-10-13 19:45:58.814495+00', '2020-11-22 18:11:28.973072+00', 'Julia Sharp Strathspey', 'JULIA SHARP STRATHSPEY', 3, 48, NULL, 1, 100, 2, 10798, '2015-07-30', 'For Julia Sharp’s 80th birthday on 30 July 2015.', 80, '5550/0555/7777/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19083, '2018-12-06 13:01:49.914048+00', '2021-03-13 21:21:46.611543+00', 'Countess of Elgin, The', 'COUNTESS OF ELGIN', 1, 32, NULL, 1, 3, 42, 11759, '2017-01-01', 'Devised by Janet Johnston, RSCDS Stirling Branch, 2017.   The Countess of Elgin was involved in the early years with Dunfermline Branch and held office within the Scottish Country Dance Society.', 66, '880/888/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5929, '1997-09-13 22:00:00+00', '2016-09-04 21:51:46.916883+00', 'Scotch Rose', 'SCOTCH ROSE', 2, 32, 9999, 5, 2, 76, 1264, NULL, 'Dedicated to all dancers who discovered Scottish Country Dancing later in life. We use this dance as an easy introductory dance for beginners. As such it has no particular tune-just "any good jig" (or, on occasion, even "any good strathspey"). As all dancers are dancing all the time, four rounds are plenty', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17263, '2016-09-04 22:51:20.62013+00', '2017-02-24 23:35:43.683602+00', 'Angus Glens Chain', 'ANGUS GLENS CHAIN', 1, 32, NULL, 5, 2, 76, 2913, NULL, 'Note:- All the main Angus glens are linked together by the watersheds, up in the Grampian mountains.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17264, '2016-09-05 22:41:57.072806+00', '2018-10-25 00:40:51.75659+00', 'Seven Eights', 'SEVEN EIGHTS', 1, 32, NULL, 1, 3, 42, 11339, NULL, '', 41, '800/822/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18431, '2018-07-19 10:42:14.787906+00', '2018-07-19 10:42:14.787906+00', 'Isobel', 'ISOBEL', 3, 32, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17278, '2016-09-06 20:24:24.855121+00', '2016-09-06 20:24:28.350327+00', 'Mobile Bay Medley, The', 'MOBILE BAY MEDLEY', 4, 32, 1, 1, 2, 76, 703, NULL, 'Devised for Debbie Palmer and Kellie Richardson of Mobile, Alabama in July, 2005. Debbie and Kellie started dancing in 2000 and dance in Mobile, as well as driving 50 miles each way to dance in Pensacola, Florida every Tuesday night.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18430, '2018-07-19 10:41:38.55895+00', '2018-07-21 13:12:43.955092+00', 'Ghan, The', 'GHAN', 2, 32, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16001, '2015-02-06 17:41:14.450017+00', '2016-09-06 20:38:33.565942+00', 'Walk In Pensacola, A', 'WALK IN PENSACOLA', 2, 32, 9999, 2, 3, 17, 703, '2005-08-01', 'Devised for Richard and Connie Walker o fPensacola, Florida in August 2005. Richard has taught dancing in the area for decades and Connie plays the fiddle. And their laughter and enjoyment is music to our ears.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15998, '2015-02-06 17:16:05.874722+00', '2016-09-06 20:41:34.973304+00', 'Traveling Peterkins, The', 'TRAVELING PETERKINS', 2, 32, 9999, 2, 3, 17, 703, '2006-04-01', 'Devised for Andrew, Catherine, and Rachel Peterkin of North Carolina in April, 2006.

Andrew and Catherine return to Thistle School every summer, where they first met, to enjoy the

dancing and the friends that they have made across the Southeast.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15997, '2015-02-06 17:04:54.413992+00', '2016-09-06 20:42:30.547775+00', 'Three Quarters of a Century', 'THREE QUARTERS OF A CENTURY', 3, 32, 9999, 1, 4, 2, 703, '2005-10-01', 'Devised for my mother, Scotty Gallamore, in October 2005 to celebrate her 75th birthday.

She had always wanted a strathspey that included the Philabeg, a figure devised by Bob Campbell.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17317, '2016-09-09 17:56:26.212279+00', '2016-09-09 17:56:26.212279+00', 'Fugue from Bruce Hamilton', 'FUGUE FROM BRUCE HAMILTON', 2, 32, NULL, 1, 3, 42, 1383, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17319, '2016-09-09 18:25:35.363241+00', '2016-09-09 18:25:35.363241+00', 'Remembering Rico', 'REMEMBERING RICO', 2, 32, NULL, 5, 56, 30, 2927, '1998-03-01', 'Presented to the Lyndhurst Group at its Annual Weekend 1998



In memory of his many contributions to Scottish Country Dancing in Cleveland and reflects his love of the interconnections between Scottish Country Dancers', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (275, '1997-08-28 22:00:00+00', '2022-11-04 07:14:23.785283+00', 'Au Revoir, Betty And Tony', 'AU REVOIR BETTY AND TONY', 3, 32, 9999, 2, 3, 17, 259, '1976-09-01', 'Dedicated to Betty and Tony Moretti for their contribution to Scottish Country Dancing while in the United States. Devised and first performed at Pinewoods, July 1976; first published in the Tartan Times for September 1976.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19041, '2018-10-27 23:54:28.344757+00', '2022-03-20 12:51:40.695908+00', 'Infamous El Guapo, The', 'INFAMOUS EL GUAPO', 2, 32, NULL, 1, 3, 42, 11077, '2016-09-01', 'There is also a 5 couple version of this dance (<<http://www.rscds-swws.org/news/stories/InfamousElGuapoTenPesoVersion.pdf>>).', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4170, '1998-01-05 23:00:00+00', '2022-12-03 19:25:43.553822+00', 'Marianne Taylor''s Hornpipe', 'MARIANNE TAYLORS HORNPIPE', 1, 32, 9999, 1, 3, 42, 1108, NULL, 'Dedicated to our teacher, Marianne Taylor, by the Boston Demonstration Team for her inspiring

leadership.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17261, '2016-09-04 20:09:03.838254+00', '2023-01-09 23:09:07.31435+00', 'Turque, La', 'TURQUE', 1, 32, NULL, 1, 3, 42, 632, NULL, 'The dance sheet states: "A la mode de 1795 (...) On the departure of Chris and John Bowie Dickson. Bismillah! This dance was first published in the Tartan Times for June 1981."', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15988, '2015-02-06 14:40:32.606124+00', '2016-09-06 20:46:18.87146+00', 'Kathy''s Garden', 'KATHYS GARDEN', 3, 32, 9999, 2, 3, 18, 703, '2004-01-01', 'Devised in the memory of Kathy Schoeffler of Durham, North Carolina in June 2004. Kathy

grew up dancing in the DC area before moving to NC and becoming a permanent fixture in the

Southeast. She was a very joyous and passionate dancer and great friend to all.



Kathy passed away suddenly in January, 2004. At her memorial service, dancers performed

one of her favourite dances, Seann Truibhas Willichan. This is a variation of the pieces of that

dance into a loving tribute to her.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17277, '2016-09-06 20:20:48.350318+00', '2016-09-06 20:56:28.886109+00', 'River Players, The', 'RIVER PLAYERS', 2, 32, NULL, 2, 3, NULL, 703, NULL, 'Devised for Dale and Brenda Sleight of North Carolina in April, 2006, Apart from enjoying dancing with the Greensboro and Raleigh dancers, they love kayaking or "playing a river" ... and their new love of rabbits.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15992, '2015-02-06 15:51:42.615563+00', '2016-09-06 21:00:22.726525+00', 'Reel MacKay, The', 'REEL MACKAY', 1, 32, 9999, 2, 3, 18, 703, '2008-09-01', 'Sugg music: Reels(Simple) 3x32 6x through the Dance by M.Johnstone



Devised for Eric and Tine MacKay of, currently. Harrisburg. PA in September. 2008 by Sandy Gallamore. Eric and Tine have lived all over the country and used to travel great miles to go dancing. normally because there is no dancing nearby. Now. they can enjoy all the dancing to be found on the East coast and it''s great to have them around.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15984, '2015-02-06 13:58:24.701834+00', '2016-09-06 21:04:38.56984+00', 'Corrigan Strathspey, The', 'CORRIGAN STRATHSPEY', 3, 32, 9999, 1, 4, 4, 703, '2007-09-01', 'Devised for Jeffand Patsy Corrigan of Placersville, California in September 2007. They

have danced all across the country; California, Little Rock, Arkansas, and taught for several years

in Williamsburg, Virginia before returning to California. They are fun teachers, great dancers, and

good friends.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15990, '2015-02-06 15:04:20.55012+00', '2016-09-06 21:09:05.548379+00', 'Maxwell''s Golden Rant', 'MAXWELLS GOLDEN RANT', 1, 32, 9999, 2, 3, 17, 703, '2004-08-01', 'Devised for Larry and Catherine Long in August, 2004for their 50th wedding anniversary.  Larry and Catherine have been long time supporters of all things Scottish: Clan Maxwell, the Grandfather Mountain Highland Games, and Scottish Country Dancing.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17280, '2016-09-06 21:36:43.061948+00', '2016-09-06 21:36:46.737701+00', 'Lucky Clover, The', 'LUCKY CLOVER', 3, 48, NULL, 4, 5, 35, 28, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17281, '2016-09-06 21:46:34.121276+00', '2016-09-06 21:46:34.121276+00', 'Moonlight Rose', 'MOONLIGHT ROSE', 3, 32, NULL, 2, 3, 17, 2203, NULL, 'Published in the "Hamilton Leaflet".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17294, '2016-09-08 03:40:42.845992+00', '2016-09-08 03:40:42.845992+00', 'Gypsy Bracelet, The', 'GYPSY BRACELET', 3, 32, NULL, 2, 3, 18, 10995, NULL, 'This dance intends to add a note of “sleight of hand” to what appears a very simple little dance….and hence the title. It was was very much influenced  by the music suggested…do use it if you have it.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17268, '2016-09-05 23:15:48.232875+00', '2020-10-24 18:42:06.863552+00', 'Laughing Heart, The', 'LAUGHING HEART', 2, 32, NULL, 5, 2, 76, 11340, '2013-09-08', 'Objective: Simple RtR dance', 75, '88/44/44/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17270, '2016-09-06 16:52:24.843352+00', '2020-10-24 18:58:05.566817+00', 'Greeting Jig, The', 'GREETING JIG', 2, 32, NULL, 1, 3, 42, 11340, NULL, '', 38, '840/804/800/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17271, '2016-09-06 16:54:46.389458+00', '2020-10-25 09:47:14.671501+00', 'Happy Tenth', 'HAPPY TENTH', 1, 32, NULL, 1, 3, 42, 11340, NULL, '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17272, '2016-09-06 16:56:13.385102+00', '2020-10-25 09:50:34.57509+00', 'Jig for Allison, A', 'JIG FOR ALLISON', 2, 32, NULL, 1, 4, 1, 11340, NULL, '', 41, '8800/8000/8000/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17273, '2016-09-06 16:57:28.973573+00', '2020-10-25 09:53:18.819041+00', 'John''s Sabbatical', 'JOHNS SABBATICAL', 1, 32, NULL, 1, 3, 42, 11340, NULL, '', 56, '800/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17274, '2016-09-06 16:59:49.884209+00', '2020-10-25 10:05:06.982139+00', 'Rainy Sunday Strathspey', 'RAINY SUNDAY STRATHSPEY', 3, 32, NULL, 2, 3, 17, 11340, NULL, '', 75, '844/888/088/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17275, '2016-09-06 17:02:33.463346+00', '2020-10-25 10:08:33.00372+00', 'Sylvia Full of Grace', 'SYLVIA FULL OF GRACE', 3, 32, NULL, 2, 3, 17, 11078, NULL, '', 67, '888/880/800/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17276, '2016-09-06 17:46:38.385676+00', '2020-10-25 10:15:07.834621+00', 'Thursday Night Ladies, The', 'THURSDAY NIGHT LADIES', 1, 32, NULL, 1, 2, 76, 11340, NULL, '', 47, '44/84/88/80', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14398, '2012-01-07 23:00:00+00', '2021-07-30 07:42:33.735926+00', 'Fairyknowe Lodge', 'FAIRYKNOWE LODGE', 1, 32, NULL, 1, 3, 42, 308, '2007-01-01', 'Written for Betsy and Colin Maxwell', 59, '866/888/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15985, '2015-02-06 14:07:21.150354+00', '2018-04-02 23:56:33.757255+00', 'Dancing Scot, The', 'DANCING SCOT', 1, 32, 9999, 1, 3, 42, 703, '2009-09-01', 'Devised for Valerie Brookeman of Richmond, Virginia on her first official day of retirement (September 1, 2009) with the hopes that she''ll enjoy more dancing with her new found free time. Originally from Scotland, her email address starts with "DancingScot@.... (This was supposed to a good dance for teaching set to and turn corners into a reel, but this is much better.)

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17289, '2016-09-08 03:21:51.603802+00', '2018-04-03 00:07:41.166332+00', 'Dancing in the Air', 'DANCING IN THE AIR', 1, 32, NULL, 1, 3, 42, 10995, NULL, 'I have always loved dancing “Pelorous Jack”. In this dance, rather than gambolling in the bow wave of a speeding ship, imagine being part of a virtuoso flying display at sunset over Fen Drayton in a cast of thousands!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17284, '2016-09-07 22:40:12.112013+00', '2016-09-07 22:40:15.322259+00', 'London''s 50', 'LONDONS 50', 3, 48, NULL, 3, 5, 16, 154, '2011-05-01', 'Note: devised in May 2011 to mark the London Ontario Branch''s 50th anniversary and was presented to the Branch on 7th May 2011 at the Golden Jubilee Ball held to mark the occasion.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17286, '2016-09-07 23:17:23.31269+00', '2016-09-08 02:51:30.17563+00', 'Amadis of Gaul', 'AMADIS OF GAUL', 2, 32, NULL, 1, 4, 1, 10995, '2009-01-01', 'Note: marked as 8x32, but with progression 2341.  Error somewhere



I enjoyed the middle sections of ”Father Connelly’s Jig” very much, but as a beginner found its length and logic difficult to assimilate. So this as an attempt to create a standard length dance with a symmetrical opening round those 16 bars!



The opening 8 is a movement imitating the winding –up, aiming & firing of the medieval siege-engine after which it is named.( I had just seen a TV program on siege war-fare) & this clicked exactly with the dance name, which, unusually I had already picked at random from a dictionary…….such is the creative process!



I thought it best to arrange that after the fun of the middle 16, everyone who would restart was static & able to concentrate on this new figure !', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2238, '1998-12-09 23:00:00+00', '2018-04-03 00:07:46.187547+00', 'Flooers O'' Fa''kirk, The', 'FLOOERS O FAKIRK', 2, 32, 9999, 1, 3, 42, 121, '1989-01-01', '[For Sheila Duncan of London (Ont)]



Fah Kirk - long converted into "Falkirk" but retained in local pronunciation. Sc. Fah = varicoloured (or pale red). The Fah Kirk gave its name to the town Fal kirk (first appearing thus in 16th century records)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17332, '2016-09-12 20:27:29.732232+00', '2018-08-18 10:29:33.542431+00', 'Glen Almond', 'GLEN ALMOND', 1, 32, NULL, 1, 4, 1, 44, '2007-02-17', 'To introduce symmetrical Reels on the sides.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17267, '2016-09-05 23:11:11.048735+00', '2022-12-11 11:45:42.243565+00', 'Merry Go Round, The', 'MERRY GO ROUND', 3, 32, NULL, 104, 2, 76, 11340, '2007-11-17', 'Objective: Teach the Rondel', 88, '88/44/88/88', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17269, '2016-09-05 23:19:27.395769+00', '2022-12-11 11:47:54.346223+00', 'Muckle Muddle, The', 'MUCKLE MUDDLE', 3, 32, NULL, 1, 4, 2, 11340, '2013-05-02', 'Objective: Fun and novelty



Music: A Strathspey set under four minutes works best



Suggest: “Leaving Benbecula” by Nicol McLaren on the Craigievar Dances album.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14363, '2011-12-16 23:00:00+00', '2018-07-18 17:28:59.949602+00', 'Emmett''s Chase', 'EMMETTS CHASE', 2, 32, NULL, 1, 3, 42, 884, '2010-03-01', 'Devised for Audrey and Robin Emmett on the occasion of their 50th birthdays - March 2010. 



This dance was originally published as a Reel on "8x32" at http://blog.lib.umn.edu/ldfs/8x32/2010_04.html, and then republished (with identical wording) as a Jig on http://www.members.westnet.com.au/trevanne/rscdswa/dances/Emmett%27s_Chase.pdf  

For the original Reel, the deviser indicated: Suitable CD recording : Track 9, RSCDS Belfast Branch Diamond Jubilee Dances recorded by Marian Anderson''s Scottish Dance Band (tune "Iain Peterson")



John Brenchley writes (private communication): "When we came to record the Other Kangaroo Paw cd we had rather too many reels and Emmett''s Chase seemed more suited to a jig so we changed it. Marian composed a new tune for it. The tune suggested on the earlier version was only based on a suitable track from a cd for those without access to live music."







', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17214, '2016-09-03 16:54:36.831003+00', '2016-09-08 02:59:00.067412+00', 'Brackenberry Rant, The', 'BRACKENBERRY RANT', 4, 64, 5, 1, 3, 42, 10995, NULL, 'This dance came into my head one Sunday morning and crystallised round the unusual but great dancing track listed. It seemed ideal to try this dance in Strathspey time before reeling it as intended .With this music, the first run is in Strathspey time & the repeat in sprightly reel time. I thought any dancers who liked the reels would also enjoy La Baratte instead of a turn or Birl.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17287, '2016-09-08 03:09:22.507242+00', '2016-09-08 03:09:22.507242+00', 'Beyond Bond', 'BEYOND BOND', 2, 40, NULL, 4, 4, 4, 10995, NULL, 'This dance is a cocktail of figures both shaken and stirred (whence its name) & is intended to be challenging to dance. In compensation, it should be easy to memorise.



N B … you will pair up with every opp. sex dancer in the set for one of the 4 repeats.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17288, '2016-09-08 03:17:56.016357+00', '2016-09-08 03:17:56.016357+00', 'Daily Bread', 'DAILY BREAD', 2, 32, NULL, 1, 3, 42, 10995, NULL, 'Curiously, here I had the Name of the dance in my head from the start. I have been lucky to be taught by George Daly who continually introduces us to new and interesting dances….a breeding ground for inspiration over many years. After his September class, I felt the need to space out 2 couple petronellas so as to avoid my ”moment with Margaret” , delightful though it was!.



The movement across the dance [b13-16] I have used before [“Quarry Triumphant” & “Hadron Collider”] ,calling it “Goodbye/Hello” setting…..much easier to call!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18432, '2018-07-19 10:42:55.933214+00', '2018-07-19 10:42:55.933214+00', 'Jump Alf, Jump!', 'JUMP ALF JUMP', 1, 32, NULL, 1, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17290, '2016-09-08 03:25:14.109921+00', '2016-09-08 03:25:18.672884+00', 'Dancing Devil, The', 'DANCING DEVIL', 2, 32, NULL, 1, 3, 42, 10995, NULL, 'A “Dancing Devil” is one of the many names for a dust-devil ….a skittish, unpredictable, small whirlwind. The figures in the dance try to capture the patterns made round my feet by sand swirling capriciously in the hot sun as I stood on the concrete step edging the approach to the beach.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17291, '2016-09-08 03:28:57.456192+00', '2016-09-08 03:29:00.370103+00', 'Ena Harkness', 'ENA HARKNESS', 3, 32, NULL, 1, 3, 42, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17292, '2016-09-08 03:33:33.073269+00', '2016-09-08 03:33:36.574155+00', 'Flying Cats of Frisco, The', 'FLYING CATS OF FRISCO', 1, 32, NULL, 1, 3, 42, 10995, NULL, 'Huge catamarans leapt out of the water and literally flew round the course during the 2013 America''s Cup Races. The New Zealand boat,”Aotearoa”, raced against “Oracle”, the American victor over a 17 race series. This dance portrays the contest.



The first 4 bars describe the manoeuvres and bluffs which go on behind the Start-line. The firing of the Start gun sends the yachts surging away on the same tack to round the marks & to jockey for position on the upwind and downwind legs.



The last 8 bars simulate the crowds of onlookers who went wild along the viewing piers as the crews crossed the line, followed by the crews reaction. On the first run, the contestants drop sail and re-group for a re-match, but on the repeat dance, the series is decided so they join in the celebrations!



The race was held in San Francisco Bay.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17293, '2016-09-08 03:37:12.219013+00', '2016-09-08 03:37:12.219013+00', 'Fourpenny One, The', 'FOURPENNY ONE', 2, 32, NULL, 1, 3, 42, 10995, NULL, 'This is a lively “partner”dance…the leads have essentially a 30bar solo!



The figure in bars 13-16 is a variation of “Set &Link” designed make the dance interesting to watch……so it needs to bedanced well…. the spins synchronised to the release of handholds, danced exactly on the side lines with spacing carefully kept as the dancers make a precise squared - corner chase.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17295, '2016-09-08 03:44:35.276477+00', '2016-09-08 03:44:35.276477+00', 'Henneker Rant, The', 'HENNEKER RANT', 3, 32, NULL, 2, 3, 18, 10995, NULL, 'Here inspiration came from watching the courtship dancing of Crested Grebes.  Bobby Brown’s lovely track has 3 repeats …Lucky 2nd couple!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17297, '2016-09-08 03:53:42.270073+00', '2016-09-08 03:53:42.270073+00', 'Mining for Flint', 'MINING FOR FLINT', 1, 32, NULL, 1, 3, 42, 10995, NULL, 'This is a team dance inspired by the absolutely cracking music suggested. I felt its figures, with their turns & twists and reveals, somehow suggested ancient mining. I hope that the dance rewards the effort expended…. obviously the mining did', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17298, '2016-09-08 03:59:43.462815+00', '2016-09-08 03:59:43.462815+00', 'New Willow Bank Reel', 'NEW WILLOW BANK REEL', 1, 32, NULL, 1, 3, 42, 10995, NULL, 'This was written to celebrate the house-warming dance held in New Willow Bank House in December 2012.



The 3rd 8 bars is pretty frenetic for the leads, so the corners need to be aware of that & assist them by ensuring that the RHs across are fast and never behind the beat! They will also need to be aware that the leads will be entering the final circle left at speed……so might need catching! If you get this one right, I am sure you will smile!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17299, '2016-09-08 04:05:31.004641+00', '2016-09-08 04:05:31.004641+00', 'Sixpenny Maid, The', 'SIXPENNY MAID', 1, 40, NULL, 1, 3, 42, 10995, NULL, 'The dance evolved from my attempts to find variations of do-si-do which offer the dancers increased communication… especially eye-contact. The nursery-rhyme “Sing a Song of Sixpence” provided inspiration plus the name, KSMJ the wonderful music to which to dance it.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17203, '2016-09-03 16:34:20.390617+00', '2016-09-08 04:19:29.949899+00', 'Gentleman''s Cravatte, The', 'GENTLEMANS CRAVATTE', 2, 32, NULL, 1, 4, NULL, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17301, '2016-09-08 04:27:13.174317+00', '2016-09-08 04:27:13.174317+00', 'Come, Take My Hand', 'COME TAKE MY HAND', 3, 32, NULL, 1, 3, 42, 3369, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17302, '2016-09-08 04:31:24.416637+00', '2016-09-08 04:31:24.416637+00', 'King Arthur and his Court', 'KING ARTHUR AND HIS COURT', 2, 48, NULL, 4, 55, 4, 3369, NULL, 'This dance was specifically devised for Arthur McNair who is always popular as a dance partner.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17303, '2016-09-08 04:34:23.455561+00', '2016-09-08 04:34:23.455561+00', 'Monkey''s On The Motorway', 'MONKEYS ON THE MOTORWAY', 1, 32, NULL, 1, 2, 76, 3371, NULL, 'This dance was devised as a teaching dance for advancing pas de basque', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17300, '2016-09-08 04:10:06.21308+00', '2018-09-19 09:54:33.188956+00', 'Wickham''s Fancy', 'WICKHAMS FANCY', 1, 32, NULL, 1, 3, 42, 10995, NULL, 'This little dance is about fly fishing & takes its name from a type of tied lure. “Hook-turns” seem particularly appropriate as they mimic the controlled check of the rod’s swing back followed by the reversing & launching out of the line across the water. The dancing lady begins by mimicking the lure skittering across the surface at the end of a cast.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17304, '2016-09-08 22:49:21.578494+00', '2018-01-04 01:33:36.480195+00', 'Rendez-vous à Vichy', 'RENDEZVOUS A VICHY', 2, 32, NULL, 1, 3, 42, 11299, '2016-03-01', 'Devised to celebrate the Vichy dance weekend, Easter 2016', 50, '840/880/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17324, '2016-09-09 20:16:12.001752+00', '2019-01-16 14:50:00.89796+00', 'Scottish Snowman, The', 'SCOTTISH SNOWMAN', 2, 32, NULL, 1, 4, 1, 2561, '2009-12-12', 'Jig or Reel (the leaflet did not specify the type of musik)



From the leaflet:  



   - The Scottish Snowman (a dance for four frozen couples)  



   - Devised by the hardy members of the Edmonton Caledonian Branch Children''s class - which showed up for dance class on December 12, 2009 when the temperature was minus 27 with a wind chill of minus 35!

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17328, '2016-09-12 20:11:06.861046+00', '2016-09-12 20:11:06.861046+00', 'Maclean on Clarence', 'MACLEAN ON CLARENCE', 3, 32, NULL, 1, 3, 42, 10907, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17329, '2016-09-12 20:17:49.522928+00', '2016-09-12 20:17:52.457677+00', 'Elizabeth 1 or Proud Mary', 'ELIZABETH 1 OR PROUD MARY', 3, 32, NULL, 1, 100, 2, 2782, '2012-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17323, '2016-09-09 20:06:36.271809+00', '2019-02-25 14:27:35.535228+00', 'Catch Me if You Can', 'CATCH ME IF YOU CAN', 1, 32, NULL, 1, 3, 42, 777, '2015-08-01', 'Deviser''s note; The turn about at the end of each half reel was taken from Tim Wilson''s dance "Chased Lovers,"although in his dance they only turn around after an eight bar reel.', 50, '800/844/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17307, '2016-09-09 09:54:29.684112+00', '2020-06-28 21:11:38.65185+00', 'Elizabethan Fancy for Henri Suhamy, An', 'ELIZABETHAN FANCY FOR HENRI SUHAMY', 2, 32, NULL, 2, 3, 18, 888, '2013-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17320, '2016-09-09 19:41:44.536578+00', '2020-02-16 12:22:00.528218+00', 'UNICOI Unlimited', 'UNICOI UNLIMITED', 2, 32, NULL, 6, 3, 4, 2927, '2011-01-01', 'Devised for the Atlanta Branch Unicol 2011 Spring Workshop



', 100, '888/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17310, '2016-09-09 10:07:16.057132+00', '2020-08-23 10:15:37.641299+00', 'Pandas Roux, Les', 'PANDAS ROUX', 2, 40, NULL, 1, 4, 1, 11347, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17327, '2016-09-12 20:05:19.897995+00', '2020-08-23 10:25:07.085411+00', 'Silver Sands of Islay, The', 'SILVER SANDS OF ISLAY', 2, 40, NULL, 1, 3, 42, 2626, NULL, 'For the 25th Anniversary of Islay''s Weekend Course)', 59, '844/844/888/833/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17306, '2016-09-09 09:48:45.586995+00', '2020-10-26 18:33:41.798702+00', 'May the 4th be with you', 'MAY THE 4TH BE WITH YOU', 1, 32, NULL, 1, 3, 42, 11344, '2016-01-01', '', 50, '880/800/888/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17305, '2016-09-09 09:45:11.597776+00', '2020-10-26 18:30:18.307661+00', 'Trip to Tobermory, A', 'TRIP TO TOBERMORY', 3, 32, NULL, 1, 3, 18, 11343, NULL, '', 61, '868/808/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17308, '2016-09-09 09:59:50.275355+00', '2020-10-26 18:37:23.432701+00', 'On DC''s Roads', 'ON DCS ROADS', 3, 32, NULL, 1, 4, 2, 11345, NULL, '', 88, '8888/0880/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17312, '2016-09-09 10:16:34.999727+00', '2020-10-26 18:40:56.152393+00', 'Love in the Marais', 'LOVE IN THE MARAIS', 1, 32, NULL, 1, 4, 2, 11345, NULL, '', 75, '8008/8888/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17311, '2016-09-09 10:13:00.069103+00', '2021-01-04 11:54:10.801462+00', 'Spanish Dance', 'SPANISH DANCE', 3, 32, NULL, 1, 2, 76, 11348, NULL, '', 56, '80/88/88/84', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17313, '2016-09-09 10:22:05.609946+00', '2020-10-26 18:45:58.313624+00', 'Place de la Nation', 'PLACE DE LA NATION', 4, 64, 5, 1, 3, 42, 11344, NULL, '', 56, '880/808/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7992, '1997-12-03 23:00:00+00', '2021-03-23 19:10:54.289188+00', 'Trip to Hopetoun House, A', 'TRIP TO HOPETOUN HOUSE', 2, 32, 9999, 1, 3, 42, 619, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17322, '2016-09-09 19:58:40.067154+00', '2021-03-04 19:09:17.728066+00', 'Eilean Na Hearadh (Isle of Harris)', 'EILEAN NA HEARADH ISLE OF HARRIS', 4, 64, 5, 1, 3, 42, 10959, '2010-12-01', 'Note: the movement in bars 1-8 is based on the Half Rondel devised by John Drewry. Bars 9-24 are

based on the movement devised by Alex Hay.', 56, '880/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16900, '2016-03-06 11:10:19.839861+00', '2019-08-02 13:26:33.397953+00', 'Tandem to Anvil', 'TANDEM TO ANVIL', 2, 32, NULL, 1, 3, 42, 11240, '2009-01-01', 'This dance was devised by Val Dawson for the wedding reception/ceilidh to celebrate the marriage of Frank and Helen Davenport. Frank and Helen undertook a tandem bike ride around the coast of Britain. Starting at the beginning of March 2009 they rode from their home in Comwall to a Scottish Dance Class in Looe on the Monday morning, and then continued their ride to finish in Gretna Green for their wedding on 19th June. They then continued their tour around the coast to finish back in Cornwall in time for their wedding ceilidh on 5th September 2009.



Bars 1 - 16 Represents their tandem bike  

Bars 16 - 24 Riding around the coast of Britain  

Bars 25 - 32 The Wedding  



For ceilidh dancing the rights and lefts (bars 17-24) could be omitted, with just the 1st couple dancing in tandem. On Bars 31 & 32 the 2d and 3d couples could just step back into place.



Recommended Tune: Original (Daisy, Daisy Trad) or Welcome to Dufftown (CD Nice to See You)', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17331, '2016-09-12 20:24:33.602721+00', '2016-09-12 22:10:25.190612+00', 'Queuing at Expo Japan', 'QUEUING AT EXPO JAPAN', 3, 32, NULL, 1, 3, 42, 3669, '2005-09-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17333, '2016-09-12 22:19:36.592354+00', '2016-09-12 22:20:00.931777+00', 'Eilean Mòr', 'EILEAN MOR', 4, 64, 5, 1, 2, 76, 758, NULL, 'Ellean Mòr (pronounced Aileen More) 1s a small relatively inaccessible island that lies half a mile offshore between Kei11s and Kilmory, southeast of Jura.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17334, '2016-09-12 22:58:18.713527+00', '2016-09-12 22:58:18.713527+00', 'Sunset at the Barn', 'SUNSET AT THE BARN', 3, 32, NULL, 4, 55, 16, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17336, '2016-09-14 08:53:01.843291+00', '2016-09-14 08:53:05.315904+00', 'Kersty''s Jig', 'KERSTYS JIG', 2, 32, NULL, 1, 3, 42, 758, NULL, 'This dance was devised as a review of some basic figures. Kersty is our cat. Friends introduced her to a

toy called a Cat Dancer and I know that we have as, much fun watching her "dance" as she has in doing

her "jigs".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17337, '2016-09-14 08:59:35.706688+00', '2016-09-14 08:59:35.706688+00', 'Miss Kate of Ashland', 'MISS KATE OF ASHLAND', 3, 32, NULL, 1, 2, 76, 758, NULL, 'Music: Any good strathspey (not too strong and not an air)



Note: Kate is a lovely young lady who celebrated her 16th birthday the weekend friends and I 

visited her home and family in Ashland, Oregon.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17043, '2016-06-19 10:20:53.836384+00', '2018-10-25 09:01:43.890201+00', 'Tea Time', 'TEA TIME', 1, 40, NULL, 1, 3, 42, 11270, '1997-01-01', 'The figures recall the daily gathering for afternoon tea, organised by Miss Ross, at the RSCDS Summer School at St.Andrews. The dance was sketched out in the 1970’s but was only recently completed and danced by Harwell Caledonian Society.', 70, '844/888/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17341, '2016-09-14 11:31:07.911196+00', '2016-09-14 11:31:07.911196+00', 'Diana''s Flight for the Fiftieth', 'DIANAS FLIGHT FOR THE FIFTIETH', 1, 32, NULL, 1, 3, 42, 11357, NULL, 'Devisor''s note: At the end of bars 13-16 (the hands across), supporting couples need to cover so

they flow right into the advance and retire.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6483, '2003-01-25 23:00:00+00', '2018-04-03 00:08:20.072+00', 'Tassel O'' The Thistle, The', 'TASSEL O THE THISTLE', 1, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17345, '2016-09-14 13:32:00.316352+00', '2016-09-14 13:32:00.316352+00', 'Platinum Pair, A', 'PLATINUM PAIR', 3, 32, NULL, 1, 100, 11, 3703, NULL, 'Presented at Thistle XXXVI to Betty Lee and Duard Bames on the occasion of their platinum anniversary.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17346, '2016-09-14 13:41:39.718414+00', '2016-09-14 13:41:39.718414+00', 'Evelyn''s Easter Exercise', 'EVELYNS EASTER EXERCISE', 3, 32, NULL, 1, 3, 42, 11359, NULL, 'From The Tartan Times VolXXVIII no 5   June 1984, published by the Boston Branch', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17524, '2017-01-05 09:20:35.434555+00', '2018-04-11 00:37:25.642178+00', 'September in Skye', 'SEPTEMBER IN SKYE', 3, 32, NULL, 2, 3, 17, 572, '2012-01-01', 'Devised by Ruth Barnes.



For her husband Ronnie to celebrate their 44th wedding anniversary in 7th September 2012. They spent their honeymoon in Skye. ', 75, '880/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17351, '2016-09-16 09:10:50.490314+00', '2016-09-16 09:10:50.490314+00', 'Callander Strathspey, The', 'CALLANDER STRATHSPEY', 3, 32, NULL, 1, 4, 2, 3571, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17352, '2016-09-16 09:29:35.398983+00', '2016-09-16 09:29:35.398983+00', 'Oquaga Breakdown', 'OQUAGA BREAKDOWN', 1, 32, NULL, 4, 4, 30, 2677, NULL, 'After first 32 bars, all couples have progressed one place clockwise and partners have exchanged

places.  The floor pattern of the dance is then repeated exactly, with the substitution of women for men, and men for women.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15958, '2015-02-01 21:33:18.344297+00', '2018-04-03 00:08:22.881986+00', 'Turnham Green', 'TURNHAM GREEN', 3, 32, NULL, 1, 3, 42, 10623, NULL, 'Devised in appreciation of kind folk Chiswick Scottish Dancing Club which meets at St.Michael & All Angels Church, Turnham Green, London

', 62, '422/12,12,12/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10398, '2002-03-14 23:00:00+00', '2020-11-15 19:20:35.843244+00', 'MacDonald Saunter, The', 'MACDONALD SAUNTER', 11, 32, 9999, 5, 1, 4, 50, '1995-01-01', 'A progressive, round the room dance for couples facing line of dance (counterclockwise) with ladies on their

partner''s right. Begin with the outside foot. Take jaunty walking steps, two per bar of music.  Skip change of step may be used instead of walking steps depending on the dancers.', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (600, '1999-08-11 22:00:00+00', '2021-07-01 16:24:43.480134+00', 'Bluebells of Scotland, The', 'BLUEBELLS OF SCOTLAND', 1, 40, 9999, 1, 3, 42, 44, '1978-01-01', '"Devised to celebrate the wedding of Gillian Brown and Richard Tunley."', 49, '420/888/800/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17340, '2016-09-14 09:26:31.36489+00', '2020-07-20 08:13:37.651687+00', 'Jane and Alice have a Birthday', 'JANE AND ALICE HAVE A BIRTHDAY', 3, 32, NULL, 2, 3, 17, 11356, '2011-11-01', 'Devised by Lydia Hedge for the occasion of Jane Jones’ and Alice Ferguson’s birthdays in November 2011.', 59, '800/844/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17353, '2016-09-16 09:39:35.559329+00', '2016-09-16 09:39:35.559329+00', 'Rod and Kristin''s Farewell Fugue', 'ROD AND KRISTINS FAREWELL FUGUE', 3, 32, NULL, 1, 3, 42, 2677, '1992-12-01', 'This dance was inspired by, and uses in slightly modified form, the first figure of a dance written by Rod Downey for his wife, Kristen MacDonald''s Strathspey, while he was visiting Ithaca In the fall of 1992.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17354, '2016-09-16 09:43:37.223927+00', '2016-09-16 09:43:37.223927+00', 'Rod''s Set Dance', 'RODS SET DANCE', 1, 48, NULL, 2, 3, 17, 2677, '1992-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17355, '2016-09-16 09:49:37.528951+00', '2016-09-16 09:49:37.528951+00', 'Sue''s Delight', 'SUES DELIGHT', 1, 32, NULL, 1, 3, 42, 2677, '2008-10-01', 'To truly appreciate not knowing "Which Hand is Right?" advanced dancers may wish to try repeating the dance with rights, lefts, and roles reversed. The repeat starts with 1st woman and 2nd man setting, then the diagonal changes are made with left hands and are followed by a counterclockwise chase. The reels start with left shoulders and flow into left hands across.  1st couple dances down the middle with a left hand lead (1st woman crossing 1st man in front of her), 1st man leads the cast up around 3rd woman, 1st woman leads the cast down around 2nd woman, and the final half turn uses right hands.



This Scottish Country Dance was commissioned to honor Sue Wartell.  It is her hard work and calm leadership that makes the Columbus Country Dance Weekend such a magical event. Thanks Sue and a belated happy birthday too!  Presented at the Columbus Country Dance Weekend, October 24-25-26, 2008', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17347, '2016-09-14 22:10:21.771045+00', '2016-10-11 23:33:17.928492+00', 'Bude''s Coming of Age', 'BUDES COMING OF AGE', 1, 32, NULL, 1, 3, 42, 11399, '2016-08-01', 'This dance was composed to celebrate the 21st weekend school at Bude, Cornwall, England.



The official instructions specify the progression (213), but both crib and diagram show the normal way this dance is danced, with progression (2,1x,3), and 1c dancing 2nd time from opposite side.', 44, '888/800/822/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17481, '2016-11-15 01:07:32.067989+00', '2016-11-19 16:39:10.82301+00', 'Ursula''s Surprise', 'URSULAS SURPRISE', 1, 32, NULL, 1, 4, 2, 228, '2016-11-15', 'For Ursula Artmann, on the occasion of her significant birthday in November, 2016.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17344, '2016-09-14 13:25:47.669545+00', '2017-05-31 10:43:41.053849+00', 'Bit of a Do, A', 'BIT OF A DO', 1, 32, NULL, 2, 3, 17, 272, '2002-08-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17835, '2017-06-22 17:25:14.626423+00', '2018-04-03 00:07:41.224704+00', 'Dancing Partners, The', 'DANCING PARTNERS', 2, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17357, '2016-09-16 13:18:19.904419+00', '2016-09-16 13:18:19.904419+00', 'Maureen''s Fancy', 'MAUREENS FANCY', 4, 128, 2, 4, 4, 3, 2792, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17358, '2016-09-16 13:23:42.231229+00', '2016-09-16 13:23:42.231229+00', 'New Horizons', 'NEW HORIZONS', 1, 32, NULL, 1, 3, 42, 2792, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17359, '2016-09-16 13:31:05.838733+00', '2016-09-16 13:31:05.838733+00', 'Close Circle of Friends, A', 'CLOSE CIRCLE OF FRIENDS', 2, 32, NULL, 5, 56, NULL, 11361, '1993-09-01', 'Triplets face triplets around the room.  Men are in the center, between two women.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17361, '2016-09-16 13:40:35.673201+00', '2016-09-16 13:40:35.673201+00', 'Dance for Polly''s Wedding, A', 'DANCE FOR POLLYS WEDDING', 4, 40, 25, 1, 3, 42, 777, '1981-12-20', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17362, '2016-09-16 13:50:33.917612+00', '2016-09-16 13:50:33.917612+00', 'Cold Day at Loch Norman, A', 'COLD DAY AT LOCH NORMAN', 1, 32, NULL, 1, 100, 2, 9998, '2008-04-20', 'By eight very cold dancers, to keep warm.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17363, '2016-09-16 13:56:41.810032+00', '2016-09-16 13:56:41.810032+00', 'Dog on the Dance Floor', 'DOG ON THE DANCE FLOOR', 1, 32, NULL, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17364, '2016-09-16 14:02:36.707974+00', '2016-09-16 14:02:36.707974+00', 'From Novosibirsk to Moscow', 'FROM NOVOSIBIRSK TO MOSCOW', 4, 64, 5, 1, 4, 2, 635, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17365, '2016-09-16 14:09:17.304285+00', '2016-09-16 14:09:17.304285+00', 'Grandfather Welcome ''88', 'GRANDFATHER WELCOME 88', 4, 32, 1, 5, 1, 4, 9998, NULL, 'from Pinewoods 1987', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17366, '2016-09-16 14:25:11.775537+00', '2016-09-16 14:25:11.775537+00', 'Gravenhurst Rocks!', 'GRAVENHURST ROCKS', 2, 32, NULL, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17367, '2016-09-16 14:28:48.38604+00', '2016-09-16 14:29:04.561555+00', 'Josh''s Digital Jig', 'JOSHS DIGITAL JIG', 2, 32, NULL, 3, 5, 7, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17368, '2016-09-16 14:34:29.879071+00', '2016-09-16 14:34:29.879071+00', 'Reel-Y Peg', 'REELY PEG', 2, 32, NULL, 1, 3, 42, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17369, '2016-09-16 14:51:29.649009+00', '2016-09-16 14:52:15.715766+00', 'Rascal Rounder, The', 'RASCAL ROUNDER', 3, 32, NULL, 1, 3, 42, 9998, NULL, 'Handwritten on the text, poorly legible, "Devised by L?es L?angen?', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9037, '1999-05-09 22:00:00+00', '2016-09-16 17:50:46.257539+00', 'Sabino Wedding', 'SABINO WEDDING', 2, 32, 9999, 1, 4, 2, 1309, '1997-04-01', 'Devised in honour of the marriage of Gail Cordy and Bryce Carey, 23 March 1997. Gail and Bryce were married in Sabino Canyon outside Tucson. There was some confusion among the guests about whether they were supposed to be going to Bear Canyon or Lower Sabino Canyon, hence the allemandes in opposite directions.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17373, '2016-09-16 17:55:46.880473+00', '2016-09-16 17:55:46.880473+00', 'Courtship, The', 'COURTSHIP', 3, 40, NULL, 1, 4, 15, 11365, NULL, 'Devised by James and Sharon LaTourette of the Scottish Country Dancers of Colorado, New Mexico Branch. This dance is a story dance depicting a typical courtship. One pursues, the other flees. A period of indecision ensues while they flirt with other partners. Finally, they are reunited and allemande off into the sunset.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17375, '2016-09-16 18:37:34.692507+00', '2016-09-16 18:37:34.692507+00', 'Shotgun Wedding', 'SHOTGUN WEDDING', 2, 32, NULL, 1, 4, 1, 11367, '1994-06-01', 'The dance was devised by Jeff and Linda Davis while under the gun searching for suitable "mob" dances for a wedding reception.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17376, '2016-09-16 18:46:04.858438+00', '2016-09-16 18:46:04.858438+00', 'Mrs. Hepburn''s New Reel', 'MRS HEPBURNS NEW REEL', 1, 48, NULL, 1, 3, 42, 11366, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17377, '2016-09-16 18:52:27.846285+00', '2016-09-16 18:52:27.846285+00', 'Chartreuse Pelican, The', 'CHARTREUSE PELICAN', 3, 32, NULL, 1, 2, 76, 11368, NULL, 'The dance was devised by James Thayer for Sharon LaTourette on the occasion of their

Birthday. The name is a play on "Seann Truibhas Willichan"', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17360, '2016-09-16 13:36:30.326536+00', '2020-06-28 21:15:45.380538+00', 'Tipsy Vicar, The', 'TIPSY VICAR', 2, 32, NULL, 1, 3, 42, 11362, NULL, '', 48, '820/844/668/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17372, '2016-09-16 17:48:58.44206+00', '2020-10-26 19:09:53.871191+00', '12th Night Ball, The', '12TH NIGHT BALL', 2, 40, NULL, 2, 3, 18, 10595, NULL, 'The Tucson Branch celebrates every New Year with the 12th night ball. It usually takes place

in historic Bisbee, Az.  It''s a quaint old copper mining town near the Mexican border, full of

antique shops and haunted hotels - but that''s another story. Written by Carole Skinner, one of

the teachers in the Tucson Branch, in celebration of the old and the bringing in of the new.', 53, '404/404/484/484/448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17378, '2016-09-16 18:59:31.02441+00', '2016-09-16 18:59:31.02441+00', 'Beavertail Slap, The', 'BEAVERTAIL SLAP', 1, 32, NULL, 1, 3, 42, 11369, NULL, 'The dance was written by Carolyn Engel-Wilson of Phoenix Branch, Arizona three years ago based on an idea from her non-dancer husband Ron, who also came up with the name. The dance tells a story about beavers. When the story begins, the beavers are cutting down a very large tree (petronella setting and turning). When the tree finally falls, two beavers are so startled by the crash that they slap their flat tails on the water in alarm (the clap) and swim around in panic. Hearing the tails slap and seeing the frantic activity alarms the other beavers in the pond. They all slap their tails on the water (all clap) and swim around seeking a safe place (reels of three).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17374, '2016-09-16 18:33:17.882999+00', '2016-09-16 19:48:00.060575+00', 'Ashley Pond''s Reel', 'ASHLEY PONDS REEL', 1, 32, NULL, 1, 3, 42, 11366, NULL, 'Ashley Pond was the headmaster of the boy''s ranch school which occupied Los Alamos before the Manhattan Project arrived. The pond in the middle of town is technically "Ashley Pond pond".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17543, '2017-01-20 02:09:25.195911+00', '2017-01-20 02:09:42.600097+00', 'Hills of Waverton, The', 'HILLS OF WAVERTON', 1, 32, 9999, 1, 3, 42, 57, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17616, '2017-02-21 21:50:03.269939+00', '2017-02-21 22:51:37.000701+00', 'Au Revoir Mes Amis', 'AU REVOIR MES AMIS', 3, 32, NULL, 1, 2, 76, 11151, '2016-01-01', '', 69, '88/88/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17846, '2017-06-22 17:46:58.561816+00', '2017-06-22 17:46:58.561816+00', 'Rose Still Blooms, The', 'ROSE STILL BLOOMS', 3, 32, NULL, 2, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17854, '2017-06-23 07:55:46.948294+00', '2017-06-23 07:55:46.948294+00', 'North Head Strathspey', 'NORTH HEAD STRATHSPEY', 3, 32, NULL, 4, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17865, '2017-06-23 09:04:45.251145+00', '2017-06-23 09:04:45.251145+00', 'Counting House Strathspey, The', 'COUNTING HOUSE STRATHSPEY', 3, 32, NULL, 1, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17868, '2017-06-23 09:06:41.319946+00', '2017-06-23 09:06:41.319946+00', 'Celandine Strathspey, The', 'CELANDINE STRATHSPEY', 3, 32, NULL, 1, 2, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17869, '2017-06-23 09:18:02.218021+00', '2017-06-23 09:18:02.218021+00', 'Bridge Over the Danube', 'BRIDGE OVER THE DANUBE', 2, 32, NULL, 1, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17871, '2017-06-23 09:19:43.171341+00', '2017-06-23 09:19:43.171341+00', 'Crossing the Globe', 'CROSSING THE GLOBE', 4, 32, 10034, 4, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17862, '2017-06-23 09:03:02.823366+00', '2018-04-03 00:08:08.671911+00', 'Olga''s Dance', 'OLGAS DANCE', 1, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6728, '1997-09-16 22:00:00+00', '2019-09-13 16:38:38.778498+00', 'Trip to Paris, A', 'TRIP TO PARIS', 1, 26, 9999, 1, 2, 76, 397, '1711-01-01', 'Note in the Whetherly Book 24: the setting on bars 23-24 has been added in accordance with modern technique.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17380, '2016-09-16 19:20:07.093799+00', '2016-09-16 19:20:07.093799+00', 'Mrs. Ella Thompson', 'MRS ELLA THOMPSON', 3, 32, NULL, 1, 4, 2, 3204, '1986-01-01', 'Dance devised in 1986 by Richard Wood, in honor of Ella, a sweet lady, RSCDS Instructor,

mentor, and director of dancing for the St. Andrew Society of Colorado. First performed for

Ella in the 3rd floor elevator landing of Porter Memorial Hospital, Denver, Colorado.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17383, '2016-09-18 09:39:32.414571+00', '2018-04-02 23:56:35.569079+00', 'Juliet''s Reel', 'JULIETS REEL', 1, 32, NULL, 1, 3, 42, 11374, '2008-05-20', 'For Louise Drummond, who had a dream.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17379, '2016-09-16 19:13:06.481213+00', '2016-09-16 19:54:08.437856+00', 'Ann''s Frolic', 'ANNS FROLIC', 2, 32, NULL, 1, 2, 76, 11370, NULL, 'Note: The dance repeats having progressed one place. When all four couples are dancing, interlock the casts through the center.



The dance was devised to complement music written and dedicated by Loretta Thompson to the memory of friend Ann Chambers.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16474, '2015-07-07 16:24:58.790775+00', '2016-09-17 23:11:01.176788+00', 'Madame de Staël', 'MADAME DE STAEL', 1, 32, 9999, 4, 4, 1, 11151, NULL, 'Madame de Staël (1766-1817)



One of the Directoire Merveilleuses, salonière, writer and essayist. During the years of 1803 and 1813 she was exiled to her family Château in Coppet alongside the shores of Lake Geneva, her was exile was mainly due to her opposition against Napoléon Bonaparte.



During the 10 years of exile, she held the most important Salon in Europe, in which the most brilliant minds of the time would gather and discuss the current day affairs, perform plays, read out aloud the latest novels, and of course dance!



Most importantly, in the Castle account book for the summer of 1808 Madame de Staël had a certain "M. Fergusson de Perrth à été mandé a donner des leçons de danse aux enfans",  Mr Ferguson from Perth was asked to give dance lessons to the children.



One can only imagine what dances we''re taught! but this also proves that everything that was "Scotch" was the height of sophistication.



Also when in London during the season of 1814, Herself and her daughter were frequent guests at Almack''s the most elite ballroom during the Regency, and Scotch Reels were always on the Program.



It is however in my belief, quite appropriate that alongside the Noble Ladies and Gentry of Scotland, that Madame de Staël should also have a dance in her name.



Lord Byron and Mary Shelley both said that her conversation was like an avalanche of snow.



This dance reflects her in a certain way!



(information provided by the deviser)', 94, '8484/8888/8888/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2346, '2002-04-19 22:00:00+00', '2016-09-18 12:32:13.74568+00', 'Friends Forever', 'FRIENDS FOREVER', 3, 32, 9999, 1, 2, 76, 228, '1992-01-02', 'For Eva Schiedrum, who talked me into taking up Scottish country dancing.  Devised in January, 1992.', 60, '44/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17382, '2016-09-18 06:45:32.644386+00', '2016-09-21 01:00:05.227531+00', 'Lorna''s dance', 'LORNAS DANCE', 2, 32, NULL, 1, 3, 42, 11002, '2015-02-14', 'For Lorna Valentine of RSCDS East Angus Branch, 14th February 2015', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15399, '2014-03-21 23:57:37.731902+00', '2016-12-31 14:47:11.491335+00', 'Ardmore Junction', 'ARDMORE JUNCTION', 1, 32, NULL, 1, 3, 42, 10934, NULL, 'This dance was devised while I was waiting for the 44 bus, which goes to Ardmore. It honors the monthly social dances Kate, Ed, and Sara Nealley host in their home, Inverarity, at the Ardmore Junction train stop. The dance incorporates bits of my favorite Inverarity dance, Flowers of Edinburgh.', 47, '888/820/820/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17564, '2017-01-22 21:27:36.964357+00', '2017-01-22 21:27:36.964357+00', 'Randall Allen of County Troup', 'RANDALL ALLEN OF COUNTY TROUP', 3, 32, NULL, 2, 3, NULL, 11446, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17428, '2016-10-30 11:27:50.721504+00', '2021-07-04 12:10:44.364249+00', 'Carlingwark Jig', 'CARLINGWARK JIG', 2, 32, NULL, 1, 4, 1, 433, '2010-01-01', 'Also published singly as a leaflet with music score by RSCDS Castle Douglas and District Branch to mark their 60th anniversary (1950-2010) and dedicated to teachers, musicians, office bearers, and members past and present. Information from <<https://my.strathspey.org/dd/issue/2535/|issue 2535>>.', 84, '8888/6222/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6688, '1997-08-24 22:00:00+00', '2018-04-03 00:08:21.73128+00', 'Treasured Souvenir, A', 'TREASURED SOUVENIR', 1, 32, 9999, 1, 3, 42, 35, '1991-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10955, '2002-11-14 23:00:00+00', '2016-09-23 22:31:18.17769+00', 'She''s Noo Awa Frae Ballantyre', 'SHES NOO AWA FRAE BALLANTYRE', 11, 16, 9999, 7, 1, 4, 1268, NULL, 'Written in 1993 to denote Nancy Weins'' departure from the Ballantyre Apartments of Eagan, Minnesota. Nancy moved to Moberly, Missouri. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17385, '2016-09-19 00:12:56.745519+00', '2016-09-19 00:12:56.745519+00', 'Rosalind''s Fancy', 'ROSALINDS FANCY', 3, 32, NULL, 1, 4, 2, 228, '2016-09-19', 'Dedicated to the memory of Rosalind Elsie Franklin (1920–1958), chemist and X-ray crystallographer, who among many other accomplishments contributed significantly to the discovery of the double-helix structure of DNA. Having died of ovarian cancer at age 37, Franklin was ineligible to share the Nobel Prize in Physiology or Medicine awarded to James Watson, Francis Crick, and Maurice Wilkins in 1962, since Nobel Prizes are not given posthumously.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2179, '1997-09-02 22:00:00+00', '2016-09-19 11:06:26.495305+00', 'Fiona''s Fancy', 'FIONAS FANCY', 1, 32, 9999, 5, 2, 76, 28, NULL, '', 60, '88/88/44/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13871, '2011-08-22 22:00:00+00', '2016-09-19 20:15:50.299034+00', 'How many are there tonight, David?', 'HOW MANY ARE THERE TONIGHT DAVID', 3, 32, NULL, 2, 3, 17, 10400, '2009-03-04', 'Dance devised to celebrate the 80th birthday of David Foster on 4 March 2009.

At the start of each Tuesday class Barbara usually asks the question ‘How many are there tonight, David?’  David can always supply the answer!

', 83, '808/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18221, '2018-01-14 17:03:33.685953+00', '2018-05-13 21:09:35.896774+00', 'Invertay House', 'INVERTAY HOUSE', 4, 32, 2, 1, 4, 1, 11587, '2017-01-01', 'Suggested music: MacDonald of Keppoch (Book 49) 



Devised by Graeme Plank from Tam O’Shanter Club, Christchurch.  



Dedicated to Gilian and Bruce Ford who were the most gracious hosts at Invertay House, a former manse converted to a Guest House in the picturesque village of Killin near Loch Tay. Graeme’s parents in law were planning to stay at Invertay House on holiday in 2017 but found that the Ford’s had just retired and still had fond memories of Graeme who had stayed for a short period 18 years earlier while tracing his MacNabb ancestry. Hence this dance is dedicated to them.  

The dance was devised for demonstration purposes as a graceful blend of the old and the new … much like Invertay House in Killin.', 88, '8888/8466/4488/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15186, '2013-10-14 08:27:11.928013+00', '2016-09-20 12:16:38.227119+00', 'Heck Hurry, The', 'HECK HURRY', 1, 24, NULL, 1, 4, 1, 10869, NULL, 'Joanna Barrie was 9 years old when she devised "The Heck Hurry" (Thistle Scottish Country Dance Club, Dumfries.



The Heck is a hamlet outside of Lockerbie, one of the four royal towns.



', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17388, '2016-09-22 22:39:19.199376+00', '2016-09-25 23:29:00.405422+00', 'Calais Sunshine', 'CALAIS SUNSHINE', 3, 40, NULL, 1, 100, 2, 11110, '2014-08-14', 'I find it difficult to sit in the sunshine with nothing to do!  Prior to going on holiday I had received a letter from Bognor SCD club asking me to write a Strathspey for their Day of Dance. This dance was devised while sitting with a Drink in the Calais Sunshine.



A full description of "Set and Link for Four" can be found on "A Twinkle in His Eye" in the Leeds Golden Collection.





', 85, '8888/8448/8008/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3186, '1997-09-04 22:00:00+00', '2018-05-15 19:42:08.851756+00', 'Jacobite Ladies Of Murrayshall, The', 'JACOBITE LADIES OF MURRAYSHALL', 2, 40, 9999, 2, 3, NULL, 13, NULL, 'Murrayshall, near Stirling, the home of William Wilson, an Edinburgh lawyer and his three daughters, was a centre of Jacobite intrigue. The daughters became known locally a "the three Jacobite ladies of Murrayshall". ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16570, '2015-08-26 08:13:37.180796+00', '2016-09-25 16:57:19.127097+00', 'Sixth of August', 'SIXTH OF AUGUST', 2, 48, NULL, 2, 3, 17, 3592, '1965-08-06', 'Devised by Ron Watson, 6th August 1965.



Having instigated the application for Bournemouth Reel Club to become a Branch of The Royal Scottish Country Dance Society, Ron Watson devised this dance to commemorate the occasion of our acceptance.



', 83, '880/844/888/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18433, '2018-07-19 10:43:32.09601+00', '2018-07-19 10:43:32.09601+00', 'Mists over Maroon', 'MISTS OVER MAROON', 3, 32, NULL, 1, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12347, '2005-04-27 22:00:00+00', '2018-03-26 09:27:22.292861+00', 'Silver Wedding', 'SILVER WEDDING', 4, 32, 9999, 1, 3, 42, 2780, '2000-01-01', 'For Mr. and Mrs. Ikema.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15051, '2013-08-06 12:53:14.22724+00', '2016-09-27 18:01:09.249652+00', 'Cate''s Conundrum', 'CATES CONUNDRUM', 3, 32, 9999, 2, 3, 18, 154, '2005-12-27', 'Devised in New Zealand after singing the upside down Christmas carol, hence the 2nd and 3rd couples crossing on bars 31-32', 73, '880/880/844/868', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10922, '2002-11-12 23:00:00+00', '2020-07-24 13:09:50.709128+00', 'Dutiful Wife, The', 'DUTIFUL WIFE', 2, 32, 9999, 1, 3, 42, 1268, '1989-01-01', 'Dedicated to Jean Waugh, the dutiful wife of Alec Waugh. The Waughs dance with the Boston branch of the Royal Scottish Country Dance Society', 38, '800/844/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17506, '2016-12-31 14:56:11.017409+00', '2020-11-02 09:36:24.554503+00', 'Spring''s Arrival', 'SPRINGS ARRIVAL', 3, 32, NULL, 1, 3, 42, 10934, NULL, 'This dance was devised to celebrate the birth of Elena Violet Giacoletti to our good friends Kathy and Justin on April 15, 2005.The final twelve bars of the dance demonstrate the birth. Please note the tempo should be fast enough such that it takes less than nine months to complete them.', 55, '800/888/860/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17386, '2016-09-19 23:32:38.291191+00', '2020-12-28 20:06:22.66693+00', 'Brays of McGregor, The', 'BRAYS OF MACGREGOR', 3, 32, NULL, 2, 3, 17, 10582, '2015-08-01', 'This dance is devised to highlight the work of the Eseltjierus Donkey Sanctuary just outside McGregor. (The sanctuary provides a permanent refuge for abused, neglected and elderly donkeys where they are given the opportunity to live out their lives with respect and dignity, in a protective and natural environment.)', 93, '888/888/888/484', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8992, '2003-04-16 22:00:00+00', '2021-03-07 19:08:57.091674+00', 'Long and the Short of It, The', 'LONG AND THE SHORT OF IT', 4, 256, 55, 1, 4, 1, 1331, '2002-01-01', '32-bar dance, designed to be danced 4 times Strathspey followed by 4 times Reel.



Bruce Herbold devised “The Long and the Short of It” for the wedding of David Newitt (6’3”) and Heather MacKay (barely 5’ 1 ¼”). Despite their height mismatch, they are a perfect pair. Patti wrote the name tune in contemplation of how long the road can be to find that person who really feels like “home”. ', 50, '8800  8000  8088  8008', 0, 1, 0, 0, 6);
INSERT INTO 'dance' VALUES (17531, '2017-01-05 10:04:35.284176+00', '2021-04-14 10:36:16.032984+00', 'Snow in Summer', 'SNOW IN SUMMER', 3, 32, NULL, 1, 3, 42, 28, '2013-05-01', 'The notes say the title of the dance is reminiscent of when, in May 2013, most of Northern Ireland was white with snow.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17265, '2016-09-05 22:44:27.743924+00', '2021-08-06 20:54:40.907086+00', 'Valley Over the Hill, The', 'VALLEY OVER THE HILL', 1, 32, NULL, 1, 3, 42, 10934, NULL, '', 56, '800/866/866/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17454, '2016-10-30 12:20:33.983393+00', '2018-12-02 15:39:01.68909+00', 'Sandy''s Strathspey', 'SANDYS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 433, '2011-07-01', 'In Memory of Sandy Millar, Gatehouse of Fleet. A devoted and natural Scottish country dancer over many years and a dear friend to all.', 45, '800/866/833/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17549, '2017-01-20 03:24:12.148763+00', '2018-04-02 16:48:21.205053+00', 'Celebration Waltz', 'CELEBRATION WALTZ', 5, 64, 9999, 107, 1, NULL, 1042, '2001-01-01', 'Devised by Bruce Fordyce in recognition of 50 years of dancing by the Hastings (NZ) Scottish Country Dance Club (1950-2001).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14262, '2011-09-10 22:00:00+00', '2016-09-27 14:27:25.013967+00', 'Floundering Around', 'FLOUNDERING AROUND', 1, 32, NULL, 4, 6, 60, 1228, '2007-01-31', 'For the Bognor Regis S.D.C.



6 couple square set. 5th couple facing lst couple, 6th couple facing 3rd couple



I was asked to devise a dance with a place being the theme.  So with my liking for plays on words I added to place gave me Plaice and I came up with the title.', 83, '808088/888888/888800/888888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1170, '1997-04-03 22:00:00+00', '2016-09-27 14:41:46.22014+00', 'Chelmsford Lassies', 'CHELMSFORD LASSIES', 2, 32, 9999, 1, 4, 1, 317, NULL, 'Slow Jig.



Devised by Plpe Major Peter Quinn, for Lassies Night of the Chelmsford Scottish Society, at the Shire Hall, Chelmsford, where it was first danced around 1961  under its original name of “Lassies Nicht at Chelmsford”', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3733, '1997-04-03 22:00:00+00', '2016-09-27 14:44:25.724329+00', 'Lassies Night At Chelmsford', 'LASSIES NIGHT AT CHELMSFORD', 1, 32, 9999, 1, 98, NULL, 380, NULL, 'Probably related to the dance "Chelmsford Lassies" by Peter Quinn.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17390, '2016-09-29 09:30:11.173871+00', '2018-04-02 23:56:37.765007+00', 'Stepways', 'STEPWAYS', 1, 32, NULL, 1, 3, 42, 108, '2007-02-01', 'May be danced either as a Reel or a Strathspey.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17394, '2016-10-04 12:53:40.331107+00', '2016-10-04 14:43:25.512385+00', 'Aloha Strathspey, The', 'ALOHA STRATHSPEY', 3, 32, NULL, 1, 3, 42, 1331, '2012-01-01', 'For Cameron MacDonald and Art Tarsa as they move to Hawaii.  Art and Cameron were long-time dancers in the San Francisco Branch.  Cameron was the only other Scottish Dancer with me at the Environmental Protection Agency.  I miss them both, but dance with them still in the Sandwich Isles.', 53, '880/844/880/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17395, '2016-10-04 15:21:53.115739+00', '2016-10-04 15:21:58.307191+00', 'Couple of Keepers, A', 'COUPLE OF KEEPERS', 3, 32, NULL, 2, 3, 17, 11385, '2013-01-01', 'Tim and Sylvain have kept the San Francisco Class fun and friendly for many years.  Tim is a librarian and Sylvain is our branch treasurer and he works in financial services, so they are both, in different ways, keepers of books.  They are beloved by the other class members who certainly consider them a couple of keepers.  The dance name was the result of long lakeside discussions in Yellowstone amongst Patti, Bruce, Mark Caplin, and Eileen Ritchey.

', 67, '840/880/844/848', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17550, '2017-01-20 04:01:52.961994+00', '2019-06-10 00:03:03.199599+00', 'Four Poster, The', 'FOUR POSTER', 3, 32, 9999, 1, 54, 11, 2677, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5900, '2003-01-25 23:00:00+00', '2016-11-06 10:10:03.322991+00', 'Sassenachs'' Pleasure', 'SASSENACHS PLEASURE', 1, 40, 9999, 1, 3, 42, 35, NULL, 'SASSENACHS (Scottish term for an Englishman) 

Written for two ladies of the same English ancestry, Ruth V. Coates and Frances M. Whittaker 



Is this dance a Reel or Jig?   The dance was first published in The Cameo Collection No.1 as a "40 bar Jig", with "Kingussie Flower" as suggested music, but that is a 40 bar REEL.  The same month a new printing of the book names this dance as a Reel.  It seems likely that "Jig" was a misprint that was corrected.   For details read the extensive discussion on the "Strathspey List" on 26-27 September 2016. 







', 50, '840/804/400/888/400/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17545, '2017-01-20 02:19:00.297406+00', '2017-01-20 02:19:00.297406+00', 'Still Journey On', 'STILL JOURNEY ON', 3, 32, 9999, 1, 3, 42, 57, '1972-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17546, '2017-01-20 02:21:48.958868+00', '2017-01-20 02:21:48.958868+00', 'Just Betty', 'JUST BETTY', 2, 48, 9999, 1, 4, 11, 3462, '1992-07-04', 'The couple in 2nd place is the dancing couple!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17547, '2017-01-20 02:24:10.841674+00', '2017-01-20 02:24:10.841674+00', 'Whisky in Glen Strae', 'WHISKY IN GLEN STRAE', 3, 32, 9999, 1, 3, 42, 57, '1971-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17548, '2017-01-20 02:26:17.061021+00', '2017-01-20 02:26:17.061021+00', 'Ian MacRae', 'IAN MACRAE', 2, 32, 9999, 1, 3, 42, 3462, '1990-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2379, '1997-09-02 22:00:00+00', '2018-05-16 00:53:30.390636+00', 'Gala Night', 'GALA NIGHT', 2, 32, 9999, 2, 2, 76, 23, NULL, 'I feel that the fIrst dance of a party or ball and the fIrst dance after intermission should be gentle dances - no pas de basque, preferably shorter than normal - and also very friendly dances; so this (which has

gone through many permutations but I''m finally happy with it) now opens our Grandfather Mountain Games Gala each July in the lovely hills of North Carolina.', 58, '80/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17391, '2016-09-30 19:50:23.12092+00', '2020-03-19 10:54:45.511995+00', 'While Grumpy Rested', 'WHILE GRUMPY RESTED', 3, 32, NULL, 1, 100, 2, 793, NULL, 'For competent sets, the side couples, during bars 17 - 24, may dance rights and lefts, starting on the sides.  If this is done, the right hands across should finish where it started, so all are in line across the dance, facing up or down, as they are at the start of the phrase. This provides 2 great covering opportunities - bar 17 and bar 21. The end of the left-hands across has to be judged carefully so that all the dancers are where they should be for the start of the reels.The dance works best if it is more of a ‘square’ than a ‘long’ set when these rights and lefts are done.



I composed this dance on the sunny balcony of an empty mountain chalet whilst I waited

for my ski-touring companions who were moving faster uphill than my injured knee would

allow me to climb; what else can one do for 2 hours in the sun on a deserted mountainside?', 81, '8008/8888/8888/8448', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3057, '2002-02-26 23:00:00+00', '2020-08-06 15:01:28.298622+00', 'Ian Powrie''s Farewell to Auchterarder', 'IAN POWRIES FAREWELL TO AUCHTERARDER', 2, 128, 9999, 4, 4, 3, 167, NULL, '', 72, '(1s+3s; 2s+4s) (88/44/44/88 / 84/88/80/80 / 48/88/08/08 / 88/44/44/88', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (17399, '2016-10-04 23:06:57.806043+00', '2020-06-08 21:29:40.521294+00', 'On the Boardwalk', 'ON THE BOARDWALK', 1, 32, NULL, 1, 2, 76, 1331, '2013-01-01', '', 94, '84/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17453, '2016-10-30 12:18:35.318797+00', '2020-10-28 22:51:24.701531+00', '70 x 4', '70 X 4', 2, 32, NULL, 1, 3, 42, 433, '2014-01-01', '', 59, '840/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2846, '1998-11-14 23:00:00+00', '2021-05-01 21:04:27.048594+00', 'Hebridean Weaving Lilt', 'HEBRIDEAN WEAVING LILT', 50, 88, 9999, 1, 4, 3, 9998, NULL, '##RSCDS-DI:omit-type



Introduction to the description:  This is an occupational dance for four couples in a  longwise set. If possible, the dance should be danced to "mouth music". The step throughout is a running step with a  distinctly marked beat on lhe first beat of each bar. Arms are linked instead of Joining hands. Where possible the movements are phrased to eight bars of music, but when this is found too difficult, the dancers keep running on the spot until they can start a new figure with the beginning of a musical phrase. ', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18434, '2018-07-19 10:44:27.644843+00', '2018-07-19 10:44:27.644843+00', 'Mover and Groover, The', 'MOVER AND GROOVER', 1, 40, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17405, '2016-10-08 23:17:32.313425+00', '2018-09-19 09:48:45.761951+00', 'Pat George''s Strathspey', 'PAT GEORGES STRATHSPEY', 3, 32, 9999, 4, 5, 6, 10889, '2016-01-01', 'Devise,d by Pat Harland for Pat George who reintroduced her to Scottish Dancing.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17535, '2017-01-05 10:35:01.730019+00', '2019-10-25 05:31:56.333645+00', 'Bunker Hill', 'BUNKER HILL', 2, 48, NULL, 4, 4, 1, 2126, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15044, '2013-08-05 06:46:37.62753+00', '2016-10-08 23:30:24.254482+00', 'Staircase In Styria', 'STAIRCASE IN STYRIA', 1, 40, NULL, 3, 5, 16, 11323, NULL, 'The dance was inspired by the double spiral staircase in the castle in Graz, capital of the Styrian region of Austria, and represents going up the stairs, down the stairs and meeting on the stairs.

', 46, '84840  80844  80800  80400  80004', 0, 1, 1, 0, 46);
INSERT INTO 'dance' VALUES (18438, '2018-07-19 10:47:38.474304+00', '2019-07-19 07:10:57.627637+00', 'Travelling Trios, The', 'TRAVELLING TRIOS', 1, 32, NULL, 2, 3, 18, 10907, NULL, 'When our travelling group parted in Dublin, two ladies and one man flew to England for further travels and two men and one lady flew home to Australia, hence the structure of the set.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17406, '2016-10-08 23:18:45.220466+00', '2017-10-20 13:41:58.690249+00', 'Newark Castle', 'NEWARK CASTLE', 2, 48, 9999, 4, 4, 1, 10889, '2014-05-01', '', 71, '8404/8808/8888/8888/0808/8080', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16855, '2016-01-18 17:03:51.960552+00', '2016-10-17 00:22:20.29384+00', 'Ones with Twos, Threes & Fours', 'ONES WITH TWOS THREES AND FOURS', 2, 32, 9999, 1, 4, 1, 11035, '2013-01-01', 'Can be danced as a Jig or a Strathspey



This dance was devised for teaching at the Wellington Region’s Beginners’ Class 2013.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (117, '2002-04-19 22:00:00+00', '2016-10-24 02:30:37.591818+00', 'Amanda Mae''s Strathspey', 'AMANDA MAES STRATHSPEY', 3, 32, 9999, 2, 2, 76, 625, '1991-02-01', 'Amanda Mae''s Strathspey was devised in her honor by local teacher Aase Hansen and then published when Amanda Mae Fleri was only about 1½ years old (born in August of 1989).  She is the daughter of San Diego dancers Cynthia and Ward Fleri.', 50, '66/66/44/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17404, '2016-10-08 23:15:11.567029+00', '2016-11-08 14:09:55.621349+00', 'Courtship, The', 'COURTSHIP', 1, 40, 9999, 1, 3, 42, 10648, '2014-06-01', '', 55, '888/822/822/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17855, '2017-06-23 07:56:21.258735+00', '2018-04-03 00:07:47.70537+00', 'Gannets Galore', 'GANNETS GALORE', 2, 40, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17401, '2016-10-04 23:16:33.057424+00', '2019-12-26 12:10:59.048792+00', 'Stolen Moments', 'STOLEN MOMENTS', 1, 32, NULL, 1, 3, 42, 1331, '2015-01-01', 'Composition of Stolen Time followed on from the Beachcomber Reel, with which it is combined in the recorded set of tunes for On the Boardwalk.  

Patti explains that "This tune is a further exploration of tunes with syncopation, playing with time."', 50, '880/800/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17400, '2016-10-04 23:13:42.58743+00', '2020-08-23 10:10:31.65803+00', 'On the Wings of a Skorie', 'ON THE WINGS OF A SKORIE', 1, 32, NULL, 1, 2, 76, 1331, '2014-01-01', 'This dance is dedicated to the late fiddler Michael Ferrie who wrote the tune and who died far too young.  The notes to the album where this tune appears explain: 



“Michael Ferrie wrote this tune after watching the family’s new kitten playing in the garden.  The kitten bravely decided to tackle a large skorie (Herring Gull) and jumped on its back.  The skorie, not much impressed, took flight with the kitten aboard.  Luckily for the kitten it managed to escape, but not until the bird had flown several hundred yards down the field.”  



The chase in bars 17-24 of the dance is my effort to represent the kitten’s adventure.  Thanks to my friend James MacQueen for bringing the tune to my attention. 

', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17403, '2016-10-08 23:12:28.821927+00', '2020-10-27 19:26:19.933814+00', 'Musical Page, A', 'MUSICAL PAGE', 3, 32, 9999, 1, 3, 42, 10648, '2016-01-01', '', 69, '880/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17407, '2016-10-08 23:21:17.33804+00', '2020-10-27 19:29:51.982211+00', 'Jan Maree', 'JAN MAREE', 1, 32, 9999, 2, 3, 17, 2957, '2007-07-31', '', 63, '888/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17408, '2016-10-08 23:23:23.391929+00', '2020-10-27 19:37:08.089697+00', 'Merry St Andrews', 'MERRY ST ANDREWS', 2, 40, 9999, 1, 3, 42, 2973, '2013-01-01', '', 50, '440/844/088/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15323, '2013-12-22 23:23:19.625331+00', '2021-07-04 08:52:36.398637+00', 'Six-Figured Man, The', 'SIXFIGURED MAN', 2, 48, NULL, 1, 3, 42, 10589, '2013-03-01', 'The dance refers to "The Six-fingered Man".  The author''s comments are:



bars 1-8: The Fateful meeting of the Stranger and the Spanish sword maker.



bars 9-40:  The son''s lifelong search for the stranger who killed his father, known to him only as the "Six-Fingered Man".



Bars 41-48:  The final last chase through the castle, culminating, at last, in the climatic face-to-face meeting with the Six-Fingered Man.



The title is meant to be humorous - a play on words - the dance is made up of six figures.



Editor''s note: as the dance refers to "The Six-Fingered Man", that name has been added as a spelling alias to help those who search using that more intuitive name.



', 54, '880/844/844/844/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17422, '2016-10-19 21:47:45.332735+00', '2016-10-20 10:19:37.073288+00', 'Trefoil Badge, The', 'TREFOIL BADGE', 1, 40, 9999, 6, 3, 18, 10912, NULL, 'This dance is so-named in recognition of the critical importance of the Girl Guide movement to Scottish Country Dancing.



But for Mrs Ysobel Stewart''s inspired idea that Scottish Girl Guides should learn and be tested in their native dancing rather than English Country Dancing, the activity which so many of us enjoy might simply have withered away. 



(Source: <<http://www.scottish-country-dancing-dictionary.com/dance-crib/trefoil-badge.html|Scottish Country Dancing Dictionary>>)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17507, '2016-12-31 15:03:00.923008+00', '2016-12-31 15:03:00.923008+00', 'Get Your Feet Wet', 'GET YOUR FEET WET', 2, 32, NULL, 1, 2, 76, 10934, NULL, 'This dance was devised during a trek from the train to one of the wonderful pool parties held at the home of Dan, Jill, and Jessica Emery.I thought a good warmup jig would be an appropriate tribute to hot afternoons by the water''s edge.', -1, '', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (17419, '2016-10-19 21:37:47.551263+00', '2016-10-20 09:46:54.956445+00', 'Step Forth', 'STEP FORTH', 1, 32, 9999, 1, 4, 1, 10912, NULL, 'The dance name is a mild pun on pas-de-basque as the fourth step to be learnt by a Beginner. 



The devisor also suggests a 3-couple variant where couples 1,2 and 3 dance 6 hands across on bars 17-24 and 6 hands round and back on bars 25-32.



(Source: <<http://www.scottish-country-dancing-dictionary.com/dance-crib/step-forth.html|Scottish Country Dancing Dictionary>>)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17411, '2016-10-18 10:22:40.65036+00', '2016-10-20 15:46:37.355105+00', 'Mary MacNiven''s Sash Pin', 'MARY MACNIVENS SASH PIN', 1, 40, 9999, 1, 3, 42, 10912, NULL, 'Contains Sash Pin Reels.



Mary MacNiven was the singer for whom John Bannerman wrote the Gaelic song Mairi Bhàn (literally, Fair Mary, in English but usually known as Mairi''s Wedding after the translation by Sir Hugh Roberton); it is sung to the traditional tune, Lewis Bridal Song. This dance is so-named because it is a derivative of James B. Cosh''s dance, Mairi''s Wedding, on the fairly safe assumption that Mary would have worn a sash at her eventual wedding to John Campbell. 



(Source: <<http://www.scottish-country-dancing-dictionary.com/dance-crib/mary-macnivens-sash-pin.html|Scottish Country Dancing Dictionary>>)





Dance Notes by the deviser, Reuben Freemantle



This dance is intended to flow seamlessly from one figure to the next as far as possible so that, at the end of every phrase, the dancers are facing in the correct direction for the beginning of the next phrase. 



  1-2   2s step up; 



  9-40 All three couples are moving continuously in these sash pin reels, never stopping. As an aide-mémoire, each corner reaches and passes through his/her original corner position at the end of each 8-bar phrase, stopping only at the end of bar 40. 



  9-16 The sash pin reel with first corners is an 8-bar combination of a half reel of 4 on the first corners'' diagonal with a chase clockwise halfway around the corners'' square; 1s are followed by partner''s first corner, 2 bars behind; second corners dance in to the centre to meet and turn so that 1s and first corners can chase through second corners'' positions, unimpeded. Timing is of the essence: 2 bars for each quarter of the diagonal reel of 4 and for each side of the corners'' square in the chase; second corners have a quite sedate movement and so must be particularly careful not to get ahead of the music. The chase should follow the rectilinear shape of the corners'' square, with a sharp change of direction at the halfway corner, rather than a sloppy oval; this helps with timing as well being more satisfying to the dancers and any spectator. 



17-24 The sash pin reel with second corners is an 8-bar combination of a half reel of 4 on the second corners'' diagonal with a chase clockwise halfway around the corners'' square; first corners dance in to the centre to meet and turn so that 1s and second corners can chase through first corners'' positions, unimpeded. 



25-32 This sash pin reel is exactly as in bars 9-16 but starting with 1s facing partner''s first corners. 



33-40 This sash pin reel is as in bars 17-24 but starting with 1s facing partner''s second corners. Corners finish facing in, 1s cross by the right to finish in 2nd place on own sides, facing out (except on the final repeat when they pull right shoulders back to face in). 



    -40 On the 1st, 3rd, 5th and 7th repeats, 1s finish in 2nd place, facing out, ready to dance as 1st couple again. 

On the 2nd, 4th and 6th repeats, 1s also finish in 2nd place, facing out, ready to cast to 4th place of the full set in bars 1-2 of the next repeat WHILE the new 3s step up. 

On the last repeat, 1s finish in 2nd place of the active set (3rd place of the full set), facing in. 



________________________________________





Laurence''s alternative description of Mary MacNiven''s Sash Pin from the dancer''s perspective, starting from the first sash pin reel, bar 9. 



The dancing couple (1s) individually dance ¼ of a diagonal reel of 4 with their first corners, then chase clockwise 2 places and turn by the left ¼ in the centre of the dance to finish facing their second corners. 



The dancing couple then individually dance ¼ of a diagonal reel of 4 with their second corners, then chase clockwise 2 places and turn by the left ¼ in the centre of the dance to finish facing their third corners. 



The dancing couple then individually dance ¼ of a diagonal reel of 4 with their third corners, then chase clockwise 2 places and turn by the left ¼ in the centre of the dance to finish facing their fourth corners. 



The dancing couple then individually dance ¼ of a diagonal reel of 4 with their fourth corners, then chase clockwise 2 places and cross by the right to 2nd place on own sides to finish facing out ready for the repeat. 



WHILE 



The first corners perform a half diagonal reel of four on the first corners diagonal line then chase clockwise 2 places to finish in original places. 



The first corners then set to each other, then turn by the right to finish in original places. 



The first corners then perform a half diagonal reel of four on the first corners diagonal line then chase clockwise 2 places to finish in original places. 



The first corners then set to each other, then turn by the right to finish in original places. 



WHILE 



The second corners set to each other, then turn by the right to finish in original places. 



The second corners then perform a half diagonal reel of four on the second corners diagonal line then chase clockwise 2 places to finish in original places. 



The second corners then set to each other, then turn by the right to finish in original places. 



The second corners then perform a half diagonal reel of four on the second corners diagonal line then chase clockwise 2 places to finish in original places. 





', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17409, '2016-10-11 00:47:09.278023+00', '2022-08-15 08:41:18.665373+00', 'Court House Walk, The', 'COURT HOUSE WALK', 2, 32, NULL, 1, 3, 42, 11398, '2016-06-14', 'To celebrate the Marriage of Ron Wallace and Gary Thomas, in Santa Rosa, Califomia, on June 14th 2016.', 59, '880/822/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17538, '2017-01-05 10:52:42.377905+00', '2022-09-07 23:30:37.771083+00', 'Orchards of Co. Armagh, The', 'ORCHARDS OF CO ARMAGH', 3, 32, NULL, 2, 3, 18, 11440, NULL, 'The dance was inspired by the rows of orchards in Porta down.  



The recording on the CD for the book states "The Orchards of Armagh" (without "Co.").', 77, '868/844/808/884', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17534, '2017-01-05 10:29:43.866271+00', '2022-12-13 19:26:54.279009+00', 'City Hall Centenary', 'CITY HALL CENTENARY', 1, 32, NULL, 1, 4, 1, 575, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17412, '2016-10-18 11:11:54.174552+00', '2016-10-20 15:33:53.42099+00', 'John Campbell''s Kilt Pin', 'JOHN CAMPBELLS KILT PIN', 1, 40, 9999, 1, 3, 42, 10912, NULL, 'Contains Kilt Pin Reels.



Mary MacNiven was the singer for whom John Bannerman wrote the Gaelic song Mairi Bhan (literally, Fair Mary, in English but usually known as Mairi''s Wedding after the translation by Sir Hugh Roberton); it is sung to the traditional tune, Lewis Bridal Song. Many years later, she married John Campbell.



The kilt pin is a piece of jewellery that is worn on the lower corner of the outer apron of a kilt in order to prevent the apron falling or blowing open, by adding weight to the outer apron. It does not pin the outer apron to the inner fabric. 



(Source: <<http://www.scottish-country-dancing-dictionary.com/dance-crib/john-campbells-kilt-pin.html|Scottish Country Dancing Dictionary>>)





*Dance Notes by the deviser, Reuben Freemantle*



This dance is so-named because it is a close derivative of Mary MacNiven''s Sash Pin; enthusiasts (but only by agreement with the other dancers in the set!) may like to dance Mary MacNiven''s Sash Pin on the odd-numbered repeats and John Campbell''s Kilt Pin on the even. 



This dance is intended to flow seamlessly from one figure to the next as far as possible so that, at the end of every phrase, the dancers are facing in the correct direction for the beginning of the next phrase. 



  1-2   2s step up; 



  9-40 All three couples are moving continuously in these kilt pin reels, never stopping. As an aide-mémoire, each corner reaches and passes through his/her original corner position at the end of each 8-bar phrase, stopping only at the end of bar 40. 



  9-16 The kilt pin reel with second corners is an 8-bar combination of a half reverse reel of 4 on the second corners'' diagonal with a chase clockwise halfway around the corners'' square; 1s are followed by partner''s second corner, 2 bars behind; first corners dance in to the centre to meet and turn so that 1s and second corners can chase through first corners'' positions, unimpeded. Timing is of the essence: 2 bars for each quarter of the reverse diagonal reel of 4 and for each side of the corners'' square in the chase; first corners have a quite sedate movement and so must be particularly careful not to get ahead of the music. The chase should follow the rectilinear shape of the corners'' square, with a sharp change of direction at the halfway corner, rather than a sloppy oval; this helps with timing as well being more satisfying to the dancers and any spectator. 



17-24 The kilt pin reel with first corners is an 8-bar combination of a half reverse reel of 4 on the first corners'' diagonal with a chase clockwise halfway around the corners'' square; second corners dance in to the centre to meet and turn so that 1s and first corners can chase through first corners'' positions, unimpeded. 



25-32 This kilt pin reel is exactly as in bars 9-16 but starting with 1s facing partner''s second corners. 



33-40 This kilt pin reel is as in bars 17-24 but starting with 1s facing partner''s first corners. Corners finish facing in, 1s cross by the left to finish in 2nd place on own sides, facing out (except on the final repeat when they pull left shoulders back to face in). 



    -40 On the 1st, 3rd, 5th and 7th repeats, 1s finish in 2nd place, facing out, ready to dance as 1st couple again. 



On the 2nd, 4th and 6th repeats, 1s also finish in 2nd place, facing out, ready to cast to 4th place of the full set in bars 1-2 of the next repeat WHILE the new 3s step up. 



On the last repeat, 1s finish in 2nd place of the active set (3rd place of the full set), facing in. 



________________________________________



Dance Notes (2)



Laurence''s alternative description of John Campbell''s Kilt Pin from the dancer''s perspective, starting from the first kilt pin reel, bar 9. 



The dancing couple (1s) individually dance ¼ of a reverse (left shoulder) diagonal reel of 4 with their second corners, then chase anticlockwise 2 places and turn by the right ¼ in the centre of the dance to finish facing their first corners. 



The dancing couple then individually dance ¼ of a reverse diagonal reel of 4 with their first corners, then chase anticlockwise 2 places and turn by the right ¼ in the centre of the dance to finish facing their third corners. 



The dancing couple (1s) individually dance ¼ of a reverse diagonal reel of 4 with their third corners, then chase anticlockwise 2 places and turn by the right ¼ in the centre of the dance to finish facing their fourth corners. 



The dancing couple (1s) individually dance ¼ of a reverse diagonal reel of 4 with their fourth corners, then chase anticlockwise 2 places and cross by the left to 2nd place on own sides to finish facing out ready for the repeat. 



WHILE 



The second corners perform a half reverse diagonal reel of four on the second corners diagonal line then chase anticlockwise 2 places to finish in original places. 



The second corners then set to each other, then turn by the left to finish in original places. 



The second corners then perform a half reverse diagonal reel of four on the second corners diagonal line then chase anticlockwise 2 places to finish in original places. 



The second corners then set to each other, then turn by the left to finish in original places. 



WHILE 



The first corners set to each other, then turn by the left to finish in original places. 



The first corners then perform a half reverse diagonal reel of four on the first corners diagonal line then chase anticlockwise 2 places to finish in original places. 



The first corners then set to each other, then turn by the left to finish in original places. 



The first corners then perform a half reverse diagonal reel of four on the first corners diagonal line then chase anticlockwise 2 places to finish in original places. 



(Dance Notes by the deviser, Reuben Freemantle) 



', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17421, '2016-10-19 21:45:16.1596+00', '2016-10-20 10:25:05.749251+00', 'St Piran''s Cross', 'SAINT PIRANS CROSS', 1, 48, 9999, 2, 3, 17, 10912, NULL, 'Contains Kilt Pin Reels.



This dance is so-named because it is a close derivative of the dance St George''s Cross with the reverse form, Kilt Pin, rather than Sash Pin reels.

St Piran is the patron saint of Cornwall; his flag has a white cross on a coloured ground (black in this case), the reverse of St George''s coloured cross on a white ground.



The earliest known description of the flag as the Standard of Cornwall was written in 1838.

The flag is attributed to Saint Piran, a 6th century Cornish abbot. Saint Piran is supposed to have adopted these two colours from seeing the molten tin spilling out of the black ore in his fire during his supposed discovery of tin in Cornwall, thus becoming the patron saint of tin miners. 



(Source: <<http://www.scottish-country-dancing-dictionary.com/dance-crib/st-pirans-cross.html|Scottish Country Dancing Dictionary>>)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17544, '2017-01-20 02:16:19.158672+00', '2017-01-20 02:16:19.158672+00', 'Topsy Turvy', 'TOPSY TURVY', 2, 40, 9999, 1, 4, 11, 3462, '1990-01-01', 'After the first time trough, the couples end in the order 3,1,4,2 but on opposite sides.

Thus, top and bottom are swapped, and the couples dance as in order 2,4,1,3.

The dance is repeated four times, swapping top and bottom after every 40-bar phrase.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17488, '2016-12-27 00:49:45.100417+00', '2017-01-11 23:17:03.535141+00', 'Chronology', 'CHRONOLOGY', 2, 32, NULL, 1, 3, 42, 10934, NULL, 'Dedicated to Lara and Dan Friedman-Shedlov for their warm hospitality

', 53, '800/888/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17495, '2016-12-27 01:10:42.951627+00', '2017-01-10 00:19:00.177329+00', 'Yvonne''s Strathspey', 'YVONNES STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10934, NULL, 'This dance is dedicated to Yvonne Yang of Washington DC, and depicts her doing her hair, checking it in the mirror, re-doing it, and rushing off to just make the dance.', 50, '800/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17617, '2017-02-21 21:59:09.631729+00', '2017-02-21 23:23:35.06265+00', 'Glaikit Gowk (April Fool), The', 'GLAIKIT GOWK APRIL FOOL', 2, 32, NULL, 1, 4, 4, 11262, '2016-01-01', 'This is a dance for the Geneva Spring Dance on 1st April 2017.  You may start with a partner, but you won’t see him / her again soon.', 98, '7887/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17866, '2017-06-23 09:05:26.683384+00', '2017-06-23 09:05:26.683384+00', 'Deepwater Reel, The', 'DEEPWATER REEL', 3, 80, NULL, 4, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13662, '2011-03-21 23:00:00+00', '2018-05-16 01:03:09.636231+00', 'Rusty Nail, The', 'RUSTY NAIL', 1, 32, 9999, 1, 3, 42, 10318, '1997-01-01', 'This dance is dedicated to Ralph and Jean Seel who always made the Rusty Nails after any out of town dance. The dance can be done in strathspey time if the dancers feel they have had too many Rusty Nails!', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17458, '2016-10-31 20:50:07.885219+00', '2018-02-24 21:56:29.77655+00', 'Musician and the Pilot''s Wedding, The', 'MUSICIAN AND THE PILOTS WEDDING', 1, 32, NULL, 1, 4, 1, 11412, '2016-08-01', '', 53, '8888/8000/8440/8004', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5023, '1997-09-10 22:00:00+00', '2016-12-06 20:20:33.61417+00', 'Oban Reel, The', 'OBAN REEL', 1, 32, 9999, 1, 2, 76, 394, NULL, 'Suited for Reel as well as Strathspey time (stated explicitly in the description of the dance).', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18435, '2018-07-19 10:45:10.398381+00', '2018-07-19 10:45:10.398381+00', '“O” for Celebration', 'O FOR CELEBRATION', 2, 40, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18440, '2018-07-19 14:14:28.910698+00', '2018-07-19 14:14:28.910698+00', 'Clarence River Reel, The', 'CLARENCE RIVER REEL', 1, 40, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18442, '2018-07-19 14:16:08.539254+00', '2018-07-19 14:16:08.539254+00', 'Crocodile Tears', 'CROCODILE TEARS', 2, 32, NULL, 4, 119, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7389, '1997-04-05 22:00:00+00', '2017-02-27 17:53:03.288216+00', 'Elspeth Pyper of St John''s', 'ELSPETH PYPER OF ST JOHNS', 3, 32, 9999, 4, 4, 4, 436, '1996-01-01', 'Dedicated to Elspeth Pyper, who started the St John’s Scottish Country Dance Group in Toorak, Melbourne in 1966 (and taught there for 47 years).  The dance was devised for the St John’s Scottish Country Dance Group 30th Anniversary Ball held in 1996 at Fitzroy Town Hall.', 75, '8888/4444/4444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17553, '2017-01-20 04:12:53.591691+00', '2017-01-20 04:15:59.516015+00', 'Apres le bal', 'APRES LE BAL', 1, 40, 9999, 1, 3, 42, 2677, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17676, '2017-03-27 21:03:25.411231+00', '2017-04-01 08:51:36.271837+00', 'Flora''s Journey', 'FLORAS JOURNEY', 2, 40, NULL, 1, 4, 1, 10788, '2016-01-01', 'Dance devised for an intermediate technique class at Asilomar 2016. It contains all of the quick-time steps, and the transitions between most.

It is important that the music be played AABBB.', 85, '8888/8888/8440/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17552, '2017-01-20 04:06:53.122771+00', '2019-06-10 00:20:19.183961+00', 'Four in Hand', 'FOUR IN HAND', 1, 32, 9999, 4, 4, 15, 2677, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19013, '2018-10-19 14:51:27.540158+00', '2018-10-20 10:31:44.025916+00', 'Anna''s Reel', 'ANNAS REEL', 1, 32, NULL, 1, 4, 1, 11734, NULL, '', 72, '8888/8888/8440/8004', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18514, '2018-08-21 09:18:09.088735+00', '2018-10-21 00:31:02.885638+00', 'Walnut Pie, The', 'WALNUT PIE', 3, 32, NULL, 3, 5, 26, 11509, '2018-02-01', 'Another dance with rights and lefts on the diagonal, more difficult, but suitable if there are just five couples of dancers.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19097, '2018-12-06 22:42:50.081433+00', '2018-12-06 22:42:50.081433+00', 'Reel Challenge, A', 'REEL CHALLENGE', 1, 40, NULL, 4, 4, NULL, 3699, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17613, '2017-02-19 02:45:03.141007+00', '2019-10-15 12:04:55.766287+00', 'Crossing the Line Again', 'CROSSING THE LINE AGAIN', 1, 32, NULL, 2, 3, 30, 11181, '2017-02-19', 'Devised in February 2017 for Fanny Raoul of the Scots Bonnet Club as she said she enjoyed dancing the original Crossing The Line by John Drewry', 67, '800/880/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17575, '2017-01-31 21:43:02.507934+00', '2019-09-06 23:12:07.605603+00', 'Vrolijkheid', 'VROLIJKHEID', 3, 32, NULL, 1, 4, 1, 11219, '2013-09-01', 'Note: Vrolijkheid is both an Afrikaans and a Dutch word that means great merriment, cheerfulness or happiness.. It is also the name of a nature reserve just outside McGregor in the Breede River Valley. This dance echoes the jig ‘Joie de Vivre’ (Joy of living) and was devised to celebrate a dancing weekend in McGregor.', 83, '8444/8888/6888/0888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17413, '2016-10-19 20:58:46.593861+00', '2016-10-20 13:21:17.024442+00', 'Chaperons', 'CHAPERONS', 2, 32, 9999, 1, 4, 13, 10912, NULL, 'Dance Notes by the deviser, Reuben Freemantle



The dance is intended to flow seamlessly from one figure to the next as far as possible so that, at the end of every phrase, the dancers are facing in the correct direction for the beginning of the next phrase.



  1-8   Partners should be exactly the width of the set apart at all times and on the same level up and down. Covering must be visual since hands cannot be taken in parallel reels.



    -8   2M3M 2L3L should already have passed left shoulders.



17-24 In reverse reels of 4 (also known as left shoulder reels of 4), the dancers pass by the left at the ends. The same considerations apply over parallelism as in bars 1-8.



23-24 Instead of passing right shoulders, 3M2M 3L2L take both hands and turn halfway by the right on the sides into original places (a quick movement similar to that in bars 31-32 of Fifty Years On); 4L finish facing out, all others in.



25-26 1s stand for two bars and so 1M can encroach on the beginning of this phrase to finish facing in.



    -32 On the 1st, 2nd and 3rd repeats, all release hands on the left foot step, pulling right shoulder back, 4M 1L 2M 3L turning 1⁄8 on the spot, 4L 1M 2L 3M turning 5⁄8.



(Dance Notes end)



This dance is so-named because 2s and 3s (like chaperons) successfully thwart any attempted assignation of 1M with 1L or 4M with 4L for 24 bars. 1s and 4s cannot meet their partners since they are constrained to stay exactly the same distance apart during the parallel reels and the chaperons pass between them; the chaperons are ever present even during the hands across.

On bar 25, while the chaperons congratulate themselves on their success and take their eyes off their charges, 4th couple slip away and, on bar 27, 1st couple also take advantage of the opportunity to elude the chaperons.

On bar 31, the errant 1s and 4s return to the party as though nothing had happened. 



A chaperone (or occasionally chaperon) is an adult who accompanies or supervises one or more young, unmarried men or women during social occasions, usually with the specific intent of preventing inappropriate social interactions or other bad behavior. The chaperone is typically accountable to a third party, usually the parents of one of the accompanied young people. 



(Source: <<http://www.scottish-country-dancing-dictionary.com/dance-crib/chaperons.html|Scottish Country Dancing Dictionary>>)', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14480, '2012-06-15 05:03:46.350173+00', '2020-09-29 08:01:30.995818+00', 'King in the Ring', 'KING IN THE RING', 1, 40, NULL, 4, 4, 13, 3661, '2007-10-01', 'The "King" (or in his absence an empty chair) sits in the centre of the set; the others dance round him.



Written for György Lajtos (Gyuri) on becoming 40.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19081, '2018-12-06 12:31:33.215546+00', '2021-03-13 21:16:15.627033+00', 'Nethertown Nights', 'NETHERTOWN NIGHTS', 3, 32, NULL, 2, 3, 17, 11684, '2017-01-01', 'RSCDS Dunfermline Branch meets on Mondays evenings in the Dell Farquharson Community Centre, formerly known as the Nethertown Institute, Nethertown Broad Street, Dunfermline - hence the title of the dance.', 52, '880/844/888/802', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17694, '2017-04-01 19:50:31.142821+00', '2021-01-04 12:32:23.496965+00', 'Serpent of Loch Nell, The', 'SERPENT OF LOCH NELL', 3, 32, 9999, 1, 3, 42, 10961, '2015-01-01', 'The ‘snake’ in this dance was inspired by an ancient earth monument, the Loch Nell Serpent Mound, in Argyll, Scotland.

', 59, '880/822/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17509, '2016-12-31 16:05:01.430961+00', '2021-01-19 00:03:53.929648+00', 'Swarthmore Friends Meeting', 'SWARTHMORE FRIENDS MEETING', 1, 32, NULL, 1, 3, 42, 10934, NULL, 'As a final dance,  I''ve included this dance for all our friends far and wide.  The Swarthmore Friends Meeting House is where we hold our biennial ceilidh, and Swarthmore College is the site of many of our big events.  It''s a true gift to have so many friends to return to after our travels for yet another dance.', 50, '800/866/822/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6837, '1997-09-17 22:00:00+00', '2021-04-04 19:32:27.53952+00', 'Under The Trees', 'UNDER THE TREES', 2, 24, 9999, 1, 2, 76, 895, '1989-01-01', 'Suited for Jig as well as Reel time (stated explicitly in the description of the dance).', 57, '88/88/80', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9424, '2002-09-22 22:00:00+00', '2021-07-30 06:13:13.216508+00', 'After Supper', 'AFTER SUPPER', 1, 32, 9999, 1, 3, 42, 308, NULL, 'She was always taught no circles or setting after supper.', 44, '800/633/633/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3613, '1997-09-07 22:00:00+00', '2021-05-17 22:59:28.053509+00', 'Lady June Gordon', 'LADY JUNE GORDON', 2, 32, 9999, 1, 3, 42, 1051, '1988-07-01', 'The dance is dedicated to Lady June Gordon, marchioness of Aberdeen and Tremair.

Bill Moorhead presented the dance to Lady June Gordon at the Grandfather Mountain Highland Games in July 1988.

', 50, '800/888/888/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17393, '2016-10-01 13:09:41.881482+00', '2016-10-20 13:42:36.256118+00', 'Cooper''s Crown, The', 'COOPERS CROWN', 2, 40, 9999, 3, 5, 16, 10912, NULL, '10 bar phrases



The dance name is intended as reminder that it is made up of 10-bar phrases, just like The Wee Cooper o'' Fife. The crown was a coin valued at five shillings and so is an allusion to this as a five-couple dance. 



(Dance Notes by the deviser, Reuben Freemantle) 



The music for this dance must be in 10-bar phrases, as in The Wee Cooper o'' Fife and The Cooper''s Wife (Mitchell); the music for Trinity Tensome or any other, more conventional 5-couple, 5 x 40 bar dance would be totally unsuitable. Until a suitable recording is available, use a 4 x 40 bar set of The Wee Cooper o'' Fife and restart after once through.



As a dancer, since these are 10-bar phrases, do not panic on bar 7 of the phrase when finding oneself still far from the end position.



  1-8   3s 5s do not step up.



  9-10 Cover in the turns.



11-30 Take hands with partner at every opportunity in these mirror reels to help with covering.

These reels of five start with the dancers all evenly spaced; each dancer should follow the dancer immediately ahead and should be exactly two bars behind, throughout.



11-20 The following instructions apply to the Mn''s reel; since these are mirror reels, the Ls'' dance with left and right, clockwise and anticlockwise, interchanged. To start, 2M 4M, on the inside, face up and to the left, 1M, half a place above his original place on the side line, and 3M 5M, on the outside, face down and to the left.



11-12 1M2M 3M4M pass giving right shoulder WHILE 5M dance round the anticlockwise loop at the bottom, finishing 1M in 3M''s position at the start of bar 11, 3M in 5M''s, 5M in 4M''s, 4M in 2M''s, 2M in 1M''s.



13-20 All repeat bars 11-12 four times from their new positions, finishing as at the start of bar 11.



21-30 All repeat bars 11-20 with 1s crossing down to opposite sides to start.



31-32 Slow turns with covering.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17467, '2016-11-06 17:18:14.910337+00', '2018-03-27 00:38:13.966442+00', 'Fentham Jig, The', 'FENTHAM JIG', 2, 32, NULL, 1, 3, 42, 3694, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17473, '2016-11-06 17:31:48.533707+00', '2018-04-02 23:56:33.531327+00', 'Colin''s Delight', 'COLINS DELIGHT', 2, 32, NULL, 1, 3, 42, 1275, NULL, 'For Colin who particularly enjoys jigs.', 59, '822/866/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17464, '2016-11-05 13:19:51.616084+00', '2019-08-29 15:29:47.339704+00', 'Sarehole Mill', 'SAREHOLE MILL', 2, 32, NULL, 1, 3, 42, 1275, NULL, '', 48, '822/802/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17465, '2016-11-06 17:07:47.766609+00', '2017-12-05 16:38:13.226488+00', 'Portincaple', 'PORTINCAPLE', 1, 32, NULL, 1, 3, 42, 11414, NULL, '', 56, '800/844/888/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17479, '2016-11-07 09:08:21.438657+00', '2018-07-13 06:39:28.429128+00', 'Ardochart House', 'ARDOCHART HOUSE', 3, 32, NULL, 2, 3, 17, 11181, '2016-11-01', '"Ardochart" is the name of the house of my scottish friends, Margaret and Dave Phillips, to whom this dance is dedicated.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18441, '2018-07-19 14:15:04.162734+00', '2018-07-19 14:15:04.162734+00', 'Convivial Cameron, The', 'CONVIVIAL CAMERON', 1, 32, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18443, '2018-07-19 14:16:46.920241+00', '2018-07-19 14:16:46.920241+00', 'Crossing the North Atlantic', 'CROSSING THE NORTH ATLANTIC', 1, 40, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18436, '2018-07-19 10:45:36.581002+00', '2018-09-19 09:49:16.436228+00', 'Robyn Craig''s Country Dance', 'ROBYN CRAIGS COUNTRY DANCE', 3, 40, NULL, 4, NULL, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17680, '2017-03-31 09:10:57.541353+00', '2019-01-16 23:59:33.62014+00', 'Jig for Mr Taylor', 'JIG FOR MR TAYLOR', 2, 32, 9999, 1, 4, 13, 10397, NULL, 'David Taylor is the teacher of the Gay Gordons (Manchester).', 63, '4444 8224 8008 8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10433, '2002-04-04 22:00:00+00', '2016-11-08 11:03:24.554049+00', 'Dream Catcher, The', 'DREAM CATCHER', 3, 96, 9999, 4, 4, 3, 3083, NULL, '##>>

In native American culture, a dreamcatcher, or dream catcher, is a handmade object based on a hoop, on which is woven a loose net or web. The dreamcatcher is then decorated with items such as feathers and beads. It is hung above the bed as a charm to protect sleeping children from nightmares.

##<<', 77, '8888  8080  8888  8282    8888  4444  4444  8888    0808  8888  2828  8888', 1, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (17039, '2016-06-11 22:31:26.010773+00', '2017-02-24 23:44:43.512248+00', 'Weaving the Tartan', 'WEAVING THE TARTAN', 2, 32, NULL, 1, 4, 1, 9998, NULL, '6th of the 7 New Dances for Beginners', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17415, '2016-10-19 21:05:48.54449+00', '2016-10-20 14:53:22.682468+00', 'Dark Island, The', 'DARK ISLAND', 4, 32, 3, 2, 3, 17, 10912, NULL, '*Dance Notes by the deviser, Reuben Freemantle*



Note that the Strathspey and Reel parts of a Medley with this format can be performed independently. 



This dance is intended to flow seamlessly from one figure to the next as far as possible so that, at the end of every phrase, the dancers are facing in the correct direction for the beginning of the next phrase. 



  3-14 With this starting point of the reel of six, all start and finish on own sides of the centre line, right shoulder to right shoulder, Mn facing up, Ls down. 



  3-4   1M, at the top, 3L, at the bottom, dance clockwise loops to finish in the positions vacated by their partners at bar 3 WHILE 1L2M 2L3M pass giving left shoulder to finish 2M 3M on the Mn''s side facing up, 1L 2L on the Ls'' side facing down, 2M1M 3M1L 3L2L right shoulder to right shoulder; 



all have now progressed one position clockwise around the set, finishing 2M3M3L on the Mn''s side of the centre line, 1M1L2L on the Ls''. 



  5-6   All repeat bars 3-4 from the new positions, finishing 3M3L2L on the Mn''s side of the centre line, 2M1M1L on the Ls''. 



  7-8   All repeat bars 3-4 from the new positions, finishing 3L2L1L on the Mn''s side of the centre line, 3M2M1M on the Ls'' (note that this is the halfway point in the reel of six). 



  9-14 All repeat bars 3-8 from the new positions, finishing 1s 2s 3s as at bar 3. 



15-16 In the reel, the turn with both hands is with skip change, not pas-de-basque. 



17-     In the strathspey, 1M 2L change foot to start the highland schottische poussette. 





23-     In the strathspey, 1L 2M change foot to start; 2s1s cover when turning with both hands. 



24-24 In the strathspey, 1s3s cover when turning with both hands. 



25-     In the strathspey, 3M 1L change foot to start the highland schottische poussette. 



31-32 In the strathspey, 1L 3M change foot to start; 3s1s cover when turning with both hands three quarters. 



(end of notes)



The Dark Island (An t-Eilean Dorcha) is the name used in Gaelic poetry for Benbecula (Beinn na Faoghla), the island in the Outer Hebrides (Na h-Eileanan Siar) which is joined by causeways to North Uist (Uibhist a'' Tuath) and South Uist (Uibhist a'' Deas).



These three islands are nowadays linked by another causeway to Eriskay (Eiriosgaigh) and then via a small vehicle ferry to Barra (Barraidh). The dance is so-named because the main road in these five islands is shaped like a reel of six with a loop at either end (North Uist and Barra), joined by a spine road through Benbecula, South Uist and Eriskay and the Barra ferry. Many parts of the road are single track with passing places, again reminiscent of the middle part of the reel.



The Dark Island is also the name of a Gaelic waltz (and a slow air) by the late Iain McLachlan, the great button-box player from Benbecula. In the early 1990s, shortly before his untimely death, he played at weekends in the bar of the, sadly now defunct, Clachan Beag Hotel in Castlebay (Bagh a'' Chaisteil). The deviser and his wife have fond memories of dancing to Iain''s music there on a "postage stamp" floor: The Canadian Barn Dance, The Schottische (also remembered in the strathspey part of this dance) and, of course, Iain''s own, renowned Gaelic waltz. 



(Source: <<http://www.scottish-country-dancing-dictionary.com/dance-crib/dark-island.html|Scottish Country Dancing Dictionary>>)', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17283, '2016-09-06 23:32:37.1966+00', '2016-10-25 03:12:31.453771+00', 'Wake the Piper', 'WAKE THE PIPER', 2, 32, 9999, 1, 3, 42, 51, '1994-10-01', 'The dance is dedicated to all the wake-up pipers at Scottish country dance weeks and weekends, but especially to piper Dan Emery when he plays at Pinewoods Camp as the sun''s rays break through the morning mist.



Originally devised in October 1994, there were revisions to the description in August 1996, August 1997 and April 2002.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17426, '2016-10-24 03:10:00.314307+00', '2016-10-24 03:10:00.314307+00', 'Fergusson Reels, The', 'FERGUSSON REELS', 4, 128, 10038, 4, 4, 3, 3, NULL, 'A demonstration dance, 4 x 32.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18444, '2018-07-19 14:17:22.501659+00', '2018-07-19 14:17:22.501659+00', 'Errington Strathspey, The', 'ERRINGTON STRATHSPEY', 3, 48, NULL, 4, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17483, '2016-11-30 03:00:58.261079+00', '2017-04-24 13:59:12.167517+00', 'Vivre A Saint Quay', 'VIVRE A SAINT QUAY', 3, 32, NULL, 2, 3, 17, 11181, '2016-11-26', '', 83, '880/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17471, '2016-11-06 17:25:51.492942+00', '2020-03-09 15:32:53.12238+00', 'Lunar Society Reel, The', 'LUNAR SOCIETY REEL', 1, 32, NULL, 1, 3, 42, 1275, NULL, '', 63, '484/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17463, '2016-11-05 00:19:56.665229+00', '2020-10-15 17:52:48.473017+00', 'Mr. Graham W. Donald', 'MR GRAHAM W DONALD', 3, 32, NULL, 2, 3, 18, 10907, NULL, '', 75, '880/844/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17234, '2016-09-03 22:06:25.635826+00', '2020-10-24 10:09:29.692116+00', 'Pentland Hills, The', 'PENTLAND HILLS', 3, 32, NULL, 1, 3, 42, 11035, NULL, '', 56, '880/888/844/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17466, '2016-11-06 17:16:05.603543+00', '2020-10-28 22:56:22.386955+00', 'Platinum Orb, The', 'PLATINUM ORB', 3, 32, NULL, 4, 4, 1, 1275, NULL, '', 100, '8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17475, '2016-11-06 17:41:13.302509+00', '2020-10-31 11:52:54.406366+00', 'Mell Square', 'MELL SQUARE', 3, 32, NULL, 4, 4, 14, 3694, NULL, '', 88, '8484/4848/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17476, '2016-11-06 17:43:02.851382+00', '2020-10-31 11:56:01.18533+00', 'Spaghetti Junction', 'SPAGHETTI JUNCTION', 2, 32, NULL, 1, 3, 42, 1275, NULL, '', 58, '888/888/860/804', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17477, '2016-11-06 17:45:10.045612+00', '2020-10-31 12:03:06.146886+00', 'Forward to Frankfurt', 'FORWARD TO FRANKFURT', 1, 40, NULL, 1, 3, 42, 1275, NULL, '', 65, '844/888/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12971, '2006-10-25 22:00:00+00', '2021-03-03 22:58:30.821571+00', 'Welcome in Tokyo, A', 'WELCOME IN TOKYO', 1, 32, 9999, 1, 3, 42, 3718, NULL, 'Although a 3-couple dance, 4th couple dance bars 1-2 on first time through. A progression in advance.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17316, '2016-09-09 10:41:49.047852+00', '2021-11-25 07:41:20.310501+00', 'Pretty Bride of Préty, The', 'PRETTY BRIDE OF PRETY', 1, 32, NULL, 1, 3, 42, 11350, NULL, 'For Aliénor Latour on the occasion of her wedding in Préty, Bourgogne, on December 13th, 2014.  

The first eight bars represent the bride and groom meeting and solemnly walking up the aisle. 

Music composed by Pascaline Latour, bridesmaid on that occasion.', 56, '800/880/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18448, '2018-07-19 14:19:32.723959+00', '2018-07-19 14:19:32.723959+00', 'Maid of Ulster, The', 'MAID OF ULSTER', 1, 40, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17480, '2016-11-08 15:43:48.350493+00', '2016-11-08 15:45:14.068484+00', 'Five-Seven-Two', 'FIVESEVENTWO', 2, 32, NULL, 1, 3, 42, 48, NULL, 'Source: Crib on "The Sunday Class" website.  The crib adds



Five-seven-two.co.uk was a site dedicated to producing easy to follow tutorials for Adobe Illustrator and providing Vector Freebies, produced by Jonathan Stones, a Freelance Designer focusing on Web Design and Printed Media. 



None of this has anything to do with this dance or its deviser, Jenny Bradley! Jenny has published at least 55 dances, though not this one unless it is under another name, so there is no clue to the significance of the name



No publication known.



', 37, '800/808/800/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16406, '2015-05-30 17:19:33.471518+00', '2017-01-04 17:03:30.881765+00', 'Valentine Special', 'VALENTINE SPECIAL', 3, 32, 9999, 2, 3, 17, 2018, '2011-01-01', 'The description given in http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf, which is probably a reproduction of the original text, has several errors.  The Reel of 4 on the midline is danced by 1c+3c (not 1c+2c), and on [18-24] 1c+2c+3c dance a full (not half) circle to the Left. ', 59, '848/808/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17582, '2017-02-14 01:13:31.749195+00', '2017-02-14 01:31:05.631584+00', 'Cocoa Beach Marathon', 'COCOA BEACH MARATHON', 2, 32, NULL, 1, 100, 2, 10568, '2016-03-01', 'Celebrating the Space Coast weekend in Cocoa Beach, Florida', 87, '8448/4884/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17432, '2016-10-30 11:37:21.888903+00', '2018-03-20 10:27:50.409024+00', 'Auchengar', 'AUCHENGAR', 2, 32, NULL, 1, 3, 42, 433, NULL, 'Devised by W. Little, Castle Douglas, to mark the retirement of Rosemary B Smith, Auchengar, Wigtown after over fifty years of enthusiastic teaching of Scottish country dancing to children and adults in various parts of the Machars of Wigtownshire.', -52, '555/555/848/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (220, '1997-11-20 23:00:00+00', '2016-10-29 02:13:27.325808+00', 'Argyll Reel', 'ARGYLL REEL', 1, 32, 9999, 1, 2, 76, 9998, NULL, 'The description used for this entry was old, the description and diagrams did not fully agree. The crib is provisional only. 



The deviser is not mentioned on the description. There is an uncertain attribution of this dance to Derek Haynes; we are looking for reliable information on this





', 56, '84/88/80/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18336, '2018-05-16 17:40:11.362599+00', '2018-05-16 17:40:11.362599+00', 'Jig for Gina, A', 'JIG FOR GINA', 2, 32, NULL, 1, 4, 82, 2084, NULL, '', 50, '8000/8440/4804/4848', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (546, '2002-04-19 22:00:00+00', '2016-10-26 00:36:42.912471+00', 'Black Isle', 'BLACK ISLE', 3, 32, 9999, 1, 3, 42, 9998, NULL, 'The description used for this entry was old, the description and diagrams did not fully agree.  The crib is provisional only.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2048, '1998-04-21 22:00:00+00', '2016-10-28 22:29:27.96515+00', 'Fairy Ring, The', 'FAIRY RING', 2, 32, 9999, 7, 1, 4, 44, NULL, 'From the original book: Iain Boyd has this either as a 40 or 32 bar dance. The former will apply to Children who find the 2 bar per hand grand chain tricky. He has then clap twice on first bar, and beat Rf twice on second bar.



Recommended music 32 bar sequence The Wild Geese, and The Fyket for a 40 bar one.



', 75, '88/80/08/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17433, '2016-10-30 11:38:40.087595+00', '2018-04-02 23:56:33.151035+00', 'Bracken Wood', 'BRACKEN WOOD', 3, 32, NULL, 1, 3, 42, 433, '2015-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18449, '2018-07-19 14:20:13.975316+00', '2018-07-19 14:20:13.975316+00', 'Nova Scotian Jig, The', 'NOVA SCOTIAN JIG', 2, 32, NULL, 1, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17438, '2016-10-30 11:47:32.835315+00', '2018-08-26 07:30:08.903396+00', 'Our Friend Viv', 'OUR FRIEND VIV', 1, 32, NULL, 1, 4, 1, 433, NULL, 'For Viv Vedat, a much loved teacher, dancer, musician and friend of the Gatehouse Branch on her move to Wigtownshire.', 67, '8444/8444/8222/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17437, '2016-10-30 11:46:21.055145+00', '2018-08-23 21:11:09.121764+00', 'Jessie Cannon''s Strathspey', 'JESSIE CANNONS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 433, NULL, 'In memory of Jessie Cannon, Gatehouse. A devoted Scottish country dancer and a kind loving friend to all.', 79, ' 844/880/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17436, '2016-10-30 11:45:02.691968+00', '2018-08-24 06:43:40.252927+00', 'Isabel Paterson''s Jig', 'ISABEL PATERSONS JIG', 2, 32, NULL, 1, 3, 42, 433, NULL, 'In memory of Isabel Paterson, Newton Stewart. Music composed by her husband, Alan, who now plays accordion for the Gatehouse Scottish Country Dance Class. ', 50, '844/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17440, '2016-10-30 11:51:10.894953+00', '2018-04-03 00:07:38.446982+00', 'Cilla''s Jig', 'CILLAS JIG', 2, 32, NULL, 1, 3, 42, 433, '2016-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12982, '2006-10-25 22:00:00+00', '2018-04-03 00:08:25.642112+00', 'Who''s Leading Who', 'WHOS LEADING WHO', 1, 40, 9999, 1, 3, 42, 3718, '2006-01-01', 'Progression results in 1M in 2L''s place and 1L in 2M'' s. Balances out after 2nd time through.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18324, '2018-05-02 18:22:10.229579+00', '2018-05-17 02:42:37.052432+00', 'Remembrance For Russell, A', 'REMEMBRANCE FOR RUSSELL', 1, 32, NULL, 1, 3, 42, 11139, '2010-04-01', 'For Beverley.  



Written in memory of Russell Young, a well-known Auckland dancer for many years, who passed away on 29 April 2009.', 63, '888/888/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17026, '2016-06-11 21:10:08.828899+00', '2020-10-18 10:15:12.511942+00', 'Reeling to Kirriemuir', 'REELING TO KIRRIEMUIR', 1, 32, NULL, 5, 4, 30, 9998, NULL, 'RR Dance of facing lines of two couples, the M in the middle.  Each line progresses to meet next line RR.  



Kirremmuir is the gateway to the Angus glens', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4136, '1998-11-25 23:00:00+00', '2021-05-09 23:36:21.670381+00', 'Many Happy Returns', 'MANY HAPPY RETURNS', 3, 32, 9999, 1, 3, 42, 51, '1988-06-03', 'The dance was devised to celebrate the departure of dancer and teacher Martin Mulligan from the Chicago Branch to begin a new phase of his career in Newfoundland; it was first taught and danced at the Chicago Branch Weekend June 3-5, 1988.', 41, '880/840/844/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17443, '2016-10-30 11:56:18.482685+00', '2020-10-28 09:55:02.114676+00', 'Light of Hope', 'LIGHT OF HOPE', 3, 32, NULL, 1, 4, 1, 433, '2011-01-01', '', 83, '8888/8080/8888/8666', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17444, '2016-10-30 11:57:34.865272+00', '2020-10-28 22:44:00.939412+00', 'Miss Alison Veitch', 'MISS ALISON VEITCH', 3, 32, NULL, 1, 3, 42, 433, NULL, '', 59, '844/888/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17445, '2016-10-30 11:59:16.169229+00', '2020-10-28 22:47:02.42003+00', 'Raiders Road, The', 'RAIDERS ROAD', 2, 32, NULL, 1, 4, 1, 433, '2014-01-01', '', 69, '8000/8888/4444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1914, '2002-11-03 23:00:00+00', '2023-02-09 12:35:49.809862+00', 'Laird of the Dance, The', 'LAIRD OF THE DANCE', 1, 32, 9999, 1, 3, 42, 2450, '1998-07-01', 'This dance is dedicated to Bob Blackie. The title comes from the description of Bob in the "Globe and Mail" from Toronto, Friday, July 10, 1998. Bob died May 25, 1998, age 62.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8488, '1997-12-28 23:00:00+00', '2021-03-19 10:42:17.617408+00', 'Wandering Dancer (Strathspey version), The', 'WANDERING DANCER STRATHSPEY VERSION', 3, 32, 9999, 1, 3, 42, 872, NULL, '', 47, '880/822/822/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8410, '1997-12-28 23:00:00+00', '2018-04-03 00:08:24.032719+00', 'Waggle of the Kilt, The', 'WAGGLE OF THE KILT', 2, 40, 9999, 1, 3, 42, 35, NULL, 'The dress of the Scots with the shoulder plaid and kilt has undergone fewer changes through the centuries than any other. The details of the complete equipment of a Highland Chief in 1797 differs very little from to-day, except in the quality of the wooL The kilt was made of the finest native wool. The sheep of that time are now extinct. There being no hem on the kilt, the hard tartans, made by machinery after the Disarmament were so raspy that the edge, or selvedge, chafed the men''s legs. When Queen Victoria inspected one of her regiments, she noticed the sores and bleeding at the backs of the soldiers'' legs. She immediately notified the War Office, and since then the tartans have been softer. The Suggested Music is played to the tune of ''The Waggle of the Kilt." The fourth tune is: ''That''s the Reason Noo I wear the Kilt." This dance gives all kilt wearers license and opportunity to make good use of the "waggle" as they try out the following formations.', 49, '820/800/822/888/888', 0, 1, 1, 1, 61);
INSERT INTO 'dance' VALUES (17452, '2016-10-30 12:16:43.280065+00', '2018-12-03 02:35:34.654003+00', '75th Anniversary Reel', '75TH ANNIVERSARY REEL', 1, 40, NULL, 4, 4, 4, 433, '1998-03-01', '', 70, '4444/4444/8888/4444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17434, '2016-10-30 11:41:04.409917+00', '2018-12-02 01:26:43.338038+00', 'Galloway Lads and Lassies', 'GALLOWAY LADS AND LASSIES', 1, 32, NULL, 1, 4, 1, 433, '2011-01-01', 'Specially for the Wigtownshire Primary Schools’, Days of Dance Competition.', 56, '8008/0880/8888/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18623, '2018-09-17 18:48:49.572502+00', '2018-09-17 22:26:22.122215+00', 'All Left Moira', 'ALL LEFT MOIRA', 3, 32, NULL, 2, 3, 17, 11270, NULL, 'This is the left-hand-only version of All Right Bob. It was named for Moira at the time of a right arm injury.', 63, '800/846/864/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18515, '2018-08-21 09:22:59.436907+00', '2018-09-09 05:34:19.467053+00', 'Walnut Cake with Chocolate Spread', 'WALNUT CAKE WITH CHOCOLATE SPREAD', 2, 32, NULL, 1, 3, 42, 11509, '2018-04-01', 'Walnut cake is very good just by itself, but it can taste even better covered with chocolate spread! It is actually one of my favourites.', 69, '880/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17450, '2016-10-30 12:12:56.564137+00', '2018-12-03 14:19:27.086132+00', '90th Birthday', '90TH BIRTHDAY', 2, 32, NULL, 1, 3, 42, 433, '2013-01-01', 'Dedicated to Wigtownshire Primary Schools on his 90th birthday in 2013.', 50, '800/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17448, '2016-10-30 12:09:33.979183+00', '2018-12-04 23:22:57.125723+00', 'Threave Strathspey', 'THREAVE STRATHSPEY', 3, 32, NULL, 1, 4, 1, 433, '2013-01-01', 'In memory of his wife Hope.', 78, '8888/8888/6222/6666', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17447, '2016-10-30 12:08:03.909307+00', '2018-12-04 23:39:42.422846+00', 'Welcome Home', 'WELCOME HOME', 2, 32, NULL, 5, 2, 76, 433, '2010-10-01', 'In honour of Margaret Philip, talented and devoted pianist over many years, for the Scottish Country Dancing in Gatehouse of Fleet.', 100, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18325, '2018-05-02 18:22:53.882227+00', '2018-05-17 02:11:05.266644+00', 'Ruby Wilkinson''s Rant', 'RUBY WILKINSONS RANT', 2, 32, NULL, 1, 3, 42, 11139, '2013-09-30', 'This dance was written during the 2013 Australian Winter School, held in Albany, Western Australia.  

The dance was devised for Ruby Wilkinson, one of the teachers at the school, who is currently the RSCDS Schools Director. The creation of the dance was inspired by Ruby’s teaching of the La Baratte movement during the first class of the school.', 63, '888/880/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12276, '2005-04-24 22:00:00+00', '2016-11-15 19:47:31.955101+00', 'Hutchison House', 'HUTCHISON HOUSE', 3, 32, 9999, 1, 2, 76, 3538, '1998-10-01', 'Hutchison House was built for Dr John Hutchison, the first doctor to practise in Peterborough.  The house is now a museum and it has been a strong supporter of Scottish heritage in the area.', 60, '84/88/88/48', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18450, '2018-07-19 14:20:43.219647+00', '2018-07-19 14:20:43.219647+00', 'Vital Spark, The', 'VITAL SPARK', 3, 32, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6922, '1997-04-03 22:00:00+00', '2020-01-01 20:34:38.439084+00', 'Wark O'' The Weavers, The', 'WARK O THE WEAVERS', 3, 32, 9999, 1, 3, 42, 13, NULL, '', 53, '844/888/822/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17435, '2016-10-30 11:42:48.555314+00', '2020-10-28 08:28:09.099347+00', 'Greyfriar''s Strathspey', 'GREYFRIARS STRATHSPEY', 3, 32, NULL, 1, 4, 1, 433, '2010-10-01', '', 84, '8888/8888/6222/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17442, '2016-10-30 11:54:32.798886+00', '2020-10-28 08:43:22.700092+00', 'My Friend Jim', 'MY FRIEND JIM', 2, 32, NULL, 1, 4, 1, 433, '2012-10-01', '', 62, '8888/8888/8000/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18445, '2018-07-19 14:18:00.251982+00', '2020-11-15 12:22:25.336789+00', 'Gold Coast Ruby, The', 'GOLD COAST RUBY', 3, 32, NULL, 1, 100, 11, 10907, NULL, '', 88, '8888/8888/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17439, '2016-10-30 11:49:07.885215+00', '2021-01-01 20:25:46.864726+00', 'Kind Robin', 'KIND ROBIN', 3, 32, NULL, 1, 3, 42, 433, '2014-11-01', 'For Robin Allan who attended dance classes at Gatehouse of Fleet and Castle Douglas during his stay at The National Trust of Scotland School of Gardening at Threave.', 50, '888/800/888/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10822, '2002-09-22 22:00:00+00', '2021-07-30 08:28:42.144124+00', 'Ian and Joan McKenzie''s Strathspey', 'IAN AND JOAN MACKENZIES STRATHSPEY', 3, 40, 9999, 2, 3, 17, 308, '2002-01-01', '', 60, '484/484/888/484/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17485, '2016-12-15 00:17:13.409893+00', '2016-12-16 00:31:52.497372+00', 'Straighten Your Lines', 'STRAIGHTEN YOUR LINES', 3, 32, NULL, 1, 4, 2, 11062, '2016-07-23', 'Deviser''s note:  "Straighten your Lines" was written in July 2016 for Angelika Schmidkonz as a farewell present when she left Munich for Bochum after more than 13 years of very active membership. Angelika had been a committee member for many years, organised many dance events, danced in the Munich Scottish Association''s demonstration team and was one of the MSA''s dance teachers. She was particularly keen on having perfectly straight lines in the sets and never omitted to remind the class of this.



', 87, '8448/8448/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17699, '2017-04-02 08:40:35.852016+00', '2021-01-11 11:55:06.138203+00', 'Five Crossings from Mallaig', 'FIVE CROSSINGS FROM MALLAIG', 2, 32, NULL, 3, 5, 44, 10961, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17619, '2017-02-24 17:10:17.094777+00', '2023-02-03 09:35:50.968876+00', 'Strathspey for Bar, A', 'STRATHSPEY FOR BAR', 3, 128, NULL, 4, 4, 3, 3580, '2013-06-01', 'The dance comprises four parts of 32 bars; each has first the 16-bar Cloverleaf formation, then one of several 8 bar figures, and finally 8 unchanging bars.  The women progress anticlockwise to a new partner each time, and finish with their original partner.



Dance devised by Brian Pierson at the request of the Chiswick Scottish Country Dance Club in June 2013 for <<ddp:Martlew, Bar#11165|Barbara Martlew>> (Bar) of Hemel Hempstead.  Born in Dunedin, New Zealand, Bar was President of the Berkhamsted Strathspey & Reel Club, an RSCDS-qualified teacher at the London Branch, and the Watford, Gerrards Cross, and Chiswick clubs, and an MC whose expertise earned her the role of MC at an RSCDS AGM Ball.

', 87, '8888/8888/4444/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17504, '2016-12-31 14:30:31.342434+00', '2016-12-31 14:30:31.342434+00', 'Movin'' Out', 'MOVIN OUT', 1, 32, NULL, 3, 5, 7, 10934, NULL, 'This dance was written while moving into my new apartment on Spruce Street,wanting anything to distract me from the packing. It is included here with special credit to Matt Sharp and Chloe and Clare Maher for making every thing happen. It Is written for 5 couples, because more hands make lighter work.', -1, '', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (18452, '2018-07-19 14:21:49.347197+00', '2018-07-19 14:21:49.347197+00', 'Will You Join the Dance?', 'WILL YOU JOIN THE DANCE', 1, 32, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11796, '2004-09-08 22:00:00+00', '2017-02-25 22:03:09.974135+00', 'Volcanicity', 'VOLCANICITY', 1, 32, 9999, 1, 4, 2, 108, '2003-05-01', 'In the original description, Drewry states: Strathspey and/or Reel.  As SCDDB has no place for a double classification the dance is classified here as a Reel, but both Reel and Strathspey steps are listed.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17028, '2016-06-11 21:57:06.164052+00', '2017-02-24 23:18:24.066759+00', 'Tumbling Waters Of Unich, The', 'TUMBLING WATERS OF UNICH', 2, 32, NULL, 1, 4, 1, 2913, NULL, 'Note: The Unich Burn starts on the watershed between Glen Clova & Glen Lee, goes through the Falls of Danff & tumbles down about one thousand feet in about a mile & a half through the Gully of Unich, to the falls of Unich. Then it joins the River Lee, which flows into Loch Lee. Then the Lee & the River Mark join to form the River North Esk (which flows down Glen Esk, and onto the sea not far from St Cyrus.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17031, '2016-06-11 22:10:16.439119+00', '2017-02-24 23:23:24.179222+00', 'Tenth Anniversary Strathspey (Aberlemno), The', 'TENTH ANNIVERSARY STRATHSPEY ABERLEMNO', 3, 40, NULL, 4, 4, NULL, 2913, '2006-03-22', 'Devised 22nd March 2006. For the 10th anniversary (1996 to 2006) of dance classes at Aberlemno (site of the famous carved Pictish Stones).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17034, '2016-06-11 22:17:40.265945+00', '2017-02-24 23:34:55.08559+00', 'Mount Keen', 'MOUNT KEEN', 3, 48, NULL, 1, 102, 28, 2913, '2004-04-11', 'Twice through only.



Mount Keen, 3,135 ft is our local Munro (Munros are mountains over 3000 ft in Scotland, all climbed and described by a member of the Munro Clan)



Note: Please check if this tune is the same as "Highland Lassie" by Jim Johnstone.  If so, those entries must be merged.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18456, '2018-07-19 16:01:25.777104+00', '2018-07-19 16:01:25.777104+00', 'Jocular Magpies', 'JOCULAR MAGPIES', 1, 32, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17512, '2017-01-04 17:28:34.005885+00', '2019-06-28 08:58:01.937258+00', 'Celtic Gathering', 'CELTIC GATHERING', 4, 112, 10039, 107, 119, NULL, 11110, '2002-01-01', 'Devised as a demonstration dance and was first performed at a Celtic Evening on 2nd February 2002.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16255, '2015-05-01 23:06:59.733336+00', '2017-02-26 22:03:34.880079+00', 'Spring Fling Reel, The', 'SPRING FLING REEL', 1, 40, NULL, 1, 3, 42, 11126, '2015-04-01', 'Spring Fling 2015 was held over the weekend of April 17th to the 19th in Hounslow, London.



On the last day of Spring Fling a dance competition was held to choose a dance for the upcoming Book 50. In total, 46 dances from around the world were submitted and trialled, with 7 finalists chosen to be voted on by Spring Fling attendees.



The winning dance, shown here, was the culmination of many hours of devising, dancing and deliberation. It was danced by Spring Fling attendees who, after a long weekend of dancing, with a lot of energy spent (and sleep lost), were up for one more dance! ', 55, '800/888/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17560, '2017-01-22 21:20:51.997927+00', '2017-01-22 21:20:51.997927+00', 'Leaning Tower, The', 'LEANING TOWER', 3, 32, NULL, 2, 3, NULL, 1110, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17561, '2017-01-22 21:22:37.215322+00', '2017-01-22 21:22:37.215322+00', 'Mr. Joseph LaFace', 'MR JOSEPH LAFACE', 2, 32, NULL, 2, 3, NULL, 1013, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18337, '2018-05-20 13:51:01.297381+00', '2018-05-22 01:06:30.163882+00', 'Nordfjordeid', 'NORDFJORDEID', 2, 32, 9999, 1, 2, 76, 2682, '2017-07-07', 'Notes from The Johnsonville Collection:



Devised 7/7/2017 as a simple ceilidh style dance for our Viking themed social on 8/7/2017, with many partners coming to the social.



Nordfjordeid is a town on one of the northerly fjords in Norway (Nordfjord), and is the birthplace of Sophus Lee. I spend a week there at a conference in the Sophus Lee Center. It is surrounded by quite high glacial hills fully equipped with lovely walks and waterfalls. It is the only place I have been where, for the week I was there, the sun did not set (yet the temperature did not exceed 7 degrees C, either).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18451, '2018-07-19 14:21:13.687434+00', '2020-06-05 18:07:30.794112+00', 'Weekend Celebration, A', 'WEEKEND CELEBRATION', 1, 40, NULL, 1, 3, 42, 10907, '2008-03-01', 'Devised for Geoff Thompson and Vivienne Murphy at a weekend of celebration: their marriage, birthdays and St Patrick’s Day.', 55, '800/844/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17620, '2017-02-25 16:49:08.230498+00', '2020-11-04 10:38:46.124379+00', 'St Columba''s 60th Anniversary Reel', 'SAINT COLUMBAS 60TH ANNIVERSARY REEL', 1, 32, NULL, 4, 4, 13, 11454, NULL, '2016 marks the 60th Anniversary of St Columba’s Church and Hall in Pont Street, Knightsbridge. To celebrate a competition was held to devise a dance to be called “St Columba’s 60th Anniversary”. The dance should be something that anyone can do and enjoy from those dancing for the first time to experienced dancers.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2097, '1998-04-11 22:00:00+00', '2020-08-08 09:39:15.68561+00', 'Farewell To Saint Kilda', 'FAREWELL TO SAINT KILDA', 3, 32, 9999, 1, 3, 42, 227, '1989-01-01', 'Advanced level.



The exodus of the St. Kilda people in 1930 inspuired me to this dance.



I "invented" the progression with the half reel of 4 and called it the "Spindle".  Then I found this progression in two more dances as the Half Chain progression. *[In SCDDB this is referred to as "Half-Reel progression"].*', 69, '888  888  888  880', 0, 1, 0, 0, 91);
INSERT INTO 'dance' VALUES (17621, '2017-02-26 16:21:53.62059+00', '2021-11-24 09:33:52.401982+00', 'Sibylle''s Mother', 'SIBYLLES MOTHER', 3, 32, NULL, 2, 3, 17, 11344, '2016-01-01', 'Dedicated to Aliénor Latour and her baby daughter Sibylle, born July 2016', 71, '880/844/888/804', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10532, '2002-05-01 22:00:00+00', '2018-06-25 19:27:02.49642+00', 'Amethyst, The', 'AMETHYST', 3, 32, 9999, 1, 3, 42, 74, '1999-01-01', 'At the 24th Australian Winter School in Perth in September/October 1999 I was in the Nullagine Class. Derek Haynes taught his dance “<<ddd:Black Donald>>” which has the figure Allemande Right and Allemande Left, which is described in the dance “<<ddd:Not I>>”, R.S.C.D.S. Book 28. I like this figure and other dances, “<<ddd:Peterhead Lassies>>” by Roy Goldring and “<<ddd:The Bluebells of Scotland>>” by Iain Boyd, which contain it. It occurred to me that I did not know of any strathspey containing the figure (although Alastair McFadyen in New Zealand had taught a version of <<ddd:Sandy O’er the Lea>> with that figure from an old book). This was the inspiration for the dance. To the Allemande figure, I have added other of my favourite strathspey movements - the progression, dancing through the ends and the hands across flowing into right hand turns.  



Nullagine is a town in Western Australia which is famous for its amethyst production. We were

pleased to learn that amethyst is said to protect from intoxication!', 50, '880/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15854, '2015-01-20 12:16:12.267516+00', '2016-12-16 21:27:39.901907+00', 'Extra Day, The', 'EXTRA DAY', 2, 40, 9999, 1, 3, 42, 2625, '2004-02-01', 'Phrasing 4 x 10.



This dance was devised by Malcolm Frost in 2004 to celebrate leap year (and to give another excuse to dance to the fabulous tune The Wee Cooper Of Fife). It is further hoped that less experienced dancers may find these figures less challenging than those for Wee Cooper when acclimatising to 10-bar phrasing, thus helping them subsequently to better enjoy dancing the WeeCooper', 50, '10 0 0/10 8 8/10 4 4/10 8 8', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17484, '2016-12-12 05:56:20.56208+00', '2016-12-18 22:52:12.282502+00', 'Take A Bow', 'TAKE A BOW', 2, 32, 9999, 1, 3, 42, 10309, '2011-09-01', 'This is a 3 couple dance in a 4 couple longwise set (8 x 32), but as it is a wedding dance the non-dancing couple also joins in in each 8 hands round on [25-32]. 



This dance is dedicated to Lena and Felix to celebrate their wedding in September 2011.



The dance contains a special variation of a reel of four called the bow tie reel (or Mascherl Reel in Austrian).', 50, '800/880/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11781, '2004-09-08 22:00:00+00', '2018-05-18 07:51:01.443133+00', 'Forty Happy Years', 'FORTY HAPPY YEARS', 3, 32, 9999, 1, 4, 2, 108, '2003-07-01', 'For the 40th Anniversary of St. Columba''s Class in Leeds requested by Avis Harrison  



John wrote: "I wrote this dance as a reel but, when it was danced in Avis''s class, they decided that they preferred it as a strathspey."', 66, '6666/8888/0660/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17489, '2016-12-27 00:52:03.897358+00', '2016-12-27 00:52:03.897358+00', 'Manhattan', 'MANHATTAN', 1, 32, NULL, 1, 3, 42, 10934, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17490, '2016-12-27 00:57:37.388437+00', '2016-12-27 00:57:41.299041+00', 'Mix and Mingle', 'MIX AND MINGLE', 2, 32, NULL, 1, 3, 42, 10934, NULL, '', -1, '', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (17498, '2016-12-27 10:02:32.03952+00', '2019-03-14 15:20:11.767249+00', 'Welcome Wagon, The', 'WELCOME WAGON', 2, 32, NULL, 1, 3, 42, 10934, NULL, 'This dance is dedicated to Mary Wessel-Walker and Molly Glenn of Ann Arbor, Michigan, who taught the beginners'' class with me.', 56, '440/888/880/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17492, '2016-12-27 01:01:45.591822+00', '2016-12-27 01:02:09.736105+00', 'Passeggiatta, La', 'PASSEGGIATTA', 3, 32, NULL, 1, 3, 42, 10934, NULL, '', -1, '', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (17493, '2016-12-27 01:04:06.050102+00', '2016-12-27 01:04:11.451603+00', 'Ribbons and Lace', 'RIBBONS AND LACE', 3, 32, NULL, 2, 3, 17, 10934, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17494, '2016-12-27 01:06:44.910868+00', '2019-03-15 08:11:47.920495+00', 'Spanish Eyes', 'SPANISH EYES', 3, 32, NULL, 1, 3, 42, 10934, NULL, 'Dedicated to Ann Rain', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18454, '2018-07-19 16:00:13.350015+00', '2018-07-19 16:00:13.350015+00', 'FINICY', 'FINICY', 2, 32, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17540, '2017-01-19 17:57:53.106006+00', '2017-01-19 18:05:59.194583+00', 'Hans'' Strathspey', 'HANS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 11181, '2017-01-19', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17496, '2016-12-27 09:43:28.825518+00', '2016-12-27 09:44:04.164464+00', 'Conshohoken Curve, The', 'CONSHOHOKEN CURVE', 1, 96, NULL, 4, 4, 3, 10934, NULL, 'The Conshohoken Curve is a notoriously difficult stretch of I-76', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17497, '2016-12-27 09:59:10.154648+00', '2016-12-27 09:59:18.271186+00', 'Four Reel Drive', 'FOUR REEL DRIVE', 2, 32, NULL, 1, 3, 42, 10934, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18457, '2018-07-19 16:02:02.626807+00', '2018-07-19 16:02:02.626807+00', 'Muresk', 'MURESK', 1, 32, NULL, 1, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18459, '2018-07-19 16:03:17.503071+00', '2018-07-19 16:03:17.503071+00', 'Sapphire Jubilee, The', 'SAPPHIRE JUBILEE', 3, 32, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17503, '2016-12-31 14:23:08.963167+00', '2016-12-31 14:23:08.963167+00', 'He Loves Me, He Loves Me Not', 'HE LOVES ME HE LOVES ME NOT', 3, 32, NULL, 1, 3, 42, 10934, NULL, 'This dance tells a tale of two lovers who meet and then part. As the woman picks the petals one by one of the daisy, she hopes to discern his feelings. In the end, they are united in the most romantic figure, the poussette right round. This dance is given in thanks to the Bryn Mawr and Haverford College dance class for programming this dance on their lovely springtime tea dance.', -1, '', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (17541, '2017-01-20 02:02:22.052958+00', '2017-01-20 02:02:22.052958+00', 'Return to Moray', 'RETURN TO MORAY', 3, 64, 9999, 2, 3, 17, 57, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17542, '2017-01-20 02:05:47.137848+00', '2017-01-20 02:05:47.137848+00', 'Wellington Reel, The', 'WELLINGTON REEL', 1, 48, 9999, 2, 3, 18, 3462, '1992-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12965, '2006-10-25 22:00:00+00', '2018-07-29 14:20:56.082644+00', 'Everchanging Medley, The', 'EVERCHANGING MEDLEY', 4, 96, 21, 6, 3, NULL, 3718, '2005-01-01', 'From the book:



The dance was originally devised so that after each sequence, not only do the dancers change partners and positions, but the rhythm also changes. However the "medley" could also be danced using only two rhythms, i.e. strathspey - jig (reel) - strathspey or jig (reel) - strathspey - jig (reel). Indeed, the "medley" could be danced with only one rhythm throughout - strathspey or jig or reel. The choice is up to you, but it is advisable to inform the dancers (and band) beforehand.

', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14129, '2011-08-25 22:00:00+00', '2018-09-07 03:37:54.688392+00', 'Cat''s Cradle', 'CATS CRADLE', 2, 32, NULL, 1, 3, 42, 10433, NULL, 'This dance is dedicated to ailurophiles, but lovers of other animals may dance it! Cat''s cradle is a game played by making intricate patterns with a loop of string between the fingers.', 42, '550/550/444/886', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17511, '2017-01-04 17:26:19.00673+00', '2019-06-28 08:42:34.01347+00', 'Caledonian Medley', 'CALEDONIAN MEDLEY', 4, 96, 11, 105, 53, NULL, 11110, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17510, '2017-01-04 17:24:55.906555+00', '2019-06-28 08:43:08.67544+00', 'Aubigny-sur-Nère Reel', 'AUBIGNYSURNERE REEL', 1, 128, NULL, 100, 4, NULL, 11110, '2004-11-02', 'For the visit to Aubigny-sur-Nere in July 2005.



The dance starts and ends as a longwise set, bars 33-96 are in a square set.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17555, '2017-01-22 15:37:03.414451+00', '2018-04-03 00:07:37.520674+00', 'Cauldron-Of-The Plaid', 'CAULDRONOFTHE PLAID', 2, 40, NULL, 1, 3, 42, 11443, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17554, '2017-01-22 15:33:14.007501+00', '2017-01-22 15:33:14.007501+00', 'C 2 C (Canton to Cartersville)', 'C 2 C CANTON TO CARTERSVILLE', 3, 32, NULL, 1, 4, NULL, 11442, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17556, '2017-01-22 15:39:17.045731+00', '2017-01-22 15:39:17.045731+00', 'Don''t Make Me Stop, I''ll Get Lost', 'DONT MAKE ME STOP ILL GET LOST', 1, 32, NULL, 2, 3, NULL, 11444, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17487, '2016-12-27 00:43:20.496198+00', '2020-10-31 12:10:11.730434+00', 'Auctioneer, The', 'AUCTIONEER', 1, 32, NULL, 1, 3, 42, 10934, NULL, 'Dedicated to Terry Harvey, Pinewoods Auctioneer extraordinaire', 47, '800/822/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17499, '2016-12-27 10:06:44.089404+00', '2020-10-31 12:16:38.413854+00', 'Witching Hour, The', 'WITCHING HOUR', 1, 32, NULL, 1, 3, 42, 10934, NULL, '', 50, '800/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17502, '2016-12-31 14:14:25.473501+00', '2020-11-01 10:07:16.775796+00', 'Center of the Universe, The', 'CENTER OF THE UNIVERSE', 1, 32, NULL, 1, 4, 1, 10934, NULL, '', 50, '4400/8880/4400/8844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17567, '2017-01-22 21:33:41.531431+00', '2018-12-20 10:39:53.419298+00', 'Swans of Atlanta, The', 'SWANS OF ATLANTA', 4, 64, 5, 4, 4, NULL, 2927, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17566, '2017-01-22 21:31:09.718063+00', '2017-01-22 21:31:09.718063+00', 'Sprezzatura', 'SPREZZATURA', 1, 32, NULL, 1, 4, NULL, 23, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17568, '2017-01-22 21:38:10.081624+00', '2017-01-22 21:38:10.081624+00', 'Wha'' A Lass', 'WHA A LASS', 1, 48, NULL, 1, 4, NULL, 11447, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13654, '2011-03-21 23:00:00+00', '2017-01-22 23:08:46.448065+00', 'Barbaron', 'BARBARON', 3, 32, 9999, 2, 3, 17, 23, '2009-01-01', 'Commissioned at the Thistle School Auction in 2009 and lovingly devised by Elizabeth Lee Barnes for

Barbara and Ron Gemmell for their 50th anniversary in 2010.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17557, '2017-01-22 15:40:56.005966+00', '2017-01-22 23:11:16.621286+00', 'Georgia On My Mind', 'GEORGIA ON MY MIND', 3, 32, NULL, 1, 4, NULL, 11445, NULL, 'Devised by Susan Tumlin, November 7, 2013.

The first eight bars represent the state capitol with its beautiful gold dome.

The second eight bars represent the Golden Isle coastline ofGeorgia by using the last eight- bar figure from Sea Tangle ofSkye.

The third eight bars represent The University ofGeorgia, the oldest public university in the United States, where the Branch’s Athens Class meets.

The last eight bars represent the square in Marietta which is visited weekly after the Tuesday night class meets.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17570, '2017-01-25 16:13:13.090044+00', '2017-01-25 16:35:59.059515+00', 'New Haven Grid Lock', 'NEW HAVEN GRID LOCK', 2, 48, NULL, 4, 4, 30, 3098, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17562, '2017-01-22 21:24:26.59703+00', '2018-04-03 00:08:09.572646+00', 'Owl''s Nest, The', 'OWLS NEST', 2, 32, NULL, 1, 3, 42, 1110, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17565, '2017-01-22 21:29:28.764694+00', '2018-04-03 00:08:16.444643+00', 'Short''s Golden Strathspey, The', 'SHORTS GOLDEN STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11444, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13311, '2007-07-26 22:00:00+00', '2017-02-01 00:39:14.924963+00', 'Mascads Jig', 'MASCADS JIG', 2, 32, 9999, 2, 3, 17, 3775, '2007-05-01', 'This dance was devised to say thank you to a few people. It is dedicated to Andrea from Dundee, Antoine from Paris, Clemens from Heidelberg, Daniele from Paris, Martina from Langenfeld, Silke from Leverkusen and Stefan from Kornwestheim.  

Thank you for your helpful support!



The Name of the dance are the initials from Martina, Andrea, Silke, Clemens, Antoine, Daniele und Stefan ;-).

', 92, '888/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17688, '2017-04-01 16:44:21.825996+00', '2017-04-07 14:53:35.720645+00', 'Chartreuse', 'CHARTREUSE', 3, 32, NULL, 1, 4, 13, 11472, NULL, 'Revised version, April 2017.

Note: the PDF of this dance has a misprint: on [17-18] 2c is turning, not 3c.', 69, '8800/8888/0800/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (495, '1998-07-08 22:00:00+00', '2017-04-21 22:43:50.934664+00', 'Betty''s Jig', 'BETTYS JIG', 2, 32, 9999, 1, 4, 2, 108, '1977-01-01', 'John Drewry noted in the original description that the dance is for Betty Haughey of Glasgow, who died in Benidorm 12 January, 1977.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17742, '2017-05-09 17:27:34.461819+00', '2017-05-09 17:27:34.461819+00', 'Welcome to Ashmerg', 'WELCOME TO ASHMERG', 1, 32, 9999, 1, 100, 2, 11466, '1997-05-01', 'Devised May 1997 to welcome dancers to the start of a new dance season at the ASHMERG Scottish Country Dance Group.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17558, '2017-01-22 15:43:28.375669+00', '2017-05-31 12:56:47.8559+00', 'Kudzu Reel, The', 'KUDZU REEL', 3, 32, NULL, 3, 5, NULL, 10310, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17569, '2017-01-22 21:39:35.777614+00', '2018-01-13 16:58:19.853308+00', 'Yellow Fliers, The', 'YELLOW FLIERS', 2, 32, NULL, 1, 3, 42, 11581, NULL, 'Devised in honor of Bernard Kaiman and the yellow fliers he took to all events to

publicize the next event.', 56, '800/888/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17459, '2016-11-01 12:48:01.71573+00', '2017-02-02 14:18:58.359341+00', 'Toast to the Mousies', 'TOAST TO THE MOUSIES', 1, 32, NULL, 1, 3, 42, 10788, '2016-09-30', 'Notes from the leaflet:



Devised by Sara Gratiot, San Francisco Branch, Sept. 2016 Inspired by the tune “Toast to the Mousies” composed by Keith Smith in 2008 The tune has always tickled me and it needed a dance!



When asked what prompted the tune, Keith responded: “There have been a number of mice incidents over the years but one in particular was trying to humanely catch and eject small cute field-mice that were making rather loud munching noises in my house whilst a pal and I were trying to record Scottish music...”



About the dance, Sara shares: “I first heard Keith’s tune “Toast to the Mousies” in a set by the same name on the CD, Highland Shortbread, with Keith Smith and Muriel Johnstone, released by Scotscores in 2009. The tune just makes me happy, and I thought it needed a light, fun, whisker-wiggling, tail-twitching dance. The dance was finally devised for the Sunday morning combined class at the San Francisco Branch’s Annual Asilomar Weekend Workshop in 2016. Bars 9–16 honor our kept creatures that get their exercise on a wheel. Bars 17–24 depict the skittering into and out of mouseholes and hidey-holes.”', 62, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18339, '2018-05-20 14:19:18.176355+00', '2018-05-20 14:19:18.176355+00', 'Summer on the Neckar', 'SUMMER ON THE NECKAR', 1, 48, 9999, 2, 3, 17, 2682, '2017-08-09', 'Note by the deviser:



Devised 9 August, 2017. Dedicated to the SCD group in Heidelberg, with whom we danced many times in May and June 2017. Many thanks especially to Stefanie Eckert for going out of her way to pick us up so many times in 2017 and previous years; Gillian and Joe Wheadon for taking us home from the class, and even from Frankfurt, Stefanie and Viktor Lehmann for teaching the class, and to the members for welcoming us there yet again. Heidelberg lies on the beautiful Neckar River, and is a remarkably nice place to be over the summer.

We have lots of very fond memories with icecream, cycling and biergartens high on this list as well as dancing, of course .

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13049, '2006-11-02 23:00:00+00', '2017-02-02 21:57:53.729353+00', 'Lord of the Dance', 'LORD OF THE DANCE', 2, 32, 9999, 1, 4, 13, 352, '2001-08-07', 'There is a misprint in the original instructions.  On bar 25, in the diagonal reel 1st Lady starts Rsh to 2nd Lady (in 1st Man''s place); the instructions mistakenly say 2nd MAN', 44, '8040/8044/8400/8404', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17574, '2017-01-30 23:34:28.13017+00', '2021-05-27 22:24:42.602641+00', 'Donna''s Cake', 'DONNAS CAKE', 2, 32, NULL, 1, 3, 42, 11448, NULL, 'For dancer Donna Graham, a great cake maker, on finishing her chemotherapy.  Donna passed away in February 2012 after a long battle with cancer.  Her smile and laughter will be with us always.', 56, '800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17563, '2017-01-22 21:25:41.848756+00', '2021-01-17 00:22:35.066588+00', 'Peachtree Reel, The', 'PEACHTREE REEL', 1, 32, NULL, 1, 3, 42, 2787, NULL, '', 55, '880/842/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17571, '2017-01-25 23:15:45.781469+00', '2021-07-30 04:02:45.860523+00', 'Day of Dance, The', 'DAY OF DANCE', 1, 32, NULL, 1, 4, 1, 308, '2011-04-01', 'Written for the Children’s Day of Dance held on May 28th 2011 in Dumfries, which was led by Louise Macdougall and organised by the Dumfries Branch of the RSCDS with children''s class teacher Jo Olive', 78, '8080/8888/8282/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17573, '2017-01-25 23:25:02.3015+00', '2021-07-30 08:35:44.215472+00', 'Queen of the Seas', 'QUEEN OF THE SEAS', 3, 32, NULL, 4, 4, NULL, 308, NULL, 'Devised on board the Cunard Liner Queen Elizabeth for the dancers in Halifax Nova Scotia as a thank you for the warm welcome I received on my visit.



The dance was then modified with the assistance of the dancers from the Nova Scotia Branch at the workshop held during my visit.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17856, '2017-06-23 07:56:47.027299+00', '2018-04-03 00:08:17.261548+00', 'Sky City Reel', 'SKY CITY REEL', 1, 40, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18455, '2018-07-19 16:00:50.183545+00', '2018-07-19 16:00:50.183545+00', 'Greenock “Pearl”, The', 'GREENOCK PEARL', 2, 32, NULL, 2, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18458, '2018-07-19 16:02:46.011554+00', '2018-07-19 16:02:46.011554+00', 'Pelicans in Paradise', 'PELICANS IN PARADISE', 3, 40, NULL, 4, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17837, '2017-06-22 17:26:31.178305+00', '2018-04-03 00:08:23.49902+00', 'Utterson Reels, The', 'UTTERSON REELS', 1, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12895, '2006-10-12 22:00:00+00', '2017-02-11 01:18:58.402113+00', 'PZ 40', 'PZ 40', 1, 40, 9999, 1, 127, 11, 753, NULL, 'Penny Gay of the Penzance SCD Club wrote: The dance was written in 2002 to celebrate the 40th Anniversary of the founding of the Club called Penzance Scottish Country Dancers.  Hence the name PZ40.  



However, we have also always liked the fact that there have been two boats with the Registration PZ40.   One is a small fishing boat, often anchored in St Ives Harbour.  But there used to be another boat registered as PZ40 - a Mounts Bay Lugger.  There is a small oil painting in Penlee House Museum depicting the Lugger PZ40 battling through a stormy sea.  ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17626, '2017-03-02 00:45:51.91045+00', '2017-03-02 00:45:51.91045+00', 'Magic of Summer School, The', 'MAGIC OF SUMMER SCHOOL', 1, 32, NULL, 1, 3, 18, 11462, NULL, 'The dance was inspired by Helen''s love of the fun and magic of New Zealand Summer School. It was written after the 2011-2012 Summer School.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17532, '2017-01-05 10:09:05.613808+00', '2018-04-06 13:19:36.136635+00', 'Platinum Skies', 'PLATINUM SKIES', 1, 32, 9999, 1, 3, 42, 11439, NULL, '', 38, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16682, '2015-08-29 13:10:29.73547+00', '2017-03-03 21:46:46.841005+00', 'Bob''s Chase', 'BOBS CHASE', 2, 32, 9999, 4, 4, 1, 11182, NULL, 'Bob was our Border Collie who loved chasing us or being chased around the garden at Dykeside. He passed away in 2014.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17576, '2017-02-02 20:49:36.016532+00', '2022-08-10 11:01:27.390214+00', 'Skyeline', 'SKYELINE', 3, 32, NULL, 1, 3, 42, 11449, NULL, 'Devised for Lesley Jones of Skyeline Ceramiics, Broadford, Skye.', 44, '800/844/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12005, '2005-02-01 23:00:00+00', '2022-12-22 18:21:33.113168+00', 'Braveheart', 'BRAVEHEART', 1, 32, 9999, 1, 4, NULL, 725, '2003-01-01', 'Possible error!  A pdf of "Braveheart" from a publication "Clapyerhands ''n Stampyerfeet" describes a very different dance from the one of the attached Minicrib.  This needs sorting out.  Eric Ferguson, 7 feb. 2017.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12004, '2005-02-01 23:00:00+00', '2022-12-22 18:30:32.040419+00', 'Robert the Bruce', 'ROBERT THE BRUCE', 1, 32, 9999, 1, 4, 1, 725, '2003-01-01', 'The instructions from 2017 describe this as a four couple longwise dance which corresponds to the MiniCrib.



An older, 2003, version of the original "Clapyerhands ''n Stampyerfeet" has it as a circle dance, all next to partner. This appears to have been completely revised for the 2017 edition.

', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1796, '2002-03-11 23:00:00+00', '2017-02-11 23:37:42.597288+00', 'Duke of Wellington, The', 'DUKE OF WELLINGTON', 1, 32, 9999, 1, 3, 42, 108, '1991-01-01', 'NOTES by Drewry



1. I have suggested the modified Petronella for two reasons. The first is that it enables the 1st couple to be well apart when setting and the second is that it is less tiring. (In strathspeys e.g. "The Lea Rig" the Petronella movement is danced with travelling steps) N.B. I am not suggesting that Petronella itself should be danced with skip-changeof-step. Those, who because of ingrained habit, find it difficult to do the movement in this way, may use pas de basque throughout provided that they use long steps for travelling.



2. In "pass and turn" (a 4-bar figure), 1st couple dance round the corner position by the right; while the corners dance in (passing 1st man or woman by the right) on bar 1; they turn each other with the right hand on bar 2; they dance out towards own places (again passing 1st man or woman by the right) on bar 3; and curve into place on bar 4.



3. Wellington was named after the Iron Duke, who chose his title from Wellington in Somerset (not Wellington in Shropshire). ', 56, '880/880/888/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17578, '2017-02-04 17:27:29.805492+00', '2017-02-14 00:19:56.017209+00', 'Optometrist, The', 'OPTOMETRIST', 3, 32, NULL, 1, 4, 1, 11164, '2017-02-13', 'Dance revised in Feb. 2017.  In the previous version, the place changes in [15-16] were Rsh, not RH.', 97, '8888/8686/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8927, '1999-02-14 23:00:00+00', '2018-06-25 16:40:35.633198+00', 'Derek''s Dilemma', 'DEREKS DILEMMA', 2, 32, 9999, 1, 128, 2, 2560, '2017-02-19', 'This dance was revised and republished on 19 feb. 2017.  This revised version replaces all earlier versions.', 78, '8008/8888/8448/8668', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17615, '2017-02-20 22:23:27.503319+00', '2018-03-31 16:53:28.038065+00', 'Apples', 'APPLES', 3, 24, NULL, 1, 3, 42, 11348, '2015-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17586, '2017-02-15 19:36:53.911075+00', '2020-08-15 07:16:06.223677+00', 'All Rounder, The', 'ALL ROUNDER', 3, 32, NULL, 1, 4, 1, 1582, '2016-10-01', '', 100, '8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17599, '2017-02-15 20:04:04.116344+00', '2020-08-15 07:33:41.043587+00', 'Mrs Betsey Maxwell', 'MRS BETSEY MAXWELL', 3, 32, NULL, 2, 3, 17, 1582, '2011-06-01', '', 83, '844/888/888/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17597, '2017-02-15 20:02:53.88863+00', '2020-08-15 13:18:31.565411+00', 'Moikei Gold', 'MOIKEI GOLD', 3, 32, NULL, 2, 3, 17, 1582, '2013-12-13', 'Devised by Pat Clark for Moira and Keith Stacey (Kirkcudbright) on their Golden Wedding Anniversary, December 13th 2013', 83, '888/880/888/808', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17591, '2017-02-15 19:50:51.130716+00', '2020-08-15 14:07:24.748011+00', 'Eileen Kirk''s Reel', 'EILEEN KIRKS REEL', 1, 32, NULL, 1, 4, 1, 1582, '2015-04-01', 'Devised for Eileen Kirk, a very accomplished dancer in Dumfries.', 70, '8008/8888/2800/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17589, '2017-02-15 19:45:33.446876+00', '2020-08-15 14:14:24.57925+00', 'Children''s Celebrations, The', 'CHILDRENS CELEBRATIONS', 1, 32, NULL, 1, 4, 1, 1582, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17585, '2017-02-15 19:34:17.721944+00', '2020-08-15 14:29:52.697071+00', 'All for Betty', 'ALL FOR BETTY', 3, 32, NULL, 1, 4, 1, 1582, '2016-06-01', 'Published in September 2016 for Elizabeth Ferguson (Branch Teacher) to mark her 90th birthday.', 88, '4884/8088/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9871, '2001-06-05 22:00:00+00', '2021-02-16 13:05:07.957357+00', 'Late in the Day', 'LATE IN THE DAY', 1, 40, 9999, 1, 3, 42, 101, '1997-01-01', 'For the 25th wedding anniversary of Denise and Ken Fallas in 1997. They were mystified by the title.', 55, '800/844/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17596, '2017-02-15 19:59:14.350098+00', '2021-08-26 10:41:12.369996+00', 'Medley for William and Linda, A', 'MEDLEY FOR WILLIAM AND LINDA', 4, 64, 17, 2, 3, 17, 1582, '2015-04-01', 'Devised for William and Linda Williamson, Amisfield.', 79, '888/888/800/888/888/800/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17583, '2017-02-15 15:53:22.004311+00', '2018-04-02 23:56:34.295717+00', 'Eleanor''s Jig', 'ELEANORS JIG', 2, 40, NULL, 1, 3, 42, 11453, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17614, '2017-02-20 09:44:14.825544+00', '2017-02-20 09:44:14.825544+00', 'Fireside Reel, The', 'FIRESIDE REEL', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'The description of this dance was published December 1993 in the book "Angela''s and Tony''s Dances Books 1", where it is stated "origin unknown".

Due to its large resemblance to "The Fireside Reel" from 1740 published in the "18th Century Book", it is likely a variant of this one. It only differs in bars 17-24, where the "Set, Petronella Turn, Set, Petronella Turn" has been substituted by a Poussette up-and-down with less turning to do the progression.

Possibly it was forwarded among dancers mistaking Petronella with Poussette...', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11558, '2003-10-30 23:00:00+00', '2018-04-03 00:07:44.569362+00', 'Eppelwoi', 'EPPELWOI', 1, 32, 9999, 1, 3, 42, 1445, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11782, '2004-09-08 22:00:00+00', '2017-02-22 00:34:36.80742+00', 'Glenmorangie', 'GLENMORANGIE', 1, 32, 9999, 1, 3, 42, 108, '2003-01-01', '', 55, '800/888/833/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17611, '2017-02-16 09:05:52.97251+00', '2017-10-19 22:56:11.810628+00', '2013 Medley, The', '2013 MEDLEY', 4, 48, 10041, 1, 4, NULL, 1582, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18460, '2018-07-19 16:03:45.517729+00', '2018-09-19 09:49:26.803737+00', 'Silkes'' Daunder', 'SILKES DAUNDER', 1, 40, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18630, '2018-09-18 17:46:05.255626+00', '2018-09-20 22:49:45.485526+00', 'Elegance', 'ELEGANCE', 3, 32, NULL, 2, 3, 18, 11711, '2014-01-01', '', 83, '880/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17627, '2017-03-02 19:25:01.214591+00', '2017-03-03 23:11:56.743875+00', 'Joie de la Danse, La', 'JOIE DE LA DANSE', 1, 32, NULL, 3, 5, 7, 703, NULL, 'Devised for Elizabeth Holtan, of Washington DC area, in honour of her landmark birthday on March 1, 2017.  The English translation – “The joy of the dance.”', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17195, '2016-08-22 21:41:08.809795+00', '2017-02-28 12:18:06.904679+00', 'Alderwood Knot, The', 'ALDERWOOD KNOT', 3, 32, NULL, 4, 4, 13, 11322, '2011-01-01', 'Dedicated to Maria Ward, for her inspirational nature, graceful dancing, and personal strength, with best wishes many more years of enjoyment from dancing.



The Alder tree is symbolic of strength and rebirth and a grove of black alders is situated near Urquhart Castle by the village of Drumnadrochit on the shores of Loch Ness, Scotland.



Dance devised on the occasion of Maria Ward’s 60th birthday and return to dancing after surgery. January 2012. Interlocking Set and Link devised August 2011.  Bars 25-26 modified in 2016; they were "All Advance{1} and Retire{1}".



Northern Virginia Branch of the Royal Scottish Country Dance Society.

', 81, '6666/8080/8888/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18461, '2018-07-19 16:04:16.955005+00', '2018-07-19 16:04:16.955005+00', 'Takayama Matsuri, The', 'TAKAYAMA MATSURI', 1, 40, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1792, '2001-09-13 22:00:00+00', '2017-03-04 12:46:28.632036+00', 'Duke of Perth', 'DUKE OF PERTH', 1, 32, 9999, 1, 3, 42, 9998, '1827-01-01', '##>>

Duke of Perth has never been an official Scottish or British title. It was granted to James Drummond, then Earl of Perth, by the deposed and exiled King James II and VII in 1701, although some sources give 1695. The Drummonds remained loyal to the Stewart cause and the 2nd Duke was, as they say, »out« with the Old Pretender in 1715. Both of his sons were with Bonnie Prince Charlie in 1745. The 3rd Duke died on board a ship fleeing after Culloden and his brother, the 4th Duke, died in fighting in Holland in 1747.



The family tree gets very complicated after the 4th Duke but John Drummond, currently 9th Earl of Perth is accepted as the Jacobite 15th Duke of Perth. 

##<<



If you have a spare 39 seconds, here is an interesting clip of the Duke of

Perth being danced in Glasgow circa 1964   Only one time through, alas.

<<http://ssa.nls.uk/film/3270>>  The caption says Highland dancing. . .but it lies.  It''s SCD.



', 44, '800  822  844  866', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (18340, '2018-05-20 14:23:21.431579+00', '2018-10-09 23:40:51.701942+00', 'Johnsonville Gold', 'JOHNSONVILLE GOLD', 3, 24, 9999, 2, 3, 17, 2682, '2016-08-25', 'Notes from the deviser:



Devised 25/8/2016, during Johnsonville''s \golden anniversary" year. This dance

is a less vertigo inducing version of THE JOHNSONVILLE DIAMOND.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18341, '2018-05-21 02:32:43.732574+00', '2018-05-21 07:15:57.324035+00', 'When Harry Wed Meghan', 'WHEN HARRY WED MEGHAN', 2, 32, NULL, 1, 3, 42, 3179, '2018-05-20', 'The tune was composed and the dance devised in honour of Prince Harry and Meghan Markle''s wedding at Windsor Castle which took place on 19 May 2018. ', 75, '800/888/866/888/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17610, '2017-02-16 09:02:34.845524+00', '2020-07-01 10:05:17.930499+00', 'Tribute to Max and Anne, A', 'TRIBUTE TO MAX AND ANNE', 3, 32, NULL, 1, 4, 1, 1582, '2014-10-01', 'Max and Anne McNaught were loyal members of Nothallerton Caledonian Society.', 72, '8800/8484/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17623, '2017-03-01 09:50:13.228687+00', '2020-05-18 20:22:12.031316+00', 'Maple Grove, The', 'MAPLE GROVE', 2, 32, NULL, 1, 2, 76, 11222, '2008-02-01', 'Source: Danciemaetion

This may also be danced as a reel.', 43, '44/44/80/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17607, '2017-02-16 08:58:40.457212+00', '2020-11-07 10:46:35.249445+00', 'Strathspey for Jayne, A', 'STRATHSPEY FOR JAYNE', 3, 32, NULL, 1, 3, 42, 1582, NULL, '', 72, '888/888/866/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17605, '2017-02-16 08:56:05.780283+00', '2020-08-15 12:55:07.911888+00', 'Silver Link, The', 'SILVER LINK', 2, 32, NULL, 3, 5, 7, 1582, '2016-10-01', '', 82, '84844/80888/80888/88888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17593, '2017-02-15 19:53:24.444625+00', '2020-07-01 17:19:04.913228+00', 'Jim Stott''s Reel', 'JIM STOTTS REEL', 1, 32, NULL, 1, 100, 99, 1582, '2012-08-01', 'In the <<ddpub:#1351|Corberry II book>> this dance is called "Jim Stott''s Reel" on the page describing the dance but "Jim Stott''s Rant" on the index page. The latter is added as an alias.', 94, '8888/8448/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17592, '2017-02-15 19:52:06.67252+00', '2020-08-15 13:42:40.544561+00', 'Hallowe''en Shadows', 'HALLOWEEN SHADOWS', 3, 32, NULL, 2, 3, 17, 1582, '2016-10-31', 'Devised for Hallowe’en at Dumfries Branch October 2016.

Note: “Corners pass left and turn left” as in corners pass and turn using right hand but replaced with left handed turns and shoulders.', 58, '800/844/800/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17595, '2017-02-15 19:56:46.853427+00', '2020-11-06 10:22:24.579755+00', 'Lindsay''s Fancy', 'LINDSAYS FANCY', 2, 32, NULL, 1, 3, 42, 1582, NULL, '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17598, '2017-02-15 20:03:28.097321+00', '2020-11-06 10:24:55.320825+00', 'Mr Colin Maxwell', 'MR COLIN MAXWELL', 2, 32, NULL, 1, 3, 42, 1582, NULL, '', 58, '802/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17600, '2017-02-15 20:04:44.99367+00', '2020-11-07 10:28:05.612037+00', 'Mrs Sommerville''s Jig', 'MRS SOMMERVILLES JIG', 2, 32, NULL, 1, 2, 76, 1582, NULL, '', 52, '88/80/80/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17601, '2017-02-15 20:08:14.404272+00', '2020-11-07 10:31:11.951535+00', 'Natasha''s 18th', 'NATASHAS 18TH', 2, 32, NULL, 1, 3, 42, 1582, NULL, '', 48, '800/880/888/842', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17603, '2017-02-15 20:11:36.70495+00', '2020-11-07 10:36:10.172779+00', 'Pitter Patter', 'PITTER PATTER', 1, 32, NULL, 1, 3, 42, 1582, NULL, '', 64, '888/864/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17606, '2017-02-16 08:57:20.550526+00', '2020-11-07 10:41:00.478181+00', 'Special Occasion, A', 'SPECIAL OCCASION', 1, 40, NULL, 1, 3, 42, 1582, NULL, '', 55, '800/844/866/866/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16686, '2015-08-29 13:41:25.693251+00', '2018-02-04 23:25:50.825061+00', 'Thomson''s Adumu', 'THOMSONS ADUMU', 1, 32, 9999, 1, 4, 11, 11182, NULL, 'Joseph Thomson was an explorer who lived in Dumfriesshire in the 1800s. He travelled to Africa on many expeditions. Joseph said, “I am a Scot and I can talk to people.” As a result, when he visited the Maasai in Kenya, he was welcomed as a friend and no one on either side was killed. He was a man of peace. Joseph gave his name to Thomson’s Falls and Thomson’s Gazelles. I am proud to say I am his Gt. Gt. Gt. Cousin. Joseph’s motto was - “He who goes gently goes safely and he who goes safely goes far.”



Bars 25-32 represent the Maasai "Adumu ("Jumping Dance") ', 84, '8888/8228/8448/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18463, '2018-07-19 16:05:12.142259+00', '2018-07-19 16:05:12.142259+00', 'Wee, Feisty but Fun', 'WEE FEISTY BUT FUN', 2, 40, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16681, '2015-08-29 13:00:54.679355+00', '2018-02-04 13:17:55.08126+00', 'Amisfield Tower', 'AMISFIELD TOWER', 3, 32, 9999, 1, 4, 1, 11182, NULL, 'Amisfield Tower is one of the best examples of a Tower House in Scotland. It dates back to around 1600 although there was a castle at Amisfield in the 1200s. There are historic links to King Robert the Bruce and the Stuart Kings. The ancient and fine oak door from Amisfield is in the National Museum of Scotland in

Edinburgh.', 91, '8888/8888/8444/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17629, '2017-03-04 09:05:34.636993+00', '2019-02-03 21:17:44.58864+00', 'Over The Heather (Jig 32 version)', 'OVER THE HEATHER JIG 32 VERSION', 2, 32, NULL, 1, 2, 76, 872, NULL, 'This is the original 24 bar Strathspey version of 1997.  It was republished as a 32 bar Jig around 2014', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17201, '2016-09-03 16:31:27.67483+00', '2017-03-10 17:05:43.849171+00', 'Canada Rising', 'CANADA RISING', 2, 32, NULL, 1, 3, 42, 10995, NULL, 'On the original description, the dance is named Canda Rising, but the diagrams are titled Canada Rising.  The deviser''s note below shows that "Canda" is a misprint.



This was written to be the first “set dance” attempted by a group of  great singers but novice dancers. Gratifyingly, 3 out of 3 sets danced it successfully...no doubt inspired by the suggested music!   It works quite well as a warm-up dance .



The choice of title is a personal reminder to me of the great conductor who lead us .... who lived at that time in a road called 2 Canada Rise” and who invited me to lay on a “bit of dancing” in the evening.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17633, '2017-03-10 17:52:21.755835+00', '2017-03-10 17:52:21.755835+00', 'For Ewa', 'FOR EWA', 3, 32, NULL, 1, 4, 1, 10995, '2015-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17634, '2017-03-10 17:58:42.727372+00', '2017-03-10 17:58:42.727372+00', 'Shimmying Bee, The', 'SHIMMYING BEE', 2, 32, NULL, 1, 3, 42, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17654, '2017-03-12 23:53:03.356987+00', '2018-04-02 23:56:34.934418+00', 'Golden Eccles Cakes', 'GOLDEN ECCLES CAKES', 2, 32, 9999, 1, 3, 42, 11467, '2015-04-01', 'Suggested music  "A Jig for Joe" recorded by Ian Slater



A dance to commemorate the 50th anniversary of the Eccles and District Scottish Society in April 2015.', -1, '880 888 888 888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17635, '2017-03-10 18:27:50.328332+00', '2017-03-10 20:56:45.146866+00', 'Dark-eyed Sailor, The', 'DARKEYED SAILOR', 3, 32, NULL, 1, 4, 5, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8475, '1997-12-28 23:00:00+00', '2022-10-04 19:05:06.820598+00', 'Passing Fancy (Strathspey version), A', 'PASSING FANCY STRATHSPEY VERSION', 3, 32, 9999, 1, 2, 76, 872, NULL, 'In "Stepping Out, part 2, Revised version" this dance was republished as a Reel', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8474, '1997-12-28 23:00:00+00', '2022-10-04 19:06:15.497691+00', 'Over the Heather (Strathspey 24 version)', 'OVER THE HEATHER STRATHSPEY 24 VERSION', 3, 24, 9999, 1, 2, 76, 872, NULL, 'This is the original 24 bar Strathspey version of 1997.  It was republished as a 32 bar Jig around 2014', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17637, '2017-03-10 20:49:39.967373+00', '2017-03-14 13:19:47.196036+00', 'Kongelige, Den', 'KONGELIGE DEN', 1, 40, NULL, 2, 3, 17, 11465, '1998-05-01', 'Devised as a tribute to the St. Andrews Society of Denmark





For the figures the deviser uses the names:



1-8:  Alexandra Progression



9-16 and 17-24:  Royal Reel



25-32: Royal visits across the country



33-40:  Letting the next generation take over.', 67, '880/844/844/888/800', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17638, '2017-03-10 21:06:06.964494+00', '2017-03-10 21:11:20.633458+00', 'Perfect 6, The', 'PERFECT 6', 2, 32, NULL, 3, 5, 16, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17639, '2017-03-10 21:14:37.263981+00', '2017-03-10 21:14:37.263981+00', 'Lady in the Ring', 'LADY IN THE RING', 1, 32, NULL, 1, 3, 42, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17640, '2017-03-10 21:16:10.202704+00', '2017-03-10 21:16:10.202704+00', 'Poseidon''s Messengers', 'POSEIDONS MESSENGERS', 1, 32, NULL, 1, 3, 42, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18462, '2018-07-19 16:04:42.213877+00', '2018-07-19 16:04:42.213877+00', 'Tippling Travellers, The', 'TIPPLING TRAVELLERS', 1, 32, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17641, '2017-03-10 21:18:00.607799+00', '2017-03-10 21:20:21.243574+00', 'Margarets of Herstmonceux, The', 'MARGARETS OF HERSTMONCEUX', 1, 32, NULL, 1, 3, 42, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17642, '2017-03-10 21:23:05.278136+00', '2017-03-10 21:23:05.278136+00', 'Trip to Scarba', 'TRIP TO SCARBA', 1, 40, NULL, 1, 4, 1, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17643, '2017-03-10 21:28:19.048441+00', '2017-03-10 21:28:19.048441+00', 'Sweet-Scented Airs, The', 'SWEETSCENTED AIRS', 3, 32, NULL, 1, 4, 1, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17644, '2017-03-10 21:34:01.752552+00', '2017-03-10 21:35:44.65929+00', 'Peacock''s Tail, The', 'PEACOCKS TAIL', 1, 32, NULL, 1, 3, 42, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17645, '2017-03-10 21:38:59.712043+00', '2017-03-10 21:38:59.712043+00', 'Chasin'' Raisins', 'CHASIN RAISINS', 2, 32, NULL, 1, 3, 42, 10995, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17657, '2017-03-15 05:00:15.188807+00', '2017-03-15 09:44:13.171141+00', 'KPSA Reel for Laurent', 'KPSA REEL FOR LAURENT', 3, 32, NULL, 2, 3, 17, 11010, NULL, 'This dance is dedicated to Laurent who is a KPSA (sofware package) expert to thank him for training the deviser for more than a year on my new job.

Laurent is now a happy young retired man.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1485, '1997-12-07 23:00:00+00', '2018-07-20 11:55:24.667031+00', 'Curleywee', 'CURLEYWEE', 3, 32, 9999, 1, 2, 76, 129, NULL, 'The original publications (Galloway Hills Set and Galloway Album) use the spelling Curleywee.

In the Collins book the name is missspelled Curlywee.



Curleywee is the name of a hill in Galloway: from the Gaelic Cor le gaoith, (Hill in the wind).', 60, '88/44/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17839, '2017-06-22 17:27:43.64089+00', '2017-06-22 17:27:43.64089+00', 'Sandra Griffiths Strathspey', 'SANDRA GRIFFITHS STRATHSPEY', 3, 32, NULL, 2, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17678, '2017-03-31 09:06:22.302135+00', '2020-06-27 20:42:00.771914+00', 'Marland Bobby', 'MARLAND BOBBY', 3, 32, 9999, 1, 3, 42, 10399, NULL, '', -1, '8880 8880 8880 4480 ', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9115, '2000-09-02 22:00:00+00', '2020-12-20 23:36:58.96913+00', 'Getting to Know You', 'GETTING TO KNOW YOU', 3, 32, 9999, 1, 4, 1, 2634, '1999-01-01', '', 78, '8888  8008  8888  0686', 1, 1, 1, 1, 78);
INSERT INTO 'dance' VALUES (17691, '2017-04-01 19:46:45.666675+00', '2021-01-19 12:03:18.71288+00', 'Winding River of Glen Coe, The', 'WINDING RIVER OF GLEN COE', 3, 32, NULL, 1, 3, 42, 10961, NULL, '', 69, '880/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17628, '2017-03-03 00:19:42.127858+00', '2021-10-05 22:46:29.473803+00', 'Over the Volcano', 'OVER THE VOLCANO', 1, 32, NULL, 3, 5, 38, 943, '2000-01-01', 'The dance was written within sight of Mexico’s famous volcano, Popocatepetl, and the name is suggested by Under the Volcano, Malcolm Lowry’s account of his life in that country.', 90, '88888/48884/68486/88888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18464, '2018-07-19 16:05:38.216109+00', '2018-09-19 09:50:23.687452+00', 'Whaler''s Welcome to Albany, A', 'WHALERS WELCOME TO ALBANY', 3, 32, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17652, '2017-03-12 23:50:03.863153+00', '2017-05-09 16:23:17.998378+00', 'Spiced Wine', 'SPICED WINE', 3, 32, 9999, 1, 100, 2, 11466, '2009-12-01', 'Specially written by Jim Haworth for ASHMERG Hogmanay Dance 2009', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18627, '2018-09-18 16:18:40.850187+00', '2018-09-20 04:58:50.194706+00', 'Angel and the Miner, The', 'ANGEL AND THE MINER', 2, 32, NULL, 1, 3, 42, 11709, '2014-10-01', '', 50, '800/866/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17653, '2017-03-12 23:51:40.925554+00', '2017-05-09 16:39:45.644965+00', 'St Catherine''s Strathspey', 'SAINT CATHERINES STRATHSPEY', 3, 32, 9999, 4, 4, 1, 11466, '2009-12-01', 'Devised December 2009 for the members of the St Catherine''s (Didsbury) Monday night class.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7617, '1997-12-27 23:00:00+00', '2017-03-22 23:23:55.580215+00', 'Blackland Farm', 'BLACKLAND FARM', 2, 32, 9999, 1, 3, 42, 1228, '1992-01-01', 'To celebrate the weekend meeting at Blackland Farm, April 1992



Note by the deviser: "At the end of the second time through, the 1st couple cast into 4th place as the new top couple begins."', 47, '800/455/455/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17659, '2017-03-19 00:46:54.272051+00', '2017-03-19 21:38:30.216525+00', 'Magic of Mary Ross, The', 'MAGIC OF MARY ROSS', 3, 32, NULL, 2, 3, 17, 11166, NULL, 'Provisional entry, based on two unofficial cribs.', 83, '888/888/088/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17658, '2017-03-18 04:33:47.203103+00', '2017-03-18 04:48:32.625989+00', 'Dancing in Séné', 'DANCING IN SENE', 2, 32, NULL, 2, 3, 17, 11181, '2017-03-18', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17661, '2017-03-19 15:07:32.328458+00', '2017-03-19 15:17:23.626605+00', 'Helen''s Fortieth Flourish', 'HELENS FORTIETH FLOURISH', 1, 40, NULL, 1, 3, 42, 11231, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19011, '2018-10-19 10:35:21.276817+00', '2018-10-28 11:58:08.211321+00', 'Inconstant Suitors', 'INCONSTANT SUITORS', 2, 48, NULL, 4, 4, 4, 63, '2018-07-01', '', 100, '8888/8888/8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17648, '2017-03-12 23:44:03.209669+00', '2017-05-09 13:13:59.930647+00', 'Diamond Jig', 'DIAMOND JIG', 2, 32, 9999, 4, 4, 1, 11466, NULL, 'This dance ws written to celebrate the "60th Wedding Anniversary" of longstanding members, Betty & Alan Dunn.

''60'': The figure ''6'' is traced out in bars 1-4 and 9-12 and the figure ''0'' in bars 17-24', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17647, '2017-03-12 23:42:21.327111+00', '2017-05-09 17:47:24.43436+00', 'Welcome to Lymm', 'WELCOME TO LYMM', 3, 40, 9999, 4, 4, 1, 11466, '2012-01-01', 'Devised 2012 to celebrate the 60th Anniversary of founding of the Lymm Scottish Country Dance Club', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17684, '2017-03-31 09:16:46.650377+00', '2018-04-11 09:19:03.45233+00', 'Perth Town Lade, The', 'PERTH TOWN LADE', 3, 40, 9999, 1, 4, 1, 11471, NULL, 'Devised by David Taylor.



The Town Lade is a waterway in the city of Perth.



- Bars 1-8 represent the mill wheels

- Bars 9-16 represent the walkway (which the author lived beside and traversed many times)

- Bars 17-32 represent the water flowing and the sluice gates

- Bars 33-40 represent the walls of the city', 93, '4884/8888/8888/4888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17677, '2017-03-31 09:05:06.559046+00', '2019-09-08 10:42:19.370856+00', 'Deca-dance', 'DECADANCE', 2, 32, 9999, 1, 4, 1, 11471, '2017-03-31', 'Dance written to celebrate the 10th anniversary of the Gay Gordons (Manchester) in 2017, with bars 9-16 representing the “10”', -1, '8000 8888 8040 8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17671, '2017-03-24 16:47:31.348789+00', '2017-03-24 16:47:31.348789+00', 'Ladies of the Albert Hall', 'LADIES OF THE ALBERT HALL', 4, 112, 18, 1, 4, 3, 50, NULL, 'Adapted by Mary S. Brandon from "Dancers of Don" by Alice MacLennon', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17672, '2017-03-24 16:58:45.06627+00', '2017-03-24 16:58:45.06627+00', 'Mary Isdale''s Highland Schottische', 'MARY ISDALES HIGHLAND SCHOTTISCHE', 4, 64, 5, 7, 4, 3, 50, NULL, 'Performance medley in a circle of four, five or six couples', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17674, '2017-03-24 17:41:41.762345+00', '2017-03-24 17:41:41.762345+00', 'Phaeton, The', 'PHAETON', 2, 128, 9999, 8, 105, 30, 50, NULL, '128 jig in four movements using three, four, five and six couples

based on "Machine Without Horses"

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17669, '2017-03-24 14:55:14.194174+00', '2020-06-21 09:37:43.306443+00', 'Brandons of Los Angeles, The', 'BRANDONS OF LOS ANGELES', 1, 32, 9999, 1, 3, 42, 598, '1997-01-01', 'Deanna St. Amand devised this dance in 1997 to celebrate Mary and David

Brandon''s accomplishments.  In 1996 Mary was named an examiner, and

David received the Society''s Scroll of Honour in 1997.', -1, '720 888 844 888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17686, '2017-03-31 10:15:10.297898+00', '2020-12-29 12:14:44.999396+00', 'Jig for Laura (Jig 32 version), A', 'JIG FOR LAURA JIG 32 VERSION', 2, 32, NULL, 1, 4, 1, 872, NULL, '', 69, '8880/8880/8000/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17668, '2017-03-24 14:38:57.199064+00', '2020-12-28 11:10:50.017791+00', 'Mo''ili''ili Jig', 'MOILIILI JIG', 2, 32, 9999, 1, 3, 42, 50, '2000-01-01', 'Mo''ili''ili (pronounce mo-eelee-eelee) is the neighborhood in Honolulu, Hawaii, where Mary and David taught Scottish Country Dance for many years.', -1, '840 820 888 844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17665, '2017-03-22 13:22:20.66923+00', '2020-06-21 14:42:15.103565+00', 'Lady Aberdeen Strathspey', 'LADY ABERDEEN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 50, '2016-01-01', 'The first dance club in Vancouver was named for Lady Aberdeen, the wife of the Governor General of Canada. When the club started holding a tea dance on Remembrance Day on November 11, they named it for her. The club no longer exists, but the Lady Aberdeen Tea dance is still a highlight of the dance calendar for the Vancouver Branch.', 63, '888/888/844/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17662, '2017-03-19 15:13:18.08134+00', '2020-11-08 11:02:56.43856+00', 'Hip Hip Hooray!', 'HIP HIP HOORAY', 2, 32, NULL, 1, 3, 42, 10795, '2016-01-01', 'Devised by Helen McGinley 2016 for Blair Halliday on his return to dancing after a hip replacement. ', 38, '800/844/844/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17666, '2017-03-22 13:43:38.855229+00', '2020-12-28 11:14:26.84142+00', 'Lions Gate', 'LIONS GATE', 1, 40, 9999, 1, 100, 2, 50, '2016-01-01', 'The twin mountain peaks called The Lions are easily recognizable Vancouver landmarks. They are named after a fancied resemblance to Landseer''s lions statues in Trafalgar Square. The suspension bridge that connects the North Shore with Vancouver is also named "Lions Gate".', -1, '8228 8448 8448 8888 8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (680, '1997-08-20 22:00:00+00', '2021-06-30 09:14:37.260409+00', 'Bonnie White Rose, The', 'BONNIE WHITE ROSE', 3, 32, 9999, 1, 3, 42, 108, '1964-01-01', 'NOTES:  



1. The title is taken from the poem *Harne, Harne, Harne* by Alan Cunningham  



2. Originally I called this dance Rose Among the Heather, then I found that Mr. lain Boyd of New Zealand had composed a dance with this title, so I had to think of a new name for my dance, but, of course, the tune stays the same.', 59, '800/866/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17664, '2017-03-22 13:06:58.286021+00', '2020-12-29 11:51:16.5253+00', 'Gleneagles Reel', 'GLENEAGLES REEL', 1, 40, 9999, 1, 3, 42, 50, '2016-01-01', 'The clubhouse at Vancouver''s Gleneagles Golf Club is the birthplace and the home of the Gleneagles SCD Club. Mary was the club''s first dance teacher in 1962.', -1, '822 888 877 877 888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17673, '2017-03-24 17:18:36.370263+00', '2021-01-06 10:31:05.490692+00', 'Mormaer of Moray, The', 'MORMAER OF MORAY', 4, 96, 11, 2, 3, 3, 50, NULL, 'Adapted by Mary S. Brandon

From "<<ddd:#3649|Laich of Moray>>" by Leslie Cumming published in "Scottish Country Dance - Canberra 25"', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17667, '2017-03-22 14:07:44.38889+00', '2018-04-02 23:56:37.606031+00', 'Simon Fraser''s Reel', 'SIMON FRASERS REEL', 1, 32, 9999, 1, 3, 42, 50, '1973-01-01', 'Simon Fraser was a Scottish fur trader and explorer who charted much of what is now the Canadian province of British Columbia (B.C.). The dance was devised for the Vancouver Branch in 1973.', -1, '864 444 888 880', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17675, '2017-03-26 23:43:50.266073+00', '2017-12-31 02:31:58.583461+00', 'Serendipity', 'SERENDIPITY', 3, 40, NULL, 3, 5, 7, 952, NULL, 'Sole Source: two videos by "Red Thistle Dancers" on YouTube, and an e-mail naming the deviser.  Have not seen the instructions.  Eric', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (988, '1997-04-03 22:00:00+00', '2017-04-01 23:03:10.560826+00', 'Canadian Corn Rigs', 'CANADIAN CORN RIGS', 1, 32, 9999, 1, 2, 76, 145, NULL, 'This dance is substantially identical to <<ddd:Riggs of Corn>>, except that for bars 17-24,  2c is always below 1c, both down and up..



This dance is not listed in the Table of Contents of the book "Flowing Reels and Proud Poussettes", but presented "on the sly" in the introduction on page 16.  The full text follows here.





"Canadian Corn Rigs" was introduced to me over 20 years ago as Canada''s adaptation of "Corn Rigs" (Book 4 No. 12), another two couple dance with its own very catchy tune which we hardly ever hear, more''s the pity. I cannot find any written reference for "Canadian Corn Rigs" and it is certainly not listed in Napier''s Index. So here it is:



Corn Rigs, you will recall, can be re-capped thus:  "Down the back and up, figure of eight round twos, down the middle and up, poussette." 



Canadian Com Rigs  goes like this:



"1-8 The 1st couple, followed by the 2nd couple (who dance up to start) dance down behind the sidelines for four bars, and then turn and dance back to places (2nd couple lead back and remain facing out at the end of bar 8).



9-16 The Lst and 2nd couples dance a double figure of 8 across the dance, the 1st couple crossing down to begin.



17-24 The lst and 2nd couples dance down the middle and up again. The 2nd couple lead down and the 1st couple lead back.



25-32 The l st and 2nd couples dance a poussette.



Danced six times through in a three couple set, this is a real fun dance to a super tune. Try it.', 69, '88  88  88  88', 1, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (18465, '2018-07-19 16:06:13.664234+00', '2018-07-19 16:06:13.664234+00', 'With Faith you are Dancing', 'WITH FAITH YOU ARE DANCING', 3, 32, NULL, 1, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16456, '2015-06-10 10:12:39.927201+00', '2017-04-05 13:39:09.285378+00', 'Tribute to Alba', 'TRIBUTE TO ALBA', 1, 32, NULL, 1, 100, 2, 11140, '2015-01-01', 'The dance was written to celebrate the 15th anniversary of the SCD group "Alba".', 87, '0880/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8047, '1997-09-17 22:00:00+00', '2017-04-02 19:08:07.219641+00', 'First Love', 'FIRST LOVE', 3, 32, 9999, 1, 3, 42, 615, '1993-11-14', 'This dance was devised for a beginner workshop in Downey, California on November 14, 1993 and is dedicated to my first granddaughter, Valerie Kaye Love, on her seventh birthday (November 14th). (JB)', 62, '888/800/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16963, '2016-05-31 00:12:17.393242+00', '2017-10-08 23:27:58.59488+00', 'Patricia Reesby', 'PATRICIA REESBY', 3, 32, NULL, 1, 3, 42, 2682, '2015-10-17', 'Pat  Reesby is a keen dancer, writer and Johnsonville club secretary. ', 58, '888/808/882/880', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17705, '2017-04-04 21:07:32.185652+00', '2017-04-04 21:22:38.432809+00', 'Loch Maree', 'LOCH MAREE', 3, 32, NULL, 2, 3, 18, 123, NULL, 'From a Luxemburg programme for June 2017; dance was then unpublished.

', 83, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17704, '2017-04-03 17:46:52.672778+00', '2017-04-25 11:31:02.460165+00', 'Tanz mit Susanne, Ein', 'TANZ MIT SUSANNE EIN', 3, 32, NULL, 1, 3, 42, 11473, '2016-04-01', 'Dance devised by Kira Dowling with Elaine Arthur and Jenny Atton.



Both this dance and its original tune were written for Susanne Reichhardt, an enthusiastic dancer who joined our Canberra dancing community for several years.  







', 53, '800/866/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11570, '2003-11-05 23:00:00+00', '2017-04-17 00:25:34.689054+00', 'In Scottish Spirit', 'IN SCOTTISH SPIRIT', 1, 48, 9999, 1, 4, 11, 550, '2003-01-01', 'This is a demonstration dance.



Edinburgh Branch’s annual show of dancing in the Edinburgh Festival Fringe changed producer and venue in 2002, moving to Edinburgh Academy in Henderson 

Row, Edinburgh, with Peter Edwards as producer. One of Peter’s key new concepts was to have the show “in the round” with the audience on all sides, and the new venue is well suited to this, having the stage in the centre with the audience all the way round, and also having a balcony.  Thinking about the potential offered by the venue, this dance took shape.



This dance is dedicated to the dancers and musicians who have performed in the show, and to those whose support has kept everything running smoothly. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7201, '1998-01-12 23:00:00+00', '2018-07-22 16:59:31.456299+00', 'Winter Park', 'WINTER PARK', 2, 32, 9999, 1, 3, 42, 108, '1982-01-01', 'For The st. Andrews Society of Winter Park, Florida', 59, '808/808/848/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17743, '2017-05-09 17:57:30.315189+00', '2017-05-09 17:57:30.315189+00', 'Wilf''s 80 Strathspey', 'WILFS 80 STRATHSPEY', 3, 32, 9999, 3, 5, 7, 11466, '2009-10-01', 'Devised for Wilf Phoenix''s 80th birthday, October 3rd 2009', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17838, '2017-06-22 17:27:00.442381+00', '2017-06-22 17:27:00.442381+00', 'Milton''s Chain', 'MILTONS CHAIN', 2, 40, NULL, 2, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17700, '2017-04-02 08:41:37.380842+00', '2020-07-14 20:41:09.915273+00', 'Roman Holiday', 'ROMAN HOLIDAY', 2, 48, NULL, 1, 4, 1, 11164, NULL, '', 79, '8222/8888/8888/8888/8888/8002', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17681, '2017-03-31 09:12:06.761915+00', '2020-06-27 21:37:53.456635+00', 'Sackville Gardens', 'SACKVILLE GARDENS', 1, 32, 9999, 1, 3, 42, 11471, NULL, '', -1, '8240 4800 8880 8440', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17685, '2017-03-31 09:29:04.278703+00', '2020-12-26 10:56:34.375012+00', 'Trip to Glenmoor (Jig version), A', 'TRIP TO GLENMOOR JIG VERSION', 2, 32, NULL, 1, 3, 42, 872, NULL, '', 53, '888  844  866  800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17687, '2017-03-31 12:05:33.786549+00', '2020-12-28 11:08:45.033092+00', 'Wandering Dancer (Reel version), The', 'WANDERING DANCER REEL VERSION', 1, 32, NULL, 1, 3, 42, 872, NULL, '', 47, '880/822/822/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17698, '2017-04-02 08:38:55.741878+00', '2021-01-19 16:17:25.580345+00', 'Hot Cross Buns', 'HOT CROSS BUNS', 4, 96, 11, 4, 4, 3, 11164, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17702, '2017-04-02 08:43:27.176819+00', '2021-01-19 16:21:39.931237+00', 'Iron Piper, The', 'IRON PIPER', 1, 32, NULL, 1, 2, 76, 11164, NULL, '', 55, '88/61/88/84', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2675, '1997-04-03 22:00:00+00', '2021-05-07 23:14:05.898103+00', 'Greenwich Hill', 'GREENWICH HILL', 1, 32, 9999, 1, 3, 42, 129, NULL, '', 49, '800/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17706, '2017-04-06 15:55:18.344984+00', '2021-11-25 00:59:46.957688+00', 'Madame Pipeau', 'MADAME PIPEAU', 4, 80, 4, 1, 4, 2, 11299, '2017-04-03', 'For the 30th birthday of Pascaline Latour, music director of the Paris Branch and professional flutist. *Pipeau*, pronounced /pi''po/, is French for “tin whistle”.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17711, '2017-04-12 18:41:52.403573+00', '2018-04-07 23:27:36.431878+00', 'Mrs Stewart of Fish Hoek', 'MRS STEWART OF FISH HOEK', 3, 32, 9999, 2, 3, 17, 10582, '2015-01-01', 'From the Cape Town group.  This dance is dedicated to RSCDS Co-founder Mrs Ysobel Stewart who retired to Fish Hoek and in fact lived just a few houses away from where we dance.', 100, '888/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17707, '2017-04-12 13:53:09.611178+00', '2017-04-12 13:55:06.899093+00', 'Flype the Socks', 'FLYPE THE SOCKS', 1, 32, NULL, 1, 4, 1, 11477, '2012-08-01', 'Note: The first 16 bars of the dance represent the argyll pattern on a long sock. The diagonal

crosses draw the single line and the double triangles setting outlines the blocks of color. The two

circles represent the openings at the top of the socks.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17708, '2017-04-12 13:57:39.975431+00', '2017-04-12 20:49:17.327908+00', 'Chocolate Upside Down Cake', 'CHOCOLATE UPSIDE DOWN CAKE', 1, 32, NULL, 1, 3, 42, 11200, '2012-08-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17709, '2017-04-12 14:03:12.440148+00', '2017-04-12 20:50:25.41005+00', 'Butterscotch Kilt', 'BUTTERSCOTCH KILT', 3, 32, NULL, 1, 3, 42, 11133, '2012-08-01', 'Note: This dance is written in honor of Alan Twhigg''s beautiful dress kilt.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17137, '2016-07-11 16:01:06.717458+00', '2018-10-14 13:54:28.147281+00', 'Doonhamer Delight, The', 'DOONHAMER DELIGHT', 1, 32, NULL, 5, 2, 76, 11301, '2014-11-01', 'The title celebrates the deviser’s home town, Dumfries, where locals are referred to as Doonhamers.

', 100, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17712, '2017-04-12 20:25:03.253948+00', '2017-04-12 20:52:23.151566+00', 'Down the Elevator and Up', 'DOWN THE ELEVATOR AND UP', 4, 32, 12, 2, 3, 17, 11478, '2012-08-01', 'Note: The strathspey time describes waiting for the slow elevator in the dorm building. The reel

time describes the faster, but much more talkative, elevator in the Recreation Center', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17713, '2017-04-12 20:30:02.658547+00', '2017-04-12 20:52:51.233209+00', 'Duck has Quacked, The', 'DUCK HAS QUACKED', 1, 40, NULL, 1, 3, 42, 11479, '2012-08-01', 'Note: In honor of Alan Twhigg’s cell phone that ”quacked” at us if we went over our time when

practicing for the Unit 3 exam.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17714, '2017-04-12 20:32:44.588017+00', '2017-04-12 20:53:32.571027+00', 'Twenty-seventh of July, The', 'TWENTYSEVENTH OF JULY', 3, 32, NULL, 2, 3, NULL, 1167, '2012-07-27', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17384, '2016-09-18 22:47:55.248858+00', '2018-08-01 13:08:18.323165+00', 'Sleepless Night', 'SLEEPLESS NIGHT', 4, 32, 1, 1, 100, 2, 3445, NULL, 'Suggested recording: Strathspey and Reel Medley by the Music Makars on Jig for Joy CD:  <<http://my.strathspey.org/dd/recording/1667/ | http://my.strathspey.org/dd/recording/1667/>>', 81, '8888/8008/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8778, '2002-03-26 23:00:00+00', '2017-04-16 00:27:15.215035+00', 'Corsair Field', 'CORSAIR FIELD', 1, 128, 9999, 4, 119, 3, 50, '1999-01-01', 'This is a demonstration dance of three 32 bar figures and two 16-bar figures, all danced once through,  The square set is formed by four trios WMW.  



This dance was first performed by the Demonstration Team of the Los Angeles, Branch, RSCDS, at the annual United Scottish Society''s Highland Games at Corsair Field, Santa Monica, California, June 1969.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17710, '2017-04-12 14:08:32.103452+00', '2018-10-14 00:25:41.597631+00', 'Flyper and the Penguin, The', 'FLYPER AND THE PENGUIN', 1, 32, NULL, 4, 4, 13, 11133, '2012-08-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8676, '2000-04-25 22:00:00+00', '2017-04-21 01:12:20.538531+00', 'Hamish Henderson''s Refusal', 'HAMISH HENDERSONS REFUSAL', 3, 32, 9999, 1, 2, 76, 1393, NULL, 'Hamish Henderson 1919 - 2002 A poet, songwriter and leader of the Scottish folk revival.



James (Hamish) Scott Henderson was born on 11 November, 1919, in Blairgowrie to a single mother who introduced him to folksong and brought him up to speak Gaelic.



In 1951 he accompanied the American folklorist Alan Lomax on a collecting tour in Scotland, recording and preserving the folk songs of Scotland''s gipsies, fishermen, farm labourers and factory hands, which can be regarded as the beginning of an upsurge of interest in Scottish folk material and tradition.  Parallel to Henderson’s research ran his close involvement with the folk revival in Scotland, beginning with the Edinburgh People’s Festivals in the early 1950s.



Henderson held several honorary degrees and after his retirement became an honorary fellow of the School of Scottish Studies. In 1983 he refused an OBE in protest against the nuclear arms policy of the Thatcher government. He died in Edinburgh on 8 March 2002', 60, '66/66/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10624, '2002-07-01 22:00:00+00', '2017-04-21 21:21:20.023855+00', 'Swirls of the Wiske, The', 'SWIRLS OF THE WISKE', 4, 288, 59, 2, 3, 18, 3153, '2002-05-01', 'Devised: 2002-05

Published on page 6 of The Leeds Branch Newsletter, Issue 29, Feb 2003 (<<http://www.rscdsleeds.org.uk/newsletters.html|http://www.rscdsleeds.org.uk/newsletters.html>>)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14597, '2012-11-02 08:44:18.422494+00', '2018-01-13 15:06:02.465367+00', 'Red Wine and Straight Lines', 'RED WINE AND STRAIGHT LINES', 4, 96, 21, 2, 3, 17, 952, '2012-02-01', 'The original version started with “set, petronella”.  That is how Fred DeMarse taught it in the Rechberg workshop Autumn 2012, as shown in the video recorded there.  Jennifer Kelly later changed bars 1-4 into “petronella turn into the center, then set”. That is the final form.  



Devised 2012-02 for Fred De Marse, to celebrate a significant Birthday, with all good wishes for many more.



According to Fred De Marse the preferred music for the dance is a medley as specified in the database.', 77, '808/666/888/484', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18343, '2018-05-21 08:52:17.306015+00', '2019-10-05 05:57:15.978972+00', 'Marjorie Crawford''s Hornpipe', 'MARJORIE CRAWFORDS HORNPIPE', 6, 32, NULL, 1, 3, 42, 2682, '2018-05-15', 'Devised 15 May 2018. Marjorie was my first tutor back in the 1990''s, and taught me a great deal when I was becoming a tutor, particularly how to really listen to the music as a teacher. She had a great sense of humour and an inpenetrable Glaswegian accent. Sadly she passed away in 2017. Recommended tune is "The Ton" by James Aird played ABAB which is a traditional tune used for "Jessie''s Hornpipe" and any good recording of this would be appropriate. I used the one by Stan Hamilton and his Flying Scotsmen, and the one by Jim Macleod is also excellent. I hope she might have enjoyed this dance.', 56, '888/800/866/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17749, '2017-05-11 07:00:30.07862+00', '2017-05-11 07:00:30.07862+00', 'Cold Ice', 'COLD ICE', 3, 32, NULL, 1, 2, 76, 11348, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17738, '2017-05-09 13:28:20.288971+00', '2017-05-09 13:28:20.288971+00', 'Diamond Plus', 'DIAMOND PLUS', 3, 32, 9999, 2, 3, 17, 11466, '2017-02-01', 'Written to mark the 64th Wedding Anniversary of Muriel & Wilf Phoenix 7th Feb 2017', -1, '8888 8448 0448', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17697, '2017-04-02 08:36:45.284179+00', '2022-10-15 14:14:24.416634+00', 'April Snow on Mull', 'APRIL SNOW ON MULL', 1, 40, NULL, 1, 3, 42, 10961, NULL, '', 56, '888/550/844/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17726, '2017-04-30 10:13:26.260988+00', '2021-02-20 13:37:45.607685+00', 'Sutherland''s Laddie', 'SUTHERLANDS LADDIE', 2, 24, NULL, 1, 3, 42, 3325, '1973-12-01', 'Devised to assist in teaching the Children''s Class of the Berkhamsted Strathspey and Reel Club by using only the skip change of step and named in dedication of Douglas Sutherland, Stephen’s class teacher from 1969-1972 at the Thursday Nighters SCD Club in Pietermaritzburg in South Africa.', 67, '800/808/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (604, '1997-08-25 22:00:00+00', '2017-04-21 23:04:27.140539+00', 'Bob Campbell', 'BOB CAMPBELL', 3, 32, 9999, 1, 3, 42, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Bob Campbell of Oakville, Ontario.', 64, '888  888  882  844', 0, 1, 1, 0, 85);
INSERT INTO 'dance' VALUES (14636, '2012-12-31 16:33:14.492112+00', '2017-04-22 19:51:59.789028+00', 'Perth meets Perth', 'PERTH MEETS PERTH', 1, 32, 9999, 1, 4, 1, 10689, NULL, 'The Perth & Perthshire Branch Newsletter "The Highland Gateway" for January 2011 has the following text:



"From locally here in Perth, Scotland, the links spread internationally to Perth, Western Australia where the RSCDS Branch was asked to contribute a reel and a strathspey in honour of the Perth 800 anniversary. The dances “The Swan and the Tay” (which represents the two city rivers) and “Perth meets Perth” (representing dancers crossing the world to join together in the dance) were submitted. Appropriately their tunes “Mo Rutherford’s compliments to Frank Thomson” and Jim Johnston’s “The Carse of Gowrie” were arranged by Mo Rutherford, former RCDS Musical Director, and of course one of Perth‘s best known musicians."



So this dance comes from Perth (Australia), but was published in Scotland in the RSCDS booklet "Perth 800".

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6259, '2002-04-29 22:00:00+00', '2018-06-27 11:29:23.855943+00', 'Spring In Helensburgh', 'SPRING IN HELENSBURGH', 1, 40, 9999, 1, 3, 42, 74, '1991-04-01', 'The recommended music was changed from "Welcome to Witney" to "Captain Mackintosh", as recorded for the Miscellanies by Muriel Johnstone, as it is better music and more readily available.

The dance was written for the Spring Social, held in the first week in September each year, by the Helensburgh Club, Helensburgh is the most northerly suburb of Wollongong, NSW.  



Notes: The movement "Dance to Corners and Set" is danced as described in the Courage Reel

by John Drewry in the Canadian Book of dances.  



Devised by Brian Charlton in April, 1991 and first danced at the Helensburgh Scottish Country

Dancing Club Spring Social, September, 1991. Helensburgh is the most northerly suburb of

Wollongong, NSW, Australia.', 65, '800/888/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18466, '2018-07-25 22:29:07.621659+00', '2018-07-25 22:29:07.621659+00', 'Another Road to the Isles', 'ANOTHER ROAD TO THE ISLES', 3, 32, NULL, 4, 4, 1, 2886, NULL, '', 87, '8484/4848/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18467, '2018-07-25 22:34:05.350794+00', '2018-07-25 22:34:05.350794+00', 'Celtic Stones', 'CELTIC STONES', 1, 32, NULL, 1, 4, 1, 2886, NULL, '', 71, '8000/8444/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18469, '2018-07-25 22:46:07.675438+00', '2018-09-25 20:28:39.705377+00', 'Just a Jolly Jig', 'JUST A JOLLY JIG', 2, 32, NULL, 2, 3, 17, 2886, NULL, '', 66, '800/888/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17719, '2017-04-30 09:30:54.025595+00', '2018-04-02 23:56:33.715394+00', 'Dancers'' Delight', 'DANCERS DELIGHT', 2, 32, NULL, 1, 3, 42, 3325, '2013-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17841, '2017-06-22 17:32:06.70088+00', '2018-04-03 00:07:59.106243+00', 'Laurel Downey''s Pleasure', 'LAUREL DOWNEYS PLEASURE', 3, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2813, '1998-11-14 23:00:00+00', '2021-04-08 10:41:44.083381+00', 'Haunt Of The Gnomes, The', 'HAUNT OF THE GNOMES', 3, 64, 9999, 4, 4, 46, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Robert MacKay of Edinburgh who introduced John Drewry to J. Scott Skinner''s tune *The Haunt of the Gnomes* at St. Andrews in July 1977.



Furthermore:



*The dance may be repeated with the side couples leading :-

The first reels of three will be up and down the dance (Bars 17-24).

The second reels of three will be across the dance (Bars 25-32).

The straight lines (Bar 25 onwards) will be across the dance.*



and



*The dance provides a good test of memory and of orientation when done twice without stopping!*', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4268, '1998-01-05 23:00:00+00', '2021-05-09 10:12:46.087667+00', 'McKeown''s Hornpipe', 'MACKEOWNS HORNPIPE', 1, 40, 9999, 1, 3, 42, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Stuart McKeown of Milngarvie.



This dance came to John Drewry while he listened to Stuart''s playing.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2169, '1998-07-08 22:00:00+00', '2021-06-08 10:45:03.004454+00', 'Findhorn In Flood', 'FINDHORN IN FLOOD', 1, 48, 9999, 1, 100, 2, 108, '1976-01-01', 'John Drewry wrote in the original description that the dance was for Simon Fraser of Nairn.



Furthermore, he notes:

*At Randolph''s Leap near the confluence of the Findhorn and Divie there are two stones marking the record height of the waters during the great floods of 1829. Simon''s father was born at Dounduff about half a mile north-east of Randolph''s Leap.*', 75, '0880/8668/8228/8448/8448/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17740, '2017-05-09 16:13:06.810547+00', '2018-04-02 23:56:37.113345+00', 'Queen''s Jig', 'QUEENS JIG', 2, 32, 9999, 1, 3, 42, 11466, '2015-04-01', 'Devised April 2015 after one of the many enjoyable weekends at the Queen''s Hotel Llandudno, organised by Brian Eckersley.



The dance consists of ''bits'' borrowed from Postie''s Jig, Seton''s Ceilidh Band, The Cooper''s Wife and The Kenora Reel.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17429, '2016-10-30 11:29:00.373766+00', '2017-05-07 07:04:59.505044+00', 'Anne and Friends', 'ANNE AND FRIENDS', 3, 32, NULL, 1, 3, 42, 433, '2003-01-01', 'In memory of Anne Anderson, Dalbeattie', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17857, '2017-06-23 07:57:28.359505+00', '2017-06-23 07:57:28.359505+00', 'Pack ''n Run', 'PACK N RUN', 1, 32, NULL, 2, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3433, '1997-08-25 22:00:00+00', '2023-01-10 11:38:30.972851+00', 'Kenavarra', 'KENAVARRA', 2, 48, 9999, 1, 110, 42, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Mary Stoker, and about the title:



*Kenavarra (Gaelic "Ceanna '' Bharra") is a headland at the west end of Balephuill Bay on the south coast of Tiree, where Mary has a holiday home.*



', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1852, '1998-07-09 22:00:00+00', '2023-02-09 18:27:18.170096+00', 'Dunnottar Castle', 'DUNNOTTAR CASTLE', 3, 32, 9999, 2, 3, 17, 108, '1977-01-01', 'John Drewry noted in the original description:



*Dunnottar Castle stands on a rocky headland overlooking the North Sea

just south of Stonehaven. During the Commonwealth Wars the Scottish

regalia was kept in this castle and when the castle was besieged the

regalia was smuggled out and kept at Kinneff, a village to the south

of the castle.*', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1261, '1997-08-25 22:00:00+00', '2023-02-17 13:01:15.63385+00', 'Cock o'' the North, The', 'COCK O THE NORTH', 2, 32, 9999, 1, 2, 76, 108, '1977-01-01', 'John Drewry noted in the original description:



*"The Cock O'' the North" was a title applied to the Marquis of Huntly, the chief of Clan Gordon, because of his powerful role in the North-East of Scotland.*



*The tune is pre-eminently the Gordon pipe tune, and is now the Barch Past of the Gordon Highlanders.*', 69, '88  88  88  88', 1, 1, 0, 1, 100);
INSERT INTO 'dance' VALUES (17335, '2016-09-14 04:30:23.918819+00', '2017-04-27 11:26:24.551116+00', 'Missed Third, The', 'MISSED THIRD', 1, 32, NULL, 1, 3, 18, 2701, '2015-07-22', 'The dance was conceived on July 4, 2015 in the Auckland, New Zealand airport while en route to the 40th Australian Winter School being held in Brisbane. My plane left San Francisco on July 2nd and arrived in Auckland, twelve hours later, on July 4th.



With its 312 progression, the dance can also be done as a 3x or a 6x. My preference is as an 8x with both 1st and 2nd couples repeating thier roles before 1st couple step down to fourth place.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17716, '2017-04-25 20:09:34.537419+00', '2018-04-26 22:42:56.574264+00', 'Bicycle Made For Two, A', 'BICYCLE MADE FOR TWO', 2, 40, NULL, 3, 5, 7, 10495, '2016-08-16', 'This dance was written to celebrate the wedding of Kirsten Ferguson and Liz Jones on 20 August 2016.  The dance includes a ‘double spoke’ movement to recognise the fun of their tandem adventures!  Ideally, the dance is danced to an up-tempo version of the song “Daisy, Daisy…”.', 62, '80800/84884/80800/80822/88888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17840, '2017-06-22 17:28:12.62336+00', '2018-04-03 00:08:18.012095+00', 'Spinnie, The', 'SPINNIE', 1, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17725, '2017-04-30 10:10:16.773989+00', '2017-04-30 10:10:16.773989+00', 'Jig for Umbrellas and Gumboots, A', 'JIG FOR UMBRELLAS AND GUMBOOTS', 2, 32, NULL, 1, 4, 1, 3325, '1980-01-01', 'All dancers wear Wellington boots and carry an umbrella.

Devised for Berkhamsted SRC as a ceilidh turn at a club evening in the 1980s.



Notes:

1. Dancers responsible for their own umbrellas except at allemande.

2. Keep dancers well spaced in the set.

3. Dancers should think ahead as to which hand is to be free and put umbrella in other hand.

4. Unless otherwise noted hold umbrella in left hand throughout.

5. In rights and lefts and turning right hand and then left change umbrella from left to right and back again at end of the appropriate even bar.

6. The scene is a dem team about to dance and then thunder is heard, lightning is seen followed by the inevitable rain, imagined. Determined still to put on the show the team leave the stage and return wearing Wellingtons and carrying umbrellas.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17717, '2017-04-28 22:58:54.360394+00', '2017-04-29 22:02:51.939956+00', 'Maplewood Knot, The', 'MAPLEWOOD KNOT', 1, 32, NULL, 1, 3, 42, 2973, '2016-10-08', 'For Keira and Marc.



Note: Experienced dancers are invited to discover additional opportunities to pivot (twiddle) beyond those written into the dance.



Recommended Music: A driving reel', 69, '888/866/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16499, '2015-07-20 16:22:02.049678+00', '2017-05-10 11:03:11.810476+00', 'Winter Garden, The', 'WINTER GARDEN', 3, 32, 9999, 1, 3, 42, 11159, '2015-01-01', '', 47, '800/822/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18470, '2018-07-25 22:52:23.122567+00', '2018-09-25 20:36:11.585557+00', 'Menai Strait Hornpipe, The', 'MENAI STRAIT HORNPIPE', 1, 32, NULL, 2, 3, 17, 2886, NULL, '', 75, '800/888/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18344, '2018-05-21 08:59:17.723486+00', '2018-05-21 08:59:26.874693+00', 'Lost Legion, The', 'LOST LEGION', 3, 32, NULL, 1, 4, 2, 2682, '2018-04-23', 'Devised 23/4/2018. Revised 1/5/2018. Xiaowen Yu contacted me and told me that they had danced the next dance "My Golden Bear" as a strathspey with a New York group, and it worked well. This got me thinking, and the above is the result. The corners pass and turn in tandem movement is from "The Golden Bear". Charlotte Williams suggested I write a dance called the lost legion, which, according to at least one legend, *Legio IX Hispana* marched into second century Scotland (from York) and were never seen again. Suggested music is "The Scottish Snap" by J. Murdoch Henderson and an excellent recording is Strathspey (track 3) of "On Track" by the Sound Company. A reasonable alternative is "Miss Macpherson of Scone" as recorded by James Coutts and his band, or if you are lucky enough to have it "Green Grow the Rashes" as recorded by Alasdair Downie (or even James Cameron if you like the Coronet).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17727, '2017-05-03 07:53:11.476673+00', '2017-05-03 07:53:11.476673+00', 'Fiona''s Reel', 'FIONAS REEL', 1, 48, 9999, 3, 5, 7, 854, '2017-04-01', 'Devised by Duncan Brown for Fiona Brunk, one of his fellow teachers at the RSCDS Spring Fling in Bonn, April 2017.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18488, '2018-08-02 11:52:21.713659+00', '2020-02-27 11:48:06.700934+00', 'Jacaranda Tree, The', 'JACARANDA TREE', 2, 40, NULL, 1, 3, 42, 872, '2013-01-01', '', 61, '880/468/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2780, '1997-08-25 22:00:00+00', '2020-05-26 20:24:23.132546+00', 'Happy Potter, The', 'HAPPY POTTER', 1, 32, 9999, 1, 2, 76, 108, '1976-01-01', 'John Drewry wrote in the original description that the dance was for Muriel Macintyre of Nairn Ceramics.', 60, '88/80/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17474, '2016-11-06 17:37:04.52211+00', '2020-10-31 11:48:06.519159+00', 'Toyshop of Europe, The', 'TOYSHOP OF EUROPE', 1, 32, NULL, 1, 4, 11, 1275, NULL, '', 94, '8888/8888/8888/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17722, '2017-04-30 09:59:55.839953+00', '2021-02-19 16:49:42.774473+00', 'Heezing the Bana', 'HEEZING THE BANA', 3, 32, NULL, 2, 3, 17, 3325, '2010-11-30', 'Devised for 30th November 2010 to celebrate St Andrew''s Day with patterns that trace the outline of the flag of Scotland. (To heeze is to hoist).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17723, '2017-04-30 10:01:38.227508+00', '2021-02-21 11:21:52.61652+00', 'Ceilidh Jig, The', 'CEILIDH JIG', 2, 48, NULL, 2, 3, 18, 3325, '1982-03-01', '', 75, '888/848/888/888/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14335, '2011-12-08 23:00:00+00', '2021-06-06 21:29:34.405466+00', 'Granville Bridge', 'GRANVILLE BRIDGE', 1, 32, 9999, 1, 3, 42, 10573, '2008-05-13', 'This dance was inspired by a visit to Vancouver, and the experience of walking from downtown Vancouver to Granville Island. The Granville Bridge appears on maps to go to the island, but in fact goes OVER the island. To walk to the island from downtown, it is necessary to walk past the island to the far shore before doubling back (represented by the first eight bars). The middle sixteen bars represent the bridge itself, and the last eight bars represent the hustle and bustle of the Granville Public Market.', 44, '800/844/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17729, '2017-05-06 14:03:25.686386+00', '2017-05-06 14:13:17.795025+00', 'Teacher Tom', 'TEACHER TOM', 1, 32, NULL, 2, 2, 76, 11348, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17736, '2017-05-09 08:43:19.254143+00', '2019-01-26 07:00:36.892439+00', 'Trip to Tabiano, A', 'TRIP TO TABIANO', 3, 32, NULL, 2, 3, 17, 3698, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17649, '2017-03-12 23:46:03.169318+00', '2019-05-01 08:53:48.583608+00', 'Eighty Not Out', 'EIGHTY NOT OUT', 4, 128, 13, 4, 4, 13, 11466, '2008-01-01', 'Devised for Alan Dunn''s 80th birthday May 2008



Recommended music  "Johnny Walker"', -1, '8080 0808 8888 8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18471, '2018-07-25 22:59:11.675653+00', '2019-09-30 18:25:50.628173+00', 'Butterscotch & Honey Squares', 'BUTTERSCOTCH AND HONEY SQUARES', 3, 32, NULL, 4, 4, 1, 2886, NULL, '', 62, '8080/0808/4444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17651, '2017-03-12 23:48:56.597235+00', '2017-05-09 15:43:47.857052+00', 'Muriel''s Strathspey', 'MURIELS STRATHSPEY', 3, 32, 9999, 4, 5, 41, 11466, '2011-11-01', 'Devised November 2011 to celebrate Muriel Phoenix''s 80th birthday.', -1, '44448 44448 04048 44486', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17655, '2017-03-12 23:54:30.405157+00', '2017-05-09 16:00:25.554823+00', 'Phoenix Strathspey, The', 'PHOENIX STRATHSPEY', 3, 32, 9999, 2, 3, 18, 11466, '2013-02-01', '60 ... At each end of the set, 

bars 9-12 trace out the number 6 - though written from the bottom And

bars 13 - 16 the zero.



Written for the 60th Wedding Anniversary of Muriel & Wilf Phoenix, 7th Feb 2013', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17850, '2017-06-23 07:52:59.788989+00', '2017-06-23 07:52:59.788989+00', 'Takapuna Reel, The', 'TAKAPUNA REEL', 2, 32, NULL, 2, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17739, '2017-05-09 14:39:53.509264+00', '2018-04-02 23:56:35.360255+00', 'Isobel''s Welcome', 'ISOBELS WELCOME', 1, 32, 9999, 1, 3, 42, 9998, '1998-08-01', 'Devised for the late Isobel Watts to celebrate her 50th birthday, 14th August 1998', -1, '800 880 822 822', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17737, '2017-05-09 12:54:07.129672+00', '2017-12-06 12:37:38.906622+00', 'Betty''s Strathspey', 'BETTYS STRATHSPEY', 3, 32, 9999, 3, 5, 7, 11466, '2010-11-09', '', -1, '0848 8884 0888 8888 0844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17741, '2017-05-09 16:55:28.780359+00', '2017-12-20 23:26:25.369391+00', 'Thank You Bob', 'THANK YOU BOB', 3, 32, 9999, 1, 100, 2, 11466, '2006-03-01', 'Devised by Jim Haworth, March 2006

To mark the occasion of the retirement of Bob Brown as Dance Director of ASGMERG Scottish Country Dance Group', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17757, '2017-05-21 09:12:59.896742+00', '2018-12-22 23:31:28.400456+00', 'Kyle Castle', 'KYLE CASTLE', 3, 32, NULL, 1, 4, 2, 11237, '2017-05-01', 'For Roy Southall whose Scottish ancestors lived in Ayrshire near Kyle Castle.', 94, '8888 4884 8888 8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17844, '2017-06-22 17:46:06.968739+00', '2018-04-03 00:07:31.153548+00', 'Arita Strathspey, The', 'ARITA STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17847, '2017-06-22 17:47:27.528393+00', '2018-12-09 13:47:15.627011+00', 'Fifty Years and Counting', 'FIFTY YEARS AND COUNTING', 1, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18472, '2018-07-26 08:14:34.313388+00', '2018-07-26 08:14:34.313388+00', 'Noughts and Crosses', 'NOUGHTS AND CROSSES', 2, 32, NULL, 8, 6, 83, 2886, NULL, '', 58, '888888/888888/800000/080000', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17748, '2017-05-10 22:53:41.205663+00', '2019-12-31 13:51:51.768613+00', 'Higham Hogmanay', 'HIGHAM HOGMANAY', 1, 32, 9999, 1, 3, 42, 11575, '2016-12-01', '''Devised by Annie Park with help from Susan Casson, Roger Cooper, Jenny Evans, Irene Roberts and Higham Hall, Cumbria, December 2016.''', 83, '844/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18958, '2018-10-13 20:09:59.825159+00', '2020-02-09 19:26:35.169196+00', 'Marion 70 Years Young', 'MARION 70 YEARS YOUNG', 3, 32, NULL, 1, 100, 11, 9998, NULL, '', 100, '8888/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17732, '2017-05-06 23:57:45.710731+00', '2020-09-01 15:27:11.515351+00', 'Park in the Sky, The', 'PARK IN THE SKY', 1, 32, NULL, 1, 3, 42, 11362, NULL, '', 66, '880/866/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17650, '2017-03-12 23:47:24.879655+00', '2020-11-07 21:12:41.519164+00', 'Emma & Danielle''s Jig', 'EMMA AND DANIELLES JIG', 2, 32, 9999, 1, 100, 2, 11466, '2010-12-01', 'Devised for Jim''s granddaughter Emma and her friend Danielle, granddaughter of the late Isobelle Watts, to be used at their children''s class in Sale. (Parents and grandparents should also feel free to dance it!)', 84, '8228 8888 8448 8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17730, '2017-05-06 23:54:48.603065+00', '2020-11-08 11:06:53.138006+00', 'G&T Time in Forest Hills', 'GANDT TIME IN FOREST HILLS', 2, 32, NULL, 1, 3, 42, 11480, NULL, '', 56, '800/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17731, '2017-05-06 23:56:34.202294+00', '2020-11-08 11:27:21.513519+00', 'Marble Walk, The', 'MARBLE WALK', 3, 32, NULL, 1, 3, 42, 11480, NULL, '', 59, '880/822/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17733, '2017-05-06 23:59:38.310756+00', '2020-11-08 11:31:21.141248+00', 'Reeling Round The Strand', 'REELING ROUND THE STRAND', 2, 32, NULL, 1, 3, 42, 11362, NULL, '', 63, '844/888/808/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17734, '2017-05-07 00:01:09.767911+00', '2020-11-08 11:35:06.531152+00', 'Chelsea Square', 'CHELSEA SQUARE', 3, 32, NULL, 1, 3, 42, 11480, NULL, '', 69, '844/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17735, '2017-05-07 00:02:03.311934+00', '2020-11-08 11:38:42.004973+00', 'High Over The Hudson', 'HIGH OVER THE HUDSON', 1, 32, NULL, 1, 3, 42, 11480, NULL, '', 56, '822/866/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11203, '2003-02-16 23:00:00+00', '2021-02-21 11:30:41.000197+00', 'Wedding Celebration', 'WEDDING CELEBRATION', 1, 32, 9999, 1, 3, 42, 3325, '1992-06-01', 'This dance symbolises a blossoming romance (represented by the 1st couple) through seeing each other, being introduced, experiencing a first touch, meeting each other; then to the engagement and finally the wedding.  

The dance, Wedding Celebration, formerly called Mr & Mrs Munro, was devised to commemorate the wedding of Rhona MacGregor and Robert Munro on 20th June 1992, when it was first performed. Rhona is the daughter of Bobby and Flora MacGregor, both of whom are past-presidents of Berkhamsted Strathspey and Reel Club.  

This dance is published in BSRC Golden Jubilee Book of Dances 2002 as Mr & Mrs Munro

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17751, '2017-05-14 00:20:05.23261+00', '2017-05-14 00:34:46.312817+00', 'Dominique''s Reel', 'DOMINIQUES REEL', 1, 40, NULL, 1, 4, 11, 11181, '2017-05-14', 'Suggested music: Forty-five Years On (Keith Smith & James Gray)', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17755, '2017-05-21 09:04:34.038162+00', '2019-01-18 19:18:08.891087+00', 'Evening Primrose', 'EVENING PRIMROSE', 2, 32, NULL, 1, 4, 1, 11237, '2017-04-01', 'For Hester Wallington and her boat full of guinea pigs.', 81, '8888 8888 8484 8080', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17851, '2017-06-23 07:54:23.095602+00', '2018-04-03 00:07:48.306141+00', 'Gin Strawberries', 'GIN STRAWBERRIES', 1, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17828, '2017-06-22 17:12:09.153285+00', '2017-06-22 17:12:09.153285+00', 'Hosken Hospitality', 'HOSKEN HOSPITALITY', 3, 32, NULL, 1, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17842, '2017-06-22 17:45:07.601411+00', '2017-06-22 17:45:07.601411+00', 'Jaunty Jean''s Reel', 'JAUNTY JEANS REEL', 1, 32, NULL, 3, 5, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17752, '2017-05-18 14:33:01.03279+00', '2018-09-19 09:50:03.262594+00', 'Summer Can''t Be Far Away', 'SUMMER CANT BE FAR AWAY', 3, 32, 9999, 1, 3, 42, 17, '2017-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17759, '2017-05-21 09:37:03.413967+00', '2019-01-18 19:37:08.087295+00', 'Treasure Of Kennington, The', 'TREASURE OF KENNINGTON', 1, 32, NULL, 1, 100, 2, 11237, '2017-01-01', 'For Richard Clarke: the busy bee of the London Gay Gordons.', 87, '8008/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17745, '2017-05-10 22:42:44.629975+00', '2019-03-03 21:50:36.103192+00', 'Celebration at Higham', 'CELEBRATION AT HIGHAM', 3, 32, 9999, 1, 3, 42, 852, '2016-12-01', '''Devised by Robert Smith with help from Geoff Entwistle, Diane Rooney, Lorna Harmsworth, Ron and Shauna Currie at Higham Hall, Cumbria, December 2016.''

', 50, '880/844/844/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17764, '2017-05-27 16:32:25.538412+00', '2017-05-27 16:34:32.53729+00', 'Dance for Des, A', 'DANCE FOR DES', 1, 32, NULL, 1, 3, 42, 10788, '2013-08-01', 'In honor of Desiree Stuart-Alexander, Santa Cruz Class, RSCDS - San Francisco

  ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17630, '2017-03-04 22:54:37.490125+00', '2019-03-23 00:36:28.463827+00', 'Dance For Helen Lobb, A', 'DANCE FOR HELEN LOBB', 4, 32, 10034, 1, 100, 2, 793, '2017-08-16', 'In February 2018, the deviser, Steve Goulden, asked the crib and diagram authors on SCDDB: "Could you change the format of this dance to Sx2/Rx2?  That way each couple gets to dance each rhythm.".



The original description uses the name "A Dance for Helen".  It is not clear when and why the second name was adopted.  ', 87, '8888/8008/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17881, '2017-06-28 12:37:44.791189+00', '2017-07-13 22:49:37.776078+00', 'An T-Uibhisteach Tapaidh', 'TUIBHISTEACH TAPAIDH', 2, 40, NULL, 1, 3, 42, 3345, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17750, '2017-05-13 18:59:37.689447+00', '2020-06-03 22:24:03.182955+00', 'Grand Old Duke, The', 'GRAND OLD DUKE', 2, 32, NULL, 1, 3, 42, 2973, NULL, 'Suitable for dancing as a reel, jig, or as a strathspey. ', 50, '800/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17747, '2017-05-10 22:52:43.117734+00', '2020-08-14 16:37:28.380916+00', 'Higham Silver Celebration, The', 'HIGHAM SILVER CELEBRATION', 2, 32, 9999, 1, 3, 42, 11574, '2016-12-01', 'Devised by Keith Evans with help from Helen Summerson, Margaret Davidson, Elizabeth Scott, Susan Madigan and Monica Sutcliffe at Higham Hall, Cumbria, December 2016.', 69, '820/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17753, '2017-05-21 08:46:56.302907+00', '2023-01-14 12:29:29.410215+00', 'Alfie''s Team', 'ALFIES TEAM', 1, 32, NULL, 1, 3, 42, 11237, '2017-04-01', 'For Alfie Ferguson: a light hearted celebration of football.', 42, '610 844 448 484', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17756, '2017-05-21 09:07:32.856966+00', '2023-01-14 15:31:34.726281+00', 'Jonathan''s Wheels', 'JONATHANS WHEELS', 3, 32, NULL, 1, 100, 2, 11237, '2017-01-01', 'For Jonathan Lewis: a dance with various two wheeled figures.', 100, '8888 8888 8888 8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18346, '2018-05-21 23:38:03.560838+00', '2021-04-12 11:39:44.733541+00', 'Trip to York, A', 'TRIP TO YORK', 1, 32, 9999, 1, 100, 2, 2682, '2017-05-24', 'Notes by the deviser:



Devised 22nd May and 19th May 2017. Revised 24th May, 2017. 



This is a present to the York group for "Downey Day of Dance". 

On the day, bars 16-24 were a chain progression and Malcolm Brown suggested the targe movement.

There was still a slight problem which I tweaked on 24th may. 



Recommended music is "Hon Mrs Fraser" by Robert Mackintosh, played ABAB. 

This is the lead tune for "The Auld Alliance" and a suitable recording is by Gordon Shand in Music for Book 23.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17763, '2017-05-27 16:18:17.497953+00', '2021-09-23 20:47:22.548728+00', 'Barefoot Lad, The', 'BAREFOOT LAD', 1, 32, NULL, 1, 3, 42, 11486, '2012-02-01', 'This dance is dedicated to Brian Tailleur, a long time member of the San Francisco branch, who passed on February 7th, 2012.  He is known for dancing barefoot and for his free spirit.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17765, '2017-05-27 16:39:02.237655+00', '2021-09-23 20:52:03.686342+00', 'Susie''s Latest Promotion', 'SUSIES LATEST PROMOTION', 1, 40, NULL, 1, 3, 42, 2701, '2016-01-01', 'Note:

Presented to Susie Langdon Kass on the occasion of her 80th birthday, May 14, 2016. The first figure is a progression that Susie particularly enjoys and has used in dances of her own devising. Wild Geese is one of her favorite dances. The final 16 bars with its reel of 3 and circle could be considered a nod to “80.”  The title is an acknowledgment of the decades of volunteer time Susie has donated to promoting Scottish country dance.  TW



Music:

“An Active Octogenarian” by Patti Cobb. “I wrote this tune to complement Tim’s dance. When discussing the particulars of a dance to mark 

this occasion, Susie asserted, ‘Just because I’m turning 80 doesn’t mean it has to be a strathspey!’  Hence the bouncy, jaunty feel and the title.” — PC', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17762, '2017-05-27 16:06:54.967305+00', '2021-09-23 20:55:10.219047+00', 'Something Blue', 'SOMETHING BLUE', 3, 32, NULL, 2, 3, NULL, 214, '2014-01-01', 'Written for Kim Jorgensen & Kathy Wendell''s nuptials.



The first six bars represent something old (setting on the sidelines), something new (petronella in tandem, a relatively new figure), and something borrowed (from The Rose Garden).



Copyright 2014 by Russ King. All rights reserved. Permission is granted for verbatim reproduction and nonprofit distribution of this leaflet provided that this notice remains intact.

______________

Traditionally, every San Francisco Class Solstice Party program includes a dance devised by or for a class member. Russ King has been a regular dancer in our class for many years and has contributed many dances for our Solstice Parties.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17767, '2017-05-27 22:37:26.30291+00', '2018-04-02 23:56:35.401914+00', 'Jan of Hearts', 'JAN OF HEARTS', 1, 32, NULL, 1, 3, 42, 11151, '2016-01-01', 'This may be danced as a reel, a jig or a strathspey.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10468, '2002-04-12 22:00:00+00', '2018-04-03 00:07:59.556789+00', 'Lilo''s Birthday Fancy', 'LILOS BIRTHDAY FANCY', 3, 32, 9999, 1, 3, 42, 3096, NULL, 'Devised in 2000 by Andreas Jelinek on the occasion of Lilo Grimm-Cresswell''s birthday



Lilo joined the Munich Scottish Association in 1993 and was very active on the committee, including as treasurer, from 1998 to 2008. She sadly died in 2010.



Andy was chairman of the Munich Scottish Association from 1999 to 2002.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13554, '2010-01-19 23:00:00+00', '2017-05-28 19:38:54.262505+00', 'Moorlands at Hay Tor', 'MOORLANDS AT HAY TOR', 1, 32, NULL, 1, 3, 42, 347, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18474, '2018-07-26 08:29:13.620564+00', '2018-09-25 20:57:13.248419+00', 'Figures of Eight', 'FIGURES OF EIGHT', 1, 40, NULL, 1, 4, 14, 2886, NULL, '', 50, '8000/0880/0008/4444/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17772, '2017-05-29 19:44:26.728117+00', '2019-03-24 10:53:21.746125+00', 'Flowers and Fields', 'FLOWERS AND FIELDS', 4, 64, 5, 1, 4, 2, 10759, '2013-01-01', '', 57, '8800/8800/8440/8880/8080/8020/8088/8088', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17770, '2017-05-29 14:35:42.05037+00', '2019-03-31 17:59:10.144502+00', 'En Tournée Avec Iris', 'EN TOURNEE AVEC IRIS', 3, 48, NULL, 1, 100, 2, 10759, '2013-11-24', '', 85, '8228/8888/8888/8008/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17338, '2016-09-14 09:15:00.196467+00', '2017-05-31 10:59:44.206472+00', 'Trip to Tagaytay, A', 'TRIP TO TAGAYTAY', 3, 96, NULL, 4, 4, 3, 403, '2011-10-06', 'Tagaytay is an area of the Philippines were Graham and Ging were married', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17381, '2016-09-16 19:26:51.893711+00', '2017-05-31 11:03:42.195146+00', '(Albu)''Querque .Flirty, The', 'ALBUQUERQUE FLIRTY', 1, 32, NULL, 1, 4, 1, 11371, '1999-01-22', 'This dance had its first glimmerings at the dance workshop in Prescott, Arizona in 1998. A couple of the dances there had some very flirtatious figures in them, which caught Glenda''s imagination and inspired the name (yes, the name very much came first!). This when combined with the influence of several contra dance figures which really have no direct translations into Scottish Country Dance (namely the Gypsy), resulted in the development of this dance which is designed to encourage the dancing couple to really play up the social aspect. Enjoy', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17103, '2016-06-30 09:46:33.395875+00', '2017-05-31 12:39:04.483471+00', 'Battle of Trafalgar, The', 'BATTLE OF TRAFALGAR', 1, 48, NULL, 1, 4, 2, 11282, '2005-01-01', 'Written to celebrate the 200th Anniversary of the Battle of Trafalgar.  The celebrations for which were centred on Portsmouth.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18347, '2018-05-21 23:46:41.170682+00', '2018-05-21 23:46:45.039371+00', 'Alec Hay', 'ALEC HAY', 6, 32, 9999, 1, 2, 76, 2682, '2017-05-26', 'Notes by the deviser:



Devised 26/7/2017, after re-reading Hay''s Australian Ladies. 



Alec was a truly fine devisor of dances, and I have incorporated modified versions of two of his ideas in the above. Meeting set and shuttle is one of them, and I introduced this formation in The Fyreladdie, the modified tourbillon is similar to one I first used in Tofino Strathspey. 



Recommended tune is Davy Nick Nack played ABAB and a good recording is by Don Bartlett in In Triumph. If the dance is performed as the alternative 4x32H I would suggest the recording of Angus Fitchet, 

The Legendary Angus Fitchet, track 10 (Set of Hornpipes), or Bobby Brown Celtic Fire in the Music Set of Reels 5, track 4, CD 2, (The Fiddler''s Contest, etc.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18475, '2018-07-26 08:35:18.40043+00', '2018-07-26 08:35:18.40043+00', 'Keep Jiggin''', 'KEEP JIGGIN', 2, 32, NULL, 3, 5, 7, 2886, NULL, '', 45, '80800/82842/80800/80800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17455, '2016-10-30 12:22:17.115934+00', '2018-09-05 10:57:24.202221+00', 'Laxey Wheel, The', 'LAXEY WHEEL', 2, 32, NULL, 1, 3, 42, 433, NULL, 'In memory of Doreen Coupe, for many years a most enthusiastic and devoted member of the Kirkcudbright Branch.', 56, '880/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16210, '2015-04-15 11:03:35.586037+00', '2017-06-01 22:28:26.317195+00', 'ABC - Jig (Annual Basic Cleaning - Jig)', 'ABC  JIG ANNUAL BASIC CLEANING  JIG', 2, 32, 9999, 1, 3, 42, 10759, '2012-07-23', 'Devised by Judith Kowalczik on Monday, 23rd July 2012, when the Oldenburg dancers met in the community centre Pasteurstr. in Oldenburg, because there was the annual basic cleaning in the community centre Erikaweg, where they usually have their dance lessons.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16728, '2015-09-03 21:00:34.004068+00', '2017-06-01 22:39:05.067101+00', 'Falls of Feugh', 'FALLS OF FEUGH', 1, 32, NULL, 2, 3, 18, 11197, '2013-01-01', 'The River Feugh joins the River Dee at Banchory, the falls are a local landmark.', 67, '800/844/888/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17771, '2017-05-29 14:43:44.331892+00', '2022-08-15 08:52:53.608963+00', 'Keep It Flowing', 'KEEP IT FLOWING', 2, 32, NULL, 1, 3, 42, 10759, '2013-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18473, '2018-07-26 08:22:23.067699+00', '2022-08-15 11:30:01.973598+00', 'Take 5', 'TAKE 5', 1, 40, NULL, 3, 5, 7, 2886, NULL, '', 57, '80800/80880/04004/84844/88888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14040, '2011-08-25 22:00:00+00', '2022-12-14 16:07:16.296722+00', 'Architect, The', 'ARCHITECT', 1, 32, NULL, 1, 3, 18, 347, NULL, 'Devised for Jeff Robertson''s birthday, 18th August 1997.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18673, '2018-10-01 10:41:48.494783+00', '2018-10-01 10:41:48.494783+00', '9 Pin Bowling', '9 PIN BOWLING', 4, 64, 5, NULL, 111, NULL, 2766, '2011-10-01', 'This dance was written as a simpler attempt to fill a need for a demo where there are many more women available than men.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18631, '2018-09-18 20:12:43.979956+00', '2018-09-18 20:22:46.733506+00', 'Gang Tither Gate', 'GANG TITHER GATE', 2, 32, NULL, 1, 3, 42, 11710, '2013-01-01', 'Earlier version written in 2012', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17774, '2017-05-30 08:17:01.164999+00', '2020-11-08 11:58:41.566433+00', 'Master and His Lady, The', 'MASTER AND HIS LADY', 1, 32, NULL, 1, 3, 42, 21, NULL, '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17778, '2017-06-03 09:13:15.553634+00', '2019-03-24 10:56:35.013346+00', 'Passion Meets Profession', 'PASSION MEETS PROFESSION', 2, 40, NULL, 1, 4, 11, 10759, '2013-10-07', '', 85, '8800/8888/8448/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17785, '2017-06-05 23:00:38.703468+00', '2018-04-02 23:56:37.068374+00', 'Pump Room, The', 'PUMP ROOM', 1, 32, NULL, 1, 3, 42, 11490, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17776, '2017-06-01 22:46:55.589599+00', '2019-03-24 11:12:02.493469+00', 'Reunion Jig, The', 'REUNION JIG', 2, 32, NULL, 5, 2, 76, 10759, NULL, '', 75, '88/80/08/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17786, '2017-06-07 09:12:33.292379+00', '2017-06-07 09:12:33.292379+00', 'New Floor Jig, The', 'NEW FLOOR JIG', 2, 32, 9999, 1, 3, 42, 11495, '1993-01-01', 'This dance was devised in 1993 by Sylvia & Godfrey Cozens on the ocassion of the first dance on the new floor of the schoolroom of the Methodist Church Bingham. (Since demolished in 2015)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1744, '1997-09-02 22:00:00+00', '2017-06-07 09:34:37.220594+00', 'Fire Hose Reel, The', 'FIRE HOSE REEL', 4, 64, 9999, 2, 3, NULL, 514, '1991-01-01', 'Those who have seen the concerts of the Scottish Fiddle Orchestra will be aware of the great sense of humour of their conductor John Masson. It is not surprising that when he saw the sign over a certain fire-fighting appliance de decided to write music for a reel: "The Firehose Reel"! This appealed very much to Stuart''s sense of humour - it was too good an opportunity to miss! So Joyce Elliott devised the dance and the Galloways performed it for him as a birthday present. [from the original description]', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7335, '1998-01-04 23:00:00+00', '2017-06-07 14:56:47.180065+00', 'Buchanan Strathspey, The', 'BUCHANAN STRATHSPEY', 3, 96, 9999, 107, 4, 3, 729, '1991-01-01', 'Although the dance description lays out the dance in ''couples'', it is explicitly written to be performed by 8 women.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18629, '2018-09-18 16:31:58.675538+00', '2019-01-24 16:15:07.171562+00', 'Dancing Gael, The', 'DANCING GAEL', 3, 32, NULL, 2, 2, 76, 11710, '2015-02-01', 'To Gayle Hoepner, RSCDS Central Iowa’s dancing (and teaching) Gael', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17779, '2017-06-04 09:29:47.181536+00', '2019-03-24 10:30:03.382849+00', 'Chasing Butterflies', 'CHASING BUTTERFLIES', 2, 32, NULL, 5, 2, 76, 10759, NULL, '', 81, '88/55/55/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17829, '2017-06-22 17:12:38.816886+00', '2017-06-22 17:12:38.816886+00', 'Island Cruising', 'ISLAND CRUISING', 1, 48, NULL, 1, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17784, '2017-06-05 22:58:49.691276+00', '2017-11-05 13:21:10.512131+00', 'Golden Gallop, The', 'GOLDEN GALLOP', 2, 32, NULL, 1, 4, 1, 11491, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17775, '2017-05-31 12:40:24.207165+00', '2019-03-24 10:18:26.555865+00', 'Rose for the Cobbler, A', 'ROSE FOR THE COBBLER', 3, 32, NULL, 1, 3, 42, 10759, '2016-08-19', '', 63, '880/888/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17783, '2017-06-05 22:57:04.073799+00', '2018-04-02 23:56:37.414011+00', 'Rotunda, The', 'ROTUNDA', 3, 32, NULL, 1, 3, 42, 11490, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17831, '2017-06-22 17:13:45.778157+00', '2018-04-03 00:08:07.871506+00', 'Noelene Petrie''s Reel', 'NOELENE PETRIES REEL', 1, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17773, '2017-05-30 07:46:02.005318+00', '2018-04-03 00:08:09.016948+00', 'Only Vacant Place, The', 'ONLY VACANT PLACE', 2, 40, NULL, 1, 3, 42, 21, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17777, '2017-06-02 21:36:27.328522+00', '2019-03-24 10:23:45.653812+00', 'Dancer''s Brainwave, A', 'DANCERS BRAINWAVE', 4, 192, 3, 2, 3, 17, 10759, NULL, '', 79, '444/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17782, '2017-06-05 07:50:06.565115+00', '2019-03-24 11:08:43.381188+00', 'Reel Thing, The', 'REEL THING', 2, 32, NULL, 5, 125, NULL, 10759, NULL, '', 100, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17789, '2017-06-16 16:01:09.066822+00', '2017-12-18 23:57:02.82015+00', 'Kalan i Manul', 'KALAN I MANUL', 1, 32, NULL, 1, 3, 42, 11496, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14722, '2013-03-14 09:42:42.699707+00', '2017-06-08 11:57:57.604866+00', 'Kintbury Strathspey, The', 'KINTBURY STRATHSPEY', 3, 32, NULL, 1, 4, 1, 10760, NULL, 'Devised by Trisha & Mick Rawlings, 2012, in appreciation of the musicians, Ian and Judith Muir, who live in Kintbury, Berkshire. ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15302, '2013-12-10 19:28:46.661815+00', '2018-03-25 11:51:21.549557+00', 'Jig for Marcus, A', 'JIG FOR MARCUS', 2, 40, NULL, 1, 3, 42, 2992, NULL, 'Devised by Hugh and Joan Ferguson for Marcus Ashman, one time Chairman of Bristol RSCDS, in celebration of a Special Birthday, October 2008.', 57, '822/12 12 12/400/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17833, '2017-06-22 17:24:15.902858+00', '2018-04-03 00:07:34.208138+00', 'Blithe Lass is Beverley, A', 'BLITHE LASS IS BEVERLEY', 3, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14724, '2013-03-14 10:02:52.482338+00', '2017-06-09 23:55:42.740826+00', 'Noces d''Or, Les', 'NOCES DOR', 1, 32, NULL, 1, 3, 42, 10760, '2006-01-01', 'Devised by Trisha & Mick Rawlings to celebrate the Golden Wedding Anniversary of Diana & Dennis Tucker, 9th August 2006.', 56, '800/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17787, '2017-06-10 21:40:45.767587+00', '2017-06-13 14:36:48.825384+00', 'Wunderbar!', 'WUNDERBAR', 1, 32, NULL, 1, 3, 42, 10795, '2017-06-01', 'Devised for Leonie Lübbe when she left Dublin to return home to Germany.', 56, '800/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17849, '2017-06-22 17:49:57.962948+00', '2018-04-03 00:07:59.34817+00', 'Lesley Nicol of Auckland', 'LESLEY NICOL OF AUCKLAND', 2, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17863, '2017-06-23 09:03:38.052166+00', '2018-04-03 00:08:09.739262+00', 'Pairkheid Cross', 'PAIRKHEID CROSS', 1, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17845, '2017-06-22 17:46:31.028722+00', '2018-04-03 00:08:12.691815+00', 'Resounding Bells, The', 'RESOUNDING BELLS', 2, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15297, '2013-12-10 19:21:23.679912+00', '2017-06-16 16:29:37.106385+00', 'Dumbarton Rock', 'DUMBARTON ROCK', 1, 32, NULL, 1, 4, 2, 3481, NULL, 'Dance written by Irene Wilkie for, and with suggestions from, Hopscotch - the children''s Scottish dance team in Chippenham. As Bill Gass is the regular piper with the team, the children wanted the dance to be named after him, hence Dumbarton Rock, as Bill comes from Dumbarton.



Bill has regularly piped for Bristol Branch''s celebrations - Bums Nights, Branch weekends in this country, tours abroad and other special occasions.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17853, '2017-06-23 07:55:20.932853+00', '2018-04-03 00:08:24.049365+00', 'Waiheke Ron, The', 'WAIHEKE RON', 2, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17843, '2017-06-22 17:45:31.282943+00', '2017-06-22 17:45:31.282943+00', 'Let''s Try Again', 'LETS TRY AGAIN', 1, 32, NULL, 3, 5, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18476, '2018-07-26 08:41:06.867402+00', '2018-07-26 08:41:06.867402+00', 'Village Hall Reel, The', 'VILLAGE HALL REEL', 1, 32, NULL, 1, 3, 42, 2886, NULL, '', 62, '888/800/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18348, '2018-05-22 00:38:03.109703+00', '2022-08-15 11:25:43.608775+00', 'Light on the Waters, The', 'LIGHT ON THE WATERS', 1, 48, 9999, 3, 5, 7, 2682, '2017-11-02', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17830, '2017-06-22 17:13:05.857977+00', '2023-02-14 12:57:01.460393+00', 'Cat on a Cushion', 'CAT ON A CUSHION', 2, 48, NULL, 4, 4, 13, 10907, '2006-08-02', 'Inscribed "For Leoni Soter as she settled into her new abode."', 83, '8888/8080/8888/0808/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17580, '2017-02-05 00:01:44.698632+00', '2020-11-06 10:12:03.335244+00', 'May Frolic', 'MAY FROLIC', 1, 32, NULL, 1, 3, 42, 63, '2016-01-01', 'The dance demands good timing, especially in bars 8-16, but works quite well.  It requires quite a lot of energy. ', 69, '866/888/888/866', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17790, '2017-06-16 16:21:25.651232+00', '2020-11-08 12:02:00.753134+00', 'Feel Your Friend', 'FEEL YOUR FRIEND', 4, 64, 5, 1, 3, 42, 11497, NULL, '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17870, '2017-06-23 09:18:26.967118+00', '2020-11-09 10:35:31.574658+00', 'Causeway Capers', 'CAUSEWAY CAPERS', 1, 32, NULL, 1, 3, 42, 10907, NULL, '', 63, '822/888/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3201, '2002-09-22 22:00:00+00', '2021-07-30 07:53:57.336058+00', 'Jane''s Jig', 'JANES JIG', 2, 32, 9999, 1, 4, 2, 308, NULL, 'This dance was written by Sue Petyt for Jane Gamon, her first Scottish Country Dance Teacher.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18477, '2018-07-26 09:51:50.203428+00', '2018-07-26 09:51:50.203428+00', 'St. Deiniol''s Strathspey', 'SAINT DEINIOLS STRATHSPEY', 3, 40, NULL, 3, 5, 10, 2886, NULL, '', 62, '88888/08080/28482/48484/48040', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17867, '2017-06-23 09:05:56.926464+00', '2017-06-23 09:15:43.316418+00', 'Sisters Three, The', 'SISTERS THREE', 3, 32, NULL, 2, 3, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18478, '2018-07-26 09:57:15.584078+00', '2018-07-26 09:57:15.584078+00', 'Lace Making', 'LACE MAKING', 3, 32, NULL, 1, 4, 1, 2886, NULL, '', 56, '8008/0880/8440/8448', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1148, '1997-08-31 22:00:00+00', '2017-07-06 10:41:04.377443+00', 'Champagne Reel (3/4), The', 'CHAMPAGNE REEL 3/4', 1, 32, 9999, 1, 3, 42, 771, NULL, 'Dance devised by Dennis Tucker, in 1993, in celebration of jubilees, birthdays and other champagne occasions.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18480, '2018-07-26 10:05:16.776053+00', '2018-07-27 13:57:33.755245+00', 'Jig for St Andrew''s Day, A', 'JIG FOR ST ANDREWS DAY', 2, 32, NULL, 1, 3, 42, 2886, NULL, '', 49, '800/888/888/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13813, '2011-08-04 22:00:00+00', '2018-12-15 14:32:26.667706+00', 'Loch Coruisk', 'LOCH CORUISK', 2, 32, NULL, 1, 3, 42, 1113, NULL, '', 50, '800/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7074, '1997-09-17 22:00:00+00', '2019-02-03 21:15:31.864758+00', 'Whaup''s Nest, The', 'WHAUPS NEST', 3, 32, 9999, 2, 3, 18, 313, NULL, '', 83, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17825, '2017-06-22 17:04:01.53826+00', '2018-04-03 00:08:10.581766+00', 'Pibroch Reel, The', 'PIBROCH REEL', 1, 40, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16384, '2015-05-21 14:50:30.637634+00', '2018-05-04 15:30:42.236628+00', 'Spark O''Water', 'SPARK OWATER', 3, 32, 9999, 2, 2, 76, 2018, NULL, 'Maggie’s inspiration for the title of the dance comes from Song for the Mira: “The stars on the river

they sparkle and spin”.



Suggested music: *Mira River*, composed by Muriel Johnstone', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17827, '2017-06-22 17:11:37.842034+00', '2018-04-03 00:07:38.572195+00', 'Clan MacKenzie Reel', 'CLAN MACKENZIE REEL', 1, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18479, '2018-07-26 10:01:38.060414+00', '2018-07-26 10:06:29.550567+00', 'Tribute to Scotland', 'TRIBUTE TO SCOTLAND', 2, 32, NULL, 1, 3, 42, 2886, NULL, '', 71, '866/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17806, '2017-06-22 10:59:01.026188+00', '2018-04-03 00:07:41.082974+00', 'Dancing Brolga, The', 'DANCING BROLGA', 1, 40, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17822, '2017-06-22 17:02:15.110585+00', '2018-04-03 00:07:44.435825+00', 'Elusive Partner, The', 'ELUSIVE PARTNER', 1, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17820, '2017-06-22 17:01:11.735483+00', '2018-04-03 00:07:49.699393+00', 'Gray-McLennans of Maclean', 'GRAYMACLENNANS OF MACLEAN', 3, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17804, '2017-06-22 10:57:25.944658+00', '2018-04-03 00:07:50.082982+00', 'Gregarious Gambol, A', 'GREGARIOUS GAMBOL', 1, 32, NULL, 1, 3, 42, 10907, '2012-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17808, '2017-06-22 11:02:05.030763+00', '2018-04-03 00:07:56.595753+00', 'Judith of Yarram', 'JUDITH OF YARRAM', 3, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17800, '2017-06-18 16:21:06.65683+00', '2017-06-19 15:22:45.637327+00', 'Leaving Portree', 'LEAVING PORTREE', 2, 40, NULL, 1, 4, 1, 11503, '2007-01-01', '- 1-8: Tears at leaving Skye

- 9-24: Winding roads leaving Skye

- 25-32: The Skye Bridge

- 33-40: The mountains of Kintail on the mainland of Scotland', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17791, '2017-06-17 08:39:42.941017+00', '2017-06-19 13:31:24.735547+00', 'Southern Rose Waltz', 'SOUTHERN ROSE WALTZ', 5, 24, NULL, 5, 1, 54, 11498, '2008-01-01', 'Couples take positions around the perimeter of the dance floor with gents having their backs toward the center;  the line of dance is anticlockwise.  Gents dance forward on the left foot and ladies dance forward on the right foot.



Dance in waltz hold.  The pattern is also danced free; that is, dance in the available space as other dancers dance either the same or another waltz pattern.



The crib uses ceilidh terminology, and is provisional; it is waiting to be rewritten using SCD terminology.



Edition of December 25, 2008



', 100, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17797, '2017-06-18 16:08:14.632909+00', '2018-09-19 09:48:36.27856+00', 'Olive''s Return To Old Scotia', 'OLIVES RETURN TO OLD SCOTIA', 1, 32, NULL, 1, 4, 1, 11502, '2009-05-01', 'Presented to Olive Jackson on the occasion of her return to the U.K.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17823, '2017-06-22 17:02:51.599459+00', '2018-04-03 00:08:07.004174+00', 'Mustard Seed, The', 'MUSTARD SEED', 2, 40, NULL, 1, 3, 42, 10907, '2009-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17821, '2017-06-22 17:01:46.994136+00', '2018-04-03 00:08:10.740214+00', 'Piper Dances, The', 'PIPER DANCES', 1, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17817, '2017-06-22 11:08:07.239267+00', '2018-10-14 00:26:03.720068+00', 'Shiny Buckle, The', 'SHINY BUCKLE', 1, 40, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17796, '2017-06-18 16:04:08.627172+00', '2019-02-09 17:44:42.49443+00', 'Sailing Days On The Penobscot', 'SAILING DAYS ON THE PENOBSCOT', 3, 32, NULL, 1, 4, 2, 11501, NULL, '', 75, '8448/0880/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17813, '2017-06-22 11:05:39.898285+00', '2017-06-22 11:05:39.898285+00', 'Stella''s Reel', 'STELLAS REEL', 1, 32, NULL, 3, 5, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17814, '2017-06-22 11:06:23.092231+00', '2017-06-22 11:06:23.092231+00', '"The Brays" of Brinsmead', 'THE BRAYS OF BRINSMEAD', 3, 40, NULL, 1, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17815, '2017-06-22 11:06:57.735402+00', '2017-06-22 11:06:57.735402+00', 'Desborough Cross, The', 'DESBOROUGH CROSS', 1, 96, NULL, 4, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17803, '2017-06-22 10:55:09.739613+00', '2019-05-13 14:29:25.347491+00', 'Birthday Smile, A', 'BIRTHDAY SMILE', 2, 32, NULL, 1, 3, 42, 10907, '2012-01-01', '', 56, '822/844/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17818, '2017-06-22 11:09:12.596431+00', '2017-06-22 11:09:12.596431+00', 'Le Brocque Strathspey, The', 'BROCQUE STRATHSPEY', 3, 32, NULL, 3, 5, NULL, 10907, NULL, '', -1, '01/11/2011', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17819, '2017-06-22 17:00:30.028968+00', '2017-06-22 17:00:30.028968+00', 'Andy''s World', 'ANDYS WORLD', 2, 32, NULL, 4, 4, NULL, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17792, '2017-06-18 14:05:22.986411+00', '2020-07-20 08:28:16.264024+00', 'Norma''s Garden', 'NORMAS GARDEN', 1, 32, NULL, 1, 3, 42, 11356, '2010-07-31', 'A birthday gift for Norma Bruce', 50, '800/844/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18959, '2018-10-13 20:22:42.956213+00', '2020-11-22 18:19:23.803858+00', 'Skibo Castle', 'SKIBO CASTLE', 3, 32, NULL, 4, 4, 13, 9998, NULL, '', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17799, '2017-06-18 16:15:33.717139+00', '2020-07-26 02:52:22.345889+00', 'Three Fathom Harbour', 'THREE FATHOM HARBOUR', 3, 32, NULL, 1, 3, 42, 1502, '1992-06-01', 'A Strathspey for Lydia Hedge

', 63, '884/866/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17798, '2017-06-18 16:11:13.161672+00', '2020-12-27 11:43:25.91361+00', 'Wedding Medley', 'WEDDING MEDLEY', 4, 32, 1, 1, 4, 1, 11502, '1997-08-03', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14156, '2011-08-26 22:00:00+00', '2021-01-04 12:12:03.230962+00', 'Coming of Age, The', 'COMING OF AGE', 3, 32, NULL, 1, 3, 42, 370, NULL, '_Music_: Patrick Keith Stacey composed by Muriel Johnstone



For Patrick''s 21st Birthday', 53, '822/866/866/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12866, '2006-10-08 22:00:00+00', '2021-01-08 11:44:33.365816+00', 'Alhambra, The', 'ALHAMBRA', 1, 32, 9999, 1, 4, 2, 212, NULL, '', 75, '8448/8008/8888/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6858, '2002-11-26 23:00:00+00', '2017-06-28 16:58:15.905303+00', 'V and J''s Maggot', 'V AND JS MAGGOT', 2, 32, 9999, 2, 3, 17, 425, '1988-07-01', '*MAGGOT*: A favourite tune or dance that "gnaws" at your mind!



For Jim and Vaurneen Powell, as a farewell dance from the RSCDS Nova Scotia Branch July, 1988.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1173, '1997-04-03 22:00:00+00', '2022-04-25 20:13:36.200834+00', 'Cherry Blossoms', 'CHERRY BLOSSOMS', 3, 32, 9999, 1, 2, 76, 44, '1984-09-01', '', -1, '88/80/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17811, '2017-06-22 11:04:27.984989+00', '2023-02-16 14:42:29.458668+00', 'Miss Nidra Aitken', 'MISS NIDRA AITKEN', 3, 32, NULL, 2, 3, 17, 10907, NULL, '', 75, '880/888/844/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17812, '2017-06-22 11:05:02.270063+00', '2018-04-03 00:08:18.620976+00', 'St. Philip''s Rant', 'SAINT PHILIPS RANT', 1, 32, NULL, 1, 3, 42, 10907, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17810, '2017-06-22 11:03:20.649405+00', '2018-04-03 00:08:24.424825+00', 'Wee Break in Cairns, A', 'WEE BREAK IN CAIRNS', 1, 32, NULL, 1, 3, 42, 10907, '2012-01-06', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1582, '2002-01-08 23:00:00+00', '2018-04-03 09:20:37.748116+00', 'Deil amang the Tailors, The', 'DEIL AMANG THE TAILORS', 1, 32, 9999, 1, 3, 42, 9998, NULL, '##>>

The title almost certainly refers to a table game of skittles. This game involves nine small skittles to be knocked down by a ball on a string attached to an arm similar to a miniature garden ‘swingball’ or, in a larger version, by directing a spinning top at the skittles.  



Why the devil should be among the tailors, however, remains a mystery although it has been suggested that a tailor’s devil is a pressing iron and the title refers to its use by a number of tailors who traditionally sit in a circle on a large workbench.

##<<', 50, '880  800  880  888', 1, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (17788, '2017-06-16 14:29:45.214473+00', '2017-06-23 15:56:18.515851+00', 'Baramande', 'BARAMANDE', 3, 32, NULL, 2, 3, 17, 10581, '2017-05-01', 'The name is derived from the new formation, a combination of a Baratte and an Allemande.', 83, '844/888/484/848', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17882, '2017-06-29 17:07:19.87289+00', '2018-08-07 21:21:40.901858+00', 'Célébrations', 'CELEBRATIONS', 2, 48, NULL, 1, 4, 1, 10568, '2017-01-01', 'Holly Boyd writes "I wrote the dance to go with 8 x 24 J music (specifically The Merry Reapers on A Camp of Pleasure by The Berkeley Scottish Players.) and feel that 8 x 24 fits the dance better that 4 x 48."', 67, '8800/8880/8440/8088/8088/8088', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17883, '2017-06-30 11:19:27.855275+00', '2018-10-05 13:01:24.873084+00', 'Green Mountain Memories', 'GREEN MOUNTAIN MEMORIES', 3, 32, NULL, 1, 3, 42, 2766, '2009-06-01', 'Suggested music is *Adieu Mon Ami* from None So Pretty.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1415, '1998-09-29 22:00:00+00', '2017-07-07 12:52:39.99777+00', 'Crieff Fair', 'CRIEFF FAIR', 1, 24, 9999, 1, 3, 42, 432, '1816-01-01', 'The movements of 1st couple on [15-16] have been much discussed, als on "Strathspey" in october 2013.



A summary of the issue can be found at http://www.rscds.org/help/technique-panel-dances/199-crieff-fair.html, which says"



Question



Crieff Fair  Bars 15-16.



The wording in 101 SCD and the 1994 edition of book 10 differs from the recent compilation Books 7-12 (2009) which says "1st couple finish facing first corners, 1st woman turning under her own right arm".



Does this mean 1st woman turns left about under their joined right hands using skip change of step rather than the pas de basque mentioned in an earlier publication?



Answer



Miss J. Milligan was very definite about pas de basque in 101 SCD but this can be considered a ‘private’ publication. Since then no RSCDS publications mentions pas de basque which would have been done if that had been the Society’s intention. In these circumstances both skip change or pas de basque could be considered acceptable. However, if teaching the dance today, the appropriate step to use would be skip change. Although previously agreed that the lady turned left about, the key phrase in the compilation books 7-12, “1st woman turning under her own right arm” means that she should turn clockwise or right about using skip change of step.  



 



', 37, '880  800  822', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (18632, '2018-09-18 20:31:42.588923+00', '2018-09-18 20:32:32.82519+00', 'Good Ladies Alpheis Jigue', 'GOOD LADIES ALPHEIS JIGUE', 3, 32, NULL, 1, 2, 76, 11713, '2014-09-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17878, '2017-06-23 09:24:07.212379+00', '2019-02-04 13:54:59.846854+00', 'Pride of Paris, The', 'PRIDE OF PARIS', 1, 40, NULL, 1, 3, 42, 10907, '2013-10-01', 'For Antoine Rousseau of Paris.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17795, '2017-06-18 15:09:31.66296+00', '2019-05-01 08:47:20.590123+00', 'Prince Edward Assembly', 'PRINCE EDWARD ASSEMBLY', 1, 88, NULL, 4, 4, 3, 1378, '2014-01-01', 'For Beaconsfield Assembly and their 2014 dancing summer July 16, 2014', 77, '4444/8888/4444/8888/4444/6666/4444/6666/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17793, '2017-06-18 15:02:44.244515+00', '2017-06-28 16:52:46.394841+00', 'Mhairi And I', 'MHAIRI AND I', 2, 40, NULL, 1, 4, 1, 11500, '2015-01-01', 'This is a story dance about the regular walk I take with my dog Mhairi, a yellow labrador, at Rainbow Haven Beach, Cole Harbour, Nova Scotia.



- 1-8: Mhairi and I wend our way down the trail to the long sandy beach.

- 9-16: We see the sparkling waves rolling onto the shore.

- 17-24: Sea gulls, piping plovers, and sandpipers work their way along the tide’s edge, seeking the breakfast treasures brought by the Atlantic Ocean.

- 25-32: We often meet other dogs and owners, greeting old friends and making new ones.

- 33-40: It''s time to go home, but we promise each other to return again.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17801, '2017-06-18 16:26:58.730469+00', '2017-06-28 16:59:44.099628+00', 'Tallahassee Reel, The', 'TALLAHASSEE REEL', 1, 48, NULL, 1, 4, 1, 11503, NULL, 'The *Tallahassee* was a Confederate ship which came into Halifax harbour for repairs during the Civil War and snuck out through Eastern Passage with the help of an Eastern Passage pilot, Jock Fleming, thus evading the Union ships waiting at the mouth of the harbour. We dance it during Tallahassee Days every year.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17891, '2017-07-16 11:41:56.120562+00', '2017-07-21 22:18:31.843087+00', 'Edinburgh Toy Shop, The', 'EDINBURGH TOY SHOP', 2, 32, NULL, 1, 3, 42, 11504, NULL, '“The deviser went with his family to Scotland in 2006 and, although not quite four years old, remembers the toys in the ‘gift shoppe’ at Edinburgh Castle, especially the foam swords.’



DEVISED:2016-03', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17901, '2017-07-16 12:35:48.61836+00', '2017-07-24 03:55:07.505733+00', 'Bohemian Reflections', 'BOHEMIAN REFLECTIONS', 1, 32, NULL, 1, 3, 42, 10961, '2016-01-01', 'The dance was inspired by the reflections on the lake behind Průhonice Castle in Bohemia.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17880, '2017-06-25 23:52:19.125415+00', '2020-11-09 10:39:46.136909+00', 'Diplomat, The', 'DIPLOMAT', 3, 32, NULL, 1, 3, 42, 1445, NULL, '', 56, '844/844/866/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17887, '2017-07-09 21:54:37.622533+00', '2020-11-10 12:23:07.499066+00', 'Fiddling in the Pinewoods', 'FIDDLING IN THE PINEWOODS', 3, 32, NULL, 1, 3, 42, 10648, '2017-01-01', 'Dedicated to Barbara McOwen and all the superb musicians, not only fiddlers but pianists, accordionists, pipers and a range of other instrument players, who I met at Pinewoods in 2014 and/or 2016.



', 52, '886/866/822/840', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9483, '2000-09-04 22:00:00+00', '2021-01-04 11:59:08.681903+00', 'Lacemaker, The', 'LACEMAKER', 3, 32, 9999, 1, 4, 1, 2766, '1998-11-01', 'This dance was written in honor of my mother, who makes beautiful bobbin lace.', 86, '8888/8888/8888/8222', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17572, '2017-01-25 23:21:26.663666+00', '2021-08-02 09:36:55.716788+00', 'Dumfries Welcomes Ribble Valley', 'DUMFRIES WELCOMES RIBBLE VALLEY', 2, 40, NULL, 4, 4, 13, 308, '2011-08-01', 'Written to welcome members of the Ribble Valley Branch of the RSCDS on their visit to Dumfries in April 2012

.', 75, '8080/8484/8888/4444/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16789, '2015-10-14 15:38:08.896766+00', '2019-09-23 20:24:06.542108+00', 'Borders Traditional', 'BORDERS TRADITIONAL', 2, 32, NULL, 1, 3, 42, 2682, '2014-04-06', 'Notes from The Johnsonville Collection:



Devised 6 April, 2014 following a suggestion by Pat Reesby and Desiree Patterson that I devise a dance based upon the Borders’ Poussette; or possibly, my (mis-)interpretation of the instructions for the Borders’ Poussette. I only learned of this figure from the old book A Complete Guide to Scottish Country Dancing by Allie Anderson and John Duthie (McDougall’s Educational Co, Ltd), where it is called “Poussette Second Form” (pages 30-31). Apparently at the time of the writing of this old edition, this method of dancing the poussette was danced in the South-East Borders Counties. The instructions for bars 6-8 say to quarter turn, hesitate, turn and retire. On reconsideration (as pointed out by Iain Boyd) likely this means continue to turn, and then retire. However, I like the mis-interpretation and kept it for that reason.  



Recommended music is “The Daggs of Craighouse” by Moira Reekie played ABAB, this being the lead tune for “A Tribute to the Borders.” Good recordings include the ones on “Music for Leaflet Dances Vol. 2” by Neil Copland and his Scottish Dance Band, and on “Dancing Live” by The Muriel Johnstone Trio. ', 50, '880/880/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (222, '1998-09-29 22:00:00+00', '2019-05-01 06:34:41.421933+00', 'Argyll''s Bowling Green', 'ARGYLLS BOWLING GREEN', 1, 32, 9999, 1, 3, 42, 9998, '1715-02-02', 'The title of this dance refers to a mountainous peninsula on the west coast of Scotland, between Loch Goil and Loch Long. The name is an anglicisation of the Gaelic *baile na greine* or »sunny cattle pasture«, which must be considered somewhat ironic since the area is not particularly suitable for cattle.

', 50, '800/888/822/884', 0, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (14077, '2011-08-25 22:00:00+00', '2017-07-13 06:34:07.297642+00', 'Eighty Years Young', 'EIGHTY YEARS YOUNG', 1, 32, NULL, 1, 3, 42, 10436, NULL, 'A dance devised by Ann Stewart to celebrate the birthday of Claire Burnett', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17885, '2017-07-09 20:55:07.834552+00', '2018-04-04 21:28:28.000011+00', 'Miss Charlotte Sandifer', 'MISS CHARLOTTE SANDIFER', 1, 32, NULL, 1, 4, 2, 802, '2005-02-11', 'Devised by Lyn Wilson for Charlotte Sandifer on the occasion of her 18th birthday in recognition of her stalwart support during her teenage years for the Golden Oldies of the Vale of Glamorgan class !

', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3221, '1998-07-08 22:00:00+00', '2017-07-15 01:29:38.239843+00', 'Jeanetta''s Progress', 'JEANETTAS PROGRESS', 3, 48, 9999, 1, 4, 13, 351, NULL, 'Devised for Jeanetta McColl on I forget which one of her many promotions. (Source: original description)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5026, '1997-09-10 22:00:00+00', '2021-04-17 17:42:34.338475+00', 'Octocentennial Jig, The', 'OCTOCENTENNIAL JIG', 2, 32, 9999, 1, 3, 42, 108, '1986-01-01', 'The leaflet says »MUSIC – opposite page« but the copy in the RSCDS Archive only has the front page. If you have the actual leaflet and can tell us about the music please do get in touch.



The dance has sometimes been misnamed "Dumfries Octocentenary Jig".  The error arose from misreading the following text section in Drewry''s description: 



"THE OCTOCENTENNIAL JIG



to mark the eight hundredth anniversary of Dumfries as a Royal Burgh 



dance devised by John Drewry



Jig - 3 couples - 32 bars.



Tune - "lain J. McConnell of Solway" - by McGowan



this tune and three other new tunes are played on the DUMFRIES OCTOCENTENARY record (Heather Sound Company No. LS020)"', 56, '800/888/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17886, '2017-07-09 21:12:14.496164+00', '2018-04-04 21:22:15.512308+00', 'Trip to Sorrento, A', 'TRIP TO SORRENTO', 2, 32, NULL, 2, 3, 30, 11233, '2017-01-01', 'This 32 bar dance goes 6 times through: After 32 bars, the progression has reached (2,1,3).  1c then repeats from 2nd place, i.e. 1c lead down and up from 2pl, and 1c+3c dance the Allemande.  The progression after 64 bars is (2,3,1)', 75, '888/800/880/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17890, '2017-07-14 18:27:22.514496+00', '2017-07-14 18:29:28.036631+00', 'Moonpath', 'MOONPATH', 3, 48, NULL, 1, 4, 11, 11150, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5907, '1997-04-03 22:00:00+00', '2017-07-09 22:39:26.584148+00', 'Saxie''s Baa', 'SAXIES BAA', 2, 32, 9999, 1, 2, 76, 313, NULL, 'Saxie and Herman were two Shetland giants. In a quarrel each hurled a rock at the other. Saxie''s rock, new known as Saxie''s Baa, fell into the water, just short of Herman''s home.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4039, '1997-09-08 22:00:00+00', '2017-07-15 01:58:36.735375+00', 'Mackenzie River Strathpey, The', 'MACKENZIE RIVER STRATHPEY', 3, 40, 9999, 1, 4, NULL, 1092, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17893, '2017-07-16 11:50:46.275348+00', '2017-07-23 18:07:21.751227+00', 'Save the Children', 'SAVE THE CHILDREN', 3, 32, NULL, 1, 3, 42, 3355, '2015-09-01', 'This dance was devised to inspire young dancers to give demonstrations in villages and towns to raise money for children''s charities.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17889, '2017-07-12 14:16:41.260842+00', '2017-10-02 10:31:55.64274+00', 'Gowan Hill', 'GOWAN HILL', 2, 32, NULL, 1, 128, 2, 11100, '2016-01-01', 'Gowan Hill (85m) is located 0.4km north-east of Stirling Castle.

There is a vitrified hill fort and many other archaeological sites across the hill.

There is also a Beheading Stone which is said to have been used regularly in the 15th century.', 78, '8008/8448/8888/8668', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17892, '2017-07-16 11:47:23.591017+00', '2017-07-23 20:41:30.22973+00', 'Somerset Children''s Reel, The', 'SOMERSET CHILDRENS REEL', 1, 32, NULL, 1, 3, 42, 11507, '2015-10-01', 'Dedicated to the children''s class of the RSCDS Somerset Branch. This dance includes the children''s favourite formations. The children also helped choose the name of the dance.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17895, '2017-07-16 12:02:35.379167+00', '2017-07-23 20:57:49.874652+00', 'Summer on the Beach', 'SUMMER ON THE BEACH', 1, 32, NULL, 1, 4, 1, 11508, '2012-06-01', 'This dance was devised for Laura in my children''s class in Ghent, Belgium. She was nine years old at the time and, although a very enthusiastic dancer, was looking forward to her summer holiday at the seaside.



- bars 1–8 represent the parasols being set up on the beach;

- bars 9–16 represent the children jumping over the waves that roll onto the beach;

- bars 17–24 represent the children diving into the water and swimming back to the shore; and

- bars 25–32 represent the children playing with their kites.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18350, '2018-05-22 17:33:31.687238+00', '2018-05-22 17:55:50.513845+00', 'Trip to Fourqueux, A', 'TRIP TO FOURQUEUX', 1, 32, NULL, 1, 3, 42, 11635, '2018-01-01', 'Inscribed to Tom McKinlay and the Sash and Sporran. The Sash and Sporran dance, gather and laugh in Fourqueux, a bonnie wee toon next to Saint-Germain-en-Laye.  



Recommended music:  

"Dancing On", Vintage Goldring, Piano, Muriel Johnstone, Fiddle, Keith Smith.', 41, '800/866/822/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4358, '1999-04-21 22:00:00+00', '2022-12-03 11:53:19.036555+00', 'Middleton Medley, The', 'MIDDLETON MEDLEY', 4, 32, 8, 1, 3, 42, 62, NULL, 'This dance is a 16S/16J medley; the tune "Craighall", universally used for this dance, is a jig.



In some older publications the quicktime part was wrongly said to be a Reel. This error was corrected in an earlier revision of Book 22, but has appeared again in the revised pocket Books 19-24. Just disregard these errors.', 34, '840  822  811  811', 1, 1, 1, 1, 45);
INSERT INTO 'dance' VALUES (17984, '2017-09-26 21:57:29.310435+00', '2017-09-26 21:57:29.310435+00', '''Innocent'' Railway, The', 'INNOCENT RAILWAY', 1, 32, 9999, 1, 3, 42, 11529, NULL, 'The Edinburgh and Dalkeith Railway was an early railway built to convey coal from pits in the vicinity of Dalkeith into the capital. It was a horse-operated line, with a terminus at St Leonards on the south side of Arthur’s Seat. Today it’s a nice walking and cycling path with a halfmile tunnel. A tablet has been erected naming the railway ''The Innocent Railway'' on the basis that the line never suffered a fatal accident.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17985, '2017-09-26 21:59:17.201794+00', '2017-09-26 21:59:17.201794+00', 'Don''t Miss Your Partner In The Dusk', 'DONT MISS YOUR PARTNER IN THE DUSK', 1, 32, 9999, 1, 3, 42, 11527, NULL, 'During one of our summer open-air dancing sessions we were dancing at sunset. When it became dark there were still no street lights switched on and the 1st lady cast one place while her partner cast to the bottom. They found each other later.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17899, '2017-07-16 12:21:23.268319+00', '2017-07-23 23:07:39.622485+00', 'Hello-Goodbye', 'HELLOGOODBYE', 3, 32, NULL, 1, 3, 42, 2973, '2012-10-01', 'The dance was devised to introduce the formation ‘set to corners and partner’ in either strathspey time or in quick time. In *Won''t You Join the Dance*, Jean Milligan offered the following advice to teachers: ‘It has been found very helpful to make them (the class) say “How do you do” – “Goodbye” to each person as they set.’', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17896, '2017-07-16 12:06:14.625315+00', '2018-09-07 07:52:11.415735+00', 'And for the Young Ones', 'AND FOR THE YOUNG ONES', 2, 32, NULL, 4, 4, 4, 11509, '2016-03-01', 'This dance was devised for lessons in a nursery school. It was first meant to be danced in one big circle with the woman on her partner''s right and without a progression.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18353, '2018-05-25 14:38:00.157513+00', '2020-10-17 17:33:58.025346+00', 'Bundle of Eights, A', 'BUNDLE OF EIGHTS', 1, 32, NULL, 3, 5, 16, 11637, NULL, '', 50, '80800/08080/80000/88888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17888, '2017-07-12 14:08:47.164883+00', '2020-11-10 12:25:49.817205+00', 'Stirling at 90', 'STIRLING AT 90', 1, 32, NULL, 3, 5, 40, 11100, '2016-01-01', 'RSCDS Stirling Branch celebrates 90 years in 2017.', 82, '80822/88888/08888/88888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17986, '2017-09-26 22:03:47.3682+00', '2020-11-11 21:21:33.104493+00', 'KNight Bus Jig, The', 'KNIGHT BUS JIG', 2, 40, 9999, 1, 4, 1, 11529, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18964, '2018-10-13 21:20:15.132559+00', '2020-11-22 18:47:33.565376+00', 'West Head', 'WEST HEAD', 2, 48, NULL, 1, 4, 1, 11730, NULL, '', 60, '4884/8008/8008/8008/8448/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18349, '2018-05-22 09:29:31.995675+00', '2021-10-12 15:47:17.68918+00', 'Haste to the Royal Wedding', 'HASTE TO THE ROYAL WEDDING', 2, 32, NULL, 1, 4, 2, 11438, '2017-11-28', 'Devised the day after Prince Harry and Meghan Markle announced their engagement in November 2017.', 62, '8080/0808/8008/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5712, '1997-04-03 22:00:00+00', '2021-07-02 12:39:24.739819+00', 'Round Pond Rant, The', 'ROUND POND RANT', 1, 32, 9999, 1, 2, 76, 351, NULL, 'The original description states: With thanks to Brian Forbes of the Birmingham Branch, RSCDS, whose "chain" progression is the best new thing in Scottish country dancing since the Rondel.



However, the Strathspey ''Ailsa Craig'' and Jig ''Glen Mor'' from the ''Birmingham Book'' from 1973 that introduce the ''Chain Progression'' were written by Eric Forbes, not Brian. (There are no dances known to date written by a Brian Forbes.)', 60, '88/88/84/48', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17989, '2017-09-26 23:08:56.595514+00', '2018-09-19 09:50:12.408839+00', 'Vladimir''s Fancy', 'VLADIMIRS FANCY', 4, 64, 22, 1, 3, 42, 11527, NULL, 'During our dance weekend in the town of Vladimir the weather was truly remarkable. We were safely indoors enjoying our social dance while a small hurricane was smashing the town’s trees into pieces.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17978, '2017-09-26 21:16:40.749124+00', '2017-09-26 22:30:09.780333+00', 'From Siberia With Love', 'FROM SIBERIA WITH LOVE', 2, 32, 9999, 1, 3, 42, 11527, NULL, 'This dance was inspired by my winter trip to Siberia where I was teaching local dancers and discovering the real Siberia.



1 - 8 Handshaking in the kitchen



9-16 Trip to Novosibirsk



17-24 “There’s too much of you!“



25-32 Evening dancing and farewell hugs at the airport', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17991, '2017-10-01 21:04:44.224343+00', '2017-10-03 23:32:48.331112+00', 'Blackness Castle', 'BLACKNESS CASTLE', 3, 32, NULL, 1, 4, 11, 11100, '2016-01-01', 'Blackness Castle stands on the south side of the River Forth four miles north-east of Linlithgow. It is also known as ‘The Ship that Never Sailed’ for its boat-like shape and was built in the 1400s for Sir George Crichton, Admiral of Scotland. ', 66, '8228/6666/4884/8008', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17618, '2017-02-23 17:21:58.238139+00', '2017-10-03 22:44:37.244853+00', 'Shorter, The Longer, The', 'SHORTER THE LONGER', 3, 32, NULL, 1, 3, 42, 11350, '2017-02-01', 'Devised by Mathias Ferber on February 2017.



Dedicated by Mathias Ferber, Christina Hood, Mélissa Meunier, Emma and Raphaëlle Orgeret to Asako Tamaki, for the occasion of her departure to Japan, after spending many years in Europe. Asako is a short dancer with very beautiful and powerful style. If any of us thinks he can’t cover in a dance, he should always remember her dancing. 



The music was written by Christina Hood.



Tune : The shortest legs take the longest steps', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16764, '2015-09-22 19:09:01.112067+00', '2018-11-03 10:45:45.737908+00', 'Gypsy Shawl, The', 'GYPSY SHAWL', 2, 32, NULL, 1, 4, 1, 9998, NULL, 'Source: A Portland (OR) Ball program.

', 91, '8888/8888/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17900, '2017-07-16 12:32:55.596546+00', '2019-08-20 20:48:50.078629+00', 'Come What May', 'COME WHAT MAY', 2, 32, NULL, 1, 2, 76, 59, '2010-05-01', '“The dance was devised on 1st May 2010 – hence the choice of title.”', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18070, '2017-11-13 15:40:21.246971+00', '2017-11-13 15:40:21.246971+00', 'Seamus'' Smile', 'SEAMUS SMILE', 3, 32, NULL, 2, 104, 17, 969, NULL, '', 88, '888|888|484|488', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11549, '2003-10-05 22:00:00+00', '2018-05-22 12:25:03.262022+00', 'Summer Serendipity', 'SUMMER SERENDIPITY', 1, 32, 9999, 1, 3, 42, 348, '2001-01-01', '"Summer Serendipity" was created to celebrate the marriage of Lori Farrell and Michael Howard on October 13, 2001.', 50, '880/888/800/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15513, '2014-06-27 21:14:24.760407+00', '2019-01-23 17:44:24.293189+00', 'Double Chase, The', 'DOUBLE CHASE', 1, 32, NULL, 1, 3, 42, 10971, NULL, 'Devised during a holiday in Madrid, Spain.', 52, '866/860/808/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17879, '2017-06-25 22:24:02.258018+00', '2017-07-21 08:20:10.633358+00', 'Sound Technician (variant 2017), The', 'SOUND TECHNICIAN VARIANT 2017', 2, 32, NULL, 2, 3, 17, 1445, NULL, 'See also The Sound Technician, http://my.strathspey.org/dd/dance/12739/ by the same author which differs only in bars 25-32', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17902, '2017-07-24 22:55:21.580712+00', '2017-07-24 22:55:21.580712+00', 'Adriana in the Gardens of Curia', 'ADRIANA IN THE GARDENS OF CURIA', 1, 32, NULL, 2, 3, 17, 11225, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13385, '2009-11-06 23:00:00+00', '2017-07-27 19:35:48.425196+00', 'Festival Interceltique', 'FESTIVAL INTERCELTIQUE', 1, 40, NULL, 7, 113, 4, 550, NULL, '##RSCDS-DI:bars:32+8



When I first wrote Festival Interceltique, I had it with dancers in square sets. so the promenade has the dancers changing set.  Unfortunately, on the original dance-through with the Lorient team there were only 5 couples, so we had to dance it as a single 5-couple set. They then taught it at the festival as a single circular set for as many as will, and this is the version that was published.  Do try it with square sets - it gives a bit more meaning to the promenade. Of course, you will probably find that when the dancers re-form at the end of the promenade, you will have sets of 3 couples, 5 couples, 2 couples, 6 couples, just as happens with the Dunedin Festival Dance / Borrowdale Exchange.  This is fine and the dance allows for it.



Cheers,  Ian Brockbank,  Edinburgh. Scotland', 90, '8  8  4  8  8', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17907, '2017-08-03 17:06:39.203713+00', '2017-08-03 17:06:39.203713+00', 'White Storks on the Meadow', 'WHITE STORKS ON THE MEADOW', 1, 32, NULL, 2, 3, 17, 11514, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17910, '2017-08-05 13:17:17.072386+00', '2017-08-05 13:17:17.072386+00', 'Next Year in Pitlochry', 'NEXT YEAR IN PITLOCHRY', 2, 32, NULL, 2, 3, NULL, 11514, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17914, '2017-08-05 13:21:11.639547+00', '2017-08-05 13:21:11.639547+00', '96 Bars for Pitlochry', '96 BARS FOR PITLOCHRY', 3, 32, NULL, 2, 3, 17, 11514, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17904, '2017-08-02 13:56:24.81427+00', '2017-08-07 10:55:41.292386+00', 'Elma McCausland MBE', 'ELMA MACCAUSLAND MBE', 2, 40, NULL, 1, 4, 1, 10387, '2017-01-01', 'Devised by Lucy Mulholland on behalf of the Belfast Branch to celebrate Elma being awarded an MBE in recognition of her years of dedicated service to Scottish County Dancing.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18351, '2018-05-22 20:46:09.546115+00', '2018-05-22 21:08:32.042298+00', 'Summerfield Lass', 'SUMMERFIELD LASS', 2, 32, NULL, 1, 3, 42, 11636, NULL, '_*Summerfield Place*_ was the name of the street where devisor’s wife Jamie lived prior to them getting married – Hence _*Summerfield Lass*_.', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17962, '2017-09-25 20:39:53.607852+00', '2020-11-11 12:29:29.886778+00', 'Everyone is Dancing!', 'EVERYONE IS DANCING', 1, 32, NULL, 1, 2, 76, 10568, '2015-11-01', '', 69, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17981, '2017-09-26 21:42:46.000266+00', '2020-11-11 20:16:27.959076+00', 'Irina''s Happiness', 'IRINAS HAPPINESS', 3, 32, 9999, 2, 3, 18, 11527, NULL, 'Dedicated to Irina Kovaleva who was nursing her baby at that time.', 81, '800/888/888/877', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17963, '2017-09-25 20:41:43.486147+00', '2021-02-08 19:09:15.007747+00', 'Flower of Pitlochry: A Dance for Ruth Taylor', 'FLOWER OF PITLOCHRY A DANCE FOR RUTH TAYLOR', 2, 48, NULL, 1, 3, 42, 10568, '2016-02-01', 'Ruth Taylor had never had a dance written for her. She certainly deserves one!', 58, '800/800/822/822/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17911, '2017-08-05 13:18:14.177676+00', '2017-11-05 13:22:09.790905+00', 'friendly Maids, The', 'FRIENDLY MAIDS', 2, 32, NULL, 2, 3, 17, 11514, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18352, '2018-05-25 14:29:35.429864+00', '2018-05-25 16:06:57.269988+00', 'St Peter Two', 'SAINT PETER TWO', 2, 32, NULL, 103, 2, 76, 635, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17906, '2017-08-03 17:05:27.919461+00', '2017-11-05 13:17:27.884904+00', 'Weavers'' Reel, The', 'WEAVERS REEL', 1, 32, NULL, 2, 3, 17, 11514, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17915, '2017-08-05 13:22:16.210879+00', '2017-11-05 13:18:09.070363+00', 'Sunset of Your Life, The', 'SUNSET OF YOUR LIFE', 3, 32, NULL, 2, 3, 17, 11514, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17916, '2017-08-05 13:23:37.584406+00', '2017-11-05 13:23:26.541424+00', 'Elegant Hotel, The', 'ELEGANT HOTEL', 3, 32, NULL, 2, 3, 17, 11514, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17917, '2017-08-05 13:25:54.210642+00', '2017-11-05 13:24:09.796308+00', 'Edradour Whisky Trail, The', 'EDRADOUR WHISKY TRAIL', 3, 32, NULL, 2, 3, NULL, 11514, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13838, '2011-08-21 22:00:00+00', '2018-07-07 00:29:35.303771+00', 'Celebrating Gold', 'CELEBRATING GOLD', 1, 40, NULL, 1, 4, 1, 872, '2001-01-01', 'Devised in 2001 to celebrate the Golden Wedding of our Treasurer, Thelma Green and Arthur', 99, '8888/8888/6888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18390, '2018-07-01 10:42:11.874522+00', '2019-06-19 16:31:02.160165+00', 'Bus Monitor, The', 'BUS MONITOR', 1, 32, NULL, 1, 2, 76, 11654, NULL, '', 68, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17922, '2017-08-23 11:25:08.379974+00', '2018-02-22 09:05:42.786127+00', 'Sunset over Connel Bridge', 'SUNSET OVER CONNEL BRIDGE', 3, 32, NULL, 2, 3, 17, 2874, '2016-08-01', '“For Jens Heckmann whose heart beats for Scottish dancing and the beauty of Scotland.

A quiet spot on the banks of Loch Etive with a view of Connel Bridge and the ever-changing

waters underneath is a favourite place of his.”', 77, '400/12 12 12/666/808', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17944, '2017-09-17 10:29:33.522162+00', '2018-04-09 00:11:16.146232+00', 'Fifty in Jig-Time', 'FIFTY IN JIGTIME', 2, 32, 9999, 1, 3, 42, 3254, '2017-05-01', 'For Wouter Joubert, RSCDS Pretoria dancer and teacher, on the occationof his 50th birthday.', 55, '770/888/888/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17997, '2017-10-10 15:13:54.792048+00', '2018-04-09 13:24:58.076108+00', 'Flowers Galore', 'FLOWERS GALORE', 3, 80, 9999, 4, 4, 3, 3254, '2017-05-01', 'In memory of my mother, Kathleen (Kay) Bamford Harris (née Richter) (11/2/1920 - 2/7/2008), to whom I owe my love of flowers and my flower-arranging skills.', 85, '8888/8080/0808/8888/6666/6666/8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18071, '2017-11-13 15:45:13.562177+00', '2018-04-02 23:56:37.839163+00', 'Strathspey for Steve', 'STRATHSPEY FOR STEVE', 3, 32, NULL, 1, 3, 42, 1041, '2004-01-01', '', 56, '8800|8800|8800|8880', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17943, '2017-09-17 10:28:49.329279+00', '2018-04-10 07:42:06.730293+00', 'Devotion', 'DEVOTION', 3, 32, 9999, 2, 3, 17, 10853, '2017-06-01', 'For Wouter Joubert, friend, dancer and teacher.', 79, '888/484/888/084', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17925, '2017-09-02 19:39:02.689673+00', '2018-04-26 22:53:14.325111+00', 'Mixed Doubles', 'MIXED DOUBLES', 3, 32, NULL, 3, 5, 4, 1228, '2011-11-02', 'Devised for the Bognor Scottish Country Dancing Club (They wanted a dance with a title beginning with the letter M).', 57, '42824/42824/04440/88888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17920, '2017-08-20 07:23:29.571491+00', '2018-05-20 20:25:49.811754+00', 'Désirée Patterson', 'DESIREE PATTERSON', 3, 40, NULL, 1, 4, 2, 2682, '2017-06-15', 'Rod writes: "Désirée has been secretary for the Johnsonville club, and is a long serving member. She and her husband John are super cyclists and have a longstanding blog. Being of Dutch descent, the cycling is part of her DNA.

The Hello and Goodbye fIgure is from the Cane Toad Collection, specially the dance called The Three Oaks.

Recommended music is "Centenary Square" by Chris Drewhurst, and a good recording is the society''s recording of The Library at Birmingham from Book 49."



Rod Downey, tutor of the Johnsonville SCD Club, Wellington, New Zealand, devised ''Désirée Patterson'' in honour of club member Désirée Patterson''s 70th birthday on Monday, August 14, 2017.



He taught this four-couple strathspey to Désirée and other club members as the last dance for the evening at the club''s weekly meeting, which occurred on Désirée''s birthday. So it was danced for the first time ever.', 81, '8008/8448/8888/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17924, '2017-08-31 10:17:17.109345+00', '2017-08-31 10:36:09.345382+00', 'Sutherland Rant, The', 'SUTHERLAND RANT', 2, 32, NULL, 1, 3, 42, 11519, NULL, '', 56, '800/866/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17877, '2017-06-23 09:23:37.01358+00', '2018-05-26 02:05:42.364073+00', 'Kilted Norseman, The', 'KILTED NORSEMAN', 2, 40, NULL, 1, 3, 42, 10907, '2015-03-01', 'For Johan Berg celebr ating his 50th birthday, March 2015.  



Devised by Francis Walduck, Brisbane, Australia, March 2015.  

Suggested music, Jig, track 2, All Set CD by David Cunningham jnr and his Band.', 63, '800/866/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (504, '1997-04-03 22:00:00+00', '2017-09-27 03:48:11.994377+00', 'Big Fiddle, The', 'BIG FIDDLE', 3, 32, 9999, 1, 4, NULL, 108, '1983-01-01', 'The dance is dedicated to John Stinton who played double bass in Jim MacLeod''s Band.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18057, '2017-11-13 02:19:22.746202+00', '2018-04-02 23:56:34.333081+00', 'Elms and Nutmegs', 'ELMS AND NUTMEGS', 2, 40, NULL, 1, 3, 42, 870, '2017-07-01', '', 45, '8800|8000|8000|8800|8880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17965, '2017-09-25 20:45:05.545507+00', '2020-11-11 12:55:30.637689+00', 'Katie in Kingston', 'KATIE IN KINGSTON', 1, 32, NULL, 3, 5, 16, 10568, '2015-11-01', '', 60, '80800/80008/84444/88888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17968, '2017-09-25 20:49:03.434442+00', '2020-11-11 18:21:50.893679+00', 'Lest We Forget', 'LEST WE FORGET', 3, 32, NULL, 1, 3, 42, 10568, '2015-11-01', '', 63, '880/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16411, '2015-05-30 18:07:32.604174+00', '2020-12-31 17:10:22.184602+00', 'Autumn Leaves', 'AUTUMN LEAVES', 3, 32, 9999, 1, 2, 76, 2018, '2011-01-01', '', 52, '44/80/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18355, '2018-05-27 10:24:29.299565+00', '2022-04-26 14:52:48.140092+00', 'Fair Helen', 'FAIR HELEN', 3, 32, NULL, 4, 4, 1, 11225, NULL, '', 75, '8888/8080/0808/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17913, '2017-08-05 13:20:03.939134+00', '2022-12-23 16:58:05.536517+00', 'Cross and Twist', 'CROSS AND TWIST', 2, 32, NULL, 2, 3, 17, 11514, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17969, '2017-09-25 20:50:23.467588+00', '2021-02-08 12:40:42.085693+00', 'Lupin Cows', 'LUPIN COWS', 3, 32, NULL, 1, 4, 2, 10568, '2016-06-01', '', 69, '8000/8888/8888/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17967, '2017-09-25 20:47:49.292581+00', '2021-02-08 13:13:25.925899+00', 'Leaves in Autumn', 'LEAVES IN AUTUMN', 1, 32, NULL, 2, 3, 17, 10568, '2016-11-01', '', 58, '800/844/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18389, '2018-06-28 21:17:47.330881+00', '2021-10-01 21:03:59.985356+00', 'Ten Pence Reel', 'TEN PENCE REEL', 1, 40, NULL, 1, 4, 2, 11652, '2018-05-01', '', 88, '4884/4884/8668/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17966, '2017-09-25 20:46:36.643386+00', '2021-02-08 16:19:50.459758+00', 'Katie''s Birthday', 'KATIES BIRTHDAY', 1, 32, NULL, 2, 3, 17, 10568, '2015-12-01', '', 75, '888/880/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18087, '2017-11-23 17:05:36.476935+00', '2021-04-14 08:52:38.016049+00', 'Remembering Robyn', 'REMEMBERING ROBYN', 3, 32, 9999, 1, 3, 42, 11566, '2010-01-01', 'Devised by Jan Pyke of Opotiki, Waikato Region.

This dance is dedicated to the memory of Robyn Margerison, a Scottish Country Dancer from Opotiki,who died tragically in January 2010.



Suggested music: Ythanside, track 7 HISCD', 75, '888/888/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18082, '2017-11-23 13:43:23.534445+00', '2021-05-12 00:39:16.633691+00', 'Friendship', 'FRIENDSHIP', 2, 32, 9999, 1, 3, 42, 11567, '2013-01-01', 'Devised by Sue Bowater, Nelson Marlborough Region, to celebrate Richmond Scottish Country Dance Club''s 50 years in 2013.



Suggeseted music: Happy Dancers, Haste Ye Back, Muriel Johnstone''s Scottish Dance Band', 53, '822/844/888/466', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18518, '2018-08-21 09:43:52.007784+00', '2018-09-06 06:24:34.196007+00', 'Walnut Chaser', 'WALNUT CHASER', 2, 32, NULL, 3, 5, 16, 11509, '2017-01-01', 'A very easy dance suitable for a ceilidh or a warm up.  It was devised as a variation of Rabbie''s Reel and Charlestown Chaser for a teaching and performance project in a nursery school in my hometown Pontcharra, so that different classes could learn very easy but slightly different dances.  It was originally called "Pontcharra Chaser" and renamed for The Walnut Book.', 55, '44444/44444/88888/80000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18279, '2018-04-10 21:25:07.002069+00', '2018-09-07 11:05:50.168896+00', 'Walnut Orchard, The', 'WALNUT ORCHARD', 1, 32, NULL, 1, 3, 42, 11509, '2018-03-01', 'There are plenty of walnut orchards in the area of Grenoble, northwards up to Chambery and southwards down to Valence, it is quite typical in the landscape all along the lsere valley.



This dance is very similar to <<ddd:Reel of the Gordon Highlanders>>



', 62, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17780, '2017-06-04 17:35:31.849102+00', '2019-03-24 11:05:07.108684+00', 'Spring Fever', 'SPRING FEVER', 2, 32, NULL, 7, 1, 4, 10759, NULL, '', 75, '48/84/44/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (894, '2000-06-12 22:00:00+00', '2017-09-14 09:33:00.387744+00', 'Byron Strathspey, The', 'BYRON STRATHSPEY', 3, 32, 9999, 2, 3, 18, 108, '1975-01-01', '<<imgt:lordbyron.jpg|George Gordon Byron, 6th Baron Byron|200x300:right>>

Lord Byron, or, more correctly, George Gordon Byron, 6th Baron Byron (1788-1824),

was a poet and important figure of the Romantic movement. He was educated in

Aberdeen and afterwards led a somewhat colourful life until he died

from a fever in Greece at age 36. Byron took part in the Greek

struggle for freedom from the Osman empire, and the Greek consider him

a national hero (which figures in view of the fact that he, too,

used to run up prodigious debts in his lifetime).

', 92, '888  888  880  888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (18196, '2017-12-27 19:49:33.1352+00', '2018-04-03 00:07:48.331412+00', 'Give Me Your Hand', 'GIVE ME YOUR HAND', 3, 32, NULL, 1, 3, 42, 44, '1989-01-21', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17926, '2017-09-11 22:56:18.987188+00', '2017-09-11 22:56:18.987188+00', 'Imagine', 'IMAGINE', 3, 32, NULL, 2, 3, 18, 11523, NULL, 'DEVISED: 2015', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17999, '2017-10-11 12:10:01.030703+00', '2018-04-10 11:37:35.749663+00', 'Hello, Bye-Bye', 'HELLO BYEBYE', 1, 32, 9999, 1, 3, 42, 3254, '2016-06-01', 'At a conference I attended, one of the speakers referred to older, non-smartphones (the sort that only do calls and text messages) as "hello, bye-bye" phones. My SCD mind immediately thought of "hello and goodbye setting" (set to corners and partner) and during a break in the proceedings, this dance took shape.', -1, '820/844/866/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18195, '2017-12-27 19:48:28.664541+00', '2018-04-03 00:08:02.750739+00', 'May I Have the Pleasure?', 'MAY I HAVE THE PLEASURE', 3, 32, NULL, 1, 3, 42, 44, '2014-11-11', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17977, '2017-09-25 21:03:27.784799+00', '2017-09-25 21:03:27.784799+00', 'Time for a New Dog (dance)', 'TIME FOR A NEW DOG DANCE', 2, 40, NULL, 3, 5, 7, 10568, '2015-11-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16189, '2015-04-11 17:19:56.244097+00', '2017-09-29 22:26:21.659967+00', 'Hans and Ulla Circles', 'HANS AND ULLA CIRCLES', 3, 32, 9999, 107, 4, 15, 10612, '2006-08-19', 'Set shape:  2s, 3s and 4s as in a three couple dance, with 1M in the centre between 2s and 3s and 1L in the centre between 3s and 4s



The dance is called "Hans and Ulla Circles" in the table of contents, and "Hans and Ulla" on the page with the description.', 59, '0844/8000/8426/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18483, '2018-07-26 10:31:24.617048+00', '2018-12-17 18:48:02.201461+00', 'Its Nearly Christmas', 'ITS NEARLY CHRISTMAS', 2, 32, NULL, 1, 4, 1, 2886, NULL, '', 63, '8000/8888/8440/8448', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14894, '2013-05-24 13:59:14.662381+00', '2017-12-26 14:05:52.130473+00', 'Coit Tower Reel', 'COIT TOWER REEL', 1, 32, NULL, 1, 3, 42, 2961, NULL, 'For Lillie Hitchcock, Coit, mascot of Knickerbocker Engine Company No. 5, who honored firemen throughout her life', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17979, '2017-09-26 21:36:59.361054+00', '2019-02-12 23:54:21.058049+00', 'Golden Rush, The', 'GOLDEN RUSH', 3, 40, 9999, 1, 4, 11, 11527, NULL, 'The dance was written to commemorate Charles Chaplin’s birthday.', 75, '8888/8888/4444/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17976, '2017-09-25 21:02:01.967145+00', '2022-01-09 18:35:26.935371+00', 'Til We Meet Up Again', 'TIL WE MEET UP AGAIN', 2, 32, NULL, 3, 5, 7, 10568, '2014-09-01', 'The book has the title starting with "Til" but "Till" is added as a spelling alias to help with searches.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17975, '2017-09-25 21:00:31.896109+00', '2022-04-18 07:47:26.629935+00', 'TACbook Scotts', 'TACBOOK SCOTTS', 3, 48, NULL, 2, 3, 17, 10568, '2016-08-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18484, '2018-07-26 10:35:32.707486+00', '2018-07-26 10:35:32.707486+00', 'Its Nearly Christmas', 'ITS NEARLY CHRISTMAS', 1, 32, NULL, 2, 3, 17, 2886, NULL, '', 75, '800/888/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18965, '2018-10-13 21:27:26.408523+00', '2020-08-25 18:40:57.277709+00', 'Whalebones', 'WHALEBONES', 2, 32, NULL, 1, 4, 1, 11731, NULL, 'Devised by a team effort led by Mick Peat in ''A Dance for Whitby 86''', 47, '0840/0480/8000/4888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17992, '2017-10-08 20:00:52.259185+00', '2021-07-16 00:04:32.107572+00', 'Isle of Oleron Reel', 'ISLE OF OLERON REEL', 1, 32, NULL, 2, 3, 18, 11181, '2017-10-08', 'Long live to scottish dances in "Ile d''Oleron" (France)



Suggested music: Lanes of Au.', 83, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17972, '2017-09-25 20:55:23.151083+00', '2021-02-07 19:03:44.272356+00', 'On the Moxley''s Deck', 'ON THE MOXLEYS DECK', 3, 32, NULL, 2, 3, 17, 10568, '2015-08-01', 'I wanted to write a dance using the Maurice progression. We tried this at the Moxley''s cottage so I named it for them.', 75, '880/844/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15401, '2014-03-27 23:32:42.756932+00', '2018-09-07 14:28:25.227378+00', 'Newburgh Jig', 'NEWBURGH JIG', 2, 32, NULL, 1, 3, 42, 957, NULL, 'For Netta Berry, who teaches the Newburgh Church Scottish Country Dance Class, on her 70th birthday.', 47, '888/800/822/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18482, '2018-07-26 10:24:43.458676+00', '2018-09-28 22:34:32.189314+00', 'Celebration Reel', 'CELEBRATION REEL', 1, 32, NULL, 1, 3, 42, 2886, NULL, 'Message from JeanShaw.  My original instructions for bars 25-32 ended with: "1s ending in 2nd place own side".  In a later version I made an error in putting "1s cross over to 2nd place"!  Please accept my sincere apologies.  ', 40, '800/822/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15516, '2014-06-27 21:16:08.449228+00', '2019-01-23 18:01:18.967572+00', 'Florida Dream, A', 'FLORIDA DREAM', 1, 40, NULL, 1, 3, 42, 10971, NULL, '', 55, '800/888/844/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17930, '2017-09-15 16:05:46.986116+00', '2017-09-15 16:05:46.986116+00', 'Cattle Market, The', 'CATTLE MARKET', 1, 32, 9999, 1, 3, 42, 17, '2008-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17928, '2017-09-15 15:55:55.652736+00', '2017-09-15 15:56:03.926239+00', 'April Showers', 'APRIL SHOWERS', 3, 40, 9999, 1, 4, 2, 17, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17929, '2017-09-15 16:03:44.806749+00', '2017-09-15 16:03:44.806749+00', 'Bubble Down', 'BUBBLE DOWN', 3, 32, 9999, 2, 3, 18, 17, '2015-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17931, '2017-09-15 16:15:25.900832+00', '2017-09-15 16:17:11.612006+00', 'Farewell to St Andrews Hall', 'FAREWELL TO ST ANDREWS HALL', 3, 40, 9999, 1, 4, 11, 17, '2012-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17932, '2017-09-15 16:20:26.17537+00', '2017-09-15 16:20:26.17537+00', 'Fly the Flag', 'FLY THE FLAG', 1, 40, 9999, 1, 4, NULL, 17, '1978-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17933, '2017-09-15 16:24:04.559561+00', '2017-09-15 16:24:04.559561+00', 'From Grey to White', 'FROM GREY TO WHITE', 2, 32, 9999, 1, 4, NULL, 17, '2014-01-01', 'The author states the Jig, Reel, Strathspey or a Medley in 4x32 suits the dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17934, '2017-09-15 22:01:34.418534+00', '2017-09-15 22:01:34.418534+00', 'Gently Down the Stream', 'GENTLY DOWN THE STREAM', 3, 32, 9999, 1, 4, 2, 17, '2011-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17876, '2017-06-23 09:22:33.532184+00', '2018-05-26 02:07:36.390711+00', 'Arrogant Frog, The', 'ARROGANT FROG', 1, 32, NULL, 1, 3, 42, 10907, '2012-07-01', 'For Marie-Solange Pollard visiting Brisbane from the RSCDS Paris Branch. Marie-Solange became the proud recipient of a bottle of The Arrogant Frog red wine. It is a long way to travel to sample a bottle ''red'' from southern France.  



Devised by Francis Walduck, Brisbane, Queensland Branch RSCDS, July 2012.  

Suggested Music: Andrew''s Reel - track 5 - Bordering on Scottish - Marian Anderson and her SD

Band.', 69, '884/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17935, '2017-09-15 22:37:51.0739+00', '2017-09-15 22:37:51.0739+00', 'Moons of Jupiter', 'MOONS OF JUPITER', 1, 32, 9999, 1, 3, 42, 17, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17936, '2017-09-15 22:40:07.075175+00', '2017-09-15 22:40:07.075175+00', 'New Halsway Hop', 'NEW HALSWAY HOP', 2, 32, 9999, 1, 2, 76, 17, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17938, '2017-09-15 22:55:20.679122+00', '2017-09-15 22:55:20.679122+00', 'Spirit of Spring', 'SPIRIT OF SPRING', 2, 32, 9999, 1, 3, 42, 17, '2017-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17939, '2017-09-15 23:36:32.123156+00', '2017-09-15 23:36:32.123156+00', 'Tower Mills', 'TOWER MILLS', 1, 32, 9999, 1, 3, 42, 17, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17940, '2017-09-15 23:42:04.113097+00', '2017-09-15 23:42:04.113097+00', 'Winter Wonderland', 'WINTER WONDERLAND', 1, 32, 9999, 1, 3, 42, 17, '2014-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18634, '2018-09-18 20:42:35.210727+00', '2018-09-27 12:05:31.383909+00', 'Higher Math', 'HIGHER MATH', 1, 32, NULL, 107, 55, 35, 3617, '2005-01-01', 'Formation: 2 face 3', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16514, '2015-07-26 10:18:29.78524+00', '2019-03-22 23:32:55.647687+00', 'Trip to the Orkneys, A', 'TRIP TO THE ORKNEYS', 2, 32, NULL, 1, 4, 1, 3355, NULL, '', 75, '8080/8888/8800/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17948, '2017-09-22 16:08:45.683626+00', '2017-11-14 00:09:25.017334+00', 'Real Wedding Reel, The', 'REAL WEDDING REEL', 1, 64, NULL, 4, 4, 13, 3661, '2017-09-22', 'A present for Márta Lilik and Dániel Gera on their wedding.', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17961, '2017-09-25 19:21:38.502666+00', '2017-09-25 19:21:38.502666+00', 'Don Kent''s Connection Inspection', 'DON KENTS CONNECTION INSPECTION', 4, 128, 2, 4, 4, 54, 10568, '2015-10-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17990, '2017-09-26 23:12:18.099242+00', '2017-09-26 23:12:18.099242+00', 'Yellow Reel (Autumn Dance)', 'YELLOW REEL AUTUMN DANCE', 1, 32, 9999, 1, 3, 42, 11531, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18060, '2017-11-13 02:34:22.95063+00', '2018-04-02 23:56:38.140418+00', 'Tristan''s Trajectory', 'TRISTANS TRAJECTORY', 2, 32, NULL, 1, 3, 42, 1041, '2004-01-01', '', 56, '8440|8800|8880|8440', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19743, '2019-10-28 21:33:55.457198+00', '2019-10-28 21:33:55.457198+00', 'Melbourne Gold', 'MELBOURNE GOLD', 1, 32, NULL, 1, 3, 42, 11902, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17951, '2017-09-25 18:39:10.13021+00', '2021-02-09 17:22:30.463125+00', 'Biking in Aarhus', 'BIKING IN AARHUS', 2, 32, NULL, 2, 3, 18, 10568, '2013-05-01', 'This is written for Fiona, Peter, Chris, Shane and Ros who joined Don and me when we took a bike tour of Aarhus, Denmark. That was fun!', 79, '866/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17958, '2017-09-25 19:13:35.972414+00', '2021-05-07 21:10:13.894772+00', 'Cyprus Roundabout', 'CYPRUS ROUNDABOUT', 4, 128, 2, 4, 4, 54, 10568, '2017-05-01', 'Celebrating a vacation in Cyprus with the International branch.



Holly Boyd has reported that the instructions for bars 49-56 should be: All set to partners (2),  half a grand chain (4) and set facing in (2). The last two bars are missing from the book.', 100, '8888/8888/8888/8888/8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17949, '2017-09-24 15:10:44.039412+00', '2020-09-16 07:56:49.51122+00', 'Caledonian Club Centenary Medley, The', 'CALEDONIAN CLUB CENTENARY MEDLEY', 4, 32, 1, 1, 4, 1, 11525, '2017-01-01', 'Devised for the 100th anniversary of The Caledonian Club, Belgravia, London, in 2017.    



Bars 1-8 make the "1" of "100".  

Bars 9-12 make the "00" of "100".

', 86, '8888/8888/8222/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17953, '2017-09-25 18:45:02.128204+00', '2021-02-12 20:13:13.175748+00', 'Cat Lover''s Birthday, A', 'CAT LOVERS BIRTHDAY', 4, 128, 2, 4, 4, 30, 10568, '2015-09-01', '', 62, '8800/8800/8080/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17950, '2017-09-25 18:37:01.238876+00', '2021-02-09 11:57:37.411517+00', 'Alistair''s Dance', 'ALISTAIRS DANCE', 2, 32, NULL, 1, 3, 42, 10568, '2016-04-28', 'For Alistair Wood''s birthday', 69, '888/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17952, '2017-09-25 18:41:49.095365+00', '2021-02-10 16:10:21.509346+00', 'California Dreaming', 'CALIFORNIA DREAMING', 3, 32, NULL, 2, 3, 18, 10568, '2016-10-01', 'Celebrating Asilomar 2016', 100, '888/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17955, '2017-09-25 18:51:23.11159+00', '2021-02-13 01:53:25.439424+00', 'Chain, Chain, Chain', 'CHAIN CHAIN CHAIN', 4, 128, 2, 4, 4, 1, 10568, '2016-03-01', '', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18085, '2017-11-23 14:59:42.633972+00', '2017-11-23 14:59:42.633972+00', 'Ever Winding Road, The', 'EVER WINDING ROAD', 3, 32, 9999, 1, 4, 1, 3357, '2007-01-01', 'Devised by Joan Tuffery, Southland Region, to celebrate the St Andrew''s Scottish Country Dance Club''s 50th Anniversary in 2007.



Suggested music: The Hiking Song', 72, '8080/8888/8884/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18197, '2017-12-27 19:50:44.500286+00', '2017-12-27 20:27:57.862194+00', 'Secret Rendezvous, A', 'SECRET RENDEZVOUS', 3, 24, NULL, 1, 2, NULL, 44, '1991-02-23', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16527, '2015-07-31 14:08:56.336503+00', '2017-10-11 22:25:56.728467+00', 'Ruby Rant, The', 'RUBY RANT', 1, 32, 9999, 1, 3, 42, 10907, '2015-01-01', 'To mark the 40th Australian Winter School in 2015, hosted by Queensland Branch.



On [1-8] we have a modified formation "Set and Rotate": set, cast clw half round, cross with P.', 56, '880/866/866/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17973, '2017-09-25 20:57:46.855344+00', '2023-02-23 00:54:19.455926+00', 'Ramona''s Dance', 'RAMONAS DANCE', 2, 32, NULL, 5, 2, 76, 10568, '2016-02-01', '', 100, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18001, '2017-10-11 12:49:49.827616+00', '2018-04-10 11:12:10.820863+00', 'Joe''s Delight', 'JOES DELIGHT', 3, 32, 9999, 1, 3, 42, 10853, '2017-06-01', 'For Joe Murphy, my teacher, mentor and special friend. Joe joined the Carlisle and Border Branch in 1967. He served on the committee for over 40 years in many different roles including Chairperson. He taught the Branch class for around 5 years.', 47, '822/844/880/808', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18012, '2017-10-12 14:47:38.513031+00', '2018-04-10 11:17:19.592396+00', 'Table Mountain Beauty', 'TABLE MOUNTAIN BEAUTY', 3, 32, 9999, 2, 3, 17, 11220, '2017-01-01', 'Bars 25 -32 are known locally in Cape Town as the ''Littlecroft'' formation as devised by Christpher Gilmour in the dance Littlecroft Strathspey.



The Table Mountain Beauty (Aeropetes tulbaghia) is a butterfly found on Table Mountain and is the pollinator for the Red Disa (Disa uniflora). 

This dance was devised as a farewell gift for Nina Hobbhahn to remind her of shared happy memories in the Western Cape.', 58, '800/880/880/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18000, '2017-10-11 12:36:15.843604+00', '2018-04-10 11:33:51.545428+00', 'Hleka Bafazi', 'HLEKA BAFAZI', 1, 64, 9999, 4, 4, 13, 10582, '2016-01-01', 'Hleka Bafazi is the Xhosa and Zulu name for a Southern African bird called the Green Wood-Hoopoe. This name is derived from the call that the bird makes which sounds like a group of woman merrily going about their business.Translated into English it means "Laughing Woman". This dance is a tribute to all the women who have made meaningful contributions to my Scottish Country dancing. Amongst the laughing women I include Joan Evans, Terry McBurnie, Rose McMillan, Helen Frame, Urisa Reungsuwan, Coral Epton, Kim Mills and of course my wife Heather.', 100, '8888/8888/8888/8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18005, '2017-10-12 11:02:59.005771+00', '2018-04-10 11:35:38.291837+00', 'Liebet''s Fancy', 'LIEBETS FANCY', 3, 32, 9999, 1, 4, 1, 10853, '2017-06-01', 'For Liebet Joubert''s twentieth birthday.', 81, '8888/8440/8448/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18008, '2017-10-12 13:09:20.527721+00', '2018-04-10 11:42:33.055317+00', 'Reel of Sapphires, A', 'REEL OF SAPPHIRES', 1, 32, 9999, 1, 3, 42, 3254, '2017-01-01', 'A dance in celebration of the Pretoria club''s sapphire (45th) anniversary in 2017.', 45, '660/066/820/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18010, '2017-10-12 14:08:55.438825+00', '2019-02-03 22:31:13.90541+00', 'Six', 'SIX', 2, 32, 9999, 2, 3, 17, 3254, '2013-08-01', 'In the winter of 2013, with attendance numbers down to six on many dance evenings, we needed three-couple dances, hence this dance and its name.', 75, '484/888/484/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18011, '2017-10-12 14:23:53.252912+00', '2018-04-08 08:12:36.387747+00', 'Spring Rains', 'SPRING RAINS', 2, 32, 9999, 2, 2, 76, 3254, '2013-11-01', '', 58, '80/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18009, '2017-10-12 13:49:17.998448+00', '2018-04-08 08:33:43.226404+00', 'Short Visit, A', 'SHORT VISIT', 2, 32, 9999, 1, 100, 11, 3179, '2017-02-02', 'Devised by Wouter Joubert, 2 February 2017, for Mervyn Short.



* My preference is for one chord only with 3rd and 4th couples already on opposite sides from the start.', 75, '0880/4884/8888/4884', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18015, '2017-10-12 15:48:28.859275+00', '2018-04-09 13:21:53.920025+00', 'Together We Are', 'TOGETHER WE ARE', 2, 32, 9999, 1, 3, 42, 10853, '2017-06-01', 'This dance is dedicated to all past and present membrs of the RSCDS Pretoria Branch.', 69, '888/888/888/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17875, '2017-06-23 09:22:08.025414+00', '2018-05-26 05:54:29.13072+00', 'Your Lady is Waiting', 'YOUR LADY IS WAITING', 3, 32, NULL, 2, 2, 76, 10907, '2013-06-01', 'For Greg and Naree Paulsen, our travelling companions through Eastern Europe and Ireland 2013. Greg was always taking another photo as the group moved on.  



Devised by Francis Walduck, Brisbane, Queensland Branch RSCDS, June 2013.  

Suggested music: West End, track 6, Haste Ye Back-Muriel Johnstone''s Scottish Dance Band.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17679, '2017-03-31 09:09:14.882042+00', '2018-07-08 13:29:01.960232+00', 'Eiffel Tower, The', 'EIFFEL TOWER', 1, 32, 9999, 1, 3, 42, 10397, NULL, 'Erratum:  In the published book, bars 17-20 say "1st man dances across the set, passes 3rd lady right shoulder ..." - 1st man actually passes 3rd lady LEFT shoulder.



A dance written to commemorate the engagement of Richard Campbell and Jose MacQueen,

two members of Gay Gordons (Manchester), who got engaged on the Eiffel Tower in Paris.  



Imagery:  



1-8 – the crowds mingling at the bottom of the Eiffel Tower  

9-16 – the lift up the Eiffel Tower  

17-24 – exchanging of rings  

25-32 – leaving the Eiffel Tower hand-in-hand  ', 36, '800/844/833/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18007, '2017-10-12 12:14:12.861387+00', '2018-07-23 10:12:07.142521+00', 'Reel for Leny, A', 'REEL FOR LENY', 1, 32, 9999, 1, 3, 42, 10853, '2013-11-01', 'For Leny Druif on the occasion of her 80th birthday.', 64, '888/820/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17456, '2016-10-30 12:23:40.546889+00', '2018-09-05 06:27:39.81017+00', 'Wee Mary''s Strathspey', 'WEE MARYS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 433, NULL, 'Mrs Mary Wilson had a passion for Scottish Country Dancing and each year she attended the Summer School in St Andrews organised by the Royal Scottish Country Dance Society. She travelled to dances in the north of England and all over Scotland. She would never dream of “sitting one out”. Always smiling, and dearly loved by everyone, she had a great zest for life. To all her many friends she was known simply as “Wee Mary”.', 79, '888/888/660/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15298, '2013-12-10 19:22:35.337927+00', '2018-08-21 16:07:01.358281+00', 'Golden Chains', 'GOLDEN CHAINS', 3, 48, NULL, 4, 4, 1, 28, '2012-01-01', 'Set shape:  The original instructions carry a heading "4 couples in a 4 couple longwise set".  The instructions, however, only make sense if the dance is in a Square Set, and that is what we, the editors, have assumed in writing this database entry, with crib and diagram.



Devised by Dorothy Bell, a founder member of RSCDS Bristol Branch, in honour of the 50th Anniversary of the Branch, and her return to visit and dance at the Ball in the City of Bristol Council House on 10th March 2012.', 75, '8888/4444/6666/4444/6666/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18516, '2018-08-21 09:29:00.870165+00', '2018-09-05 16:46:44.403423+00', 'Walnut Tree, The', 'WALNUT TREE', 1, 32, NULL, 1, 4, 2, 11509, '2017-12-01', 'This dance was devised to teach the formation reel of four.  

My husband and I bought a house in summer 2004, and one of the things we did in the garden within the first year, was to plant a walnut tree. This tree has now grown quite big in our small garden, and it gives lots of walnuts every year, with which I can bake my favourite walnut cake, and which I can take with honey for breakfast as well.', 75, '8008/8448/8888/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18635, '2018-09-18 20:53:43.600385+00', '2018-09-18 20:55:28.465904+00', 'Isle of Toddy, The', 'ISLE OF TODDY', 2, 32, NULL, 1, 3, NULL, 11710, '2014-12-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18507, '2018-08-17 14:01:06.983908+00', '2018-10-03 02:19:36.077664+00', 'Cloud Cover', 'CLOUD COVER', 3, 32, NULL, 2, 3, 4, 2766, '2012-08-01', 'This dance was written when we finally had an overcast day after a long, hot summer drought.', 67, '800/844/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15518, '2014-06-27 21:17:19.992827+00', '2019-01-23 18:11:42.458441+00', 'Florida Fling, The', 'FLORIDA FLING', 1, 32, NULL, 1, 4, 2, 10971, NULL, '', 90, '8888/8008/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17947, '2017-09-17 10:32:10.253979+00', '2018-04-09 09:36:31.624451+00', 'Gratitude', 'GRATITUDE', 2, 40, 9999, 1, 3, 42, 10853, '2017-06-01', 'In memory of Margaret Parker (Peggy), a vera dear friend from Carlisle and Border Branch.Peggy passed away on 28 June 2017. She joined the carlisle and Border Branch in 1955, becoming a committee member shortly afterwards and loyally served in all committee roles over 60 years. Latterly she was elected President, a role she served in actively until the day she left us.', 55, '880/888/800/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18014, '2017-10-12 15:37:17.188674+00', '2018-04-08 08:42:39.02373+00', 'Through the Mist', 'THROUGH THE MIST', 2, 32, 9999, 1, 3, 42, 3254, '2016-03-01', 'The title for this dance came to me while driving up Tom Jenkins Drive over Pretoria''s Meintjieskop (Meintjies Hill) through the mist on a very welcome day of rain in the midst of a crippling drought.', 61, '888/820/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17946, '2017-09-17 10:31:21.687435+00', '2018-04-08 10:22:37.38197+00', 'Friendship', 'FRIENDSHIP', 3, 32, 9999, 1, 3, 42, 10853, '2017-06-01', 'For Wouter Joubert, to mark a special birthday.', 55, '800/886/880/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17874, '2017-06-23 09:21:35.253247+00', '2019-10-27 23:53:04.762367+00', 'Northern Spring, The', 'NORTHERN SPRING', 2, 32, NULL, 3, 5, 7, 10907, '2013-05-01', 'Spring in the northern hemisphere 2013 was chilly and wet, however, the leafless tress were budding and coming into flower and the daffodils and tulips were everywhere. The colour in the bleakness was a vivid contrast.  



Devised by Francis Walduck, Brisbane, Queensland Branch RSCDS, May 2013.  

Suggested music: Jig Generic, track 05, Strictly Scottish Vol 1 - Robert Whitehead''s SD Band.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18013, '2017-10-12 15:26:00.432849+00', '2018-04-09 09:32:51.015033+00', 'Three is Magic', 'THREE IS MAGIC', 3, 32, 9999, 2, 3, 17, 11520, '2017-07-01', 'We listened to the audio recording of Harry Potter and the Prisoner of Azkaban, while driving down to Betty''s Bay for a family wedding. This, as well as the tune, The Forbidden Forest, inspired this dance. I wanted to write a Harry Potter related dance to go with the title of the tune, so I decided to use the number three - for the trio of main characters: Harry, Ron, and Hermione. Thus we have a three couple dance in a three couple set, using formations of three wherever possible, titled ''Three is Magic''.', 79, '646/646/888/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18016, '2017-10-12 16:04:55.933717+00', '2019-02-23 19:00:17.08651+00', 'Very Happy Birthday, A', 'VERY HAPPY BIRTHDAY', 1, 32, 9999, 1, 100, 2, 3179, '2014-03-01', 'For Gill Wocke''s 60th birthday celebration.



*As the devisor my personal preference is for one chord only with the 3rd and 4th couples already on opposite sides from the start.', 66, '8228/8008/8888/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18198, '2017-12-27 19:53:46.456146+00', '2018-04-03 00:07:52.44303+00', 'Holding Hands in the Moonlight', 'HOLDING HANDS IN THE MOONLIGHT', 3, 32, NULL, 1, 3, 42, 44, '2016-07-24', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17873, '2017-06-23 09:21:01.590493+00', '2018-05-27 06:20:29.171643+00', 'Italian Tryst, The', 'ITALIAN TRYST', 3, 32, NULL, 1, 3, 42, 10907, '2013-05-01', 'Four of our intrepid travellers ventured off early to spend a couple of weeks in Rome and points north before we all met up in Budapest. The food and accommodation in places are described as ''very Italian'' but much enjoyed experiences.  



Devised by Francis Walduck, Brisbane, Queensland Branch RSCDS, May 2013.  

Suggested music: Brunette d''Ecosse, track 11, Reel Friends Book 2 - David Hall and his SCD Band.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18086, '2017-11-23 16:28:32.761888+00', '2017-11-23 16:28:32.761888+00', 'Memories of the Canongate', 'MEMORIES OF THE CANONGATE', 3, 32, 9999, 1, 4, 2, 11035, NULL, 'Devised by Gaye Collins, Wellington Region, for Charlotte Williams (who named the dance)



Suggested music: Fran''s Fancy, Dancing on Air by Muriel Johnstone', 75, '8888/8008/8008/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18089, '2017-11-23 18:14:00.570334+00', '2017-11-23 18:14:00.570334+00', 'Wee Davy', 'WEE DAVY', 3, 32, 9999, 3, 5, 16, 3262, NULL, 'Devised by Coreen Wallis, Canterbury Region, for Dave Lindsay''s 50th birthday July 2002.



Suggested music: Scotch Mist, Highlander Series Volume 6 by Drummond Cook', 63, '82820/80800/88888/82824', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18354, '2018-05-27 09:08:18.037307+00', '2018-10-22 09:26:27.708745+00', 'Teachers'' Twin Birthday', 'TEACHERS TWIN BIRTHDAY', 1, 32, NULL, 2, 3, 17, 11225, NULL, 'For Joana and Roger', 54, '800/844/844/804', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4553, '1997-08-12 22:00:00+00', '2018-05-29 17:38:37.146725+00', 'Miss McPherson Grant''s Jig', 'MISS MACPHERSON GRANTS JIG', 2, 32, 9999, 1, 3, 42, 129, '1969-01-01', '', 56, '840/804/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14353, '2011-12-14 23:00:00+00', '2017-11-11 13:53:38.922019+00', 'Ladebraes', 'LADEBRAES', 3, 32, NULL, 1, 4, 2, 854, '2009-01-01', '<<scddb:not-identical:3572>>



Notes: Ladebraes in St Andrews, Scotland is a short cut between South Street and the Boys Brigade Hall used by dancers ''in the know'' on the long walk to the hall. Ladebraes was one of the possible titles of The Chequered Court when I wrote it in 2001. However, I decided that Ladebraes sounded like a strathspey rather than a quick time dance, so here is the dance to go with the title!





', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18363, '2018-06-03 14:43:32.029488+00', '2018-06-03 14:43:32.029488+00', 'Jig for Robert Black, A', 'JIG FOR ROBERT BLACK', 2, 40, NULL, 1, 3, 42, 11636, NULL, 'The dance, devised by Jack Pressley, was for Robert Black who is one of the greatest ever Scottish Musicians whose extra ordinal talent spans many styles of music and is in great demand by all.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14987, '2013-07-24 14:24:15.921898+00', '2017-11-10 23:55:15.978265+00', 'Minister on the Mississippi, The', 'MINISTER ON THE MISSISSIPPI', 3, 32, NULL, 1, 3, 42, 2408, '2012-12-01', 'Devised December 2012 by Lara Friedman-Shedlov (lfriedmanshedlov [at] gmail.com) in memory of RSCDS Twin Cities Branch member Alan Grant, who passed away on October 29. A native of the Pacific Northwest, Alan spent most of his adult life in Minneapolis and many years living along the shores of the Mississippi.

', 54, '800  818  888  866', 0, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (4562, '2000-02-21 23:00:00+00', '2021-05-07 19:53:27.066866+00', 'Miss Nancy Frowns', 'MISS NANCY FROWNS', 2, 32, 9999, 1, 3, 42, 466, '1751-01-01', 'Former RSCDS Archivist Marilyn Healy writes:



> Miss Nancy  -  frowns or Frowns?  The source is Thompson’s Compleat

> Collection of 200 Favourite CD c.1755 (there is a copy in the archive) and

> it clearly shows ‘Miss Nancy frowns’ i.e. it’s not her surname!  

', 50, '880  800  888  844', 0, 1, 0, 1, 66);
INSERT INTO 'dance' VALUES (18019, '2017-10-20 07:28:32.932577+00', '2022-12-08 16:05:46.248015+00', 'Queensland Twosome, The', 'QUEENSLAND TWOSOME', 1, 32, NULL, 1, 3, 42, 11139, '2015-07-06', 'The dance was created during the 40th Australian Winter School in Brisbane, Australia.  It''s written for Emma Nixon and Iain Mckenzie. who were playing for the evening social on the night the dance was devised.

(Amy Luxton-Esler).', 59, '888/840/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4464, '1997-04-03 22:00:00+00', '2018-05-29 17:56:46.63336+00', 'Miss Edwina Angus', 'MISS EDWINA ANGUS', 2, 32, 9999, 1, 3, 42, 129, NULL, '', 51, '864/800/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13635, '2010-11-10 23:00:00+00', '2017-10-22 20:33:41.360818+00', 'Mortar-Board, The', 'MORTARBOARD', 1, 32, 9999, 2, 3, 17, 10285, NULL, 'Notes from "The Vienna Book":  

This dance was devised by the members of the Vienna Branch of the RSCDS to mark the graduation of Elisabeth Wolzt.



A <<https://en.wikipedia.org/wiki/Square_academic_cap|mortar-board>> should be used if possible, otherwise any suitable hat. The dance begins with 1st man wearing the hat.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18187, '2017-12-24 08:32:28.568666+00', '2018-04-03 00:08:01.099555+00', 'Macfarlane''s Lantern', 'MACFARLANES LANTERN', 1, 32, NULL, 1, 3, 42, 2525, '2003-11-30', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13629, '2010-11-10 23:00:00+00', '2017-10-22 19:23:20.050148+00', 'Ambassadors'' Reel, The', 'AMBASSADORS REEL', 1, 32, 9999, 1, 3, 42, 589, '2007-01-01', 'The dance was devised as a farewell present of the RSCDS Vienna Branch to John and Judith MacGregor, British Ambassadors in Vienna and Bratislava. 

John Macgregor had been the Honorary President of the Branch for a couple of years. John and Judith MacGregor were leaving Austria in August 2007 as their appointments as ambassadors to Vienna and Bratislava came to an end. 



The dance and tune was presented to them at the end-of-season dance at the residency of the British ambassador in Vienna.



A Note from "The Vienna Book":  

This is a very fluid dance. Although conventional barring is used in the description above, it should be taken only as an approximation of what happens at any given point in the dance. For the sake of convenience, couples should start and end each turn of the dance in the sidelines, facing each other.

', 44, '800  800  844  888', 1, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (3766, '1997-04-03 22:00:00+00', '2017-11-03 21:58:08.008778+00', 'Leeze Me', 'LEEZE ME', 3, 32, 9999, 1, 4, 1, 363, '1984-01-01', 'Slow Air Strathspey



Devised in 1984 to commemorate the 25-year involvemenl of James'' wife Phyllis in Scottish Country Dancing. "Leeze Me" is on old Scottish expression meaning "Dear Is To Me".



Bars 1 - 8 Visiting both islands of New Zealand.  

Bars 9 - 12 Making friends and dancing with New Zealanders.  

Bars 13 - 16 Returning to Australia.  

Bars 17 - 24 Visiting St. Andrews and Europe.  

Bars 25 - 32 Dancing in Scotland and returning home.  ', 66, '8008/8888/8000/6688', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18042, '2017-11-08 07:40:59.932865+00', '2017-11-09 09:03:53.644554+00', 'Music Melts Upon the Evening Breeze', 'MUSIC MELTS UPON THE EVENING BREEZE', 3, 32, NULL, 2, 3, 18, 11455, '2014-01-01', 'The title is a line from "Great Things and Small" by D.H. Edwards', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18309, '2018-04-28 13:00:14.803764+00', '2018-10-30 22:28:00.656232+00', 'Surbiton Frolic, The', 'SURBITON FROLIC', 1, 40, NULL, 1, 3, 42, 616, '2017-12-01', 'Devised in honour of the 70th anniversary of the Surbiton & District Caledonian Society. 



The instructions were revised slightly in July 2018 to be clear that 1st couple pass each other left shoulder on bars 17 and 33 when entering the (right shoulder) half reels and pass right shoulder between the half reels.

', 50, '800/866/844/866/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18054, '2017-11-13 00:02:52.64661+00', '2017-11-13 00:02:52.64661+00', 'Welcome to the Strobel-Mühle', 'WELCOME TO THE STROBELMUHLE', 3, 32, NULL, 1, 3, 42, 228, '2017-11-11', 'The deviser explains: “For the dancers at the 7th Chemnitz SCD Weekend in November, 2017,

which took place, for the first time, at the Strobel-Mühle, near Pockau-Lengefeld, in the remote

mountains of Saxony. The Strobel-Mühle (Strobel Mill) is a residential training centre operated by the

CVJM (YMCA for our Anglophone friends). I had been invited to teach the

not-quite-beginners/intermediate class and had originally

planned to teach <<ddd:The Byron Strathspey>> in the Saturday afternoon session, but then

didn’t get around to explaining reels of three during the morning session, so desperate action was

called for – hence this dance! I’m pleased to say that it was reasonably well received.”

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18020, '2017-10-20 16:05:13.437142+00', '2020-11-12 10:17:15.450442+00', 'Gay Gordons Two Step', 'GAY GORDONS TWO STEP', 11, 16, NULL, 5, 1, NULL, 9999, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12089, '2005-03-16 23:00:00+00', '2021-01-17 12:38:46.117503+00', 'Five-Couple Macdonald of the Isles (Big Mac)', 'FIVECOUPLE MACDONALD OF THE ISLES BIG MAC', 3, 32, 9999, 3, 5, 7, 1047, NULL, '', 76, '48884/48884/86884/44088', 0, 1, 1, 0, 76);
INSERT INTO 'dance' VALUES (18356, '2018-05-30 20:51:33.849764+00', '2021-04-17 17:25:46.689192+00', 'Katrina''s Kapers', 'KATRINAS KAPERS', 1, 32, NULL, 3, 5, 7, 11638, '2017-05-19', 'To celebrate Katrina Osborne''s 50th birthday.  Published in The Reel, <<https://www.rscdslondon.org.uk/wp-content/uploads/2019/02/Reel-306-electronic.pdf#page=13|issue 306>>, December 2018.



A video of the dance can be found on the Richmond Caledonian society website: <<www.richmondcaledonian.co.uk/photo_gallery_select.php>>', 83, '86868/83863/83863/88888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13642, '2010-11-10 23:00:00+00', '2017-10-22 20:57:01.268165+00', 'Thirty plus Ten (30 + 10)', 'THIRTY PLUS TEN 30  10', 2, 40, 9999, 4, 4, 1, 10288, '2004-01-01', '10 bar phrases



A Note from "The Vienna Book":  

Devised by Beatrix Wepner for Jutta Kribala on the occasion of her 30 plus 10th birthday in 2004.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14973, '2013-07-03 21:51:54.001662+00', '2019-04-02 20:49:36.471636+00', 'Weaving Together', 'WEAVING TOGETHER', 3, 32, NULL, 1, 3, 42, 10805, NULL, '', 55, '820/844/884/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14530, '2012-07-27 07:40:00.425892+00', '2018-04-03 00:07:36.177252+00', 'Busy Bee, The', 'BUSY BEE', 2, 32, 9999, 1, 3, 42, 589, '2009-01-01', 'Dedicated to Michaela Haslinger for her 40th birthday.



The patterns of the dance are inspired by Michi’s endless energy, her ability to buzz from one thing to the next and to organise others into following her lead.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16617, '2015-08-27 02:09:40.583165+00', '2018-06-01 13:02:46.261221+00', 'Díky Marie', 'DIKY MARIE', 3, 32, NULL, 2, 3, 17, 11164, '2012-10-01', 'Devised for Marie Stanzel', 81, '888/820/848/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18043, '2017-11-08 07:46:03.220693+00', '2018-04-03 00:08:13.075287+00', 'Rin Wuid', 'RIN WUID', 1, 32, NULL, 1, 3, 42, 11455, '2014-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16509, '2015-07-21 14:50:49.652728+00', '2018-05-30 08:03:58.093712+00', 'Flora''s Cross', 'FLORAS CROSS', 3, 32, NULL, 1, 3, 42, 10961, '2014-03-01', 'This dance, devised in March 2014, was inspired by the monument to Flora MacDonald in Kilmuir Cemetery on the Isle of Skye.  

The cross shape formed by the reels of four is reminiscent of the memorial stone.', 53, '747/888/648/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15343, '2014-02-20 13:38:53.918188+00', '2018-06-01 14:22:53.390351+00', 'Brockbank''s Drowning', 'BROCKBANKS DROWNING', 2, 32, NULL, 1, 3, 42, 3694, NULL, 'The idea for this dance came from an inscription on a bridge over the river Tay which joins the villages of Strathtay and Grandtully. It is a memorial to Charles Brockbank a man from Birmingham who drowned in the river in 1873. He was possibly one of the first canoeing tourists and still the only one to drown in the river which runs rapidly and dangerously under the bridge.', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16027, '2015-02-10 12:50:45.859284+00', '2018-06-02 17:34:49.802966+00', 'Lilly and Grumpy', 'LILLY AND GRUMPY', 2, 32, 9999, 4, 4, 46, 3694, NULL, 'For my granddaughter Lilly who couldn’t quite manage to say Grandad which somehow turned into Grumpy, I wonder why.  



Please note set and link back to back was originally devised by John Drewry in the Bankhead Collection 5', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16031, '2015-02-11 12:48:19.788992+00', '2018-06-03 08:06:05.554587+00', 'Haytor Reel, The', 'HAYTOR REEL', 1, 32, 9999, 1, 3, 42, 3694, '2011-10-28', 'Written to celebrate the week-end of dance organised by the Westbury Scottish Dance group 28th-30th October 2011', 44, '800/844/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18359, '2018-06-03 14:29:31.664661+00', '2018-06-03 14:29:31.664661+00', 'Day at The Beach, A', 'DAY AT THE BEACH', 1, 32, NULL, 1, 3, NULL, 11640, NULL, 'The dance was devised by Patrick Carter (aged 10) and member of CSCDS Inc. wrote the dance on the way to the beach

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18072, '2017-11-13 15:49:12.554818+00', '2020-09-05 11:05:26.623194+00', 'Rubinus Portus Novi', 'RUBINUS PORTUS NOVI', 3, 40, NULL, 4, 4, 13, 1167, '2017-09-11', '', 100, '8888|8888|8888|8888|8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18360, '2018-06-03 14:32:00.956477+00', '2018-06-03 14:32:26.902059+00', 'James Carter''s Strathspey', 'JAMES CARTERS STRATHSPEY', 3, 40, NULL, 2, 3, 18, 11640, NULL, 'Dance was devised by Patrick Carter (CSCDS Inc.) for his father James who has been a great supporter and promoter of Scottish Country Dancing. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18361, '2018-06-03 14:34:43.534966+00', '2018-06-03 14:34:43.534966+00', 'Jig for Jennifer C., A', 'JIG FOR JENNIFER C', 2, 32, NULL, 2, 3, NULL, 11639, NULL, 'The dance was devised by David Carter, member of the Charlotte Scottish Country Dance Society and dedicated to his mother Jennifer', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18055, '2017-11-13 01:02:09.217204+00', '2017-11-13 01:02:09.217204+00', 'Waters of Jona, The', 'WATERS OF JONA', 3, 32, NULL, 2, 3, 18, 671, NULL, 'The deviser says: “Jona [in Switzerland – SCDDB ed.] is the town where I live. It''s also the name of the river that runs through it.”



DEVISED:2012-05', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18024, '2017-10-22 22:00:58.939483+00', '2020-11-12 10:21:58.830382+00', 'Scottish Covenant, The', 'SCOTTISH COVENANT', 3, 48, NULL, 1, 4, 1, 11537, '1950-01-01', '', 36, '8000/8800/8800/8000/8000/8222', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18067, '2017-11-13 15:19:54.757194+00', '2020-11-12 10:27:56.164315+00', 'Young Foxes, The', 'YOUNG FOXES', 1, 32, NULL, 1, 3, 42, 3101, NULL, '', 56, '8000|8880|8880|8440', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7073, '1998-09-30 22:00:00+00', '2021-03-31 09:42:26.691302+00', 'What you please', 'WHAT YOU PLEASE', 2, 40, 9999, 1, 3, 42, 9998, NULL, 'The old MMM Vol 2 says for bars 25-40:  

25-32: 1st and 3rd couples make a circle and dance 8 slip steps round to left and 8 back again.  

33-40: 1st and 2nd couples make a circle and dance 8 slip steps round to left and 8 back again.



The revised combined MMM edition 0f 2007 says:

25 - 32 1st and 3rd couples dance four hands round and back.  

33 - 40 2nd and 1st couples dance rights and lefts.  

(this is the same as in Miss Milligan''s still earlier "99 More").



The source is given as:  

Skillern, T: *Twenty Four Country Dances for the Year 1781*  

Customary tune: *What you please* (Skillern)  ', 45, '880/880/800/808/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18023, '2017-10-22 21:58:09.356723+00', '2021-04-19 10:17:12.106003+00', 'St Andrew''s Day', 'SAINT ANDREWS DAY', 2, 64, NULL, 1, 4, 1, 11537, '1949-01-01', 'Modified version. The original published instructions (<<https://my.strathspey.org/dd/dance/18076/|Dance 18076>>) were for a 48 bar dance.  This has been altered to improve danceability.  Bars 17-32 took 8 bars and bars 41-64 have been changed.



The original publication, Two National Dances of Scotland, describes this dance on the cover page, on the title page and on the dance description page as a Reel while the music, in the same publication and with the same title, composed by the dance deviser is in 6-8 time, i.e. a Jig.



This dance is discussed in RSCDS London Branch''s The Reel, 

(<<https://www.rscdslondon.org.uk/wp-content/uploads/2017/11/Reel-301-electronic.pdf|Issue 301>>  and <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-302-Electronic.pdf|Issue 302>>)', 56, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18027, '2017-10-25 09:21:55.276182+00', '2017-10-25 09:21:55.276182+00', 'Fun at Forty', 'FUN AT FORTY', 2, 40, NULL, 1, 4, NULL, 2673, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18362, '2018-06-03 14:37:53.729688+00', '2018-06-12 21:36:13.244659+00', 'Jig for Jyllian, A', 'JIG FOR JYLLIAN', 2, 32, NULL, 1, 3, 42, 11640, NULL, 'Dance was devised by Patrick Carter (aged 10) for his eldest sister Jyllian.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18030, '2017-10-25 09:27:14.279363+00', '2017-10-25 09:27:14.279363+00', 'Nethervale', 'NETHERVALE', 2, 32, NULL, 1, 4, NULL, 2673, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18032, '2017-10-25 09:30:09.273866+00', '2017-10-25 09:30:09.273866+00', 'Tonkle Knot', 'TONKLE KNOT', 1, 32, NULL, 4, 4, NULL, 2673, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18026, '2017-10-25 09:20:43.819179+00', '2017-10-25 17:34:48.19314+00', 'Elms, The', 'ELMS', 1, 32, NULL, 1, 4, NULL, 2673, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16128, '2015-02-27 10:12:13.501553+00', '2018-07-11 01:01:27.877376+00', 'Border Lads and Lassies', 'BORDER LADS AND LASSIES', 3, 32, 9999, 1, 3, 42, 11103, NULL, 'Devised by Lyn Bryce for Ann Naismith in recognition of her contribution to Scottish Country Dancing and her many years of teaching all age groups, especially in the Scottish Borders. ', 49, '880/800/880/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18035, '2017-10-26 16:45:00.020099+00', '2018-04-02 23:56:33.472833+00', 'Chocolate Raspberry Swirl', 'CHOCOLATE RASPBERRY SWIRL', 3, 40, NULL, 1, 3, 42, 2677, '2004-01-01', 'unpublished - draft notes for the Picton workshop 23 April 2005.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18034, '2017-10-26 14:12:06.878662+00', '2018-04-02 23:56:33.907653+00', 'Deborah''s Request', 'DEBORAHS REQUEST', 1, 32, NULL, 1, 3, 42, 1167, '2014-01-26', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18025, '2017-10-25 09:18:59.07227+00', '2018-04-02 23:56:34.040961+00', 'Dumgoyne', 'DUMGOYNE', 2, 32, NULL, 1, 3, 42, 2673, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18039, '2017-10-29 17:15:43.616375+00', '2017-10-29 17:43:20.196632+00', 'Trip to San Juan, A', 'TRIP TO SAN JUAN', 2, 32, NULL, 1, 4, 1, 11200, '2017-11-11', '', 50, '8800/8000/8000/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18028, '2017-10-25 09:24:23.783299+00', '2018-04-03 00:07:59.865227+00', 'Liz''s Diamond Reel', 'LIZS DIAMOND REEL', 1, 32, NULL, 1, 3, 42, 2673, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18029, '2017-10-25 09:25:42.897714+00', '2019-02-11 18:20:58.283419+00', 'Meikle Twosome', 'MEIKLE TWOSOME', 1, 32, NULL, 4, 4, 13, 2673, NULL, '', 50, '4040/8080/4040/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16958, '2016-05-27 21:37:11.224371+00', '2017-11-02 02:31:22.516185+00', 'Let''s Ask Avril !', 'LETS ASK AVRIL ', 3, 32, NULL, 1, 3, 18, 11263, NULL, '*From the book:*



On the occasion of Avril and David''s departure from Geneva, in 2015.



We love you and wish you all the best in Germany!



Note: The dance contains so-called "push me pull you reels" where the dancing couple dances Figures of Eight around their corners, while the corners dance Back to Back twice.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13505, '2009-11-21 23:00:00+00', '2018-08-21 20:48:03.840909+00', 'Three Creeks Shore, The', 'THREE CREEKS SHORE', 2, 32, 9999, 1, 3, 42, 1269, '2007-01-01', 'A rugged slope from the bottom of Patrol Road to the beach area adjoining the Hythe.', 50, '844/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17912, '2017-08-05 13:19:05.628846+00', '2017-11-05 13:16:41.981832+00', 'Teapots, The', 'TEAPOTS', 2, 32, NULL, 2, 3, 17, 11514, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18041, '2017-11-07 21:26:29.515289+00', '2017-11-07 21:26:29.515289+00', 'Morland High Jinks', 'MORLAND HIGH JINKS', 4, 32, 55, 1, 4, 2, 108, '2006-01-01', 'A dance for the week of dancing in Morland ln the summer of 2006.



Could be danced as Strathspey or Reel or Medley (i.e. Strathspey and Reel). However, John Drewry suggests this dance to be danced four times as a strathspey and then four times as a reel.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17370, '2016-09-16 14:56:35.119161+00', '2018-08-27 19:42:24.381008+00', 'Welcome Dance, The', 'WELCOME DANCE', 1, 32, NULL, 5, 1, 4, 9998, NULL, 'Single circle, all facing toward the center with Lady on Gentleman’s right.', 62, '88/08/80/44', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18033, '2017-10-25 10:12:25.44728+00', '2018-09-14 18:04:13.150397+00', 'Palace Pier', 'PALACE PIER', 1, 40, NULL, 1, 3, 42, 2673, NULL, 'Devised for the Brighton and Hove Scottish Dance Club to celebrate their Diamond Jubilee.  Unfortunately Alice ''passed away'' before she could see it danced at the 60th Tartan Ball in May 2012.  Music specially composed by Alastair Forbes.', 50, '888/800/444/444/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18625, '2018-09-18 15:07:40.358188+00', '2018-09-19 02:56:44.181693+00', 'Abby''s Reel', 'ABBYS REEL', 1, 32, NULL, 1, 2, 76, 3617, '2014-11-21', 'This dance was originally Halloween Reel (1999) but we adjusted it Nov 21/2014.  Judy''s new granddaughter was born the same week, Abby Keeling.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16957, '2016-05-27 21:33:12.515502+00', '2019-02-19 23:12:35.409165+00', 'Bye-Bye Bluebelle', 'BYEBYE BLUEBELLE', 3, 32, 9999, 2, 3, 17, 11262, '2015-01-01', 'Composed for Avril and David Quarrie (and Bluebelle) on their leaving Geneva for more northerly climes.', 83, '484/888/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18031, '2017-10-25 09:28:08.185351+00', '2019-02-11 18:13:09.334596+00', 'Pandora Way', 'PANDORA WAY', 2, 32, NULL, 4, 4, 13, 2673, NULL, '', 75, '8080/8888/8080/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18394, '2018-07-12 16:29:51.618187+00', '2019-06-24 21:52:55.867947+00', 'Alan''s Romp', 'ALANS ROMP', 2, 32, NULL, 1, 3, 42, 11237, '2018-02-01', 'For Alan Ip who liked the dance on its first test.', 56, '822/866/866/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18047, '2017-11-10 17:34:06.999927+00', '2018-04-04 21:12:49.847427+00', 'White Eagle', 'WHITE EAGLE', 2, 32, 9999, 1, 3, 42, 11555, '2017-04-01', 'The dance was written for Richard Schmidt who founded the White Eagle Dance Academy

in Montreal in 2008. He taught Polish dances in Japan in 2013, 2015 and 2017.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18068, '2017-11-13 15:25:09.884514+00', '2018-04-02 23:56:33.405899+00', 'Catriona''s Ramble Through Scotland', 'CATRIONAS RAMBLE THROUGH SCOTLAND', 3, 32, NULL, 1, 3, 42, 3098, NULL, '', 69, '8880|8800|8880|8880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3943, '1997-09-08 22:00:00+00', '2020-08-06 15:51:47.54726+00', 'Lord Malcolm Douglas-Hamilton Reel, The', 'LORD MALCOLM DOUGLASHAMILTON REEL', 1, 40, 9999, 1, 3, 42, 921, '1967-01-01', 'This dance was devised in memory of the late Lord Malcom Douglas-Hamilton, Scottish patriot and founder of the  American Scottish Foundation.', 47, '800/844/844/844/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14993, '2013-07-24 15:05:57.172212+00', '2017-11-11 00:31:54.102917+00', 'Maggie and Caitlin', 'MAGGIE AND CAITLIN', 1, 32, NULL, 1, 3, 42, 10811, NULL, 'Devised by J. A. McKernan (jamckern [at] gmail.com) for Maggie and Caitlin on leaving Minnesota for Oregon, May 2012. It is a fast-paced dance to reflect Maggie and Caitlin''s youth and vitality, it has a 1C solo to reflect their relationship, a chase to represent travel (4 bars to get to Oregon, pretty speedy!) and CPCP to suggest making new Scottish dance friends there.



Original text copied from 8x32



1-4     1st couple set advancing, turn both hands to face down nearer hands joined.

5-8     1st couple dance below 3rd couple, cross and cast up to 2nd place on opposite sides.

9-16     Right hands across: 1st man with 2nd couple, 1st woman with 3rd couple. Left hands across: 1st woman with 2nd couple, 1st man with 3rd couple.

17-20     All chase anti-clockwise halfway around the set.

21-24     3rd and 2nd couples dance half rights and left WHILE 1st couple cross right hand and cast right to face 1st corners.

25-32     1st couple turn corner, partner, corner, partner.', 53, '800  888  888  822', 1, 1, 1, 0, 70);
INSERT INTO 'dance' VALUES (14367, '2011-12-16 23:00:00+00', '2017-11-11 13:36:49.19588+00', 'As Cedar Falls, So Falls Waterloo', 'AS CEDAR FALLS SO FALLS WATERLOO', 2, 32, NULL, 4, 4, 46, 1268, '2010-09-01', 'for Lee and Karen Potter; September 2010



THE PUN.  Lee and Karen Potter live in Cedar Falls, Iowa. They built a dance floor in the basement of their home, and held a party to inaugurate the floor (and celebrate their 1st anniversary). This dance was written for the party.   Hence the pun: As Cedar Falls..... Falls is really a noun, but when you put it in this structure, it becomes a verb.



THE TEASE   We have numerous instances of cities in the United States that are so close to another city that they get hyphenated. Minneapolis-St. Paul, Fargo-Moorhead, Cedar Falls-Waterloo.  Typically, the people who live in the first of the hyphenated cities do not want to be associated with the people who live in the second hyphenated city. And vice versa.  So, I am teasing Lee and Karen by putting Waterloo in the title of the dance.  Sorry, it takes longer to explain the title than to teach the dance...', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14351, '2011-12-14 23:00:00+00', '2017-11-13 14:19:49.877122+00', 'Miss Dow''s Strathspey', 'MISS DOWS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 246, NULL, 'Devised by Alan Macpherson (amdmac [at] blueyonder.co.uk). 



"Miss Dow was a very influential figure in promoting and developing SCD in the Dundee area and some have described her as the "Miss Milligan" of the East. Alistair Macfadyen was of the opinion that Miss Dow deserved more recognition from the Society than was accorded to her, and Alistair suggested that a dance in her honour would be a fitting tribute and that I should write such a dance for publication by the Society. The strathspey, "Miss Dow''s Strathspey", was devised by me and submitted to the Society in the mid 90s, but unfortunately it was rejected."



"The composer of the tune ''Miss Dow''s Fancy'' was John Reid (1869-1942), a famous Angus "Dancie" from Newtyle. He taught step dancing at the early Summer Schools and his Newtyle Orchestra provided the music for the Younger Hall dances. ''Miss Dow''s Fancy'' was first played by John Reid''s orchestra at a Dundee Branch dance in the Training College Hall on the 14th December, 1934"', 62, '880  888  888  844', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (18049, '2017-11-10 20:26:06.401814+00', '2018-04-04 21:28:10.702526+00', 'Cascade Jig, A', 'CASCADE JIG', 2, 32, 9999, 1, 4, 1, 3783, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18200, '2017-12-27 19:56:33.148329+00', '2017-12-27 19:56:33.148329+00', 'Parting Kiss, The', 'PARTING KISS', 3, 32, NULL, 2, 3, NULL, 44, '1998-08-21', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13473, '2009-11-17 23:00:00+00', '2018-10-14 09:12:58.930012+00', 'There and Back', 'THERE AND BACK', 1, 32, NULL, 1, 3, 42, 146, NULL, '', 56, '800  888  888  844', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (18045, '2017-11-09 20:10:45.705578+00', '2019-03-27 23:34:42.607734+00', 'After Three Gins', 'AFTER THREE GINS', 1, 64, 9999, 1, 4, 1, 11552, '2017-01-01', 'Stricty speaking the progression after 64 bars is (2,3,1,4), as 1s step down and 4s up on bars 1 and 2 of the next repeat.  But the dance functions as if it had the normal (2,3,4,1) progression.





', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12999, '2006-11-01 23:00:00+00', '2017-11-11 19:03:26.029298+00', 'Ladies of Schiehallion, The', 'LADIES OF SCHIEHALLION', 4, 64, 5, 1, 100, 1, 3723, '2005-01-01', 'The dance tells a story:

Part one of the story is in strathspey  because the party hasn’t gotten going yet and it denotes the personality of one of the roommates. The Set and Rotate figure represents the opening of a champagne bottle – so only the top 2 couples dance – representing the cork.  After the cork pops, the champagne bubbles up and spills out and down the sides of the bottle. This bubble up figure was devised by Michael Bentley. The constant flowing movement in the reel of four represents the pouring of the champagne and in the last figure of strathspey - the people are setting in little groups talking - but decide to circulate to see who else is at the party – then the couples decide to split up and get the party going.



Part two of the story is in quick time to represent the personality of the other roommate – and because the party is now in full swing.  Dancing the Schiehallion reels is always fun and lively - just like a party.  Then it’s time to settle down – take a breather – look for a place to rest for awhile.  While the top 2 couples rest (and think about opening another bottle of champagne in strathspey time) – the bottom 2 couples have found a little champagne left in the old bottle and decide to finish it off - with the Slip Knot – danced up as the bottle empties. Don’t worry – the Schiehallion ladies would never have just one bottle of champagne – in fact they have four – so all 4 couples have a chance to open a bottle, dance, and have a “Reel” good time.   

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18062, '2017-11-13 02:49:38.923165+00', '2018-03-31 17:46:08.476027+00', 'Boys Hornpipe, A', 'BOYS HORNPIPE', 1, 32, NULL, 2, 2, 76, 11563, '2017-01-01', 'Recommended Tune: Drunken Sailor', 58, '880|440|880|880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18058, '2017-11-13 02:22:16.638065+00', '2017-11-13 02:22:16.638065+00', 'Middletown Welcome', 'MIDDLETOWN WELCOME', 2, 32, NULL, 5, 2, 76, 3097, '2008-09-02', '', 100, '88|88|88|88', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18063, '2017-11-13 02:55:20.20558+00', '2020-11-12 10:26:00.459292+00', 'Great Day for Dancing, A', 'GREAT DAY FOR DANCING', 1, 40, NULL, 1, 3, 42, 969, '2017-01-01', '', 60, '8000|8880|8880|8440|8880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18091, '2017-11-26 11:43:57.641349+00', '2019-05-06 11:48:02.557776+00', 'Yorkshire Man, The', 'YORKSHIRE MAN', 2, 32, 9999, 1, 3, 42, 1727, NULL, 'With fond memories of Alan Brown, my own Beginner dance teacher.', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15122, '2013-09-13 13:12:12.056631+00', '2018-04-07 07:03:35.568093+00', 'Turning Sixty', 'TURNING SIXTY', 2, 48, 9999, 2, 3, 17, 10858, NULL, 'Devised by Anna-Marie Arnold, 2011, for the celebration of Miles Arnold''s sixtieth birthday. Miles is a descendant of the Mackenzie Clan of Eilean Donan Castle, Scotland.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14357, '2011-12-14 23:00:00+00', '2018-04-03 00:18:02.254686+00', 'Lairds'' Diamond, The', 'LAIRDS DIAMOND', 3, 32, NULL, 2, 2, 76, 2983, '2003-01-01', 'Devised by Peter McClure (joptmc [at] cc.umanitoba.ca), for Rena and Adam Laird, on the occasion of their Sixtieth Wedding Anniversary, 10 April 2003. Rena and Adam were married in Glasgow in 1943, and emigrated to Winnipeg a few years later. A devoted couple - symbolised by the solo turn for the first couple - they have also been very active in their community, both Rena''s hospitality and Adam''s music being appreciated by many people, including visitors to Winnipeg from faraway parts of the world. The reel of four is central to Scottish country dancing, as they have been central in their community, and the Diamond Poussette salutes their Diamond Anniversary. ', 67, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18056, '2017-11-13 02:14:22.210923+00', '2018-04-02 23:56:33.489676+00', 'Civic Accord', 'CIVIC ACCORD', 2, 32, NULL, 1, 3, 42, 11562, '2006-01-01', 'Petronella Double Triangles - corners petronella to next corner positioning a counter clockwise direction on bars19-20 and 23-24.



This dance was written in 2006 for the Greater hartford Scottish country Dance Demo Team. At the time of devising, most of the members drove Hondas.', 56, '8000|8440|8880|8880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18048, '2017-11-10 17:53:40.35025+00', '2021-10-20 15:09:42.082248+00', 'Charlottetown', 'CHARLOTTETOWN', 3, 32, 9999, 1, 4, 1, 10958, '2017-07-01', '', 94, '8484/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18061, '2017-11-13 02:38:37.20254+00', '2018-04-02 23:56:38.290658+00', 'Unfortunate Snow Incident, The', 'UNFORTUNATE SNOW INCIDENT', 2, 32, NULL, 1, 3, 42, 11562, NULL, '', 56, '8000|8880|8880|0880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18059, '2017-11-13 02:29:25.377335+00', '2018-10-25 21:48:25.289304+00', 'Triangular Jig, A', 'TRIANGULAR JIG', 2, 32, NULL, 6, 53, 18, 11032, '2014-03-01', 'Recommended Music: "Cool as a Cucumber" from Tartan Capers by The White Cockade', 83, '844|888|888|484', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18064, '2017-11-13 03:01:45.743316+00', '2018-10-25 21:49:26.26356+00', 'Reel for Lady Di, A', 'REEL FOR LADY DI', 1, 32, NULL, 1, 3, 42, 3097, NULL, '', 56, '8880|8880|8000|8800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14428, '2012-05-06 23:03:31.433994+00', '2017-11-14 06:21:22.680475+00', 'Silver Heather', 'SILVER HEATHER', 2, 32, NULL, 1, 3, 42, 3135, '2012-05-01', 'Official description, published with the author''s permission.



Bars

1 - 4 	1W followed by 1M cast off one place (2C step up on 3-4) and cross to opposite side

5 - 8 	2C + 1C RHA (and 1W faces out)

9 - 12	1W followed by 1M cast off one place (3C step up on 11-12) and cross to own side 

13 - 16	1C + 3C LHA

17- 20	1C cross RH and cast up one place (3C step down)

21 - 24	1C dance petronella turn (to 1M between 2C, 1W between 3C), and all set in lines across the dance

25 – 28	1C cross RH up/down, cast to the Right to second place on own side while 2M + 3M and 2W + 3W dance back to back

29 – 32	all turn partner RH



Repeat having passed a couple.



Suggested recording: 	“Sarah’s Favourite” in “Reels and Wheels” by Gordon Shand and his Scottish Dance Band.



This dance was devised in May 2012 for the coming Silver Jubilee of the Geldermalsen Scottish Country Dance Group “White Heather” in 2013.

', 47, '840  804  822  888', 1, 1, 1, 0, 62);
INSERT INTO 'dance' VALUES (18073, '2017-11-14 08:44:51.146256+00', '2017-11-14 08:44:51.146256+00', 'Rock Lily, The', 'ROCK LILY', 2, 32, NULL, 1, 2, 76, 325, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14364, '2011-12-16 23:00:00+00', '2017-11-14 16:28:04.676994+00', 'Laird of Dalnair, The', 'LAIRD OF DALNAIR', 1, 32, NULL, 1, 3, 42, 1415, '2010-04-01', 'This dance is dedicated to Alan Munro. He lives at Dalnair farm and has been affectionately called "The Laird of Dalnair".', 62, '800  888  888  888', 0, 0, 0, 0, 83);
INSERT INTO 'dance' VALUES (18074, '2017-11-15 04:37:12.611225+00', '2017-11-20 08:42:51.055986+00', 'Linton Whipman, The', 'LINTON WHIPMAN', 1, 32, NULL, 1, 2, 76, 2408, '2015-07-05', 'Devised by Lara Friedman~Shedlov, with help from Helen Bruce, Dan Friedman~Shedlov, and Janet

and Stuart McKernan. Debuted on 5 July 2015 on the lower green of the village of West Linton,

Scotland (see https://youtu.be/GzQ5HUfricM). The dance represents the traditions of the annual

Whipman Play , with the Whipman and his lass riding out, along with the left  and right hand

supporters.



It is also a play on the traditional dance, “The Linton Ploughman.”



Whipman is the old Scots word for a carter or carrier, and the story of the Linton play began in 1803

when the Whipman Benevolent Society, providing mutual aid to its members, held their annual

meeting. The Whipman Play is an annual summer festival held in the village of West Linton, and is one

of the Scottish Borders'' oldest festivals.  A local man is elected to the office of "Whipman" and he

chooses a young lady to be his "Lass". The celebrations begin with the Installation of the Whipman

and Lass, followed by a celebratory ceilidh. The following day, the Ride Out (of around 80 to 100

horses) introduces the Whipman to the area, and a full week of events culminates in the annual sports

day, held on the village green.



*When Summer smiles in sweet delight,



And field are starred with daisies white,



Upon a certain gladsome night,



Rejoicings start in Linton.*', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18366, '2018-06-03 14:52:47.268237+00', '2018-07-08 10:52:03.317261+00', 'Many Thanks', 'MANY THANKS', 3, 32, NULL, 2, 3, 18, 11639, NULL, 'Dance was devised by David Carter (CSCDS Inc.) for Jack Pressley and Jamie Pressley, teacher and treasurer of CSCDS Inc, Charlotte, NC.', 85, '886/866/888/088', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15309, '2013-12-19 10:47:02.311931+00', '2019-07-18 17:26:22.683466+00', 'Anne Archdeacon Reel, The', 'ANNE ARCHDEACON REEL', 1, 40, 9999, 1, 4, 2, 10907, '2011-09-01', 'To mark the occasion of the presentation of the Society’s ''Scroll'' to Anne Archdeacon for her work in the development and continued growth of Scottish Country Dancing in Far North Queensland. September 2011.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15229, '2013-11-09 22:52:42.678235+00', '2018-12-07 17:49:34.87246+00', 'Turn, Turn, Turn', 'TURN TURN TURN', 3, 32, NULL, 2, 3, 17, 3369, '2012-10-01', 'Author''s note: I will leave the choice of music up to you, but I like the Music Makars "Beauty of the North" from their CD "Jig for Joy"', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18077, '2017-11-21 18:02:02.459422+00', '2018-04-02 23:56:34.633787+00', 'For a Special Lady', 'FOR A SPECIAL LADY', 3, 32, NULL, 1, 3, 42, 3775, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18081, '2017-11-22 13:40:39.682963+00', '2017-11-22 14:04:02.26892+00', 'Ron''s Strathspey', 'RONS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 3775, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18088, '2017-11-23 17:43:30.624495+00', '2017-11-23 17:43:30.624495+00', 'Shaky Island Schottische', 'SHAKY ISLAND SCHOTTISCHE', 3, 32, 9999, 2, 3, 17, 1066, NULL, 'Devised by Yvonne Plant, South Canterbury Region, to acknowledge all those affected by the Canterbury earthquakes in 2010-2011.', 65, '842/844/844/808', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18075, '2017-11-20 15:26:35.984095+00', '2019-07-13 20:35:26.506214+00', 'Lock 3 Jig', 'LOCK 3 JIG', 2, 32, NULL, 1, 3, 42, 11565, '2009-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18079, '2017-11-21 18:09:19.009151+00', '2019-02-01 15:53:23.933812+00', 'Never done before', 'NEVER DONE BEFORE', 2, 32, NULL, 1, 3, 42, 3775, NULL, 'Devised  for Ute Schüssler who likes to say: “Never done (this dance) before” and loves the figure dance to each corner and set. ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17905, '2017-08-02 14:35:47.74232+00', '2019-04-18 17:37:41.263725+00', 'Glenoe', 'GLENOE', 3, 32, NULL, 2, 3, 17, 573, '2017-03-23', 'Devised by Daphne Jones, 23rd March 2017, for Elma McCausland MBE, who lives at Glenoe, Bangor, Co. Down', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15121, '2013-09-13 13:10:20.000237+00', '2018-04-09 13:18:59.085084+00', 'Shadows and Reflections', 'SHADOWS AND REFLECTIONS', 2, 32, 9999, 2, 3, 17, 64, NULL, 'Devised by Irene van Maarseveen, 11 September 2007.



Inspired by Thelma''s comment to Nicole: "I''ll be your shadow". Nicole was a little girl of about 7 at the time who came to dancing with her grandfather. One evening, to help Nicole cope with a more difficult dance, Thelma became her dancing shadow, guiding her through her part by dancing closely behind her.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18393, '2018-07-12 16:22:34.204695+00', '2023-02-28 21:46:07.203856+00', 'Luke''s Life in London', 'LUKES LIFE IN LONDON', 1, 32, NULL, 1, 100, 2, 11237, '2016-06-01', 'For Luke Bradley.', 84, '8228/8888/8888/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15104, '2013-09-12 15:29:16.286375+00', '2018-04-10 08:58:07.767593+00', 'Elephants Don''t Forget', 'ELEPHANTS DONT FORGET', 3, 32, 9999, 2, 3, 17, 3179, '2010-10-01', 'Devised by Wouter Joubert, October 2010, as a happy reminder of the visit by Helen Frame and Jean Martin during September 2010. While they were here we visited the Elephant Sanctuary at the Hartebeespoort Dam and at the ball we hosted in honour of their visit Jean commented about the fact that elephants are believed lo have excellent memories ... 



The figure described in bars 3-6, 11-14 and 25-28 is commonly known as ''Turn and Twirl''.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18095, '2017-11-26 14:18:09.641978+00', '2017-11-26 14:18:09.641978+00', 'Catherine''s Wedding', 'CATHERINES WEDDING', 3, 32, 9999, 1, 100, NULL, 1727, NULL, 'For my daughter, Catherine - and my daughter-in-law, another Catherine.

The "double cross" figure was conceived by Alison Moen and Peter Richards.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18098, '2017-11-27 17:45:37.497701+00', '2017-11-27 17:45:37.497701+00', 'Fancy Ladies', 'FANCY LADIES', 3, 32, 9999, 3, 5, 7, 1727, '2005-01-01', 'Devised in 2005 for Barbara Fancy and her daughter, Nina.', -1, '82842/80088/84444/88888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18100, '2017-11-27 18:20:08.364512+00', '2017-11-27 18:20:08.364512+00', 'Special Birthday, A', 'SPECIAL BIRTHDAY', 3, 32, 9999, 1, 4, 11, 1727, NULL, 'Devised for the birthday of Kay Sutherland, whose ability to ''cover'' is a delight to her teacher.', 59, '4440/4440/6666/8668', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18094, '2017-11-26 14:05:26.05674+00', '2019-10-08 21:14:57.594303+00', 'Whisky Jack', 'WHISKY JACK', 2, 32, 9999, 1, 4, 2, 1727, NULL, 'The Whisky Jack is a cheeky jay found in Canada, who is very bold and quick at stealing food even from one''s hand.', 88, '6886/6886/8888/4884', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18368, '2018-06-03 14:57:27.644236+00', '2018-06-03 14:57:27.644236+00', 'To Pennsylvania and Back', 'TO PENNSYLVANIA AND BACK', 1, 32, NULL, 4, 4, NULL, 11639, NULL, 'Dance was devised by David Carter (CSCDS Inc.)  for his elder sister Jyllian who is a nun in Pennsylvania.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15109, '2013-09-13 10:15:30.155832+00', '2017-11-29 13:17:02.515419+00', 'Goodness Gracious Grasshopper', 'GOODNESS GRACIOUS GRASSHOPPER', 1, 40, NULL, 1, 3, 42, 10855, '2012-01-01', 'Devised by Ryan Nelson, 2012.



At night my son Duncan always wants me to dance with him. When I showed him how to dance for the first time, he exclaimed: "Goodness Gracious Grasshopper!" over and over again while dancing with me. Good Gracious Grasshopper is a character in the animated DVD "The Easter Egg Escapade", which he had watched two dozen times or more.



I dedicate this dance to Duncan as he is my pride and joy and I am sure he will join me in dancing class in the not-too-distant future. ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18092, '2017-11-26 11:58:10.933866+00', '2018-09-10 15:11:48.162016+00', 'Treasured Cove, The', 'TREASURED COVE', 3, 32, 9999, 1, 4, 2, 1727, NULL, 'With thanks to Jean Dodds of Adelaide, Australia, for teaching the Deep Cove class in 2008/2009', 69, '8448/8008/8808/8808', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18093, '2017-11-26 13:45:51.012518+00', '2019-03-10 17:11:21.237596+00', 'Laughing Lizzie', 'LAUGHING LIZZIE', 1, 32, 9999, 1, 3, 42, 1727, NULL, 'For Liz Johnstone, one of my former teachers and now a great friend.', 75, '880/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18099, '2017-11-27 17:57:14.604494+00', '2018-04-02 23:56:35.986508+00', 'Macallan, The', 'MACALLAN', 1, 32, 9999, 1, 3, 42, 1727, '2015-01-01', 'Devised for Dort Landley''s 15th Anniversary Whisky Dance in 2015.



The 12-bar formation reflected the door prize of a bottle of 12-year-old Macallan.', 85, '864/888/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18189, '2017-12-24 08:39:25.129943+00', '2017-12-24 08:39:25.129943+00', 'Salute to the Legionnairs', 'SALUTE TO THE LEGIONNAIRS', 1, 32, NULL, 1, 4, NULL, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6677, '1998-07-08 22:00:00+00', '2018-07-13 00:48:21.578952+00', 'Tranter''s Rant', 'TRANTERS RANT', 2, 40, 9999, 1, 4, 11, 21, NULL, 'For Frank Tranter', 85, '0880/8888/8888/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18395, '2018-07-12 16:47:34.291583+00', '2019-01-18 19:22:03.164138+00', 'Hidden Heart, The', 'HIDDEN HEART', 3, 80, NULL, 4, 4, 3, 11237, '2017-09-01', 'For David Quarrie. After many years of energetic dancing, David’s sporran wore a small hole in his kilt. This was neatly repaired by costume designer Marina Harrington with a (normally hidden) heart shaped patch.', 75, '8008/8008/0880/0880/8888/8888/6666/6666/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18203, '2018-01-01 11:24:35.273272+00', '2018-01-07 20:46:38.772517+00', 'Just for Jo', 'JUST FOR JO', 3, 32, NULL, 3, 129, 30, 372, NULL, 'Jo Chapman has for many years been the secretary of the Great Ayton Scottish Country Dance Club', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18202, '2017-12-27 19:59:01.907736+00', '2018-04-03 00:08:25.300223+00', 'Wherever You May Be', 'WHEREVER YOU MAY BE', 2, 32, NULL, 1, 3, 42, 44, '2010-08-04', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18193, '2017-12-27 19:45:13.253629+00', '2018-08-18 00:00:58.311292+00', 'Collonel''s Daughter, The', 'COLLONELS DAUGHTER', 2, 32, NULL, 1, 3, 42, 44, '1998-10-24', '', 53, '800/888/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18097, '2017-11-26 19:59:34.988616+00', '2019-08-16 06:54:11.070638+00', 'Shores of Black Mill Bay, The', 'SHORES OF BLACK MILL BAY', 3, 32, NULL, 2, 3, 17, 11570, '2017-08-17', 'Deviser says: “Dedicated to Steff Eckert, remembering our lovely stay at the island of Luing at „The Gorsten Bed & Breakfast“, run by Julia Shuff. We hade an interesting „walk“ at the beach with me hopping from stone to stone, from mudhole to mudhole and - of course - me kissing the earth. Eventually, we sat on a rock at the beach, listening to the waves and mother nature.”', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3690, '1998-07-08 22:00:00+00', '2019-04-02 20:18:46.053697+00', 'Land Of The Heather Hills', 'LAND OF THE HEATHER HILLS', 3, 32, 9999, 1, 100, 11, 313, NULL, 'The title was suggested by a line by R. L. Stevenson: "In the land of the heathery hills".', 75, '8008/8448/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11041, '2002-11-24 23:00:00+00', '2017-12-12 12:20:46.270242+00', 'Thistle Dew', 'THISTLE DEW', 2, 32, 9999, 1, 3, 42, 64, '1995-01-01', 'Devised by Irene van Maarseveen, Pretoria, South Africa; 1995.



This dance was devised for a beginners'' class. When a suitable dance containing specific formations could not be found, this dance evolved and it was decided that "This'' ll do".', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11031, '2002-11-24 23:00:00+00', '2017-12-04 09:44:16.968166+00', 'Finders Keepers', 'FINDERS KEEPERS', 4, 64, 5, 1, 2, 76, 64, '1995-11-01', 'Recommended music: Her Majesty Is Welcome



Devised by Irene van Maarseveen, Pretoria, South Africa; Nov. 1995.



This dance was born one evening during a beginners'' class of one, Alexandre Filipov from Bulgaria.



Dedicated to Cooks Dauth, for the many times she has made me aware of points that I had failed to notice where dancing technique could be improved and who "found" the name that the dance has "kept".', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18109, '2017-12-13 14:37:31.99878+00', '2018-04-02 23:56:33.732137+00', 'Dancing Dustbins', 'DANCING DUSTBINS', 2, 32, NULL, 1, 3, 42, 550, '2002-10-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18096, '2017-11-26 16:29:10.720681+00', '2021-07-19 17:12:29.755056+00', 'Dales of Stirling, The', 'DALES OF STIRLING', 2, 40, 9999, 3, 5, 7, 1727, NULL, 'For my cousins, Alan and Alison Dale, who live in Stirling, Scotland', 71, '82820/84884/84884/88808/82888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11050, '2002-11-24 23:00:00+00', '2017-12-06 14:16:05.996625+00', 'Wouter and Tobie', 'WOUTER AND TOBIE', 3, 32, 9999, 1, 4, 2, 3224, '1994-01-01', 'Recommended music: Culla Bay (SSCD 07) or The Strathspey King (EWO 001) "The Music Makars"



Devised by Lyn Christie, Pretoria, South Pretoria; 1994.



This dance was devised for the weeding of Wouter Joubert and Tobie Muller.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8328, '2002-04-28 22:00:00+00', '2017-12-08 21:15:13.599898+00', 'Black Leather Jig, The', 'BLACK LEATHER JIG', 1, 32, 9999, 1, 3, 42, 2079, NULL, 'Title is a reverse play on all the dances titled reels that are really jigs & strathspeys- this is a jig that is really a reel



Note: Video 2 - for FUN! It was unrehearsed and we were letting our hair down.', 53, '800  888  888  822', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (18105, '2017-12-11 11:43:49.767034+00', '2017-12-11 11:57:00.453729+00', 'Hamburg Welcome 2012', 'HAMBURG WELCOME 2012', 1, 32, NULL, 5, 2, 30, 1582, '2012-01-01', 'Devised as a warm-up dance for the Hamburg weekend 2012', 100, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18112, '2017-12-13 14:55:19.464989+00', '2023-01-18 16:43:21.564222+00', 'Holy Corner', 'HOLY CORNER', 2, 32, NULL, 1, 3, 42, 550, '2013-03-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18116, '2017-12-13 15:13:18.843272+00', '2023-01-18 16:45:42.087347+00', 'New Scotland Gold', 'NEW SCOTLAND GOLD', 2, 32, NULL, 1, 3, 42, 550, '1996-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18108, '2017-12-11 14:19:54.996301+00', '2017-12-11 20:08:52.576111+00', 'Adelaide Two- Step, The', 'ADELAIDE TWO STEP', 11, 32, NULL, 5, 2, 30, 815, NULL, 'Sandy Dodds:  husband to Jean Dodds, teacher in Adelaide Branch RSCDS.   

 

Peter Clark: for the Australian Winter School 2003

', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18370, '2018-06-03 15:01:31.874146+00', '2018-06-03 15:01:31.874146+00', 'Wayne Robertson''s Reel', 'WAYNE ROBERTSONS REEL', 1, 40, NULL, 1, 3, 42, 11636, NULL, 'The dance, devised by Jack Pressley, was for Wayne Robertson who is one of the great Scottish accordionists who has been a long time friend of my wife Jamie and I. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18107, '2017-12-11 14:12:08.276174+00', '2017-12-11 20:08:58.552398+00', 'Change and Go', 'CHANGE AND GO', 11, 32, NULL, 104, 2, 4, 1582, '2013-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18365, '2018-06-03 14:50:06.597805+00', '2019-02-03 21:12:52.331069+00', 'Light and Shade', 'LIGHT AND SHADE', 3, 32, NULL, 2, 3, 17, 11639, NULL, 'Dance was devised by David Carter (CSCDS Inc.) for Jim Stott who visited Charlotte, NC for the CSCDS Inc. annual "REEL SCOTTISH WEEKEND".', 80, '822/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18371, '2018-06-03 15:03:21.504151+00', '2018-06-03 15:03:52.363163+00', 'Week Not in Scotland, A', 'WEEK NOT IN SCOTLAND', 1, 40, NULL, 1, 4, NULL, 11639, NULL, 'The dance was devised by David Carter (CSCDS Inc.) when he was not able to go to Summer School because of a previously planned trip to Peru.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11044, '2002-11-24 23:00:00+00', '2017-12-12 12:07:47.48808+00', 'Touch of Tartan, A', 'TOUCH OF TARTAN', 1, 32, 9999, 1, 3, 42, 64, '1995-11-01', 'Devised by Irene van Maarseveen, Pretoria, South Africa; November 1995.



This dance was devised for a beginners'' class, to introduce the concept of corners.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18104, '2017-12-11 11:32:36.236375+00', '2017-12-12 17:58:22.793276+00', 'Guid Tae Ken Ye', 'GUID TAE KEN YE', 11, 32, NULL, 5, 2, 30, 1582, '2016-10-01', 'Devised on the spur of the moment for a warm up dance in October 2016.', 94, '88/88/88/66', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18118, '2017-12-13 15:21:41.593091+00', '2018-12-04 15:42:40.155494+00', 'Camserney Strathspey', 'CAMSERNEY STRATHSPEY', 3, 32, NULL, 2, 3, 18, 11235, '2016-12-11', '', 58, '880/882/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18119, '2017-12-13 16:07:46.555671+00', '2017-12-13 16:07:46.555671+00', 'Prestonfield Reel, The', 'PRESTONFIELD REEL', 1, 32, NULL, 5, 2, 76, 550, '2001-05-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18190, '2017-12-24 08:43:19.109947+00', '2017-12-24 08:43:19.109947+00', 'Silvery Tay, The', 'SILVERY TAY', 3, 32, NULL, 1, 3, 42, 2525, '2004-01-19', 'Suitable music Peggy''s Love', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18191, '2017-12-24 08:51:36.896513+00', '2017-12-24 08:51:36.896513+00', 'Subtle Hint, The', 'SUBTLE HINT', 2, 32, NULL, 1, 4, NULL, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18192, '2017-12-24 08:56:50.404137+00', '2017-12-24 08:56:50.404137+00', 'We Meet Again', 'WE MEET AGAIN', 1, 32, NULL, 2, NULL, NULL, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18372, '2018-06-05 00:05:32.203653+00', '2018-06-05 16:19:48.063646+00', 'Finkenwerder Fancy, The', 'FINKENWERDER FANCY', 1, 96, NULL, 4, 4, 3, 2874, '2018-05-01', 'DEVISED:2018-05', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18117, '2017-12-13 15:20:29.516497+00', '2019-07-02 20:24:20.929244+00', 'Strathspey for a Perfect Day', 'STRATHSPEY FOR A PERFECT DAY', 3, 40, NULL, 1, 100, 2, 550, '2008-06-01', 'For Diane Breslin on the occasion of her marriage to Avi Chatterjee in Edinburgh on the 7th of June 2008.', 80, '8888/8888/8448/8448/8008', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18374, '2018-06-10 11:21:49.828552+00', '2018-06-10 11:21:49.828552+00', 'Rush Hour', 'RUSH HOUR', 1, 32, NULL, 1, 3, 42, 11641, NULL, 'DEVISED:2010-07

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18120, '2017-12-13 16:14:10.765943+00', '2017-12-13 16:16:27.291531+00', 'Sixth of November, The', 'SIXTH OF NOVEMBER', 3, 32, NULL, 2, 3, 17, 550, '2008-11-07', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18121, '2017-12-13 21:14:42.375057+00', '2018-04-04 21:21:15.69238+00', 'Strathspey for Stan', 'STRATHSPEY FOR STAN', 3, 32, NULL, 1, 3, 42, 515, '2017-03-01', 'Dedicated to Stan Hamilton whose wonderful music has been enjoyed by dancers and

listeners from all over the world.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18148, '2017-12-23 12:58:50.309843+00', '2017-12-23 13:00:18.365838+00', 'Getting There is Lots of Fun', 'GETTING THERE IS LOTS OF FUN', 2, 32, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18369, '2018-06-03 14:59:42.713146+00', '2020-11-15 12:15:35.494493+00', 'Tribute to John Wilkinson, A', 'TRIBUTE TO JOHN WILKINSON', 2, 32, NULL, 6, 3, 17, 11639, NULL, '', 96, '866/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18145, '2017-12-22 23:56:17.578353+00', '2021-06-06 19:31:50.044856+00', 'In the Wee Small Hours of the Morning', 'IN THE WEE SMALL HOURS OF THE MORNING', 2, 32, NULL, 1, 3, 42, 2525, '2004-11-05', 'Sleepless nights are the best time for devising dances', 69, '880/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5885, '1998-04-19 22:00:00+00', '2017-12-17 16:28:51.206365+00', 'Sands of Morar', 'SANDS OF MORAR', 3, 32, 9999, 1, 3, 42, 313, '1983-01-01', 'The »Sands of Morar« are on the west coast of Scotland, between

Arisaig and Morar (south of Mallaig on the A380). Lovers of the cinema

will recognise parts of the sands from the Bill Forsyth film,

<<http://www.imdb.com/title/tt0085859/|Local Hero>>.

(The village apparently near the beach as shown in the film is

actually in a completely different part of Scotland – Pennan, on the

east coast.)', 56, '800  888  888  880', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (9864, '2001-05-20 22:00:00+00', '2018-04-26 22:50:31.481294+00', 'Islay', 'ISLAY', 3, 40, 9999, 3, 5, 16, 2886, '1992-01-01', 'Jean Shaw rewrote the dance in 2017; that is the version shown on this site.  



The following crib follows original 1992 description 



1--	All C circle once round L  

9--	1c+2c & 4c+5c LHA ; RHA, finish C facing C up/dn NHJ while{8} 3c set | cross RH ; repeat and face out and R  

17--	1c+2c & 4c+5c “mirror” Rondels (end couples make the arch) while{8} 3c chase clw ½ round the set {6} | cross to own place and face out and L (2,1,3,5,4)  

25--	1c+3c+5c Reels3 on the sides, 3c start out and L, at end 3c turn RH to 3pl and all face in while{8} 2c & 4c set | dance BtoB | dance in and cast to place facing out  

33--	2c+1c & 5c+4c change places on the side EH | 1c cast off 4 (2c+3c+4c+5c up) | 1c turn RH (2,3,4,5,1)  



', 90, '88888  88888  88888  88888  80246', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (18263, '2018-03-21 15:32:56.004858+00', '2019-03-24 11:24:39.678467+00', 'Wild Hedda Reel', 'WILD HEDDA REEL', 1, 40, NULL, 1, 3, 42, 10759, '2018-01-01', 'Devised by Judith Kowalczik in 2018 for Hedda Hein on the occasion of her 50th birthday. Hedda is a

passionate dancer and a faithful member of the Potter''s Pairs.', 61, '844/888/844/488/688', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1953, '1998-07-08 22:00:00+00', '2018-07-13 01:10:07.030536+00', 'Elizabethan Jig', 'ELIZABETHAN JIG', 2, 32, 9999, 1, 4, 2, 21, NULL, 'For The Royal Silver Jubilee 1977', 91, '8228/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18126, '2017-12-19 09:53:35.622342+00', '2018-04-02 23:56:34.967778+00', 'Good Bye to Australia', 'GOOD BYE TO AUSTRALIA', 2, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10264, '2001-11-25 23:00:00+00', '2018-10-07 12:31:24.699021+00', 'Trip to Scotland, A', 'TRIP TO SCOTLAND', 2, 32, 9999, 1, 3, 42, 2766, '2001-08-01', 'I took my first visit to Scotland in August 2001. This dance captures my impressions of that trip. You wander around all day seeing as much as you can, then get to your Bed and Breakfast late in the day, collapse into bed, and start all over again the following morning.', 49, '800/866/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18124, '2017-12-19 09:48:38.325056+00', '2019-10-17 01:46:00.030043+00', 'Off to Rio', 'OFF TO RIO', 2, 32, NULL, 1, 2, 76, 10971, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18129, '2017-12-19 18:26:44.061391+00', '2017-12-19 18:28:51.740686+00', 'Celebrations', 'CELEBRATIONS', 3, 32, NULL, 1, 3, 42, 2525, '2006-02-04', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18125, '2017-12-19 09:49:42.188573+00', '2023-01-17 02:43:01.090677+00', 'Butterfly Flutter, The', 'BUTTERFLY FLUTTER', 2, 32, NULL, 2, 3, 17, 10971, NULL, 'NB the original instructions say this is 8x32 but the choreography and suggested recording are actually 3x32.', 83, '880/888/888/808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18113, '2017-12-13 14:59:55.713165+00', '2023-01-18 16:44:32.754324+00', 'Invited Guests', 'INVITED GUESTS', 5, 40, NULL, 5, 2, 76, 550, '2007-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18115, '2017-12-13 15:10:15.237397+00', '2023-01-18 16:45:11.432312+00', 'Morino VII', 'MORINO VII', 1, 32, NULL, 104, 2, 76, 550, '2006-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18114, '2017-12-13 15:04:31.414304+00', '2023-01-18 16:49:17.889619+00', 'SCD Kaleidoscope', 'SCD KALEIDOSCOPE', 3, 32, NULL, 5, 2, 76, 550, '2009-07-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18131, '2017-12-19 23:45:33.270859+00', '2017-12-19 23:46:39.0816+00', 'Royal York Reel, The', 'ROYAL YORK REEL', 1, 32, NULL, 1, 3, 42, 2525, '2005-02-19', 'Suitable music The Braes of Balluder', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18127, '2017-12-19 09:54:20.536638+00', '2019-10-19 23:13:44.664325+00', 'Holiday in Peebles, A', 'HOLIDAY IN PEEBLES', 2, 32, NULL, 1, 3, 42, 10971, NULL, '', 63, '808/888/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18194, '2017-12-27 19:47:26.248745+00', '2017-12-27 20:04:12.602663+00', 'Wi'' A Sparkle in Her E''e', 'WI A SPARKLE IN HER EE', 2, 32, NULL, 1, 4, NULL, 44, '2015-09-12', 'With a Sparkle in her Eye', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18133, '2017-12-20 18:19:23.173657+00', '2019-10-19 23:33:43.031131+00', 'January Thaw', 'JANUARY THAW', 2, 32, NULL, 1, 3, 42, 10971, NULL, '', 56, '822/888/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18135, '2017-12-20 18:27:43.405178+00', '2019-10-20 21:39:18.548675+00', 'On the Blue Nile', 'ON THE BLUE NILE', 2, 32, NULL, 1, 3, 42, 10971, NULL, '', 72, '888/888/888/884', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12475, '2005-07-21 22:00:00+00', '2017-12-21 08:14:11.317099+00', 'Kathleen and Walter McAdam', 'KATHLEEN AND WALTER MACADAM', 2, 40, 9999, 1, 4, NULL, 952, '2005-01-01', 'Jenifer Kelly writes:    

Notes for teachers on the dances in the Anniversary Suite.   

As I devised these dances I had a particular teaching point in mind for each of them.  



These teaching notes can be found at 

http://rscds-sf.org/resources/dances/Anniversay%20Suite%20Notes.pdf', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18132, '2017-12-20 00:14:11.537799+00', '2017-12-21 23:11:01.423098+00', 'Earl of Kinnoull, The', 'EARL OF KINNOULL', 1, 32, NULL, 1, 3, 42, 2525, '2005-09-24', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18134, '2017-12-20 18:21:48.323297+00', '2018-04-02 23:56:35.76923+00', 'Koalas and Kangaroos', 'KOALAS AND KANGAROOS', 2, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18122, '2017-12-18 16:07:19.239449+00', '2018-04-02 23:56:38.057134+00', 'Till We Meet Again', 'TILL WE MEET AGAIN', 2, 32, 9999, 1, 3, 42, 11577, '2017-12-01', '', 77, '820/888/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18170, '2017-12-23 15:35:10.336476+00', '2018-04-03 00:18:02.514429+00', 'Through Open Doors', 'THROUGH OPEN DOORS', 1, 32, NULL, 2, 2, 76, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18158, '2017-12-23 13:17:33.286928+00', '2018-04-02 23:56:37.339038+00', 'Rivers of the World', 'RIVERS OF THE WORLD', 3, 40, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18139, '2017-12-22 01:56:46.370545+00', '2017-12-22 02:00:05.483282+00', 'Far from Home', 'FAR FROM HOME', 3, 32, NULL, 1, 3, 42, 2525, '2006-02-16', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18166, '2017-12-23 15:23:10.416306+00', '2017-12-23 15:23:10.416306+00', 'Land o'' Lakes', 'LAND O LAKES', 3, 40, NULL, 1, 100, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18140, '2017-12-22 02:18:29.202343+00', '2017-12-22 02:22:44.581339+00', 'Fiddles and Flutes', 'FIDDLES AND FLUTES', 1, 32, NULL, 1, 3, 42, 2525, '2003-12-14', 'Suitable music The Woods of Fyvie', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18160, '2017-12-23 13:22:50.325535+00', '2018-04-02 23:56:32.761275+00', 'Around the World in Forty-Eight Bars', 'AROUND THE WORLD IN FORTYEIGHT BARS', 3, 48, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18141, '2017-12-22 22:39:13.922992+00', '2017-12-22 22:45:11.114849+00', 'Mr. & Mrs. Belshaw', 'MR AND MRS BELSHAW', 3, 32, NULL, 1, 3, 42, 2525, '2005-12-20', 'For Audrey and Gordon Belshaw on the occasion of their marriage December 20th, 2005', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18168, '2017-12-23 15:30:17.262728+00', '2017-12-23 15:30:17.262728+00', 'Just a Little Different', 'JUST A LITTLE DIFFERENT', 3, 32, NULL, 3, 5, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18143, '2017-12-22 22:58:19.374577+00', '2017-12-22 23:02:38.315561+00', 'Mist on the Hills', 'MIST ON THE HILLS', 1, 32, NULL, 1, 3, 42, 2525, '2004-08-06', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18142, '2017-12-22 22:55:47.21912+00', '2017-12-22 23:32:55.593777+00', 'Sylvia''s Diamond Reel', 'SYLVIAS DIAMOND REEL', 1, 32, NULL, 1, 3, 42, 729, '2000-03-01', 'Devised for Sylvia Cozens, in celebration of her 60th birthday!', 66, '888/866/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18144, '2017-12-22 23:46:40.818925+00', '2017-12-22 23:47:49.863434+00', 'It''s My Turn', 'ITS MY TURN', 1, 32, NULL, 1, 4, 1, 2525, '2005-11-05', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18152, '2017-12-23 13:07:03.712454+00', '2018-04-02 23:56:33.184564+00', 'Bridge at West Montrose, The', 'BRIDGE AT WEST MONTROSE', 3, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18123, '2017-12-18 21:31:21.355357+00', '2020-11-13 10:07:23.333474+00', 'Bridge to Scalpay', 'BRIDGE TO SCALPAY', 3, 32, NULL, 2, 2, 76, 11578, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18138, '2017-12-21 23:13:42.430444+00', '2020-11-13 10:15:04.785546+00', 'Pictish Scroll, The', 'PICTISH SCROLL', 1, 32, NULL, 1, 3, 42, 515, '2006-02-01', '', 47, '860/800/806/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18375, '2018-06-10 13:58:13.874799+00', '2018-10-06 10:44:57.633283+00', 'Miss Priss', 'MISS PRISS', 3, 32, NULL, 1, 3, 42, 2766, '2011-05-01', 'This dance is for my first cat, Misty. Misty was a long-haired muted tortieshell (gray and cream). She was sweet and dainty and somewhat prissy.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18164, '2017-12-23 15:18:10.221947+00', '2019-01-21 12:44:49.502253+00', 'Touring the World', 'TOURING THE WORLD', 3, 32, NULL, 1, 100, 11, 10971, NULL, '', 91, '7777/8888/8448/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18156, '2017-12-23 13:14:47.491295+00', '2019-10-26 01:10:56.832943+00', 'Rotating Wheels', 'ROTATING WHEELS', 3, 32, NULL, 1, 3, 42, 10971, NULL, '', 69, '888/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18176, '2017-12-23 15:51:03.320805+00', '2019-10-25 11:35:38.311405+00', 'Sarasota Surprise', 'SARASOTA SURPRISE', 1, 40, NULL, 1, 4, 1, 10971, NULL, '', 85, '8888/8888/8888/8440/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18161, '2017-12-23 13:24:37.477571+00', '2017-12-23 13:24:37.477571+00', 'Autumn in Canada', 'AUTUMN IN CANADA', 3, 32, NULL, 1, 4, 2, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18162, '2017-12-23 15:14:28.706827+00', '2017-12-23 15:14:28.706827+00', 'Lakes of the North', 'LAKES OF THE NORTH', 3, 32, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18165, '2017-12-23 15:21:22.338614+00', '2017-12-23 15:21:22.338614+00', 'Zebras and Wildebeests', 'ZEBRAS AND WILDEBEESTS', 3, 32, NULL, 1, 102, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18153, '2017-12-23 13:08:30.814623+00', '2018-04-02 23:56:33.481238+00', 'Christchurch Strathspey, The', 'CHRISTCHURCH STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18173, '2017-12-23 15:41:21.397619+00', '2017-12-23 15:41:21.397619+00', 'It''s Off to Nowhere', 'ITS OFF TO NOWHERE', 1, 32, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18182, '2017-12-23 16:05:33.050054+00', '2019-10-30 00:21:13.707498+00', 'Chasing Game, The', 'CHASING GAME', 4, 32, 8, 1, 3, 42, 10971, NULL, '', 56, ' 808/808/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18177, '2017-12-23 15:53:21.010438+00', '2017-12-23 15:53:21.010438+00', 'Dancing up a Storm', 'DANCING UP A STORM', 1, 88, NULL, 1, 102, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18180, '2017-12-23 16:00:15.398512+00', '2017-12-23 16:00:15.398512+00', 'Reel of Reels', 'REEL OF REELS', 1, 32, NULL, 3, 5, 16, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18154, '2017-12-23 13:09:45.073441+00', '2018-04-02 23:56:35.084899+00', 'Haliburton Highlands, The', 'HALIBURTON HIGHLANDS', 3, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18155, '2017-12-23 13:11:16.479269+00', '2018-04-02 23:56:35.218432+00', 'Home at Last', 'HOME AT LAST', 3, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18147, '2017-12-23 12:57:33.592415+00', '2017-12-23 16:12:40.122171+00', 'Buckshot Lake Jig, The', 'BUCKSHOT LAKE JIG', 2, 48, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18172, '2017-12-23 15:38:57.214302+00', '2018-04-03 00:08:14.826534+00', 'Salute to the Haliburton Highlands', 'SALUTE TO THE HALIBURTON HIGHLANDS', 1, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18157, '2017-12-23 13:15:56.628878+00', '2017-12-23 16:14:07.936757+00', 'Snake in the Lake, The', 'SNAKE IN THE LAKE', 3, 32, NULL, 2, 3, 17, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18163, '2017-12-23 15:16:34.356961+00', '2017-12-23 16:14:23.433802+00', 'Temples of Kyoto, The', 'TEMPLES OF KYOTO', 3, 32, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18174, '2017-12-23 15:44:13.313284+00', '2017-12-23 16:14:40.831516+00', 'West Highland Way, The', 'WEST HIGHLAND WAY', 1, 32, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18183, '2017-12-23 19:09:14.93553+00', '2017-12-23 19:37:46.93385+00', 'Double Trouble', 'DOUBLE TROUBLE', 1, 32, NULL, 1, 3, 42, 2525, '2006-02-25', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18185, '2017-12-24 08:06:30.729573+00', '2017-12-24 08:06:30.729573+00', 'Westview Welcome, A', 'WESTVIEW WELCOME', 2, 0, NULL, 5, NULL, NULL, 2525, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18186, '2017-12-24 08:12:47.213214+00', '2017-12-24 08:12:47.213214+00', 'Dance around the World', 'DANCE AROUND THE WORLD', 2, 32, NULL, 4, 4, NULL, 2525, '2006-02-14', 'Suitable Music Postie''s Jig', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18188, '2017-12-24 08:36:19.709441+00', '2017-12-24 08:36:19.709441+00', 'Rowan Berries', 'ROWAN BERRIES', 3, 32, NULL, 1, 4, 1, 2525, '2005-09-12', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18169, '2017-12-23 15:32:19.191087+00', '2018-02-19 00:42:25.701547+00', 'English Interlude', 'ENGLISH INTERLUDE', 1, 32, NULL, 1, 2, 76, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18159, '2017-12-23 13:20:10.282932+00', '2018-04-02 23:56:38.365603+00', 'Visit to Bogota, A', 'VISIT TO BOGOTA', 3, 40, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18137, '2017-12-21 19:38:35.958445+00', '2023-01-26 21:50:45.566247+00', 'King''s Knot, The', 'KINGS KNOT', 1, 32, NULL, 2, 3, 18, 103, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18175, '2017-12-23 15:47:05.866266+00', '2018-04-03 00:07:35.534793+00', 'Breathless in Cuzco', 'BREATHLESS IN CUZCO', 1, 40, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18146, '2017-12-23 12:55:34.87233+00', '2018-04-03 00:08:18.612573+00', 'St Patrick in Sarasota', 'SAINT PATRICK IN SARASOTA', 2, 40, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15453, '2014-05-25 09:06:24.011947+00', '2018-01-12 01:52:07.001993+00', 'Miss G-L''s Strathspey', 'MISS GLS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 3192, NULL, 'Dedicated to Gwyneth, my wife of 34 years, on the occasion of her sixtieth birthday.



G-L - My Wife''s name was Gwyneth Langford before our marriage.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15445, '2014-05-25 08:46:35.214253+00', '2018-01-13 02:34:29.384462+00', 'Millennium Medley, The', 'MILLENNIUM MEDLEY', 4, 128, 10020, 1, 4, 2, 3192, NULL, 'This dance was inspired by the threat of computer malfunctions when the year 2000 ticks in, and is dedicated to all those people who will need to work over the Millennium Hogmanay holiday period to sort out the problems. The change from Strathspey to Reel time symbolises the change from one Millennium to the next. The freezing of the dance for a moment at bar 31-32 on the last time through on the variation (THE BUG), symbolises *The "Millennium Bug" that threatens to stop the computers*. The two circles represent the two zeros that older computers and systems will not recognize.



Once the novelty of the Millennium has passed and with it the danger of computer malfunctions, most dancers will prefer to dance this dance as "THE MILLENIUM MEDLEY".', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18215, '2018-01-13 12:11:45.337475+00', '2018-05-10 16:02:30.43598+00', 'Tui''s Call, The', 'TUIS CALL', 1, 32, NULL, 2, 3, 17, 11073, '2012-07-01', 'Recommended music; ''Figure It Out'' on CD ''Reel On''  



Devised by Elaine Laidlaw July 2012  



The notes of the tui’s call drop into the clear morning air like a pebble dropping into water, the ripples spreading outwards over the surrounding countryside. The last four bars depict the feathers at the throat of the tui.', 63, '800/844/888/804', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15454, '2014-05-25 09:09:44.748811+00', '2018-01-12 11:18:16.215521+00', 'Flight to Turkmenistan', 'FLIGHT TO TURKMENISTAN', 1, 32, NULL, 1, 4, 1, 3192, NULL, 'Dedicated to Mike Pagella, a valued and popular member of the Peterborough RSCDS, when he was appointed consultant on the installation of air traffic control equipment at an airfield In Turkmenistan. This dance was first danced at Mike''s farewell party and tries to represent some aspects of airport life and flying.



- Bars 1-8: aims to show the general movement of people at an airport from point "A" to point "B".

- Bars 9-16: the scene in the concourse, farewells being said whilst others are milling around.

- Bars 17-24: the movement of the planes on and around the.airfield.

- Bars 25-28: good air traffic control avoids head on collisions.

- Bars 29-32: the safe landing of a plane on the runway. ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18178, '2017-12-23 15:55:03.094649+00', '2019-11-10 11:17:28.208631+00', 'Organised Confusion', 'ORGANISED CONFUSION', 1, 48, NULL, 1, 102, 1, 10971, NULL, 'I hope this dance lives up to its name!', 96, '8888/8888/8888/8888/4848/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18219, '2018-01-13 18:54:52.591032+00', '2020-07-18 09:06:27.48252+00', 'Rubik''s Cube', 'RUBIKS CUBE', 1, 48, NULL, 4, 122, 30, 11586, NULL, '', 75, '84848484/88888888/08080808/08080808/48484848/88888888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18136, '2017-12-21 13:28:34.985995+00', '2020-11-13 10:11:01.960099+00', 'Ketchin Sync, The', 'KETCHIN SYNC', 3, 32, NULL, 1, 3, 42, 515, '2016-09-01', '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18181, '2017-12-23 16:01:46.272186+00', '2020-11-13 10:19:37.601956+00', 'Australian Rain', 'AUSTRALIAN RAIN', 4, 64, 22, 1, 3, 42, 10971, NULL, '', 56, '888/822/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18151, '2017-12-23 13:05:13.829029+00', '2021-01-04 12:35:16.029722+00', 'Billabong, The', 'BILLABONG', 3, 32, NULL, 1, 3, 42, 10971, NULL, '', 59, '888/880/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18212, '2018-01-13 11:56:56.811424+00', '2018-05-09 02:59:12.217128+00', 'Over the Hill', 'OVER THE HILL', 1, 32, NULL, 1, 4, 1, 11584, '2011-05-01', 'Celebrating the 50th birthday of the Nelson/Marlborough Region, May 2011.  



Dancers from the Nelson Marlborough Region talk about going “over the hill” to travel from Nelson to Blenheim or vice versa.  



The first formation represents the windy road over the Whangamoas, the second formation is from Pelorus Jack, the third formation represents a fish hook and the fourth formation is the sun.  



Suggested Music – Bank Street Reel', 63, '8000/8888/8000/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18207, '2018-01-13 10:51:15.12273+00', '2018-05-09 02:34:10.498339+00', 'Violet', 'VIOLET', 3, 32, NULL, 1, 3, 42, 11155, '2015-01-03', 'Devised by Maureen Robson on 3 Jan 2015 for a proposed rainbow theme night.  



Recommended recorded music: “In Traditional Mode” on “Reel On” played by Muriel Johnstone

and Jim Lindsay.  



Music for Violet composed by Peter Elmes.', 50, '888/800/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18210, '2018-01-13 11:45:40.156622+00', '2018-05-10 09:29:12.286704+00', 'Tribute to Drew, A', 'TRIBUTE TO DREW', 3, 32, NULL, 1, 100, 2, 10830, '2015-04-01', 'Suggested music: Scottish Dances Vol.6  Drummond Cook – Track 12  



Devised by Glenys Kefalas, April 2015  



Dedicated to Drew with love.', 63, '8008/8888/8008/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18218, '2018-01-13 12:22:44.663003+00', '2018-05-18 05:41:35.248954+00', 'On a Branch', 'ON A BRANCH', 1, 32, NULL, 1, 3, 42, 10933, NULL, 'Suggested music: ''Mr William Brown''s Reel'' as played by Peter Elmes Band CD ''Thistle Half''  Track 2', 44, '844/800/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18379, '2018-06-11 10:55:59.238816+00', '2018-06-21 16:52:30.672334+00', 'Orage à Lyon', 'ORAGE A LYON', 3, 32, NULL, 2, 3, 18, 11642, '2018-06-01', '', 66, '800/808/888/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (733, '1997-04-03 22:00:00+00', '2018-07-13 06:33:41.46196+00', 'Bradenstoke House Strathspey', 'BRADENSTOKE HOUSE STRATHSPEY', 3, 40, 9999, 1, 3, 42, 347, NULL, '"Bradenstoke" is the name of the house of my dance teacher, Miss Margaret Ogilvie, to whom this dance is dedicated.', 40, '800/800/866/800/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18211, '2018-01-13 11:49:37.322826+00', '2018-12-29 10:57:20.870027+00', 'Insomnia', 'INSOMNIA', 2, 32, NULL, 1, 3, 42, 3357, NULL, 'Recommended music: *Gothenburg''s Welcome* Luke Brady, Take Your Partners Vol.5', 56, '800/888/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18213, '2018-01-13 12:03:32.976677+00', '2018-12-29 12:02:26.5222+00', 'Rainbow Falls', 'RAINBOW FALLS', 3, 32, NULL, 2, 3, 17, 11585, '2016-07-26', 'The Rainbow Falls are on the Kerikeri River.



Suggested CD. ''Celtic Fire in the Music'' Bobby Brown and the Acottish Accent. Disc 2 Track 12 Selection of Strathspeys. Tunes Earl Grey (J. Hill) Blin'' Jamie (J Scott Skinner) Miss Doreen Lambert (Angus Fitchet)', 50, '404/404/484/088', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18217, '2018-01-13 12:19:08.148564+00', '2018-12-29 12:44:02.00554+00', 'Lady Karlotta''s Stables', 'LADY KARLOTTAS STABLES', 2, 32, NULL, 1, 3, 42, 11211, '2016-09-01', 'Suggested music: ''Lady Home''s Jig''  by Catherine Frser and Duncan Smith on ''Old Favourites and Odd couples''', 38, '800/844/800/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15446, '2014-05-25 08:48:42.541503+00', '2018-01-14 01:40:43.55243+00', 'Norman Cross', 'NORMAN CROSS', 2, 32, NULL, 1, 4, 15, 3192, NULL, 'This dance is dedicated to the Peterborough RSCDS advanced class who patiently practice my ''incomplete'' dances, special thanks to Hilary for suggesting the formation (bars 1-4).

Norman Cross is a famous crossroad milestone on the A1 outside Peterborough, notorious over later years for traffic hold-ups at its roundabout, which the new motorway section has now eliminated.

In this dance something of the movement of traffic at roundabouts is shown along with having to wait for one''s turn to enter onto it.  In the last two bars - the road now goes straight through below the junction.

The St Andrews Cross formation is used because of the ''CROSS'' in the name of this famous junction.

Norman Cross is also famous for a POW camp situated there during the Napoleonic wars.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18223, '2018-01-14 17:19:41.483457+00', '2018-01-14 17:19:41.483457+00', 'Falkirk Wheel, The', 'FALKIRK WHEEL', 3, 32, NULL, 1, 4, 1, 11589, '2017-01-01', 'Suggested music: Colin Dewar''s Special Requests 7, Track 16 (set of strathspeys', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18226, '2018-01-20 15:53:12.965418+00', '2018-04-18 17:07:38.178237+00', 'Boxing the Compass', 'BOXING THE COMPASS', 4, 128, 10034, 1, 4, 30, 635, '2006-06-01', 'The dance was devised for demonstration purposes – the first 2 repeats are in strathspey time, and the second 2 are in reel time. At the end of the 2nd repeat everyone will be opposite where they started, i.e. in their partner’s original place.  At the end of 4 repeats everyone should be back where they started!', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1229, '1997-04-03 22:00:00+00', '2018-01-14 21:40:38.519501+00', 'Clavie, The', 'CLAVIE', 1, 40, 9999, 1, 3, 42, 313, NULL, '"Burning the Clavie is a fire festival held annually at Burghead on January 11th. The Clavie, made from half a tar barrel and fixed to a six foot spike, is lit then carried through the streets of the town before being taken to a nearby hilltop from which the burning embers are scattered."



The words for the dance also include the instructions that     

- At the end of the first time through, the 1st couple continue into the right hand turn to begin their 2nd turn without first returning to the sidelines    

- Similarly, at the end of the repeat, the 1st couple continue into a right hand turn and cast to 4th place as the new 1st couple turn right hand and cast.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2499, '1998-04-12 22:00:00+00', '2018-01-17 11:14:35.031963+00', 'Glasgow Jubilee', 'GLASGOW JUBILEE', 3, 96, 9999, 4, 4, 3, 108, '1973-01-01', 'From the leaflet: 

The "GLASGOW JUBILEE" - devised by Mr. John Drewry and gifted to the Glasgow Branch Demonstration Team to commemorate the Jubilee of the Glasgow Branch.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18225, '2018-01-19 13:45:29.588575+00', '2018-01-19 13:55:42.473127+00', 'Mein Heidelberg', 'MEIN HEIDELBERG', 3, 104, NULL, 2, 3, 18, 11593, '2013-05-11', 'The dance was devised for the Heidelberg Jubilee Ball in 2013, celebrating  25 Years of Scottish Country Dancing in Heidelberg.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18222, '2018-01-14 17:10:33.506494+00', '2018-05-08 16:53:55.403329+00', 'Cobra, The', 'COBRA', 2, 40, NULL, 1, 4, 13, 11588, '2017-01-01', 'Recommended music: "The Dalston Jig" played by Marion Anderson''s Band on The Sunday Class Dance Book 1', 80, '4444/4444/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19753, '2019-10-29 10:15:08.895998+00', '2019-10-29 10:15:08.895998+00', 'Weaver''s Reel, The', 'WEAVERS REEL', 1, 40, NULL, 3, 5, 16, 10773, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18216, '2018-01-13 12:15:04.692713+00', '2020-11-14 10:39:22.348266+00', 'Nelson''s Golden Jubilee', 'NELSONS GOLDEN JUBILEE', 3, 32, NULL, 1, 3, 42, 11567, '2003-01-01', 'Suggested music: "Anna Holden''s Strathspey"', 56, '800/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1990, '2002-04-30 22:00:00+00', '2021-02-19 20:25:01.923017+00', 'Ennismore Strathspey, The', 'ENNISMORE STRATHSPEY', 3, 32, 9999, 1, 4, 1, 104, NULL, 'The Ennismore Arms was a hostelry in South Kensington. It was closed in 2002.', 88, '8888/8888/0808/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18227, '2018-01-22 19:43:43.228154+00', '2018-01-22 19:46:43.862788+00', 'Come To My Party', 'COME TO MY PARTY', 2, 32, NULL, 1, 3, 42, 11594, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3127, '1997-09-04 22:00:00+00', '2018-01-22 21:55:53.054847+00', 'Iris Jig, The', 'IRIS JIG', 2, 32, 9999, 1, 3, 42, 653, NULL, 'Note from the deviser: ''The Iris flower, in full bloom, reminds me of a hand and so I named this dance after the Iris, because of the continuous use of hands. The first 8 bars represent the lower petals, or "falls", of the Iris.''', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18382, '2018-06-11 21:12:32.561686+00', '2019-01-31 19:51:25.455312+00', 'Strathspey for Hamish, A', 'STRATHSPEY FOR HAMISH', 3, 32, NULL, 1, 3, 42, 11634, '2018-01-01', 'Devised by Alan Ip for Hamish Todd on the occasion of their 30th Anniversary.', 49, '800/888/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18224, '2018-01-14 17:25:31.043665+00', '2018-05-13 15:26:33.045934+00', 'Forty Happy Years', 'FORTY HAPPY YEARS', 2, 40, NULL, 1, 3, 42, 11590, '2017-01-01', 'Suggested music: "Fireworks", Diamond Jubilee Collection, Colin Dewar Track 4  



Devised by Sue Lindsay for Martin and Cindy Snelson’s 40th Wedding Anniversary on the 8 May 2016.  



Note: the movement in bars 9-24 was devised by the late Alec Hay.

', 69, '800/844/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18231, '2018-01-26 23:52:59.556073+00', '2018-01-28 20:06:12.199995+00', 'Runaway Devil', 'RUNAWAY DEVIL', 1, 32, NULL, 1, 4, 1, 3645, '2015-01-01', 'Deviser''s note:  1st couple run away from their set and stand at the side of the hall where the dance event is being held. If desired, they may even leave the hall for a moment (this however depends on its size).  



This dance, based on The Deil amang the Tailors (RSCDS Book 14 no. 7), was devised for not fewer than four available sets on the dance floor.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18229, '2018-01-23 03:04:57.769069+00', '2018-01-23 03:07:27.996649+00', 'Merrymaking in Edinburgh', 'MERRYMAKING IN EDINBURGH', 4, 32, 1, 1, 4, 11, 11594, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16469, '2015-07-07 14:48:33.981206+00', '2019-04-24 22:50:05.271286+00', 'Early Spring', 'EARLY SPRING', 3, 32, 9999, 2, 3, 17, 11150, NULL, 'May also be danced as a 4C/4L dance. Only 1c+2c+3c dance the Allemande.  Both 3c+2c and 1c+4c dance the Tourbillon, and finish (2,3,4,1).  This version is approved by the author.  See the video.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18381, '2018-06-11 21:05:43.415423+00', '2018-06-11 21:08:59.110584+00', 'Lanham Reel', 'LANHAM REEL', 1, 40, NULL, 1, 3, 42, 11634, '2018-01-01', 'Devised by Alan Ip for Hamish Todd on the occasion of their 30th Anniversary.', 45, '822/844/844/808/822', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18233, '2018-01-28 20:54:21.120237+00', '2019-07-08 17:56:12.212615+00', 'Mr Greystoke''s Favourite', 'MR GREYSTOKES FAVOURITE', 2, 32, NULL, 1, 3, 42, 10640, NULL, '', 38, '800/833/855/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18378, '2018-06-11 10:50:20.959206+00', '2018-06-21 16:08:17.099603+00', '8 + 9 = 17', '8  9  17', 2, 32, NULL, 1, 3, 42, 11642, '2018-06-01', 'A dance for Naïri', 56, '800/888/888/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18380, '2018-06-11 16:17:49.042006+00', '2019-05-01 22:03:10.479716+00', 'Rainbow Fairy, The', 'RAINBOW FAIRY', 2, 96, NULL, 4, 4, 3, 11150, '2018-01-01', 'Due to the structure of the dance, the 96 bars need to be played as a 4x24 Jig (not 3x32).', 89, '8282/8888/8888/2828/8888/8888/4444/8888/8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18235, '2018-01-30 01:22:22.537798+00', '2018-04-19 08:57:35.273389+00', 'Six Lively Decades', 'SIX LIVELY DECADES', 1, 32, NULL, 1, 3, 42, 11596, '2018-01-01', 'Devised to celebrate the birthday of Elke Szepanski. ', 62, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18236, '2018-02-01 11:02:10.23323+00', '2018-02-01 11:24:42.340499+00', 'Arran Weekend, The', 'ARRAN WEEKEND', 1, 32, NULL, 1, 3, 42, 146, '1987-01-01', 'In 2018, the North Ayrshire Branch, when preparing a dance in memory of Alastair Aitkenhead, found these dance instructions (in his papers) which were written by Roy Goldring on the 40th Anniversary of the Branch (1987) and handed by Roy to Alastair Aitkenhead.   This dance is almost identical to Liquid Assets by John Drewry, the last 8 bars being different.

', 59, '888/844/888/822', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18232, '2018-01-28 20:18:33.618234+00', '2018-02-24 21:55:07.590809+00', 'Salute to Ian Robertson', 'SALUTE TO IAN ROBERTSON', 3, 32, NULL, 2, 3, 17, 11412, '2017-01-01', 'The dance has been written to mark Ian B Robertson’s 50th birthday. Ian is well known for providing superb music for dancers with either his fiddle or accordion. However not many people are aware that Ian is also a proficient dancer although not always familiar with all the dances. This dance has been written so that the couples dance primarily with, or mirror, their partners and can be helped by the giving of hands.



', 56, '080/484/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13351, '2007-09-19 22:00:00+00', '2022-10-03 22:22:47.398168+00', 'Eté à Paris, L''', 'ETE A PARIS', 1, 40, 9999, 1, 3, 42, 3783, '2007-09-01', 'Official Alias: Summer in Paris.      

I devised this dance for a dance event in Paris scheduled for the 7th of September in 2007.



This is the 40-bar version of the dance <<ddd:Bobby & Kobby#13476>> (which is actually a 64-bar reel for four couples).', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16680, '2015-08-29 12:53:55.755963+00', '2018-02-04 23:52:17.373085+00', 'B.I.B', 'BIB', 2, 32, 9999, 1, 3, 42, 11182, NULL, 'Deviser''s note:



Blootered in Benidorm



As we seek to keep the dances of Scotland alive, so we must maintain its ancient languages. The word blootered is an old Scots word meaning the person is in a state of extreme inebriation. Other words and phrases are - fu, stocious, flein or oot the game to name but a few. The person would be unable to lie on the ground without holding on!



At a country dancing weekend in Spain, the band and I arrived a few days early and enjoyed the cultural activities Benidorm had to offer.', 66, '866/888/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18239, '2018-02-07 09:59:03.35891+00', '2018-03-15 22:14:55.054789+00', 'Strangeness and Charm', 'STRANGENESS AND CHARM', 3, 32, NULL, 2, 3, 17, 11237, '2016-01-01', 'Although this dance really has nothing to do with quarks, I have noticed that the names of two of the six types of quark, “up”  and  “down”, appear frequently in the  instructions for dances while two others, “top” and “bottom”, are seen occasionally.  However the two most whimsically named quarks, “strange” and “charm”, are virtually never mentioned at all.  So the title of this dance is an attempt to rectify that omission!  Hopefully 1st couple will show each other some charm at least in bars 5-6 while bars 21-24 are probably a bit strange for everyone. ', 83, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18238, '2018-02-07 00:37:59.481695+00', '2018-03-15 22:30:47.624274+00', 'Zeal of the Joyous Scots, The', 'ZEAL OF THE JOYOUS SCOTS', 1, 32, NULL, 4, 4, 80, 11237, '2016-01-01', 'Mnemonic ditty : 

-  turn, set, move, set

-  turn, move, back to back 

-  turn, swoop, turn, swoop

-  circle round and back. ', 100, '8888/8888//8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2062, '1997-09-02 22:00:00+00', '2018-07-13 07:56:45.801046+00', 'Falls of Lora, The', 'FALLS OF LORA', 2, 32, 9999, 1, 3, 42, 347, NULL, 'The Falls of Lora are situated at the mouth of Loch Etive which is narrow and the site of a reef of rocks. The tide passes through it very quickly and a cataract, the Falls of Lora, has been made.', 47, '800/844/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17469, '2016-11-06 17:22:44.358799+00', '2018-03-18 14:43:53.067253+00', 'Symphony Hall Strathspey', 'SYMPHONY HALL STRATHSPEY', 3, 32, NULL, 2, 3, 18, 1275, NULL, 'Symphony Hall, officially opened by Her Majesty the Queen in 1991, has a seating capacity in excess of 2200 and is home to the City of Birmingham Symphony Orchestra.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8923, '2002-04-30 22:00:00+00', '2018-01-30 13:41:21.463082+00', 'Aarhus Festival', 'AARHUS FESTIVAL', 1, 32, 9999, 1, 3, 18, 520, NULL, 'The progression (312) is unusual, but works correctly in a 4L set. As usual the two bottom couples change places after each second turn.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18234, '2018-01-29 22:32:09.497767+00', '2018-04-03 00:08:23.032168+00', 'Twilight Reel, The', 'TWILIGHT REEL', 1, 32, NULL, 1, 3, 42, 3355, '2016-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18171, '2017-12-23 15:36:28.559428+00', '2018-02-08 10:36:40.055995+00', 'Down the Clyde', 'DOWN THE CLYDE', 1, 32, NULL, 2, 3, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18128, '2017-12-19 09:56:27.146489+00', '2018-02-08 10:40:31.220993+00', 'In Victoria Park', 'IN VICTORIA PARK', 2, 32, NULL, 2, 3, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18241, '2018-02-11 16:40:03.518147+00', '2018-02-13 12:53:50.529465+00', 'Jig for Josselin, A', 'JIG FOR JOSSELIN', 2, 32, NULL, 1, 3, 42, 1275, '2018-01-01', 'The dance was presented as a gift to those who attended the inauguration of a Scottish Weekend in the town of Josselin in Brittany and was first danced on Sunday 11th February 2018.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18240, '2018-02-09 11:39:04.916001+00', '2018-02-09 11:41:56.687297+00', 'Montgomery and the Maple Leaf', 'MONTGOMERY AND THE MAPLE LEAF', 1, 32, 9999, 1, 3, 42, 2983, '2018-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1015, '1997-08-31 22:00:00+00', '2018-08-27 15:22:10.08125+00', 'Captain John Hunter', 'CAPTAIN JOHN HUNTER', 2, 40, 9999, 1, 3, 42, 325, NULL, 'Captain John Hunter commanded HMS Sirius, flagship of the First Fleet, which entered Port Jackson to found the colony of New South Wales, after rejecting Botany Bay as unsuitable.', 38, '804/840/822/633/633', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12504, '2005-08-21 22:00:00+00', '2018-02-13 00:57:43.223833+00', '10th Anniversary Celebration', '10TH ANNIVERSARY CELEBRATION', 3, 32, 9999, 1, 100, 2, 3618, NULL, 'For the 10th anniversary of dancing at Saint Martin In-The-Fields, Victoria, B.C. 





', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18556, '2018-09-07 22:31:26.294387+00', '2018-09-07 22:38:18.070375+00', 'Mirror, The', 'MIRROR', 1, 32, NULL, 3, 5, 16, 10478, '2007-01-01', 'The author, Wil van den Berg, has withdrawn this dance; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18558, '2018-09-07 22:44:19.48002+00', '2018-09-07 22:44:43.772991+00', 'Out in the Air', 'OUT IN THE AIR', 3, 32, NULL, 1, 3, 42, 10478, NULL, 'The author, Wil van den Berg, has withdrawn this dance; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18512, '2018-08-21 09:08:09.767748+00', '2018-10-19 10:53:43.411188+00', 'Walnuts and Honey for Breakfast', 'WALNUTS AND HONEY FOR BREAKFAST', 3, 32, NULL, 1, 3, 42, 11509, '2018-04-01', '', 68, '852/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18967, '2018-10-15 14:12:57.76993+00', '2018-12-09 13:46:48.855479+00', 'Elizabeth''s Fancy', 'ELIZABETHS FANCY', 1, 32, NULL, 1, 3, 42, 11734, NULL, '', 56, '888/880/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18559, '2018-09-07 22:46:38.864722+00', '2019-01-26 04:59:19.493437+00', 'Fairest Lass', 'FAIREST LASS', 3, 32, NULL, 1, 4, 1, 10478, '2012-01-01', 'The author, Wil van den Berg, has withdrawn this dance; it is no longer available to the public.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18384, '2018-06-13 19:19:11.389063+00', '2019-03-24 11:13:38.077954+00', 'Weasel''s Nest, The', 'WEASELS NEST', 1, 40, NULL, 1, 3, 42, 10759, '2018-06-01', '', 75, '800/888/888/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15662, '2014-10-19 09:44:31.475583+00', '2018-06-23 08:51:13.451274+00', 'You Can Do It', 'YOU CAN DO IT', 1, 32, NULL, 1, 3, 42, 74, '2013-01-01', 'The U-chain was devised by Heinz Duewell in his Tighes Hill book. It follows the form of a Grand

Chain, except that all cases the giving of hands take 2 bars and when dancers get to the end of the

set, they set before returning back along the previous track.



In the case of a “Bottom Open U-Chain”, the setting is in third place. For a “Top Open U-Chain”,

setting would be in first place.', 69, '888/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18386, '2018-06-17 21:57:47.607712+00', '2018-06-22 10:44:32.120332+00', 'Nymphaea Caerulea', 'NYMPHAEA CAERULEA', 2, 32, NULL, 1, 2, 76, 11508, '2018-02-01', 'For Lilly.

', 60, '84/88/88/84', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18150, '2017-12-23 13:03:28.129324+00', '2018-02-19 00:39:17.622277+00', 'Variation on a Theme', 'VARIATION ON A THEME', 3, 32, NULL, 1, 2, 76, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18244, '2018-02-19 20:54:26.317869+00', '2018-04-08 01:04:54.254661+00', 'Anna Marshall''s Strathspey', 'ANNA MARSHALLS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 246, NULL, '', 58, '550/888/866/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17468, '2016-11-06 17:20:50.837428+00', '2018-04-02 23:56:33.648665+00', 'Cross-City Line, The', 'CROSSCITY LINE', 1, 40, NULL, 1, 3, 42, 11415, NULL, 'The Cross-City Line is a suburban railway line in the West Midlands made up of a combination of lines opened by different companies between 1837 and 1885. It runs for 32 miles from Redditch, Worcestershire, in the south to Lichfield, Staffordshire, in the north, via Birmingham New Street.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18242, '2018-02-14 14:22:36.429781+00', '2020-07-11 06:18:08.112194+00', 'Turtle Shells', 'TURTLE SHELLS', 2, 32, NULL, 1, 4, 1, 11599, '2012-01-01', 'I called it Turtle Shells, because when I was devising the dance it reminded me of the formation of turtle shells.



Published in RSCDS Youth Ezine 4, November 2011', 66, '8000/8880/8888/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18954, '2018-10-12 20:27:53.59596+00', '2022-08-13 22:05:28.41826+00', 'Two Wise Old Owls - female', 'TWO WISE OLD OWLS  FEMALE', 3, 32, NULL, 1, 3, 42, 558, '2015-01-02', 'Dedicated to Gwen Traxler for her Two Wise Old Owls anniversary', 62, '844/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17430, '2016-10-30 11:32:23.987382+00', '2022-08-15 08:44:24.467351+00', 'Carol''s Frolic', 'CAROLS FROLIC', 1, 32, NULL, 4, 4, 1, 433, NULL, 'A fun dance in recognition of Carol Clark''s teaching skills with the boys and girls of Gatehouse Primary School.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17470, '2016-11-06 17:24:18.842325+00', '2022-08-15 08:46:00.526399+00', 'Doodling at Dawn', 'DOODLING AT DAWN', 2, 32, NULL, 1, 100, 1, 11414, NULL, 'The title refers to the mental process of devising a new dance while lying awake first thing in the morning.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18022, '2017-10-22 09:25:32.636791+00', '2018-06-19 06:51:26.044623+00', 'Racing in Spa', 'RACING IN SPA', 2, 32, NULL, 1, 3, 42, 11508, '2017-03-31', 'Devised for Anne Scobie''s 60th birthday and Jette Rosen''s 40th birthday; both SCD teachers in Brussels.



These birthdays were celebrated during a week-end of dancing in Spa, hometown of the Francorchamps motor-racing circuit, on 31 March to 2 April 2017.



The dance describes the motor races:  

- bars 1-8 represent the warming up of the engines;  

- bars 9-24 represent the actual race;  

- bars 25-32 represent the after-race party.', 56, '880/844/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4216, '1997-04-03 22:00:00+00', '2019-03-14 22:29:48.019368+00', 'Mary Ross''s Jig', 'MARY ROSSS JIG', 2, 32, 9999, 1, 4, 1, 108, '1982-01-01', 'A dance for the Silver Wedding Anniversary of Jonathan and Mary Ross of Inverness.', 81, '8888/8888/8888/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9542, '2002-03-03 23:00:00+00', '2018-10-08 21:02:24.9394+00', 'Agnes and Bobby Crowe', 'AGNES AND BOBBY CROWE', 3, 96, 9999, 4, 4, 3, 146, '1997-01-01', 'The Fig8 [1] and [65] were the other way round (in front of P first) in an earlier note 9801', 63, '4444/8888/8888/8888//8080/8888/0808/8888//4444/8888/8888/8888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (18385, '2018-06-17 12:03:18.265402+00', '2018-08-28 10:40:08.475062+00', 'Friday Frolics', 'FRIDAY FROLICS', 1, 32, NULL, 1, 3, 42, 3414, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (588, '2001-09-13 22:00:00+00', '2018-07-15 00:28:34.522822+00', 'Blue Bonnets', 'BLUE BONNETS', 2, 32, 9999, 1, 2, NULL, 9998, NULL, '<<scddb:not-identical:8753>>



The dark blue bonnet, or cap, is a typical article of traditional male

Scottish attire, and it should not come as a big surprise that the

“blue bonnets” in this case refer to the Scots in arms against the

English (*All the blue bonnets are o''er the border* – Sir Walter

Scott).



During the past few centuries, Scottish military units sported a

variety of bonnets including the “Balmoral bonnet” (a fairly flat cap

similar to a beret, but with a cockade and badge at the front left and

a “toorie” or fluffy woolen pom-pom, usually red, at the centre of the

crown) and the “Glengarry bonnet” (a more elaborate item more like a

fore-and-aft or overseas cap, with a cockade, badge, red toorie and

often a red-and-white diced band at the bottom, cock feathers and long

streamer ribbons in the back). Nowadays only the Glengarry bonnet

remains in military use, although the Balmoral bonnet is still popular

as a part of Highland dress. In *So You''re Going to Wear the Kilt*,

J. Charles Thompson claims that “some of my Scottish advisors […] have

no use for a Glengarry for anyone of any age who is not forced to wear

it by military regulations”.



The music for the dance used to be called *Lesley''s March* (its

namesake, one General Lesley, lived in the 17th century and fought,

like many other Scots, on the Swedish side in the Thirty-Year War on

the Continent before returning to Scotland to lead the army of the

“covenanters” against Cromwell), but was renamed *Blue Bonnets o''er

the Border* after Sir Walter Scott had come up with appropriate words

to suit the tune.

', 43, '44  44  80  88', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (9812, '2002-05-24 22:00:00+00', '2018-10-08 20:07:13.576226+00', '14/12', '14/12', 1, 32, 9999, 1, 3, 42, 2409, '2001-01-01', 'Devised to teach pas-de-basque with changes to and from skip-change. The name refers to the number of setting steps for 1c/ the others.



The dance was originally published on Internet, but the site no longer exists (now resuscitated at e-cribs.org).  Here is the original text.



14/12



	by Alan Paterson 



	3 couple Reel for a 4-couple set 



Care to pas-de-basque?



Bars



1 - 8 	1st 2nd and 3rd couples petronella into the centre (to form a line up-and-down) and set. Turn partner 3/4 by the right hand to opposite sides, take hands and set.



 9 - 16	1st and 2nd couples continue to set once, then dance 1/2 right hands across. 1st and 3rd couples take hands and set, then also dance 1/2 right hands across. (2nd and 3rd couples are now back on own sides in 1st and 2nd places. 1s are in 3rd place on opposite sides)



17 - 22	1st couple cast up one place, dance in to meet, take nearer hands, dance up between the 2s, then cast to 2nd place (still on opposite sides). 3rd couple step down on bars 17-18.



23 - 24	1st couple, while setting in place, pull right shoulder back to face out.



25 - 30	1st couple cast round to their right, cross with each other, giving right hands, up and down the centre of the set, cast out to their left (own sides) while 2nd and 3rd man and also 2nd and 3rd ladies, change places giving right hands, set to each other, and change back, again giving right hands.



 31 - 32	All take hands and set.



Repeat having passed a couple.



Recommended tune: Jack''s Delight (trad). A recording can be found on David Cunningham''s Silver Thistle album - track ''The Silver Thistle''. 



This dance was devised 30 March 2001 to fill the need of teaching pas-de-basque with changes to and from skip-change.



Notes:



1.   Bars 15-16. Yes, I appreciate that some might want to dance left-hands across. This is just me being perverse.



2.   Bars 23-24. While gazing enchantingly at one another of course.



3.   My wife points out that no-one uses their left hands at all in this dance. I felt that the dancers had enough to think about. Feel free to change this if you prefer.



4.   The name? Seems obvious to me, but, as yet, no-one has worked it out. There is a clue in the text somewhere.

', 56, '888/844/800/888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (6607, '1997-04-03 22:00:00+00', '2018-08-20 20:55:49.390412+00', 'Until We Meet Again', 'UNTIL WE MEET AGAIN', 1, 40, 9999, 1, 3, 42, 44, '1989-08-26', 'Iain Boyd explains:  In 1984, I devised a dance which I titled "Till We Meet Again". I subsequently distributed the instructions to a number of friends.  In my opinion, this dance should not have been entered into DanceData as the instructions were only distributed to friends and not formally published.  When I decided to formally publish the dance (in "Vive La Danse!") I also decided to change the title to "Until We Meet Again" and extend the dance from 32 bars to 40 bars (to improve the join between the second and third times through).



The name of the obsolete "Till We Meet Again" has been added here as an alias, to help those who search for it.  But please be aware that the instructions are no longer available.  Also, those of you who would like the instructions for the new dance, may contact me and I will send you a copy of the instructions as published.  ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18628, '2018-09-18 16:25:42.451769+00', '2018-09-18 16:25:42.451769+00', 'Banks of Boone', 'BANKS OF BOONE', 1, 32, NULL, 1, 3, 42, 11710, NULL, 'To Scottish Country Dancers in Boone, Iowa, and Boone, North Carolina.



Note 1: The turns on bars 1-8 are similar to the turns of the corners in Pass & Turn, except that 1M on bars 3-4, and 1W on bars 7-8, takes smaller steps to finish in 2nd place own side.



Note 2: At the end of every second repetition of the dance, 1C finish in 3rd place and step out and down on bars 1-2 of new active couple’s turn. This requires 3W to begin the next repetition by dancing up from 4th place to turn the new 1M. 3W finishes the turn in 3rd place.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18649, '2018-09-18 23:04:54.444094+00', '2018-09-19 08:55:19.426317+00', 'Strathspey for Doug', 'STRATHSPEY FOR DOUG', 3, 32, NULL, 2, 3, 17, 3617, '2013-10-01', 'With love to Doug Schneider on his seventieth birthday.   



Linda''s note on the Star Meanwhile figure: 1st couple needs to "watch for the gap" as they cross the set and as they change places up and down: For 1st man it ''s between the third couple and for 1st woman it''s between the 2nd couple both times. Another way to think of it is that 1M is always casting around 3M and 1W is always casting around 2W.

', 79, '800/888/888/848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18383, '2018-06-12 23:27:36.855044+00', '2021-11-08 19:03:22.33665+00', 'Love is in the Air', 'LOVE IS IN THE AIR', 1, 48, NULL, 1, 3, 42, 11643, '2018-01-01', '', 41, '555/080/800/844/866/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18648, '2018-09-18 23:01:56.984313+00', '2018-09-23 22:57:52.230588+00', 'Wee Drappie, A', 'WEE DRAPPIE', 2, 32, NULL, 2, 3, 17, 11710, '2013-12-01', '1-28 the Same as Skunk River Reel  



My home town of Newton, Iowa, lies on the high ground (‘high’ being a relative term in Iowa) between the north and south branches of the Skunk River. The south branch also flows along the eastern edge of Ames, Iowa, home of several RSCDS Central Iowa Branch dancers.', 49, '800/888/888/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18744, '2018-10-04 18:07:17.224484+00', '2020-05-08 17:16:17.285869+00', 'Emily''s Fireworks', 'EMILYS FIREWORKS', 2, 32, NULL, 1, 3, 42, 2766, '2014-02-01', 'This dance was written at a shower for Andrew, Emily’s younger brother, where Emily showed how she does fireworks – touching fists with someone and raising hands into a fireworks fall. I wrote this dance to capture that moment.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18534, '2018-08-26 18:41:57.980456+00', '2018-08-28 16:19:50.713778+00', 'Lazlo', 'LAZLO', 3, 32, NULL, 1, 4, 1, 11689, '2007-01-01', 'Deviser''s Note:  Lazlo is the artist pseudonym of Maguy Paillet, a keen dancer with the Scottish Chanterelle society (Lyon, France) for many years. The dance was written in 2007 as a tribute to Maguy’s courage in her fight against cancer and to celebrate all the happy moments spent together. The Lazlo figure tells of the dancers’ admiration for her loveliness and charm, while bars 29-32 stand for the artist’s talent in modelling clay into shape and thus bringing it to life.





"The Reel" (RSCDS London) No 261 (September to November 2007), page 14, carried the following obituary of Maguy Paillet.   



It was with great sadness that SCD dancers recently learned of the death of Maguy Paillet on July 24 after a brief but very courageous struggle with cancer. Maguy’s first contact with Scottish Country Dancing came about through Scottish friends in her native Lyon (France) a little under 20 years ago. Thereafter she became a stalwart of the Lyon group now known as Scottish Chanterelle, her special interest being in co-ordinating a modest “Dem Team” who performed at Burns Suppers and various local cultural events. At the end of June she was at the helm of a little open-air dem in a park in Lyon but finally went into hospital two days later. She also travelled extensively and managed to take her dancing shoes along, whether to Japan or to North America. She loved the dancing and the music and also the welcoming friendly atmosphere she encountered wherever she went. Her art work was another important part of her life and her notelets and greetings cards illustrated with pictures of dancers and especially “The Blue Lady” were regularly on sale at the Summer School shop. A collage of these has now been gifted to the RSCDS as a token of the great pleasure she derived from her many years of attending Summer School. Her fondness for strathspeys was well known and two dances have been devised for her by her friends, one with music by Ken Martlew and the other with a tune by Keith Smith. She was thrilled to be able to dance these with her Lyon friends earlier this year. It is perhaps no coincidence that she passed away the morning after her Lyon friends started their 2007 Summer School and her picture had arrived safely at the RSCDS. 



Editor''s note:  The Strathspey "Lazlo" was originally written in 2007, and slightly modified before final publication.

', 71, '8008/8888/8111/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14115, '2011-08-25 22:00:00+00', '2018-09-01 00:37:30.439867+00', 'El Nino', 'NINO', 2, 32, NULL, 1, 3, 42, 10433, NULL, 'This dance is dedicated to the set of dancers who trialled The Waverley Suite'' dances on a day of high temperature. In the afternoon the hosts put on the air conditioning. We were all so hot it took some moments to realise that the unit was pumping out hot air. I thought the Spanish title covered very appropriately the espagnole start, the hot air (from both the air conditioning and the dancers), the time of the year we were dancing, the patterns in the dance signifying swirling winds and the way we were all behaving towards the end of a long dancing day! (El Nino - a warm current affecting the Peruvian coast every ten years or so; from the Spanish ''the child'' short for El Nino de Navidad - the Christ Child - from the arrival of the current at Christmas.)', 63, '880/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18548, '2018-08-29 20:30:47.769956+00', '2018-08-30 16:18:55.619204+00', 'Wyches of Cheshire, The', 'WYCHES OF CHESHIRE', 3, 32, NULL, 6, 3, 18, 11699, NULL, 'This dance has been devised by Liz Bruynooghe for three Societies in Cheshire - Northwich Scots'' Society, Nantwich and District Scottish Society and RSCDS Cheshire Branch - who have come together to organise a Ball.  Our first combined Ball will be held on Sat 30 March 2019 and this dance will feature on it.  



The ''Wyches'' refer to three Cheshire Market Towns - Northwich, Nantwich and Middlewich.  These towns are also famous for salt - there are salt mines in Cheshire!  (Sadly it is not refined salt, such as Aigues Mortes.  Cheshire salt is used for spreading on the roads in winter.)', 91, '777/888/666/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16960, '2016-05-29 05:43:49.590334+00', '2018-09-03 17:44:29.138605+00', 'Topsy Turvy', 'TOPSY TURVY', 3, 32, NULL, 2, 3, 17, 2677, '2016-01-01', 'The dance was devised for Gini Grover and Gene Robinson of Binghampton, New York.



(Source: a copy of this dances was published in the "Dance On!" magazine together with the above information.)





TOPSY TURVY (3 X 32 S) 3C



1-4        1L ½ Fig of Eight round 2C to finish in prom hold with 1M



5-8        1C ½ prom reel of 3 across with 2C, LSh to 2L



9-12      1C followed by 2C dance down between 3C & cast up



13-16    1C & 2C dance ½ rights & lefts



17-20    3M ½ Fig of Eight round 1C (in 2nd pl) to finish in prom hold with 3L



21-24    3C prom reel of 3 with 1C, LSh to 1M



25-28    3C followed by 1C dance between 2C & cast off



29-32    1C & 3C dance ½ rights & lefts, to finish 231



Source: This Carnoustie dance crib for 27th July 2016.



', 54, '640/880/406/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18520, '2018-08-21 09:56:53.957269+00', '2018-09-05 13:12:04.413681+00', 'Noix de Grenoble, La', 'NOIX DE GRENOBLE', 1, 32, NULL, 1, 4, 1, 11509, '2012-11-01', 'This dance is also suitable for three or five couples.  In this case, the single couple at the bottom of the set turn right hand and then left hand while the others dance hands across, they then stand still during bars 9-16.

This is an easy dance quite suitable for warming up or for ceilidhs.  It was devised after teaching in a secondary school, but finally never user there.  Later it was taught and performed in a nursery school in the area of Grenoble by the "older" ones (5-6 year-old children), quite difficult for them though.  At that time, the dance was called "Kids in the Alps", but it was renamed for publishing in the Walnut Book.', 42, '8888/2222/2222/6000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14130, '2011-08-25 22:00:00+00', '2021-01-04 12:09:06.275813+00', 'Birds of a Feather', 'BIRDS OF A FEATHER', 3, 32, NULL, 1, 3, 42, 10433, NULL, 'Only a few doors away from where we were trialling The Waverley Suite'' dances, I hit a member of the Manorina melanocephala family - a Noisy Australian Miner - which was sitting in the road. By the time I had parked the car, there was a flock of Miners surrounding the injured bird and - it seemed - offering sympathy and advice. Whatever it was, their concern worked; when I left some hours later there was no sign of any mishap. It made me think that Scottish Country Dancers are like that flock of Miners - concerned for their fellow dancers within and without the set. In this dance you are with your partner for all but four bars, but even then you can keep an eye on each other!', 69, '888/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15338, '2014-02-15 07:24:02.078683+00', '2019-04-03 20:17:53.906924+00', 'Ann of Scotia', 'ANN OF SCOTIA', 3, 32, NULL, 1, 3, 42, 10373, '2013-11-01', 'Devised by Chris and Sue Ronald, November 2013, to honor Ann Hankins’ extraordinary contribution to Scotia Dancers in New York.



Original text:



Bars	



1-4	(Cuddle cast) 1st couple dance towards partner, face up, touch nearer hands and cast to second place. 2nd couple step up on bars 3 and 4. 



5-8	1st couple set advancing, turn ½ way with both hands and pivot pulling right shoulder back on the last bar to face first corners. 



9-16	(Set and flirt) 1st couple set to first corners, and dance around each other by right shoulder (gypsy) to face second corners; repeat with second corners, and finish on own side in second place, facing out.



17-20	1st couple dance a loop (by right shoulder) around third corners and pass each other by right shoulder up and down the centre of the set while third corners ½ turn with right hand, face each other, and dance into each other’s place on a curve, pulling right shoulder back (½ turn and twirl).



21-24	Repeat bars 17-20 with fourth corners. On the last two bars, 1st couple pass right shoulder to finish in second place on opposite side.



25-32	All chase clockwise half way (4 bars) then all turn partner once round with both hands.  

Repeat having passed a couple.

', 47, '800/822/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9888, '2002-08-26 22:00:00+00', '2018-09-10 19:17:34.594696+00', 'Rocking Horse, The', 'ROCKING HORSE', 4, 96, 54, 4, 4, 13, 1502, '1994-12-01', 'The rocking Horse is the symbol of the Children''s Hospice Association, Scotland.



Muriel Johnstone has commented about the last 4 bars:  

"This query has cropped up on a few occasions and we did issue an amendment to the instructions at one stage in the late 1990s I think it was. The last line of bars 45-48 of the original instructions should read ''. . . . one place round the set clockwise.'' so first couple finish in second place.', 83, '8080/0808/8888/8888/8888/8888', 1, 1, 1, 1, 41);
INSERT INTO 'dance' VALUES (14720, '2013-03-09 13:02:38.068323+00', '2018-09-13 14:04:56.893624+00', 'Prince of Sutton Coldfield, The', 'PRINCE OF SUTTON COLDFIELD', 1, 32, NULL, 1, 3, 42, 2682, '2013-03-02', 'Full description (posted at request of the author)



THE PRINCE OF SUTTON COLDFIELD



Devised by Rod Downey, Wellington, New Zealand.



A three couple 32 bar reel in a four couple set.



1-8 The three couples dance parallel RS reels of three on the side, finishing with first couple on opposite sides in first place. The reels begin on own sides, but finish on opposite sides. This is accomplished by first lady crossing to the men''s side through second man''s place (care is needed that the third man is not tardy) on bar 7, and first man dancing across the top on bar 8. (This movement resembles that used in Tulloch Gorm, but with gender roles reversed.)



9-16 Repeat 1-8 to original places.



17-24 First and second couples dance 4 hands across and back. The left hands back finishes with both couples taking both hands with partner in a line on on the first diagonal (1W and 2M back to back), ready for a Hello Goodbye Poussette.



25-32 1C and 2C dance a Hello Goodbye Poussette.



Repeat having passed a couple.



Hello Goodbye Poussette



This begins in a diagonal line between first man''s place and second lady’s place with 1W and 2M back to back; 1C and 2C holding partners with both hands in order 1M 1W 2M 2W. The retain hands until the end of bar 6. All begin on the right foot.



1-2 All set R, and move left on the left jete'' to finish in a line across the set, with the 1M and 2W back to back. (This rotates the line 1/8 anticlockwise.)

3-4 Repeat a further 1/8, so that we are now on the second diagonal.



5-6 Repeat, so that now all are in a line up and down the set, (from the top), 2M, 2W, 1M, 1W. Drop hands.



7-8 All petronella to own sides in progressed places.



Notes: Dedicated to Barry Priddey, wonderful dance deviser. Devised 2 March, 2013. The last figure was inspired by a similar one by Barry Priddey. 



Music: Any good reel. I found Dumbarton Drums, as recorded by Alastair Downie, worked well.





', 62, '888  888  880  880', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (17254, '2016-09-04 12:02:35.179304+00', '2018-09-13 21:42:23.43018+00', 'Reel Parenting', 'REEL PARENTING', 1, 32, NULL, 1, 3, 42, 11335, '2015-06-01', 'The Story: This dance is inspired by how, when one has a family, things delightfully and mischievously happen when parents aren''t looking. There is a game afoot where the set gets rearranged when the parents are busy. The challenge is to put it all back together.



1-8 Two of the kids turn away and run; the parents take off in pursuit.



9-16 Thinking all is in order, the parents leave together, but when they turn around they discover the kids are out of place. They scold the kids who then put themselves back in order.



17-24 Taking the kids by the hand, the parents do a normal double triangle making eye contact with the corners like any upstanding parents would do, but the kids keep moving whenever the parents let go.



25-32 The set is truly a mess. Working together, they all put it right', 62, '880/888/888/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17247, '2016-09-04 10:40:14.980486+00', '2018-09-14 01:12:09.245963+00', 'In Mr. McGregor''s Garden', 'IN MR MACGREGORS GARDEN', 1, 32, NULL, 1, 3, 42, 11331, NULL, 'This dance was inspired by the music “McGregor’s Leap,” which brings to the deviser’s mind dancers swirling into petronella turns. The title of the music suggests the Beatrix Potter story “The Tale of Peter Rabbit,” in which the young Peter Rabbit sneaks into Mr. McGregor’s garden (to eat the vegetables that give him the energy to leap) and he is chased about the garden by Mr. McGregor.', 47, '808/808/880/822', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2148, '1998-01-04 23:00:00+00', '2018-09-17 06:43:12.178367+00', 'Fiddler''s Joy', 'FIDDLERS JOY', 1, 32, 9999, 1, 2, NULL, 899, NULL, 'This dance was devised to make use of the record "Fiddlers to the Fore" published by the B.B.C. The music used is the Reel played by the 150 fiddlers on side 2. It is suggested that you listen to the music for 32 bars before starting to dance, as the fiddlers play for 9 rounds of the dance.  



The debut of FiddZer''s Joy was at Pinewoods in 1971; the music sounded well in the open air.  



Any similarity to a dance previously published is purely coincidental. ', -1, '888/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18610, '2018-09-15 23:07:22.518219+00', '2018-09-17 11:01:20.689122+00', 'Reflections of Sherbrooke', 'REFLECTIONS OF SHERBROOKE', 3, 32, NULL, 1, 4, 5, 2973, '2011-04-01', 'Chis Ronald wrote “The name of the dance was chosen to depict the mirror (reflection) formations in the dance, and the fact that it was introduced at the TAC Summer School in Sherbrooke in July 2011 for a class on ‘Unusual Progressions’. The dance has several unusual features: ‘dolphin’ mirror reels of three, set and ‘mirror link’ for three, and the progression 3-4-2-1."', 68, '8800/8840/8888/8804', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17296, '2016-09-08 03:50:26.313272+00', '2018-09-19 09:47:41.494287+00', 'Marshal''s Rosette', 'MARSHALS ROSETTE', 3, 32, NULL, 6, 3, NULL, 10995, NULL, 'In this dance I have tried to evoke the rhythms and pageant of a jousting tournament. It’s

name links it to William Marshal who was the greatest ever medieval Knight, whether in

tournament or war.



The key figure is the tilt which mimics the charge of the knights in the lists. This must be danced vigorously with menacing eye contact! In contrast, the solo is a stroll “to be seen”,& the Progression a vigorous warm-up with the squires at arms in preparation for the next joust!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16882, '2016-02-25 00:51:25.883527+00', '2018-09-19 09:47:49.465222+00', 'May McLeod''s Medley', 'MAY MACLEODS MEDLEY', 4, 32, 5, 2, 3, 18, 3379, NULL, 'To celebrate the 90th Birthday of May McLeod from Huntly.





Bars			Description



1 – 8	2nd couple cross over right hand, cast to their right, dance in towards their partner and passing right shoulder dance round their partner to finish back to back in the centre woman facing up, man facing down.



9 – 16	2nd woman with the 1st couple; 2nd man with the 3rd couple dance a circle round to the left with the 2nd couple dropping left hands on bar 12 to join into 6 hands round to left half way.



17 – 20	2nd woman with the 3rd couple; 2nd man with the 1st couple dance half a reel of 3 across the dance with 2nd couple finishing in 2nd place on the correct side.



21 – 24	1st and 2nd couples turn right hand for 4 bars and stay in the middle ready for:



25 – 32	2nd couple and 1st couple dance an allemande.







The dance is done 3 times as a Strathspey then 3 times as a Reel.  





During Reel time on bars 7 & 8 the 2nd couple do not dance round each other instead they set to each other pulling their right shoulders back to face up or down.





Original Tunes: May’s 90th (Strathspey) & Councillor Coull (Reel) by Frank Thomson

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18653, '2018-09-18 23:21:15.079125+00', '2018-09-19 09:26:22.440823+00', 'Watchman, The', 'WATCHMAN', 3, 32, NULL, 2, 3, 17, 11710, '2012-12-01', 'To the memory of the late Ken Bull, friend and fellow member of the Central Iowa Branch. Ken worked as a security guard in the years preceding his retirement.   



Note: At the end of the reel, 1st woman pulls RS back before reaching the women’s side to finish in center to the left of her partner, facing down.', 56, '880/888/880/808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17339, '2016-09-14 09:21:28.361865+00', '2018-09-19 09:45:27.713951+00', 'Finlay''s Frolic', 'FINLAYS FROLIC', 1, 64, NULL, 4, 4, 3, 11110, '2005-09-01', 'Note: This could be danced as a 64 bar strathspey or 64 Strathspey/64 bar reel medley. In order

to do this a slight amendment would need for bars 33-40 in strathspey time:  At the end of bar 32 the men would finish in the centre facing their partners.



Bars 33 – 40 All set to partners, change places with the right hand, all set to partners, turn left

hands to face corners.', 94, '8888/8484/4848/8888/8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4239, '1998-09-29 22:00:00+00', '2018-09-19 09:53:25.481233+00', 'Maxwell''s Rant', 'MAXWELLS RANT', 1, 32, 9999, 1, 3, 42, 453, '1752-01-01', '##>>

The Society’s version of this dance can be traced to Rutherford’s first collection of about 1755 where it is given as *Maxwill’s Rant*. 



The Maxwells, in common with many of the great Border families, regularly changed allegiance between English and Scottish monarchs as best suited the family interest. For example, Sir Eustace Maxwell held Caerlaverock Castle, the family seat, for Edward I in 1312 but by 1320 was one of the signatories of the Declaration of Arbroath as a supporter of Robert the Bruce although five months later he was accused, and cleared, of involvement in an attempted assassination of The Bruce.

##<<', 56, '888  888  800  844', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (17682, '2017-03-31 09:14:42.230109+00', '2020-06-27 21:01:19.816257+00', 'Grey Cairns of Camster', 'GREY CAIRNS OF CAMSTER', 3, 32, 9999, 6, 3, 18, 10397, NULL, '', 69, '444 444 666 888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18666, '2018-09-28 19:32:07.529728+00', '2018-09-28 21:48:32.21234+00', 'Welcome to Tübingen', 'WELCOME TO TUBINGEN', 1, 32, NULL, 2, 3, 18, 11720, '2018-08-01', 'Dedicated to the International Branch of the RSCDS



Symbolism: 



Bar 1 + 2 symbolises the Swabian Hello “Grüß Gott”  



Bar 3-8 a walk along of the rivers in Tübingen such as the Neckar, Steinlach, Ammer etc.  



Bar 9-16 Dancing couple meets other people and friends in Tübingen. Then they go different ways to discover different parts of Tübingen, while the second and the third couple do something together (chase - walk around and discover, cross - you meet each other in the small town, set - say hello). At the end they meet the first couple.  



As they had a wonderful time in Tübingen, they dance a circle. In addition, the circle symbolises integration, people from lots of different countries live in Tübingen, in good peaceful cohabitation and living with different generations.  

', 83, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18626, '2018-09-18 16:13:39.490674+00', '2018-09-20 04:38:30.582134+00', 'Ames to Please', 'AMES TO PLEASE', 2, 32, NULL, 1, 2, 76, 1268, NULL, 'Written by Doug Schneider and Susan Mills of the Highland Mist Scottish Country Dancers in Missouri, in honor of the upcoming 25th Iowa Ball. The inspiration was a lament by Liz Donaldson that people don’t seem to write dances with advance-and-retire and back-to-back any more...', -1, '88/88/44/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18758, '2018-10-05 06:19:50.910432+00', '2018-10-05 06:19:50.910432+00', 'Flume, The', 'FLUME', 1, 32, NULL, 1, 3, 42, 2766, '2008-05-01', 'The flume this dance refers to is in the Genesee River canyon in Letchworth State Park, New York. It has a stone bridge over it you can walk across and from which you can view the lower falls tumbling below.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18762, '2018-10-05 07:20:53.045122+00', '2018-10-05 07:20:53.045122+00', 'Follow the Yellow Brick Road', 'FOLLOW THE YELLOW BRICK ROAD', 1, 32, NULL, 2, 3, NULL, 2766, '2011-04-01', 'Note that the suggested music is 6 times through. I suggest that the second time a couple dances this dance, 1W dances a reel with 2C in bars 1-8 and with 3C in bars 9-16 and 1M dances only in bars 9-16.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17625, '2017-03-01 12:11:08.342667+00', '2020-11-07 11:07:30.081413+00', 'St Andrew''s Anniversary Strathspey', 'SAINT ANDREWS ANNIVERSARY STRATHSPEY', 3, 32, NULL, 2, 3, 17, 11456, NULL, 'Source:  Dance found on Danciemaetion and on the programme of the September Dance Party, Saturday, September 21, 2013, Austin, TX.



The Crib was taken from the Dance Party programme.  An error on bars 5-8 (2M+1L should be 1M+2L) has been corrected.  ', 53, '840/880/888/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16054, '2015-02-14 03:00:17.913128+00', '2018-09-25 11:17:46.942419+00', 'Camino Real, El', 'CAMINO REAL', 3, 40, NULL, 2, 3, 17, 3690, NULL, 'El Camino Real (The Royal Road) is the historic trail in California which is now approximated by U.S. 101, along which historic mission-bell markers have been placed. This route connects four of the Los Angeles Branch classes, from east to west Van Nuys, Thousand Oaks, Ventura, and Santa Barbara.



Note: The figure-of-eight grand chain is precisely the same pattern as the figure in the dance Equilibrium, here in strathspey time two bars to a hand, but beginning with the dancers in different positions from Equilibrium.  A good mnemonic for starting the figure is that the same two dancers who crossed diagonally in bars 7-8 are the ones who cross first diagonally in this figure.







', 93, '888/888/884/848/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9153, '1999-11-07 23:00:00+00', '2018-09-25 22:29:25.701437+00', 'Old Girls, The', 'OLD GIRLS', 3, 32, 9999, 1, 3, 42, 2675, '1990-08-15', 'Dedicated to all Wanganui Girls'' College Old Girls on the occasion of the 100th anniversary of the College celebrated in 1991. The dance was performed by eight Old Girls on Saturday 30 March 1991 at the "Nog ''n'' Natter" held in the College Hall.  



The formations in the dance depict aspects of the badge of the Wanganui Girls'' College Old Girls Association. The deviser wishes to acknowledge the use of the three couple half diagonal rights and lefts devised by Ian Barbour.', 69, '888/880/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18540, '2018-08-28 18:11:48.524224+00', '2019-06-27 21:28:48.143976+00', 'Bathampton Breakdown', 'BATHAMPTON BREAKDOWN', 4, 64, 5, 6, 3, 54, 11694, NULL, 'This dance is for everyone who would rather dance than stand about chatting. The triangle form lends itself best to true equality within the dance, where top and bottom have no meaning. The increasing demands and speed of the dance may lead to the suggested "Breakdown"!', 87, '444/444/888/888/888/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18672, '2018-10-01 10:37:44.812096+00', '2018-10-01 10:37:44.812096+00', '5 Feisty Women and Michael', '5 FEISTY WOMEN AND MICHAEL', 1, 32, NULL, 2, 3, 17, 2766, '2013-02-01', 'The women in my class are generally not shy and Michael is a favorite dancer in the class. At one time we found ourselves dancing in a set of 5 women and Michael. That same class we had danced to the music Feisty Women and I was tasked with writing a dance with this name.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13180, '2006-12-11 23:00:00+00', '2018-10-01 17:22:04.340052+00', 'Barnyard Dance!', 'BARNYARD DANCE', 1, 64, 9999, 4, 4, NULL, 2766, '2006-07-01', 'This dance was inspired by the book *Barnyard Dance!* I saw at a baby shower. This is a fun children’s book by Sandra Boynton. The dance described in the book looked like it could almost be a Scottish country dance, so I ''interpreted'' it. The music should not be too fast as the promenades can be a challenge to get into, and to be totally true to the book, the music should start with two chords, so people can bow to their partners and to their corners.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16288, '2015-05-06 22:32:32.992125+00', '2019-09-30 00:24:51.505654+00', 'After All These Years', 'AFTER ALL THESE YEARS', 3, 32, NULL, 1, 3, 42, 2766, '2011-10-01', 'Dan and I finally decided to marry after being together 15+ years. This dance has a knot and a circle for the marriage and a 3-couple bourrel as that is the figure I created from the regular bourrel. I wrote this during class the week we married while I was sitting out dancing and presented it later that night. My class told me this is one of my easier dances, which I find odd as it has a knot and a 3-couple bourrel.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18670, '2018-09-30 16:46:35.072118+00', '2019-02-03 23:40:25.608954+00', 'Unit 5', 'UNIT 5', 3, 32, NULL, 1, 3, 42, 146, '2006-01-01', 'Source: Minicrib



', 56, '866/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13177, '2006-12-11 23:00:00+00', '2018-10-02 13:32:31.24189+00', 'Calligraphy', 'CALLIGRAPHY', 1, 32, 9999, 1, 3, 42, 2766, '2006-06-01', 'I love the way the half reels in bars 9-16 flow; it always reminds me of a script capital letter L and thus gave me a name for this dance. All dancers are encouraged to add loops on the ends of the half reels when possible.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16473, '2015-07-07 16:13:34.402175+00', '2018-10-02 19:22:10.865892+00', 'Lincoln Imp, The', 'LINCOLN IMP', 2, 32, 9999, 1, 3, 42, 10959, NULL, 'The Lincoln Imp is said, in legend, to have been sent by the devil to plague the clergy of Lincoln Cathedral.  He was blown in the great west doors by the west wind and blew out the candles, scattered the hymn sheets and attacked the choristers.  He flew into the angel choir, and when he threatened to pluck out the angels'' feathers the smallest angel turned him into stone.  He can be found today near the top of one of the pillars in the cathedral.



This dance was devised by Deirdre MacCuish Bark to honour her husband, the notably impish Scroll of Honour winning Keith Bark, who is from Lincoln. The legend of the Lincoln Cathedral Imp who was thwarted and turned to stone by the littlest angel is depicted. When 1st lady is chasing her partner near the end, and he looks back, the standing dancers are like pillars in the cathedral, where the stone imp now resides.', 53, '662/886/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18750, '2018-10-04 23:46:21.217124+00', '2018-10-04 23:46:21.217124+00', 'Firefly Flirt', 'FIREFLY FLIRT', 1, 32, NULL, 2, 3, NULL, 2766, '2015-03-01', 'I was intrigued by the idea of swapping ends of the set each time through a dance and wrote several dances to try it out. This is the reel.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15740, '2015-01-09 16:27:35.886961+00', '2018-12-06 12:00:13.390992+00', 'Frances''s Fancy', 'FRANCESS FANCY', 3, 40, 9999, 2, 3, 17, 3694, '2009-05-31', 'For Frances Richardson who chose the Targe as her favourite figure', 65, '808/484/446/808/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18701, '2018-10-02 22:27:19.821311+00', '2018-10-02 22:27:19.821311+00', 'Carpenter''s Wheel', 'CARPENTERS WHEEL', 3, 80, NULL, 4, 4, NULL, 2766, '2013-03-01', 'At the 2013 Madison Ball, Lynn Litterer mentioned a figure she''d danced at a workshop earlier that day (the Helix) and asked if I could create a dance for which the name Double Helix would be appropriate. This is the third of several dances I came up with. When we first danced this, Mady Newfield said the figures seemed like a quilt pattern. Carpenter''s Wheel is one of my favorite quilt patterns and the figures in this dance seem to fit pattern.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10265, '2001-11-25 23:00:00+00', '2018-10-02 22:30:52.885605+00', 'Chasing Castles', 'CHASING CASTLES', 1, 32, 9999, 1, 3, 42, 2766, '2001-08-01', 'During my August 2001 trip to Scotland we visited a number of castles. My favorite was Inverlochy Castle, which was built in the 1300''s and is the classic shape of a castle in childhood stories (square with round towers at the corners).', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11761, '2004-08-21 22:00:00+00', '2018-10-03 01:24:46.633069+00', 'Another City, Another Move', 'ANOTHER CITY ANOTHER MOVE', 1, 32, 9999, 1, 3, 42, 2766, '2003-12-01', 'I wrote this dance as I was thinking about how Katherine Andrefsky and Gordon Anderson (who were here much too short a time) move every few years and have to deal with packing and moving and all. It may help to understand this dance to realize that the first 24 bars are 6 bar phrasing: set, cross, cast – turn LH, balance, turn corners in – turn LH, balance, turn corners in – turn LH, balance, turn corners in.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11494, '2003-09-22 22:00:00+00', '2018-10-05 07:30:50.659596+00', 'Four-poster Jig, The', 'FOURPOSTER JIG', 2, 32, 9999, 1, 4, NULL, 2766, '2002-10-01', 'Suggested music is Susan’s Jig Set from The Music Makars. (I actually was hearing The Moudiewort from Muckle Carfuffle while this dance occurred to me, but it is 8 times through.).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12500, '2005-07-30 22:00:00+00', '2018-10-03 12:03:23.888299+00', 'Cry Havoc', 'CRY HAVOC', 1, 32, 9999, 1, 3, 42, 2766, '2005-07-01', 'This summer my group has had a large number of new dancers join us for regular dancing. This has led to some interesting problems as often they outnumber the regular dancers. Recently we tried a dance with consecutive half reels and realized half figures are hard for those still learning timing. Barbara Parks mentioned she’d like a dance of all half figures that she’d name Havoc. I liked the idea and came up with this dance and a slightly modified name. I chose the music because it sounds busy and carries with it a slightly frenetic feeling, even though it isn’t any faster than other reels.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12182, '2005-04-14 22:00:00+00', '2018-10-04 05:15:11.090801+00', 'Dance Program, The', 'DANCE PROGRAM', 3, 32, 9999, 1, 3, 42, 2766, '2004-03-01', 'This dance was written in frustration as I searched for appropriate dances for a ball program. Most strathspeys with a poussette are for two couples and I couldn’t find a dance with the combinations of figures I wanted, so I wrote one that combines some of my favorite strathspey figures.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18732, '2018-10-04 08:15:30.321755+00', '2018-10-04 08:15:30.321755+00', 'Diamonds on Black Velvet', 'DIAMONDS ON BLACK VELVET', 3, 32, NULL, 1, 3, 42, 2766, '2012-06-01', 'On a trip to Mexico I stayed in a thatched hut on the Chichen Itza site. I remember the night sky as darker than any I''d ever seen before and the Milky Way sprinkled across it like diamonds on black velvet.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9493, '2000-09-04 22:00:00+00', '2018-10-04 08:07:07.640732+00', 'Diagonal Jig, A', 'DIAGONAL JIG', 2, 24, 9999, 1, 3, 42, 2766, '2000-02-01', 'I wanted to emphasize technique in diagonal rights and lefts, but all dances I found with the figure are fairly complex. So I wrote a simple dance with diagonal rights and lefts and it turned out to dance rather nicely.', 46, '800/488/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18748, '2018-10-04 23:35:26.404774+00', '2018-10-04 23:35:26.404774+00', 'Fiddle Meister, The', 'FIDDLE MEISTER', 2, 32, NULL, 1, 3, 42, 2766, '2014-09-01', 'This dance was written in honor of Tim Macdonald taking first place in the 2014 US National Scottish Fiddling Championship.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18747, '2018-10-04 23:30:37.807979+00', '2019-01-30 16:19:05.671157+00', 'Fanwood Frolic', 'FANWOOD FROLIC', 1, 32, NULL, 3, 5, 33, 2766, '2008-11-01', 'This dance commemorates my trip to New York, when I took the train to New Jersey and dances with the SCD group in Fanwood.', 75, '82842/86846/88888/80844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10241, '2001-11-25 23:00:00+00', '2019-06-30 07:54:03.154767+00', 'Moment of Coalescence, The', 'MOMENT OF COALESCENCE', 3, 32, 9999, 1, 3, 42, 2767, '2000-10-01', 'In class, Doug often mentions the "moment of coalescence" when the figures end and all couples are neatly in places on the sides of the dance, just before entering the next figure. I decided to write a dance that flowed, but where each figure ended exactly on the sides, rather than in other positions as often happens. When I first wrote the dance, it had no reels, and when I showed it to Mady, she said the moment of coalescence requires reels, so we replaced bars 17-24 with reels.', 63, '844/888/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18738, '2018-10-04 09:01:35.950919+00', '2018-10-04 09:01:35.950919+00', 'Double Helix, The', 'DOUBLE HELIX', 3, 32, NULL, 1, 100, 2, 2766, '2013-03-01', 'At the 2013 Madison Ball, Lynn Litterer mentioned a figure she''d danced at a workshop earlier that day (the Helix) and asked if I could create a dance for which the name Double Helix would be appropriate. This is the first of several dances I came up with.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9494, '2000-09-04 22:00:00+00', '2018-10-04 10:17:38.830359+00', 'Ducks on the Pond', 'DUCKS ON THE POND', 4, 32, 1, 1, 3, 42, 2766, '2000-03-01', 'This dance was inspired by the behavior of the ducks on our new property. Frequently when we visit the property, there are ducks on the pond. They swim in circles, often in pairs, until they realize we are there; then they converge to a group, quack excitedly, and fly or swim off in groups to the other end of the pond, where they swim agitatedly for a while.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18749, '2018-10-04 23:38:42.060284+00', '2018-10-04 23:38:42.060284+00', 'Fifth Helix, The', 'FIFTH HELIX', 3, 32, NULL, 1, 3, 42, 2766, '2013-04-01', 'At the 2013 Madison Ball, Lynn Litterer mentioned a figure she''d danced at a workshop earlier that day (the Helix) and asked if I could create a dance for which the name Double Helix would be appropriate. This is the fifth of several dances I came up with.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12190, '2005-04-14 22:00:00+00', '2019-06-04 17:23:22.084039+00', 'Double Nickels', 'DOUBLE NICKELS', 1, 32, 9999, 3, 5, 7, 2766, '2004-08-01', 'I wrote this dance for all of us who have passed a certain milestone (double nickel originally referred to the 55 mile-per-hour speed limit in the U.S.) and to prove we could still dance. The reel version proved a bit speedy (although a tweak to bars 23 and 24 helped), so we tried it as a strathspey and it works quite well.', 73, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13419, '2009-11-10 23:00:00+00', '2019-02-20 10:05:42.835988+00', 'Joan''s Joy', 'JOANS JOY', 2, 32, NULL, 2, 3, 17, 3718, NULL, '', 58, '800/844/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18718, '2018-10-03 11:54:10.014254+00', '2020-12-15 13:17:43.431572+00', 'Crossing the Deadly Desert', 'CROSSING THE DEADLY DESERT', 1, 40, NULL, 3, 5, 7, 2766, '2010-10-01', 'This dance gets its name from the book Ozma of Oz where the people from OZ have to cross the Deadly Desert to get to the Nome King’s kingdom to rescue the people of the Land of Ev. All the setting and moving seemed like what one might have to do to avoid all that hot sand.', 78, '86846/84884/88808/84884/84844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18764, '2018-10-05 07:34:07.465722+00', '2018-10-05 07:34:07.465722+00', 'Freedom Rant, The', 'FREEDOM RANT', 1, 32, NULL, 1, 3, 42, 2766, '2007-07-01', 'Written around the time of the July 4th holiday in honor of Independence Day. I chose a tune with pipes as I used to march in a pipe band and spent several July 4ths marching in parades to the sound of pipes.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18765, '2018-10-05 07:36:27.970556+00', '2018-10-05 07:36:27.970556+00', 'French Roundabout, The', 'FRENCH ROUNDABOUT', 2, 32, NULL, 1, 3, 42, 2766, '2014-08-01', 'Note that 1C is dancing diagonal reels while corners are dancing half reels around the outside of the set. At the start of each half reel, corners dance into the set and 1C dances out of the set.  



Written for a local dancer originally from France whose name is Charles.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9482, '2002-08-29 22:00:00+00', '2018-10-05 08:05:48.98593+00', 'Frolic, The', 'FROLIC', 1, 40, 9999, 1, 3, 42, 2766, '1997-09-01', 'Suggested music is any 40-bar reel similar to *Mairi''s Wedding*.  



This dance was written to celebrate the annual fall dance, *Frolic on the Fox*, put on by my local class of the RSCDS - Chicago branch.', 81, '800/888/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18770, '2018-10-05 08:35:04.135483+00', '2018-10-05 08:35:04.135483+00', 'Genesee River Gorge, The', 'GENESEE RIVER GORGE', 2, 32, NULL, 1, 3, 42, 2766, '2008-06-01', 'The Genesee River Gorge runs through Letchworth State Park in New York State. This is a beautiful area with three large waterfalls.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18771, '2018-10-05 08:38:18.45619+00', '2018-10-05 08:38:18.45619+00', 'George Whitehorne', 'GEORGE WHITEHORNE', 2, 32, NULL, 1, 2, NULL, 2766, '2010-09-01', 'This dance is written in honor of George Whitehorne, who has written many fun dancers and is the father of a friend and fellow dancer.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13975, '2011-08-24 22:00:00+00', '2018-11-09 20:10:49.71246+00', 'Jill''s Gentle Jig', 'JILLS GENTLE JIG', 2, 32, NULL, 1, 3, 42, 2701, '2001-01-01', 'Jill''s Gentle Jig by Tim Wilson honors Jill Breslauer, a longtime member of the San Francisco class.  The dance was written in 2001 and published in the SF Class''s book Measures of Pleasure.

The first tune was written for the dance by Gary Thomas in 2007 and was published with the dance in 2007.  



The rather brisk third figure is the version of ''Double Triangles'' described  Thomas Wilson (no relation to Tim) in 1811.  



The conclusion of each time through should be danced with the right shoulder swirl into place as performed by Tim and Trina (in Video 1).  Optionally, if there is time, Tim suggests swirling around each other into place. 

There is usually not enough time.  



The band consists of Gary Thomas with Ron Wallace and Steve Wyrick.  The dancers are Tim Wilson and Trina Merriman, Sylvain Pelletier with Pat Obrien, Bruce Herbold with Eileen Richey and Geoffrey Wood with Claire Hunter Chow.   

', 50, '880/844/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18776, '2018-10-05 12:22:48.506362+00', '2018-10-05 12:23:03.75091+00', 'Go Cubs Go', 'GO CUBS GO', 1, 32, NULL, 1, 3, 42, 2766, '2016-11-01', 'This dance is written to celebrate the Chicago Cubs winning the 2016 World Series – their first such win in 108 years.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18777, '2018-10-05 12:25:03.167638+00', '2018-10-05 12:25:03.167638+00', 'Golden Rain', 'GOLDEN RAIN', 1, 32, NULL, 1, 3, 42, 2766, '2012-07-01', 'I wrote this on the 4th of July (Independence Day); golden rain refers to one of the kinds of fireworks popular on this day.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18779, '2018-10-05 12:30:50.886315+00', '2018-10-05 12:30:50.886315+00', 'When Nothing Goes Right Go Left', 'WHEN NOTHING GOES RIGHT GO LEFT', 1, 32, NULL, 1, 3, 42, 2766, '2012-03-01', 'I love this expression and my class told me to write a dance for the phrase.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11500, '2003-09-22 22:00:00+00', '2018-10-05 12:33:44.38104+00', 'Great Big Sea', 'GREAT BIG SEA', 1, 32, 9999, 1, 3, 42, 2766, '2001-08-01', 'I attended a Celtic concert at Ravinia with a group of Scottish Country Dancers and on the program was a group called Great Big Sea that played toe-tapping tunes. I wrote this dance while listening to them play.', 34, '800/844/822/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18781, '2018-10-05 13:05:44.699783+00', '2018-10-05 13:05:44.699783+00', 'Gypsy', 'GYPSY', 3, 32, NULL, 1, 3, 42, 2766, '2014-02-01', 'This dance was written after seeing a production of Gypsy and wanting to incorporate the gypsy figure into a dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12494, '2005-07-26 22:00:00+00', '2018-10-05 13:10:14.424915+00', 'Hannah''s Journey', 'HANNAHS JOURNEY', 1, 32, 9999, 1, 3, 42, 2766, '2005-05-01', 'This dance was written to go with music written specifically for Hannah Newfield-Plunkett to mark her graduation from high school. The tune is named Merry Ship to England. Other suitable music is *The Carl Cam’ Ower the Croft* from Muckle Carfuffle.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18784, '2018-10-05 13:30:12.41709+00', '2018-10-05 13:30:12.41709+00', 'Harrington''s Feather', 'HARRINGTONS FEATHER', 2, 32, NULL, 1, 3, 42, 2766, '2015-04-01', 'Our cat Harrington loves to play with a feather cat toy and jumps around all over the place to try to catch it.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18786, '2018-10-05 13:34:25.53947+00', '2018-10-05 13:34:25.53947+00', 'Hawk on the Rail', 'HAWK ON THE RAIL', 3, 32, NULL, 1, 3, 42, 2766, '2016-03-01', 'One day I looked out and saw a young red-tailed hawk sitting on our deck railing. It sat there for quite a while surveying the area, swiveling its head 180 degrees left, right, and back.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18377, '2018-06-11 09:28:44.293734+00', '2018-10-05 13:57:08.735487+00', 'How to Teach a Human', 'HOW TO TEACH A HUMAN', 1, 32, NULL, 1, 4, NULL, 2766, '2011-06-01', 'Note: timing is critical in bars 9-24; people in corner positions should allow the people in the center to dance to the right and start dancing out to corner positions.  



This dance is for my third cat, Shadow. Shadow was a gray tabby with patches of red and spots on her belly. She loved to play and would jump feet into the air trying to catch a tinfoil ball.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18792, '2018-10-05 14:41:52.021564+00', '2018-10-05 14:41:52.021564+00', 'Inquisitive Paws', 'INQUISITIVE PAWS', 1, 32, NULL, 1, 3, NULL, 2766, '2007-02-01', 'After years of nursing sick, elderly cats, we found ourselves with no cats and adopted four young, healthy males. This dance captures one of the joys we now experience: paws under closed doors, seeking out attention or anything that might pass as a toy.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18794, '2018-10-05 14:46:11.987042+00', '2018-10-05 14:46:11.987042+00', 'In the Boreal Forest', 'IN THE BOREAL FOREST', 1, 32, NULL, 1, 3, 42, 2766, '2015-02-01', 'I was inspired after reading about the boreal forest in a National Geographic article – it encircles the Arctic and based on the lovely shades of green in the pictures with the article, I want to go.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13193, '2006-12-11 23:00:00+00', '2018-10-05 14:48:27.024634+00', 'Inverlochy Castle', 'INVERLOCHY CASTLE', 3, 32, 9999, 1, 3, 42, 2766, '2005-11-01', 'When I traveled in Scotland, my favorite spot was Inverlochy Castle, which has round towers at each of its four corners like a fairy-tale castle.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19188, '2019-02-19 15:04:22.604179+00', '2019-02-19 21:07:47.688548+00', 'So Far Yet So Close', 'SO FAR YET SO CLOSE', 3, 32, NULL, 1, 3, 42, 11780, NULL, '', 50, '800/844/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18774, '2018-10-05 09:39:32.444216+00', '2022-08-17 21:03:12.619079+00', 'Glass Scroll, The', 'GLASS SCROLL', 3, 32, NULL, 1, 3, 42, 2766, '2011-10-01', 'I''ve written a few dances now with the figure in bars 9-16 and Mady Newfield suggested that I call it a French Scroll to give it a name and make it easier to brief. The name of the dance is a combination of the name of the figure and the name of the chosen tune.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13199, '2006-12-11 23:00:00+00', '2018-10-05 14:49:28.868018+00', 'Irregular Progression, An', 'IRREGULAR PROGRESSION', 2, 32, 9999, 107, 6, NULL, 2766, '2005-10-01', 'Couples are arranged in two regular triangular sets in the following formation with the A set aligned as normal, A1 with their backs to the music and the B set aligned as if rotated 180°, so B1 is facing the music:  



Doug Jensen has lead the Silk & Thistle class for more than the eleven years I have danced with the class. He prepares on average 50 classes a year and is always ready for whoever shows up - we have new people drop in at any time. This dance is written to honor him, his dedication, and his very special birthday this year.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18796, '2018-10-05 14:54:19.029938+00', '2018-10-05 14:54:19.029938+00', 'It''s Just a Number', 'ITS JUST A NUMBER', 1, 32, NULL, 1, 3, 42, 2766, '2016-03-01', 'My Mom has hated birthdays since turning 80 and is at the time of writing this dance 91. I always tell her "It’s just a number."', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9568, '2000-09-05 22:00:00+00', '2018-10-05 14:57:28.145155+00', 'Ivy Vines', 'IVY VINES', 1, 32, 9999, 1, 3, 42, 2766, '2000-07-01', 'I loved this music the first time I heard it and wanted to write a dance to it. When I listened to it again, this dance wrote itself.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12284, '2005-04-25 22:00:00+00', '2018-10-05 15:06:19.540901+00', 'Jensen Jig, The', 'JENSEN JIG', 2, 96, 9999, 4, 4, NULL, 2766, '2004-10-01', 'This dance is written to honor Doug Jensen, who runs the Silk & Thistle class of the Chicago Branch 50 or more weeks a year, and is always well prepared for and patient with the class.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11495, '2003-09-22 22:00:00+00', '2018-10-05 15:52:36.996056+00', 'King Tut', 'KING TUT', 1, 32, 9999, 6, 3, NULL, 2766, '2002-10-01', 'This dance occurred to me while I was watching a TV program proposing that King Tutankamen had been assassinated.

  	', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18803, '2018-10-05 15:54:08.527643+00', '2018-10-05 15:54:08.527643+00', 'Kitty Cornered', 'KITTY CORNERED', 1, 32, NULL, 1, 3, 42, 2766, '2013-03-01', 'One night I lay down to go to bed and opened my eyes to find 2 cats around my head and 1 at my side and felt kitty cornered.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18787, '2018-10-05 13:38:24.458485+00', '2019-09-02 23:30:03.589124+00', 'Herding Cats', 'HERDING CATS', 2, 32, NULL, 1, 3, 42, 2766, '2012-07-01', 'Not much of this dance contains figures that parallel or mirror and the messiness of it reminded me of the phrase herding cats – which is quite appropriate since I have never lived without cats.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18805, '2018-10-05 16:23:13.382776+00', '2018-10-05 16:28:31.398015+00', 'Lace Across the Sky', 'LACE ACROSS THE SKY', 1, 32, NULL, 1, 3, 42, 2766, '2014-07-01', 'This dance was written the day after powerful thunderstorms raked the area and lightning wrote lace on the clouds.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12483, '2005-07-24 22:00:00+00', '2018-10-05 21:30:26.906992+00', 'Ladies'' Auxiliary, The', 'LADIES AUXILIARY', 2, 48, 9999, 1, 3, 42, 2766, '2005-03-01', 'We have a group of ladies who meet nearly every Friday for handwork and also spend a lot of time planning SCD events, e.g. the New Year’s Ball, the Weekend Workshop, etc. for the Branch.', 51, '660/860/606/848/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18809, '2018-10-05 21:35:41.273413+00', '2018-10-05 21:35:41.273413+00', 'Lady from Wales, The', 'LADY FROM WALES', 2, 32, NULL, 1, 3, 42, 2766, '2014-09-01', 'This dance was written in memory of Stephanie Donaghey who was born in Wales and danced with our class for several years.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18811, '2018-10-05 21:43:32.087545+00', '2018-10-05 21:43:32.087545+00', 'Lady Mairi''s Dream', 'LADY MAIRIS DREAM', 1, 32, NULL, 1, 3, 42, 2766, '2013-07-01', 'I wanted to try a dance with a quicktime tournée and also wanted to try the ''old way'' of performing bar 4 in the tournée. This dance combines figures from Lady McGowan''s Dream and Mairi''s Wedding.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18533, '2018-08-26 11:22:19.131728+00', '2018-10-05 22:12:56.257907+00', 'Lyon Treasurer, The', 'LYON TREASURER', 2, 32, NULL, 1, 3, 42, 11689, NULL, 'This dance was devised by Laure Gardelle for Pierre Vernay, of the RSCDS Lyon Branch, when he left his position as treasurer in 2010. Not only is he greatly appreciated as a person and as a dancer, but he has

also proved an invaluable treasurer. A big thank you from everyone at the Branch.', 59, '844/822/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14955, '2013-06-25 08:32:31.045277+00', '2018-10-06 05:06:08.485082+00', 'Lavender Strathspey, The', 'LAVENDER STRATHSPEY', 3, 32, NULL, 1, 3, 42, 2766, '2011-01-01', 'This dance was written for Barbara Youngman, leader of the Durham, North Carolina class.  



Note that the gypsy poussette in this dance is a slight variant of the figure invented by Terry Glasspool in his dance Gypsy Dreams.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18813, '2018-10-06 05:31:26.448764+00', '2018-10-06 05:31:26.448764+00', 'Lenten Rose, The', 'LENTEN ROSE', 3, 32, NULL, 1, 3, 42, 2766, '2012-04-01', 'I have a Lenten Rose growing in my backyard; the flower is lovely and the figures are a bit reminiscent of the shape of the flower.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18829, '2018-10-06 10:34:21.755316+00', '2018-10-06 10:34:21.755316+00', 'Mike''s Request', 'MIKES REQUEST', 1, 32, NULL, 1, 3, 42, 2766, '2014-08-01', 'After dancing a dance with a progressive grand chain I was asked by a friend to create a dance using this figure.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18815, '2018-10-06 05:39:12.414085+00', '2018-10-06 05:53:23.290432+00', 'Lightning in a Bottle', 'LIGHTNING IN A BOTTLE', 1, 32, NULL, 1, 3, 42, 2766, '2013-10-01', 'I remember catching fireflies as a child – in a bottle – and watching them flash for a while before releasing them.', 44, '800/880/808/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18816, '2018-10-06 08:07:03.648643+00', '2018-10-06 08:07:03.648643+00', 'Linda''s Trip to Beloit', 'LINDAS TRIP TO BELOIT', 3, 32, NULL, 1, 3, 42, 2766, '2015-06-01', 'This dance is written to mark Linda Henderson’s trip to the Midwest Weekend Workshop in Beloit, WI.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12489, '2005-07-26 22:00:00+00', '2018-10-06 08:08:58.16278+00', 'Lipstick on my Knee', 'LIPSTICK ON MY KNEE', 2, 32, 9999, 1, 3, 42, 2766, '2004-09-01', 'The name for this dance occurred when Mady Newfield bent to check out something on Mike Fitak’s reenactment leggings just as he raised his knee.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18817, '2018-10-06 08:11:55.334154+00', '2018-10-06 08:11:55.334154+00', 'Little H', 'LITTLE H', 1, 32, NULL, 1, 3, 42, 2766, '2011-07-01', 'This dance is named for our cat Harrington, whom we affectionately call Little H because he is our largest cat.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18819, '2018-10-06 08:35:31.610055+00', '2018-10-06 08:35:31.610055+00', 'Loki''s Reel', 'LOKIS REEL', 1, 32, NULL, 1, 3, 42, 2766, '2008-11-01', 'Loki is the god of mischief in Norse mythology. We affectionately call one of our cats Loki because he is always stirring up the other cats.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18820, '2018-10-06 08:39:29.700433+00', '2018-10-06 08:39:29.700433+00', 'Lorain Moraine, The', 'LORAIN MORAINE', 1, 32, NULL, 1, 3, 42, 2766, '2008-04-01', 'The Lorain Moraine is a ridge deposited at the time of glaciers just south of Lake Erie near Cleveland, Ohio.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18822, '2018-10-06 08:50:00.872829+00', '2018-10-06 08:50:00.872829+00', 'Lynn''s Request', 'LYNNS REQUEST', 3, 32, NULL, 1, 3, 42, 2766, '2013-03-01', 'At the 2013 Madison Ball, Lynn Litterer mentioned a figure she''d danced at a workshop earlier that day (the Helix) and asked if I could create a dance for which the name Double Helix would be appropriate. This is the second of several dances I came up with.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18912, '2018-10-09 10:46:06.3191+00', '2018-10-09 10:46:06.3191+00', 'There Are No Auroras on Venus', 'THERE ARE NO AURORAS ON VENUS', 1, 32, NULL, 1, 3, 42, 2766, '2016-05-01', 'I wrote this dance after watching a TV show that mentioned there are no auroras on Venus because it lacks a strong magnetic field.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18824, '2018-10-06 09:06:12.289494+00', '2018-10-06 09:06:12.289494+00', 'Mady''s Idea', 'MADYS IDEA', 3, 32, NULL, 1, 3, 42, 2766, '2013-04-01', 'At the 2013 Madison Ball, Lynn Litterer mentioned a figure she''d danced at a workshop earlier that day (the Helix) and asked if I could create a dance for which the name Double Helix would be appropriate. This is the fourth of several dances I came up with. The figure in bars 9-16 is based on an idea Mady Newfield had in class when we tried one of the earlier Helix dances.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12310, '2005-04-25 22:00:00+00', '2018-10-06 10:09:35.858657+00', 'Maureen Calling', 'MAUREEN CALLING', 1, 32, 9999, 1, 4, NULL, 2766, '2005-01-01', 'This dance is written for Maureen Pettigrew on the occasion of her birthday; the name of the dance is the salutation she often uses when sending out email.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11460, '2003-09-22 22:00:00+00', '2018-10-06 10:10:49.033793+00', 'Merry Go Round Mountains, The', 'MERRY GO ROUND MOUNTAINS', 2, 32, 9999, 1, 3, 42, 2766, '2002-04-01', 'The Merry Go Round Mountains are featured in the Oz Book, The Lost Princess of Oz; they are spinning rubber cones that must be crossed to save Ozma from her captor.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18827, '2018-10-06 10:18:09.847379+00', '2018-10-06 10:18:09.847379+00', 'Midnight Crazies, The', 'MIDNIGHT CRAZIES', 1, 32, NULL, 1, 3, 42, 2766, '2008-08-01', 'This dance was inspired by the antics of our cats: about the time we’re ready to go to bed, they decide to bounce off the walls!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18828, '2018-10-06 10:20:32.282359+00', '2018-10-06 10:20:32.282359+00', 'Midwestern Links', 'MIDWESTERN LINKS', 2, 32, NULL, 1, 3, 42, 2766, '2006-06-01', 'Three Midwestern branches work together to put on the Midwest Scottish Weekend (Chicago, Madison, and Milwaukee).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18830, '2018-10-06 10:40:28.041698+00', '2018-10-06 10:40:28.041698+00', 'Miss Cream Coral', 'MISS CREAM CORAL', 1, 32, NULL, 1, 3, 42, 2766, '2011-08-01', 'My fifth cat was a pure-bred Persian with papers that I officially named Miss Cream Coral but called Cory. She was a truly pink cat and beautiful, but she didn’t like being in a multi-cat household, so I ended up giving her to a friend whose only other pet was a neurotic Sheltie named Princess. Cory and Princess became fast friends, so it worked out well for all.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18870, '2018-10-07 11:41:57.946341+00', '2018-10-07 11:41:57.946341+00', 'Rocky River Reel, The', 'ROCKY RIVER REEL', 1, 32, NULL, 1, 3, 42, 2766, '2008-01-01', 'The Rocky River runs near where I grew up on the western edge of Lakewood, Ohio."', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18831, '2018-10-06 10:50:44.294264+00', '2018-10-06 10:50:44.294264+00', 'Monty''s Little Brother', 'MONTYS LITTLE BROTHER', 2, 32, NULL, 1, 3, 42, 2766, '2015-02-01', 'I like to do the setting in Montgomeries’ Rant as it is done in The Full Monty and wrong this dance to incorporate a variation of that setting.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12328, '2005-04-27 22:00:00+00', '2018-10-06 11:25:03.046367+00', 'Motorcycle Lady', 'MOTORCYCLE LADY', 3, 32, 9999, 1, 4, NULL, 2766, '2005-02-01', 'This dance is written for Mary Helen Polensky, one of the original members of the Silk & Thistle class, who enjoys touring with her husband on his motorcycle.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18833, '2018-10-06 11:33:28.129753+00', '2018-10-06 11:33:28.129753+00', 'Mr. Gilbert Has Arrived!', 'MR GILBERT HAS ARRIVED', 1, 32, NULL, 1, 3, 42, 2766, '2016-08-01', 'Dancers in our class welcomed a baby boy they named Gilbert in August this year.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18834, '2018-10-06 11:36:49.153947+00', '2018-10-06 11:36:49.153947+00', 'Mrs Norma Briggs', 'MRS NORMA BRIGGS', 3, 32, NULL, 1, 4, NULL, 2766, '2015-08-01', 'Norma Briggs was a lovely lady and a major contributor to establishing and maintaining the Madison Branch.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18836, '2018-10-06 11:46:04.287067+00', '2018-10-06 11:46:04.287067+00', 'My Bonny Beau', 'MY BONNY BEAU', 3, 32, NULL, 1, 3, 42, 2766, '2011-02-01', 'This dance is for my cat Beau. Beau was one of a pair of American Shorthair silver and black tabbies and though he didn’t have the gorgeous markings of his sister, Belle, he had a really sweet face and disposition.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18726, '2018-10-04 05:40:40.185356+00', '2018-10-06 12:22:55.473951+00', 'Dark Side of the Moon, The', 'DARK SIDE OF THE MOON', 2, 32, NULL, 1, 4, 1, 2766, '2012-06-01', 'This dance is a good teaching dance for the timing of reels of four.', 84, '8888/8888/8440/8668', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18839, '2018-10-06 12:37:27.183127+00', '2018-10-06 12:37:27.183127+00', 'Niddy Noddy', 'NIDDY NODDY', 1, 32, NULL, 1, 3, 42, 2766, '2013-02-01', 'A niddy noddy is a bar with crossbars at each end and offset from each other by 90 degrees. It is used to create skeins of yarn.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18842, '2018-10-06 12:50:50.061486+00', '2018-10-06 12:50:50.061486+00', 'Off the Axum', 'OFF THE AXUM', 1, 32, NULL, 3, 5, 7, 2766, '2013-02-01', 'One of the dancers in my class has written a couple of dances based on the Axum reel, so I decided to try a 5-couple version and realized it is no longer a reel, but still based on the tracks of the Axum reel.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18844, '2018-10-06 13:00:02.054922+00', '2018-10-06 13:00:02.054922+00', 'Off to Virginia Reel, The', 'OFF TO VIRGINIA REEL', 1, 32, NULL, 1, 3, NULL, 2766, '2007-07-01', 'This dance is written for Jeanne and Mike Millin as they are moving from Chicago to Williamsburg, Virginia.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13153, '2006-12-11 23:00:00+00', '2018-10-06 13:01:48.17881+00', 'Olympic Gold', 'OLYMPIC GOLD', 3, 32, 9999, 3, 5, 41, 2766, '2006-02-01', 'This dance is dedicated to Michelle Kwan, Kurt Browning, and all other Olympic athletes who went to the games with golden talents, but didn’t win a gold medal. The figure in bars 17-24 represents the five Olympic rings.', 45, '80008  80008  66666  60202', 1, 1, 1, 1, 45);
INSERT INTO 'dance' VALUES (11458, '2003-09-22 22:00:00+00', '2018-10-06 13:27:09.8367+00', 'Ozma of Oz', 'OZMA OF OZ', 1, 32, 9999, 4, 4, NULL, 2766, '2002-04-01', 'I am a great fan of the Oz books and Ozma of Oz is one of my favorites in the series. This dance traces out the OZ symbol (mirrored).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18847, '2018-10-06 13:29:24.718113+00', '2018-10-06 13:29:24.718113+00', 'Panama!', 'PANAMA', 1, 32, NULL, 2, 3, 17, 2766, '2007-05-01', 'This dance is a palindrome (if you take cross/cast as a single figure). I took the name from "a man, a plan, a canal, Panama!"', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18848, '2018-10-06 13:33:55.829873+00', '2018-10-06 13:33:55.829873+00', 'Parchment Scroll, A', 'PARCHMENT SCROLL', 1, 32, NULL, 1, 3, 42, 2766, '2012-07-01', 'The paths inscribed by the reels in this dance remind me of how a scroll looks from the side.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11470, '2003-09-22 22:00:00+00', '2018-10-07 12:38:27.928993+00', 'Search for MacDonald, The', 'SEARCH FOR MACDONALD', 1, 32, 9999, 3, 5, 16, 2766, '2002-07-01', 'I liked this music and wanted to write a dance that worked with it. Also, I spent part of my trip to Scotland in 2001 researching my name. I had always known my name was associated with Clan Donald somehow, but it wasn’t until this trip I learned it is an alternate spelling of MacDonald.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13197, '2006-12-11 23:00:00+00', '2021-01-04 16:12:12.895197+00', 'Miss Nora Elizabeth', 'MISS NORA ELIZABETH', 3, 32, 9999, 2, 3, 17, 2766, '2005-10-01', 'Nora Elizabeth Fitak entered this world in October of this year. This dance was written to welcome her.', 67, '800  880  808  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (18852, '2018-10-06 19:41:09.727908+00', '2019-09-24 17:36:03.758161+00', 'Watchmaker', 'WATCHMAKER', 3, 32, NULL, 1, 2, NULL, 2682, '2018-09-12', 'This is a teaching dance for tourbillon for intermediate dancers. Most dances with this figure are quite complex. I wished to remedy that, with a relatively straightforward dance involving quite familiar figures, and natural transitions.  



In 1801, Abraham-Louis Breguet patented the tourbillon (= whirlwind in French) as an addition to the mechanics of watch escapement to counteract the effect of gravity.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18853, '2018-10-06 19:46:00.938949+00', '2018-10-06 19:46:00.938949+00', 'Helen Brown', 'HELEN BROWN', 3, 32, NULL, 1, 4, NULL, 2682, '2018-07-01', 'Presented at \Downey Day of Dance, 2018". Given to Helen Brown for all her work for the York Branch and her (and Malcolm''s) hospitality to Kristin and me. Recommended music is "The Bob O'' Dowally", and either of the recordings for Book 2 by Bobby Crowe would be good. Lacking this a strong strathspey should be used (not an air).', -1, '', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (18871, '2018-10-07 11:45:28.685565+00', '2018-10-07 11:45:28.685565+00', 'Rollercoaster Ride', 'ROLLERCOASTER RIDE', 1, 32, NULL, 1, 3, 42, 2766, '2009-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18872, '2018-10-07 11:51:30.581974+00', '2018-10-07 11:51:30.581974+00', 'Rose of Sharon', 'ROSE OF SHARON', 3, 32, NULL, 1, 3, 42, 2766, '2010-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18874, '2018-10-07 12:14:06.690547+00', '2018-10-07 12:14:06.690547+00', 'Salmagundi', 'SALMAGUNDI', 1, 32, NULL, 3, 5, 6, 2766, '2009-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19189, '2019-02-20 00:20:57.497703+00', '2019-02-20 10:49:06.409655+00', 'Anniversary Jig, An', 'ANNIVERSARY JIG', 2, 32, NULL, 1, 3, 42, 10902, NULL, '', 56, '844/888/800/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7033, '1997-09-17 22:00:00+00', '2018-10-07 14:43:52.283381+00', 'Welcome To The 51st.', 'WELCOME TO THE 51ST', 1, 128, 9999, 2, 3, 3, 1355, NULL, 'The dance represents the 51st Club''s programme at the time - three weeks of classes and a monthly social evening.  Lorraine (now Mrs. Scott) has devised several other delightful dances for the Club.', 91, '484/888/888/888//484/888/888/888//484/888/888/888//888/888/282/888/', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18878, '2018-10-08 17:57:20.703272+00', '2018-10-08 17:57:20.703272+00', 'Silver Earrings', 'SILVER EARRINGS', 2, 32, NULL, 1, 4, 2, 2766, '2009-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1656, '1998-04-08 22:00:00+00', '2018-10-08 17:04:35.394127+00', 'Dignity and Grace', 'DIGNITY AND GRACE', 3, 32, 9999, 2, 3, 17, 108, '1994-01-01', 'In memory of Illeana Goldberg of Woodmere, New York', 73, '880/880/808/868', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18879, '2018-10-08 18:06:55.111852+00', '2018-10-08 18:06:55.111852+00', 'Silver on the Tree', 'SILVER ON THE TREE', 2, 32, NULL, 1, 3, NULL, 2766, '2014-11-01', 'Honoring a favorite fantasy series by Susan Cooper.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18584, '2018-09-12 20:04:10.565835+00', '2018-10-07 07:00:10.569521+00', 'Pickle in the Middle', 'PICKLE IN THE MIDDLE', 3, 64, NULL, 105, 111, 3, 2766, '2010-10-01', 'This dance was written as an attempt to fill a need for a demo where there are many more women available than men.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10254, '2001-11-25 23:00:00+00', '2018-10-07 07:08:47.818115+00', 'Pinball Wizard', 'PINBALL WIZARD', 1, 32, 9999, 1, 3, 42, 2766, '2001-04-01', 'The figure in bars 1-16 reminds me of the physics of the ball bouncing around in pinball; thus the name of the dance.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11504, '2003-09-22 22:00:00+00', '2018-10-07 07:11:23.474011+00', 'Playful Progression', 'PLAYFUL PROGRESSION', 1, 32, 9999, 1, 3, 42, 2766, '2001-11-01', 'Martin Sheffield on the Strathspey list server mentioned he liked set and cast into ½ rights and lefts and I misunderstood and thought he said set and rotate into ½ rights and lefts, so I started playing with the figure. This and two other dances written around the same time are the result.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12481, '2005-07-24 22:00:00+00', '2018-10-07 07:12:54.410264+00', 'Plea to Chac', 'PLEA TO CHAC', 1, 32, 9999, 1, 3, 42, 2766, '2005-06-01', 'This dance was written as my rain dance in a time of moderately severe drought. Chac is the Mayan rain god.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9486, '2000-09-04 22:00:00+00', '2018-10-07 07:41:39.091969+00', 'Pluto''s Head', 'PLUTOS HEAD', 1, 32, 9999, 1, 2, 76, 2766, '1999-09-01', '“The name for this dance came from a trip to Disneyquest where I attended the Animation Station and learned to draw Pluto''s head: draw circles for the basic outline, add meridian lines for reference, and then fill in the details. It seemed to match the structure of this dance.“', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11462, '2003-09-22 22:00:00+00', '2018-10-07 08:21:44.501805+00', 'Polychrome''s Rainbow', 'POLYCHROMES RAINBOW', 3, 32, 9999, 1, 3, 42, 2766, '2002-04-01', 'Polychrome is a daughter of the rainbow who likes to dance on, and sometimes off, the rainbow. She is always getting stranded on the earth for a while until a rainbow appears. She is featured in several Oz books.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18856, '2018-10-07 08:26:23.741653+00', '2018-10-07 08:26:23.741653+00', 'Portage High Bridge, The', 'PORTAGE HIGH BRIDGE', 2, 32, NULL, 1, 3, 42, 2766, '2005-08-01', 'The Portage High Railroad Bridge towers 234 feet over the upper falls of Letchworth State Park, New York.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18857, '2018-10-07 08:29:38.851645+00', '2018-10-07 08:29:38.851645+00', 'Puffin'' Billy', 'PUFFIN BILLY', 1, 32, NULL, 1, 4, NULL, 2766, '2010-11-01', 'This dance is named for the signature tune for the television show Capt''n Kangaroo, which was popular when I was young. An insurance company started using it in a commercial and its familiarity drove me nuts until I figured out from where I knew the tune.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18583, '2018-09-12 19:59:27.163397+00', '2018-10-07 09:28:41.687361+00', 'Quilter''s Quest, The', 'QUILTERS QUEST', 4, 32, 1, 1, 3, 42, 2766, '2014-03-01', 'This dance is for Susan Jensen to celebrate a very special birthday this March. Susan is a very creative quilter; she designs her own quilt patterns and makes up the quilts. She likes the set and link figure, but it confounds her at times.', 62, '888/888/088/844', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18861, '2018-10-07 10:11:12.217266+00', '2018-10-07 10:11:12.217266+00', 'Raccoon Babies', 'RACCOON BABIES', 1, 32, NULL, 1, 3, 42, 2766, '2015-08-01', 'We have baby raccoons in the yard every year and one year I watched them trying to climb a tree; they would climb a foot or two then fall off. Eventually they figured out how to make it to the nesting hole much higher in the tree.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18869, '2018-10-07 11:38:39.407773+00', '2018-10-07 11:38:39.407773+00', 'Rocky River Ice', 'ROCKY RIVER ICE', 1, 32, NULL, 1, 3, 42, 2766, '2014-02-01', 'In February 2014 national TV showed ice breaking up and moving rapidly down the Rocky River in Ohio – near where I grew up.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18873, '2018-10-07 12:10:04.838824+00', '2018-10-07 12:10:04.838824+00', 'Rush Hour Train', 'RUSH HOUR TRAIN', 1, 32, NULL, 1, 3, 42, 2766, '2008-10-01', 'This dance was written after a trip to New York and taking the commuter trains to dance with the SCD group in Fanwood, NJ.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12385, '2005-04-28 22:00:00+00', '2018-10-07 12:24:56.465705+00', 'Sands of Time, The', 'SANDS OF TIME', 1, 32, 9999, 3, 5, 41, 2766, '2004-12-01', 'This dance uses the swirl figure from Doug Jensen’s dance Swirling Five, but in a longways set.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12386, '2005-04-28 22:00:00+00', '2018-10-07 12:26:36.917178+00', 'Sassy Cat', 'SASSY CAT', 1, 32, 9999, 1, 4, NULL, 2766, '2005-02-01', 'This dance is named for my cat, Sassafras - Sassy, because she has definitely decided to live her life on her terms, following no one’s rules but her own.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5013, '1998-07-09 22:00:00+00', '2021-05-01 10:25:36.297003+00', 'O Wha''s at The Window', 'O WHAS AT THE WINDOW', 2, 40, 9999, 3, 5, 7, 270, NULL, '10-bar phrases. The tune is a popular alternative for <<ddd:The Wee Cooper o'' Fife>>.', 74, '10,10,10,10,10/10,0,10,0,0/10,10,10,10,10/10,2,10,4,2', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13822, '2011-08-04 22:00:00+00', '2020-08-23 10:06:06.662006+00', 'Physicist''s Folly, The', 'PHYSICISTS FOLLY', 3, 128, NULL, 4, 4, 3, 2766, '2009-10-28', 'UPDATE 9 November 2009: Wording for bars 9-16 and 73-80 slightly tweaked', 73, '80  80  88  80    08  08  88  08    55  55  88  88    66  88  66  88', 0, 1, 0, 0, 73);
INSERT INTO 'dance' VALUES (18876, '2018-10-08 15:18:25.27753+00', '2018-10-08 15:18:25.27753+00', 'Shawshank', 'SHAWSHANK', 3, 32, NULL, 4, 4, 1, 2766, '2014-08-01', 'My sister is affiliated with the Mansfield Reformatory Preservation Society, which is where the movie The Shawshank Redemption was filmed. She asked me to replicate the cross stitch that was hung over the safe in the warden’s room, which I did – then I wrote this dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18877, '2018-10-08 15:24:45.609523+00', '2018-10-08 15:24:45.609523+00', 'She''s No'' a Gentleman', 'SHES NO A GENTLEMAN', 3, 32, NULL, 1, 100, 2, 2766, '2014-01-01', 'I had a request for a 3-couple targe, but ended up with this – a 4-couple targe.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13204, '2006-12-11 23:00:00+00', '2018-10-08 18:26:33.284995+00', 'Snakes and Ladders', 'SNAKES AND LADDERS', 1, 32, 9999, 8, 105, 32, 2766, '2005-08-01', 'I was challenged to write a dance with an interlocking snake pass figure. I haven’t figured that out yet, but I did come up with this variation of the snake pass.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18887, '2018-10-08 18:31:37.020693+00', '2018-10-08 18:31:54.081746+00', 'Soldier''s Bed, The', 'SOLDIERS BED', 2, 32, NULL, 1, 4, 2, 2766, '2012-08-01', 'This dance reminds me of the cat''s cradle figure called the soldier''s bed.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15326, '2013-12-22 23:33:26.063395+00', '2018-10-08 20:09:47.807545+00', 'Aas Yooou Wiiissshhh', 'AAS YOOOU WIIISSSHHH', 3, 32, NULL, 1, 3, 42, 10593, '2012-12-01', 'The dance was originally published as "As You Wish, PBC", the suffix being added to avoid to avoid confusion with the Bob McMurtry dance.  It has now been renamed to "Aas Yooou Wiiissshhh" for the same reason, but the old name is still evident in many places.', 62, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (29, '2002-02-21 23:00:00+00', '2018-10-08 20:34:11.639373+00', 'Across the Brandywine', 'ACROSS THE BRANDYWINE', 2, 32, 9999, 5, 56, 4, 44, '1972-01-01', 'The Brandywine is a river in “Lord of the Rings”.', 92, '888  888  484  888', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (18888, '2018-10-08 21:35:07.634494+00', '2018-10-08 21:35:07.634494+00', 'Solid As the Granite Hills of Vermont', 'SOLID AS THE GRANITE HILLS OF VERMONT', 2, 32, NULL, 1, 3, 42, 2766, '2012-02-01', 'This dance was written for my Uncle Jimmy who died of cancer at the age of 81 in Vermont, where he lived for most of his adult life.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18889, '2018-10-08 21:37:06.842378+00', '2018-10-08 21:37:06.842378+00', 'Someone in a Tree', 'SOMEONE IN A TREE', 3, 32, NULL, 1, 3, NULL, 2766, '2013-04-01', 'In 1976 I saw Pacific Overtures on Broadway and loved it. This dance is named for one the songs in the musical.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18895, '2018-10-08 21:52:02.482098+00', '2018-10-08 21:52:02.482098+00', 'Square Chaos', 'SQUARE CHAOS', 2, 32, NULL, 4, 4, 1, 2766, '2013-10-01', 'I like to play with mixing people up and trying to restore order to the pattern by the end of 32 bars.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18896, '2018-10-09 05:46:39.323818+00', '2018-10-09 05:47:13.046965+00', 'Square Day', 'SQUARE DAY', 1, 32, NULL, 4, 4, 13, 2766, '2009-03-01', 'March 3, 2009 was known as a square day because 3 times 3 (3 squared) is 9 and this dance was written on that day.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18899, '2018-10-09 06:02:12.248031+00', '2018-10-09 06:02:12.248031+00', 'St Louis Canyon', 'SAINT LOUIS CANYON', 2, 32, NULL, 1, 3, NULL, 2766, '2015-10-01', 'On a trip to Starved Rock State Park we hiked to St Louis Canyon.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18900, '2018-10-09 06:05:03.041317+00', '2018-10-09 06:05:03.041317+00', 'Reel for the Strathspey 10th, A', 'REEL FOR THE STRATHSPEY 10TH', 1, 32, NULL, 4, 5, 21, 2766, '2003-02-01', 'This dance should be danced to a lively five-times through reel. Hoedown Reel Set from The Music Makars works well.  



The dance was created for the tenth anniversary of the Strathspey mailing list and server. In honor of the celebration, it is written with 10 people (5 couples) dancing.  



Some notes on the dance: bars 9-24 are essentially Mairi’s Wedding reels for the fifth couple and regular reels of 4 for the other dancers. The dance was originally written to pass left shoulders in these reels as it seemed dancers would not have time to pass right shoulders; however my local group proved (and preferred) otherwise.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18901, '2018-10-09 06:09:06.087848+00', '2018-10-09 06:09:06.087848+00', 'Sudoku', 'SUDOKU', 2, 32, NULL, 105, 111, NULL, 2766, '2014-10-01', 'Our demo team often has many more women than men available and this dance addresses that.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18902, '2018-10-09 06:11:20.680999+00', '2018-10-09 06:11:20.680999+00', 'Sue''s Fantasy', 'SUES FANTASY', 3, 32, NULL, 1, 3, 42, 2766, '2008-07-01', 'This dance was conceived while dancing a different dance in class and danced later that same night.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18903, '2018-10-09 06:37:12.193378+00', '2018-10-09 06:37:12.193378+00', 'Sweet Ember', 'SWEET EMBER', 3, 32, NULL, 1, 4, 2, 2766, '2011-07-01', 'I adopted Ember as an adult stray from a shelter that brought cats to a cat show. As I walked by the cage where she was being held, she reached through the bars and kept pawing at me, so I had to have her taken out of the cage so I could hold her. Her name was given as Alice, but she was a black and red tortieshell and I thought she looked like embers in a fire. She had a very sweet mellow temperament.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18906, '2018-10-09 06:47:10.766324+00', '2018-10-09 06:47:10.766324+00', 'Taste of the Past, A', 'TASTE OF THE PAST', 1, 32, NULL, 1, 3, NULL, 2766, '2008-07-01', 'This dance was inspired by a thread on the Strathspey server about differences in ways of dancing down the outside and back at different periods of dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13174, '2006-12-11 23:00:00+00', '2018-10-09 06:48:33.18459+00', 'Teaching Dance #1', 'TEACHING DANCE 1', 1, 32, 9999, 1, 4, 1, 2766, '2006-06-01', 'This dance is one of four that were written for a teaching session at the Chicago Highland Games. Since the people who participate in this are usually totally unfamiliar with Scottish Country Dancing, I needed simple dances with easy figures and an easy progression.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13175, '2006-12-11 23:00:00+00', '2018-10-09 06:49:52.347335+00', 'Teaching Dance #2', 'TEACHING DANCE 2', 2, 32, 9999, 1, 4, 1, 2766, '2006-06-01', 'This dance is one of four that were written for a teaching session at the Chicago Highland Games. Since the people who participate in this are usually totally unfamiliar with Scottish Country Dancing, I needed simple dances with easy figures and an easy progression.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18907, '2018-10-09 10:19:13.230264+00', '2018-10-09 10:19:13.230264+00', 'Bug Who Came to Dance, The', 'BUG WHO CAME TO DANCE', 1, 32, NULL, 1, 3, NULL, 2766, '2016-05-01', 'At our AGM/Spring Dance, we found a beautiful moth wandering around the floor, managed to capture it and release it outside.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18908, '2018-10-09 10:22:21.434607+00', '2018-10-09 10:26:43.869766+00', 'Gardener''s Bane, The', 'GARDENERS BANE', 2, 32, NULL, 1, 3, 42, 2766, '2016-06-01', 'We have spent hours fighting the ‘evil weed’ (non-variegated Bishop’s weed) that showed up in a pile of wood chips we got and quickly took over our yard.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18898, '2018-10-09 06:00:08.811699+00', '2020-05-08 17:17:22.741083+00', 'Stephanie''s Big Day', 'STEPHANIES BIG DAY', 3, 32, NULL, 1, 4, 2, 2766, '2015-05-01', 'This dance is written to honor Stephanie McDaniel and Greg Canfield on their wedding day August 23, 2015.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9286, '2002-02-12 23:00:00+00', '2021-02-26 13:59:07.291024+00', 'Abbot of Unreason, The', 'ABBOT OF UNREASON', 2, 32, 9999, 1, 3, 42, 501, '1982-01-01', 'At the end of the 15th and beginning of the 16th centuries, the Abbot of Unreason was master of the Christmas Revels at the court of Scotland. (source: the published description)



The name of the dance is written with two ''t'' in the table of contents of the book, which might have led to misspellings elsewhere (e.g. recordings).', 56, '800  844  888  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (18909, '2018-10-09 10:35:42.248595+00', '2021-03-02 12:14:45.169244+00', 'Northern Isles, The', 'NORTHERN ISLES', 1, 32, NULL, 1, 3, 42, 2766, '2016-09-01', 'The title of this dance refers to the Shetland and Orkney Islands at the NE edge of Scotland.', 47, '422/488/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18913, '2018-10-09 10:49:19.364917+00', '2018-10-09 10:49:19.364917+00', 'Three Little Bandits', 'THREE LITTLE BANDITS', 1, 32, NULL, 1, 3, 42, 2766, '2014-08-01', 'I was inspired after watching 3 baby raccoons in the back yard attempting to climb a tree, getting about 2 feet up, and falling off – over and over again.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18914, '2018-10-09 11:49:04.436866+00', '2018-10-09 11:49:04.436866+00', 'Through the Looking Glass', 'THROUGH THE LOOKING GLASS', 1, 32, NULL, 2, 3, NULL, 2766, '2016-06-01', 'This dance was inspired by Lewis Carroll’s Alice Through the Looking Glass.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18915, '2018-10-09 12:07:16.077113+00', '2018-10-09 12:07:16.077113+00', 'Timing Is Everything', 'TIMING IS EVERYTHING', 1, 32, NULL, 1, 3, 42, 2766, '2016-08-01', 'This dance was written as an exercise in timing/phrasing.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18568, '2018-09-09 21:18:48.988635+00', '2018-10-09 12:08:21.176032+00', 'Tiny Dancer', 'TINY DANCER', 2, 32, NULL, 1, 3, 42, 2766, '2011-08-01', 'I watched a show about 3 sets of kittens from birth to adoption. One of the litters of kittens was Abyssinian and the smallest kitten was named Tiny Dancer. She had it rough starting out as she couldn’t get to Mama for milk and had to be hand-fed, but she survived and turned out to be the most fearless and curious of the litter.', 52, '800/684/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18916, '2018-10-09 12:10:19.008151+00', '2018-10-09 12:10:19.008151+00', 'Tiny Spaces', 'TINY SPACES', 1, 32, NULL, 1, 3, 42, 2766, '2008-08-01', 'The title refers to the size of the auditorium stage we dance on in the summer.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18917, '2018-10-09 12:14:22.444633+00', '2018-10-09 12:14:22.444633+00', 'Toasty Tootsies', 'TOASTY TOOTSIES', 2, 32, NULL, 1, 3, 42, 2766, '2015-10-01', 'My cat, Christopher, sleeps on my wool bed socks when I leave them on the bad; they are then nice and warm when I put them on.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10238, '2001-11-25 23:00:00+00', '2018-10-09 12:18:42.792473+00', 'Tom Senior Reel, The', 'TOM SENIOR REEL', 1, 32, 9999, 1, 4, NULL, 2766, '2000-08-01', 'Tom Senior asked me to write a dance with mirror reels of four as he knows of no dance with such a figure. When my local class danced this we realized that how the first couple crosses in bars 29-30 depends on how actively they set to and turn their second corners; thus, I have removed any designation there to allow people to pass whichever shoulder "works."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12409, '2005-05-01 22:00:00+00', '2018-10-09 12:25:55.995312+00', 'Tournée Squared, The', 'TOURNEE SQUARED', 3, 32, 9999, 4, 4, 13, 2766, '2004-10-01', 'This dance happened when it occurred to me that a square set allows for getting into the tournée position with no turns.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18921, '2018-10-09 12:33:51.169075+00', '2018-10-09 12:33:51.169075+00', 'Transit of Venus, The', 'TRANSIT OF VENUS', 1, 32, NULL, 1, 3, 42, 2766, '2012-06-01', 'I wrote this dance shortly after a transit of Venus occurred; we watched it from outside the barn at Fermilab where we dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11439, '2003-09-22 22:00:00+00', '2018-10-09 13:21:08.66485+00', 'Truth Pond, The', 'TRUTH POND', 2, 32, 9999, 1, 3, 18, 2766, '2003-05-01', 'This dance takes its name from the Truth Pond in the book The Lost Princess of OZ, where the Frogman bathes and forever after must tell the truth.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18922, '2018-10-09 13:29:57.912141+00', '2018-10-09 13:29:57.912141+00', 'Tumbleweed', 'TUMBLEWEED', 3, 64, NULL, 1, 4, 22, 2766, '2011-04-01', 'This dance might work as a reel also to The Shetland Fiddler from Campbell''s Birl or as a medley 2X strathspey/2X reel.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18924, '2018-10-09 13:36:12.821658+00', '2018-10-09 13:36:12.821658+00', 'Turn About Is Fair Play', 'TURN ABOUT IS FAIR PLAY', 3, 32, NULL, 2, 3, 46, 2766, '2015-03-01', 'I was intrigued by the idea of swapping ends of the set each time through a dance and wrote several dances to try it out. This is the strathspey.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18925, '2018-10-09 13:37:56.322696+00', '2018-10-09 13:38:13.497106+00', 'Turning Tide, The', 'TURNING TIDE', 1, 32, NULL, 1, 3, 42, 2766, '2015-09-01', 'This dance was written to illustrate timing for various turns and some basic figures for new dancers.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12415, '2005-05-01 22:00:00+00', '2018-10-09 13:46:03.227153+00', 'Twiddly Bits', 'TWIDDLY BITS', 1, 32, 9999, 1, 3, 42, 2766, '2004-11-01', 'I wrote this dance for Mady Newfield, who really likes dances with twirls and turns and tight timing. I liked the idea of the figure in the first 16 bars; first couple should add loops to get into appropriate position at the ends of bars 8 and 16.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13185, '2006-12-11 23:00:00+00', '2018-10-10 04:01:46.050593+00', 'Three''s Company', 'THREES COMPANY', 1, 32, 9999, 6, 53, 18, 2766, '2006-10-01', 'On rare occasions we start with very few people. This dance was written to accommodate that circumstance.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18968, '2018-10-15 14:18:24.393665+00', '2018-10-15 14:24:17.691271+00', 'Glenmoriston Ceilidh Special', 'GLENMORISTON CEILIDH SPECIAL', 2, 40, NULL, 1, 4, 1, 9998, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18910, '2018-10-09 10:38:49.432483+00', '2018-12-17 15:47:45.788094+00', 'Pirate Queen, The', 'PIRATE QUEEN', 6, 32, NULL, 1, 3, 42, 2766, '2016-02-01', 'Grace O’Malley was an Irish contemporary of Elizabeth I and an independent woman known as the Pirate Queen.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18911, '2018-10-09 10:40:56.109385+00', '2018-11-09 10:52:58.151456+00', 'There and Back Again', 'THERE AND BACK AGAIN', 2, 32, NULL, 1, 3, 42, 2766, '2014-12-01', 'Written for a geek night celebrating the release of the hobbit movie.', 53, '840/880/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9496, '2000-09-04 22:00:00+00', '2019-06-30 04:16:22.886053+00', 'Two for One', 'TWO FOR ONE', 4, 32, 1, 3, 5, NULL, 2767, '2000-04-01', 'This dance was written for a class to illustrate the differences in phrasing when dancing the same figures in strathspey and reel time. It is an astonishingly difficult dance in parts, given the simple figures from which it is constructed. It may be danced as a three-couple set dance, or with five couples and regular double progression, or contra-style.', 30, '88000/80000/80800/80000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12794, '2006-06-25 22:00:00+00', '2018-10-09 14:06:55.662752+00', 'Eileen Watt''s Strathspey', 'EILEEN WATTS STRATHSPEY', 3, 32, 9999, 2, 3, 18, 99, '2005-01-01', 'Eileen Watt was on the staff at RSCDS headquarters for 17 years, and retired in 2005. She was beloved by those who knew her.  She had the added distinction of then being the only member of staff who danced! ', 83, '888  844  844  888', 0, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (18928, '2018-10-09 14:15:53.408347+00', '2018-10-09 14:15:53.408347+00', 'Unintended Consequences', 'UNINTENDED CONSEQUENCES', 3, 32, NULL, 1, 3, 42, 2766, '2015-09-01', 'I wanted to play with a tournée for 3 couples, but couldn’t work it out and ended up with this dance instead.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18929, '2018-10-09 14:23:05.845687+00', '2018-10-09 14:23:05.845687+00', 'Velcro Kitty', 'VELCRO KITTY', 3, 32, NULL, 1, 3, 42, 2766, '2016-05-01', 'Sebastian doesn’t like to move and will hang on even vertically to avoid being moved from a lap.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9567, '2000-09-05 22:00:00+00', '2018-10-09 14:28:30.738617+00', 'Waterfall Glen', 'WATERFALL GLEN', 1, 32, 9999, 1, 3, 42, 2766, '2000-06-01', 'The figure in the first 12 bars reminds me of a waterfall; thus the name of the dance. Some members of my group like to set during the 2-bar phrases they are not active during the first 12 bars of the dance.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11489, '2003-09-22 22:00:00+00', '2018-10-09 14:46:07.182306+00', 'Wedding Vows', 'WEDDING VOWS', 3, 32, 9999, 4, 4, NULL, 2766, '2002-08-01', 'I attended the wedding of a friend’s cousin and this dance occurred to me as I watched the ceremony.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18930, '2018-10-09 14:39:48.654553+00', '2020-05-05 09:46:53.428083+00', 'Weak Link, The', 'WEAK LINK', 3, 32, NULL, 1, 3, 42, 2766, '2009-02-01', 'This dance is written for Susan Jensen, who while learning to dance a dance with a reverse set and link for 3 couples declared she was the "weak link" in the set (she was not).', 59, '840/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12498, '2005-07-30 22:00:00+00', '2018-10-09 14:48:43.414484+00', 'Wee Cottages, The', 'WEE COTTAGES', 3, 32, 9999, 1, 100, 2, 2766, '2005-05-01', 'When we visited Scotland four years ago, we stayed in at a home in Digg on Skye. Our hostess referred to the Skye Museum of Island Life at the northern tip of Skye as "the wee cottages."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18932, '2018-10-09 15:26:21.562065+00', '2018-10-09 15:26:21.562065+00', 'When Giants Fell', 'WHEN GIANTS FELL', 3, 32, NULL, 1, 3, 42, 2766, '2014-08-01', 'This dance was written after hearing of the deaths of John Drewry and Robin Williams.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13172, '2006-12-11 23:00:00+00', '2018-10-09 15:28:17.380025+00', 'Where the Buffalo Roam', 'WHERE THE BUFFALO ROAM', 3, 32, 9999, 1, 2, NULL, 2766, '2006-06-01', 'The class in which I dance meets at Fermilab, where they have a large herd of buffalo; each spring there are buffalo calves to watch.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18933, '2018-10-09 15:30:57.903788+00', '2018-10-09 15:30:57.903788+00', 'Where''s the Knife?', 'WHERES THE KNIFE', 1, 32, NULL, 1, 3, 42, 2766, '2013-12-01', 'Every Christmas my family opens gifts one at a time and several of us use a lot of tape in wrapping. My Dad has a penknife that gets passed around and people lose track of where it is frequently. This phrase is heard often Christmas Day.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18934, '2018-10-09 15:39:29.597855+00', '2018-10-09 15:39:29.597855+00', 'White Pearl Speaks, The', 'WHITE PEARL SPEAKS', 2, 32, NULL, 1, 3, 42, 2766, '2015-08-01', 'In Rinkitink in OZ there are 3 pearls: pink for protection, blue for strength, and white for guidance and wisdom (it speaks and answers questions).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18935, '2018-10-09 15:43:01.086722+00', '2018-10-09 15:43:01.086722+00', 'Why Not?', 'WHY NOT', 2, 32, NULL, 1, 3, 42, 2766, '2013-11-01', 'One night we danced 2 dances with rights and lefts for 3 couples and I realized how much I like the figure and thought why not write a dance with rights and lefts for 3 couples?', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18936, '2018-10-09 15:46:16.796214+00', '2018-10-09 15:46:16.796214+00', 'Wings O''er the Atlantic', 'WINGS OER THE ATLANTIC', 1, 32, NULL, 1, 3, 42, 2766, '2007-01-01', 'This dance is written for Jenny Lee, who is leaving Fermi for an internship at CERN.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11488, '2003-09-22 22:00:00+00', '2018-10-09 16:20:38.39406+00', 'Floating Chicken Coop, The', 'FLOATING CHICKEN COOP', 3, 32, 9999, 1, 3, 42, 2766, '2002-08-01', 'The book *Ozma of OZ* begins with Dorothy washed overboard from a sailing ship to Australia in a chicken coop where she meets Billina - a talking chicken - that ends up on a beach just outside the land of OZ.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12478, '2005-07-24 22:00:00+00', '2018-10-09 16:56:13.281402+00', 'Scraps'' Jig', 'SCRAPS JIG', 2, 32, 9999, 1, 3, 42, 2766, '2005-06-01', 'Scraps is the Patchwork Girl in the OZ books. She’s lively with a sense of mischief.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16860, '2016-02-02 22:34:22.770377+00', '2018-10-09 23:39:14.113161+00', 'Stafford 45th Anniversary Jig', 'STAFFORD 45TH ANNIVERSARY JIG', 2, 32, NULL, 1, 4, 1, 10998, '2001-01-01', 'The dance is described as 3C/4L, but in the description 3c+4c step up at the end, and so that the dance has the progression 2341 and is danced 4 times through.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18710, '2018-10-03 01:09:12.083106+00', '2020-05-01 17:14:31.997712+00', 'After Only 5 Minutes', 'AFTER ONLY 5 MINUTES', 2, 32, NULL, 1, 3, 42, 2766, '2016-10-01', 'Every night within 5 minutes of my going to bed my cat, Christopher, jumps up and lays down on my left arm and stays there most of the night.', 44, '840/880/480/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18950, '2018-10-12 17:31:24.317969+00', '2020-11-22 14:22:14.624487+00', 'Lady Aberdeen', 'LADY ABERDEEN', 1, 32, NULL, 1, 3, 42, 993, NULL, 'Each november the RSCDS Vancouver Branch holds a Lady Aberdeen Tea Dance.

', 50, '880/888/840/840', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18940, '2018-10-09 22:04:29.339272+00', '2020-05-30 23:44:50.17319+00', 'Any Good Tune', 'ANY GOOD TUNE', 1, 32, NULL, 1, 3, 42, 2766, '2016-12-01', 'I write dances then come up with music to determine what the dance is: reel, jig, or strathspey. Usually I know whether it is strathspey or quicktime, but often have to dance it in my head to music to find an appropriate tune and whether it is a reel or jig. This one dances to most reels and jigs; thus the name.', 53, '811/855/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9489, '2000-09-04 22:00:00+00', '2020-08-25 07:45:59.057786+00', 'Gie it a Whirl, Mady!', 'GIE IT A WHIRL MADY', 1, 32, 9999, 1, 3, 42, 2766, '1999-11-01', 'Our group dances this dance to an edited version of track 6 of The Jura Ceilidh Band CD (the tunes are Miss Thompson''s, Cairngorm Brooch, and John McNeil''s).  



Note that the figure in bars 27-32 is normal double triangles for 1C and double triangles combined with half rights and lefts for 2C & 3C.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18966, '2018-10-13 22:32:08.674123+00', '2020-11-22 18:50:27.642538+00', 'Barbara White''s Diamond Strathspey', 'BARBARA WHITES DIAMOND STRATHSPEY', 3, 32, NULL, 2, 3, 17, 3143, '2009-01-01', 'Found on the RSCDS Cheshire website, 2018-10-14



This dance was presented to Barbara White at the 25th Anniversary Ball of RSCDS Cheshire Branch on 10th January 2009. Its purpose is to honour Barbara and thank her for her service to the RSCDS and to the Cheshire Branch. She is a founder member of the Cheshire Branch and has been an RSCDS member for over sixty years.', 54, '800/844/844/804', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13648, '2011-03-09 23:00:00+00', '2021-01-01 18:45:25.652067+00', 'Round and Roundabout', 'ROUND AND ROUNDABOUT', 3, 32, NULL, 2, 3, 18, 10293, '2010-01-01', 'This dance is dedicated to Beatrix "Bexi" Wepner to celebrate her birthday in November 2010. The title, in either English or Austrian, fits a number of formations in the dance.



Note: The ''circulating knot'' was introduced independently by Sue McKinnell (in the USA) and Heiko Schmidt (in Austria) at the same time.

', 83, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18939, '2018-10-09 21:55:49.010509+00', '2021-06-06 11:24:21.433161+00', 'Baby C-McD', 'BABY CMACD', 1, 32, NULL, 1, 2, 76, 2766, '2016-04-01', 'At a baby shower we were decorating onsies for the new baby. I am not very artistic, so I created a dance using Pillings symbols I could remember and draw.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15706, '2014-11-19 11:25:30.433294+00', '2018-10-14 00:04:35.653945+00', 'Dance for Susi, A', 'DANCE FOR SUSI', 3, 32, NULL, 2, 3, 18, 635, '2001-01-01', 'Note: The Rose Progression was devised by Rod Downey of New Zealand;

As the men dance in to turn halfway, they pass the women who are casting by the right 

', 67, '880/808/808/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15032, '2013-08-02 16:11:57.823592+00', '2018-10-14 00:10:37.549549+00', 'Selkirk Settlement, The', 'SELKIRK SETTLEMENT', 1, 32, NULL, 1, 2, NULL, 10814, '2012-01-01', 'Devised by Christine M. Wallace of the RSCDS Winnipeg in honour of the Bicentennial in 2012 of the Selkirk Settlers.', 52, '88/80/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16534, '2015-07-31 14:25:36.181695+00', '2018-10-14 06:38:37.480589+00', 'Library of Birmingham, The', 'LIBRARY OF BIRMINGHAM', 3, 40, 9999, 1, 4, 11, 1275, '2013-09-03', 'A new public library for Birmingham, the largest in Europe, was opened by Malala Yousafzai on 3rd September 2013. The Dutch architect, Francine Houben, designed a building whose exterior is extensively covered with black and silver circles.



Note: The rose progresion was devised by Downey, New Zealand, who specifies that the figure should be danced in as round a shape as possible', 100, '8888/8888/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18812, '2018-10-06 04:57:46.309581+00', '2018-10-14 23:17:40.453699+00', 'Lady of the Elves, The', 'LADY OF THE ELVES', 3, 32, NULL, 1, 3, 42, 2766, '2011-06-01', 'This dance is for my fourth cat, Dria. Dria’s full name was Galadriel for the lady of the elves in The Lord of the Rings. She was a plain little brown tabby, but she had emerald green eyes.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11852, '2004-10-31 23:00:00+00', '2018-10-17 11:12:13.556799+00', 'Monarch Butterfly', 'MONARCH BUTTERFLY', 1, 32, 9999, 1, 4, 11, 3441, '1994-01-01', 'The dance was devised after the meeting to choose the 1994 Asilomar Ball dances. Since Pacific Grove is the home of not only Asilomar but also the Monarch butterfly, the name seemed appropriate. The music has that busy motion that reminds one of the motion of butterflies', 72, '8282/2828/4884/8668', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10239, '2001-11-25 23:00:00+00', '2018-10-16 16:40:33.986636+00', 'By Special Request', 'BY SPECIAL REQUEST', 3, 32, 9999, 1, 4, 1, 2766, '2000-09-01', 'I wrote The Tom Senior Reel because Tom wanted a dance with mirror reels of four. When we danced it, he asked if I would write a strathspey with mirror reels of four, so the dancers had time to enjoy the reels.', 70, '8000/8888/8888/4266', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10245, '2001-11-25 23:00:00+00', '2018-10-16 16:42:27.149776+00', 'Friends from Overseas', 'FRIENDS FROM OVERSEAS', 2, 32, 9999, 1, 3, 42, 2766, '2000-12-01', 'This dance was written in honor of Maureen and Andrew Pettigrew, who came over from Scotland and brought much fun and a love of Scottish Country Dancing to the Silk and Thistle class.', 47, '804/840/888/822', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18080, '2017-11-22 09:32:58.377194+00', '2018-10-18 22:10:26.224991+00', 'Keep the Home Fires Burning', 'KEEP THE HOME FIRES BURNING', 3, 32, NULL, 1, 4, 1, 11449, NULL, 'to commemorate so many husbands & wives, like my parents who married in 1939 and then spent half of the first 10 years of their ''married life'' apart as they served during WW2



1 – 8		represent the couple meeting, marrying then separating to go in different directions  

9 – 16 and 17 – 20 she to serve in the Red Cross in Folkstone and he in REME (Royal Electrical & Mechanical Engineers) Highland Division in the North African desert & invasion of Sicily etc.  

Setting facing each other from opposite ends of the set represents their connection over the miles & years while the mayhem of military manouvres goes on in between them  

21 – 24	their reunion with each other  

25 – 32  	& family & friends  

', 59, '8000/8888/8444/8026', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19147, '2019-01-16 23:25:39.121942+00', '2020-07-20 23:23:30.430993+00', 'Autumn Showers', 'AUTUMN SHOWERS', 3, 32, NULL, 2, 3, 17, 11503, NULL, '', 67, '444/808/840/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5044, '1997-04-03 22:00:00+00', '2020-03-09 11:01:40.162394+00', 'Old Chain Pier, The', 'OLD CHAIN PIER', 3, 48, 9999, 1, 4, 1, 270, NULL, '', 65, '8642/8888/8888/8888/4848/8044', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18963, '2018-10-13 21:13:51.656364+00', '2020-08-24 22:38:48.193048+00', 'Waxing of the Moon', 'WAXING OF THE MOON', 3, 32, NULL, 2, 2, 76, 3075, '2014-10-01', 'Devised with Donna MacFarland



The original instructions are unclear.  They say "32S3C", but as only 1st and 2nd couples dance, the instructions probably mean "2C dance in a 3C set".  ', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18944, '2018-10-12 14:09:21.160256+00', '2020-11-22 10:45:18.24373+00', 'Wyn''s Fancy', 'WYNS FANCY', 3, 32, NULL, 1, 4, 1, 884, '2016-01-01', 'A dance for Wyn Caldwell, Western Autralia Branch Teacher, on the occasion of a very special birthday, January 2016', 61, '8400/8680/8888/8004', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14890, '2013-05-22 13:17:28.498842+00', '2018-11-26 00:29:58.738856+00', 'Milliner''s Farewell', 'MILLINERS FAREWELL', 1, 40, NULL, 1, 4, 1, 1049, '2009-01-01', 'Dance devised for the farewell of Jayne and Mike Milliner 

by Anne-Miek Klokgieters, september 2009, The Hague

', 55, '8400  8040  8448  8888  8000', 1, 1, 1, 0, 55);
INSERT INTO 'dance' VALUES (18945, '2018-10-12 14:22:10.345488+00', '2020-11-22 10:49:28.806054+00', 'Lord Lieutenant, The', 'LORD LIEUTENANT', 2, 32, NULL, 1, 3, 42, 11725, '2008-01-01', 'This dance has been written in honour of Dr A R Trickett, Lord Lieutenant of Orkney, on the occasion of Orkney Ceilidh Weekend 2008. Orkney Traditional Dance Association wishes to say “Thank you, Tony, for Opening this special event”.', 38, '844/800/844/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18955, '2018-10-13 19:24:59.257703+00', '2020-11-22 14:27:46.784565+00', 'Ian Cruickshanks of Kirriemuir', 'IAN CRUICKSHANKS OF KIRRIEMUIR', 3, 40, NULL, 1, 4, 1, 10798, '2015-04-24', 'Ian Cruickshank’s 60th birthday on 24 April 2015 at the Atholl Palace Hotel, Pitlochry.', 70, '8040/8888/8888/8242/8066', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18962, '2018-10-13 20:57:52.527497+00', '2020-11-22 18:35:05.220808+00', 'Thither and Yon', 'THITHER AND YON', 1, 40, NULL, 1, 3, 42, 2841, NULL, 'In the past few years Ann and I (Alan Cameron) have travelled widely for our employers, this dance represents the nature of our life, meeting many new people and passing each other by en route to the next destination.', 55, '400/800/12 12 12/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15055, '2013-08-07 15:39:14.88107+00', '2021-03-26 17:13:54.338836+00', 'Agnes Blackadder Fire Alarm, The', 'AGNES BLACKADDER FIRE ALARM', 4, 32, 12, 1, 2, NULL, 10824, '2013-08-01', 'During Summer School 2013 in New Hall, which since a short time ago is called "Agnes Blackadder Hall", at 2 o''clock at night, the fire alarm went off, so all had to go outside. An hour later we could go back to our bedrooms.

 

This inspired me to create this dance, called ''The Agnes Blackadder Fire Alarm'':

The first 8 bars show how all guests rapidly leave the building. The reel-time pousette without hands represents that people are excited and agitated, talking to each other. Then everything slows down, and one wonders if anything will happen. And the Rights and Lefts suggest people are returning to their bedrooms.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18961, '2018-10-13 20:37:51.050452+00', '2021-04-12 17:12:40.44941+00', 'Dancing Diamonds, The', 'DANCING DIAMONDS', 3, 32, NULL, 1, 4, 1, 11699, '3006-06-08', 'Written for and presented to "Two Diamonds", namely Marjorie (Robbie) and Maurice Robinson on the occasion of their Diamond Wedding anniversary.', 72, '8668/8888/8008/8044', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7940, '1997-09-14 22:00:00+00', '2019-03-07 22:07:14.754044+00', 'Seventeenth of February, The', 'SEVENTEENTH OF FEBRUARY', 3, 32, 9999, 1, 4, 2, 1069, NULL, 'Devised in honour of Mrs Connie Grainger on the occasion of her “Special Birthday”

', 88, '8888/8888/8888/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17120, '2016-06-30 21:40:15.555889+00', '2018-11-03 00:11:10.751558+00', 'Wild Mountain Thyme, The', 'WILD MOUNTAIN THYME', 3, 32, NULL, 6, 3, 4, 11283, '2005-09-01', '', 87, '666/666/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6520, '1997-09-15 22:00:00+00', '2018-10-29 14:03:31.076371+00', 'There And Back Again', 'THERE AND BACK AGAIN', 1, 64, 9999, 102, 5, 54, 666, NULL, 'For 10 to 12 year olds.  Danced twice', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19020, '2018-10-19 20:19:07.419472+00', '2018-10-19 20:19:43.460208+00', 'Green Facing, The', 'GREEN FACING', 1, 32, NULL, 1, 4, 1, 11734, NULL, 'Devised for Lt-Col (retired) David Newton - a dancer from Hereford.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19021, '2018-10-19 20:21:58.886735+00', '2018-10-19 20:22:40.528985+00', 'Trip to Leominster, A', 'TRIP TO LEOMINSTER', 2, 48, NULL, 1, 4, NULL, 142, NULL, 'Devised for Andrew''s dear friends Rosa and Bill McKean of Leominster for their many kindnesses and warm hospitality to him over the years.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6141, '1998-04-19 22:00:00+00', '2018-10-19 20:32:37.275024+00', 'Skirrid Strathspey, The', 'SKIRRID STRATHSPEY', 3, 96, 9999, 4, 4, NULL, 181, '1976-01-01', 'Devised for the Abergavenny Scottish Country Dance Club and included in this collection by kind permission of Birmingham RSCDS  

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19027, '2018-10-19 20:52:26.308817+00', '2018-10-19 20:52:26.308817+00', 'Black Mountain Anniversary Jig', 'BLACK MOUNTAIN ANNIVERSARY JIG', 2, 32, NULL, 1, 3, 42, 11738, '2004-01-01', 'Devised to celebrate the 40th Anniversary of The Black Mountain Reel Club', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19029, '2018-10-19 21:19:32.444563+00', '2018-10-19 21:19:32.444563+00', 'Four of Diamonds', 'FOUR OF DIAMONDS', 1, 160, NULL, 107, 54, 3, 11739, NULL, 'A 5 x 32 bar dance for 4 ladies in a diamond formation. Type (R, J, S) not specified in the Hereford 40th Anniversary Book', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19022, '2018-10-19 20:24:26.387891+00', '2018-10-21 00:21:35.011221+00', 'Ewan Telford''s Jig', 'EWAN TELFORDS JIG', 2, 32, NULL, 1, 4, 2, 881, NULL, 'Devised for Ewan Telford who was still dancing at the time of his 80th Birthday in 1993', 88, '8888/8888/8888/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19025, '2018-10-19 20:42:40.92301+00', '2018-10-21 00:25:03.873474+00', 'Birch Strathspey, The', 'BIRCH STRATHSPEY', 3, 32, NULL, 1, 4, 22, 11734, NULL, 'Devised by Flora Inglis when she taught a class in the village of Much Birch.', 69, '0880/4004/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19016, '2018-10-19 15:06:39.507242+00', '2018-10-20 11:12:33.445781+00', 'Shula''s Choice', 'SHULAS CHOICE', 2, 32, NULL, 2, 3, 17, 11736, NULL, 'This dance was devised by MORNA RINTOUL and FRAN SMITH for a group of local Young Farmers.  



They had attended one introductory evening of Scottish Country Dancing and wanted to perform a Scottish Dance in the  Dance Competition at their annual County Rally - 7 Weeks away!!', 42, '880/800/800/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19032, '2018-10-24 19:01:05.068239+00', '2019-03-03 09:37:12.692845+00', 'Asilomar Celebration', 'ASILOMAR CELEBRATION', 2, 32, NULL, 1, 3, 42, 723, '2008-10-01', 'Written for the San Francisco Branch of the Royal Scottish Country Dance Society in celebration of the 50th Anniversary of the first Scottish Dance Workshop at Asilomar.



Available as a leaflet from the deviser.', 56, '880/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2794, '1997-09-03 22:00:00+00', '2018-10-23 23:29:16.617677+00', 'Harlequin', 'HARLEQUIN', 2, 40, 9999, 1, 3, 42, 987, '1988-01-01', 'A 40 bar Jig to celebrate 40 years of Scottish dancing at Harwell.  

Harlequin was the Harwell site magazine at the time.', 65, '888/888/844/484/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9166, '2000-02-25 23:00:00+00', '2018-10-24 16:13:04.094195+00', 'Merrill Gathering, The', 'MERRILL GATHERING', 1, 40, 9999, 2, 3, 18, 2680, '1999-01-01', 'This dance was devised for the 31st annual Asilomar Weekend Workshop of the San Francisco Branch of the RSCDS. It is dedicated to all those who gathered in Merrill Hall on Sunday October 31, 1999, where Fiona taught the dance.', 46, '811  888  840  848  800', 1, 1, 1, 1, 61);
INSERT INTO 'dance' VALUES (19026, '2018-10-19 20:45:20.40922+00', '2018-10-22 04:50:34.322196+00', 'Down House Strathspey, The', 'DOWN HOUSE STRATHSPEY', 3, 32, NULL, 1, 4, 2, 11738, '2005-01-01', 'The Down House is the home of Nigel Carter, long serving teacher of the Black Mountain Reel Club, and his wife Doreen', 88, '8888/8888/8888/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19087, '2018-12-06 17:04:23.093996+00', '2018-12-06 17:58:12.057127+00', 'Little Teddies, The', 'LITTLE TEDDIES', 2, 32, NULL, 1, 4, 2, 3699, NULL, 'Devised to encourage the Primary School Children taught by Jimmy in and around Glasgow', 84, '8448/8888/8228/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18976, '2018-10-17 00:14:22.53029+00', '2020-06-28 10:37:10.224544+00', 'Wakey Wakey', 'WAKEY WAKEY', 1, 32, NULL, 1, 4, 1, 11733, NULL, 'The Minicrib is the ONLY original source for this dance.', 75, '8448/8448/8448/8484', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19054, '2018-11-18 14:05:34.599091+00', '2020-05-24 08:46:39.280647+00', 'Quiltmaker, The', 'QUILTMAKER', 3, 32, NULL, 1, 4, 1, 10714, '2016-03-01', 'Devised for and presented to Marilyn Stocker', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10605, '2002-06-30 22:00:00+00', '2020-09-11 08:38:57.470323+00', 'Bunessan', 'BUNESSAN', 3, 32, 9999, 1, 3, 42, 27, '1997-01-01', 'Bunessan, at the south west corner of Isle of Mull - the Ross of Mull, is on the road to Fionnphort Ferry and the Isle of Iona. 



Suggested tune: The Original, a Gaelic melody - <<ddt:#14289>>.  Mary MacDonald 1817 - c 1890.  The tune is used in the Scottish Hymnary for Hymn no. 53', 59, '844/888/844/866', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18971, '2018-10-15 16:42:23.675203+00', '2020-11-08 12:16:50.35807+00', 'Stuken Rant', 'STUKEN RANT', 2, 32, NULL, 1, 107, 2, 11996, NULL, 'Devised by Stuart Ross and Ken Unsworth.



On second chord dancers move into Glasgow Highlanders'' positions. ', 93, '8888/8448/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19058, '2018-11-27 18:01:58.553777+00', '2018-11-27 19:58:50.054408+00', 'Helen''s Reel', 'HELENS REEL', 1, 32, NULL, 2, 3, 17, 10951, '2012-01-01', 'The deviser recommends dancing this six times through rather than the minimum three times which would be expected from the progression.

', 66, '800/888/800/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17472, '2016-11-06 17:29:47.816543+00', '2021-01-01 20:20:24.251996+00', 'Ross in Bloom', 'ROSS IN BLOOM', 3, 32, NULL, 1, 4, 1, 11416, '2004-09-01', 'To celebrate the Flower Festival held in Ross-on-Wye.  



This dance, devised by MARMIE SMITH was the winning entry in a competition organised by Ross Reel Club  



The story goes:  

  1 -   8	The petals  

  9 - 16	Putting a ribbon round  

17 - 24	The ribbon curling at the ends  

25 - 32	Wrapping the blooms  

  ', 69, '4444/8008/8888/8088', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7125, '1997-04-03 22:00:00+00', '2021-03-30 20:40:17.217697+00', 'Whitecaps', 'WHITECAPS', 2, 32, 9999, 1, 3, 42, 260, '1987-01-01', 'The dance was devised for the 1987 Asilomar Ball. Gloria Devised the dance with the limited space in mind.  Asilomar Ball has always been well attended making for a sometimes crowded dance floor.

', 50, '888  484  440  880', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (18969, '2018-10-15 15:10:09.66211+00', '2018-10-22 14:00:59.301727+00', 'Ross Reel', 'ROSS REEL', 2, 32, NULL, 1, 3, 42, 11732, NULL, 'This dance was devised for the Ross Group when it was revived in the early 1990’s and danced in the Conservative Club in Ross-on-Wye



In the "RSCDS Herefordshire Branch 40th Anniversary Collection of Dances 1967-2007" the dance description has the correct name "Ross Reel", but in the Table of Contents the name is misprinted as "The Ross Reel" (information obtained from RSCDS Herefordshire) . ', 44, '880/800/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18578, '2018-09-11 07:20:38.761021+00', '2018-10-23 14:47:15.127034+00', 'Geburtstag in Wien', 'GEBURTSTAG IN WIEN', 3, 32, 9999, 1, 3, 42, 1534, '2018-05-01', 'Devised by David Hall, May 2018 to celebrate his 50th birthday, using some of his favourite formations.', 83, '888/880/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18287, '2018-04-23 23:26:51.684896+00', '2018-10-25 15:10:01.855317+00', 'Torque Back', 'TORQUE BACK', 2, 32, NULL, 1, 3, 42, 11237, '2017-10-01', 'This dance was originally called Twirlaholics - but someone who very much liked dance, but who very much did not like the original name, persuaded the deviser to change it to Torque Back.

', 53, '800 866 466 888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19042, '2018-10-29 10:03:47.049275+00', '2018-10-29 10:03:47.049275+00', 'Route des Granges', 'ROUTE DES GRANGES', 3, 32, NULL, 4, 4, NULL, 11066, '2005-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17042, '2016-06-19 10:13:23.060545+00', '2018-10-25 15:59:33.484054+00', 'Harwell Caledonian Society', 'HARWELL CALEDONIAN SOCIETY', 4, 128, 2, 4, 4, 28, 987, '1998-01-01', 'This dance was written to celebrate the first 50 years of the Harwell Caledonian Society - still known to the oldies as the AERE Harwell & District Caledonian Society and Reel Club.', 66, '6464/8484/8080/6666', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19045, '2018-10-29 11:00:37.056575+00', '2018-10-29 11:00:37.056575+00', 'Bienvenue à Lyon Branch', 'BIENVENUE A LYON BRANCH', 2, 32, NULL, 1, 2, NULL, 154, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19046, '2018-10-29 11:02:54.140509+00', '2018-10-29 11:02:54.140509+00', 'Danse Lyonnaise', 'DANSE LYONNAISE', 3, 32, NULL, 1, 3, 42, 154, '2009-11-11', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19047, '2018-10-29 11:05:13.700915+00', '2018-10-29 11:05:13.700915+00', 'Come Hither to Bed', 'COME HITHER TO BED', 1, 40, NULL, 1, 4, NULL, 3337, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19031, '2018-10-23 16:12:55.753818+00', '2018-10-31 08:29:12.656951+00', 'Golden Spires', 'GOLDEN SPIRES', 2, 32, NULL, 1, 3, 42, 10760, '2018-01-01', 'Devised for the 50th anniversary of the RSCDS Oxfordshire Branch.', 56, '800/888/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19036, '2018-10-24 19:14:21.21375+00', '2018-10-24 19:14:21.21375+00', 'Monarch of the Grove', 'MONARCH OF THE GROVE', 3, 32, NULL, 1, 3, NULL, 11504, '2016-10-01', 'Ethan Bailey attended his first Asilomar Weekend in 2016. The title came after Ethan and his family then visited the nearby Monarch Butterfly Sanctuary in Pacific Grove. The title is a play on words from the TV show "Monarch of the Glen". The dance was first danced in the Santa Rosa class and at the Santa Rosa Youth Workshop, 2017.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (255, '1998-04-04 22:00:00+00', '2018-10-24 20:49:33.492805+00', 'Asilomar', 'ASILOMAR', 3, 32, 9999, 1, 4, NULL, 389, '1986-01-01', 'Asilomar was devised after attending the Asilomar Weekend in 1986. It was the deviser''s first time there, and his first time seeing an ocean. The ocean inspired him to write the dance which emulates the crashing waves, the tide pools, etc. The dance features a mirror diamond poussette.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12600, '2005-11-01 23:00:00+00', '2018-10-24 20:50:35.330382+00', 'Tides of Asilomar', 'TIDES OF ASILOMAR', 3, 32, 9999, 2, 3, NULL, 2961, NULL, 'Tides of Asilomar was devised especially for and taught by Bob at the 2005 Asilomar Weekend. Dedicated to his friend, Tom Cuthbertson.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12601, '2005-11-01 23:00:00+00', '2018-10-24 20:53:39.991537+00', 'Vexed & Hexed, Halloween', 'VEXED AND HEXED HALLOWEEN', 1, 32, 9999, 1, 3, 42, 2961, NULL, 'Devised for the 2005 Asilomar Weekend workshop, which occurred on Hallowe’en weekend.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8389, '1998-01-05 23:00:00+00', '2018-10-29 01:06:45.161891+00', 'Twin Beacons', 'TWIN BEACONS', 1, 32, 9999, 1, 3, 42, 2015, NULL, 'In Newcastle, NSW, Australia, in the early days of the settlement, one of the most pressing problems was to make the port safe for shipping. One attempt to provide navigational aids was the building (in about 1865) of twin towers in which fires were lit at night. Once these were aligned, theoretically a helmsman had dead reckoning for the harbour channel. But as they were only 68.5 metres apart, in rough seas on a plunging deck, the navigator had major problems in holding his course for the lights. Only one of these beacons now remains and it can be seen at the top of Tyrrell Street.   



Read more at http://www.abc.net.au/local/stories/2012/03/27/3464691.htm', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17047, '2016-06-19 10:40:02.506063+00', '2018-10-25 00:49:10.66998+00', 'Amapola', 'AMAPOLA', 3, 32, NULL, 1, 4, 1, 987, '1997-01-01', 'This dance is dedicated to Sheila and John Findlay to celebrate the club’s summer party in their riverside garden in Wallingford, 1997. Unfortunately, it poured with rain on the chosen evening and we had to retreat to the Harwell Social Club. John and Sheila have since sold their sailing boat “Amapola” and bought a new boat. Dancing in Wallingford in 1998 will demand a new dance!', 72, '8444/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9878, '2001-05-20 22:00:00+00', '2018-10-26 20:37:40.925742+00', 'Our Nancy', 'OUR NANCY', 3, 40, 9999, 1, 4, 1, 2889, NULL, 'This dance is dedicated to Nancy Stephen, with many thanks from all her pupils in East Kilbride and District.



Music by George Stirrat.', 75, '8888/8448/4884/8440/8448', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19048, '2018-10-29 11:53:55.580247+00', '2018-10-29 11:53:55.580247+00', 'Misses Orgeret, The', 'MISSES ORGERET', 2, 32, NULL, 1, 3, 42, 3335, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12054, '2005-02-23 23:00:00+00', '2018-10-27 01:26:01.721121+00', 'Chicago Silver', 'CHICAGO SILVER', 1, 32, 9999, 3, 5, 7, 2766, '2004-06-01', 'This dance is written to honor the 25th anniversary of the Chicago Branch of the RSCDS in the year 2005.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11274, '2003-04-21 22:00:00+00', '2018-10-28 14:51:20.922347+00', 'West Sands', 'WEST SANDS', 1, 32, 9999, 1, 4, 1, 3337, '2000-08-01', 'Contrary to SCD tradition, in this dance the leading couple only look at each other when setting at the beginning and the end (bars 1 and 2, and bars 29-32).', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14721, '2013-03-14 09:34:46.130609+00', '2018-11-12 00:05:22.616241+00', 'Champagne Reel14721 (4/4), The', 'CHAMPAGNE REEL14721 4/4', 1, 32, NULL, 1, 4, NULL, 771, NULL, 'This entry is a duplicate of the 3C/4L dance with the same name and ID 1148.  This 4C/4L variant is, as far as we can see, an error.



Many SCDDB collections list this dance.  Those links need to be transferred to dance 1148 before this entry can be deleted.



Eric. Co-editor', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14925, '2013-05-30 16:55:45.209978+00', '2018-12-22 22:49:30.603991+00', 'Brownian Motion', 'BROWNIAN MOTION', 2, 32, NULL, 101, 112, 56, 1394, NULL, '', 82, '8888888/8888888/0088800/4888884', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19035, '2018-10-24 19:10:06.192588+00', '2021-09-23 20:39:21.405364+00', 'Jezebel''s Jig', 'JEZEBELS JIG', 2, 32, NULL, 1, 3, 42, 2701, '2017-01-01', 'Jezebel R. Cat successfully pounced at the Asilomar Weekend’s silent auction in 2016. Her mum, Jane Maxwell, reports that Jezebel enjoys leaping out from behind furniture and pouncing on one’s ankles, was a retriever in her youth, and always enjoys a good chase. Jane celebrated a significant birthday in 2016. The dance was performed at the Asilomar Weekend''s 2017 Friday night Ceilidh.', 54, '803/803/888/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (887, '1998-11-07 23:00:00+00', '2018-11-24 00:06:36.472475+00', 'Butterscotch and Honey', 'BUTTERSCOTCH AND HONEY', 3, 32, 9999, 1, 4, 1, 13, '1984-01-01', 'In 2003, in response to a query redarding bars 17-24, Mrs. Attwood wrote:



I wrote this dance in 1984 and have had one or two queries like yours over the years.  As the dancers reach the top of the set, 1st couple leading, they cross to their own side, each couple in turn passing his, or her, partner by the left shoulder.  As you say the dancers "interleave", or as I always put it, they "criss-cross".

', 72, '8400/8044/8888/8888', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (15608, '2014-09-03 15:11:49.819659+00', '2019-01-29 00:22:17.748197+00', 'Barr None', 'BARR NONE', 1, 32, NULL, 1, 3, 42, 1375, '2007-01-01', 'In 2007 Sue and Vic Tyler visited the South Ayrshire Village of Barr for its Scarecrow Festival.  The teas in the hall, available at weekends during the summer, come highly recommended.', 47, '680/680/808/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16788, '2015-10-14 15:33:59.830198+00', '2018-10-29 08:10:49.907281+00', 'Bunting Bee, The', 'BUNTING BEE', 3, 32, NULL, 1, 3, 42, 2682, '2014-03-29', 'Notes from The Johnsonville Collection:



Devised 29th March 2014. The dance is a teaching dance for grand chain. The name comes from a tribute to the highly energetic 2013 beginners who organized themselves to have a “bunting bee” to produce tartan bunting for our hosting of the region’s “New Dancers’ Celebration” in late 2013.  



Recommended music is “Callum’s Road” by D. Shaw played ABAB, and a set of suitable tunes can be found for the track “Moranbank”, which is track 9 of the CD “A’ the Best from Banffshire” by Colin Dewar and his Band.  



This dance could also be performed as a reel. In this case I would suggest the tune “Walking on the Moon” by Addie Harper, and an excellent set or reels with this as part is by Bobby Brown and his Band, “Celtic Fire in the Music” CD 1, track 9.

', 50, '800/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19043, '2018-10-29 10:09:07.626384+00', '2018-10-29 23:47:33.736352+00', 'Daedal Di', 'DAEDAL DI', 1, 32, NULL, 1, 3, 42, 11689, NULL, 'This dance was devised for Diana Sarran, a keen (and much appreciated!)  

Scottish country dancer with the Scottish Chanterelle in Lyon (France), for her 60th birthday. On the first eight bars of the dance the first couple draw the 6s and the Os.', 48, '844/822/864/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4081, '1997-04-03 22:00:00+00', '2018-10-31 01:52:55.562957+00', 'Maid of Glen Duror, The', 'MAID OF GLEN DUROR', 3, 40, 9999, 1, 4, NULL, 347, NULL, 'The Maid of Glen Duror is a ghost who has often been seen at Auchindarroch one of the oldest buildings in the district. It is thought that she was a dairymaid employed many years ago by the original Stewart owner of Auchindarroch and during a storm was carried down the glen and into Loch Linnhe together with the sheep ahe was tending.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16796, '2015-10-14 16:01:45.262054+00', '2018-10-31 12:13:16.972134+00', 'Paparangi', 'PAPARANGI', 1, 32, NULL, 1, 3, 42, 2682, NULL, 'Devised 9 April, 2014 following our advanced dancing group of the 8th, where

the previous dance was danced for the first time. Notes as to the origin of

the Borders’ Poussette can be found in the notes for that dance. The Wheelie

Chain is due to John Drewry in the Bankhead Book Vol. 3. Having messed up

teaching “Blaven” from that book on the 8th April, particularly misinterpreting

the instructions for this formation twice, I wrote the above since it seemed

appropriate, and I could not get the formation out of my head. The Tuesday

group dance at the Paparangi School Hall, hence the name. Charlotte Williams

gave the excellent interpretation that the Wheelie Chain is rights and lefts with

second man and first man, third lady and first woman acting in tandem. As per

John Drewry’s instructions the Wheelie Chain should be danced in a round-ish

fashion, rather than on a square.



Recommended tune is “The Man from Skye” by Pipe Major Donald Macleod

played ABAB and my preferred recording is by Muriel Johnstone on “A Skye

Collection,” this being the lead tune for “Broadford Bay.” This not being

available, I suggest a driving real with strong 2 bar p', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14988, '2013-07-24 14:32:05.926836+00', '2018-10-31 12:14:18.142517+00', 'Heathery Breeze', 'HEATHERY BREEZE', 3, 32, NULL, 1, 4, 1, 3309, '2012-04-12', 'Devised by Bob Davidson (piobbeag [at] aol.com) after listening to a tune by the same name performed by Matt Molloy.



Suggested recorded music: "The Double Diamond Strathspey" from the Muriel Johnstone/Keith Smith album, Vintage Goldring.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17728, '2017-05-03 07:58:40.48834+00', '2018-11-01 23:58:40.536404+00', 'Raphaëlle''s Jig', 'RAPHAELLES JIG', 2, 32, 9999, 1, 3, 42, 854, '2017-04-01', 'Devised by Duncan Brown, for Raphaëlle Orgeret, one of his fellow teachers at the RSCDS Spring Fling in Bonn, April 2017  





*Deviser''s note:  The movement in bars 9-16 and 17-24 is a development of bars 25-40 of “The Waggle O’ The Kilt” by JB Cosh.', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11282, '2003-05-04 22:00:00+00', '2018-11-03 18:49:39.073998+00', 'Hanna''s Pride', 'HANNAS PRIDE', 2, 32, 9999, 1, 3, 42, 3342, '1997-01-01', 'For Hanna Quarrie.  Hanna''s Pride is the name of a foal born in Walnut Creek during her stay in the Bay area, and named after her.



Contains the "Quarrie''s Jig" formation, and "Interrupted set to corners and partner", for which there are no codes.', 53, '800  888  888  822', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (5355, '2002-03-03 23:00:00+00', '2018-11-05 15:34:25.796855+00', 'Prince Charlie''s Quickstep', 'PRINCE CHARLIES QUICKSTEP', 2, 48, 9999, 1, 100, 2, 108, '1975-02-02', 'John Drewry slightly revised this dance in 1996. The original version had set and half left hand turn in bars 1-4 (continuing the turn into bar 5) whereas the revised version has petronella followed by half right hand turn.



Video 1 shows another variation.

', 72, '8008/8888/8228/8008/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9683, '2001-10-23 22:00:00+00', '2019-02-21 23:33:45.120509+00', 'Mrs Doreen Kaye', 'MRS DOREEN KAYE', 3, 32, 9999, 2, 3, 17, 2892, NULL, '', 62, '800/866/822/848', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (2671, '1997-09-06 22:00:00+00', '2020-08-05 11:37:37.396617+00', 'Green Well Of Scotland, The', 'GREEN WELL OF SCOTLAND', 3, 48, 9999, 1, 4, 28, 129, '1966-01-01', '', 87, '8800/8888/8686/8668/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9609, '2000-09-05 22:00:00+00', '2020-09-09 08:55:15.32262+00', 'Spreading the Soul of Scotland', 'SPREADING THE SOUL OF SCOTLAND', 3, 32, 9999, 1, 4, 2, 35, NULL, '', 94, '8888  8888  8448  8888', 0, 1, 0, 0, 93);
INSERT INTO 'dance' VALUES (15836, '2015-01-18 14:46:23.66188+00', '2020-12-30 21:26:56.115457+00', 'Pâques à Lyon', 'PAQUES A LYON', 4, 80, 4, 1, 4, 2, 1582, '2005-03-01', 'First & third couples dance strathspey, second & fourth couples reel

or

first & second couples dance strathspey, third & fours couples reel.', 75, '8008/8888/8448/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5806, '1997-11-27 23:00:00+00', '2018-11-06 23:19:29.036076+00', 'Saint Andrew''s Medley', 'SAINT ANDREWS MEDLEY', 4, 128, 2, 1, 4, NULL, 377, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14381, '2011-12-17 23:00:00+00', '2018-11-09 21:59:58.267368+00', 'Red Squirrel, The', 'RED SQUIRREL', 3, 32, NULL, 1, 4, 1, 2765, '2011-06-01', 'Dedicated to Jim Rae of Lockerbie', 34, '8000/8330/8330/8000', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14600, '2012-11-15 19:11:17.594282+00', '2022-08-14 08:58:47.93569+00', '60 and Still Going Strong', '60 AND STILL GOING STRONG', 1, 32, NULL, 1, 3, 42, 308, '2009-11-01', 'Contributed Crib compiled by the deviser, Sue Petyt, 2009', 56, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8470, '1997-12-28 23:00:00+00', '2022-10-04 19:09:34.912222+00', 'Largo Frolic', 'LARGO FROLIC', 2, 32, 9999, 1, 2, 76, 872, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15114, '2013-09-13 11:45:25.922875+00', '2019-02-01 15:33:12.076329+00', 'Maria''s Farewell to Pretoria', 'MARIAS FAREWELL TO PRETORIA', 1, 40, 9999, 1, 3, 42, 10853, '2012-09-01', 'Devised by Urisa Reungsuwan, September 2012.



This dance is dedicated to Maria Elizabeth Giron. She has been a lively and cheerful sup­porter at the RSCDS Pretoria Branch. Maria, who hails from Guatemala, will accompany her husband to Colombia where he has to take up a new position. ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17104, '2016-06-30 18:18:18.287663+00', '2019-02-23 19:10:56.723253+00', 'Crossing the Harbour', 'CROSSING THE HARBOUR', 2, 32, NULL, 1, 4, 1, 832, '2005-01-01', 'For those of us who sometimes cross Portsmouth harbour from Gosport to join in demonstrations at Southsea', -1, '8008/8888/8888/6868', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19051, '2018-11-10 15:43:41.388777+00', '2019-03-27 00:04:39.849974+00', 'Lucy Mulholland''s Strathspey', 'LUCY MULHOLLANDS STRATHSPEY', 3, 32, NULL, 1, 4, 2, 10648, '2018-01-01', '', 78, '8448/8888/8668/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14941, '2013-06-04 12:31:49.543222+00', '2018-11-16 15:03:44.591627+00', 'Sleepwalkers'' Strathspey, The', 'SLEEPWALKERS STRATHSPEY', 3, 32, NULL, 1, 4, 2, 10794, NULL, 'Demo dance.  "Based very loosely on a dance I remember from a dream".', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19057, '2018-11-20 13:00:07.724387+00', '2018-11-20 13:13:44.070279+00', 'Moonen Bay', 'MOONEN BAY', 3, 32, 9999, 2, 2, 76, 3689, '2015-02-01', 'Comments by Anne Taylor (formerly Grant) from the leaflet describing the dance:



I devised Broadford Bay in 1990 and it appears in the Skye Collection Vol 1 and was adopted by the RSCDS in the Leaflet Dances in 2001. Despite the popularity of the dance, the Chase and Turn movement (Bars 17-24) still appears to pose problems with many dancers.



I have devised Moonen Bay to try to clarify the Chase and Turn movement (Bars 9-16). I have often suggested that Broadford Bay could be taught firstly in Strathspey time which may help the dancers to understand the movement. Good Luck!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17106, '2016-06-30 21:02:07.414995+00', '2018-11-11 02:47:23.954213+00', 'Gosport Queen, The', 'GOSPORT QUEEN', 2, 40, NULL, 1, 3, 42, 11294, '2005-09-01', 'This dance represents one of the ferries across Portsmouth Harbour, with the winding of the ropes

round the capstans, the crossing of the harbour, and then the bicycles and the people leaving the

ferry on the other side.', 75, '800/888/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17107, '2016-06-30 21:04:04.497057+00', '2018-11-11 03:14:01.877946+00', 'Langdale Round', 'LANGDALE ROUND', 1, 32, NULL, 1, 3, 42, 11293, '2005-07-01', 'Named after a long circular ridge walk around the Langdale Valley in the Lake District. The first twenty-four bars describe gaining height and traversing the summits. The last eight bars celebrate arriving at the pub safely.', 72, '866/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19050, '2018-11-10 13:36:52.595913+00', '2018-11-11 11:05:50.058734+00', 'Barley Twist', 'BARLEY TWIST', 3, 32, NULL, 2, 3, 18, 11744, '2018-06-22', 'The original description received by the e-crib team specifies wrong positions (3,1,2) on bar 20.', 98, '888/888/886/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9008, '2002-01-08 23:00:00+00', '2020-12-20 11:20:08.395978+00', 'Mary Erskine', 'MARY ERSKINE', 1, 32, 9999, 1, 3, 42, 146, NULL, 'Mary Erskine (1629-1708), born and raised in  Edinburgh, was a Scottish entrepreneur and philanthropist (after being twice  widowed) who founded a school for girls which was eventually renamed for her as benefactress and still exists as the Mary Erskine School in the  Ravelston area of Edinburgh. (Thanks to Robb Quint for digging this up; see <<sspey-thread:63106|this Strathspey thread>>.)



The dance is dedicated to the school on the occasion of its tercentenary.

', 47, '840  888  800  844', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (11616, '2003-12-04 23:00:00+00', '2021-01-22 20:54:15.39682+00', 'Kristin MacDonald''s Strathspey', 'KRISTIN MACDONALDS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 2682, '1992-01-01', 'From the deviser''s notes:



Devised in Ithaca,  New York,  USA in September,  1992 and modified in June 1997.

Kristin is my wife.  This was the first dance I ever wrote.



Note that the preferred recording (Ms Gillian McMullen Of Cambridge) is played four times through although this is a three couple set dance.

', 91, '888/808/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12451, '2005-06-05 22:00:00+00', '2021-04-08 12:10:17.035802+00', 'West Coast Delight', 'WEST COAST DELIGHT', 4, 128, 2, 4, 4, 3, 3400, NULL, '', 87, '8888/8888/8888/4444/4444/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13358, '2009-08-02 22:00:00+00', '2018-11-23 23:48:17.699814+00', 'Mrs. Frances MacCullough', 'MRS FRANCES MACCULLOUGH', 1, 32, NULL, 1, 3, 42, 1322, NULL, 'Dedicated to Fran MacCulloch, a long time member of the Montréal Branch.



Note that the dance was published with her surname incorrectly spelled as MacCullough (see http://my.strathspey.org/dd/issue/1583/).

', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17536, '2017-01-05 10:41:02.143245+00', '2018-11-24 05:13:31.686227+00', 'Lonely Honeybee, The', 'LONELY HONEYBEE', 1, 32, NULL, 1, 3, 42, 28, NULL, 'The Honeybees search for food,  

Bars 1-6 a straight flight tells direction of food.  

Bars 17-24 a figure of eight means food is further away.  

Bars 25-32 a circle in both directions means food is near.', 53, '800/840/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13619, '2010-10-08 22:00:00+00', '2018-11-24 08:56:37.189005+00', 'Hedwig''s Reel', 'HEDWIGS REEL', 1, 32, 9999, 1, 3, 42, 10254, NULL, 'In reply to a question on how 1W moves on bar 8 and bar 16, the deviser answered "This dance was written for children, but a slightly older group, and we were doing the Society''s Medal Tests.  It is a while since I was teaching children and I can''t quite remember how we did it, but I suspect it was the easy way - dance out to place & face down, not finishing facing in then turning to face down. As you say, it could very easily turn into a twirl round, if someone is late. I have danced it in the Dundee Branch General class & I don''t think the class teacher has ever made any comment on this point.  Again, my purpose in writing the dance was to teach & practice a 3 couple grand chain in an easy dance & that is what I concentrated on."

', 50, '800/800/888/888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (17530, '2017-01-05 10:02:01.564973+00', '2018-11-24 13:04:37.490902+00', 'Glint in the Eye, A', 'GLINT IN THE EYE', 2, 32, NULL, 1, 100, 11, 11438, NULL, 'This dance is dedicated to Jean McCadden who has dispensed knowledge and fun to her Helen''s Bay class for over 50 years.', 94, '8888/8448/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17314, '2016-09-09 10:25:54.459068+00', '2018-11-27 16:19:36.033373+00', 'Stooge Extraordinaire', 'STOOGE EXTRAORDINAIRE', 2, 32, NULL, 1, 3, 42, 11349, '2016-02-01', 'Devised by Corerentin Lefevre. This dance is dedicated to all the stooges who give of their time and patience for the teaching certificate, an important part of Scottish Country Dancing. It was devised on the occasion of the Unit 3 exam organised by the Lyon Branch in February 2016. The surprising phrasing illustrates the fact that stooges have to do what the teacher says, even when it is not the most logical thing to do.', 62, '400/888/888/888/400', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19195, '2019-02-20 23:27:03.927582+00', '2019-02-22 17:58:40.801063+00', 'Busy Busy Bees', 'BUSY BUSY BEES', 1, 32, NULL, 4, 4, 13, 11354, NULL, '', 94, '8888/8888/8888/6666', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17980, '2017-09-26 21:40:24.205187+00', '2018-11-27 02:32:36.519808+00', 'Birth of a New Star, The', 'BIRTH OF A NEW STAR', 1, 88, 9999, 4, 4, 3, 11529, NULL, '“When the wise men saw the star, they were filled with joy”



The Magi Visit Jesus, Matthew 2:1-12', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17441, '2016-10-30 11:52:25.234912+00', '2018-12-02 01:59:38.741903+00', 'Kirkcall Strathspey', 'KIRKCALL STRATHSPEY', 3, 32, NULL, 1, 3, 42, 433, '2011-08-01', 'Dedicated to Ian Kirkpatrick, talented dancer, musician and true friend for many years.', 50, '880/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7503, '1997-04-04 22:00:00+00', '2019-01-24 14:53:00.541232+00', 'Rose of Ardwall', 'ROSE OF ARDWALL', 3, 32, 9999, 1, 3, 42, 433, '1987-01-01', 'Willie was quoted to have said there is only one thorn in this dance and it is in bars 21-24.  

  

Dedicated to Kath McCulloch of Ardwall, an outstanding teacher and dancer of Gatehouse of Fleet Branch of Royal Scottish Country Dance Society. Known to many ladies for her ‘Hags Hop’ Class at Ardwall.', 44, '800/822/884/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17449, '2016-10-30 12:11:09.790051+00', '2018-12-04 00:37:01.599136+00', 'Haggis, The', 'HAGGIS', 1, 32, NULL, 1, 3, 42, 433, '2009-01-01', 'Dedicated to ‘Days of Dance’ competition.  

  

Narative.  

1 - 8 The first couple go out and bring in the haggis.  

9 - 16 Celebrate the shape of it.  

17 - 24 Hands across the table / world friendship. Back to back = intermingling socialising.  

25 - 32 The twisty road hame in high spirits after a wee dram maybees!', 59, '800/888/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17446, '2016-10-30 12:00:44.450006+00', '2018-12-05 05:01:24.458819+00', 'Rooftops', 'ROOFTOPS', 3, 32, NULL, 1, 3, 42, 433, '2006-12-01', 'Dedicated to John and Heather Hockenhull, ‘Rooftops’, Newton Stewart. Enthusiastic long serving members of The Gatehouse of Fleet Branch, of the Royal Scottish Country Dance Society- John being a past chairman.', 50, '888/664/646/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19068, '2018-12-06 10:33:55.433383+00', '2018-12-06 10:33:55.433383+00', 'Castlehill Capers', 'CASTLEHILL CAPERS', 1, 40, NULL, 4, 4, NULL, 3699, '2011-01-01', 'For Chris Sanders of Castlehill, Bearsden. Chris and his wife Margaret were good friends of Jimmy.', 69, '8080/8282/8282/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19072, '2018-12-06 11:05:15.243051+00', '2018-12-06 11:05:15.243051+00', 'Farewell to Shawlands', 'FAREWELL TO SHAWLANDS', 1, 24, NULL, 3, 5, 7, 3699, NULL, 'Devised for the class in Shawlands Primary School. In 1993 Glasgow Branch changed all class teachers after they completed 5 years with a class.', 87, '88880/88888/80888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19074, '2018-12-06 11:31:47.760271+00', '2018-12-06 17:59:22.464086+00', 'Glasgow MacDonalds, The', 'GLASGOW MACDONALDS', 3, 32, NULL, 1, 100, NULL, 3699, NULL, 'For a demonstration at the Clan Donald annual dinner in Glasgow.', 94, '8888/4884/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19067, '2018-12-06 10:20:47.466416+00', '2019-04-20 22:41:55.567713+00', 'Ben Lui', 'BEN LUI', 4, 32, 1, 6, 3, NULL, 3699, NULL, 'Ben Lui was the home of George & Ellen Regan, friends and dance team partners.', 100, '888/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19065, '2018-12-06 00:33:08.707783+00', '2019-01-29 00:13:51.182336+00', 'All Cross', 'ALL CROSS', 2, 32, NULL, 1, 3, 42, 3699, NULL, 'Devised to teach the phrasing of 6 bar reels and cross over on bars 7 & 8', 66, '844/888/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19073, '2018-12-06 11:25:20.962133+00', '2019-01-29 00:10:18.001999+00', 'Farewell to Westerton Hall', 'FAREWELL TO WESTERTON HALL', 3, 32, NULL, 1, 3, 42, 3699, NULL, 'Devised when the original hall was closed for demolition it was a Nissan hut which had many uses over the years.', 69, '880/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19066, '2018-12-06 00:40:51.642958+00', '2019-03-03 09:35:33.368931+00', 'Bairds of Balloch, The', 'BAIRDS OF BALLOCH', 2, 32, NULL, 1, 3, 42, 3699, '2010-06-01', 'Devised for Mary & Robert Baird on their move from Glasgow to Balloch, June 2010', 63, '844/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19069, '2018-12-06 10:42:47.304174+00', '2021-11-12 15:29:37.976813+00', 'Connie''s Fancy', 'CONNIES FANCY', 2, 32, NULL, 1, 3, 42, 3699, '2000-01-01', 'For Constance Freeland, loyal and regular member of Jimmy’s class.', 59, '800/866/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19088, '2018-12-06 17:17:54.975806+00', '2019-01-29 00:09:19.338128+00', 'Lochranza Castle', 'LOCHRANZA CASTLE', 3, 32, NULL, 1, 3, 42, 3699, NULL, 'Lochranza Castle is situated on the North of Arran and is the ancestral territory of the Clan MacMillan.', 56, '880/888/888/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19089, '2018-12-06 17:22:48.592577+00', '2018-12-06 17:22:48.592577+00', 'Miss Margery Gray', 'MISS MARGERY GRAY', 3, 32, NULL, 1, 3, NULL, 3699, NULL, '', 58, '866/888/800/688', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19090, '2018-12-06 17:35:48.260963+00', '2018-12-06 17:35:48.260963+00', 'Miss Shona Armour', 'MISS SHONA ARMOUR', 2, 32, NULL, 1, 4, 84, 3699, NULL, 'Devised for his granddaughter, Shona.', 53, '8000/8044/4804/6886', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19091, '2018-12-06 17:46:11.15542+00', '2018-12-06 17:46:11.15542+00', 'Mrs Helen Murray', 'MRS HELEN MURRAY', 3, 40, NULL, 2, 3, 17, 3699, NULL, '', 78, '820/888/866/855/868', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19092, '2018-12-06 17:54:13.956431+00', '2018-12-06 17:57:36.371498+00', 'Oak Tree, The', 'OAK TREE', 3, 32, NULL, 2, 3, NULL, 3699, NULL, '', 83, '686/888/282/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19093, '2018-12-06 18:30:11.227217+00', '2018-12-06 18:33:31.206669+00', 'Perpetual Motion', 'PERPETUAL MOTION', 2, 32, NULL, 2, 3, 17, 3699, NULL, '', 100, '888/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19095, '2018-12-06 18:47:35.261081+00', '2018-12-06 18:47:35.261081+00', 'Push Me, Pull Me', 'PUSH ME PULL ME', 4, 128, 10020, 1, 4, 84, 3699, NULL, '', 72, '8000/8888/4884/4888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19096, '2018-12-06 22:37:17.390475+00', '2018-12-06 22:37:17.390475+00', 'Red Craig, The', 'RED CRAIG', 3, 32, NULL, 3, 5, 16, 3699, '1993-03-01', 'Dance devised for Arthur Craig, a "Red Headed" dancer from Glasgow but known to many branches.', 79, '68686/88888/88888/82020', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19101, '2018-12-06 23:04:43.000482+00', '2018-12-06 23:04:43.000482+00', 'Teddy Bears Jig, The', 'TEDDY BEARS JIG', 2, 32, NULL, 3, 5, 35, 3699, NULL, '', 88, '88888/48884/84848/88884', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19102, '2018-12-06 23:16:15.867835+00', '2018-12-06 23:16:15.867835+00', 'Tenovus', 'TENOVUS', 4, 64, 5, 3, 5, 3, 3699, NULL, 'Dance devised for a fund raising Charity established by 10 ladies from East Kilbride', -98, '88888/88888/48884/88888/88888/88888/88888/88888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16568, '2015-08-25 22:48:23.093153+00', '2018-12-07 18:07:11.618587+00', 'Good Luck to Thomas', 'GOOD LUCK TO THOMAS', 2, 32, NULL, 1, 3, 42, 1445, '2014-01-01', 'To congratulate Sjoerd and Sophie van Leersum with the birth of their son Thomas Alexander.', 44, '880/880/800/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16809, '2015-10-28 19:50:24.573198+00', '2018-12-07 18:09:24.276207+00', 'Princes Street Strathspey (Edinburgh)', 'PRINCES STREET STRATHSPEY EDINBURGH', 3, 32, NULL, 107, 3, NULL, 2419, NULL, 'Start in "Ruthven Formation": 1c face 3c on midline, 1c is on opposite side; 2c in 2pl. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19033, '2018-10-24 19:03:33.333561+00', '2018-12-09 10:10:16.748021+00', 'C. Stewart Smith', 'C STEWART SMITH', 1, 32, NULL, 1, 4, 2, 952, '2015-10-01', 'Devised to celebrate the fiftieth anniversary of the San Francisco Branch of the R.S.C.D.S., and named for one of those most influential in promoting Scottish dance during the early years.



Available as a leaflet from the deviser.', 71, '8008/4884/8228/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19103, '2018-12-06 23:23:51.648615+00', '2018-12-14 11:10:35.987285+00', 'Alice McLean''s Hornpipe', 'ALICE MACLEANS HORNPIPE', 1, 32, NULL, 1, 3, 42, 640, NULL, 'Inscribed to Alice McLean of Clarkston', 72, '888/888/888/884', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12812, '2006-08-17 22:00:00+00', '2018-12-09 21:47:56.972677+00', 'Anne Harper''s Jig', 'ANNE HARPERS JIG', 2, 32, 9999, 1, 4, 2, 640, '2006-01-01', '', 81, '8008/8888/8448/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19105, '2018-12-06 23:31:19.227593+00', '2018-12-10 20:47:16.129401+00', 'Ayrshire Hospitality', 'AYRSHIRE HOSPITALITY', 3, 32, NULL, 1, 100, 2, 640, '2008-01-01', '', 81, '8888/8008/8448/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7332, '1997-08-26 22:00:00+00', '2018-12-11 16:56:19.269019+00', '29th of June', '29TH OF JUNE', 1, 32, 9999, 1, 4, 1, 17, '2003-01-01', 'There may also be another dance of the same name, also by Martin Sheffield devised in 1991, a 4x40 Reel with a ladies chain and a half reel of four ', 55, '6840/8048/8000/8484', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19099, '2018-12-06 22:51:51.933056+00', '2018-12-14 00:24:00.482019+00', 'Sheilandwill Jig', 'SHEILANDWILL JIG', 2, 32, NULL, 1, 3, NULL, 3699, NULL, 'For Sheila MacMillan and Willie Stevenson, members of the Shawlands class



', 53, '800/666/666/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19112, '2018-12-06 23:48:46.244012+00', '2018-12-14 20:08:27.540391+00', 'Sunset on the Clyde', 'SUNSET ON THE CLYDE', 3, 32, NULL, 1, 102, 2, 640, '2008-01-01', '', 93, '8888/8888/8888/8448', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19111, '2018-12-06 23:47:29.393626+00', '2018-12-14 20:24:40.980003+00', 'Sandra Fraser''s Jig', 'SANDRA FRASERS JIG', 2, 32, NULL, 1, 3, 42, 640, '2010-07-19', 'Inscribed to Sandra Fraser on the occasion of her special birthday on 19th July 2010', 68, '880/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19113, '2018-12-06 23:56:06.859033+00', '2018-12-14 23:46:55.978569+00', 'Westerton Jig', 'WESTERTON JIG', 2, 32, NULL, 1, 102, 2, 640, '2015-01-01', 'To celebrate the 25th Anniversary of the Westerton Summer Dancing Class.  For many years John Renton played for the class and Fiona McDonald is one of its regular teachers.', 93, '8888/8888/8448/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19107, '2018-12-06 23:35:25.063588+00', '2018-12-19 14:03:38.608965+00', 'Frances Corbett''s Hornpipe', 'FRANCES CORBETTS HORNPIPE', 1, 32, NULL, 1, 4, 1, 640, '2007-01-01', 'Inscribed to Frances Corbett on the occasion of a special birthday.', 50, '8260/8880/8000/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19106, '2018-12-06 23:32:54.75165+00', '2018-12-16 00:47:06.411464+00', 'Bridge of Weir', 'BRIDGE OF WEIR', 2, 32, NULL, 3, 5, 7, 640, '2008-01-01', '', 72, '84840/88880/84884/84844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19108, '2018-12-06 23:38:57.914657+00', '2018-12-27 22:21:12.33101+00', 'Let Glasgow Flourish', 'LET GLASGOW FLOURISH', 2, 32, NULL, 1, 4, 2, 640, '2008-01-01', 'Devised for children at the request of RSCDS Glasgow Branch.  Yhis dance is dedicated to Glasgow as host city for the 2014 Commonwealth Games.  This does not preclude adults from dancing it.', 97, '8888/8888/8668/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12344, '2005-04-27 22:00:00+00', '2019-01-04 15:55:04.240916+00', 'Upsidedown Jig, The', 'UPSIDEDOWN JIG', 2, 32, 9999, 1, 4, 2, 1, '2004-04-01', '', 75, '0880/8888/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15499, '2014-06-27 21:05:14.668612+00', '2019-10-15 00:07:47.631897+00', 'Whirlpools in the River', 'WHIRLPOOLS IN THE RIVER', 3, 32, NULL, 1, 3, 42, 10971, NULL, 'This dance suggests the swirling water of a fast flowing river.', 50, '800/888/880/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19098, '2018-12-06 22:46:44.754605+00', '2019-01-29 00:09:54.657885+00', 'Roundhill Reel', 'ROUNDHILL REEL', 1, 32, NULL, 1, 3, 42, 3699, NULL, 'For Linda Henderson who lived in Roundhill Road.', 56, '800/888/888/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19071, '2018-12-06 10:56:55.80345+00', '2019-01-29 00:14:40.604174+00', 'Eaglets, The', 'EAGLETS', 1, 32, NULL, 1, 2, 76, 3699, NULL, 'For the little eagles of the eagle’s hame. The Eaglesham Class was where Jimmy started dancing.', 56, '80/88/88/84', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19100, '2018-12-06 22:57:39.370739+00', '2019-01-29 00:15:54.393+00', 'Silver Thimble, The', 'SILVER THIMBLE', 3, 32, NULL, 1, 2, 76, 3699, NULL, 'For George & Ellen Regan’s 25th Anniversary.', 56, '84/80/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19104, '2018-12-06 23:27:23.965273+00', '2019-02-23 18:26:44.333746+00', 'Alice McLean''s Jig', 'ALICE MACLEANS JIG', 2, 32, NULL, 1, 3, 42, 640, NULL, 'Inscribed to Alice McLean of Clarkston', 45, '880/808/811/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19150, '2019-01-16 23:42:23.257699+00', '2019-01-16 23:42:23.257699+00', 'Canada 150 Eh!', 'CANADA 150 EH', 3, 40, NULL, 2, 3, 17, 11503, '2017-01-01', 'For the celebration of Canada’s 150th birthday.', 63, '888/844/844/488/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17581, '2017-02-13 19:15:20.475078+00', '2020-05-05 10:38:39.736279+00', 'Breakfast Time Jig', 'BREAKFAST TIME JIG', 2, 32, NULL, 1, 3, 42, 11164, '2014-12-01', '', 50, '800/844/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16106, '2015-02-22 22:34:12.79888+00', '2021-01-05 19:24:51.017233+00', 'February Gold', 'FEBRUARY GOLD', 3, 32, NULL, 1, 4, 2, 692, '2010-02-01', 'Devised to mark the 50th anniversary of the Derwent Scottish Country Dance Club.', 75, '0880/8888/8008/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18523, '2018-08-24 15:59:45.157103+00', '2018-12-14 00:13:38.855688+00', 'Brabloch Strathspey, The', 'BRABLOCH STRATHSPEY', 3, 24, NULL, 2, 3, 17, 3699, NULL, 'The Brabloch was where Jimmy, Nan and friends celebrated Hogmanay with Dinner Dances for many years. The dance was originally written as a jig but the tournée worked better in strathspey time.





The publication "Scottish Country Dances by James McMillan" has the following description of the figure



Triple Tournée



This is a tournée for 3 couples in strathspey time. Top and bottom couples change places with 8 travelling steps.



Bars

1 Top lady dances in above partner, top man dances in below his partner pulling back left shoulder to face his own side; middle couple dance in and pull back right shoulder to face their own side of the dance, man above his partner; bottom lady dances in pulling back left shoulder to face own side of the dance and bottom man dances in below partner. All three couples are now in a straight line up and down the middle of the set, the top 3 people are facing the men’s side and the bottom 3 facing the women’s side, with nearer hands joined.



2 - 4 All three couples dance round half-way, anti-clockwise, on the fourth step the couples at top and bottom of the line change to right hands so the women face towards the men''s side and the men face towards the women''s side of the dance, middle couple retain left hands



5 - 8 Top and bottom couple turn with the right hand one-and-a-half times, middle couple turn with the left hand one-and-a-half times, then dance out to finish on own sides.', 89, '888/488/488', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15046, '2013-08-06 12:02:47.620832+00', '2018-12-12 20:42:43.003191+00', 'Buchan''s Country', 'BUCHANS COUNTRY', 3, 48, 9999, 2, 3, 17, 154, '2005-11-01', '', 71, '842/808/844/844/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19116, '2018-12-12 20:52:58.433653+00', '2018-12-12 21:00:18.584977+00', 'Fifty Years of Friendship', 'FIFTY YEARS OF FRIENDSHIP', 3, 32, NULL, 4, 4, 1, 1276, '2018-01-01', 'In affectionate memory of Ruth Thornton, Liskeard Scottish Country Dancers.



', 87, '8484/8888/8888/8484', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (264, '1998-04-29 22:00:00+00', '2018-12-13 01:52:24.017189+00', 'At the Town''s End', 'AT THE TOWNS END', 1, 32, 9999, 1, 2, 76, 44, '1982-01-09', 'Presented to the sixteenth Fort Worden Scottish Country Dance Weekend.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5284, '1997-04-03 22:00:00+00', '2018-12-13 09:47:04.007737+00', 'Pipes and Drums, The', 'PIPES AND DRUMS', 1, 40, 9999, 1, 3, 42, 35, NULL, '', 45, '800/844/888/822/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19117, '2018-12-12 23:34:47.716794+00', '2018-12-13 14:18:49.616843+00', 'Miss Lucy Fallon', 'MISS LUCY FALLON', 3, 32, NULL, 1, 3, 42, 316, '2018-01-01', 'For Lucy Fallon on her birthday.', 56, '844/844/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11021, '2002-11-24 23:00:00+00', '2018-12-21 07:58:51.433508+00', 'Hairy Hooligan', 'HAIRY HOOLIGAN', 1, 32, 9999, 1, 3, 42, 1, '2001-01-01', 'Abigail Sunnyhurst, a 9 year old rough collie who still acts like a boisterous puppy, is often referred to as “The Haiiy Hooligan”.', 44, '880/844/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4897, '1997-09-10 22:00:00+00', '2018-12-13 23:29:38.300259+00', 'Neil''s Reel', 'NEILS REEL', 1, 32, 9999, 1, 3, 42, 155, NULL, '', 43, '800/888/880/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11015, '2002-11-24 23:00:00+00', '2019-02-24 10:35:29.279795+00', 'Alphabet Reel', 'ALPHABET REEL', 1, 40, 9999, 1, 3, 42, 930, '2000-02-01', 'For all those who have enjoyed Scottish Dancing weekends organised by ABCD Holidays.', 40, '804/840/844/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (171, '1997-08-28 22:00:00+00', '2020-08-29 11:45:06.526579+00', 'Anne of Portsoy', 'ANNE OF PORTSOY', 1, 32, 9999, 1, 3, 42, 635, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7892, '1997-12-03 23:00:00+00', '2020-09-05 10:17:04.485251+00', 'Piggy in the Middle', 'PIGGY IN THE MIDDLE', 2, 32, 9999, 107, 112, 30, 1202, '1973-01-01', '"Piggy in the Middle" is a demonstration dance for 7 persons, more explicitly 3 couples in a longwise set and a 7th dancer facing down between 2nd couple. The description specifies the 7th dancer as being a ''man''.



When devising this demonstration dance, Jean McWilliam was inspired by Lindsey Ross'' tune "The Wind that shakes the Piggery".

', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8529, '2003-02-16 23:00:00+00', '2020-09-07 08:46:12.637012+00', 'Blenheim Gardens', 'BLENHEIM GARDENS', 1, 32, 9999, 1, 2, 76, 2082, NULL, '', 67, '86/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (76, '1998-09-29 22:00:00+00', '2020-09-07 14:14:42.190949+00', 'Alewife and her Barrel, The', 'ALEWIFE AND HER BARREL', 1, 32, 9999, 1, 2, 76, 453, '1759-01-01', '', 47, '80  88  44  66', 0, 1, 0, 0, 68);
INSERT INTO 'dance' VALUES (18522, '2018-08-24 15:53:13.794582+00', '2018-12-14 00:12:42.433923+00', 'Big "T", The', 'BIG T', 3, 32, NULL, 1, 3, 42, 3699, NULL, 'The publication "Scottish Country Dances by James McMillan" has the following description of the figure



Triple Tournée



This is a tournée for 3 couples in strathspey time. Top and bottom couples change places with 8 travelling steps.



Bars

1 Top lady dances in above partner, top man dances in below his partner pulling back left shoulder to face his own side; middle couple dance in and pull back right shoulder to face their own side of the dance, man above his partner; bottom lady dances in pulling back left shoulder to face own side of the dance and bottom man dances in below partner. All three couples are now in a straight line up and down the middle of the set, the top 3 people are facing the men’s side and the bottom 3 facing the women’s side, with nearer hands joined.



2 - 4 All three couples dance round half-way, anti-clockwise, on the fourth step the couples at top and bottom of the line change to right hands so the women face towards the men''s side and the men face towards the women''s side of the dance, middle couple retain left hands



5 - 8 Top and bottom couple turn with the right hand one-and-a-half times, middle couple turn with the left hand one-and-a-half times, then dance out to finish on own sides.', 63, '800/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10040, '2001-09-02 22:00:00+00', '2018-12-22 16:25:36.558544+00', 'Seven Dwarfs, The', 'SEVEN DWARFS', 1, 32, 9999, 2, 112, 30, 9, '1970-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19129, '2018-12-21 11:04:59.018497+00', '2019-01-04 16:22:46.078375+00', 'Rose of Cambridge', 'ROSE OF CAMBRIDGE', 3, 32, NULL, 1, 3, 42, 11601, '2018-01-01', 'Dance devised by Lesley McCourt in 2018 and dedicated to Rose Wharton, who came from Cambridge. She had battled cancer but passed away in 2018. The Rose progression is included in the dance in memory of her, and also because coincidentally it is Lesley’s middle name, as it was the name of her grandmother.



Information supplied in issues http://my.strathspey.org/dd/issue/1602/ and http://my.strathspey.org/dd/issue/1603/', 56, '888/888/800/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12343, '2005-04-27 22:00:00+00', '2019-02-19 16:12:08.03347+00', 'Trip to Ireland, A', 'TRIP TO IRELAND', 1, 32, 9999, 1, 4, 1, 930, '2004-06-01', 'This was devised for a dancing holiday in Waterford in June 2004.', 69, '8448/8448/8888/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16033, '2015-02-11 13:03:23.846675+00', '2018-12-24 07:53:52.419585+00', 'Mrs Balgarnie of Hanley Swan', 'MRS BALGARNIE OF HANLEY SWAN', 3, 32, 9999, 1, 4, 2, 3694, '2011-11-01', 'For Win Balgarnie of Hanley Swan near Malvern to celebrate a special birthday in November 2011. Win organises dances which exercise the brain as well as the feet!!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19142, '2019-01-10 20:36:24.683967+00', '2019-04-17 14:28:19.761117+00', 'Can-Do Ceilidh', 'CANDO CEILIDH', 1, 32, NULL, 5, 1, 4, 11768, NULL, 'This dance is a modified version of A Canonbie Celidh <<http://my.strathspey.org/dd/dance/8104/>>









', 75, '4/4/8/8', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11025, '2002-11-24 23:00:00+00', '2020-09-14 15:40:20.74964+00', 'Stromeferry', 'STROMEFERRY', 2, 64, 9999, 4, 4, 13, 1, '2001-04-01', 'For Joy Forinton who has happy memories of life at Stromeferry, a remote croft near Scourie on the wild and rugged north west coast of Scotland. In former years the croft was occupied by a ferryman, who would row passengers across the estuary when the weather permitted.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13640, '2010-11-10 23:00:00+00', '2021-01-01 18:51:37.240014+00', 'Vienna Underground', 'VIENNA UNDERGROUND', 4, 128, 13, 4, 4, 3, 10293, '2009-01-01', 'If there is no S64+J64 recording at hand, a S64+R64 recording should work as fine. (note by the deviser)



A Note from "The Vienna Book":  

The dance and its figures resemble the layout of the underground lines that circle around Vienna’s city centre (U2 and U4) or intersect below St Stephen’s Cathedral (U1 and U3), as well as the transition from early morning to rush-hour traffic, waiting on the platform and getting on and off the trains.', 81, '8888/8888/8888/8484/8080/4848/0808/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (942, '1998-01-05 23:00:00+00', '2021-06-26 08:51:09.845473+00', 'Calgary''s First Hundred', 'CALGARYS FIRST HUNDRED', 1, 40, 9999, 1, 3, 42, 118, '1975-01-01', 'Devised for the Centennial Celebrations for the City of Calgary, Alberta, 1975.', 53, '800/888/822/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19070, '2018-12-06 10:49:58.517785+00', '2018-12-14 00:18:38.491311+00', 'Drymen Hall, The', 'DRYMEN HALL', 3, 32, NULL, 2, 3, 17, 3699, NULL, 'The Drymen Hall is part of All Saints Church, Bearsden, location of the Glenburn Club, set up for experienced dancers to provide them with "Challenges".





The publication "Scottish Country Dances by James McMillan" has the following description of the figure



Triple Tournée



This is a tournée for 3 couples in strathspey time. Top and bottom couples change places with 8 travelling steps.



Bars

1 Top lady dances in above partner, top man dances in below his partner pulling back left shoulder to face his own side; middle couple dance in and pull back right shoulder to face their own side of the dance, man above his partner; bottom lady dances in pulling back left shoulder to face own side of the dance and bottom man dances in below partner. All three couples are now in a straight line up and down the middle of the set, the top 3 people are facing the men’s side and the bottom 3 facing the women’s side, with nearer hands joined.



2 - 4 All three couples dance round half-way, anti-clockwise, on the fourth step the couples at top and bottom of the line change to right hands so the women face towards the men''s side and the men face towards the women''s side of the dance, middle couple retain left hands



5 - 8 Top and bottom couple turn with the right hand one-and-a-half times, middle couple turn with the left hand one-and-a-half times, then dance out to finish on own sides.', 83, '808/888/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19109, '2018-12-06 23:41:49.806901+00', '2018-12-14 23:30:32.077262+00', 'Millport', 'MILLPORT', 1, 32, NULL, 1, 3, 42, 640, '2008-01-01', '', 65, '866/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19123, '2018-12-15 16:04:57.010555+00', '2018-12-15 16:04:57.010555+00', 'Highlands of Durham Strathspey, The', 'HIGHLANDS OF DURHAM STRATHSPEY', 3, 32, NULL, 1, 4, 1, 10595, NULL, '', 75, '8080/8888/8242/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19127, '2018-12-17 12:23:25.211878+00', '2018-12-17 12:46:18.502734+00', 'Whirlwind Affairs', 'WHIRLWIND AFFAIRS', 3, 32, NULL, 1, 3, 42, 11237, '2018-08-01', 'The three couple tourbillon figure comes from <<ddd:Sulis Minerva>> by <<ddp:Rawlings, Rosamund>>.', 68, '844/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11024, '2002-11-24 23:00:00+00', '2019-02-05 00:14:52.786378+00', 'Elasticity', 'ELASTICITY', 3, 32, 9999, 1, 4, 11, 1, '2001-05-01', 'Another award for Betty Stretch M.B.E.', 75, '0880/8888/4884/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19124, '2018-12-16 01:04:32.685375+00', '2019-01-29 00:08:42.942744+00', 'Gruffalo, The', 'GRUFFALO', 2, 40, NULL, 1, 3, 42, 11764, '2018-08-01', 'To commemorate a memorable train journey to Ware', 40, '822/844/822/844/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (965, '1997-04-03 22:00:00+00', '2018-12-17 09:27:34.122484+00', 'Came a Hot Christmas', 'CAME A HOT CHRISTMAS', 1, 32, 9999, 1, 3, 42, 352, '1993-04-10', '', 60, '800/880/880/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19125, '2018-12-17 11:42:40.45993+00', '2018-12-17 12:41:08.280559+00', 'Gallivanting', 'GALLIVANTING', 2, 40, NULL, 1, 102, 1, 11237, '2017-02-01', 'For Allan Gavine.', 85, '8888/8888/8888/8440/8448', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16169, '2015-03-17 14:06:03.812888+00', '2018-12-17 13:45:47.877878+00', 'Carol''s Christmas Reel', 'CAROLS CHRISTMAS REEL', 1, 32, NULL, 1, 4, 2, 3694, '2012-12-01', 'For Carol Anderson', 81, '8888/8448/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15887, '2015-01-22 12:53:03.478727+00', '2018-12-17 12:46:02.102625+00', 'Forward to Bon Accord', 'FORWARD TO BON ACCORD', 3, 32, 9999, 1, 4, 1, 3694, '2007-07-01', 'Suggested Music: Cannadine Strathspey recorded by Gerge Meikle and the Lothian Band on the CD for Birmigham''s Diamond Jubilee Dance Book', 81, '8888/8008/8888/8088', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19128, '2018-12-17 12:56:23.355484+00', '2018-12-17 13:02:43.047577+00', 'Reel for Marie-Laure, A', 'REEL FOR MARIELAURE', 1, 32, NULL, 2, 3, 18, 11181, '2018-12-17', '', 83, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10236, '2001-11-25 23:00:00+00', '2021-02-10 14:06:32.925343+00', 'Bricks and Mortar', 'BRICKS AND MORTAR', 1, 32, 9999, 1, 3, 42, 2766, '2000-09-01', 'I wrote this dance as I was thinking about how to represent the house we are planning to build on the property we bought.', 50, '800/888/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9769, '2002-04-03 22:00:00+00', '2021-02-20 20:41:27.61293+00', 'At the Top of the Hill', 'AT THE TOP OF THE HILL', 2, 32, 9999, 2, 3, 18, 104, '1995-03-01', '', 53, '884/800/866/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13592, '2010-09-05 22:00:00+00', '2021-08-10 18:59:30.629687+00', 'Michelle Depledge of Preston', 'MICHELLE DEPLEDGE OF PRESTON', 3, 32, 9999, 1, 3, 42, 10208, NULL, 'Devised by Barbara Taylor at the request of Laird Brown, a gift for his wife Michelle.', 50, '880/844/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19122, '2018-12-15 15:50:42.881578+00', '2021-08-10 18:55:04.979504+00', 'St Kilda Jig', 'SAINT KILDA JIG', 2, 32, NULL, 1, 3, 42, 10959, '2015-01-01', 'St Kilda is a group of islands about 100 miles west of the Scottish mainland & 50 miles west of the Outer Hebrides. It is part of the Parish of Harris.  

The islands feature high cliffs & dangerous seas. The village of St Kilda was cleared of its inhabitants in 1930 & now the islands belong to the National Trust.  



_Music_: Luke Brady – Hirte (Hirte is the main island in the St Kilda group) or alternative CD Campbell''s Birl: Traveller''s Jig', 62, '888/880/880/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18841, '2018-10-06 12:45:21.494802+00', '2021-06-05 09:26:27.643641+00', 'NY Yu', 'NY YU', 1, 32, NULL, 1, 4, 1, 2766, '2016-07-01', 'Written for Xiaowen Yu as she prepares to leave Chicago for New York City – specifically NYU.', 50, '8800/8080/8080/8008', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (715, '1997-08-31 22:00:00+00', '2021-06-29 09:39:06.647596+00', 'Boston Hospitality', 'BOSTON HOSPITALITY', 2, 32, 9999, 5, 2, 4, 717, NULL, '', 100, '88 88 88 88', 1, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (685, '1997-04-03 22:00:00+00', '2021-06-29 10:01:58.946962+00', 'Bonnyton Woodie', 'BONNYTON WOODIE', 2, 32, 9999, 1, 3, 42, 332, NULL, '', 59, '888/808/844/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19120, '2018-12-15 15:29:33.861547+00', '2021-08-23 13:37:04.952293+00', 'Casual Briefing, A', 'CASUAL BRIEFING', 2, 32, NULL, 1, 3, 42, 440, '2014-01-23', 'Devised on January 23, 2014, inspired by a comment made by Paul Maloney one night at St. Andrew’s of Brampton.', 50, '880/800/808/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13792, '2011-07-24 22:00:00+00', '2018-12-26 12:41:31.742032+00', 'Corner Greeting', 'CORNER GREETING', 2, 32, NULL, 1, 3, 42, 2682, '2006-03-01', 'Devised as a teaching dance to teach corners. Subsequently I discovered that the last 24 bars is the same as one of Iain Boyd''s teaching dances ("The Mad Hatter" from "Happy to Meet"), except there are no claps in Iain''s dance.', 52, '811/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18734, '2018-10-04 08:29:45.904773+00', '2018-12-27 10:45:57.297176+00', 'Disappearing Cat, The', 'DISAPPEARING CAT', 3, 32, NULL, 1, 3, 42, 2766, '2014-03-01', 'The figure in bars 9-16 is a figure taken from the dance Seann Truibhas Willichan expanded to 3 couples. The people who end up in 2nd place have to be awake for this figure.  



The name of the dance comes from when one of our cats disappeared *in the house* for several days. We nearly went crazy trying to find him until one day he just appeared. We are very glad to have him back.', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13799, '2011-07-24 22:00:00+00', '2018-12-28 02:36:36.516926+00', 'Miss Leslie Cunningham', 'MISS LESLIE CUNNINGHAM', 3, 32, NULL, 1, 3, 42, 2682, '2006-10-01', 'Devised October 2006 in Wellington as a teaching dance for Corners Pass and Turn. Most Strathspey with that formation seem quite difficult. Modified 3 December 2010, after a suggestion of Romaine Butterfield, namely the stepping up/down of the third couple, which makes the phrasing easier. The dance was inspired by the tune it is named after, "Miss Leslie Cunningham" by Muriel Johnston. This tune can be found as part of a Muriel Johnston set for the Strathspey "The Marquis of Lorne" track 3 of "A Dancer''s Miscellany, Vol. 4", or part of the set for "John Derek Evans", in "Dancing Fingers, Vol 3" track 9.

A suitable alternative Strathspey would be "The Armstrong''s Rant" as recorded by Bobby Brown on "H.I.S.C.D", track 3.', 41, '800/844/800/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14020, '2011-08-25 22:00:00+00', '2019-01-02 11:06:27.519886+00', 'MacDonald''s Ball, The', 'MACDONALDS BALL', 4, 64, 1, 1, 3, 42, 401, '2001-10-01', 'For Anthea and Doug MacDonald on the occasion of their wedding anniversary, October, 2001.', 50, '880/880/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11553, '2003-10-05 22:00:00+00', '2019-01-03 01:29:50.330299+00', 'Celebration', 'CELEBRATION', 3, 32, 9999, 1, 2, 76, 348, '2002-04-01', 'For Avril Quarrie on the occasion of her 60th birthday.  

  

Dance record resulting from a merge; check needed whether the two sources refer to the same dance, to variants or to different dances.', -1, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19130, '2018-12-29 02:28:02.997569+00', '2018-12-29 21:55:08.406139+00', 'Silvery Knot, The', 'SILVERY KNOT', 3, 32, NULL, 1, 3, 42, 3439, '2013-05-01', 'Written for the Silver Wedding Anniversary of Craig and Sandy Miller of Richmond, Virginia ', 47, '800/888/880/822', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1613, '1997-09-01 22:00:00+00', '2019-01-02 18:30:58.748134+00', 'Delft Delight, The', 'DELFT DELIGHT', 1, 32, 9999, 5, 53, 4, 142, '1973-06-08', 'A Scottish Country Dance devised by Andrew Gillies and with music especially composed by Gertrude Stewart commemorating their visit to Delft, Netherlands, 8-10 June, 1973.  Dedicated to the St. Andrew''s Society of Delft, which in 1979 became the Delft Branch of The Royal Scottish Country Dance Society. ', 92, '888/888/484/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12824, '2006-08-24 22:00:00+00', '2019-01-02 22:59:00.084378+00', 'Portencross', 'PORTENCROSS', 2, 32, 9999, 1, 3, 42, 640, NULL, '', 50, '800/844/888/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6744, '1997-09-16 22:00:00+00', '2019-01-04 01:10:51.750586+00', 'Trip We Gaily O''er The Machair', 'TRIP WE GAILY OER THE MACHAIR', 2, 32, 9999, 1, 3, 42, 128, NULL, '', 50, '800/880/808/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13326, '2007-09-03 22:00:00+00', '2019-01-03 21:40:26.791493+00', 'Skelmorlie Castle', 'SKELMORLIE CASTLE', 3, 32, 9999, 1, 3, 42, 640, '2007-01-01', '', 56, '888/848/840/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1470, '1997-08-31 22:00:00+00', '2019-01-04 01:34:45.304461+00', 'Culag, The', 'CULAG', 2, 24, 9999, 1, 3, 42, 128, NULL, '', 46, ' 800/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19037, '2018-10-24 19:20:59.242477+00', '2019-01-04 14:29:00.560526+00', 'Hostess with the Mostest', 'HOSTESS WITH THE MOSTEST', 3, 32, NULL, 1, 3, 42, 952, '2018-01-01', 'Fred DeMarse successfully bid on a dance at the Asilomar Weekend''s Fundraiser silent auction in 2017. The resulting dance was devised by Jennifer Kelly for Julee Montes. The title of the dance was chosen by her friends.', 49, '844/888/800/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19133, '2019-01-04 14:45:10.362347+00', '2019-01-04 14:47:11.124987+00', 'Red Dress, The', 'RED DRESS', 2, 32, NULL, 1, 3, 42, 2874, '2017-09-01', 'For Tina Hanson who looked stunning in her red dress on the front cover of The Scottish Country Dancer (April 2016).', 62, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17491, '2016-12-27 00:59:37.642328+00', '2019-01-06 00:41:28.739191+00', 'Narrow Escape, A', 'NARROW ESCAPE', 1, 32, NULL, 1, 3, 42, 10934, NULL, '', -1, '', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (16466, '2015-07-07 13:39:36.425089+00', '2019-01-05 22:51:15.454853+00', 'Crystal Congratulations', 'CRYSTAL CONGRATULATIONS', 1, 40, 9999, 1, 3, 42, 3583, '2008-05-01', 'On bars 1-2 of the third repetition, the dancing couple dance down to fourth place while the 4th couple step up and the new top couple cross down.



Music: "Mousa Broch" by John Turner.



For Sandy & Craig Miller on the occasion of their Twentieth Wedding Anniversary (May 2008). The original tune "Mousa Broch" was composed by John Turner for the same celebration.', 45, '800/844/088/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2284, '1997-08-25 22:00:00+00', '2019-01-10 01:29:29.208699+00', 'Forfar Frolic', 'FORFAR FROLIC', 2, 32, 9999, 1, 3, 42, 515, '1986-01-01', 'Dance devised by John Wilkinson for the demonstration team of the Glasgow Branch of the Royal Scottish Country Dance Society, who visited Forfar every Hogmanay.', 64, '864/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19134, '2019-01-08 15:14:09.353006+00', '2020-01-07 21:37:50.911746+00', 'Babbling Brooke, A', 'BABBLING BROOKE', 2, 32, NULL, 1, 3, 42, 11035, '2013-01-01', '', 44, '800/080/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10593, '2002-12-05 23:00:00+00', '2019-02-21 19:48:32.155593+00', 'Merlin''s Thorn', 'MERLINS THORN', 2, 32, 9999, 1, 3, 42, 154, NULL, '', 56, '800/888/888/880', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (17221, '2016-09-03 19:53:13.311701+00', '2020-10-24 09:45:43.684039+00', 'Anne''s Heather Jig', 'ANNES HEATHER JIG', 2, 48, NULL, 2, 3, 17, 9998, NULL, 'During her first two years of teaching, Anne was frequently challenged with not having enough dancers for a four couple set. As with most of the dances in this book, this reel provides an opportunity for experiencing the joy of Scottish Country Dancing without having to alter dances and music designed for a larger group. ', 69, '800/844/844/888/888/804', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19132, '2019-01-02 12:00:42.920475+00', '2021-09-23 20:57:36.991165+00', 'Together For Forty Years', 'TOGETHER FOR FORTY YEARS', 3, 32, NULL, 1, 3, 42, 2701, '2018-01-01', 'For Tom and Kathy Allen on the occasion of their 40thanniversary. Kathy gave me the gist of the dance—must have a flirtatious opening and a poussette.I hope the rest weds their appreciation of tradition with a nod to sociable and uncomplicated interactions. They’vealways been interested in getting new dancers on the floor,building community, and keeping things grounded in good humor.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19139, '2019-01-08 15:23:55.512535+00', '2020-11-23 10:19:41.397403+00', 'Little Bit of Monty', 'LITTLE BIT OF MONTY', 2, 32, NULL, 1, 3, 42, 11035, '2014-01-01', '', 47, '800/844/844/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19140, '2019-01-08 15:26:49.013778+00', '2020-11-23 10:28:25.743452+00', 'St Aidan''s Church Hall', 'SAINT AIDANS CHURCH HALL', 3, 32, NULL, 1, 4, 1, 11035, NULL, '', 44, '8200/8080/8080/8006', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19152, '2019-01-17 09:42:09.553637+00', '2019-01-17 09:42:09.553637+00', 'Dance for Mae', 'DANCE FOR MAE', 3, 32, NULL, 1, 4, 1, 11770, NULL, '', 75, '8440/8448/0888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19156, '2019-01-17 10:10:59.104842+00', '2019-01-17 10:10:59.104842+00', 'Janis - The Dancing Damsel', 'JANIS  THE DANCING DAMSEL', 2, 40, NULL, 4, 4, 30, 11502, NULL, 'In memory of Janis Platts', 54, '0888/4044/6400/8000/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19158, '2019-01-17 10:24:12.978944+00', '2019-01-17 10:24:12.978944+00', 'Kilmarnock Lad', 'KILMARNOCK LAD', 3, 32, NULL, 2, 3, 17, 2018, NULL, 'For Rob Raeside, VSCD teacher, who grew up in Kilmarnock, Scotland and was a scholar at Kilmarnock Academy before emigrating to Canada.', 67, '840/888/444/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19159, '2019-01-17 10:30:51.935889+00', '2019-01-17 10:30:51.935889+00', 'Let''s Celebrate', 'LETS CELEBRATE', 2, 48, NULL, 1, 4, 1, 425, '1997-11-15', 'For the 15th Anniversary of the RSCDS Nova Scotia Branch', 100, '8888/8888/8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19160, '2019-01-17 10:35:10.999215+00', '2019-01-17 10:35:10.999215+00', 'Mac-Mary Strathspey', 'MACMARY STRATHSPEY', 3, 32, NULL, 1, 4, 1, 209, NULL, 'In honour of Mac and Mary Gray', 66, '8000/8880/8880/8488', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19157, '2019-01-17 10:19:15.073693+00', '2019-01-26 06:58:58.998527+00', 'Jessica''s Strathspey', 'JESSICAS STRATHSPEY', 3, 32, NULL, 2, 2, 76, 425, '1993-03-01', 'For Jessica Beveridge (Demonstration Team Dancer).  This may also be danced in a four couple set.', 67, '88/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18941, '2018-10-12 13:35:51.203174+00', '2019-02-23 18:42:50.298499+00', 'Butterfly', 'BUTTERFLY', 1, 32, NULL, 1, 4, 1, 11035, '2016-01-01', 'Dance devised in early 2016, for Kathleen, Glenna, Joan, & Ruth.  Butterfly was named by two of these women. 



When I was devising it my thoughts were on four women who had gone through changes in their lives and seemed to have come out the other side stronger and ready to enjoy their new path in life. I think the name they chose was very thoughtful and I love the beauty and grace of the Butterfly.', 59, '8040/8080/8888/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3743, '1998-09-29 22:00:00+00', '2019-01-11 00:10:38.877237+00', 'Last of the Lairds, The', 'LAST OF THE LAIRDS', 2, 32, 9999, 1, 3, 42, 392, NULL, 'This dance was significantly modified, in agreement with the deviser, from the version first sent in, to the version published.   

It is said the deviser would have preferred to omit the setting on [17-18], which makes it necessary to deviate from standard phrasing on [17-28].  

On [20-21] 1c leads down, crossing back to own side.  It would seem that a LH lead would be more convenient than the traditional RH version.  The original instructions give no information on this.   ', 56, '888/888/800/844', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (3517, '1998-07-06 22:00:00+00', '2019-01-12 11:20:45.719726+00', 'Kirk''s Hornpipe', 'KIRKS HORNPIPE', 1, 32, 9999, 3, 5, 7, 270, NULL, '', 63, '80800/80022/84488/88888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19143, '2019-01-13 11:45:44.375264+00', '2019-01-13 11:45:44.375264+00', 'Traveling Jenny', 'TRAVELING JENNY', 2, 32, NULL, 1, 3, 42, 2766, '2007-08-01', 'This dance is written for Jenny Lee, who danced with our group as an intern at Fermilab, spent part of the year at CERN, returned to Fermi, and is now going home in California to go back to school.', 50, '800/844/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15506, '2014-06-27 21:10:23.833741+00', '2019-01-23 16:57:28.938439+00', 'Sarasota Strathspey, The', 'SARASOTA STRATHSPEY', 3, 128, NULL, 4, 4, 3, 10971, NULL, '', 60, '8080/8080/8080/8080/8080/8080/8080/8080/0808/0808/0808/0808/0808/0808/0808/0808/8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (573, '1997-04-03 22:00:00+00', '2019-03-19 21:41:49.452174+00', 'Blin'' Jamie', 'BLIN JAMIE', 3, 32, 9999, 1, 4, 2, 270, NULL, '', 75, '8008/8888/8448/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19135, '2019-01-08 15:15:40.373403+00', '2019-12-19 00:31:58.752853+00', 'Susie from Penilee', 'SUSIE FROM PENILEE', 3, 32, NULL, 1, 3, 42, 11035, '2018-01-01', 'In memory of Susie Dorricott.', 63, '880/880/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19151, '2019-01-16 23:47:47.334508+00', '2020-05-08 17:18:00.976812+00', 'Catherine''s Garden Walk', 'CATHERINES GARDEN WALK', 3, 32, NULL, 1, 4, 11, 11501, NULL, 'In celebration of Catherine Pross'' 60th Birthday and her magnificent garden.', 91, '8888/8668/8888/8448', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19154, '2019-01-17 09:55:32.729068+00', '2020-07-19 12:40:17.355295+00', 'Eleanor''s First Birthday', 'ELEANORS FIRST BIRTHDAY', 2, 40, NULL, 1, 3, 42, 11356, NULL, 'For Eleanor Nieforth on the occasion of a special birthday party – the first since she was a small child.', 35, '800/880/633/633/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7261, '1997-11-25 23:00:00+00', '2020-08-07 10:38:50.656985+00', 'Young Sandy Tulloch', 'YOUNG SANDY TULLOCH', 3, 32, 9999, 4, 4, 3, 129, NULL, '', 75, '8080/8080/8080/8080/8888/8888/8888/8888/0808/0808/0808/0808/8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19137, '2019-01-08 15:20:30.625074+00', '2020-09-01 15:18:37.925426+00', 'Dancing The Baby', 'DANCING THE BABY', 1, 72, NULL, 4, 4, 3, 11035, '2017-01-01', 'This may also be danced as a medley of 72 bars Reel and 72 bars Strathspey. 2C & 4C begin the Strathspey which finishes with eight hands round to the left for 3 bars, pivot left and 8 hands round to the left to original places', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14442, '2012-06-12 13:18:40.688418+00', '2021-02-19 15:53:38.472137+00', 'Berkhamsted Castle', 'BERKHAMSTED CASTLE', 1, 32, NULL, 1, 3, 42, 3325, '2010-10-01', 'Berkhamsted was where in 1066 Saxon leaders offered the crown of England to William of Normandy. The castle’s construction was begun that year. The dance was devised to celebrate 60 years of friendship at Berkhamsted Strathspey & Reel Club and depicts the castle motte and bailey whilst echoing the club’s Diamond Jubilee through it’s patterns.', 53, '822/888/800/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3583, '1997-09-07 22:00:00+00', '2019-01-14 19:29:50.982415+00', 'Lads Of Ayr, The', 'LADS OF AYR', 1, 32, 9999, 1, 3, 42, 976, '1740-01-01', '', 50, '660/888/804/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19167, '2019-01-17 19:59:12.947988+00', '2019-01-17 20:09:16.605494+00', 'Jamie''s Retirement Reel', 'JAMIES RETIREMENT REEL', 1, 40, NULL, 3, 5, 16, 11774, '2011-01-01', '', 70, '80008/88888/86468/86868/80008', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14448, '2012-06-12 13:32:17.371293+00', '2022-02-15 15:39:43.843969+00', 'Ocean Voyage', 'OCEAN VOYAGE', 1, 32, NULL, 3, 5, 6, 10624, '2011-04-01', 'From the dance description:  

This dance is a nautical allegory, which depicts an ocean voyage from the preparation of the two ships, the voyage itself crossing three oceans and encountering stormy weather, to the eventual safe return home.', 80, '84844/86846/82882/88888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14457, '2012-06-12 13:48:48.898407+00', '2022-02-15 15:52:02.440961+00', 'Galbraith Gold', 'GALBRAITH GOLD', 1, 32, NULL, 1, 3, 42, 2197, '2005-04-09', 'From the dance description:  

Devised for Ian and Ebba Galbraith, bastions of Berkhamsted Strathspey & Reel Club, to celebrate their Golden Wedding in Bovingdon, Hertfordshire on 9th April 2005. It was danced for the first time on that occasion.', 53, '800/888/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15491, '2014-06-27 21:00:09.455691+00', '2019-01-22 23:17:20.889318+00', 'Cold Night in February, A', 'COLD NIGHT IN FEBRUARY', 2, 32, NULL, 3, 5, 7, 10971, NULL, 'A typically Canadian title for a dance guaranteed to keep you warm.', 68, '80800/82842/88888/84844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15495, '2014-06-27 21:02:54.493388+00', '2019-01-22 23:29:09.148287+00', 'International Strathspey, The', 'INTERNATIONAL STRATHSPEY', 3, 32, NULL, 2, 3, 17, 10971, NULL, 'A dance dedicated to friends we have made through scottish country dancing in many countries.', 88, '888/880/888/848', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17919, '2017-08-09 12:19:19.321069+00', '2019-01-18 19:03:47.794393+00', 'Bracken on Broughton Moor', 'BRACKEN ON BROUGHTON MOOR', 1, 32, NULL, 1, 114, 11, 11237, '2017-01-01', 'The title comes from a trip back from Wasdale at New Year over Broughton Moor along a lonely road through acres of red/brown bracken, glowingly rendered in an impressionistic drawing by Ivan Cartwright.  Broughton, in Cumbria, rhymes with "Orton".', 94, '8888/8448/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18044, '2017-11-08 21:39:15.222582+00', '2019-01-18 19:33:19.257287+00', 'Stroller In Hades, A', 'STROLLER IN HADES', 1, 32, NULL, 1, 3, 42, 11237, '2014-03-01', 'This dance was inspired by “The Australian Ladies” with the aim of having equal amounts of right and left handedness in both the “signature” last 16 bars and also the first 16 which consequently ended up being very  different  from  the  original.  The  word  “Stroller”  in  the  title  contains  the  R,L,L,R 

sequence indicating the handedness of each successive four bars (for 1st couple).



After the second repeat, 1st couple dance bars 1-4 again with 4th couple to end in 4th place 

(although this does sadly break the otherwise equal amounts of left and right handedness). 

For mathematical completeness 3rd and 4th couples could also do this at the start so that all 

four couples are dancing at the start of the 1st, 3rd, 5th and 7th times through. 



', 62, '880/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19094, '2018-12-06 18:38:58.372785+00', '2019-01-19 14:00:28.124288+00', 'Priestgill', 'PRIESTGILL', 2, 32, NULL, 1, 3, 42, 3699, NULL, '', 63, '844/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16835, '2015-12-15 14:54:51.293654+00', '2019-01-19 17:43:50.653724+00', 'Reel Challenge, A', 'REEL CHALLENGE', 2, 32, NULL, 1, 3, 42, 11226, NULL, '', 38, '888/800/800/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9282, '2000-01-16 23:00:00+00', '2019-01-20 07:39:15.577201+00', 'September Strathspey', 'SEPTEMBER STRATHSPEY', 3, 32, 9999, 1, 2, 76, 684, '1999-07-01', '', -1, '88/44/88/80', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15496, '2014-06-27 21:03:40.319143+00', '2019-01-22 23:37:02.963217+00', 'November at Home', 'NOVEMBER AT HOME', 3, 32, NULL, 1, 3, 42, 10971, NULL, 'A dance whose purpose it is to think of something more than the weather.

', 63, '800/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19168, '2019-01-17 20:36:05.50245+00', '2019-01-22 00:29:56.725897+00', 'Call of the Island', 'CALL OF THE ISLAND', 3, 32, NULL, 1, 3, 42, 3618, NULL, '', 63, '800/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15485, '2014-06-27 20:56:42.759985+00', '2019-01-22 22:54:05.240256+00', 'Dancing in Dysart', 'DANCING IN DYSART', 2, 32, NULL, 1, 3, 42, 10971, NULL, 'The deviser''s ancestors were pioneers in Dysart Township, County of Haliburton, Ontario, in the 1860’s.



At the end of the second time through, 1st couple finish in third place. They step down to fourth place on the first two bars of the next time through as the 4th couple cross over diagonally into the middle of the dance in third place.', 63, '808/888/448/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19374, '2019-06-01 13:00:10.261736+00', '2019-06-01 13:00:10.261736+00', 'Urain Strathspey', 'URAIN STRATHSPEY', 3, 32, NULL, 1, 4, 1, 743, NULL, '', 94, '8888/8888/8888/0888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19162, '2019-01-17 10:55:06.509046+00', '2020-07-28 16:39:07.262148+00', 'Pat''s Delight', 'PATS DELIGHT', 3, 32, NULL, 2, 3, 17, 11772, '2002-01-01', 'For the occasion of Pat Kent receiving the RSCDS Scroll of Honour', 74, '800/888/888/843', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6558, '1997-09-16 22:00:00+00', '2020-08-07 09:49:28.563019+00', 'Thorntonian Jig, The', 'THORNTONIAN JIG', 2, 32, 9999, 1, 4, 1, 1020, '1967-01-01', 'The Thorntonian Jig was devised in 1967 to be danced at the October weekend camp in Sydney in the same year. (Name taken from Thornton Club).', 66, '8448/8888/8444/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (424, '1998-07-08 22:00:00+00', '2020-10-13 18:21:47.830095+00', 'Battle of the Shirts, The', 'BATTLE OF THE SHIRTS', 1, 32, 9999, 1, 100, 2, 678, NULL, '', 81, '8448/8888/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18943, '2018-10-12 14:05:30.288629+00', '2020-11-22 10:38:18.803804+00', 'Cambuslang Octogenarian, The', 'CAMBUSLANG OCTOGENARIAN', 1, 32, NULL, 1, 3, 42, 515, '1998-09-03', 'Dedicated to Charlie McGinley', 41, '800/800/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3697, '1997-09-07 22:00:00+00', '2020-12-08 22:55:38.507947+00', 'Lang May Your Lum Reek', 'LANG MAY YOUR LUM REEK', 2, 32, 9999, 1, 2, 76, 313, NULL, '', 60, '84  88  88  66', 1, 1, 0, 1, 87);
INSERT INTO 'dance' VALUES (13597, '2010-09-20 22:00:00+00', '2021-01-01 19:23:47.205992+00', 'David Queen Strathspey, The', 'DAVID QUEEN STRATHSPEY', 3, 32, 9999, 2, 3, 18, 3462, '2008-12-01', 'This dance was devised by Angela Bulteel in honour of David Queen, in recogniton of his relentless patience whilst teaching me the tourney, which is conspicuous by its absence in this dance.', 77, '848/848/846/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14194, '2011-08-26 22:00:00+00', '2021-01-04 12:15:09.995484+00', 'Amberley Court', 'AMBERLEY COURT', 3, 40, NULL, 1, 3, 42, 10433, '2003-01-01', 'Dedicated to Maretta Frolley, longtime friend who has been Assistant Secretary of the Melbourne and District Branch Inc. for a number of years. Maretta''s previous home was located in Amberley Court, Bulleen. I added bars 33 - 40 subsequent to devising the original 32-bar dance, but on the dance''s debut, Maretta told me that she had lived in Amberley Court for 40 years, so coincidentally the dance is ''one bar for every year''.', 77, '820/888/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19146, '2019-01-16 23:19:18.795423+00', '2021-04-02 20:45:56.375549+00', 'An'' ''t Were Na For the Lasses', 'AN T WERE NA FOR THE LASSES', 3, 32, NULL, 1, 4, 1, 11502, '2011-03-25', 'Dedicated to Allan Swanzey who especially loved to dance with the Lassies.', 36, '8200/8400/8400/8022', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19166, '2019-01-17 13:17:40.801136+00', '2021-11-08 19:07:35.700634+00', 'Dance of Love', 'DANCE OF LOVE', 3, 32, NULL, 2, 3, 18, 11345, '2018-01-01', '', 56, '888/880/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15510, '2014-06-27 21:12:53.412412+00', '2019-01-23 17:21:13.282257+00', 'Twin Cities Reel, The', 'TWIN CITIES REEL', 1, 32, NULL, 1, 2, 76, 10971, NULL, 'A “thank you” to the members, past and present, of the Kitchener-Waterloo Branch of the RSCDS

', 69, '88/88/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15507, '2014-06-27 21:10:54.55735+00', '2019-01-23 17:24:58.036886+00', 'Just for the Fun of It', 'JUST FOR THE FUN OF IT', 3, 32, NULL, 3, 5, 16, 10971, NULL, '', 70, '84848/80808/84848/40488', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15511, '2014-06-27 21:13:25.469843+00', '2019-01-23 17:29:37.289256+00', 'Conestoga Reel, The', 'CONESTOGA REEL', 1, 32, NULL, 1, 3, 42, 10971, NULL, 'The “Conestoga Wagon” played a significant role in the early history of the Waterloo region, which is the deviser''s home.

', 38, '880/800/808/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19328, '2019-05-12 08:58:55.074009+00', '2020-11-25 10:05:44.664899+00', 'Pickaquoy Reel, The', 'PICKAQUOY REEL', 1, 32, NULL, 3, 5, 7, 374, NULL, '', 57, '80800/88880/84844/80800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5644, '1997-04-03 22:00:00+00', '2022-11-12 18:46:23.270168+00', 'Rocks Of Solitude, The', 'ROCKS OF SOLITUDE', 3, 32, 9999, 1, 3, 42, 313, NULL, 'For Barbara Hallam, who was born in Glen Esk within a very short distance of the Rocks of Solitude which stand in the North Esk River.', 63, '880/880/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2199, '1998-07-09 22:00:00+00', '2023-01-27 20:20:36.023967+00', 'Fisher Blue', 'FISHER BLUE', 3, 32, 9999, 3, 5, 16, 108, '1991-02-01', 'The notes say this was "For a S.C.D. Weekend at the Waterside Inn, Inverugie, Peterhead".



"Fisher Blue" is the title of a poem by Peter Buchan - a Peterhead poet.', 85, '44844/88888/88888/86666', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (994, '1997-04-03 22:00:00+00', '2022-12-21 10:08:27.378352+00', 'Canongait', 'CANONGAIT', 4, 28, 9999, 3, 5, NULL, 128, NULL, 'It is quite obvious that the bar count is incorrect as the rest of the information might be. No information on this dance with the deviser mentioned can be found, last checked 2022-12-21. The editors'' team decided to keep the dance in the database for future reference in case some information may be added later.  

<<https://my.strathspey.org/dd/issue/1569/>> ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15522, '2014-06-27 21:19:18.660887+00', '2019-01-23 18:33:33.064558+00', 'Our Trip to Japan', 'OUR TRIP TO JAPAN', 1, 48, NULL, 1, 4, 1, 10971, NULL, 'To commemorate the wedding of Tara Scheurwater and Michael Carroll in Edmonton, Alberta.

', 48, '8000/8044/8844/4444/4444/8004', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1471, '1997-04-03 22:00:00+00', '2019-01-24 13:30:35.283856+00', 'Culbin Sands', 'CULBIN SANDS', 2, 32, 9999, 1, 3, 42, 313, NULL, 'The Culbin Sands are to the west of Findhorn Bay on the Moray Firth. This once fertile district was overwhelmed by sandstorms in the autumn of 1694. In recent years the Culbin Sands have been afforested with pine trees.', 62, '8440|8880|8800|8880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12884, '2006-10-10 22:00:00+00', '2019-01-24 13:33:31.949803+00', 'Hasten to Your Feet', 'HASTEN TO YOUR FEET', 2, 32, 9999, 2, 3, 17, 1268, NULL, 'Devised by Doug Schneider, St. Louis, Missouri ( paradiseMO [at] aol.com )



Notes from Doug: Dedicated to Bonnie Dickson of Ames, Iowa. The title is taken from a poem that Bonnie wrote about Scottish country dancing.', 67, '800/800/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12414, '2005-05-01 22:00:00+00', '2019-01-24 14:42:20.446547+00', 'Triskel, The', 'TRISKEL', 1, 32, 9999, 6, 3, 18, 2766, '2004-10-01', 'This dance and The Triquetra were inspired by a catalog of Irish gifts I received that had pictures of jewelry in the shapes of the triskel and the trinity celtic knot, aka the triquetra.', 88, '888/666/666/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13742, '2011-07-11 22:00:00+00', '2019-01-24 15:17:30.746574+00', 'Golden Apple Jig, The', 'GOLDEN APPLE JIG', 2, 40, NULL, 1, 3, 42, 2973, '2009-01-01', 'Devised in January 2009 to celebrate the 50th anniversary of the RSCDS New York Branch.', 50, '800/844/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18719, '2018-10-03 11:58:08.116643+00', '2019-01-26 06:08:09.670282+00', 'Crossing the Line', 'CROSSING THE LINE', 3, 32, NULL, 1, 100, 2, 2766, '2010-09-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10953, '2002-11-14 23:00:00+00', '2019-01-26 06:14:41.142111+00', 'Seagull''s Feast', 'SEAGULLS FEAST', 2, 32, 9999, 1, 2, 76, 1268, '1994-01-01', 'Beginner Level. 



Written by Doug Schneider in 1994 after observing some seagulls with a "lucky find" in a dumpster in the Kmart parking lot on Lake Street, Minneapolis, Minnesota. ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18002, '2017-10-11 13:11:03.038747+00', '2019-01-26 06:57:05.658327+00', 'Joyous Celebration, A', 'JOYOUS CELEBRATION', 3, 32, 9999, 2, 3, 18, 3179, '2017-03-20', 'Devised by Wouter Joubert in honour of Jonathan and Chevonne Womack''s Wedding.', 88, '884/844/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (523, '1998-11-22 23:00:00+00', '2019-01-26 07:09:17.366242+00', 'Birmingham Rant', 'BIRMINGHAM RANT', 1, 32, 9999, 1, 3, 42, 382, '1992-01-01', 'This is a long-way reel-time dance for three couples. A new top couple begins on every second repetition.', 69, '888  888  888  844', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (1414, '2000-10-13 22:00:00+00', '2019-01-26 16:29:24.028934+00', 'Crieff Jig, The', 'CRIEFF JIG', 2, 32, 9999, 1, 2, 76, 394, NULL, 'Suited for Jig as well as Strathspey time (stated explicitly in the description of the dance).



In the table of contents of the publication, the dance is erroneously spelled with one ''f'' only.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6582, '1999-05-09 22:00:00+00', '2019-01-26 22:14:16.538745+00', 'Three''s the Charm', 'THREES THE CHARM', 2, 32, 9999, 105, 53, 18, 1309, '1989-01-01', 'This dance was published in two forms, "original" and "variation".  The E-crib, Minicrib, Keith''s diagram and the formation list show the "variation", as that seems to be the more popular version.  The "SCDDB Contributed Crib" shows the "original" version, which differs on [1-16].', 71, '080/888/484/884', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10576, '2002-05-12 22:00:00+00', '2019-01-26 23:35:53.38655+00', 'Star Trek', 'STAR TREK', 2, 32, 9999, 1, 4, 13, 9998, NULL, '', 91, '8888/8888/8888/4448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15138, '2013-09-20 16:43:21.225274+00', '2019-01-27 00:01:30.200147+00', 'Mathematician, The', 'MATHEMATICIAN', 3, 32, 9999, 1, 4, 1, 3453, NULL, '', 91, '8888/8888/8888/4844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3834, '1999-11-01 23:00:00+00', '2019-01-27 19:57:22.62492+00', 'Linton Ploughman', 'LINTON PLOUGHMAN', 2, 32, 9999, 1, 2, 76, 9998, NULL, 'This dance is almost identical to <<http://my.strathspey.org/dd/dance/3834/|The  Blue Loch>> by <<http://my.strathspey.org/dd/person/872/|Marilyn Watson>>, but ending with a Poussette instead of an Allemande.', 60, '88  88  80  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (7180, '2000-02-21 23:00:00+00', '2019-01-27 20:09:59.428344+00', 'Wind on Loch Fyne, The', 'WIND ON LOCH FYNE', 3, 32, 9999, 6, 3, 17, 101, '1986-01-01', 'Loch Fyne extends north from the Sound of Bute and, at 65 kms, is the

longest »sea loch« on the west coast of Scotland. It is noted for its

oyster and herring fisheries, with Loch Fyne kippers widely considered

the best available. During World War II Loch Fyne served as a training

ground for the Normandy landings. Later on it was used by the Royal

Navy to test torpedoes. Beside the herrings and oysters, Loch Fyne is

home to wild life such as otters, dolphins, seals, and (in summer)

basking sharks.



The name »Loch Fyne« derives from the Gaelic for »Loch of the Wine (or

Vine)«, even though there is no evidence of grapes growing in the area.

', 83, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (11929, '2004-12-06 23:00:00+00', '2020-06-27 21:42:14.360294+00', 'Heptathlon Jig, The', 'HEPTATHLON JIG', 2, 32, 9999, 107, 112, 85, 3478, '2003-01-01', 'Dance for 7 people.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19141, '2019-01-08 15:27:46.842784+00', '2020-08-25 18:52:33.994414+00', 'Chain Lynx', 'CHAIN LYNX', 1, 32, NULL, 1, 3, 42, 11035, NULL, '', 50, '880/633/633/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19164, '2019-01-17 11:10:44.731837+00', '2020-07-22 22:06:15.135814+00', 'Turn for the Better, A', 'TURN FOR THE BETTER', 3, 32, NULL, 2, 3, 17, 11773, NULL, '', 83, '888/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18318, '2018-05-02 18:15:40.459949+00', '2020-11-15 11:52:59.345884+00', 'Issy and Nicol''s Dance', 'ISSY AND NICOLS DANCE', 1, 32, NULL, 1, 3, 42, 11139, '2014-01-02', 'The dance was written during the 2013/2014 New Zealand Branch Summer School in Cambridge, for Isobelle (Issy) Hodgson and Nicol McLaren, two of the fabulous and talented musicians who performed numerous times during the school.', 50, '880/880/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9824, '2001-04-25 22:00:00+00', '2021-02-19 14:44:13.827379+00', 'Toast to the Lassies', 'TOAST TO THE LASSIES', 4, 64, 17, 6, 3, NULL, 165, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8352, '2002-06-03 22:00:00+00', '2021-03-20 12:52:57.915521+00', '4007', '4007', 3, 32, 9999, 1, 2, 76, 108, '1996-01-01', 'The dance is intended to be pronounced: ''For 007''.



The dance was written by John Drewry for his good friend, Paul Bond aka ''Bond, Paul Bond'', hence the title ''For 007''.', 60, '80/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18708, '2018-10-03 00:57:48.217369+00', '2021-06-06 19:36:21.565797+00', 'Chasing the Red Dot', 'CHASING THE RED DOT', 1, 32, NULL, 3, 5, 41, 2766, '2010-05-01', 'This dance is for our cat, Edwin, who loves to chase the red dot from the laser pointer cat toy.', 78, '80008/88888/88888/84646', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15512, '2014-06-27 21:13:54.562812+00', '2019-07-24 11:21:09.038164+00', 'Copenhagen Reel, The', 'COPENHAGEN REEL', 1, 32, NULL, 1, 3, 42, 10971, NULL, 'Devised while travelling in Denmark.



', 56, '880/888/888/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14817, '2013-04-29 13:59:43.367604+00', '2019-01-28 23:11:23.726729+00', 'Subarashii Saitama Strathspey', 'SUBARASHII SAITAMA STRATHSPEY', 3, 32, NULL, 4, 4, 13, 2887, '2010-09-01', '', 81, '8000/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19170, '2019-01-28 21:36:08.997489+00', '2019-01-28 23:29:09.900506+00', 'Exeter''s 50th', 'EXETERS 50TH', 2, 32, NULL, 1, 3, 42, 3316, NULL, 'To commemorate the 50th Anniversary of RSCDS Exeter Branch which was founded in 1969.', 56, '800/866/866/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17683, '2017-03-31 09:15:34.823027+00', '2019-02-11 10:22:01.186797+00', 'Outpost, The', 'OUTPOST', 1, 32, 9999, 1, 4, 1, 10397, NULL, 'Devised by Rob Kinnon-Brettle.



The Gay Gordons (Manchester) started classes in the back bar of the Outpost, now demolished. The dance started life as a training dance for a number of Scottish Country Dancing figures.', 45, '8600/8440/8022/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19187, '2019-02-18 00:14:41.197549+00', '2022-04-26 01:33:41.291321+00', 'Ruby Celebration Strathspey, The', 'RUBY CELEBRATION STRATHSPEY', 3, 32, NULL, 2, 3, 18, 3183, '2018-04-01', 'Devised by Anne Thorn in April 2018 for the 40th Helensburgh Weekend School.', 77, '828/484/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (834, '1997-08-31 22:00:00+00', '2023-02-21 13:26:08.333268+00', 'Kildrummy Castle', 'KILDRUMMY CASTLE', 1, 32, 9999, 1, 3, 42, 109, '1981-01-01', '"Dedicated to Sam Firth and his class in Sheffield, 1981."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18946, '2018-10-12 14:29:33.613256+00', '2019-01-28 23:49:27.071321+00', 'Rosss''s Reel', 'ROSSSS REEL', 1, 32, NULL, 1, 3, 42, 11035, NULL, 'This dance was devised in memory of Ross Edwards, who died in November 2016.



Cath, Ross’s wife, had great trouble at times dancing with his freespirited approach on the dance floor and sometimes had to take him in hand for a few quiet words.



His naughty ways were loved by many and we miss him dearly. Not many dancers could get away with this approach to Scottish Country dancing but Ross, with his twinkling eyes, could. Like a box of chocolates, you never knew when you danced with Ross quite how it would turn out.



Damon Collin has named the first formation “The Rosss”



The Reel in this dance is an example of what he got up to.



The extra ssss in the title are because when Ross emailed me he often signed off with:

   Rossss staff to Catherine, or

   Rossss on behalf of she who should be obeyed, another one was,

   Rossss secretary to Catherine E Edwards, or just

  Staffee



No longer with us in person, but always in spirit, R.I.P dear Ross.', 44, '660/660/888/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19110, '2018-12-06 23:43:19.611433+00', '2019-01-29 00:09:02.778165+00', 'On the Farm', 'ON THE FARM', 3, 32, NULL, 1, 3, 42, 640, '2008-01-01', '', 63, '880/888/888/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18983, '2018-10-17 12:28:38.371184+00', '2019-01-29 00:20:04.944001+00', 'Brian and Alice Arrowsmith', 'BRIAN AND ALICE ARROWSMITH', 1, 32, NULL, 1, 3, 42, 10435, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19171, '2019-01-29 12:07:19.593904+00', '2019-01-29 12:07:19.593904+00', 'Twelve 1314', 'TWELVE 1314', 4, 128, 2, 101, 6, 86, 11776, NULL, 'An adaptation of John Drewry''s <<ddd:1314>> for six couples (12 people) in a hexagonal set.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17500, '2016-12-31 00:45:47.063104+00', '2019-01-29 18:41:13.384111+00', 'Gypsy Thread, The', 'GYPSY THREAD', 2, 32, NULL, 3, 5, 16, 9998, NULL, 'Can also be danced with 4 couples', 80, '88888/88888/88888/80000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19175, '2019-01-29 23:11:50.732972+00', '2019-01-29 23:11:50.732972+00', 'Noethersche Ringlein, Das', 'NOETHERSCHE RINGLEIN', 3, 32, NULL, 1, 3, 42, 11777, '1999-11-19', 'This dance is a simpler variant of Der Noethersche Ring. Both dances were written in honor of the mathematician Emmy Noether, who loved to dance. Noether was born in Erlangen on March 23, 1882 at Hauptstrasse 23. The mathematical definition of a Noetherian Ring is that it is a ring where every ascending chain of ideals terminates. From this definition, the dance wrote itself.





', 63, '888/844/880/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12771, '2006-05-31 22:00:00+00', '2019-02-07 00:01:45.077924+00', 'Jig for Rebecca, A', 'JIG FOR REBECCA', 2, 32, NULL, 1, 4, NULL, 370, '2000-05-01', 'For Rebecca Appleyard on her 11th birthday, 20th March, 2003.



This dance may be for 3 or 4 couples.', 67, '800/888/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19172, '2019-01-29 22:52:18.203945+00', '2019-01-29 22:52:18.203945+00', 'Audrey''s Zeta Zoo', 'AUDREYS ZETA ZOO', 1, 32, NULL, 2, 3, 30, 11777, '2002-01-01', 'Devised in the summer of 2002 in honor of mathematician Audrey Terras.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19173, '2019-01-29 22:56:56.694165+00', '2019-01-29 22:56:56.694165+00', 'Ceilidh Dance, The', 'CEILIDH DANCE', 1, 32, NULL, 1, 3, 42, 2031, '2001-01-01', 'Devised in memory of a cat called Ceilidh.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19176, '2019-01-29 23:16:14.857368+00', '2019-01-29 23:16:14.857368+00', 'Artinsche Ring, Der', 'ARTINSCHE RING', 2, 32, NULL, 1, 3, 42, 11777, '1999-11-19', '', 59, '888/840/844/888', 1, 0, 1, 0, -1);
INSERT INTO 'dance' VALUES (9558, '2000-08-06 22:00:00+00', '2019-01-30 16:54:16.97259+00', 'Haggis Hunt, The', 'HAGGIS HUNT', 1, 40, 9999, 1, 3, 42, 2030, '1998-01-01', 'This dance was written a day before the Burns Supper in January 1998 in Lindelbach, a small village near Würzburg. A day later the haggis was caught, slaughtered and consumed...



The original URL (http://mitglied.lycos.de/ErlangenScotDance/links/dances.html#Dance6) is now defunct.', 61, '800/888/888/888/477', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19148, '2019-01-16 23:30:45.417994+00', '2020-07-20 07:52:57.06754+00', 'Bill Nauss of Boulder Bay', 'BILL NAUSS OF BOULDER BAY', 1, 32, NULL, 1, 3, 42, 11356, '2009-12-04', 'Devised by Lydia Hedge - a birthday gift for Bill Nauss - December 4th, 2009.  



1-8 The two loops of the letter B  

17-20 The letter N', 45, '800/800/855/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14785, '2013-04-05 13:35:55.680728+00', '2020-10-01 11:48:49.286958+00', 'Mirror Madness', 'MIRROR MADNESS', 1, 32, NULL, 1, 4, 1, 10766, NULL, '(32 bar reel, jig or strathspey for four couples in a four couple longwise set)



Suggested Recorded Music:



Reel: ''The Acklam Reelers'', from ''The Vallin Suite 2'', played by David

Cunningham and his Scottish Dance Band



Jig: ''lt Should be Fun'', from'' Reel On'', played by Muriel Johnstone and Jim

Lindsay.



Strathspey: ''Fill the Fetters'', from ''Celebrate 50 Years of Dancing with the Boston

Branch RSCDS'', played by Tullochgorum.', 56, '8000/8880/8224/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14371, '2011-12-16 23:00:00+00', '2020-09-27 09:24:01.346041+00', 'Chopped Nuts and Chocolate Swirls', 'CHOPPED NUTS AND CHOCOLATE SWIRLS', 2, 32, NULL, 2, 3, 17, 10591, NULL, '"Top Rated Jig"



Explanation

01-08 chopped nuts

09-24 chocolate swirls

25-32 chopped nuts

', 56, '880/844/888/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12108, '2005-03-22 23:00:00+00', '2021-01-15 20:56:21.029659+00', 'Isabella''s Travels', 'ISABELLAS TRAVELS', 1, 32, 9999, 4, 4, 13, 3523, '2004-01-01', '', 88, '8888/4444/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8627, '2002-02-26 23:00:00+00', '2021-03-16 10:11:31.910292+00', 'Maypole Medley, The', 'MAYPOLE MEDLEY', 4, 64, 17, 4, 4, 4, 2030, NULL, 'The original URL (http://mitglied.lycos.de/ErlangenScotDance/links/dances.html#Dance1) is now defunct.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7558, '2002-11-18 23:00:00+00', '2021-08-02 08:27:19.863283+00', 'Up the Pond', 'UP THE POND', 2, 32, 9999, 1, 3, 42, 452, '1994-01-01', '', 44, '880/880/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6131, '2000-08-06 22:00:00+00', '2021-04-14 11:35:09.143182+00', 'Irish Romance', 'IRISH ROMANCE', 3, 32, 9999, 1, 3, 42, 2782, NULL, 'This dance is a simpler version of the <<ddd:Romance in Ireland>> by <<ddp:Barthel, Stefan>>. <<ddp:Gilliam, David>> learned it in Paris (Thanks to <<ddp:Chamoin, Patrick>>, who saw it at our ball in Erlangen in 1996, but let''s keep the story short...) and he taught it at classes and workshops during the summer and fall of 1997 in America. He decided to make this version more suitable for a bit less experienced dancers by changing bars 9 to 24. It sure takes less time to teach it and make the dancers move. 



The original URL (http://mitglied.lycos.de/ErlangenScotDance/links/dances.html#Dance3) is now defunct.', 47, '800/822/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9408, '2001-06-12 22:00:00+00', '2019-01-31 13:11:07.802427+00', 'St Margaret Queen of Scotland', 'SAINT MARGARET QUEEN OF SCOTLAND', 3, 32, 9999, 1, 4, 1, 2742, '1993-01-01', 'Devised by Dorothy Leurs, Edinburgh, in 1993 for the St. Margaret''s Chapel Guild at Edinburgh Castle

to celebrate the 900th anniversary of the death of St. Margaret, Queen of Scotland 1058- 1003.



The figures of the dance represent the King (Malcolm Canmore) presenting his Queen to the people, crossing the River Forth at Queensferry (named after Margaret), taking the relics to St. Andrews and the cross of St. Andrew.



Note: The title uses "St" and not "Saint".', 72, '8004/8440/8888/8888', 0, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (19179, '2019-01-31 22:24:26.551213+00', '2019-01-31 22:38:06.723659+00', 'Birthday Teaching', 'BIRTHDAY TEACHING', 3, 32, NULL, 1, 3, 42, 3135, '2009-11-05', 'Written for Monica Ferguson, who, on her birthday, 5th november 2009, found herself teaching the White Heather SCD group in Geldermalsen.

', 37, '800/844/044/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18760, '2018-10-05 06:24:20.348323+00', '2019-01-31 23:30:34.938394+00', 'Fly the W', 'FLY THE W', 1, 32, NULL, 3, 5, 7, 2766, '2016-11-01', 'This dance is written to celebrate the Chicago Cubs winning the 2016 World Series – their first such win in 108 years.', 76, '80800/88888/86846/86866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14287, '2011-10-26 22:00:00+00', '2019-02-01 09:33:39.189253+00', 'Poohsticks', 'POOHSTICKS', 2, 40, 9999, 1, 4, 2, 10495, '2008-06-01', 'As music the author suggests "any lively jig".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1784, '2006-03-07 23:00:00+00', '2019-02-02 20:03:26.235645+00', 'White Rose and the Yellow Waistcoat, The', 'WHITE ROSE AND THE YELLOW WAISTCOAT', 1, 32, 9999, 1, 3, 42, 370, '2004-01-01', 'To celebrate our Ruby Wedding Anniversary, December, 2004', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16827, '2015-12-11 13:48:59.880575+00', '2019-02-01 15:26:58.871269+00', 'Hooked on Bells', 'HOOKED ON BELLS', 2, 32, NULL, 1, 4, 2, 3593, '2015-08-01', 'Dance devised by Irene Paterson with music composed by Calum MacKinnon for Rachel Pusey and Dilip Sequeira when they left Seattle.



The dance name is a very clever play on words, the details of which Irene has kindly explained.  Because this departing dancer was quite involved in bell-ringing, she was thereby "hooked" on bells.  But that''s not all:  she is also an avid crocheter, and thus there is a double entendre for the word "hooked."  Furthermore the slip-knot figure, not a very common one in SCDs but included in this dance, names also with its double meaning the initial stitches for starting a crocheting project.



This same video is also accessible on Facebook at https://www.facebook.com/rscdsseattle/videos/996978727010425/', 75, '8008/8888/8888/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11464, '2003-09-22 22:00:00+00', '2019-02-01 15:47:10.521119+00', 'Wooden Sawhorse, The', 'WOODEN SAWHORSE', 1, 32, 9999, 1, 3, 42, 2766, '2002-04-01', 'Ozma created the Wooden Sawhorse from a log and branches, then brought him to life with a magic powder. He is a tireless steed and often takes people to locations in Oz by pulling the red wagon carrying them.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5936, '1998-04-19 22:00:00+00', '2019-02-02 15:34:19.09403+00', 'Scotland''s Gardens', 'SCOTLANDS GARDENS', 1, 32, 9999, 1, 3, 42, 146, '1991-01-01', 'The dance "Scotland''s Gardens" has been devised by Roy Goldring to mark the Diamond Jubilee of Scotland''s Gardens Scheme 1931-1991.', 62, '888  844  888  844', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (19181, '2019-02-02 20:24:50.640133+00', '2019-02-02 20:24:50.640133+00', 'Kate''s Day', 'KATES DAY', 1, 32, NULL, 5, 2, 76, 3325, '2011-04-01', 'Dance devised for and first performed at a street party in Denford Village to celebrate Catherine Middleton''s wedding to HRH Prince William on 29th April 2011', 88, '88/88/44/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3241, '2001-01-15 23:00:00+00', '2019-02-03 00:19:00.733835+00', 'Jessie Stewart''s Strathspey', 'JESSIE STEWARTS STRATHSPEY', 3, 32, 9999, 1, 4, 2, 371, '1982-01-01', 'Fondly dedicated to the memory of my mother-in-law, Jessie Atwood Stewart, who, while not a country dancer herself, received much pleasure from our interest in Scottish Country Dancing, during the last few years of her life: Ben Stein', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2797, '1997-04-03 22:00:00+00', '2019-02-03 07:42:44.020402+00', 'Harold Stewart''s Reel', 'HAROLD STEWARTS REEL', 1, 32, 9999, 1, 4, 2, 371, NULL, '', 86, '8888/8888/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18307, '2018-04-25 22:33:37.767426+00', '2019-02-03 21:42:10.885451+00', 'Bell Rock Strathspey, The', 'BELL ROCK STRATHSPEY', 3, 32, NULL, 2, 3, 17, 11631, '2017-08-01', 'Devised while on a family holiday at St Andrew’s Summer School in 2017, staying in a cottage overlooking Bell Rock.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3851, '1997-04-03 22:00:00+00', '2019-02-03 07:54:21.812076+00', 'Liza Davidson''s Rant', 'LIZA DAVIDSONS RANT', 2, 32, 9999, 1, 3, 42, 371, NULL, '', 59, '800/880/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2141, '1997-09-02 22:00:00+00', '2019-02-22 22:00:50.13914+00', 'Fiddlehead Feast', 'FIDDLEHEAD FEAST', 1, 32, 9999, 1, 4, 1, 90, NULL, '', 63, '8888/8000/8440/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17425, '2016-10-21 09:46:59.652043+00', '2019-02-23 19:07:00.720159+00', 'Fortieth Anniversary', 'FORTIETH ANNIVERSARY', 1, 32, NULL, 3, 5, 7, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12381, '2005-04-28 22:00:00+00', '2020-10-11 17:08:35.401787+00', 'Road to Ronda, The', 'ROAD TO RONDA', 3, 32, 9999, 1, 100, 2, 3589, NULL, '', 72, '8008/8448/8888/8228', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9752, '2000-12-14 23:00:00+00', '2021-02-20 21:15:15.991537+00', 'Caper for Priscilla, A', 'CAPER FOR PRISCILLA', 1, 40, 9999, 2, 3, 18, 118, '1992-11-01', 'Devised by Ernst Eder in November 1992, after dancing "<<ddd:Mrs. Watt''s Teakettle#4815>>" (devised by Priscilla Burrage and published in her booklet "Kitchen Capers") at the 1992 Vermont Harvest Festival, Old Lantern, Charlotte, VT.', 50, '880/444/888/444/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5568, '1998-11-02 23:00:00+00', '2021-04-24 09:44:14.188435+00', 'Rideau Reel, The', 'RIDEAU REEL', 1, 40, 9999, 1, 4, 1, 394, '1982-01-01', 'Devised in 1982 by John Trew for Catherine and Donald Cutts on the occasion of their 25th Wedding Anniversary Catherine was at that time President of the Rideau Trail Association.', 62, '8000/0880/8888/8888/8220', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19180, '2019-02-01 16:15:22.103406+00', '2021-02-20 12:48:56.346295+00', 'Dance for Susana, A', 'DANCE FOR SUSANA', 3, 32, NULL, 6, 3, 18, 3325, '2015-02-01', 'The dance was devised for Susana Page of the Schiehallion Dancing Group (Madrid) on the occasion of her passing Part 2 of the RSCDS Teaching Examination at St Andrews Summer School in August 2014', 88, '822/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7576, '2002-03-11 23:00:00+00', '2021-03-24 11:31:33.474846+00', 'Horton''s Fancy', 'HORTONS FANCY', 1, 48, 9999, 1, 4, 2, 127, NULL, 'Devised for David and Cally Horton on the occasion of their marriage.', 83, '8228/8888/8888/8888/8448/8228', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18801, '2018-10-05 15:38:33.077799+00', '2019-02-03 21:08:20.166272+00', 'Just As Crazy As It Looked', 'JUST AS CRAZY AS IT LOOKED', 2, 32, NULL, 1, 3, 42, 2766, '2016-03-01', 'We looked out one morning to see a police car parked in front, a neighbor from 3 doors left picking up pieces of his mailbox, and a car in our right-hand neighbor’s driveway that had hit his car parked there and had at least one flat tire. Someone driving got confused and turned into the side street leading to our street, hit the curb, a mailbox, and a car on that street then turned right by driving over the corner lot and hitting a tree on the other side of the street. He continued on our street running up on the curb, wiping out a mailbox and driving over the corner of our lot into our neighbor’s driveway and into his car (we are in a cul-de-sac). It was freaky, but the person was OK and everyone recovered from it eventually.', 69, '888/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12777, '2006-06-14 22:00:00+00', '2019-02-03 21:43:07.014489+00', 'New River Reel, The', 'NEW RIVER REEL', 1, 32, 9999, 1, 3, 42, 2245, NULL, 'Recommended recorded music: “Feisty Women” from *Catch the Wind* by The Music Makars.  



This dance was devised to assist teaching beginners where their corners are.  



Originally published in The Flying Ghillies Collection, Volume 2. This version has been revised to clarify the devisors’ intent for bars 1-8 and 17-24.', 44, '800/800/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16956, '2016-05-27 21:29:07.41443+00', '2019-02-19 23:09:42.60486+00', 'Deliberate Mistake, A', 'DELIBERATE MISTAKE', 2, 32, NULL, 1, 3, 42, 11236, '2015-05-01', 'Note: On bars 25-32, 2nd and 3rd man may not give hands to let an empty space between them, thus allowing the circle to be bigger and letting 1st man perform some setting or highland step if he wishes to. This is however not necessary.



This dance was devised for David Quarrie, who likes to refer to his (rare) mistakes as "deliberate". It should allow him to make some actually deliberate mistakes without any shame.

', 50, '800/888/800/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14155, '2011-08-26 22:00:00+00', '2022-12-18 16:39:19.124931+00', 'By the Way', 'BY THE WAY', 1, 48, NULL, 1, 4, 1, 370, '1994-01-01', 'For Keith’s 50th birthday 1994', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7296, '2006-03-07 23:00:00+00', '2019-02-04 09:57:20.858564+00', 'Rossway', 'ROSSWAY', 3, 32, NULL, 2, 3, 17, 370, '2005-06-01', '', 90, '888 /880 /886 /888', 1, 1, 1, 1, 89);
INSERT INTO 'dance' VALUES (18513, '2018-08-21 09:12:00.285406+00', '2019-02-04 10:40:43.030271+00', 'Walnut Cake, The', 'WALNUT CAKE', 2, 32, NULL, 1, 3, 42, 11509, '2018-02-01', 'This dance was devised to teach the formation half rights and lefts on the diagonal.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19182, '2019-02-04 14:29:30.085539+00', '2019-02-04 14:29:30.085539+00', 'Happy Memories', 'HAPPY MEMORIES', 2, 40, NULL, 107, 4, NULL, 3325, '2007-03-01', '4 couple trapezoidal set.  To commemorate the 50th anniversary of the SE Herts SCD Society founded in 1958.  The unusual shape reflects the floor plan of The Castle Hall, Hertford where many annual balls had been held.', 76, '8444/8484/6844/8888/8088', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4933, '2002-02-27 23:00:00+00', '2019-02-05 11:28:46.168732+00', 'New Virginia Reel, The', 'NEW VIRGINIA REEL', 1, 128, 9999, 4, 4, 3, 181, NULL, 'Dedicated to Genie Callander Sharp, founder of the Northern Virginia Branch.





The following corrections were included on a loose sheet "Notes on Dances by Bob Grant June 1996", when Book 39 was first sold in the Summer School bookshop:



Fig 1.  17-32  Slip in a curve so that start and finish are centred



Fig 3.  1-8  Dancing couples need to "cheat" here and meet to start going round the side couples', 69, '8888  8888  8080  0808  4444  8888  4444  8888    8080  8080  0808  0808    4444  4444  8888  8888', 1, 1, 1, 1, 17);
INSERT INTO 'dance' VALUES (16052, '2015-02-13 15:07:28.885255+00', '2019-09-08 11:02:59.888005+00', 'Thank You Jack', 'THANK YOU JACK', 2, 40, NULL, 1, 4, 2, 11078, '2011-06-19', 'Written to honor Jack Pollock retiring from many years teaching  the Asheville, NC Scottish country dance class.  



Devised: 7/28/10 and published in "The Petronella Paper" (May-August 2010) of the Atlanta Branch.



Revised 6/19/11 and republished in the "Spring Creek Collection"', 67, '4884/8228/8888/8008/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15129, '2013-09-20 14:47:22.130508+00', '2019-09-16 18:12:37.743283+00', 'Dance for Misato, A', 'DANCE FOR MISATO', 2, 32, 9999, 1, 4, 1, 10715, NULL, 'Devised: 2007', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8243, '1998-01-06 23:00:00+00', '2019-02-25 22:43:07.848778+00', 'Fingal''s Cave', 'FINGALS CAVE', 3, 40, 9999, 1, 4, 2, 1110, '1991-06-01', 'Fingal''s Cave is a mass of jet black rock on the Island of Staffa, west of Mull.', 76, '8222/8888/8668/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7544, '2001-11-28 23:00:00+00', '2020-12-18 20:48:52.542753+00', 'Traquair House', 'TRAQUAIR HOUSE', 1, 48, 9999, 1, 4, 1, 1827, NULL, '', 100, '888  888  888  888  888  888', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (17218, '2016-09-03 17:00:46.447055+00', '2020-10-24 09:41:13.731773+00', 'Ropemakers Reel, The', 'ROPEMAKERS REEL', 1, 32, NULL, 1, 4, 1, 10995, NULL, '', 78, '8484/8484/8484/8686', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (875, '1997-04-03 22:00:00+00', '2020-11-30 10:20:14.250272+00', 'Burning The Water', 'BURNING THE WATER', 1, 32, 9999, 3, 5, 7, 13, NULL, '', 88, '88880/82842/88888/80800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7826, '1998-01-15 23:00:00+00', '2021-03-23 20:15:35.528013+00', 'Merry Ploughboy, The', 'MERRY PLOUGHBOY', 1, 32, 9999, 1, 3, 42, 313, NULL, '', 47, '800/844/844/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12790, '2006-06-22 22:00:00+00', '2021-01-09 10:31:20.298124+00', 'Jahrzehnt, Das', 'JAHRZEHNT', 2, 40, 9999, 1, 3, 42, 3690, '2004-01-01', 'The "Spelling Alias" "Jahrzent, Das" has been made only because this erroneous spelling has been used for a long time both on DanceData and in Eric''s cribs.  It is _not_ an official alias.



10 bar phrases.', 61, '10 10 0    9 9 0    10 10 10    10 10 10', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (7318, '2006-03-23 23:00:00+00', '2021-03-27 15:57:14.156251+00', 'Alexander''s Link', 'ALEXANDERS LINK', 2, 32, 9999, 3, 5, 55, 3665, NULL, 'The original instructions note that the Lincoln Alexander Parkway is a busy traffic corridor which connects the west and east ends of greater Hamilton along the top of the Niagara Escarpment. It is known locally as "The Link".', 63, '84448/88088/80808/04480', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6380, '2002-02-27 23:00:00+00', '2021-04-12 22:03:36.678056+00', 'Summer Assembly, The', 'SUMMER ASSEMBLY', 1, 88, 9999, 4, 4, 3, 146, '1985-01-01', 'Devised as a tribute to the annual RSCDS Summer School in St Andrews.', 68, '7777  7777  7777  7777  8080  0808  4444  4444  8080  0808  8888', 1, 1, 0, 1, 68);
INSERT INTO 'dance' VALUES (12243, '2005-04-19 22:00:00+00', '2019-02-06 00:50:25.462678+00', 'Arctic Circle, The', 'ARCTIC CIRCLE', 1, 64, 9999, 4, 4, 3, 108, '2004-06-01', 'Dance devised by John Drewry April 2004.  Revised in June 2004 after teaching the dance in Morland in Cumbria.



NOTE by John Drewry: I had a letter from Susan Hagen, who lives in Oslo, requesting a dance with this title. The dance is to be performed at a ball in the British Ambassador''s Residence in October. She sent me a booklet about the residence, which is called "Villa Frognæs". I have based Bars 41-56 of the dance on the design above the oriel window. I did go once north of the Arctic Circle in Norway with a Swiss friend. We flew separately to Oslo and then went by train to Narvik. From there we went by cargo boat northwards until, after calling in various ports, we rounded the North Cape and reached Honningsvåg where we stayed for a few days.



We were amused to see people from the various tourist ships taken to see a Lappish village with the Lapps living in tents made of reindeer skin. Once the buses had taken the tourists back to their ships, the Lapps returned to their comfortable houses in the town.



NOTE by James Gray about the music: “The Oslo Scottish Country Dance Group asked John Drewry to write a dance called The Arctic Circle which had its premiere in Villa Frognæs, the residence of the British ambassador in Oslo. The tune has specially constructed phrasing to fit the dance.”

', 75, '8888  8080  8888  0808  8888  4444  4444  8888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14420, '2012-04-29 09:13:47.162064+00', '2019-02-06 00:51:30.585355+00', 'Love to Lois', 'LOVE TO LOIS', 3, 32, NULL, 2, 3, 17, 10615, '2003-02-01', 'Dedicated to Lois Simpson, first life member of the Tokoroa SCD club, who recently passed away.

Recommended recording: Strathspey (Bobby Brown and The Scottish Accent, Grandfather Mountain Gala) ', 98, '886  12 12 12  444  888', 1, 1, 1, 1, 97);
INSERT INTO 'dance' VALUES (7785, '1998-01-07 23:00:00+00', '2019-02-20 22:38:38.805391+00', 'Macraes, The', 'MACRAES', 2, 40, 9999, 1, 3, 42, 10606, '1992-02-01', 'The dance was devised by Marjorie Duffield''s pupils, who were not named in the information we received.



Devised to celebrate Marjorie Duffield''s marriage to Brian Macrae on 29 February, 1992. 



The dance was first named "Marjorie and Brian", written by some as "Marjorie & Brian".', 40, '800/800/844/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18330, '2018-05-04 21:50:14.454426+00', '2019-02-19 15:48:24.607597+00', 'Hillpark', 'HILLPARK', 3, 40, NULL, 1, 100, 2, 3699, '2011-01-01', 'Glasgow General Class meets at Hillpark Secondary School', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19383, '2019-06-02 12:33:48.24317+00', '2019-06-02 12:33:48.24317+00', 'Jack Daniel''s Waltz', 'JACK DANIELS WALTZ', 5, 64, NULL, 4, 4, 14, 11815, '2015-01-01', '', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4601, '2002-03-03 23:00:00+00', '2022-11-27 17:29:34.766139+00', 'Misses Cramb of Linlithgow, The', 'MISSES CRAMB OF LINLITHGOW', 2, 32, 9999, 2, 3, 17, 91, '1974-01-01', 'The »Misses« in question were the dance author''s granddaughters.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18003, '2017-10-12 10:04:57.389075+00', '2019-02-06 00:52:27.239945+00', 'J-P', 'JP', 2, 32, 9999, 1, 3, 42, 3254, '2016-06-01', 'In memory of Jean-Paul (J-P) Genot (13 August 1949 — 30 November 2013): friend, Scottish Country dancer and former colleague and mentor.

Jean-Paul Genot grew up in what was then the Belgian Congo (now the Democratic Republic of Congo). He came to South Africa to study at the University of Natal (now the University of KwaZulu-Natal) in Durban and then moved to Pretoria to work at the University of South Africa (Unisa) Library. 

When I started work as a librarian at Unisa in 1979, he was my supervisor and mentor. 

He later moved back to Durban to work at the Technikon Mangosuthu (now the Durban University of Technology). 

In the early 1990s he and his wife and their two daughters moved to Europe. 

While working for a library systems company, he spent some time in Jerusalem, Israel. 

While there, he took up Scottish Country Dancing at the St Andrews Presbyterian Church. 

After moving to Frankfurt, Germany, to work for the European Central Bank, he danced with the Frankfurt SCD Club. 

Whenever he came to South Africa to visit his in-laws and friends, he came to see me at the Library for coffee and a chat. 

On 30 November 2013, at the age of 64, he lost his battle with cancer. Sadly, I never had the chance to dance with him.



J-P, this one''s for you. Merci beaucoup.', 75, '880/888/844/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19183, '2019-02-08 11:30:36.908619+00', '2019-02-08 11:37:43.846473+00', 'Ebb and Flow', 'EBB AND FLOW', 2, 32, NULL, 1, 3, 42, 11778, '2019-02-08', '', 53, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5498, '1997-04-03 22:00:00+00', '2019-02-08 17:20:09.078002+00', 'Red Lion Of Stow, The', 'RED LION OF STOW', 2, 32, 9999, 1, 4, 1, 259, NULL, '', 100, '8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19012, '2018-10-19 13:45:35.543104+00', '2019-02-09 17:49:02.798398+00', 'Water Ways', 'WATER WAYS', 3, 48, NULL, 1, 100, 13, 11735, '2018-03-01', 'Written in memory of Roger Withenshaw and his love of narrowboat holidays.



Interpretation:  

1-8 casting off from mooring  

9-16 turning paddles at lock gates  

17-24 journey along the canal  

25-32 descending staircase flight of locks  

33-40 mooring and securing ropes  

41-48 raise your glass (with partner) as sun sets (small circles)  ', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18565, '2018-09-09 19:54:36.737586+00', '2019-09-02 11:13:32.455028+00', 'Meols Reel, The', 'MEOLS REEL', 1, 32, NULL, 1, 3, 42, 11000, NULL, '', 56, '844/844/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19757, '2019-10-29 11:02:24.006548+00', '2019-10-29 11:02:24.006548+00', 'William Tait', 'WILLIAM TAIT', 2, 32, NULL, 1, 3, 42, 10466, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6481, '1997-08-26 22:00:00+00', '2021-04-11 10:53:03.226607+00', 'Tartan Waistcoat, The', 'TARTAN WAISTCOAT', 3, 32, 9999, 1, 4, 1, 176, '1972-01-01', '', 72, '8888/8080/8888/8282', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17260, '2016-09-04 20:03:19.030501+00', '2020-10-24 18:21:21.429352+00', 'Wedding in the Glen', 'WEDDING IN THE GLEN', 3, 32, NULL, 1, 4, 2, 608, NULL, 'For Livia Kohn and Tom Moscarillo on the occasion of their wedding in 1999.', 62, '8008/4444/4444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16257, '2015-05-04 10:36:14.135141+00', '2020-12-29 12:41:17.687045+00', 'London''s Turning', 'LONDONS TURNING', 2, 80, NULL, 1, 4, 5, 2865, '1999-10-01', 'Acknowledgement:

This dance was inspired by the unusual alternating reel structure of the dance ''London''s Burning'' by Sue Petyt and is merely a variation on that dance. The continuous motion of the dance made me think of gear wheels and ''London''s Turning'' is an attempt to develop that concept.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11837, '2004-10-31 23:00:00+00', '2021-01-18 19:06:57.057855+00', 'Dancing with Fyre', 'DANCING WITH FYRE', 2, 32, 9999, 1, 3, 42, 2961, NULL, 'Devised: 2003', 50, '800/888/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19059, '2018-12-03 15:55:17.02893+00', '2021-03-13 20:01:11.898143+00', 'Reel or Two for Sheila, A', 'REEL OR TWO FOR SHEILA', 1, 40, NULL, 1, 4, 1, 11750, '2001-01-01', 'For his wife, Sheila Imrie, as a surprise present on her 65th birthday', 52, '8880/8440/8440/8002', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6387, '2001-03-13 23:00:00+00', '2021-04-12 21:56:52.831929+00', 'Summer''s End', 'SUMMERS END', 2, 32, 9999, 1, 4, 1, 401, '1988-01-01', '', 81, '8888/8484/8888/8080', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3065, '1998-01-05 23:00:00+00', '2021-03-27 19:56:41.031174+00', 'Illabo Rant, The', 'ILLABO RANT', 1, 64, 9999, 4, 4, 14, 151, NULL, 'Twice through only.  

Beginners'' dance.  As the dancers get better you can substitute setting for the claps.  

Music: »The Reverend John MacFarlane« or »The Shetland Fiddler«.  ', 75, '8888  8080  0808  4444  8888  4444  8888  8888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (1008, '1998-04-29 22:00:00+00', '2021-06-24 09:58:57.431175+00', 'Captain Cook''s Hornpipe', 'CAPTAIN COOKS HORNPIPE', 1, 32, 9999, 1, 4, 1, 539, NULL, '', 84, '8880/8888/8888/8048', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15684, '2014-10-29 22:07:30.164624+00', '2019-02-12 23:42:58.574389+00', 'Last Set in the Hall, The', 'LAST SET IN THE HALL', 3, 32, NULL, 2, 3, 18, 10824, '2014-01-01', 'This dance was devised when the Utrecht SCD-group (www.theswilcan.nl) was informed that the gymnasium where we danced was to be be demolished on very short term. Fortunately we found another hall in time, but I devised this dance to celebrate our last dance class in the old hall.



The dance author has asked that the original description be published here.



The Last Set in the Hall 



Strathspey for 3 couples in a longwise set, 3 x 32 bars



1 – 8	1s & 2s dance the Knot. 1s turn to face 1st  corners



9 – 10	1s set to 1st corners



11 – 12	1s pull back RSH, dance round each other and out to 3rd corner position WHILE 1st corners dance towards each other, pull back RSH and face out



13 – 16	Repeat 9 - 12. 1s finish with twirl to face 2nd corners. 1st corners finish in opposite corner place



17 - 24 	Repeat with 2nd corners. 1s finish by passing right shoulder to 2nd place opposite side



25 - 26 	All set



27 - 30 	All turn partner 2 hands one and a half times, and stay in the middle to face each other,



31 - 32	All pull back RSH and twirl to own side.



 	Finish in order 3, 1, 2



Recommended Music:	Miss Nicola Jack (Bob Shakespeare)



Recording:	 If at First (S32 3) – David Cunningham and his Scottish Dance Band.  CD Leicester Branch 1977-2002 The Silver Collection

', 75, '880/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19184, '2019-02-13 21:27:00.698113+00', '2019-02-16 11:03:01.006518+00', 'Knot Again', 'KNOT AGAIN', 4, 64, 5, 1, 3, 42, 11779, NULL, '', 50, '880/800/808/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10944, '2002-11-14 23:00:00+00', '2019-02-13 18:22:04.559953+00', 'Code Breaker, The', 'CODE BREAKER', 1, 32, 9999, 1, 4, 2, 108, '2002-05-01', 'A dance to the memory of <<ddp:Hugh Foss#129|HUGH FOSS>> who worked at Bletchley with Alan Turing during the 1940''s and helped in breaking the Enigma Code.



The initial movements in this dance are similar to those in Hugh''s dance <<ddd:Caller Herrin''#950>>.', 78, '8642/8888/8448/8448', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19186, '2019-02-15 18:32:50.590609+00', '2019-02-15 21:25:51.429679+00', 'Mulberry Bush, The', 'MULBERRY BUSH', 3, 32, NULL, 1, 3, 42, 2973, '2015-03-01', 'This may also be danced as a Reel or a Medley of 32 S + 32 R.  



Devised as an introduction to set and rotate for three couples', 69, '844/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6205, '2002-03-02 23:00:00+00', '2019-02-19 01:00:40.094942+00', 'Sound of Harris, The', 'SOUND OF HARRIS', 1, 48, 9999, 2, 3, 17, 108, '1977-01-01', 'In the Canadian Book, Drewry dedicates this dance to Valerie Harris of Ontario. The inscription on the dance states: *The Sound of Harris is the sea between Harris and North Uist in the Outer Hebrides; it is also Valerie''s laugh!*', 93, '833  888  888  888  888  888', 1, 1, 1, 0, 93);
INSERT INTO 'dance' VALUES (19190, '2019-02-20 20:02:51.216261+00', '2019-02-20 20:02:51.216261+00', 'Isdale Jig, The', 'ISDALE JIG', 2, 40, NULL, 1, 3, 42, 39, '1957-01-01', 'A token of appreciation and admiration, and in honour of the visit of Mrs Mary Isdale MacNab of Vancouver, to Edinburgh, 27 July, 1957 at the International Festival of Dancing', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18622, '2018-09-17 18:28:12.601123+00', '2019-02-23 18:51:09.388827+00', 'Margaret Carson''s Strathspey', 'MARGARET CARSONS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 979, '2003-05-01', 'Dance devised by Rona Mcleod for her Aunt Margaret''s 80th Birthday', 73, '800/288/888/848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18004, '2017-10-12 10:41:57.753013+00', '2019-02-23 19:01:16.169406+00', 'Let''s Make a Set', 'LETS MAKE A SET', 1, 40, 9999, 1, 4, 1, 10853, '2017-06-01', 'For Olive Duff, on the occasion of her 77th birthday. Olive was an active member of the Pretoria Branch, dancing with us for over 35 years. Over these years shr served on the committee from time to time, was a member of the demontration team, always friendly, always ready to help, always welcoming new dancers by asking them to partner her in a set...', 80, '8400/8884/8888/8440/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8548, '2000-04-25 22:00:00+00', '2020-12-29 11:46:05.54557+00', 'Five Minute Wonder, The', 'FIVE MINUTE WONDER', 3, 64, 9999, 1, 4, 1, 2756, '1997-02-01', '', 66, '8000/8222/8222/8888/8000/8444/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13447, '2009-11-16 23:00:00+00', '2021-01-01 23:22:07.272143+00', 'Falcon Square', 'FALCON SQUARE', 3, 40, 9999, 4, 4, 13, 10395, NULL, 'Published in the Diamond Jubilee Collection of the RSCDS Inverness and District Branch: http://my.strathspey.org/dd/publ/1027/', 90, '8888/8888/8888/4444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9983, '2001-06-17 22:00:00+00', '2021-02-14 12:26:40.024678+00', 'Dundee to Malaga', 'DUNDEE TO MALAGA', 3, 32, 9999, 1, 3, 42, 11724, NULL, '', 66, '880/888/884/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (530, '1998-04-15 22:00:00+00', '2021-07-02 11:39:24.030891+00', 'Black Angus', 'BLACK ANGUS', 3, 32, 9999, 2, 3, 17, 686, NULL, '', 88, '888/844/884/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16136, '2015-02-27 13:50:25.767856+00', '2019-02-23 01:06:20.798718+00', 'Our Peter White', 'OUR PETER WHITE', 3, 32, 9999, 1, 3, 42, 10568, '2006-11-01', 'Music: Montréal Summers, ''Les joueurs de bon accord''  



The "Peter White Diagonal figure" (bars 17-24 and 25-32) is taken from the dance "Peter White" by the late Alec Hay. I don''t know if the figure has a name but it is a great formation. I devised this dance to introduce the figure to our TMR class one night when we didn''t have a teacher and were all bringing a dance or two. Joanne and our Peter White brought "Best Set in the Hall" for us to dance that night which has the same Peter White Diagonal figure but in quick time.', 50, '800/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16137, '2015-02-27 13:59:12.293518+00', '2019-02-23 01:37:41.162393+00', 'Always and Forever', 'ALWAYS AND FOREVER', 2, 32, 9999, 3, 5, 7, 10568, '2007-04-01', 'Music: Come Under My Plaidie  



Written for Tom and Betty Speirs, generous and supportive dancing partners for many years. Betty introduced me to my first dolphin reel. Tom helped my husband look the part of a Scottish country dancer when we first started dancing and Betty taught us a lot of the skills. They are also an inspiration to us as a couple.  



Thank you, Tom and Betty, for making dancing such a pleasure.', 68, '80800/84844/84844/84888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14534, '2012-08-15 09:01:47.763879+00', '2019-02-23 16:38:14.781945+00', 'Mist o''er the Loch', 'MIST OER THE LOCH', 3, 32, NULL, 1, 3, 42, 347, NULL, 'A reliable source tells us that the author originally wanted to call the dance »The Duke and Duchess of Cambridge«, in honour of Prince William and his wife, but permission to do so was refused by the Palace (with no reason specified).



The current title of the dance is perhaps less than 100% fortunate given its phonetic proximity to <<ddd:The Minister on the Loch>>.



Notes (additional to the book and the Manual) collected by Helen Russell from staff teaching The Diamond Jubilee book at Summer School 2012. 



13 - 16   1st couple, with 2nd woman and 3rd man, dance half rights and lefts on the diagonal. 



21 - 24   1st couple, with 2nd man and 3rd woman, dance a variation on half rights and lefts on the diagonal.  To begin 1st man dances diagonally up and 1st woman dances diagonally down.  N.B. It may help to note that 1st man goes up, down down and up, while 1st woman goes down, up, up and down.



27 & 31   Ensure that hands are released before starting to cast.



', 41, '880  822  822  822', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (18658, '2018-09-24 22:27:25.754739+00', '2019-02-23 18:45:56.231233+00', 'A for Alex', 'FOR ALEX', 3, 32, NULL, 1, 4, 2, 1445, '2018-01-01', 'This dance was devised for our friends Kay and Keith Dixon on becoming grandma and granddad of Alex. ', 75, '8008/8888/8008/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16140, '2015-02-27 14:26:33.971413+00', '2019-02-24 00:21:35.265214+00', 'Guinea Pig Gallop', 'GUINEA PIG GALLOP', 1, 32, 9999, 1, 3, 42, 10568, '2007-11-01', 'Helpful hints:  

- 1 s need to stretch their steps on bars 15/16 and 23/24.  

- Corners need to be alert, especially on bars 11 and 17 (coming out of the reel) and 19.  

- Use a slow reel.  



Written for the TMR Friday night group who have guinea pigged all my dances. Many thanks for the suggestions and encouragement.', 56, '800/866/866/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19199, '2019-02-21 09:12:17.958618+00', '2019-02-24 17:42:55.316487+00', 'Ian''s Delight', 'IANS DELIGHT', 1, 32, NULL, 1, 3, 42, 11789, '2018-02-01', 'Dedicated to the memory of Ian Ross, a dear friend and fellow-dancer who, together with his devoted partner, Marmie Smith, epitomised the joyfulness of Scottish country dancing.', 59, '804/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9889, '2002-03-03 23:00:00+00', '2019-02-24 10:25:19.260528+00', 'Round Arran Jig, The', 'ROUND ARRAN JIG', 2, 80, 9999, 4, 4, 54, 318, NULL, 'This dance was originally named Jean McKelvie''s (Arran) Jig. 



The original copy of the dance description, held by the Ayrshire Branch, has the following annotation written by hand at the end by the late Alistair Aitkenhead, Branch founder member and highly respected dance teacher.  These amendments (ratified as correct by Alastair MacFadyen, President RSCDS, verbally, in 2019) are:

-   Change of name to THE ROUND ARRAN JIG effective May 1988.

-   Bars 65-68 All four ladies RIGHT (NOT left) hands across

-   Bars 69-72 All four men LEFT (NOT right) hands across …………..ladies on the outside facing in ANTI clockwise (NOT clockwise) direction………

-   At the end “Second time round dance off”

', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11784, '2004-09-08 22:00:00+00', '2019-02-24 21:26:44.352408+00', 'Lap-Top Dancer and the Stripper, The', 'LAPTOP DANCER AND THE STRIPPER', 1, 32, 9999, 1, 4, 2, 108, '2003-01-01', 'Paul complained to me over the phone that his computer equipment was giving him trouble. His Lap-Top was misbehaving and the hard disc in his other machine would have to be stripped!', 72, '4444/4444/8888/8668', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6819, '1998-01-04 23:00:00+00', '2019-02-24 22:26:39.657412+00', 'Two Bonnie Lads, The', 'TWO BONNIE LADS', 1, 32, 9999, 1, 2, 76, 1149, NULL, '', 38, '80/62/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11633, '2004-01-14 23:00:00+00', '2019-03-02 12:02:57.475707+00', 'Daisy Chain', 'DAISY CHAIN', 3, 80, 9999, 4, 4, 3, 3412, NULL, '', 83, '8888/4444/4444/8888/6666/8888/8888/8888/4444/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15664, '2014-10-19 09:50:20.326573+00', '2019-02-26 00:05:53.654738+00', 'Southern Highlands Anniversary Strathspey', 'SOUTHERN HIGHLANDS ANNIVERSARY STRATHSPEY', 3, 32, NULL, 2, 3, 17, 11027, '2006-06-01', 'Devised for the Southern Highlands Scottish Country Dancers for their 20th Anniversary. First

danced at the Annual Social, 2nd September 2006.', 92, '888/888/888/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14352, '2011-12-14 23:00:00+00', '2022-08-07 11:18:51.972569+00', 'Twinkle in His Eye, A', 'TWINKLE IN HIS EYE', 3, 32, NULL, 1, 4, 11, 10453, '2007-09-08', 'Devised by Chris Godwin. [note: I hope this is the same person as Christine Godwin.  Eric F; DD Editor]



"Dedicated to Roy Goldring, who devised so many of my favourite dances." ', 81, '8008  8448  8888  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (17162, '2016-08-17 17:51:19.824322+00', '2019-02-26 00:43:00.60892+00', 'Runaway Morgan, The', 'RUNAWAY MORGAN', 2, 32, NULL, 1, 3, 42, 2823, '2009-11-01', 'In the summer of 2009, I had a run-in with an Amish horse & buggy.  The horse (a Morgan) and the 

buggy was a runaway and it ran into my car, which was parked on a farm.  The horse and buggy 

came at us from the front and missed us as it passed us by.  Then, having turned around, it came at 

us from the rear and it clipped the passenger side door as it passed on by.  The horse and buggy were fine, my Amish Liaison and I were fine, … the car had $3200 worth of damage to it.  



Suggested Tunes:  Tam’s Hunting Horn, Andy Clark of Crieff, Jim McAlister''s jig, and Miss Sarah Gillies.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15066, '2013-08-10 15:39:18.677685+00', '2019-02-26 12:48:35.242108+00', 'To Honour a King', 'TO HONOUR A KING', 3, 32, NULL, 4, 4, 1, 10832, NULL, '', 63, '4444/4444/4444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19203, '2019-02-25 22:04:38.482491+00', '2019-02-25 22:05:36.151975+00', 'Kinnaird Head Strathspey', 'KINNAIRD HEAD STRATHSPEY', 3, 32, NULL, 1, 3, 42, 9998, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19200, '2019-02-25 00:06:27.115518+00', '2021-02-20 13:16:17.280172+00', 'Tassie Devil, The', 'TASSIE DEVIL', 1, 32, NULL, 5, 1, 4, 293, NULL, 'Full name: The Tassie Devil (in courtship).



And don''t forget the growls in bars 9-16! (Special request from the deviser).', 100, '8/8/8/8', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11897, '2004-11-04 23:00:00+00', '2021-07-30 07:41:46.747953+00', 'Dumfries Rambler, The', 'DUMFRIES RAMBLER', 1, 32, 9999, 1, 4, 11, 308, '2003-01-01', 'On bars 5-6, dancers may also face in diagonally.  Sue Petyt writes "I am always relaxed about small changes to my dances if it makes the dance more enjoyable"', 87, '0880  8888  8888  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (16794, '2015-10-14 15:58:40.613557+00', '2019-02-25 23:49:21.698914+00', 'Desiree and John', 'DESIREE AND JOHN', 3, 48, NULL, 2, 3, 18, 2682, NULL, 'Devised 6th April, 2015, following a suggestion of Kristin which lead to the figure

“Highland Schottische Balance with Turns”. Recommended music is “Sidlaw

Hills” (James Watson 19th Century) played ABABAB, and a good recording

is by the Sound Company as a “Set of Strathspeys Suitable for the Moray

Rant” on the MC “Best Foot Forward.” (Track 3) An acceptable alternative

tune is “Caerlaverock Castle” (Ian Homes) and an acceptable recording is to be

found as “One for the Millennium” by Robert Whitehead the Danelaw Band in

“Dancer’s Choice Volume 2.” (Track 6) Desiree and John Patterson are loyal

Johnsonville members, and very keen cyclists, inspiring us to try to emulate

them. Recently they obtained electric bicycles enabling them to do remarkably

adventurous rides. So far we resist ge tting the s', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16615, '2015-08-26 19:15:26.580536+00', '2019-02-25 23:54:21.922418+00', 'Pillar Box Reel, The', 'PILLAR BOX REEL', 1, 32, NULL, 1, 4, 2, 3183, '2014-03-01', 'For Bob Drummond’s special birthday at the request of his sister Isabel Bone. Bob is a keen Scottish country dancer who has a passion for Victorian post boxes (hence the title).', 75, '8008/8888/8888/8044', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12803, '2006-07-02 22:00:00+00', '2019-02-28 21:21:59.554183+00', 'Floosie in the Jacuzzi, The', 'FLOOSIE IN THE JACUZZI', 1, 48, 9999, 4, 4, 14, 3694, NULL, 'The dance title refers to the sculptural fountain, <<http://en.wikipedia.org/wiki/The_River_(artwork)|“The River”>>, in Victoria Square, Birmingham, England. 



This dance contains Schiehallion Reels reverse, that means men start facing out to cast and ladies dance across the set to their left.', 100, '8888  8888  8888  8888  8888  8888', 0, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (14285, '2011-10-26 22:00:00+00', '2019-02-26 17:23:25.233574+00', 'François'' Frolic', 'FRANCOIS FROLIC', 1, 32, 9999, 1, 4, 42, 3286, '2008-01-01', 'As music the author suggests "The Sword of St Columba" or "any frolicksome reel".', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17155, '2016-08-17 17:37:47.304133+00', '2019-02-27 15:50:41.317662+00', 'Mac''s Delight', 'MACS DELIGHT', 3, 32, NULL, 1, 2, 76, 2823, '2006-03-01', 'This is dedicated to my father, Michael McMahon, Sr.  Mac’s Delight could be his wife, his daughter, or his grand-daughter.  Any and all do apply.', 44, '88/66/66/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8523, '1998-02-08 23:00:00+00', '2019-02-27 22:10:11.344325+00', 'Searching the Archives', 'SEARCHING THE ARCHIVES', 1, 32, 9999, 2, 3, 18, 2075, NULL, '', 92, '888/888/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19205, '2019-02-28 19:13:21.23996+00', '2019-03-01 00:54:50.426636+00', 'Of Quakes and Quaichs', 'OF QUAKES AND QUAICHS', 3, 32, NULL, 1, 3, 42, 2701, '2019-01-01', 'For Donna Weidenfeller and Harry Andrews in celebration of their wedding. Donna is from Wisconsin originally but has been living in San Francisco, California for most of her adult life. Harry is from Edinburgh. They met several years ago in the San Francisco Scottish dance class and began a friendship that has grown deeper over time.  



For the dance, they both requested the half turn and twirl figure (bars 18-22, 23-26). I added the California twirl variation (bars 5-6), and the two-handed turn which is a nod to the quaich often used in Scottish weddings.', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11516, '2003-10-02 22:00:00+00', '2019-03-02 11:49:30.190439+00', 'Fiona''s Jig', 'FIONAS JIG', 2, 96, 9999, 4, 4, 3, 1253, NULL, '', 75, '8888/8080/0808/8888/8080/0808/8888/8080/0808/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12622, '2005-11-08 23:00:00+00', '2019-03-04 19:23:03.7092+00', 'Bracknell Strathspey, The', 'BRACKNELL STRATHSPEY', 3, 40, 9999, 2, 3, 17, 3647, NULL, '', 88, '844/888/684/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9849, '2002-03-03 23:00:00+00', '2019-03-05 00:42:09.958854+00', 'Doreen''s Delight', 'DOREENS DELIGHT', 3, 48, 9999, 1, 4, 1, 2890, NULL, '', 75, '8000/8440/8448/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10651, '2002-07-21 22:00:00+00', '2019-03-02 23:05:11.523889+00', 'Fare Frolic, A', 'FARE FROLIC', 2, 32, 9999, 1, 4, 1, 3166, NULL, '', 75, '4444/8888/4444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15329, '2014-01-06 00:50:36.901255+00', '2019-03-03 06:28:30.400792+00', 'Gypsy Girl''s Headscarf, The', 'GYPSY GIRLS HEADSCARF', 2, 32, NULL, 1, 4, 1, 10912, NULL, 'May also be danced in a 3-couple set.



The dance relates to the painting ''The Yellow Headscarf'' by the Romanian painter Octav Băncilă.





Deviser''s Dance Notes (Source: <<|Scottish Country Dancing Dictionary>>):



This dance is a derivative of "The Gypsy Shawl"; it uses slip step throughout (plus stepping up) and so is suitable for younger children who haven''t yet learnt skip change or for inexperienced dancers at a ceilidh.



17-20  1s take large steps.



21-24  1s take small steps to finish below 4s, retaining M''s right, L''s left hand hold ready for the hands round.



32       At the end of every repeat except the last, all except 2s (M''s left, L''s right) retain the hands round hold ready for bar 1 of the new repeat. 





', 81, '8888/8888/8000/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19015, '2018-10-19 15:01:27.712072+00', '2019-03-03 09:37:57.690304+00', 'Jig for Helen, A', 'JIG FOR HELEN', 2, 32, NULL, 1, 3, 42, 11734, NULL, 'These three Dances (pages 6 and 7) were devised by FLORA INGLIS for her grand-daughters', 44, '444/444/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12014, '2005-02-02 23:00:00+00', '2019-03-03 10:35:38.983919+00', 'Rice and Lefse', 'RICE AND LEFSE', 2, 40, 9999, 2, 3, 18, 2408, '2005-01-01', 'Devised by Lara Friedman-Shedlov in 2005 in an attempt to create a dance with three types of rights and

lefts. Lefse is a round flatbread of Norwegian origin, traditionally made of a potato-based dough and

baked on a griddle. It is quite popular in Minnesota, which has many people of Scandanavian descent.

Wild rice is native to the Minnesota wetlands and traditionally cultivated by its native people.  



"Although unorthodox, it has been noted that this progression technically will work as an 8x40 dance in traditional 4-couple longwise set, with the 1st couple stepping down to 4th place after the 2nd repetition. Since 8x40 jig recordings are a lot easier to come by than 3x40, feel free to dance it this way. Music for "The Express" was recommended by at least one person who tried this." (Lara Friedman-Shedlov).', 80, '800/888/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10229, '2001-11-06 23:00:00+00', '2019-03-03 18:41:28.057207+00', 'John Duncanson of Falmouth', 'JOHN DUNCANSON OF FALMOUTH', 3, 32, 9999, 2, 3, 17, 2018, NULL, '', 75, '888/484/484/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19222, '2019-03-03 22:42:53.248185+00', '2019-03-04 01:15:10.087323+00', 'Sachel', 'SACHEL', 1, 32, NULL, 1, 4, 1, 401, '2018-01-01', 'for Sachel Kizner.', -78, '8888/8000/4888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15035, '2013-08-02 19:13:53.994007+00', '2021-01-03 12:59:56.058496+00', 'Shirley''s Strathspey', 'SHIRLEYS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 10818, NULL, 'Devised by Diana Ashworth and the Cairn Dancers of Dewsbury in memory of Shirley M Shields - one of the founder members of the Leeds Branch', 88, '822/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9581, '2000-09-06 22:00:00+00', '2021-02-21 19:07:54.782941+00', 'Alex Jappy''s Pleasure', 'ALEX JAPPYS PLEASURE', 3, 32, 9999, 2, 3, 18, 118, '1999-01-01', '', 75, '880/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2177, '1998-01-05 23:00:00+00', '2021-06-20 22:09:59.472585+00', 'Fiona Fair', 'FIONA FAIR', 1, 32, 9999, 1, 2, 76, 352, '1990-09-22', '"For my daughter Fiona"', 44, '80/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11898, '2004-11-04 23:00:00+00', '2021-08-02 10:06:58.866049+00', 'Queen Elizabeth of Mey', 'QUEEN ELIZABETH OF MEY', 2, 40, 9999, 1, 4, 1, 308, '2002-06-01', 'This dance was written in response to a challenge by Ian MacPhail, made on ‘Take the Floor’ for devisors to come up with a dance to fit the music he had written.  The music is in 20 bar phrases!



However the devisor does not consider this dance works well *(comment received from Sue Petyt by email)*.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4550, '1997-04-03 22:00:00+00', '2019-03-04 17:09:36.43316+00', 'Miss Mary Milne', 'MISS MARY MILNE', 2, 32, 9999, 1, 3, 42, 165, NULL, '', -1, '800/888/888/866', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8851, '2002-03-11 23:00:00+00', '2019-03-06 10:56:25.17782+00', 'Looking for a Partner', 'LOOKING FOR A PARTNER', 2, 48, 9999, 6, 3, 4, 663, NULL, '', 83, '444/444/888/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8211, '1997-12-27 23:00:00+00', '2019-03-07 00:11:57.49099+00', 'Copycat!', 'COPYCAT', 1, 88, 9999, 4, 4, 3, 2014, NULL, '', 55, '4444/4444/8080/0808/8080/0808/8080/0808/8080/0808/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19225, '2019-03-07 09:05:49.331469+00', '2019-03-07 10:52:41.436228+00', 'Geestland Jig, The', 'GEESTLAND JIG', 2, 32, NULL, 1, 3, 42, 3342, '2018-04-01', '', 44, '800/800/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19223, '2019-03-04 17:24:53.566123+00', '2019-03-11 19:41:35.609137+00', 'Stephen Black of Banchory', 'STEPHEN BLACK OF BANCHORY', 1, 32, NULL, 1, 3, 42, 11794, NULL, 'Source: Minicrib.  Entry needs to be checked against the original.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8006, '1997-12-27 23:00:00+00', '2019-03-07 18:33:09.256813+00', 'Wait For It', 'WAIT FOR IT', 1, 32, 9999, 1, 4, 2, 1228, '1990-01-01', 'Should be danced to Hornpipe tunes.  



For Ellen Delvin from comments made to classes.  



I am sure all Teachers have experienced the enthusiastic class that doesn''t wait to find out the "meanwhile" before walking their own part. Hence the name and hence the style. In this dance they will have to wait!', 75, '6666/6006/6006/6666', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7975, '1997-09-16 22:00:00+00', '2019-03-07 18:40:08.487395+00', 'Three Sisters of Glencoe, The', 'THREE SISTERS OF GLENCOE', 3, 32, 9999, 2, 3, 17, 566, NULL, '', 67, '808/422/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7849, '2000-04-09 22:00:00+00', '2019-03-07 22:14:08.102277+00', 'Monmouth Ramble, The', 'MONMOUTH RAMBLE', 3, 32, 9999, 1, 4, 1, 1148, NULL, '', 72, '8888/8444/8440/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19227, '2019-03-07 11:10:05.865724+00', '2019-03-08 00:34:57.14778+00', 'Tartan Bonnet, The', 'TARTAN BONNET', 2, 32, NULL, 1, 2, 76, 3342, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19282, '2019-05-03 19:09:28.189878+00', '2019-05-03 23:41:02.859858+00', 'Wonderful Person', 'WONDERFUL PERSON', 2, 32, NULL, 1, 4, 2, 3775, '2019-01-01', 'Devised to honour Gary Thomas', 81, '8008/8888/8888/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8770, '1998-10-19 22:00:00+00', '2019-05-06 10:14:23.712981+00', 'Dochroyle', 'DOCHROYLE', 2, 32, 9999, 1, 2, 76, 349, '1998-01-01', 'Dochroyle was the name of the family farm of the deviser''s wife''s Great Grandparents situated near Newton Stewart, Galloway.  On emigrating to New Zealand her Grandfather settled on a farm in Taihape and gave it the same name.', 52, '44/44/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7448, '1998-09-23 22:00:00+00', '2019-03-08 11:54:44.37503+00', 'Leaping Salmon', 'LEAPING SALMON', 2, 32, 9999, 1, 3, 42, 434, '1996-11-01', '', 44, '646/646/800/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19232, '2019-03-08 19:47:04.902353+00', '2019-03-08 19:47:04.902353+00', 'No Hands Dance', 'NO HANDS DANCE', 2, 32, NULL, 1, 4, 2, 11037, '2013-03-01', 'Devised for some members of the Schiehallion SCD group with arms temporarily handicapped.', 75, '8008/8888/8888/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19235, '2019-03-08 20:39:24.944748+00', '2019-06-26 21:32:42.704578+00', 'Wallflower, The', 'WALLFLOWER', 3, 32, NULL, 6, 112, 30, 11150, NULL, 'For three couples in a triangular set and a 4th woman in the middle.

Two chords. On the 1st chord the three couples bow or curtsey towards the 4th woman,

who curtseys towards the 1st couple. On the second chord the three couples bow or curtsey to partner.', 79, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19230, '2019-03-08 18:34:06.804612+00', '2019-03-08 18:34:06.804612+00', 'German Frolic', 'GERMAN FROLIC', 3, 32, NULL, 1, 3, 42, 11150, NULL, 'The deviser intended this as a simple dance to teach the three couple allemande.', 47, '800/822/088/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19292, '2019-05-09 13:14:09.300272+00', '2019-05-09 13:14:09.300272+00', 'In Touch', 'IN TOUCH', 2, 40, NULL, 1, 4, 1, 743, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5775, '1997-04-03 22:00:00+00', '2019-03-11 10:50:52.261788+00', 'Rural''s Jubilee Strathspey, The', 'RURALS JUBILEE STRATHSPEY', 3, 32, 9999, 1, 4, 1, 295, NULL, '', 56, '8008/8008/8000/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6671, '1997-09-16 22:00:00+00', '2019-03-09 14:01:50.535445+00', 'Town Of Flowers', 'TOWN OF FLOWERS', 3, 32, 9999, 1, 4, 1, 1012, '1978-09-01', 'Note on the original description:  "Looking at the directions for Town of Flowers, I think it''s clear that bars 21-24 should end with "to regain own sides" rather than "original places" because the dancers are in the order 3,2,1,4." 

', 100, '8888  8888  8888  8888', 1, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (6094, '1997-08-26 22:00:00+00', '2019-03-10 16:00:12.841318+00', 'Silver Wedding, The', 'SILVER WEDDING', 2, 32, 9999, 3, 5, 7, 561, '1972-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6081, '1997-04-03 22:00:00+00', '2019-03-10 16:05:37.541073+00', 'Silver Glen, The', 'SILVER GLEN', 3, 32, 9999, 1, 4, 1, 313, NULL, '', 78, '8686/8888/8888/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5719, '2002-03-03 23:00:00+00', '2019-03-11 11:03:19.145659+00', 'Rounder Reel Of Eight, The', 'ROUNDER REEL OF EIGHT', 1, 88, 9999, 4, 4, 3, 580, NULL, '', 80, '8888/8888/4444/4444/6666/6666/6666/6666/6666/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5518, '2002-08-06 22:00:00+00', '2019-03-11 11:52:32.859975+00', 'Reel for the Ridings, A', 'REEL FOR THE RIDINGS', 2, 40, 9999, 1, 4, 1, 1222, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5451, '1997-11-27 23:00:00+00', '2019-03-11 12:00:22.490285+00', 'Radcliffe Square', 'RADCLIFFE SQUARE', 4, 128, 2, 4, 4, 3, 1216, NULL, '', 95, '8888/8888/8888/5555/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5446, '1997-09-11 22:00:00+00', '2019-03-11 12:03:51.078808+00', 'Rab The Ranter', 'RAB THE RANTER', 1, 32, 9999, 1, 4, 1, 78, NULL, '', 78, '8448/4884/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17937, '2017-09-15 22:50:03.350959+00', '2020-07-04 22:37:28.15013+00', 'Seven of Diamonds', 'SEVEN OF DIAMONDS', 2, 32, 9999, 107, 112, 30, 17, '2011-01-01', 'The dance is performed by 7 persons arranged as the 7 in a pack of playing cards.



According to the original description Jig or Reel is suited for the dance.

Progression 4512736', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19426, '2019-06-26 22:42:40.101374+00', '2020-08-25 18:46:49.253161+00', 'Road to Rannoch', 'ROAD TO RANNOCH', 4, 128, 2, 4, 4, 3, 11828, NULL, '', 100, '8888/8888/8888/8888/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8493, '2001-06-12 22:00:00+00', '2022-06-17 19:34:58.512798+00', 'Ruby Wedding Strathspey', 'RUBY WEDDING STRATHSPEY', 3, 80, 9999, 4, 4, 3, 2899, NULL, '', 80, '8888  4444  4444  8888  8888  8888  8888  4444  4444  8888', 0, 1, 0, 0, 80);
INSERT INTO 'dance' VALUES (9874, '2001-09-12 22:00:00+00', '2022-07-21 16:02:07.12964+00', 'Millennial Strathspey, The', 'MILLENNIAL STRATHSPEY', 3, 40, 9999, 1, 4, 2, 108, '1999-01-01', 'Dedication from *Greenburn Book 3:* A dance for the new millennium', 70, '8888/8008/8008/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19226, '2019-03-07 10:58:42.385747+00', '2022-08-15 11:31:45.63697+00', 'Sunshine Reel, The', 'SUNSHINE REEL', 1, 32, NULL, 1, 3, 42, 2874, '2019-02-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6044, '1998-04-19 22:00:00+00', '2022-11-08 16:59:08.116296+00', 'Shetland Fiddler, The', 'SHETLAND FIDDLER', 1, 32, 9999, 1, 4, 1, 62, '1973-02-01', '', 58, '8600/8888/8022/8008', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8672, '1999-08-06 22:00:00+00', '2020-12-19 15:13:27.945311+00', 'George Washington Bridge, The', 'GEORGE WASHINGTON BRIDGE', 3, 32, 9999, 1, 4, 2, 479, '1994-05-01', 'The dance was devised in May 1994, and dedicated to Jim ("Fergie") and Susan Ferguson of the New York Branch of the Royal Scottish country Dance Society, on the occasion of the Pawling Weekend, May 1994.', 81, '8484  8888  8008  8888', 0, 1, 0, 0, 81);
INSERT INTO 'dance' VALUES (19244, '2019-03-20 16:35:08.505878+00', '2020-11-02 09:52:17.683067+00', 'Dark Clouds', 'DARK CLOUDS', 3, 32, NULL, 1, 4, 1, 10612, NULL, 'Description found in the programme for the Kuckucksnest March Beginners'' Course 2019.', 56, ' 8000/8844/8888/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5414, '1997-09-11 22:00:00+00', '2019-03-11 18:07:59.827137+00', 'Queen Mary of Scotland', 'QUEEN MARY OF SCOTLAND', 3, 32, 9999, 1, 4, 2, 108, '1985-01-01', '', 75, '4444/8888/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19233, '2019-03-08 20:01:10.091921+00', '2019-03-11 19:46:39.736437+00', 'Old Fairy Bridge, The', 'OLD FAIRY BRIDGE', 2, 40, NULL, 1, 3, 42, 11798, NULL, 'The Fairy Bridge in Manx legend, is near Castletown in the south of the Island, and in olden times carried people over the Fairies'' dwelling. Today it is a road bridge, and it is customary for those crossing, to acknowledge the Fairies with a nod of the head and "Good (Morning) Fairies". Those who do so are assured of good fortune that day.', 58, '844/822/088/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19237, '2019-03-09 09:34:47.0738+00', '2019-03-21 00:07:48.098161+00', 'Modestine''s Romp', 'MODESTINES ROMP', 3, 40, NULL, 2, 3, 17, 10992, '2018-01-01', 'Modestine was the donkey who carried Robert Louis Stevenson''s kit during a walk in southern France in 1878 described in his book "Travels with a Donkey in the Cévennes".



Bars 9-32 depict RLS leading Modestine and tapping her on the shoulder to goad her along.', 53, '800/800/844/844/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19246, '2019-03-22 20:44:33.761286+00', '2019-03-29 09:46:42.500496+00', 'Clopton Bridge', 'CLOPTON BRIDGE', 1, 32, NULL, 1, 4, 1, 11800, NULL, '', 41, '4004/4004/0880/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19255, '2019-04-03 10:33:49.628249+00', '2019-04-03 10:53:04.72822+00', 'My Friend Carol', 'MY FRIEND CAROL', 1, 32, NULL, 1, 100, 2, 3694, NULL, '', 81, '8448/8888/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19268, '2019-04-07 15:22:29.165383+00', '2019-04-07 15:22:29.165383+00', 'Bonfire Waltz, The', 'BONFIRE WALTZ', 5, 16, NULL, NULL, NULL, NULL, 11534, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19234, '2019-03-08 20:24:11.883379+00', '2019-04-24 23:12:43.351329+00', 'Short and Easy Dance for Six Couples', 'SHORT AND EASY DANCE FOR SIX COUPLES', 1, 32, NULL, 8, 6, 83, 11225, NULL, '', 67, '888888/880000/088000/888888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19294, '2019-05-09 13:19:04.525991+00', '2019-05-09 13:19:04.525991+00', 'Lead the Way', 'LEAD THE WAY', 3, 32, NULL, 1, 4, NULL, 743, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19296, '2019-05-09 15:20:30.049543+00', '2019-05-09 15:20:30.049543+00', 'Twice is Enough', 'TWICE IS ENOUGH', 2, 48, NULL, 8, 6, NULL, 743, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5271, '1997-04-03 22:00:00+00', '2019-03-11 18:57:35.834985+00', 'Piper And His Lass, The', 'PIPER AND HIS LASS', 3, 32, 9999, 1, 4, 1, 146, NULL, '', 81, '8888/8844/8888/8080', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5199, '1997-08-28 22:00:00+00', '2019-03-11 19:10:27.902936+00', 'Peat Inn, The', 'PEAT INN', 1, 32, 9999, 1, 4, 1, 146, NULL, '', 56, '8080/0808/8440/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5178, '1997-04-03 22:00:00+00', '2019-03-11 19:14:25.319584+00', 'Patched Bagpipe, The', 'PATCHED BAGPIPE', 2, 32, 9999, 1, 4, 2, 270, NULL, '', 81, '8888/8888/8448/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6805, '1997-08-25 22:00:00+00', '2019-04-20 23:28:47.680927+00', '26th of March, The', '26TH OF MARCH', 2, 40, 9999, 2, 3, 17, 532, '1977-01-01', 'Dance deVised by Stewart Adam. Jim Gardner and Bruce Wood, for the wedding of Anne Mechie and Mike Logan in March 1977', 73, '646/844/044/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19239, '2019-03-11 16:00:07.691719+00', '2019-03-14 23:47:41.198677+00', 'Brooklyn Bridge', 'BROOKLYN BRIDGE', 3, 32, NULL, 2, 3, 18, 2973, '2019-03-01', 'The dance can also be done as a 3-couple dance in a 4-couple set. 1st couple dance the second time through from second place as usual, but with 2nd and 4th couples, and then they step to the bottom.  The progression is unusual because it is 3rd couple who stand out at the top, and 3rd couple who dance as 1st couple for the third and fourth times through.  After all eight times through, however, each couple has had their turn from each position.    ', 83, '800/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19241, '2019-03-12 22:44:28.365396+00', '2019-03-12 22:46:38.872492+00', 'Joined at the Hip', 'JOINED AT THE HIP', 1, 32, NULL, 1, 3, 42, 2927, NULL, 'Source: Atlanta Dance programme', 47, '800/888/822/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4425, '1997-04-03 22:00:00+00', '2019-03-13 09:19:47.20669+00', 'Miss Anderson''s Bouquet', 'MISS ANDERSONS BOUQUET', 2, 48, 9999, 1, 4, 1, 94, NULL, '', 82, '8448/4884/8888/8888/8888/8222', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4256, '2002-02-28 23:00:00+00', '2019-03-13 10:04:25.407634+00', 'McCulloch Strathspey, The', 'MACCULLOCH STRATHSPEY', 3, 80, 9999, 4, 4, 3, 54, '1966-01-01', 'Dance notes from RSCDS Manual, 3rd edition, 2013:



Bars 9 – 12

1st and 3rd couples change places (1st couple dancing between 3rd couple), then both couples, giving left hands to their partners, dance a half turn, women finishing on the right of their partners.



Bars 13 – 16

2nd and 4th couples change places (2nd couple dancing between 4th couple), then both couples, giving left hands to their partners, dance a half turn, women finishing on the right of their partners.



Bars 65 – 72

This follows the path of a reel of four.



Comment on McCulloch Strathspey from RSCDS Teachers Advisory Panel:



I wonder if you can help with the interpretation of bars 65 - 72 of the McCulloch Strathspey from the RSCDS leaflets. The dance is a square strathspey and at the end of bar 64, everyone is back in their original places. My 1981 copy of the leaflet and also my 1987 edition of the pocket book for the leaflets has the following description of bars 65 - 72: "1st and 4th men dance a figure of eight round 1st and 4th women while 2nd and 3rd men dance a figure of eight round 2nd and 3rd women. Men pass left shoulders in the middle and dance round the women passing right shoulders." The 2005 edition of the Manual has no guidance on these bars. The 2008 TAC notes contains the following note: "1st and 3rd men (passing in front of partners) begin by passing 4th and 2nd men L shoulder & round women by R shoulder. Men finish by dancing round partners by R shoulder to finish facing c/clockwise, with partners on their right, ready for allemande." It seems to me that if 4th man is going to pass 1st man by the left and then dance round 1st lady by the right, that will be a very twisting route for him to take. Also, the pattern the men take is more a reel of four than a figure of eight and will be quite a stretch in 8 bars. 



It is like a reel of four with only two dancers, starting with 1st and 4th men, and 2nd and 3rd men, passing by the left.  It is quite a tight pass by the left for the men and then by the right round a lady, and also a long way to travel, but providing the men are ready (prompt them in plenty time) there should be no problem. 





', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14432, '2012-05-09 13:11:02.906653+00', '2019-03-15 19:16:10.257138+00', 'Paris Celebration Medley, The', 'PARIS CELEBRATION MEDLEY', 4, 64, 5, 3, 5, 41, 15, '2010-05-08', 'Dance devised by Bill Zobel for the 25th Anniversary of the Paris Branch and introduced at the Anniversary Ball in Paris on 8th May 2010.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7938, '1997-12-03 23:00:00+00', '2020-01-11 02:01:11.009243+00', 'Sassenach, The', 'SASSENACH', 2, 48, 9999, NULL, 98, NULL, 1260, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (313, '1997-12-10 23:00:00+00', '2020-05-15 10:06:23.58364+00', '(Hay''s) Australian Ladies', 'HAYS AUSTRALIAN LADIES', 1, 32, 9999, 1, 4, 1, 173, '1966-06-29', 'Following publication of <<ddd:Australian Ladies@Campbell|Bob Campbell''s dance of the same name>> some ten years after this dance was written, Alec Hay referred to his dance as “Hay''s Australian Ladies”.



Preferred music: "Gay Gordons" recorded by Stan Hamilton and "The Flying Scotsman" (RCA Victor R.P.L. 3404).   The tune "Australian Ladies" is also named in the description.', 87, '8888  4444  8888  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (705, '1997-11-25 23:00:00+00', '2020-08-02 23:30:04.193949+00', 'Border Reiver''s Reel', 'BORDER REIVERS REEL', 1, 128, 9999, 6, 3, 3, 82, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5371, '1997-09-05 22:00:00+00', '2020-09-02 18:03:10.836115+00', 'Jimmy''s Strathspey', 'JIMMYS STRATHSPEY', 3, 32, 9999, 1, 100, 2, 606, NULL, '', 83, '6886/8008/8888/8778', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4350, '1998-11-03 23:00:00+00', '2021-03-26 07:43:14.534134+00', 'Michigan Reel, The', 'MICHIGAN REEL', 1, 32, 9999, 1, 4, 1, 394, '1976-01-01', '', 91, '8888/8888/8888/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4191, '1997-04-03 22:00:00+00', '2022-12-03 19:18:34.326302+00', 'Marquis of Hastings'' Strathspey, The', 'MARQUIS OF HASTINGS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 94, NULL, '', 75, '4444/4444/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3799, '2002-12-01 23:00:00+00', '2019-03-14 22:11:10.561067+00', 'Lieutenant Zachary Hicks R.N.', 'LIEUTENANT ZACHARY HICKS RN', 1, 32, 9999, 1, 4, 1, 1073, NULL, '', 70, '8888/8444/8226/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3358, '1998-01-04 23:00:00+00', '2019-03-15 19:55:11.162605+00', 'Joy Be Wi'' Ye', 'JOY BE WI YE', 1, 32, 9999, 3, 5, 7, 59, NULL, '', 70, '80800/82842/88888/80888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3352, '1997-09-05 22:00:00+00', '2019-03-15 19:57:56.633235+00', 'Josephine', 'JOSEPHINE', 1, 32, 9999, 1, 4, 1, 282, NULL, '', 88, '8484/8888/8888/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3368, '1997-09-05 22:00:00+00', '2019-03-15 19:52:11.932658+00', 'Jubilee Reel, The', 'JUBILEE REEL', 1, 32, 9999, 1, 4, 1, 1035, NULL, '', 97, '8888/8888/8488/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3219, '1997-04-03 22:00:00+00', '2019-03-15 20:03:33.523112+00', 'Jean''s Reel', 'JEANS REEL', 1, 32, 9999, 1, 4, 1, 200, NULL, '', 75, '8008/8008/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3020, '2000-11-12 23:00:00+00', '2019-03-15 20:11:17.218939+00', 'Here''s a Hand', 'HERES A HAND', 4, 32, 9999, 1, 4, 1, 683, NULL, 'Medley, first 2 times in Strathspey time, 3rd and 4th in Reel', 72, '8800/8880/8888/8444', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3009, '1997-04-03 22:00:00+00', '2019-03-15 20:13:43.304193+00', 'Humberstone''s Magic Piano', 'HUMBERSTONES MAGIC PIANO', 3, 32, 9999, 1, 4, 2, 270, NULL, '', 75, '8008/8448/8888/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1125, '1997-08-31 22:00:00+00', '2019-03-18 23:53:38.898591+00', 'Celtic Brooch, The', 'CELTIC BROOCH', 2, 192, 9999, 6, 3, 54, 129, '1964-01-01', 'This is a demonstration dance written by Hugh Foss for 3 couples arranged in a triangular shape. According to the instructions *the women stand about six yards from each other, at the comers of a triangle. The men stand about a yard inside the triangle. All face partners.*



Hugh Foss describes three different sets (of elementary, intermediate and advanced level). Every set comprises six figures of 32 bars each. 



In addition Hugh Foss describes 57 varieties and other possible setting for demonstrations.



Since the publication contains so many variations with different figures for different levels of dancers, it is not very sensible to try to add all of these to the database entry of the dance.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1050, '2002-11-26 23:00:00+00', '2019-03-19 00:08:48.754526+00', 'Carrick Farmer, The', 'CARRICK FARMER', 2, 32, 9999, 2, 3, 17, 517, NULL, '', 75, '844/778/338/488', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5966, '1998-04-19 22:00:00+00', '2019-03-16 04:16:03.411477+00', 'Scottish Werewolf, The', 'SCOTTISH WEREWOLF', 2, 32, 9999, 2, 3, 17, 1266, NULL, 'Iain Boyd writes:  "The Scottish Werewolf" was devised by Denise Sander one evening when I was late arriving at the Johnsonville Children''s Class. I suggested that the dance should have a name. At the end of the class my group decided to name it in my ''honour''. I have a very good idea who was responsible for the choice of name.', 31, '800/880/800/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10737, '2002-07-24 22:00:00+00', '2019-03-16 11:51:57.499103+00', 'Portadown Strathspey, The', 'PORTADOWN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 28, NULL, 'A dance for Mrs Patricia Hodges on the occasion of her retirement after teaching the Portadown class for fifty years.', 59, ' 880/822/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2911, '1997-09-04 22:00:00+00', '2019-03-16 12:20:20.690779+00', 'Highland Gathering', 'HIGHLAND GATHERING', 3, 32, 9999, 4, 4, 13, 995, NULL, '', 81, '8484/8888/8888/4444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2811, '1997-09-12 22:00:00+00', '2019-03-16 13:07:04.961695+00', 'Haste Ye Back To Bonnie Scotland', 'HASTE YE BACK TO BONNIE SCOTLAND', 1, 32, 9999, 1, 4, 1, 126, NULL, '', 81, '8888/6666/8664/8466', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (898, '1997-09-29 22:00:00+00', '2019-03-19 00:29:28.990294+00', 'Ca'' Canny', 'CA CANNY', 3, 32, 9999, 2, 3, 18, 13, NULL, '', 83, '844/866/866/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19242, '2019-03-17 01:24:57.611791+00', '2019-03-17 01:56:20.256702+00', 'Mrs Walker of Birklands', 'MRS WALKER OF BIRKLANDS', 1, 32, NULL, 1, 3, 42, 1649, '2000-01-01', 'Devised for his (in 2019, late) wife Carol Walker', 58, '844/864/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8157, '1998-10-12 22:00:00+00', '2019-03-16 14:30:59.869561+00', 'Stern Polka', 'STERN POLKA', 13, 48, 9999, 5, 1, NULL, 1995, NULL, 'Music: original tune (essentiRl), 2/4 time in 3 sections. On the RSCDS CD Scottish Country Dancing Vol. 1, the music for ''C'' is 8 8 bars, which is the way it is played in some areas.



Source: dance originally devised by B.M. and T. Edney. Collected by Barbara Gibbons.

276', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2760, '1998-04-12 22:00:00+00', '2019-03-16 15:52:35.516198+00', 'Hands Across the Border', 'HANDS ACROSS THE BORDER', 3, 32, 9999, 1, 4, 1, 212, '1990-01-01', '', 84, '8888/8888/8880/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2708, '1998-01-05 23:00:00+00', '2019-03-16 16:08:34.584006+00', 'Gushic Neuk', 'GUSHIC NEUK', 1, 48, 9999, 1, 4, 1, 978, NULL, '', 63, '8880/8880/8000/8880/8000/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2540, '1997-09-03 22:00:00+00', '2019-03-16 16:33:06.423676+00', 'Glen Garry Medley, The', 'GLEN GARRY MEDLEY', 4, 32, 9999, 1, 4, 1, 961, NULL, '', 56, '8888/8800/8040/8004', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11178, '2003-02-12 23:00:00+00', '2019-03-17 00:35:11.145409+00', 'Happy and Glorious', 'HAPPY AND GLORIOUS', 3, 32, 9999, 1, 100, 2, 3316, '2002-01-01', 'To celebrate the Golden Jubilee of Her Majesty The Queen.', 88, '8888/8008/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2089, '1997-04-03 22:00:00+00', '2019-03-17 11:41:40.88079+00', 'Farewell To Miller''s Forest', 'FAREWELL TO MILLERS FOREST', 3, 32, 9999, 1, 4, 1, 109, NULL, '', 81, '8484/8080/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2020, '2001-12-19 23:00:00+00', '2019-03-17 12:03:53.956921+00', 'Exciseman, The', 'EXCISEMAN', 1, 32, 9999, 4, 5, 93, 2980, NULL, '', 71, '26268/62628/88888/22868', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2014, '1997-04-03 22:00:00+00', '2019-03-17 12:08:58.22263+00', 'Everlasting Friendship, The', 'EVERLASTING FRIENDSHIP', 3, 48, 9999, 1, 4, 1, 414, NULL, '', 54, '8000/8440/8880/8880/8080/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (502, '1998-04-05 22:00:00+00', '2019-03-17 13:47:42.466053+00', 'Follow Your Dreams', 'FOLLOW YOUR DREAMS', 1, 32, 9999, 1, 3, 42, 44, '1993-01-01', '', 50, '800/844/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1720, '1997-12-21 23:00:00+00', '2019-03-17 22:56:41.311025+00', 'Doune Mill, The', 'DOUNE MILL', 2, 32, 9999, 1, 4, 1, 9, NULL, '', 83, '8668/8888/8888/8006', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1566, '1998-01-11 23:00:00+00', '2019-03-17 23:26:38.496007+00', 'Welcome to Claggan', 'WELCOME TO CLAGGAN', 3, 32, 9999, 1, 4, 1, 535, '1993-01-01', 'Devised by Ian Harmsworth of Heysham.  Claggan is the name of a converted farmhouse near Bridgend, Islay, where dancers from North Lancashire stey when attending the RSCDS Islay Branch Weekend School.  Welome to Claggan was first danced there in May 1993.', 88, '6666  8088  8888  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (1477, '1997-04-03 22:00:00+00', '2019-03-18 10:41:20.201917+00', 'Culzean Castle', 'CULZEAN CASTLE', 2, 32, 9999, 1, 4, 1, 48, '1991-01-01', '', 56, '4444/4444/8008/8088', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1378, '1997-08-31 22:00:00+00', '2019-03-18 11:27:01.792457+00', 'Covenanter''s Reel, The', 'COVENANTERS REEL', 1, 32, 9999, 1, 4, 1, 95, NULL, '', 63, '8448/8008/4884/4444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1204, '2002-03-03 23:00:00+00', '2019-03-18 16:27:49.702615+00', 'Chrysanthemum', 'CHRYSANTHEMUM', 1, 96, 9999, 4, 4, 3, 152, '1986-01-01', '', 92, '4444/4444/8888/8888/8888/8888/8888/8888/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2492, '1998-04-12 22:00:00+00', '2020-08-04 21:23:52.405383+00', 'Glasgow Assembly', 'GLASGOW ASSEMBLY', 4, 64, 5, 1, 4, 1, 62, '1973-01-01', '', 68, '8444/4488/8888/8844/8600/8800/8022/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (964, '1998-11-14 23:00:00+00', '2021-04-18 12:15:33.931299+00', 'Cambuskenneth', 'CAMBUSKENNETH', 3, 80, 9999, 4, 4, 3, 108, '1988-01-01', 'Drewry writes that Cambuskenneth Abbey is on the banks of the River Forth near Stirling.', 85, '8888/8080/8888/8888/8888/0808/8888/8888/4444/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3987, '2002-11-26 23:00:00+00', '2021-06-12 10:41:00.194811+00', 'Lucy Helen''s Strathspey', 'LUCY HELENS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 3124, NULL, 'Devised to celebrate the birth of the deviser''s granddaughter, Lucy Helen Thompson.', 75, '800/888/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1513, '1997-04-03 22:00:00+00', '2021-06-18 08:33:58.771555+00', 'Dan the Cobbler', 'DAN THE COBBLER', 2, 32, 9999, 1, 3, 42, 270, NULL, '', 73, '888/888/868/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1202, '1997-11-27 23:00:00+00', '2019-03-18 23:39:45.408556+00', 'Christmas Tree, The', 'CHRISTMAS TREE', 4, 64, 5, 1, 4, 3, 325, NULL, '', 94, '8888/8888/8888/8888/8888/8888/4444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (188, '1998-04-04 22:00:00+00', '2019-03-19 23:41:14.805507+00', 'Anniversary Tensome, The', 'ANNIVERSARY TENSOME', 1, 32, 9999, 4, 5, 33, 313, NULL, '', 66, '88888/08088/80808/24048', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18, '1998-01-11 23:00:00+00', '2019-03-20 00:26:28.116818+00', 'Acadian Jig, The', 'ACADIAN JIG', 2, 48, 9999, 1, 4, 14, 108, '1984-01-01', '''Glasgow Highlander''s''  sets', 79, '4444/8888/4444/6666/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19389, '2019-06-04 09:02:21.59586+00', '2019-06-08 12:10:13.324819+00', 'Budapest Fun', 'BUDAPEST FUN', 1, 32, NULL, 1, 3, 42, 3414, '2018-10-14', '', 50, '800/844/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18560, '2018-09-08 11:16:39.189586+00', '2019-04-04 11:36:55.419493+00', 'Claudia''s Barn Dance', 'CLAUDIAS BARN DANCE', 1, 32, NULL, 8, 6, 47, 10759, '2018-08-20', 'Devised by Judith Kowalczik for Claudia Koch-Fänger to celebrate her 60th Birthday in 2018.  



Note: Bars 17 – 24 are inspired by the dance ''''Back to Back'''' devised by Terry Glasspool and published in the book ''''An Itch to Dance'''' which contains complete ''''pushme-pullyou reels''''.', 56, '888888/666666/666666/777777', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8081, '1997-12-03 23:00:00+00', '2019-03-21 00:21:26.693903+00', 'Through the Garden Gate', 'THROUGH THE GARDEN GATE', 2, 32, 9999, 1, 2, 76, 598, NULL, 'This dance was devised as an introduction to the polite turn in a beginners class.  

I usually teach this dance just before introducing rights and lefts. {Deanna Saint Amand)', -1, '440/440/800/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19336, '2019-05-12 09:48:23.33785+00', '2019-05-27 09:54:05.006856+00', 'King Of Spain''s Daughter, The', 'KING OF SPAINS DAUGHTER', 3, 32, NULL, 1, 3, 42, 44, '2013-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16828, '2015-12-14 17:22:27.398807+00', '2019-03-24 10:39:41.005952+00', 'Dinner for One', 'DINNER FOR ONE', 1, 32, NULL, 2, 3, 17, 10759, '2015-01-01', 'This dance is based on the movie “<<https://en.wikipedia.org/wiki/Dinner_for_One|Dinner for One>>” with Freddie Frinton starring as James and May Warden as Miss Sophie, which was originally released in 1963 and is traditionally watched on New Year''s Eve by many Germans. [This is really an 18-minute sketch which, in spite of its cult status in Germany, is virtually unknown in the UK. The Wikipedia page linked to above explains it in detail and also points to video of the actual sketch.]



The plot: It is Miss Sophie''s 90th birthday. As every year she hosts a celebration dinner for her dear

guests Sir Toby, Admiral von Schneider, Mr. Pommeroy and Mr. Winterbottom. Due to Miss

Sophie''s considerable age, she has outlived all of her friends. So her equally aged butler James

makes his way around the table, impersonating each of the guests in turn and getting terribly drunk.



Devised by Judith Kowalczik in January 2015 and dedicated to all members and friends of the

Scottish Country Dance group “Potter''s Pairs” from Oldenburg who prefer dancing into the new

year instead of sitting in front of the TV!



DEVISED:2015-01', 78, '822/888/744/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19248, '2019-03-25 21:17:08.145985+00', '2019-03-25 21:24:47.106437+00', 'Sally''s Rally', 'SALLYS RALLY', 2, 40, NULL, 1, 3, 42, 165, '2009-01-01', '', 60, '8400/4466/8260/8044/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19249, '2019-03-25 21:45:49.175759+00', '2019-03-25 21:45:49.175759+00', 'Heather & Sally''s Charity Jig', 'HEATHER AND SALLYS CHARITY JIG', 2, 32, NULL, 1, 3, 42, 11002, '2018-01-01', '', 56, '800/844/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13085, '2006-11-10 23:00:00+00', '2019-03-27 11:51:45.352145+00', 'Patti''s Pleasure', 'PATTIS PLEASURE', 3, 32, 9999, 1, 3, 42, 2862, '2006-05-01', '''The dance is named for Patti Cobb. It was fIrst danced on September 26, 2006. The gypsy poussette is drawn from Terry Glasspool''s "Gypsy Dreams" and the figure of eight grand chain is drawn from Ian Barbour''s "Equilibrium."-GK', 50, '880/800/12 12 12/400', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19379, '2019-06-01 16:15:08.17491+00', '2019-06-04 15:09:22.231073+00', 'Finding You', 'FINDING YOU', 3, 56, NULL, 2, 3, 18, 11816, '2017-01-01', 'A recording of music for this dance can be found at <<https://youtu.be/zcYa9I9FHn0>>', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19298, '2019-05-09 15:29:40.401068+00', '2019-05-09 15:29:40.401068+00', 'Forfar Fancy', 'FORFAR FANCY', 3, 32, NULL, 1, 4, NULL, 743, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19388, '2019-06-04 08:55:31.615125+00', '2019-06-04 16:46:16.638302+00', 'Right Partner, The', 'RIGHT PARTNER', 1, 32, NULL, 7, 113, 4, 11816, '2018-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19376, '2019-06-01 15:53:15.242368+00', '2019-06-08 12:15:43.16071+00', 'Znojmo Sixsome', 'ZNOJMO SIXSOME', 1, 32, NULL, 5, 56, NULL, 2688, '2017-01-01', 'Devised for the 3rd annual gathering for Austrian, Czech, Slovak and Hungarian SCD dancers (and friends) held in Znojmo, Czech Republic in 2018.', 100, '88/88/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19381, '2019-06-01 16:58:48.398478+00', '2019-06-02 16:51:31.351926+00', 'Fairmount', 'FAIRMOUNT', 3, 32, NULL, 1, 3, 42, 10934, NULL, 'Fairmount Park is a favorite spot in Philly for hikes, outdoor concerts, and the May Day ritual dancing.', 56, '844/666/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19419, '2019-06-24 09:34:22.105759+00', '2019-06-27 11:40:58.210811+00', 'Moira McInnes of Troon', 'MOIRA MACINNES OF TROON', 1, 32, NULL, 1, 3, 42, 640, '2019-01-01', 'Inscribed to Moira McInnes.', 47, '800/888/808/770', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19412, '2019-06-24 08:49:13.570922+00', '2019-06-27 11:39:38.799545+00', 'Sue Meek''s Strathspey', 'SUE MEEKS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 640, '2019-01-01', 'Inscribed to Sue Meek of Dalry, Ayrshire.', 61, '510/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19418, '2019-06-24 09:28:15.407987+00', '2019-06-27 11:40:48.831607+00', 'John Henderson''s Reel', 'JOHN HENDERSONS REEL', 1, 32, NULL, 1, 3, 42, 640, '2019-01-01', 'Inscribed to John Henderson of Glasgow.', 50, '800/808/888/484', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9376, '2002-03-24 23:00:00+00', '2020-12-07 13:05:19.041626+00', 'Rush Hour Reel', 'RUSH HOUR REEL', 1, 48, 9999, 2, 3, 17, 2706, '1998-01-01', 'Devised by Eric Dam in 1998 to the drive home after work: There is the initial stop and go traffic, the merging on to the freeway, the chaos of lane switching, finally a stretch of empty space to accelerate in, followed by the realization that you forgot to stop at the store, and then the fun of trying to park at the mall.', 72, '888/888/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19365, '2019-05-30 22:05:25.048775+00', '2021-02-23 18:01:14.544522+00', 'Reel for Iris, A', 'REEL FOR IRIS', 1, 32, NULL, 1, 4, 1, 3325, '2013-03-01', 'This dance was devised to mark the 50th birthday of Iris Ronayne on 19 March 2013 and is a celebration of her love for SCD and was first danced at her birthday party, as a gift, by her friends.', 70, '8820/8888/8844/8800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10842, '2002-09-26 22:00:00+00', '2021-04-03 12:20:06.314019+00', 'Toast to the Ladies, A', 'TOAST TO THE LADIES', 3, 96, 9999, 4, 4, 3, 1641, '1998-01-01', 'Devised for a competition of the Adelaide Branch (S. Australia) to celebrate the 75th Anniversary of the Society.', 100, '8/8/8/8/8/8/8/8/8/8/8/8', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19420, '2019-06-24 09:40:36.120422+00', '2019-06-27 11:41:08.207736+00', 'Marilyn Thomson''s Jig', 'MARILYN THOMSONS JIG', 2, 32, NULL, 1, 3, 42, 640, '2019-01-01', 'Inscribed to Marilyn Thomson of Saltcoats.', 44, '800/844/844/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19422, '2019-06-24 09:49:38.683256+00', '2019-06-27 11:41:28.294435+00', 'Dalgarven Mill', 'DALGARVEN MILL', 1, 32, NULL, 1, 3, 42, 640, '2019-01-01', '', 56, '800/888/888/484', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19421, '2019-06-24 09:45:34.094665+00', '2019-07-13 17:56:45.504518+00', 'Horse Isle', 'HORSE ISLE', 3, 32, NULL, 2, 3, 18, 640, '2019-01-01', '', 88, '844/888/888/884', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13488, '2009-11-20 23:00:00+00', '2019-03-27 12:16:30.541686+00', 'Mrs Eightfold', 'MRS EIGHTFOLD', 4, 64, 5, 1, 4, 1, 3783, NULL, 'For Yaeko Yasoshima of Yokosuka



"Yae" can be translated as "folded eight times" but I believe her name means "a flower with eight

petals". lt may be her name that has made her a versatile lady.



Unfortunately the name of the CD is misspelt as Mrs Eightford.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13572, '2010-04-14 22:00:00+00', '2019-03-28 10:55:11.874041+00', 'Newton Shore', 'NEWTON SHORE', 1, 40, NULL, 1, 3, 42, 10360, NULL, 'Newton Shore is part of the Ayrshire coast well known for its swirling tides depicted by the formations in the dance.', 60, '844/844/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19386, '2019-06-02 21:49:35.946819+00', '2019-06-02 21:49:35.946819+00', 'Clink the Glass', 'CLINK THE GLASS', 1, 32, NULL, 2, 3, 18, 10632, '2016-01-01', 'Devised in 2016 to celebrate the 150th ceilidh of the Budapest Scottish Dance Club.', 79, '444/880/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19252, '2019-04-01 23:33:27.317649+00', '2019-06-04 17:54:17.152675+00', 'Emma''s Strathspey', 'EMMAS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 3646, NULL, 'Trudy Roughgarden devised the dance and also composed the lead tune, both in honour of her daughter-in-law, formerly Emma Dickson; she has generously made the sheet music available as Emma''s Strathspey - Violin Score and Emma''s Strathspey - Piano Score.', 59, '884/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19250, '2019-03-31 19:50:14.883104+00', '2019-03-31 21:42:46.771292+00', 'Dashing White Circle', 'DASHING WHITE CIRCLE', 1, 32, NULL, 5, 1, 4, 9998, NULL, '', 100, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19256, '2019-04-03 12:51:48.545346+00', '2019-04-03 13:12:15.545503+00', 'Falstone Jig, The', 'FALSTONE JIG', 2, 32, NULL, 1, 3, 42, 3694, NULL, 'The original instructions are not clear for the reels [17-24], the way to reach (2,1,3) is not described explicitly.  The most elegant is 6-bar reels of 3, followed by changing places at the bottom on [23-24].', 62, '880/808/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13768, '2011-07-13 22:00:00+00', '2019-04-02 20:44:05.688528+00', 'Hudson Landing', 'HUDSON LANDING', 1, 32, NULL, 1, 3, 42, 2973, '2009-07-01', 'With thanks to Jim Rae whose ‗Dancing in the Cuckoo‘s Nest‘ inspired bars 9 to 16.



Devised in July 2009. 



The dance recalls the miraculous landing on 15 January 2009 of US Airways

Flight 1549 on the Hudson River, just a mile or two south of our home in Edgewater.



Music Rakes of Mallow. 

A suitable recording is ‗Cromarties Rant‘, RSCDS Books 31 &

32, Alistair Wood and his Scottish Country Dance Band, track 10.', 83, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19251, '2019-03-31 22:31:51.048089+00', '2019-04-05 00:55:59.851285+00', 'Lassies on the Green, The', 'LASSIES ON THE GREEN', 3, 32, NULL, 2, 3, 18, 123, NULL, 'Found on the Luxembourg programme for 2019-05-17', 83, '880/088/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19207, '2019-03-02 10:24:04.744593+00', '2019-04-06 10:03:51.895899+00', 'Redland Reel, The', 'REDLAND REEL', 1, 32, NULL, 1, 3, 42, 3165, NULL, 'Music:  Will go with any good reel by Don Bartlett or Marian Anderson', 53, '800/866/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19257, '2019-04-03 13:13:23.727361+00', '2019-04-03 13:32:12.572811+00', 'Lucky Strathspey, The', 'LUCKY STRATHSPEY', 3, 32, NULL, 2, 3, 17, 3694, NULL, '', 92, '888/880/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19299, '2019-05-09 15:35:49.021006+00', '2019-05-09 15:35:49.021006+00', 'Freya''s Jig', 'FREYAS JIG', 2, 48, NULL, 1, 4, 13, 743, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19272, '2019-04-12 16:13:11.837947+00', '2019-05-03 21:06:25.148594+00', 'David''s Warm Welcome', 'DAVIDS WARM WELCOME', 1, 32, NULL, 8, 6, 47, 11804, '2019-04-01', 'Devised in memory of David Talbot, Kathy''s husband, who always made any newcomer to SCD feel very welcome, no matter what their dancing ability. This dance captures how he would often add an extra "twirl" or "Birl" whenever he could, making it more fun.', 50, '800008/844448/484484/800008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19305, '2019-05-09 15:54:36.462207+00', '2019-05-09 15:54:36.462207+00', 'Grady''s Gambol', 'GRADYS GAMBOL', 2, 40, NULL, 1, 4, 1, 743, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19311, '2019-05-11 23:52:55.98752+00', '2019-05-11 23:52:55.98752+00', 'Men of Hoy', 'MEN OF HOY', 1, 32, NULL, 5, 56, NULL, 374, '2006-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19314, '2019-05-12 00:01:13.558715+00', '2019-05-12 00:01:13.558715+00', 'Welcome to Hoy', 'WELCOME TO HOY', 1, 32, NULL, 5, 2, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19532, '2019-08-12 08:31:16.341823+00', '2019-08-12 08:31:16.341823+00', 'Lisa''s Fancy', 'LISAS FANCY', 3, 32, NULL, 1, 3, 42, 11853, NULL, '', 63, '888/888/880/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19411, '2019-06-23 23:26:33.825951+00', '2020-09-19 09:35:04.265112+00', 'Jig Time', 'JIG TIME', 2, 32, NULL, 1, 3, 42, 640, '2019-01-01', '', 58, '880/880/888/864', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13292, '2007-06-20 22:00:00+00', '2020-09-30 11:42:15.244373+00', 'St Jerome''s Reel', 'SAINT JEROMES REEL', 1, 32, 9999, 3, 5, 44, 2924, '2000-01-01', '', 65, '80008/80808/88888/48444', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19302, '2019-05-09 15:46:56.924677+00', '2021-01-04 17:25:10.137642+00', 'Alexandra House', 'ALEXANDRA HOUSE', 3, 32, NULL, 1, 4, 1, 743, NULL, '', 91, '8888/8888/8448/8488', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (214, '1998-01-05 23:00:00+00', '2021-03-02 21:27:26.257486+00', 'Argyll', 'ARGYLL', 1, 32, 9999, 1, 2, 76, 213, NULL, 'The available instructions say "Taught by Miss Milligan during her visit in Apr-May 1975".  These instructions have an error, see the two cribs.



Stephen Webb, in <<https://my.strathspey.org/dd/issue/2336/|issue 2336>>, gives details of the corrections made on the spot by Jean Milligan at that London Branch day school. This information is not yet incorporated in the cribs.', 60, '44/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13446, '2009-11-16 23:00:00+00', '2021-03-27 21:51:23.054916+00', 'Away Tae Moray', 'AWAY TAE MORAY', 1, 32, 9999, 1, 3, 42, 1582, '2008-07-01', 'The dance "Away Tae Moray" was composed in July 2008 for the chairman of the RSCDS Inverness and District Branch.  It was included in their 2009 "Diamond Jubilee Collection" under the name "The Telford Hornpipe".  The deviser republished the dance in her own "The Corberry Collection" using the original name, which she prefers.  

', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19271, '2019-04-11 08:11:54.779071+00', '2021-07-15 22:24:59.871258+00', 'Airing Your Oxters', 'AIRING YOUR OXTERS', 1, 40, NULL, 1, 3, 42, 704, '2018-07-24', 'Dedicated to Elaine Brunken. In January 2013, Elaine came to the Delaware Valley to teach a weekend workshop. At one point, in exhorting the class to keep their hands up, she said “You need to air your oxters!” Nobody knew what she meant, so she explained that “oxters” is a Scottish term for armpits. In this dance, first couple is always airing at least one of their oxters.', 50, '800/884/844/822/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4758, '1997-09-10 22:00:00+00', '2021-07-20 08:54:13.48644+00', 'Mrs Hamilton of Wishaw', 'MRS HAMILTON OF WISHAW', 3, 32, 9999, 1, 2, 76, 1160, '1803-01-01', 'The original instructions in Whetherly Book 24, derived from an 1803 text,  specify "set" for 4 bars starting on bar 1 and 9, but give no further information on how to do this.', 43, '44/44/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14738, '2013-03-14 17:48:58.045013+00', '2019-04-03 20:16:40.079519+00', 'Chasing the Eclipse', 'CHASING THE ECLIPSE', 3, 32, 9999, 2, 3, 18, 703, '2013-02-01', 'Devised for Mike and Eilean Yates, formerly of Shelby North Carolina, in February, 2013. The Yates'' have been a pillar of dancing in the Carolinas for decades and also been involved in the dancing at the Loch Norman Highland Games almost since the beginning. 



Beyond dancing, Mike''s passion for viewing solar eclipses have taken them all over the world. You can detect that in the Promenade Chain progression (thanks, Mary!)', 71, '800/888/822/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14543, '2012-08-23 16:10:50.034591+00', '2019-04-03 20:22:00.158722+00', 'Noces d''Argent', 'NOCES DARGENT', 4, 32, 1, 1, 3, 42, 10646, '2012-06-23', 'Dance devised by Mylène Rousseau, on behalf of the RSCDS Paris Branch, for the 25th Wedding Anniversary of Danielle and Jerry Reinstein and introduced at their Anniversary Dance held in Paris on 23rd June 2012.



This dance has been revised on 2017 (last 8 bars of the reel).', 56, '880/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19264, '2019-04-07 15:00:16.199705+00', '2019-04-07 15:00:16.199705+00', 'Love''s Hesitation', 'LOVES HESITATION', 1, 40, NULL, 1, 3, 42, 11534, NULL, '', 55, '800/888/888/888/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19265, '2019-04-07 15:07:15.796309+00', '2019-04-07 15:07:15.796309+00', 'Birlin'' Corners', 'BIRLIN CORNERS', 2, 40, NULL, 3, 5, 7, 11534, NULL, 'Devised with fond memories of endlessly birling with uiversity students in Scotland. Please note that pivot turns may be replaced by right hand turns if desired.', 70, '80800/84884/84884/86846/84844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14688, '2013-01-28 20:32:10.324379+00', '2019-04-05 22:51:49.636646+00', 'Monica''s Way', 'MONICAS WAY', 2, 32, 9999, 1, 100, 11, 3610, NULL, 'Source: the youtube video https://www.youtube.com/watch?v=Q5RyjqXCTaA&feature=relmfu



Devised for Monica Roots on the occasion of her retirement in 2007 from six years of teaching on Salt Spring Island.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15087, '2013-08-23 18:24:54.99275+00', '2019-04-18 21:45:07.230607+00', 'Have a Good Weekend', 'HAVE A GOOD WEEKEND', 4, 64, 5, 1, 4, 54, 10623, NULL, 'This dance is under revision and is presently withdrawn.



Extensive description in the book. The dance was devised as a "tongue-in-cheek" description of work in the corporate world, from waiting for the morning bus, through time-wasting pointless meetings, a hurried lunch, more meetings and rushing home for the weekend with a hint of an office romance thrown in. ', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4759, '1998-09-29 22:00:00+00', '2019-04-05 23:42:17.317236+00', 'Mrs Hamilton of Wishaw', 'MRS HAMILTON OF WISHAW', 3, 32, 9999, 1, 3, 42, 108, '1967-01-01', 'The instructions for 1st couple on bars 15-16 have changed.



Drewry''s original text in Book 23 says: "First couple, giving right hands cross to own sides, dance up to the top and turn to face the second couple who have danced in ready for the Rondel."



The later Pocket Book 23 has the text: "First couple, giving right hands, dance up turning halfway round to finish  facing second couple ready for the Rondel." 



The issue was discussed at the Technique Committee, see https://www.rscds.org/learn/resources-dancers/technique-advisory-panel-dances and search for Mrs. Hamilton of Wishaw.  Apparently the old version was specified in the "Prescribed Dances for the Teacher''s Certificate Examination (2003)", the new version in the same for 2008.  



The Committee answered: "When we reviewed the Manual [this is the 2nd. edition, 2004. EF] we looked at the latest publication (the Pocket edition in this case) and any ambiguity was referred back to the video as the final word. In this case the two are in agreement for first couple although the handing for second couple is not clear. It was felt therefore there was no need for a Manual note in chapter 7. The earlier A4 book instructions certainly imply a different way of finishing the reel in today''s terminology and I doubt if there is a record of why the wording was changed - the intention may have been to change the way the reel was being danced or simply trying to "clarify" the instructions. In a further attempt at clarification, the Prescribed Dances for the Teacher''s Certificate Examination (2008) now read: "1st couple, giving right hands, dance a half turn as they lead up to finish at first place on own sides in the middle of the set facing down. 2nd couple finish in the middle of the set, facing up and 3rd couple dance to places." This description now brings the movement into line with the formation shown in the video. "



There was a discussion on this issue on Strathspey message 64873 of Thu, 17 Oct 2013 11:27:26 -0400



The E-crib follows the new version.



There are now two videos. 



The one added on 2013-06-01 by Gert Werder follows Drewry''s original instructions.



The "Official RSCDS video" added on 2015-08-29 by Eric Ferguson follows the current revised instructions.



Eric Ferguson, 2016-11-14', 64, '864  888  880  888', 1, 1, 1, 1, 85);
INSERT INTO 'dance' VALUES (19266, '2019-04-07 15:12:48.210254+00', '2019-04-07 15:12:48.210254+00', 'Ladies'' Triumph', 'LADIES TRIUMPH', 3, 32, NULL, 1, 100, 2, 11534, NULL, 'Dedicated to the creative ladies of the German team.', 94, '8888/8888/8448/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19267, '2019-04-07 15:16:13.868163+00', '2019-04-07 15:16:13.868163+00', 'California Double', 'CALIFORNIA DOUBLE', 2, 32, NULL, 1, 4, 2, 11534, NULL, '', 81, '8448/8888/8008/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19260, '2019-04-07 14:40:20.454088+00', '2019-04-07 22:44:00.117226+00', 'Memories from Lyon', 'MEMORIES FROM LYON', 3, 32, NULL, 2, 3, 17, 11534, '2016-04-10', 'Devised on the way home from RSCDS Lyon Branch''s 30th anniversary weekend 8-10 April 2016.', 63, '840/822/844/848', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19052, '2018-11-10 15:52:09.051684+00', '2019-04-06 22:02:16.712369+00', 'Regards to Helensburgh', 'REGARDS TO HELENSBURGH', 1, 32, NULL, 1, 3, 42, 10648, '2018-01-01', '', 50, '880/888/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19259, '2019-04-07 14:35:40.507796+00', '2019-04-07 14:35:40.507796+00', 'Wood Splitter, The', 'WOOD SPLITTER', 2, 32, NULL, 1, 3, 42, 11534, NULL, '', 53, '880/808/804/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19261, '2019-04-07 14:44:52.504008+00', '2019-04-07 14:44:52.504008+00', 'Taste of Home, A', 'TASTE OF HOME', 1, 32, NULL, 1, 3, 42, 11534, NULL, '', 42, '800/877/800/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19262, '2019-04-07 14:49:59.129625+00', '2019-04-07 14:49:59.129625+00', 'Venison and Kale', 'VENISON AND KALE', 2, 40, NULL, 1, 3, 42, 11534, '2017-05-06', 'Devised for Pate and Laura McKale''s wedding on the 6th May 2017 in Edinburgh.', 53, '400/808/880/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19263, '2019-04-07 14:56:31.969702+00', '2019-04-07 14:56:31.969702+00', 'Stroll in Munich, A', 'STROLL IN MUNICH', 3, 32, NULL, 1, 3, 42, 11534, NULL, 'Devised in memory of Munich Scottish Association''s 2016  Whitsun Course and dedicated to an exceptional and mesmerizing partner.', 38, '800/880/800/808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19269, '2019-04-08 21:37:49.801424+00', '2019-04-08 22:22:21.064944+00', 'Ramsay''s Fancy', 'RAMSAYS FANCY', 3, 32, NULL, 2, 3, 17, 10957, '2018-01-01', 'Dedicated to Ramsay Morrison, a long time member of the St. Catharines Branch of the RSCDS and friend to all.  He always greeted you with a smile, a pleasant conversation and a joke or two.

Carol Howe 2018

', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13889, '2011-08-22 22:00:00+00', '2019-04-11 10:58:30.013655+00', 'Still Buzzing', 'STILL BUZZING', 1, 32, NULL, 1, 3, 42, 2788, '2004-03-01', 'This dance was written for John Ferguson, a stalwart member of the demonstration team of the Newcastle and District Branch of the RSCDS, on the occasion of his fiftieth birthday.', 41, '800/844/833/833', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19318, '2019-05-12 00:08:08.334664+00', '2019-05-12 00:08:08.334664+00', 'Ladies of Hoy', 'LADIES OF HOY', 1, 32, NULL, 4, 4, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19288, '2019-05-06 21:32:27.287792+00', '2020-08-08 11:08:49.714585+00', 'Seal and the Beaver, The', 'SEAL AND THE BEAVER', 2, 32, NULL, 1, 100, 2, 11807, '2018-08-01', 'Written for Louise and Joshua Msika, on the occassion of their wedding, August 2018





', 62, '8000/8008/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18851, '2018-10-06 19:37:40.722648+00', '2019-04-13 00:46:09.109296+00', 'One for All', 'ONE FOR ALL', 1, 32, NULL, 1, 3, 42, 2682, '2018-09-21', 'Devised 21/9/2018 as simple teaching dance for corners pass and turn. I use this after teaching the figure in Strathspey time using Miss Leslie Cunningham. Note that there are no figures aside from completely straightforward ones. The name is to suggest that this is one all can do, and also for Muriel Johnstone''s tune of the same name, played ABAB. An excellent recording to use is \Clydeside Lassies" as recorded by Luke Brady in part 5 of Dances from the Miscellany, where Muriel''s tune appears as the second tune.', 50, '880/800/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14560, '2012-09-04 00:41:06.206456+00', '2019-04-20 22:10:54.455102+00', 'Edison Circle', 'EDISON CIRCLE', 2, 32, NULL, 7, 98, 4, 1309, '2001-09-01', 'I''ve been teaching SCD to 3rd- and 5th-grade classes this fall, and wanting to start with an easy dance with no partners and no progression that any number could do I devised the Edison Circle.  (I''m teaching at the Edison School.)  Here it is for anyone who''d like to try it.



Original description submitted to Strathspey List on 8 Nov 2001.



Edison Circle           4 x 32 J for any number of dancers in a circle, all facing the center



1-8:               All dance hands round to the left and back to the right. (Younger children may do better with 8 bars to the left only.)



9-16:            Facing the center, all advance and retire twice.



17-20:          All dance spring points right, right, left, left, right, right, left, left.



21-24:          All clap 8 times.



25-32:          All dance 8 skip change of step clockwise.

', 100, '8  8  8  8', 1, 1, 1, 0, 100);
INSERT INTO 'dance' VALUES (19273, '2019-04-13 16:14:15.170423+00', '2019-04-13 16:27:17.20971+00', 'It''s Nicola''s Round!', 'ITS NICOLAS ROUND', 2, 32, NULL, 5, 2, 76, 11306, '2019-02-01', 'I have devised this easy starter dance for the RSCDS Birmingham Summer Social 2019.

', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7079, '1997-11-27 23:00:00+00', '2019-04-20 09:42:34.821025+00', 'When In Doubt, Dance Petronella', 'WHEN IN DOUBT DANCE PETRONELLA', 4, 128, 2, 4, 4, 3, 678, NULL, '', 81, '8080/8484/8888/8888/0808/4848/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3188, '1998-07-08 22:00:00+00', '2019-04-18 22:41:04.494494+00', 'Jacobite Reel', 'JACOBITE REEL', 1, 32, 9999, 1, 100, 2, 313, NULL, '', 69, '8008/8228/8228/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19363, '2019-05-27 08:24:36.677566+00', '2022-12-13 23:14:40.207375+00', 'Judith''s Strathspey', 'JUDITHS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 3775, '2019-05-01', 'Dedicated to Judith Kowalczik who developed the new figure Corners Chase and Turn.', 56, '880/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19270, '2019-04-10 13:49:06.851524+00', '2022-12-25 22:21:51.96295+00', 'Waltz of the Bells (Ceilidh)', 'WALTZ OF THE BELLS CEILIDH', 5, 32, NULL, 5, 1, 54, 9998, NULL, '(Celidh dance)   *Line of Dance is cclw; cpls face LoD NHJ, W on R.*

Full description to be found on the album "Are ye dancin''?" from The Glencraig Scottish Dance Band.

', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12539, '2005-09-24 22:00:00+00', '2019-05-02 21:39:06.315367+00', 'Never at Sea', 'NEVER AT SEA', 1, 48, 9999, 8, 105, 49, 3633, NULL, 'Devised by John Haddow for Lynn Edington’s 60th Birthday. Lynn was a meteorological officer in the Women’s Royal Naval Service (the “Wrens”). Their role, when founded in  1917, was to release men for sea service by taking over shore jobs, hence their original motto “Never At Sea”. It  was not until 1990, after Lynn had left the Service, that Wrens became full operational members of the Royal  Navy, able to go to sea as part of their service.', 72, '800008/808808/888888/800008/888888/888888', 0, 1, 1, 0, 61);
INSERT INTO 'dance' VALUES (19284, '2019-05-04 13:16:23.509201+00', '2019-05-04 13:24:26.859651+00', 'Dundee Reel (Dundee version)', 'DUNDEE REEL DUNDEE VERSION', 2, 48, NULL, 1, 3, 42, 9998, NULL, 'A secretary of the RSCDS Dundee Branch wites:  I have lived in Dundee for over 30 years but have never danced the Dundee Reel as described in the Border Book. The Dundee Reel as it is danced here is a longer version and is well established in this area. ', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19330, '2019-05-12 09:01:14.34792+00', '2019-05-12 09:01:14.34792+00', 'St Magnus Waltz', 'SAINT MAGNUS WALTZ', 5, 32, NULL, 5, 2, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19320, '2019-05-12 08:32:54.255626+00', '2019-05-12 08:32:54.255626+00', 'Waltz for Mabel', 'WALTZ FOR MABEL', 5, 32, NULL, 5, 1, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19286, '2019-05-04 23:30:11.636427+00', '2019-05-04 23:54:42.194482+00', 'Coleraine Rant, The', 'COLERAINE RANT', 1, 32, NULL, 1, 2, 76, 2682, '2019-03-12', 'This is a beginner’s dance for poussette, and emphasising pas de Basque. It was devised for an Irish-themed St Patrick’s night, as an interesting easy dance; and hence lots of partner contact. Te Mata Coleraine is one if the great wines of New Zealand, and perhaps the world. Its name is derived from the fact that original winemaker John Buck’s grandfather was born in County Coleraine in Northern Ireland, and this name is maintained through the family home and the wine.  ', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19313, '2019-05-11 23:59:45.220687+00', '2019-05-12 08:38:24.335211+00', 'Angus Waltz, The', 'ANGUS WALTZ', 5, 32, NULL, 5, 1, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19319, '2019-05-12 00:09:21.131654+00', '2019-05-12 08:40:04.195335+00', 'Hoy Chase, The', 'HOY CHASE', 1, 32, NULL, 1, 4, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19321, '2019-05-12 08:48:21.520351+00', '2019-05-12 08:48:21.520351+00', 'Orkney Welcome, An', 'ORKNEY WELCOME', 1, 32, NULL, 5, 2, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19322, '2019-05-12 08:49:19.789074+00', '2019-05-12 08:49:19.789074+00', 'Kirkwall Bay', 'KIRKWALL BAY', 11, 16, NULL, 5, 1, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19323, '2019-05-12 08:50:49.534813+00', '2019-05-12 08:50:49.534813+00', 'Kirkwall Two Step', 'KIRKWALL TWO STEP', 50, 16, NULL, 5, 1, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19324, '2019-05-12 08:52:36.921538+00', '2019-05-12 08:52:36.921538+00', 'Festival Saunter', 'FESTIVAL SAUNTER', 50, 16, NULL, 5, 1, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19325, '2019-05-12 08:53:45.041971+00', '2019-05-12 08:53:45.041971+00', 'Lana''s Jig', 'LANAS JIG', 2, 32, NULL, 2, 3, 17, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19329, '2019-05-12 09:00:11.260699+00', '2019-05-12 09:00:11.260699+00', 'Royal Quadrille', 'ROYAL QUADRILLE', 1, 64, NULL, 4, 4, 54, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19331, '2019-05-12 09:02:34.566825+00', '2019-05-12 09:02:34.566825+00', 'Wedding March, The', 'WEDDING MARCH', 11, 16, NULL, 5, 1, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19332, '2019-05-12 09:03:36.051378+00', '2019-05-12 09:03:36.051378+00', 'Wedding Reel, The', 'WEDDING REEL', 1, 32, NULL, 5, 2, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19350, '2019-05-12 10:33:16.256213+00', '2019-05-12 10:33:16.256213+00', 'Chris of Kathmandu', 'CHRIS OF KATHMANDU', 4, 128, 13, 4, 4, NULL, 11002, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19352, '2019-05-12 10:35:49.788202+00', '2019-05-12 10:35:49.788202+00', 'Burnt Tatties', 'BURNT TATTIES', 1, 32, NULL, 1, 2, 76, 11002, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19351, '2019-05-12 10:34:34.676354+00', '2019-05-12 10:36:56.462511+00', 'Memorial Jig for Elizabeth, A', 'MEMORIAL JIG FOR ELIZABETH', 1, 32, NULL, 1, 3, 42, 11002, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19353, '2019-05-12 10:38:38.987566+00', '2019-05-12 10:38:38.987566+00', 'Arbroath Round ''O'' Reel', 'ARBROATH ROUND O REEL', 1, 96, NULL, 8, 105, NULL, 11002, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19349, '2019-05-12 10:31:45.166627+00', '2019-05-12 10:44:34.563461+00', 'Miss Margaret MacIndeor', 'MISS MARGARET MACINDEOR', 3, 32, NULL, 2, 3, 30, 11002, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19416, '2019-06-24 09:18:32.572301+00', '2019-06-27 11:40:27.183152+00', 'Karen Hamilton''s Strathspey', 'KAREN HAMILTONS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 640, '2019-01-01', 'Inscribed to Karen Hamilton of Stevenston, Ayrshire.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13733, '2011-07-10 22:00:00+00', '2020-12-31 12:35:22.765924+00', 'Square Cut Diamond', 'SQUARE CUT DIAMOND', 4, 128, 2, 4, 4, 3, 10363, NULL, 'The dance of the same name in the book "Winchester Branch Diamond Jubilee Dances 1952-2012", devised by Wendy Mumford, is a similar medley with some of the same figures; there could be a relationship.  ', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19079, '2018-12-06 12:28:53.551634+00', '2021-03-13 21:02:40.774354+00', 'Dunfermline to Sarasota', 'DUNFERMLINE TO SARASOTA', 3, 32, NULL, 2, 3, 18, 11756, '2017-01-02', 'One of Dunfermline''s twin cities, Sarasota (Florida, USA) is now home to the interior of the old Dunfermline Opera House as part of the Asolo Center for the Performing Arts. The deviser regularly dances with Dunfermline Branch, and with Sarasota Branch when in Florida, and describes both groups as extremely welcoming and friendly.

', 92, '888/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16608, '2015-08-26 19:01:52.810207+00', '2019-04-14 21:04:12.911026+00', 'Perthshire Lad', 'PERTHSHIRE LAD', 2, 32, NULL, 1, 3, 42, 3183, NULL, 'Devised by Anne Thorn for Nicol McLaren leader of the Glencraig SCD Band.





There is an error in some printed editions of Magic of Music 2.  Bars 17-24 should be:



17-20	1st woman turns 3rd woman once round with the left hand whilst 1st man turns 3rd man once round with the right hand.



21-24	1st woman turns 2nd woman with the right hand whilst 1st man turns 2nd man with the left hand.





=========================

Original



A 32-bar jig for three couples in a four-couple longwise set.  

Bars Description  

1-8 1st couple lead down the middle for three bars and up for three bars then cast off into second place. 2nd couple step up on 7-8.  

9-16 2nd, 1st and 3rd couples dance reels of three on the sides. To begin 2nd couple cast off, 1st couple dance in and down and 3rd couple dance out and up.  

17-20 1st and 3rd woman, giving right hands, 1st and 2nd men, giving left hands, turn once round.  

21-24 1st and 2nd woman, with the right hand, 1st and 2nd man with left hand turn once round.  

25-28 2nd, 1st and 3rd couples advance and retire.  

29-32 2nd, 1st and 3rd couples, giving right hands, turn once round  

Repeat having passed a couple.

Tune: Nicol McLaren O’Blair’s Jig (John Renton)

Devised by Anne Thorn for Nicol McLaren, leader of the Glencraig SCD Band.



', 56, '800/888/844/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19274, '2019-04-17 08:40:42.75384+00', '2019-04-17 08:40:42.75384+00', 'Silver Years, The', 'SILVER YEARS', 3, 32, NULL, 1, 3, 42, 11805, NULL, '“For Mick and Trisha Rawlings on the occasion of their silver wedding anniversary, 2013”', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16126, '2015-02-26 13:01:25.371279+00', '2019-04-18 17:34:06.951713+00', 'Bannockburn 700', 'BANNOCKBURN 700', 2, 40, 9999, 1, 3, 42, 11100, '2013-01-01', 'This dance was devised to commemorate the 700th Anniversary of the Battle of Bannockburn in 1314.





The dance comprises a formation in bars 25-32, that is a progressive variation of a Grand Chain with 2 bars per hand and when dancing across the dancers turn once round instead of crossing. In the original description, this movement was paraphrased as ''Chain progression''. However, ...

The ''Chain Progression'' was seemingly invented by Eric Forbes in the dances ''Summer in Assynt'' and ''Glen Mor'' in the Birmingham Book 1973 ''Twelve Scottish Country Dances'', but the figure in ''Bannockburn 700'' is not similar to Eric Forbes'' figure named ''Chain progression''. Instead there is another figure described in Eric Forbes'' dance ''Ailsa Craig'' in the same book. This figure is referred to as ''Progressive Chain for three couples'' and is indeed identical to the figure in bars 25-32 of ''Bannockburn 700''... seemingly the two figures have been mistaken here.



This figure is now described in the database as "Grand Chain - progressive (with turns)".', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19343, '2019-05-12 10:01:27.109038+00', '2019-05-27 09:57:20.302035+00', 'Dancing In The Wind', 'DANCING IN THE WIND', 1, 32, NULL, 1, 3, 42, 44, '2009-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15837, '2015-01-18 14:52:50.861449+00', '2019-04-18 22:44:20.759183+00', 'Part-time Postie''s Jig, The', 'PARTTIME POSTIES JIG', 2, 32, 9999, 2, 3, 17, 1582, '2005-01-01', 'The original instructions for bars 17-24 have "turn right hand once round, then left hand 3/4 ... to own sides" which seems wrong. The E-crib has swapped right & left hand turns pending clarification from the deviser.', 54, '800/844/800/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (458, '2000-09-03 22:00:00+00', '2019-04-20 08:39:26.997775+00', 'Belhaven', 'BELHAVEN', 4, 360, 41, 1, 4, 3, 129, '1963-01-01', 'A set of 3 diagrams for the complete dance, one for each section (Reel, Strathspey and Jig), may be downloaded from: <<http://my.strathspey.org/u/keithrose/belhaven.pdf>>



Foss notes:  The first movement is complete in itself and may be danced alone if desired.



The tunes are all old. Most of them appear in the Collections and Repositories of Niel Gow and Sons. Mrs Hamilton of Wishaw''s Strathspey is in their 3rd Collection. p. 20, and Lady Belhaven''s Delight in their 4th Collection. p. 34.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14561, '2012-09-04 00:54:37.572815+00', '2019-04-20 22:09:56.492209+00', 'Eagle Circle', 'EAGLE CIRCLE', 2, 24, NULL, 7, 98, 4, 1309, '2001-09-01', 'Edison Circle worked so well that I modified it to add a progression and the kids named the new dance Eagle Circle for the Edison Eagles.  Here it is for anyone who''d like to try it.



Eagle Circle            4x24 J or R for any number of couples in a circle, all facing the center.  Partner on left is #1, partner on right is #2.



1-8:               All dance hands round to the left and back to the right. (Younger children may do better with 8 bars to the left only.)



9-12:            All 1''s advance and retire.



13-16:          All 2''s advance and retire.



17-20:          All dance spring points right, right, left, left, right, right, left, left.



21-22:          Face partner and clap 4 times.



23-24:          Change places with partner giving right hand.



                        Repeat with new partner.



', 83, '8 4 8', 1, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (19276, '2019-04-22 08:44:00.349854+00', '2019-04-22 15:08:56.203577+00', 'Win''s Dance', 'WINS DANCE', 1, 32, NULL, 3, 5, 7, 11789, '2018-08-01', 'Dedicated to Win Balgarnie who organised challenging dances at Welland.', 58, '80800/84884/80800/84844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19278, '2019-04-29 20:46:13.408871+00', '2019-05-01 00:01:24.594963+00', 'Keep Smiling', 'KEEP SMILING', 3, 40, NULL, 2, 3, 17, 11110, '2019-02-01', '', 85, '800/12,12,12/442/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19354, '2019-05-14 22:05:51.520871+00', '2019-05-14 22:06:36.656332+00', 'Little Star', 'LITTLE STAR', 3, 32, NULL, 1, 2, 76, 9998, NULL, 'Source: Dance List "RSCDS New York Branch Classes May 16 2019 " by Sue Ronald, May 14th, 2019', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19358, '2019-05-18 21:30:15.235743+00', '2019-06-17 10:00:38.288129+00', 'Soaring and Swooping', 'SOARING AND SWOOPING', 2, 32, NULL, 1, 3, 42, 11237, '2018-12-01', '', 56, '844/844/866/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3320, '1997-04-03 22:00:00+00', '2020-08-06 15:15:35.554781+00', 'John Grumlie', 'JOHN GRUMLIE', 2, 48, 9999, 1, 3, 42, 129, '1966-01-01', 'No e-crib was made as this dance is unlikely ever to be danced except as a demonstration.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15526, '2014-07-02 19:25:45.139758+00', '2019-04-20 22:12:53.131336+00', 'Flame From Delhi, The', 'FLAME FROM DELHI', 1, 32, NULL, 4, 4, 1, 550, '2014-01-01', 'Hi All,  I wrote this dance for a performance related to the Commonwealth Games which fell through, so I’ll share it here in case anyone is interested in giving it a try.  



The Flame From Delhi   

Square set 4x32R  



1-8         Grand chain all round (1 bar per hand)                   

9-10       Turn ¾ RH to bring women into the middle          

11-12     Women dance LH across half way while men dance one place clockwise  

13-14     Turn ½ RH to bring men into the middle  

15-16     Men dance LH across half way while women dance one place clockwise.  Men finish back to back in the middle facing partner, one place ACW around set.  

17-20     Highland setting  

21-24     Tulloch turn RH, opening out into  

25-28     Circle round to the left  

29-32     All dance into the middle, pull back right shoulders, dance out and chase round to complete the circle. *  

Finish in the order 2, 3, 4, 1 ready to start again



* This mimics the Delhi Commonwealth Games logo



If you want symbolism:  

[1-8] Passing the torch around the world  

[9-16] Coming together  

[17-20] Individual performances, or sizing up the opposition  

[21-24] The combat  

[25-28] All together for the closing ceremony  

[29-32] Dispersing and heading back home  

', 100, '8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3509, '1997-04-03 22:00:00+00', '2019-04-20 22:17:01.281333+00', 'Kinmont Willie', 'KINMONT WILLIE', 2, 48, 9999, 1, 4, 1, 108, '1967-01-01', 'To the members of the Carlisle and Border Branch Advanced Class, who drink coffee under Kinmont Willie''s portrait in the "Crown and Mitre".

Kinmont Willie, the hero of one of the Border Ballads, was an Armstrong who was captured and imprisoned by the citizens of Carlisle. His fellow Scots made a raid across the Border and rescued him out of Carlisle Castle.

In this dance, 1st man represents Kinmont Willie, his partner and 4th couple are the other Scots, while 2nd and 3rd couples are the worthy citizens of Carlisle.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16736, '2015-09-16 11:35:26.696039+00', '2019-04-20 22:23:53.300632+00', 'Rain Dancers, The', 'RAIN DANCERS', 1, 32, NULL, 1, 3, 42, 411, '2013-01-01', 'For the group of American dancers who brought rain to New Zealand in April 2013.', 53, '440/880/440/804/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6513, '1998-04-19 22:00:00+00', '2019-04-20 22:33:25.230532+00', 'Thanks to You All', 'THANKS TO YOU ALL', 1, 128, 9999, 107, 98, 3, 227, '1987-01-01', 'This is a demonstration dance of 4M+8W who form four lines WMW facing in pairs, sideways to the audience.



Music: a lively reel.  ', 83, '3333  3333  3333  3333    0330  0330  0330  0330    3333  3333  3333  3333    2222  2222  3333  3333', 0, 1, 0, 1, 31);
INSERT INTO 'dance' VALUES (5908, '1997-11-25 23:00:00+00', '2019-04-20 23:07:49.919844+00', 'Saxmundham Reel, The', 'SAXMUNDHAM REEL', 1, 80, 9999, 2, 3, 3, 1261, NULL, 'Demonstration dance.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7017, '1997-09-17 22:00:00+00', '2019-04-29 16:48:06.728557+00', 'Welcome Mina Corson', 'WELCOME MINA CORSON', 1, 40, 9999, 1, 3, 42, 3461, '1973-11-01', 'This dance commemorates Mrs. Mina Corson''s visit to North America during the RSCDS Jubilee Year, 1973. Bars 1-16 symbolize travel back and forth across the continent, 17-32 symbolize her meeting many dancers, and 33-40 are the Knot, a new progression which Mrs. Corson had devised that year for the RSCDS jubilee dance "Miss Milligan''s Strathspey."



The dance was first published in the Tartan Times for November, 1973. It has also been published by Scottish Dance Archives, Formby, England.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18282, '2018-04-15 15:04:46.788888+00', '2019-04-22 15:16:55.52269+00', 'Dixon''s Delight', 'DIXONS DELIGHT', 3, 80, NULL, 4, 4, 3, 11627, '2007-01-01', 'Devised to mark the occasion of Dixon Halliday''s 90th birthday.  Dixon is a former teacher of the Abingdon Scottish Country Dance Class.', 65, '8888/8080/0808/8080/0808/4444/8080/0808/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9337, '2000-02-17 23:00:00+00', '2019-04-23 13:42:35.855577+00', 'Tribute to William Wallace, A', 'TRIBUTE TO WILLIAM WALLACE', 2, 32, 9999, 5, 2, 76, 2694, NULL, 'A Sicilian circle progressive dance.', 100, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16825, '2015-12-01 10:54:00.53837+00', '2019-04-25 08:28:20.589445+00', 'Tough Love', 'TOUGH LOVE', 2, 32, NULL, 2, 3, 18, 2408, '2015-11-01', 'Devised by Lara Friedman-Shedlov in memory of the inimitable Norma Briggs to be presented at her memorial event in Madison, Wisconsin, November 2015.', 56, '800/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16100, '2015-02-21 17:05:42.517453+00', '2019-04-25 08:35:27.354831+00', 'Down Corkery Road', 'DOWN CORKERY ROAD', 2, 48, 9999, 2, 3, 18, 2998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10515, '2002-04-30 22:00:00+00', '2019-04-25 19:04:37.054125+00', 'Donald''s Gain...', 'DONALDS GAIN', 1, 32, 9999, 4, 5, 16, 520, '1997-01-01', '', 63, '80808/08088/40008/88888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19373, '2019-06-01 12:53:16.209843+00', '2019-06-01 12:53:16.209843+00', 'Myain Jig', 'MYAIN JIG', 2, 32, NULL, 1, 3, 42, 743, NULL, '', 75, '888/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13779, '2011-07-24 22:00:00+00', '2019-04-26 22:49:47.099825+00', 'Trip to Johnsonville School, A', 'TRIP TO JOHNSONVILLE SCHOOL', 2, 32, NULL, 1, 4, 1, 2682, '2011-07-05', 'Written for teaching a children''s class



Devised 5th July 2011, after teaching a class of 9 and 10 year old children, and wanting to write a dance which had elements of Noeline O''Connor''s "Kingston Flyer" and Tang''s "A Trip to Gatlinberg".  The young dancers were confused with progressions so I sought to write a simple dance for them. Adults find the dance a bit quick.



Music:  Any reasonable 4 by 32 J. For the class I used "Pelorus Jack" and asked them to dance it 8 times.', 53, '8800/4222/4222/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1833, '1997-09-01 22:00:00+00', '2019-04-29 16:45:05.288502+00', 'Dundee Holt', 'DUNDEE HOLT', 2, 40, 9999, 1, 3, 42, 3461, '1973-04-01', 'Devised in honour of the marriage of Eleanor Brown (a native o fDundee) and Al Holt, July,

1972, and first published in the Tartan Times for April, 1973', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19281, '2019-04-30 21:57:47.210943+00', '2019-05-03 23:01:09.466388+00', 'North Walls Quadrille', 'NORTH WALLS QUADRILLE', 1, 48, NULL, 4, 4, 13, 374, NULL, '', 79, '8080/0808/7777/7777/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19283, '2019-05-04 07:14:37.846084+00', '2019-05-04 10:11:18.796747+00', 'Chase Halfway in Brittany', 'CHASE HALFWAY IN BRITTANY', 2, 40, NULL, 1, 4, 2, 11778, '2019-03-01', '', 90, '8008/8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19277, '2019-04-28 08:40:11.336158+00', '2019-05-19 07:54:10.784647+00', 'Yvonne''s Strathspey', 'YVONNES STRATHSPEY', 3, 48, NULL, 2, 3, 17, 11806, '2018-01-01', '', 76, '800/866/866/844/868/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3134, '1997-04-03 22:00:00+00', '2019-05-27 06:59:24.805998+00', 'Iron Man, The', 'IRON MAN', 3, 32, 9999, 1, 3, 42, 108, '1975-02-02', 'Devised for Tom Steele of Hamilton ', 69, '888/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19312, '2019-05-11 23:57:58.452405+00', '2019-05-11 23:57:58.452405+00', 'Mabel Besant''s Two Step', 'MABEL BESANTS TWO STEP', 50, 16, NULL, 5, 1, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19285, '2019-05-04 19:54:30.80074+00', '2019-05-08 18:20:47.946934+00', 'Twisted Rights and Lefts', 'TWISTED RIGHTS AND LEFTS', 1, 32, NULL, 1, 3, 42, 11035, '2018-06-01', '', 53, '880/800/888/488', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19293, '2019-05-09 13:16:32.256297+00', '2019-05-09 13:16:32.256297+00', 'Guiding Light Jig', 'GUIDING LIGHT JIG', 2, 32, NULL, 1, 3, 42, 743, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19297, '2019-05-09 15:24:26.772072+00', '2019-05-09 15:24:26.772072+00', 'Good Companions', 'GOOD COMPANIONS', 2, 32, NULL, 1, 4, 1, 743, NULL, '', 75, '8880/8800/8880/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19300, '2019-05-09 15:39:53.460534+00', '2019-05-09 15:39:53.460534+00', 'Walk in the Park, A', 'WALK IN THE PARK', 3, 40, NULL, 1, 4, NULL, 11808, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19301, '2019-05-09 15:43:53.835783+00', '2019-05-09 15:43:53.835783+00', 'Blackhall Capers', 'BLACKHALL CAPERS', 2, 32, NULL, 1, 4, NULL, 11808, NULL, 'May also be danced with 5 couples.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19303, '2019-05-09 15:49:19.815576+00', '2019-05-09 15:49:19.815576+00', 'Broken Ankle Strathspey', 'BROKEN ANKLE STRATHSPEY', 3, 40, NULL, 1, 4, 1, 743, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19304, '2019-05-09 15:52:22.074664+00', '2019-05-09 15:52:22.074664+00', 'Margaret''s Medley', 'MARGARETS MEDLEY', 4, 32, 8, 1, 4, NULL, 743, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19295, '2019-05-09 13:24:19.399679+00', '2019-05-09 16:50:59.391828+00', 'Paws for Thought', 'PAWS FOR THOUGHT', 2, 32, NULL, 1, 107, 13, 743, NULL, 'Couples numbered anticlockwise: 1 & 2 down the men''s side, 3 & 4 up the women''s side, women on the right of their partner.', 100, '8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (584, '1998-10-15 22:00:00+00', '2019-05-10 08:38:28.216167+00', 'Blooms of Bon Accord', 'BLOOMS OF BON ACCORD', 1, 32, 9999, 1, 100, 2, 108, '1971-01-01', 'Devised in 1971 to commemorate the winning by the City of Aberdeen of the "Britain in Bloom" Competition for the third successive year.', 75, '8888  8008  8888  8008', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (19339, '2019-05-12 09:54:26.34568+00', '2019-05-12 09:54:26.34568+00', 'Awa'' Tae The Highlands', 'AWA TAE THE HIGHLANDS', 1, 32, NULL, 1, 3, 42, 44, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19317, '2019-05-12 00:07:02.583235+00', '2019-05-12 00:07:02.583235+00', 'Hoy - The Enchanted Island', 'HOY  THE ENCHANTED ISLAND', 1, 48, NULL, 4, 4, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19315, '2019-05-12 00:03:41.851552+00', '2019-05-12 08:40:49.543135+00', 'Lieutenant''s March, The', 'LIEUTENANTS MARCH', 11, 16, NULL, 5, 1, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19316, '2019-05-12 00:05:52.589164+00', '2019-05-12 08:41:43.942389+00', 'Longhope Lifeboat, The', 'LONGHOPE LIFEBOAT', 10, 32, NULL, 5, 4, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19327, '2019-05-12 08:57:37.399195+00', '2019-05-12 08:57:37.399195+00', 'Orcadian Medley, The', 'ORCADIAN MEDLEY', 4, 128, 2, 4, 4, 54, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19333, '2019-05-12 09:04:44.820471+00', '2019-05-12 09:04:44.820471+00', 'Diamond Quadrille, The', 'DIAMOND QUADRILLE', 1, 48, NULL, 4, 4, NULL, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19334, '2019-05-12 09:05:42.539774+00', '2019-05-12 09:05:42.539774+00', 'Reel for Johnny, A', 'REEL FOR JOHNNY', 1, 32, NULL, 1, 4, 2, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19335, '2019-05-12 09:07:13.807879+00', '2019-05-12 09:20:07.540961+00', 'Ruby Wedding Reel, The', 'RUBY WEDDING REEL', 1, 40, NULL, 1, 4, 1, 374, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19338, '2019-05-12 09:52:57.387843+00', '2019-05-12 09:52:57.387843+00', 'Under Southern Skies', 'UNDER SOUTHERN SKIES', 3, 32, NULL, 1, 3, 42, 44, '2013-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19344, '2019-05-12 10:23:34.071308+00', '2019-05-12 10:23:34.071308+00', 'Reel for Bill & Mary Cant, A', 'REEL FOR BILL AND MARY CANT', 1, 32, NULL, 1, 3, 42, 11002, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19345, '2019-05-12 10:24:32.34713+00', '2019-05-12 10:24:32.34713+00', 'Blue Hatchback, The', 'BLUE HATCHBACK', 1, 32, NULL, 1, 3, 42, 11002, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19346, '2019-05-12 10:25:42.155054+00', '2019-05-12 10:25:42.155054+00', 'Irene Cruickshanks Strathspey', 'IRENE CRUICKSHANKS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11002, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19347, '2019-05-12 10:27:47.217519+00', '2019-05-12 10:27:47.217519+00', 'Shona MacFadyen''s Jazzy Sheen', 'SHONA MACFADYENS JAZZY SHEEN', 2, 32, NULL, 1, 3, 42, 11002, '2017-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19348, '2019-05-12 10:29:15.924777+00', '2019-05-12 10:29:15.924777+00', 'Welcome to the First Foot Ball', 'WELCOME TO THE FIRST FOOT BALL', 2, 32, NULL, 1, 3, 42, 11002, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19291, '2019-05-06 23:52:23.170396+00', '2019-05-13 13:29:21.889766+00', 'Simple Little Strathspey, A', 'SIMPLE LITTLE STRATHSPEY', 3, 48, NULL, 2, 3, 18, 11002, NULL, 'Dedicated to Muriel Boal', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10144, '2001-10-22 22:00:00+00', '2019-05-26 18:25:40.577117+00', 'Jig for Abbie, A', 'JIG FOR ABBIE', 2, 32, 9999, 1, 3, 42, 2939, NULL, '', 48, '800/844/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19337, '2019-05-12 09:50:10.377719+00', '2019-05-27 09:52:00.576617+00', 'Down Among The Heather', 'DOWN AMONG THE HEATHER', 2, 32, NULL, 1, 3, 42, 44, '1998-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19340, '2019-05-12 09:56:31.55358+00', '2019-05-27 09:55:26.008778+00', 'Flight Of The Wild Geese, The', 'FLIGHT OF THE WILD GEESE', 2, 48, NULL, 1, 3, 42, 44, '1989-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19341, '2019-05-12 09:58:04.702271+00', '2019-05-27 09:56:11.189181+00', 'Bridge Over The Leith, The', 'BRIDGE OVER THE LEITH', 3, 32, NULL, 1, 3, 42, 44, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19342, '2019-05-12 10:00:13.684599+00', '2019-05-27 09:56:59.265386+00', 'At The End Of The Rainbow', 'AT THE END OF THE RAINBOW', 1, 48, NULL, 1, 3, 42, 44, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7111, '2001-09-13 22:00:00+00', '2022-04-10 17:22:17.783865+00', 'White Heather Jig, The', 'WHITE HEATHER JIG', 2, 40, 9999, 1, 4, 1, 87, '1964-01-01', 'There is a variant where on [35-36] 1c casts up to 2nd place (3c step down), making this into an 8 x 40 dance; it is called "<<ddd:#14666|The White And Purple Heather Jig>>".', 37, '8000  8800  8220  8080  8000', 1, 1, 1, 1, 37);
INSERT INTO 'dance' VALUES (19307, '2019-05-11 08:40:21.541021+00', '2022-04-10 21:19:21.125558+00', 'New Home, A', 'NEW HOME', 2, 32, NULL, 1, 4, 2, 11225, NULL, '', 63, '4444/4444/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19306, '2019-05-09 21:09:31.622171+00', '2022-10-01 18:00:11.242241+00', 'One Humanity', 'ONE HUMANITY', 3, 32, NULL, 1, 3, 42, 3179, '2019-04-01', 'This dance is a celebration of what binds us together; about seeing brothers and sisters

instead of enemies or strangers.', 50, '880/844/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19357, '2019-05-18 21:25:23.5398+00', '2019-06-24 22:26:29.935787+00', 'Xylem and Phloem', 'XYLEM AND PHLOEM', 3, 32, NULL, 6, 3, 17, 11237, '2018-01-01', '', 75, '800/844/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19356, '2019-05-18 18:50:25.174387+00', '2019-05-18 22:58:46.725165+00', 'Enigma', 'ENIGMA', 3, 32, NULL, 2, 3, 4, 11237, '2019-03-24', 'Devised to commemorate the work of Hugh Foss, along with Alan Turing and others, at Bletchley Park during the 2nd world war.



The Enigma Machine had three coding wheels which were used to scramble messages into a ciphered form or to decipher encoded messages. These are represented here by hands across, circles and turning with both hands.



Cryptographic literature often uses a few stock characters to illustrate problems. Alice and Bob are the main actors who hope to exchange secret messages without them being intercepted or decrypted by Eve, the eavesdropper. Here 1st woman and 2nd man are Alice and Bob while 3rd woman is Eve. Bars 1-8 and 9-16 represent encryption and decryption with Alice and Bob exchanging places as Eve tries to get close to Bob. The final progression is suitably scrambled with all changing partners. Alice and Bob end up together for the repeat.', 77, '465/762/888/686', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11296, '2003-05-04 22:00:00+00', '2019-05-24 10:32:55.423442+00', '10th of May, The', '10TH OF MAY', 1, 40, 9999, 3, 5, 6, 2701, '2001-05-10', 'This dance is dedicated to Sylvain Pelletier to commemorate the occasion of our domestic

partnership on May 10, 2000. Due to the date, I felt it needed to be a 5-couple dance; and I tried

to blend three of our favorite dances, The Reel of the Royal Scots, Pelorus Jack and Polharrow

Burn. With thanks and apologies to Roy Goldring, Barry Skelton and Hugh Foss', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19359, '2019-05-21 16:24:37.65945+00', '2019-05-21 16:41:27.530999+00', 'Bordeaux en Belle', 'BORDEAUX EN BELLE', 3, 32, NULL, 1, 3, 42, 11307, '2018-07-01', 'Written for Line Farr and Terry Harvey in honor of their 30th wedding anniversary remembering sharing wonderful wines on Belle Island.', 50, '880/844/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19360, '2019-05-21 16:27:55.546094+00', '2019-05-21 16:45:12.912907+00', 'Brian Johnson Lighthouse Keeper', 'BRIAN JOHNSON LIGHTHOUSE KEEPER', 1, 32, NULL, 2, 3, 17, 11812, '2019-01-01', 'Brian Johnson is the retained lighthouse keeper at Shetland.



5-8 Half Reels signify stairs within a lighthouse  

9-16 Set & Link represents the sea swirling around  

17-20 Rights and lefts are saying goodbye to crew signing off, couple at the bottom arriving crossing left hand  

25-32 Circle and back - the light on top of the lighthouse

', 100, '888/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13784, '2011-07-24 22:00:00+00', '2019-05-22 16:49:49.588947+00', 'Unjust Incarceration, The', 'UNJUST INCARCERATION', 3, 32, NULL, 1, 2, NULL, 2682, '2011-06-27', 'The isobirl formation is due to Terry Glasspool.



The name of the dance is one of my favourite piobaireachds. King James I imprisoned his political enemies on Bass Rock, a grim volcanic plug in the Firth of Forth. This included Walter Stewart. In 1428, 14 year-old Neil Bhass Mackay was imprisoned on the rock in exchange for his father''s freedom. In an attempt to pacify the Highlanders, James imprisoned 40 Chiefs including Angus Dubh Mackay of Strathnaver. Though he was soon released his eldest son Neil, was retained as hostage for the good behaviour of the Clan and since his mother was a daughter of MacDonald of the Isles, for that Clan too. Following the murder of King James at Perth in 1437 Neil escaped from the Bass and was proclaimed 8th Chief of the Clan Mackay. A pobaireachd commemorating this event ''The Unjust Incarceration'' was composed by the blind piper of Gairloch, Iain Dall Mackay.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8574, '1998-10-20 22:00:00+00', '2019-05-24 10:23:33.263938+00', 'On the Port Tack', 'ON THE PORT TACK', 1, 32, 9999, 1, 3, 42, 2099, '1991-01-01', 'There are lots of dances, such as "The Reel of the Royal Scots'', in which two dancers first set

with hands joined as in Double Triangles and then use the joined hands as the axis of a

tum. This dance explores what can happen if that turn is extended from half-way to threequarters

of the way around.  



As for the title: Scottish country dances tend to be quite symmetric. When an imbalance

between left and right does crop up, though, right is almost invariably the winner. This

dance is one of left''s rare victories. If all of the right turning in dances like '':Australian

Ladies" has twisted your ghillies around your feet, this dance will untwist them for you.   



One of my favorite dance teachers introduced this dance as a left-handed person''s response

to the intolerance and insensitivity of a right-handed culture. Feel free to spread that story

around - it makes a good introduction. But please don''t give me any left-handed scissors,

as I am right-handed.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19361, '2019-05-24 20:46:25.956402+00', '2019-05-24 21:15:52.715369+00', 'DAVID Minor', 'DAVID MINOR', 1, 40, NULL, 2, 3, 18, 11237, '2018-10-01', 'This is a slimmed down version of the original 5 couple dance <<ddd:DAVID>> for a 3 couple set.', 73, '844/833/455/488/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19364, '2019-05-30 10:03:39.422381+00', '2019-05-31 08:35:04.561244+00', 'Miss Frances Stamp', 'MISS FRANCES STAMP', 2, 32, NULL, 1, 2, 76, 11814, '1996-01-01', 'Miss Frances Stamp taught the RSCDS London Branch Teachers'' Certificate class from 1954 to 1975.  She was President of the Ealing Scottish Country Dance Club and taught their Beginners class', 60, '88/88/80/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19366, '2019-06-01 11:48:41.855535+00', '2019-06-01 12:02:57.613185+00', 'In Unison', 'IN UNISON', 3, 32, NULL, 1, 4, 2, 3753, '2017-11-01', '', 81, '8888/8080/8888/8448', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19367, '2019-06-01 12:13:49.680159+00', '2019-06-01 12:13:49.680159+00', 'Debra Strathspey, The', 'DEBRA STRATHSPEY', 3, 40, NULL, 1, 4, 13, 743, NULL, '', 95, '8888/8888/8888/8880/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19368, '2019-06-01 12:24:55.526513+00', '2019-06-01 12:24:55.526513+00', 'Anicuta''s Reel', 'ANICUTAS REEL', 2, 32, NULL, 1, 4, 30, 743, NULL, '1st & 3rd couples progress around those four places ending in original places after four repeats. 2nd & 4th couples progress similarly.', 88, '8888/8008/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19369, '2019-06-01 12:28:53.350401+00', '2019-06-01 12:28:53.350401+00', 'Cramond''s Own Country Dance', 'CRAMONDS OWN COUNTRY DANCE', 2, 32, NULL, 5, 2, NULL, 743, NULL, 'Compiled for the under 8''s class at the Cramond Scottish Country Dance Club.', 100, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19370, '2019-06-01 12:35:46.816133+00', '2019-06-01 12:35:46.816133+00', 'Big "8-0", The', 'BIG 80', 2, 32, NULL, 1, 4, 1, 743, NULL, '', 75, '8008/0880/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19375, '2019-06-01 13:04:49.317752+00', '2019-06-01 13:04:49.317752+00', 'Flecks of Gold', 'FLECKS OF GOLD', 2, 32, NULL, 1, 4, 1, 743, NULL, 'Dedicated to George and Isabel Watson on their Golden Wedding Anniversary.', 84, '8888/8008/8888/8488', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19371, '2019-06-01 12:41:11.453558+00', '2019-06-01 13:08:46.852865+00', 'Kelso Kapers', 'KELSO KAPERS', 3, 40, NULL, 2, 3, 17, 743, NULL, '', 87, '888/888/484/888/088', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19377, '2019-06-01 16:02:32.369605+00', '2019-06-01 16:02:32.369605+00', 'Hip-Hop for Hipsters', 'HIPHOP FOR HIPSTERS', 1, 32, NULL, 3, 5, 16, 2688, '2019-01-01', 'Dedicated to Jan Jones and all the dancers who are doing SCD with replacement hip joints.', 83, '48888/08888/08888/08888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18053, '2017-11-12 01:04:49.054374+00', '2023-01-14 12:09:28.361996+00', 'DAVID', 'DAVID', 1, 40, NULL, 3, 5, 6, 11237, '2017-06-01', 'This dance is for David Lieberman, one of the Gay Gordons enthusiasts for difficult or unusual dances.  It was inspired by <<ddd:Mrs Stuart Linnell>> which is one of his favourites.  



DAVID is an acronym for David Admires Very Involved Dances.

', 80, '84844/83863/55585/68688/88888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19279, '2019-04-30 12:09:42.182142+00', '2022-06-13 21:46:38.515562+00', 'Fast and Furious', 'FAST AND FURIOUS', 1, 48, NULL, 3, 5, 16, 10759, '2019-05-01', 'For Lennart Schweers', 78, '88088/08080/48884/48884/88888/28888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (556, '1998-09-17 22:00:00+00', '2019-06-02 23:08:48.326429+00', 'Black Swans of Narrabeen, The', 'BLACK SWANS OF NARRABEEN', 2, 32, 9999, 3, 5, 35, 325, '1981-01-01', 'Devised for a 1981 Christmas party of the S.C.D. Clubs of Harbord and Lakeside, NSW, Australia. Black swans frequent the nearly Narrabeen Lakes.  »Flock of Geese« is similar, but the progression is different.', 65, '80808/80808/08080/88888', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (19378, '2019-06-01 16:11:13.031452+00', '2019-06-04 14:56:45.844979+00', 'Two Hornpipes', 'TWO HORNPIPES', 1, 66, NULL, 1, 4, NULL, 11815, NULL, 'Actually 66 and a half bars - but SCDDB can only accept a whole number of bars!



Inspired by the music of Hans Zimmer for Pirates of the Caribbean.



The online source URL <<http://bstk.hu/dances/two-hornpipes/>> has more information, a diagram and a link (<<https://youtu.be/wVknCcIrH7E>>) to a special recording usable for trying the dance.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19382, '2019-06-02 12:28:49.445907+00', '2019-06-04 15:10:39.476595+00', 'Interval', 'INTERVAL', 4, 128, 10044, 4, 4, 1, 11815, '2018-01-01', 'Inspired by the word "Interval" that can be found on every ball or social event programme.



A recording of music for this dance can be found at <<https://youtu.be/-4-gF784S-Y>>', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19390, '2019-06-04 09:15:33.149594+00', '2019-06-04 16:47:30.398855+00', 'Dagda Circle, The', 'DAGDA CIRCLE', 1, 32, NULL, 7, 113, 4, 10632, '2019-01-01', 'Created for the 25th anniversary of the band Dagda who provide dance music for Scottish events in Hungary and have been playing at the monthly Budapest Scottish Dance Club dances for over ten years.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19385, '2019-06-02 21:34:53.365671+00', '2019-06-08 12:19:45.250264+00', 'Birthday Birl', 'BIRTHDAY BIRL', 1, 32, NULL, 1, 3, 42, 10632, '2015-01-01', 'For Zsófia Jósef on her birthday. First danced at the RSCDS summer school 2015.', 53, '800/888/822/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19391, '2019-06-04 09:19:03.257601+00', '2019-06-08 12:21:47.081894+00', 'Debbie the Hungarian Lady', 'DEBBIE THE HUNGARIAN LADY', 1, 32, NULL, 1, 2, 76, 11818, '2018-01-01', '', 60, '84/88/48/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19387, '2019-06-03 17:51:55.865413+00', '2019-06-08 12:26:32.080785+00', 'Meet in Linlithgow', 'MEET IN LINLITHGOW', 3, 40, NULL, 1, 4, 1, 11818, '2018-01-01', '', 88, '8888/8008/8848/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (529, '1997-04-03 22:00:00+00', '2019-06-24 05:08:27.377152+00', 'Black Agnes', 'BLACK AGNES', 1, 40, 9999, 1, 4, 1, 341, NULL, 'This dance was specially composed by Mrs. June Scott, a native of Dunbar, for the celebration of the 600th anniversary of the founding of the Burgh. It represents a siege of Dunbar Castle, and was performed in public for the first time in Dunbar High Street by teams of children from various parts of East Lothian.', 75, '8888/8448/8440/8448/0888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19310, '2019-05-11 12:58:26.623139+00', '2019-06-24 21:54:37.954855+00', 'Holywood Production, A', 'HOLYWOOD PRODUCTION', 3, 32, NULL, 2, 3, 18, 11237, '2019-01-01', 'For Patrick Brunskill who is responsible for filming, editing and occasionally appearing in the excellent series of Belfast branch videos (many thanks also to the other members of the demonstration team). Patrick lives in the Holywood district of Belfast which is pronounced exactly like the more famous film district of Los Angeles.

', 83, '448/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16461, '2015-06-19 21:34:19.462654+00', '2019-06-04 15:05:22.628204+00', 'Three "E"s, The', 'THREE ES', 3, 32, NULL, 4, 5, 16, 523, '2015-04-25', 'The dance derives its name from the theme of the Budapest Scottish Dance Weekend, 24-26 April 2015.  The “three Es” are Enthusiasm, Experience & Excellence, which also represent the trio of organisers: Ágnes, Zsófia & Laura.  The dance is dedicated to the Budapest Scottish Dance Club with many thanks and great affection for their wonderful hospitality and happy dancing.   



In the “Teapot Chain” the first wheel (or “teapot”) is done with the Head Couple positions and the second one with the Side Couple positions. At the end of this figure, the outside couples finish in the place opposite where they started while the middle couple returns to the centre of the set.  This figure was devised at the Budapest Scottish Dance Weekend in 2013 (using the pink & blue tops from bottles of water!) for a dance I was asked to write for a 50th birthday celebration.  I thought it would be nice to use it again in a dance for Budapest.



Tim Bolton-Maggs', 82, '44448/88888/24688/88888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14478, '2012-06-15 04:51:23.704568+00', '2019-06-04 15:07:17.689988+00', '30 isnae Enaw', '30 ISNAE ENAW', 2, 32, 9999, 1, 4, 2, 3661, '2011-01-01', 'As a present to Anikó Biró for her 30th birthday.



This dance was first (officially) published in 2011 in "A Reel Goulash".  Recently (2019) the deviser saw that that original dance description has an error: on bars 13-16 the 1½ turn takes FOUR bars, and there is NO SETTING on [15-16].  The crib on this page ahs been corrected.  



', 72, '8448/8448/8888/6006', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19394, '2019-06-07 22:36:43.178579+00', '2021-01-02 16:03:45.632156+00', 'If You Ever Get There', 'IF YOU EVER GET THERE', 1, 40, NULL, 3, 5, 35, 3583, '2017-06-01', 'A freely downloadable recording of music for this dance is available via <<http://www.fiddletree-music.com/johnturner/scdrecordings.html>>', 78, '80008/88888/88888/80448/88884', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19392, '2019-06-04 09:23:05.382125+00', '2020-02-07 12:31:28.909661+00', 'Gift to Bo''ness Dance', 'GIFT TO BONESS DANCE', 1, 24, NULL, 5, 2, 76, 11818, '2019-01-01', '', 100, '88/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19395, '2019-06-09 10:23:06.85439+00', '2019-06-09 16:34:49.701635+00', 'Penultimate Class Dance', 'PENULTIMATE CLASS DANCE', 2, 32, NULL, 1, 3, 42, 10593, '2019-06-06', 'The dance was written to be a succinct review of numerous basic figures (Linda Mae Dennis).  



Arandel new formation: Read Tom Halpenny''s article at <<http://www.rscds-swws.org/news/stories/arandel.htm>>', 44, '800/888/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19355, '2019-05-15 16:01:02.921113+00', '2019-06-08 22:17:42.919025+00', 'Kilt Swing', 'KILT SWING', 1, 32, NULL, 1, 3, 42, 11810, NULL, 'Devised to celebrate the wedding of Chandi McCracken and Jacob Holm in July 2017. Kilt Swing combines Scottish country dance and the flirty twirls of swing dance.', 55, '800/888/886/880', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19427, '2019-06-27 16:47:51.667863+00', '2019-06-27 17:35:11.094459+00', 'Electric Brae, The', 'ELECTRIC BRAE', 3, 32, NULL, 3, 5, 35, 10240, '2018-01-01', '', 88, '88888/48888/80888/80888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19417, '2019-06-24 09:22:36.125034+00', '2019-06-27 11:40:38.059481+00', 'Brisbane Glen', 'BRISBANE GLEN', 3, 32, NULL, 2, 3, 18, 640, '2019-01-01', '', 83, '880/866/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19428, '2019-06-27 16:55:53.897406+00', '2019-06-27 17:29:44.566183+00', 'Silver Celebrations', 'SILVER CELEBRATIONS', 1, 32, NULL, 3, 5, 7, 10240, '2019-01-01', '', 57, '80800/84884/80800/84844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17514, '2017-01-04 17:30:49.445708+00', '2019-06-28 14:20:09.313876+00', 'Fare Thee Well', 'FARE THEE WELL', 1, 32, NULL, 1, 4, 2, 11110, '2003-11-11', 'This dance was devised for Helen Cox and Lorraine Bruce on their departure to the Midlands. It

was first danced at their Farewell Ceilidh on 27th November 2003.', 84, '7777/8888/8008/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17519, '2017-01-04 17:56:20.508134+00', '2019-06-28 14:58:44.081003+00', 'Rock Gardens, The', 'ROCK GARDENS', 3, 40, NULL, 2, 3, 18, 11110, '2005-10-01', 'The Rock Gardens in Southsea are sunken gardens with many steps and paths. There is a fountain and a variety of plants and shrubs and in the winter months beautiful beds of heather.', 77, '800/822/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19400, '2019-06-15 07:42:55.317867+00', '2019-06-15 07:51:32.231417+00', 'Agile Jacks', 'AGILE JACKS', 1, 32, NULL, 1, 3, 42, 2766, '2017-01-01', 'Written for a friend who has Jack Russell terriers.', 69, '844/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19414, '2019-06-24 09:05:31.018198+00', '2023-01-22 19:53:22.557865+00', 'Sandra Mollison''s Jig', 'SANDRA MOLLISONS JIG', 2, 32, NULL, 1, 3, 42, 640, '2019-01-01', 'Inscribed to Sandra Mollison of Stewarton, Ayrshire.', 58, '800/888/666/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19397, '2019-06-13 09:58:28.298993+00', '2019-06-13 16:15:35.827127+00', 'Pat and Chris''s Anniversary', 'PAT AND CHRISS ANNIVERSARY', 3, 64, NULL, 2, 3, 18, 2957, NULL, 'Dedicated to Cairns dancer Pat Neve and her husband Chris on the occasion of their 38th  wedding anniversary.', 92, '888/888/888/888/844/844/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19396, '2019-06-09 21:22:11.16572+00', '2019-06-15 08:44:25.177066+00', 'Crimson Sari, The', 'CRIMSON SARI', 3, 32, NULL, 2, 3, 17, 2435, NULL, '', 72, '800/880/867/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19398, '2019-06-14 22:30:57.004817+00', '2019-06-14 22:35:11.734207+00', 'Unfortunate Acronym, The', 'UNFORTUNATE ACRONYM', 3, 32, NULL, 1, 3, 42, 2766, '2017-01-01', 'Another dance for Mary Jo''s request for dances with 4 8-bar figures that include the helix and tournée. The first letters of the 4 figures form an unfortunate word.', 56, '880/880/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15098, '2013-09-10 08:11:07.164665+00', '2019-06-15 12:51:23.734935+00', 'Ezekiel''s Wheel', 'EZEKIELS WHEEL', 1, 88, NULL, 4, 4, 3, 3784, '2013-06-01', 'First danced at Baton Rouge in 2013.  The author has asked for this official description to published below, 11 September 2013.  



Ezekiel’s Wheel



An 88-bar Reel for Four Couples in a Square Set



Devised by: James Mungall



1-4: Women dance right hands across.



5-8: Women take left hands with their partners and balance in line (holding in right hands across position) (2 bars), then turn partners by the left (2 bars), putting men into the center.



9-12: Men dance right hands across.



13-16: Men take left hands with their partners and balance in line (holding in right hands across position) (2 bars), then turn partners by the left (2 bars), putting women into the center facing their partners.



17-32: Double Celtic Reel (17-20 Men and Women pass right shoulder (as for reel of four), Women dance clockwise 1/4 of the way around the set while Men dance 3/4 Left shoulder around each other to face partner,  21-24 Men and Women pass right should (as for reel of four), Men dance clockwise 1/4  of the way around the set while the Women dance 3/4 Left shoulder around each other to face their partner,  25-32 M+W repeat bars 17-24)



33-48: Dance straight into Schiehallion Reels



33-34 Women dance through their position and around to place vacated by partner WHILE Men pass left shoulder to position vacated by second corner;



35-36  Men cast to follow the same Woman (2 bars behind) WHILE Women pass left shoulder and continue to follow their partner (2 bars behind);



37-48  repeat bars 33-36 three times to finish in original places.



49-56: 1st and 3rd couples take partner with both hands and slip step to the opposing position (men passing back to back) (2 bars), turn partner once round with both hands (using slip step) (2 bars), slip back to original position (women passing back to back) (2 bars) turning again with both hands (using slip step) once around and to place (2 bars).



57-64: 2nd and 4th couples repeat bars 49-56



65-80: Grand Chain half way around, set to partners on bars 71 and 72, continue Grand Chain to place setting to partners on bars 79 and 80.



81-88: Eight hands around and back.





. 



', 89, '6666  6666  8888  8888  8888  8888  8080  0808  8888  8888  8888', 1, 1, 1, 0, 86);
INSERT INTO 'dance' VALUES (19399, '2019-06-14 22:43:49.136731+00', '2019-06-14 23:08:34.403475+00', 'Lady McGowan''s Nightmare', 'LADY MACGOWANS NIGHTMARE', 3, 32, NULL, 1, 2, 76, 2766, '2017-01-01', 'While learning Lady McGowan''s Dream, Mary Jo requested a dance similar to The Ultimate Brief (which consists of 4 8-bar figures: poussette, knot, bourrel, allemande) which uses a helix, men''s chain, and tournée to help learn the figures.', 47, '88/75/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19425, '2019-06-26 21:58:51.082958+00', '2020-11-25 11:01:34.668905+00', 'Kincorth Ceilidh Capers', 'KINCORTH CEILIDH CAPERS', 1, 32, NULL, 5, 53, NULL, 11827, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5882, '1997-09-13 22:00:00+00', '2021-01-02 23:40:35.626018+00', 'Sands of Asilomar, The', 'SANDS OF ASILOMAR', 3, 32, 9999, 1, 4, 2, 108, '1984-01-01', 'Dedicated to the members of the San Francisco Branch, “Sands of Asilomar” was named after the tune of the same name by Paul Machlis. It was danced at the 1985 Asilomar Weekend''s Saturday night Ball. ', 78, '8888/4444/7777/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20238, '2021-03-02 14:30:41.233862+00', '2021-03-04 13:47:46.257323+00', 'Dancing David', 'DANCING DAVID', 1, 32, NULL, 1, 3, 42, 1445, '2019-01-01', 'To commemorate the arrival of our grandson David Benjamin.', 48, '800/866/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20300, '2021-04-05 09:07:16.805046+00', '2021-04-05 10:56:51.04806+00', 'Dancing OBE''s, The', 'DANCING OBES', 1, 32, NULL, 1, 3, 42, 11029, NULL, 'This dance is for all those dancing octogenarians.', 59, '880/822/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19409, '2019-06-18 09:24:40.629807+00', '2021-11-08 19:09:31.787492+00', 'Partisan, The', 'PARTISAN', 3, 40, NULL, 2, 3, 18, 11643, '2019-06-06', 'This dance is inspired by the song “The partisan” by Leonard Cohen and was devised on the 75th anniversary of D-Day. This strathspey is dedicated to my wonderful grandfather, Louis Devèze - aka “Papou”- who was a member of the French Resistance (FFI), and to all the partisans who fought for freedom.



Bars 19-24: It’s a 6 bars 11⁄2 gypsy turn, so take the time to turn around and exchange looks with your partner when you turn the 11⁄2 gypsy turn before going to your lines. It must be very sweet in this part of the dance.', 73, '880/844/888/800/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20408, '2021-07-30 09:10:58.910507+00', '2021-07-30 09:10:58.910507+00', 'Jamieson''s Fancy', 'JAMIESONS FANCY', 3, 0, NULL, NULL, NULL, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19403, '2019-06-16 04:39:35.593656+00', '2019-06-16 04:49:26.458059+00', 'Vertical Basking', 'VERTICAL BASKING', 1, 32, NULL, 1, 3, 42, 2766, '2017-02-01', 'One day I was looking out a second story room at a large oak and saw a squirrel splayed out on the bark soaking up the sun on a fairly cold day.', 53, '800/888/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19401, '2019-06-15 22:01:15.448753+00', '2019-06-15 22:15:48.727569+00', 'Flashing Lights', 'FLASHING LIGHTS', 2, 32, NULL, 1, 3, 42, 2766, '2017-01-01', 'Our cul-de-sac is in a quiet and safe neighborhood, but one day we looked out and saw 3 police cars with lights flashing and doing a "traffic stop" of an odd neighbor that lasted more than an hour. Not a clue what it was all about.', 41, '860/860/800/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19407, '2019-06-16 13:00:14.508589+00', '2019-06-16 13:00:14.508589+00', 'Rainbow Dragon', 'RAINBOW DRAGON', 2, 32, NULL, 1, 3, 42, 2766, '2016-02-01', 'Dragonvale only allows Celtic or rainbow dragons during leap year around leap day.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19404, '2019-06-16 04:51:58.351191+00', '2019-06-16 10:37:18.177305+00', 'Everything By Halves', 'EVERYTHING BY HALVES', 3, 32, NULL, 1, 3, 42, 2766, '2017-02-01', 'When this dance came to me I realized it was made up by 4-bar (half) figures.', 50, '840804/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11800, '2004-09-16 22:00:00+00', '2019-06-17 11:44:22.904123+00', 'Arkansas Traveler', 'ARKANSAS TRAVELER', 1, 32, 9999, 1, 3, 42, 3453, '2002-01-01', 'Devised for Chris Peterson and Michael Hudson, their lifetime of musical collaboration and their home state of Arkansas.', 58, '866/824/888/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10019, '2001-08-19 22:00:00+00', '2019-06-21 21:44:57.528407+00', 'Holey Knickers!', 'HOLEY KNICKERS', 2, 32, 9999, 3, 5, 7, 108, '2000-01-01', 'From John Drewry''s note: "John Brown''s tartan underpants are on display at the Tartan museum in Keith. They are made of coarse fabric and have holes in them. Was John Brown moth-infested or was he just air-conditioned?"', 60, '68680/82820/84884/80800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19406, '2019-06-16 12:56:37.27364+00', '2019-06-20 01:29:15.572969+00', 'Orange Slices', 'ORANGE SLICES', 3, 96, NULL, 4, 4, NULL, 2766, '2016-01-01', 'At the 2016 Chicago New Years Ball Tom Senior and Mary Helen Polensky were suggesting names for my yet-to-be-written dances and Tom suggested orange slices as there were orange slices on the snack table. It turns out ‘slice’ is a figure in English Country Dancing somewhat like that in bars 65-72.

  	', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19410, '2019-06-19 23:22:18.387445+00', '2019-06-20 12:31:16.730242+00', 'Bruce''s Jig', 'BRUCES JIG', 2, 32, NULL, 1, 3, 42, 11638, '2019-01-01', 'Dedicated to the deviser''s father-in-law on his 85th birthday.', 50, '800/844/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19413, '2019-06-24 08:55:17.771969+00', '2019-06-27 11:39:48.092932+00', 'May and Jim''s Reel', 'MAY AND JIMS REEL', 1, 32, NULL, 1, 3, 42, 640, '2019-01-01', 'Inscribed to May and Jim Holmes of Irvine, Ayrshire.', 41, '804/808/633/633', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19415, '2019-06-24 09:13:42.265114+00', '2019-06-27 11:40:15.319089+00', 'Bill Meek''s Jig', 'BILL MEEKS JIG', 2, 32, NULL, 1, 3, 42, 640, '2019-01-01', 'Inscribed to Bill Meek of Dalry, Ayrshire.', 55, '884/808/288/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19405, '2019-06-16 05:10:53.137754+00', '2022-08-17 21:29:45.1057+00', 'Lost Princess of OZ, The', 'LOST PRINCESS OF OZ', 2, 32, NULL, 1, 3, 42, 2766, '2017-03-01', 'Written for a favorite character Geek week. I love the OZ books and a favorite is The Lost Princess of OZ. The snake pass evokes the merry-go-mountains in the book.', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20298, '2021-04-05 08:56:22.192093+00', '2022-09-23 20:01:51.638502+00', 'Butterfly, The', 'BUTTERFLY', 1, 32, NULL, 1, 3, 42, 11029, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19432, '2019-06-28 18:56:06.113292+00', '2019-06-28 18:56:06.113292+00', 'While the Baby Sleeps', 'WHILE THE BABY SLEEPS', 2, 32, NULL, 1, 3, 42, 2766, '2017-03-01', 'I find it hardest to name dances (writing them is easy), so I asked my group for ideas for this one and was given several ideas: Charles’ Jig, Playing While Gilbert Sleeps, Playing While the Baby Sleeps, and The Cat’s Meow. The ultimate choice was Charles Plays with the Cat While Baby Gilbert Sleeps, which I decided was too long.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19433, '2019-06-28 18:58:01.106304+00', '2019-06-28 18:58:01.106304+00', 'Walking With Fire', 'WALKING WITH FIRE', 1, 32, NULL, 1, 3, 42, 2766, '2017-03-01', 'Named when watching a National Geographic show postulating that learning to control fire is the origin of human society.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19434, '2019-06-28 18:59:21.649563+00', '2019-06-28 18:59:21.649563+00', 'Bolillos (Bobbins)', 'BOLILLOS BOBBINS', 1, 32, NULL, 1, 3, 42, 2766, '2017-04-01', 'Bolillos is the Spanish name for bobbins used in bobbin lace, which I like to do.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19435, '2019-06-28 19:01:04.251426+00', '2019-06-28 19:01:04.251426+00', 'Measured Sleep', 'MEASURED SLEEP', 3, 32, NULL, 4, 4, 1, 2766, '2017-04-01', 'This is an idea that came to me while I was participating in a sleep study for a CPAP machine.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19436, '2019-06-28 19:02:39.688685+00', '2019-06-28 19:02:39.688685+00', 'Crazy 8''s', 'CRAZY 8S', 1, 32, NULL, 1, 3, 42, 2766, '2017-05-01', 'This dance explores variations of figures of eight.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19439, '2019-06-28 19:09:33.645324+00', '2019-06-28 19:09:33.645324+00', 'Half Stitch', 'HALF STITCH', 3, 32, NULL, 1, 3, 42, 2766, '2017-05-01', 'The figure in bars 9-16 is similar to half stitch in bobbin lace.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19440, '2019-06-28 19:19:22.535043+00', '2019-06-28 19:21:14.751329+00', 'Katie''s Wedding', 'KATIES WEDDING', 1, 32, NULL, 2, 3, 17, 2766, '2017-06-01', 'Written for a wedding featuring 6 dancers, some of whom are not familiar with Scottish Country Dancing. This dance ends with a circle representing a wedding ring.

  	', 58, '800/840/804/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19431, '2019-06-28 17:28:28.438167+00', '2019-06-28 21:49:58.180517+00', 'Goodbye from Him', 'GOODBYE FROM HIM', 3, 32, NULL, 1, 4, 2, 11237, '2018-10-01', 'The Hello-Goodbye chase figure comes from <<ddd:The Cane Toad Jig>> by Rod Downey where it is done all the way round in 16 bars of pas-de-basque.', 69, '8448/8448/8448/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19508, '2019-07-29 15:24:11.885023+00', '2019-07-29 15:24:11.885023+00', 'For All the Days of Dance', 'FOR ALL THE DAYS OF DANCE', 3, 32, NULL, 1, 3, 42, 59, '2016-04-25', 'Present to Hilda Brodie to mark her 90th birthday.', 53, '800/888/822/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19461, '2019-06-29 15:33:52.676511+00', '2019-06-30 07:11:00.420115+00', 'Ten Words', 'TEN WORDS', 1, 32, NULL, 1, 3, 42, 2766, '2017-12-01', 'My husband and I like to watch The Voice. We have a joke that rock/pop songs have few words and we count them. Most choruses have ten words or fewer.', 41, '840/840/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19507, '2019-07-29 14:53:33.290268+00', '2019-07-30 00:36:35.359601+00', 'Sophie''s Sand Castle', 'SOPHIES SAND CASTLE', 1, 32, NULL, 1, 2, 76, 59, '2019-03-27', 'Inspired by a walk on the beach and the book Sophie''s Castle by Heather Levine.', 52, '80/88/80/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19455, '2019-06-29 15:14:25.60007+00', '2019-06-29 15:14:25.60007+00', 'Molly''s Ring', 'MOLLYS RING', 3, 32, NULL, 1, 3, 42, 2766, '2017-10-01', 'Molly announced her engagement at dancing, so I decided to write a dance for her.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19534, '2019-08-12 08:54:40.842051+00', '2019-08-12 08:54:40.842051+00', 'Eagle Rock Triumph, The', 'EAGLE ROCK TRIUMPH', 1, 32, NULL, 1, 3, 42, 11857, NULL, 'This dance has an allemande in triumph hold for which there is no formation code in SCDDB.', 66, '822/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19423, '2019-06-26 21:55:21.677726+00', '2020-01-24 10:47:30.976459+00', 'Isobel''s Flirty Fancy', 'ISOBELS FLIRTY FANCY', 2, 32, NULL, 1, 100, 2, 11827, NULL, '', 69, '8008/8448/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19438, '2019-06-28 19:07:50.01232+00', '2020-04-29 00:43:01.700536+00', 'Evening Star', 'EVENING STAR', 3, 32, NULL, 1, 2, 76, 2766, '2017-05-01', 'This dance was written for a needlework/canvaswork pattern I made for a couple of people.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19424, '2019-06-26 21:56:58.25987+00', '2020-11-25 10:19:16.223921+00', 'Billy''s 65th Fling', 'BILLYS 65TH FLING', 1, 40, NULL, 1, 3, 42, 11827, NULL, '', 58, '888/800/822/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18855, '2018-10-06 19:54:20.989315+00', '2019-07-29 10:21:23.986732+00', 'Ullswater Way', 'ULLSWATER WAY', 2, 40, NULL, 1, 4, NULL, 2682, '2018-07-06', 'Ullswater is a lovely lake in the Lakes District, we visited after "Downey Day of Dance 2018". The "Way" is a walk around the lake, of which we did the part to Howtown from Glenridding. The recommended tune is "Barley Cakes" which is traditional, the lead tune for "Barley Bree" from Book 13, and I would recommend either the recording by The Carfuffle Ceilidh Band, or either of the society recordings for book 13 (Neil Barron and Bobby Crowe) would be excellent.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3677, '1997-04-03 22:00:00+00', '2019-07-30 16:55:55.563402+00', 'Lammas Night', 'LAMMAS NIGHT', 1, 32, 9999, 1, 3, 42, 13, NULL, '"It was upon a Lammas night,  

When corn rigs are bonnie..."



The old dance "Corn Rigs" is never done these days, and it seems a shame to waste such a dancetable tune.', 56, '888/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19509, '2019-07-30 19:42:50.566377+00', '2019-07-30 19:50:19.051549+00', 'Ten Beach Dancers', 'TEN BEACH DANCERS', 2, 32, NULL, 3, 5, 7, 2682, '2019-04-05', 'Obviously an homage to the late Eddie West’s ”Beach Dancer”, and inspired whilst daydreaming at the bottom of a 5C set,



the first 3 couples walking through the Beach Dancer at the Capitol City Club on the night of the 4th. Recommended music is ”A Quickstep by the Duke of Gordon” by Robert Petrie, and 5C recorded music is that for ”The Campbells are Coming” as recorded by Muriel Johnston and her band in the Society’s ”Music for Book 24”. ”Come under my Plaidie” as recorded by the Craigowl Band in the Society’s recording of the Children’s book” would work at a pinch. I would avoid pipe marches, and use a light jig suggesting flight.

', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19510, '2019-07-30 19:57:40.556516+00', '2019-10-05 06:10:19.976845+00', 'Cocker Spaniel, The', 'COCKER SPANIEL', 3, 32, NULL, 2, 3, 17, 2682, '2019-07-24', 'A relatively simple dance with an espagnole and an all round poussette for teaching purposes. The recommended set is the one for “The Orchards of County Armagh” as recorded by Marian Anderson and her Band on Belfast Branch Platinum. (”Sailing South” by J. Nicholson, The Sally Gardens (trad), and ”To Pauline” by M. Anderson).  



The name is a pun on the Espagnole, I sometimes use when teaching this formation.', 60, '880/800/864/088', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7197, '1997-04-03 22:00:00+00', '2019-08-02 20:52:56.136964+00', 'Wing-the-Wind', 'WINGTHEWIND', 1, 64, 9999, 1, 4, 1, 129, NULL, '', 72, '8000/8008/8808/0888/4488/8484/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3398, '1997-09-05 22:00:00+00', '2019-08-02 21:15:59.234608+00', 'Kate and Dod', 'KATE AND DOD', 2, 32, 9999, 1, 2, 76, 875, NULL, 'This dance is named in honour of my parents, Kate and George S. Duncan, formerly of Insch and Kintore, Aberdeenshire.', 34, '80/08/66/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19520, '2019-08-11 20:49:42.215631+00', '2019-08-11 20:49:42.215631+00', 'Bonny Nancy', 'BONNY NANCY', 3, 32, NULL, 1, 4, 1, 11851, NULL, 'For Nancy Key on her birthday.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19521, '2019-08-11 20:58:32.176192+00', '2019-08-11 20:58:32.176192+00', 'Lovely Maggie', 'LOVELY MAGGIE', 1, 32, NULL, 2, 3, NULL, 11852, NULL, 'Written for Maggie, the Cal Tech class mascot:  

1-4: upright ear  

5-8: down-turned ear  

9-16: eyes and nose  

17-32: tail wagging   

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14173, '2011-08-26 22:00:00+00', '2019-09-13 23:15:03.035533+00', 'Bob Wilson''s Jig', 'BOB WILSONS JIG', 2, 32, NULL, 1, 4, 1, 127, NULL, 'The dance spells Robert''s name, hence:-  

R - reel, 0 - circle, B- balance, E -exchange place, set, RT - rotate!', 87, '8888/8888/8080/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19469, '2019-07-03 18:06:56.652013+00', '2019-07-03 20:46:50.331999+00', 'Third Leg, The', 'THIRD LEG', 3, 48, NULL, 2, 3, 17, 11832, '2001-03-01', 'A Strathspey for 3 couples, to celebrate the ability to dance again after losing a leg and getting a new one!

', 92, '844/888/888/888/888/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19475, '2019-07-20 22:01:57.312729+00', '2019-07-20 22:01:57.312729+00', 'Irish Rose', 'IRISH ROSE', 2, 48, NULL, 1, 3, 42, 851, '2018-01-01', 'To celebrate Rose''s 70th birthday.', 63, '800/888/888/844/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19466, '2019-07-03 17:50:18.088754+00', '2019-07-04 06:42:16.926759+00', 'Sharon', 'SHARON', 1, 40, NULL, 1, 3, 42, 11831, '2001-06-01', '', 60, '800/844/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19430, '2019-06-28 17:23:29.466404+00', '2019-06-28 22:07:47.97979+00', 'Great Permian Mass Extinction, The', 'GREAT PERMIAN MASS EXTINCTION', 1, 40, NULL, 3, 5, 58, 11237, '2016-01-01', 'I no longer remember why I ever thought it might be a good idea to try to represent the most severe of all known mass extinctions as a Scottish country dance, but it quickly occurred to me that I could dedicate it to the memory of my friend Martin with whom I used to have many fascinating conversations about biology and evolution. It was also an interesting and brain teasing challenge to organise the figures to allow the single surviving dancer’s solo in the last four bars.



The first 8 bars are supposed to represent a trilobite (on its back) though the real ones had many more legs than are here depicted by the highland arms of six dancers while the first two couples are illustrating the head. Bars 9-12 are a convergent evolutionary progression via different paths leading into bars 13-24 which represent a pair of ammonites. Fossil ammonites used to be called snakestones, so an extended version of the “snake pass” figure seems suitable. Disaster arrives in bars 25-32. The figure here starts with a warning preshock which is followed by immense supervolcanic eruptions and falling ash and lava. Enthusiastic and extrovert dancers might add their own sound effects here! In bars 33-34 the dust settles and in bars 35-36 all is still. I am not normally in favour of dancers standing idle, but a moments silence after the “great dying” which ended the Palaeozoic era feels very appropriate. Finally in bars 37-40 3rd woman dances up alone to start the repopulation of an almost empty world.', 80, '88888/66466/88888/88888/22422', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19441, '2019-06-29 13:34:50.876404+00', '2019-06-29 13:34:50.876404+00', 'River Road Roundabouts', 'RIVER ROAD ROUNDABOUTS', 1, 32, NULL, 1, 3, 42, 2766, '2017-06-01', 'Naperville has 3 roundabouts (traffic circles) – all on River Rd – that I navigate every time I go for a haircut. These figures remind me of going around a roundabout.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19443, '2019-06-29 13:38:17.877152+00', '2019-06-29 13:38:17.877152+00', 'Dance of the Golden Flashes', 'DANCE OF THE GOLDEN FLASHES', 3, 32, NULL, 1, 3, 42, 2766, '2017-07-01', 'Every evening we see lightning bugs in the front yard, flying from plant to plant and giving us lots of lovely flashes of golden light.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19444, '2019-06-29 13:39:31.647283+00', '2019-06-29 13:39:31.647283+00', 'Milkweed Dancer', 'MILKWEED DANCER', 3, 32, NULL, 1, 3, 42, 2766, '2017-07-01', 'Monarch butterflies come to the milkweed we have in our yard. In their visits, they make the milkweed seem to dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19445, '2019-06-29 13:40:53.561241+00', '2019-06-29 13:40:53.561241+00', 'North of Scotland', 'NORTH OF SCOTLAND', 1, 32, NULL, 1, 3, 42, 2766, '2017-07-01', 'Inspired by a video showing people dancing a Shetland reel.

  	', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19449, '2019-06-29 14:59:56.978905+00', '2019-06-29 14:59:56.978905+00', 'Flights of Gold', 'FLIGHTS OF GOLD', 2, 32, NULL, 1, 3, 42, 2766, '2017-08-01', 'This dance was inspired by watching our bees take off from the hives and fly off with the sun catching them and turning them to flying gold.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19450, '2019-06-29 15:01:38.778684+00', '2019-06-29 15:01:38.778684+00', 'Twilight at Noon', 'TWILIGHT AT NOON', 1, 32, NULL, 1, 3, 42, 2766, '2017-08-01', 'There was a full eclipse of the sun on August 21, 2017. It was only 87% where I live, but still noticeable.

  	', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19451, '2019-06-29 15:02:47.681337+00', '2019-06-29 15:02:47.681337+00', 'Jewel on the Wing', 'JEWEL ON THE WING', 1, 32, NULL, 1, 3, 42, 2766, '2017-09-01', 'A hummingbird came to flowers in our yard and the sun lit up the iridescent wings so they looked like jewels.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19452, '2019-06-29 15:10:22.727531+00', '2019-06-29 15:10:22.727531+00', 'Circle Is Small, The', 'CIRCLE IS SMALL', 2, 32, NULL, 1, 3, 42, 2766, '2017-10-01', 'This dance was inspired by the English Country dance Crossroads and is named for a favorite Gordon Lightfoot song.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19454, '2019-06-29 15:13:18.786282+00', '2019-06-29 15:13:18.786282+00', 'Nature''s Confetti', 'NATURES CONFETTI', 2, 32, NULL, 1, 3, 42, 2766, '2017-10-01', 'The title of this dance comes from a comic strip using this phrase to leaves falling in Autumn.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19511, '2019-08-02 21:00:04.081348+00', '2020-11-26 10:37:04.849609+00', 'My Second Ever SCD', 'MY SECOND EVER SCD', 1, 32, NULL, 1, 4, 1, 11035, NULL, 'CD: Reel On. Track 3 “Time to Meet”', 47, '8000/8000/8444/8088', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19456, '2019-06-29 15:17:17.137728+00', '2019-06-29 15:17:17.137728+00', 'Platinum', 'PLATINUM', 3, 32, NULL, 1, 3, 42, 2766, '2017-11-01', 'News reports of the platinum wedding anniversary of the King and Queen of England reminded me that my parents celebrated their 70th anniversary in September. This dance honors that.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19457, '2019-06-29 15:26:30.269266+00', '2019-06-29 15:26:30.269266+00', 'Chain Reaction', 'CHAIN REACTION', 2, 48, NULL, 2, 3, 18, 2766, '2017-11-01', 'During class one week, Mary Helen said she’d love to see a dance with all the chain figures. This is an attempt to fulfill that desire.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19458, '2019-06-29 15:29:08.34987+00', '2019-06-29 15:29:08.34987+00', 'Chocolate Chip Double Triangles', 'CHOCOLATE CHIP DOUBLE TRIANGLES', 2, 32, NULL, 3, 5, NULL, 2766, '2017-11-01', 'Chocolate Chip Double Triangles', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19459, '2019-06-29 15:30:22.049961+00', '2019-06-29 15:30:22.049961+00', '50 Years a Fan', '50 YEARS A FAN', 1, 32, NULL, 1, 3, 42, 2766, '2017-11-01', 'For Gordon Lightfoot’s 80th birthday. I have been a fan since I was a junior in college (around 1968).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19462, '2019-06-29 15:35:01.157244+00', '2019-06-29 15:35:01.157244+00', 'Dashing Through the Snow', 'DASHING THROUGH THE SNOW', 1, 32, NULL, 1, 3, 42, 2766, '2017-12-01', 'Just another dance for the Christmas season.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19463, '2019-06-29 15:36:24.709412+00', '2019-06-29 17:09:52.318101+00', 'Christmas Stars', 'CHRISTMAS STARS', 2, 32, NULL, 3, 5, 33, 2766, '2017-12-01', 'Just a seasonal dance with figures that are reminiscent of stars.', 76, '68686/48884/48884/46446', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19402, '2019-06-15 22:19:17.319967+00', '2019-06-30 03:56:00.477593+00', 'Walking on Air', 'WALKING ON AIR', 2, 32, NULL, 1, 3, 42, 2766, '2017-01-01', 'I love writing dances; this one wrote itself in 10 minutes.', 52, '800/864/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19460, '2019-06-29 15:31:28.661078+00', '2019-07-02 20:59:46.326544+00', 'Circle of Steel', 'CIRCLE OF STEEL', 1, 32, NULL, 1, 3, 42, 2766, '2017-11-01', 'Named for a favorite Gordon Lightfoot song.', 47, '800/833/833/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19522, '2019-08-11 21:09:27.671669+00', '2019-08-11 21:09:27.671669+00', 'Swarthmore College Reel, The', 'SWARTHMORE COLLEGE REEL', 1, 48, NULL, 1, 3, 42, 11853, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19528, '2019-08-12 07:58:11.25764+00', '2019-08-12 07:58:11.25764+00', 'Ridgecrest Reel, The', 'RIDGECREST REEL', 1, 48, NULL, 1, 100, 2, 11034, NULL, '', 92, '8888/8228/8888/6886/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19464, '2019-07-03 17:37:08.467936+00', '2019-07-03 17:37:08.467936+00', 'Summer Pudding', 'SUMMER PUDDING', 2, 32, NULL, 6, 3, NULL, 2627, '2001-07-01', 'The women stand back to back in the middle of the set, facing their partner to begin.



Amendment: Summer Pudding, bars 1-8.

Now we''ve danced the dance through several times, I would prefer ''change right hand, set; change right hand, set'' at the beginning!

Wendy Mumford, May 2002.



(The original version had set, change, set, change).', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19467, '2019-07-03 17:55:29.96351+00', '2019-07-03 17:55:29.96351+00', 'Netley Abbey Ramble, The', 'NETLEY ABBEY RAMBLE', 2, 32, NULL, 1, 4, 1, 3597, '2001-05-01', '', 81, '8000/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19468, '2019-07-03 18:00:20.810094+00', '2019-07-03 18:00:20.810094+00', 'Lower Upham Reel, The', 'LOWER UPHAM REEL', 1, 32, NULL, 1, 3, 42, 2627, '2001-01-01', '', 63, '888/800/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19470, '2019-07-03 18:15:12.403368+00', '2019-07-03 18:15:12.403368+00', 'Sparsholt Frolic', 'SPARSHOLT FROLIC', 1, 64, NULL, 4, 4, 3, 11833, '2001-06-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19465, '2019-07-03 17:43:57.4432+00', '2019-07-03 19:14:52.541877+00', 'Abbot''s Strathspey, The', 'ABBOTS STRATHSPEY', 3, 32, NULL, 1, 4, 1, 11830, '2001-06-01', 'Bars 1-8 depict the monks, in their habits, leading up the aisle of the abbey.  

Bars 17-24 represent the abbey.', 97, '8888/8888/8888/8866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6811, '1997-08-24 22:00:00+00', '2019-07-05 19:24:03.218281+00', 'Twinbairn''s Reel, The', 'TWINBAIRNS REEL', 2, 32, 9999, 1, 2, 76, 108, '1981-01-01', '', 38, '66/66/44/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12219, '2005-04-17 22:00:00+00', '2019-07-17 22:06:52.932369+00', 'Findlater Castle', 'FINDLATER CASTLE', 1, 32, 9999, 1, 3, 42, 127, '2004-01-01', 'Findlater Castle, now a ruin, built in 1455 and once home of the "Ogilvie" clan, is situated about 2 miles east of Cullen in the Moray Firth area', 67, '833/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15178, '2013-09-28 22:22:12.336907+00', '2019-07-06 07:51:52.10163+00', 'Dagmar''s Delight', 'DAGMARS DELIGHT', 3, 32, NULL, 1, 2, NULL, 10568, NULL, 'Solo R&Ls by <<ddp:Tague, David>> in <<ddd:Whistler''s Jig>>  

Targe by <<ddp:Haynes, Derek>> in <<ddd:The Clansman>>', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2832, '1997-09-03 22:00:00+00', '2019-07-18 23:01:45.671799+00', 'Heath, Hill And Heather', 'HEATH HILL AND HEATHER', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 56, '800/888/888/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13574, '2010-05-29 22:00:00+00', '2021-04-02 21:32:30.919356+00', 'Celtic Steps', 'CELTIC STEPS', 1, 32, NULL, 100, 4, 2, 550, '2005-06-01', '4x32 in a longwise set, then another slightly different 32 bars in a square set to finish.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12394, '2005-04-28 22:00:00+00', '2021-07-25 20:14:25.92505+00', 'St Magnus Reel', 'SAINT MAGNUS REEL', 1, 64, 9999, 2, 3, 17, 264, NULL, 'February 2003. Dance first performed by a group of Community dancers as part of the “Elements” performance in St Magnus Cathedral on 25 June forming part of the St Magnus Festival 2003.



Originally entered in SCDDB as "Saint Magnus Reel", but changed to "St Magnus Reel" as the online sources use that spelling. The "Saint" version is kept as an alias.', 88, '800/844/888/888/888/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15566, '2014-08-18 14:17:44.658472+00', '2021-09-23 20:20:41.402347+00', 'State of Grace', 'STATE OF GRACE', 3, 32, NULL, 1, 3, 42, 2701, '2012-02-07', 'Written in memory of Polly Paterson who passed away on January 29, 2012. Polly was a loyal and enthusiastic member of the Berkeley class. She attended dances all over and served on the branch board. Her enjoyment of SCD was reflected in her ready smile and the encouragement she shared with all in her set. I’ve borrowed 8 bars from Adieu Mon Ami as a tribute to a friend and dancer who is sorely missed.', 47, '880/800/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19472, '2019-07-13 13:10:01.699543+00', '2019-07-13 13:19:19.515757+00', 'Bodhran Drum with a Flourish, The', 'BODHRAN DRUM WITH A FLOURISH', 1, 32, 9999, 1, 4, 1, 725, '2003-07-01', 'music is The Corries singing with the bodhran drum Wha Wadna Fecht for Charlie on The Very Best of the Corries', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19473, '2019-07-13 21:40:23.356531+00', '2019-07-13 21:40:23.356531+00', 'Lady Diana Reel, The', 'LADY DIANA REEL', 3, 32, NULL, 2, 3, 18, 11834, NULL, 'Published in Strathspey message 12353, 18 June 1998 by Dianne Evans', 88, '888/888/888/426', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15021, '2013-08-01 19:30:01.476058+00', '2019-07-19 09:39:01.907125+00', 'Chriss Cross', 'CHRISS CROSS', 2, 32, NULL, 1, 3, 42, 10645, NULL, 'For Chrissie Osborne on her 70th birthday



Devised by Robert Senior with much assistance from Margaret, Eileen, Amanda , Oliver and John.



This dance was devised for Chrissie Osborne for her 70th birthday - for which she held a magnificent Party Dance, with music by a six-piece Nicol McLaren & the Glencraig Band. A wonderful occasion befitting a wonderful lady -   and over £1200 was raised for Cancer UK.   The recommended recording for this dance is Marian Anderson’s Set of Jigs on the Belfast Diamond Jubilee CD.   This set includes tunes which Marian plays for Father Connelly’s Jig and bars 9-24 bear many similarities to movements in Father Connelly’s Jig (one of Chrissie’s favourite dances).

', 56, '800/888/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10638, '2002-07-01 22:00:00+00', '2019-07-21 09:11:41.485373+00', 'Tail Kinker''s Jig', 'TAIL KINKERS JIG', 2, 48, 9999, 1, 3, 42, 10300, NULL, 'The <<ddpub:Pawprints>> book has this dance also as a strathspey with the alternative title Dances with Shadows.', 35, '800/820/802/844/844/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19062, '2018-12-03 16:01:47.468295+00', '2019-07-23 17:10:57.123966+00', 'Trip to Orlova, A', 'TRIP TO ORLOVA', 1, 32, NULL, 1, 3, 42, 11752, '2017-01-01', 'In 2012 and 2016, Dunfermline Branch were asked to accompany a local church group to Orlova, in the Czech Republic. In 2012, the Branch provided the dancing for a fun Highland Games which included a large Dunfermline v Orlova tug of war - the dance represents travel to Orlova, the tug of war, the hands of friendship extended, the dancing and the races which also took place.', 64, '888/828/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16878, '2016-02-25 00:37:54.482901+00', '2019-07-23 12:41:23.44582+00', 'Copenhagen Dragons, The', 'COPENHAGEN DRAGONS', 2, 32, NULL, 1, 3, 42, 3379, '2015-05-01', 'The Copenhagen Dragons are the tails of four dragons intertwined on the spire of the børsen or stock exchange building in Copenhagen.', 63, '888/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19483, '2019-07-24 18:17:51.385804+00', '2019-07-27 09:52:45.888027+00', 'Partner Race Strathspey', 'PARTNER RACE STRATHSPEY', 3, 32, NULL, 1, 100, 2, 11152, '2008-02-24', 'Devised on the occasion of  the 80th birthday of Else Hartzberg on February 25 year 2008, 350 years after the peace in Roskilde 1658.  Celebrated on Sunday the 24th.



The instructions suggest using Castles in the Air by Peter White although that is an 8x32 recording whereas this is a 4x32 dance.', 69, '6886/8008/8448/8228', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19477, '2019-07-24 11:00:32.670152+00', '2019-07-24 11:03:53.493206+00', 'C. R. Petersens Strathspey', 'C R PETERSENS STRATHSPEY', 3, 32, NULL, 1, 4, 2, 11837, '2016-09-24', 'Devised to celebrate C. R. Petersen''s 70th birthday.', 84, '8888/8008/8668/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19478, '2019-07-24 11:17:53.950395+00', '2019-07-24 11:17:53.950395+00', 'Copenhagens'' Delight', 'COPENHAGENS DELIGHT', 1, 32, NULL, 1, 3, 42, 278, '1982-02-01', 'The instructions state that music for this dance was composed by Stanley Watts but the tune name(s) are not given.', 63, '844/888/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19479, '2019-07-24 11:28:54.622886+00', '2019-07-27 10:02:19.516246+00', 'Copenhagen Reel', 'COPENHAGEN REEL', 1, 32, NULL, 1, 3, 42, 11152, '2016-01-01', '', 56, '880/888/822/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16902, '2016-03-06 11:51:36.029243+00', '2019-08-01 06:18:55.457686+00', 'Mrs Carmichael of Okataina', 'MRS CARMICHAEL OF OKATAINA', 3, 32, NULL, 2, 3, 17, 11241, '2005-01-01', 'Devised by George Roberts to celebrate Joan Carmichael''s birthday which coincided with the Saltash

Scottish Country Dance Club''s Annual Christmas Social held on Saturday 10th December 2005.  



"Heagy" and Joan Carmichael used to run the Saltash Scottish Country Dance Club for many years.

"Okataina" is the name of their house. They were instrumental in encouraging Scottish country dancing in Cornwall.  



George Roberts plays the accordion and is lead of the Scottish Country dance Band, "Celtic Capers" and was playing for the dance that evening. When George plays this "live" he likes to use as the first tune "Peter Sanderson''s Strathspey" which is the first tune played by Hugh Ferguson on Reflections of Dalriada, track 2 for the strathspey "The Red Rose of Dunoon" which is a 4 x 32 bar strathspey.', 71, '822/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14565, '2012-09-08 08:55:29.241036+00', '2022-08-13 20:21:27.626559+00', 'Dance for David, A', 'DANCE FOR DAVID', 3, 32, NULL, 3, 5, 16, 2627, NULL, '', 75, '88888/48884/48884/82222', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16244, '2015-05-01 13:57:08.212308+00', '2019-07-24 15:19:11.599338+00', 'Fare Thee Well', 'FARE THEE WELL', 3, 40, 9999, 2, 3, 17, 84, '2005-01-01', '_Notes from the book ''Book of Tom''s Dances'':_  

*This dance was devised in 2005.  It is the sequel to "<<http://my.strathspey.org/dd/dance/7284/|Cape Town Wedding>>".  Sadly our marriage did not last, so the dance was devised to mark the parting of the ways.   

Like <<http://my.strathspey.org/dd/dance/7284/|Cape Town Wedding>> the figures are symbolic.  The all-round poussette symbolises being very much in love.  The couple is going out together symbolised by leading down the middle and up, but then the break up happens, and they cross and cast to go their separate ways, meeting occasionally thereafter.  As the Knot represents the wedding in Cape Town Wedding, I devised _Untie the Knot_ to symbolise the divorce.*



In 1995 Tom Kerr choreographed the dance "<<http://my.strathspey.org/dd/dance/7284/|Cape Town Wedding>>" for his own and Christine Dawson''s wedding celebration.  

', 55, '880/800/888/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17505, '2016-12-31 14:37:22.348022+00', '2020-11-02 09:31:22.325225+00', 'Revolving Hat, The', 'REVOLVING HAT', 2, 32, NULL, 2, 3, 4, 10934, NULL, 'This dance was devised at Scottish Week of Pinewoods Dance Camp.  During one particularly silly moment (not that I''d ever indulge this) at an evening dance, the hat I was wearing was constantly being switched from head to head.  This dance replicates this, switching places and partners throughout. Also, I think Scottish Country Dance could use more mixers.', 92, '880/888/888/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19501, '2019-07-25 11:26:55.845348+00', '2021-07-25 20:15:48.301016+00', 'Stockholm Ceilidh', 'STOCKHOLM CEILIDH', 2, 40, NULL, 1, 3, 42, 264, '2016-06-01', 'This dance is dedicated to the Scottish Country dancers in Stockholm, past and present, on the 40th Anniversary of the Stockholm Branch of the RSCDS, June 2016.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20409, '2021-07-30 09:12:21.809931+00', '2021-07-30 09:12:21.809931+00', 'Jean and Geoff', 'JEAN AND GEOFF', 1, 0, NULL, NULL, NULL, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19503, '2019-07-29 09:39:58.033927+00', '2019-07-29 10:00:03.881955+00', 'Durian Rant, The', 'DURIAN RANT', 1, 32, NULL, 1, 3, 42, 2682, '2019-04-29', 'Devised 23/4/2019 for an upcoming midwinter dances based on an international theme. We have members from both Malaysia and from Singapore, but all are united in their love of food. (1-8 Look at the durian hawker stall to see if it looks edible. 9-16 looking at the other hawker stalls and finding some friends. 17-24 eating the durian with them. 25-32 celebrating.) For Priscilla, Moira, and Nancy. Kristin and I lived in Singapore for several years.



', 56, '880/800/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19516, '2019-08-07 18:24:50.605906+00', '2019-08-08 07:04:22.720579+00', 'Stephen''s Found Baggage', 'STEPHENS FOUND BAGGAGE', 1, 32, NULL, 1, 4, 1, 10599, '2019-07-01', 'Dance composed by Anne Scobie at Summer School Week 2 2019, VA Low Impact Class to the tune "Stephen''s Lost Baggage" composed by our class musician, Ewan Galloway, for Stephen Kraus whose baggage had still not arrived on Tuesday morning.  



The dance represents the plane landing, passengers disembarking, going through customs and moving on to the baggage reclaim area, the carousel and a happy ending (as Stephen''s baggage did arrive Tuesday afternoon :-))', 72, '8000/8888/8888/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19523, '2019-08-11 21:16:29.79546+00', '2019-08-11 21:16:29.79546+00', 'Penny in Her Shoe, A', 'PENNY IN HER SHOE', 1, 48, NULL, 2, 3, NULL, 10719, NULL, 'For Shirley Guthrie.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19524, '2019-08-12 06:49:32.876332+00', '2019-08-12 06:50:26.257508+00', 'Midsummer Night''s Dream, A', 'MIDSUMMER NIGHTS DREAM', 3, 32, NULL, 4, 4, 4, 10699, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19525, '2019-08-12 07:01:48.158783+00', '2019-08-12 07:01:48.158783+00', 'High-Flying Hussy, The', 'HIGHFLYING HUSSY', 1, 32, NULL, 1, 3, 42, 10642, NULL, '', 41, '800/822/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19526, '2019-08-12 07:42:47.378933+00', '2019-08-12 07:42:47.378933+00', 'Dragonfly Reel, The', 'DRAGONFLY REEL', 1, 48, NULL, 1, 2, 76, 10719, NULL, '', 44, '64/54/46/45/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19504, '2019-07-29 10:16:36.151705+00', '2019-07-29 10:19:07.800827+00', 'New York Fugue, The', 'NEW YORK FUGUE', 3, 48, NULL, 1, 4, 1, 2682, '2019-02-24', 'Devised 24th February, 2019 following a request from Chris Ronald for a not unreasonably difficult fugue in Strathspey time. 



I would suggest ”Lochiel’s awa’ to France” by Niel Gow as the lead tune, but all recordings I know are 8 by 48. So for recorded music I would would use ”The Nether Bow Has Vanished” (4 × 48 recording) by Bobby Crowe, or ”Lucy of Lammermoor” by Peter White. Since all of these are on vinyl, for a CD recording, perhaps ”The Ellwyn Stathspey” by Ian Homes in the Highlander Series.



Personally, I would use Lochiel and edit the music. The music needs strong 2 bar phrases', 67, '8000/8800/8880/8888/8008/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19506, '2019-07-29 10:38:03.102643+00', '2019-07-30 19:40:26.530824+00', 'Dovecote Park', 'DOVECOTE PARK', 2, 32, NULL, 3, 5, 20, 2682, '2018-11-13', 'Devised 20 October 2018. Revised 13 November 2018. Written for the recording of a 5 by 32 J of the same name by Jim Cameron and his band (Jim Cameron and his Scottish Band Vol. 2) for which I could find no written dance. The set they use is excellent. Dovecote Park (James Braidwood), Midlothian Pipe Band (F Beaton), and The Quaker (Trad). As best I can tell, the organization is 64 bars of Dovecote Park, Midlothian Pipe Band repeated twice and The Quaker once.



Given that this is not a widely known (nor owned) recording, acceptable alternative recorded music would include (preferably) the Muriel Johnston 5×32 recording of ”The Campbells are Coming” in the Society’s recording of Music for Book 24, and alternatively any good recording of Airie Bennan (e.g. Ron Gonella, Caber Feidh, Peter White, or McBain), or finally if you lack such ancient recordings, the society’s recording of ”Vintage Simon” would work at a pinch.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19515, '2019-08-07 10:05:27.082256+00', '2019-08-07 10:55:16.167599+00', 'Kobberhaughytta', 'KOBBERHAUGHYTTA', 2, 48, NULL, 1, 4, 11, 3445, '2014-03-01', 'Devised in February/March 2014 after the Ski’n’do at Kobberhaughytta in the woods north of Oslo, Norway.



To get to Kobberhaughytta, you walk or ski uphill, hence fourth couple is dancing couple. Kobberhaughytta has a bigger and a smaller hall, both very cosy. For the Ski’n’do, the dancers met for dancing at Kobberhaughytta the first night, went off on their separate tracks for skiing (or doing) the next day and met again in the evening for more common dancing.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19513, '2019-08-04 10:31:45.757747+00', '2019-08-04 10:58:30.295254+00', 'St Andrews Society of Denmark, The', 'SAINT ANDREWS SOCIETY OF DENMARK', 3, 32, NULL, 1, 3, NULL, 11169, NULL, 'Tune used for this dance is Michael''s compliments to Muriel and Robert



The published instructions are shown as a "Contributed Crib".  They must contain a misprint, as the entry into the tournée on [25] is impossible.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3265, '1997-04-03 22:00:00+00', '2019-08-04 16:14:00.263991+00', 'Jig Wi'' The Snap', 'JIG WI THE SNAP', 2, 36, 9999, 1, 3, 42, 129, NULL, 'The tune has four 8 bar phrases plus an extra 4 bars.', 53, '800/888/800/888/444', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19518, '2019-08-11 20:36:35.073343+00', '2019-08-11 20:36:35.073343+00', 'Merry Meet', 'MERRY MEET', 3, 32, NULL, 4, 4, 1, 11850, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19519, '2019-08-11 20:42:33.524967+00', '2019-08-11 20:42:33.524967+00', 'Eaglet in Flight, The', 'EAGLET IN FLIGHT', 1, 32, NULL, 1, 4, NULL, 10719, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19529, '2019-08-12 08:05:16.866762+00', '2019-08-12 08:06:15.304404+00', 'My Turn', 'MY TURN', 1, 48, NULL, 107, 55, 16, 11854, NULL, 'For five people arranged as:  

..1..  

5..2  

4..3  ', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19530, '2019-08-12 08:16:21.203331+00', '2019-08-12 08:16:21.203331+00', '1776', '1776', 1, 32, NULL, 3, 5, 35, 11855, NULL, '', 55, '84048/84048/00008/80888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19531, '2019-08-12 08:24:41.389735+00', '2019-08-12 08:24:41.389735+00', 'Basque Reel, The', 'BASQUE REEL', 1, 32, NULL, 1, 4, NULL, 10642, NULL, 'Pas-de-Basque is used exclusively in all figures.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19535, '2019-08-12 08:59:05.360374+00', '2019-08-12 08:59:05.360374+00', 'Jacob''s Jig', 'JACOBS JIG', 2, 32, NULL, 1, 3, 42, 11851, NULL, 'For Jacob Cameron Green.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19536, '2019-08-12 09:05:53.214832+00', '2019-08-12 09:05:53.214832+00', 'Lea''s Dream', 'LEAS DREAM', 2, 32, NULL, 1, 2, 76, 10699, NULL, '', 60, '88/80/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19487, '2019-07-24 20:18:23.541801+00', '2019-07-24 20:18:23.541801+00', 'Mr Stackling''s Rant', 'MR STACKLINGS RANT', 1, 32, NULL, 1, 3, 42, 11839, '2003-06-01', 'Devised to mark the 60th birthday of Mr Hå kan Stackling.', 63, '880/880/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7284, '2001-11-21 23:00:00+00', '2019-07-24 15:17:12.561463+00', 'Cape Town Wedding', 'CAPE TOWN WEDDING', 3, 32, 9999, 1, 3, 42, 84, '1995-01-01', 'Tom Kerr choreographed this dance for his own and Christine Dawson''s wedding celebration.



The _following corrections_ were included on a loose sheet "Notes on Dances by Bob Grant June 1996", when Book 39 was first sold in the Summer School bookshop:



- 9-16  Reel across is between 1st and 2nd positions

- 21-24  Use first setting step to advance into the circle.  Pull right shoulders back quickly and tightly





_Notes from the book ''Book of Tom''s Dances'':_  

*"The dance was devised in 1995 to celebrate my wedding to Christine Dawson in Cape Town. lt is symbolic in that the dancers crossd own without giving hands as they do not know each other.  

Turning the 3rd couple represents meeting other people; then they meet as they turn in the middle only to take right hands as they do not know each other well at that stage. As they lead up they get to know each other better represented by taking promenade hold for the reel across. After the petronella turn all join hands to form a circle representing the ring. The dance finishes with the Knot which represents the Wedding."*



_Some additional information_ from the "<<http://my.strathspey.org/dd/dance/16244/|Fare Thee Well>>" instructions in the ''Book of Tom''s Dances'':  

Unfortunately the marriage did not last, hence Tom Kerr devided the dance "<<http://my.strathspey.org/dd/dance/16244/|Fare Thee Well>>" as a sequel to "Cape Town Wedding". It contains the formation "Untie the Knot" to symbolize the divorce.

', 52, '802  880  888  880', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (19481, '2019-07-24 17:55:35.553269+00', '2019-07-24 17:55:35.553269+00', 'Milliteas', 'MILLITEAS', 1, 32, NULL, 2, 3, 46, 11152, '2008-01-12', 'The progression is 213 with all on opposite sides, the dance is then repeated from the bottom.', 59, '444/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19482, '2019-07-24 18:02:13.785668+00', '2019-07-24 18:02:13.785668+00', 'My way, on my day 160303', 'MY WAY ON MY DAY 160303', 3, 32, NULL, 1, 3, 42, 11152, '2016-03-03', '', 63, '880/880/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19486, '2019-07-24 19:30:48.649903+00', '2019-07-27 10:24:47.878299+00', 'Everlasting Flower, The', 'EVERLASTING FLOWER', 1, 40, NULL, 1, 100, 2, 11465, '2017-08-01', 'Devised as a tribute to Lise Nordal Rückert, Certified Teacher, for her relentless effort  in promoting Scottisch Country Dancing in Gothenburg, especially amongst young dancers, always bringing the standard of dancing to a very high level among the Branch members. Combining dancing with a good spirit and a good laugh has always been a landmark of hers.', 80, '8888/8448/8448/8888/8008', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19484, '2019-07-24 18:33:04.155736+00', '2019-07-24 18:33:04.155736+00', 'Two Towers Reel', 'TWO TOWERS REEL', 1, 32, NULL, 1, 3, 42, 11152, '2017-09-11', 'The instructions give the deviser as "CRP/CPH" without indicating who CPH might be.



Devised after a visit to Oslo where the City Hall has two towers.', 66, '866/888/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19485, '2019-07-24 19:12:38.988189+00', '2019-07-24 19:12:38.988189+00', 'Danish Royalties', 'DANISH ROYALTIES', 1, 40, NULL, 1, 3, 42, 11465, '1996-03-01', 'Devised as a tribute to The St. Andrew Society of Denmark, to mark the wedding of the Danish Prince Joachim to Miss Alexandra Manley, Hongkong.



Revised 2003-01-06.', 50, '880/844/844/888/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19490, '2019-07-24 21:49:39.039608+00', '2019-07-24 21:49:39.039608+00', 'Grapefruit on the Hill, The', 'GRAPEFRUIT ON THE HILL', 1, 32, NULL, 1, 3, 42, 3445, '2006-02-01', '', 59, '840/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19493, '2019-07-24 22:18:57.574641+00', '2019-07-27 12:16:04.459662+00', 'Northern Lights and Melting Snow', 'NORTHERN LIGHTS AND MELTING SNOW', 3, 32, NULL, 1, 3, 42, 1846, NULL, '', 56, '800/866/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19492, '2019-07-24 22:11:38.08541+00', '2019-07-24 22:11:38.08541+00', 'Last Day of Summer, The', 'LAST DAY OF SUMMER', 3, 32, NULL, 2, 3, 18, 11840, '2017-09-01', '', 83, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19494, '2019-07-24 22:26:13.499121+00', '2019-07-24 22:26:13.499121+00', 'SKI ''n'' DO', 'SKI N DO', 2, 32, NULL, 5, 2, 4, 154, '2014-02-01', 'Devised for the Ski ‘n’ Do weekend organised by Kjell Mathiesen and Martin McWilliam in the Kobberhaughytta near Oslo 21/23 February 2014.', 75, '44/44/88/88', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19499, '2019-07-25 10:14:04.504703+00', '2019-07-25 10:14:04.504703+00', 'Moth, The', 'MOTH', 1, 32, NULL, 1, 4, 1, 11844, '2017-01-01', '', 50, '8880/8080/8080/8000', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19500, '2019-07-25 10:49:01.075104+00', '2019-07-25 10:49:01.075104+00', 'Red Rose, The', 'RED ROSE', 1, 32, NULL, 1, 4, 11, 11845, '1991-05-27', 'Dedicated to Brita Viksten on her 70th birthday. At that time she was chairman of the Stockholm Branch.



Revised 2017.', 88, '8008/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19488, '2019-07-24 20:25:58.671261+00', '2019-07-27 10:47:46.354738+00', 'Summer in Gothenburg', 'SUMMER IN GOTHENBURG', 1, 40, NULL, 1, 3, 42, 11838, '2000-07-10', 'Devised to celebrate the 50th birthday of Gunnar Numeus.', 53, '800/822/844/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19491, '2019-07-24 21:59:18.70946+00', '2019-07-27 11:52:42.482949+00', 'Holmenkollen Strathspey, The', 'HOLMENKOLLEN STRATHSPEY', 3, 32, NULL, 1, 4, 2, 278, '1983-01-01', 'Written to mark the occasion of the 4th Scandinavian Scottish Weekend course.', 63, '8448/8448/8000/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19498, '2019-07-25 09:53:57.264895+00', '2019-07-27 14:57:41.848178+00', 'Happy Fourty (or Life Begins)', 'HAPPY FOURTY OR LIFE BEGINS', 1, 40, NULL, 1, 3, 42, 11845, '1992-01-01', 'Dedicated to the deviser''s wife Elke.', 41, '800/800/824/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19609, '2019-09-02 22:40:58.014972+00', '2020-12-22 22:53:57.767545+00', 'Handem Reel', 'HANDEM REEL', 3, 32, NULL, 2, 3, 17, 210, NULL, 'Dance Crib compiled by the deviser at <<https://www.scottish-country-dancing-dictionary.com/dance-crib/handem-reel.html>>.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12252, '2005-04-24 22:00:00+00', '2021-07-25 20:11:08.15777+00', 'Gairie Burn', 'GAIRIE BURN', 1, 48, 9999, 2, 3, 17, 264, '2003-10-01', 'Devised for the members of the St Andrew’s Scottish Country Dance Group, Kirriemuir.', 67, '800/822/888/822/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19480, '2019-07-24 17:46:36.961822+00', '2021-03-08 00:37:23.405542+00', 'Dancetide Strathspey 2010, The', 'DANCETIDE STRATHSPEY 2010', 3, 32, NULL, 1, 4, 13, 11152, '2010-09-19', '', 81, '8448/4884/8888/8880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3945, '1998-04-12 22:00:00+00', '2019-07-27 17:06:43.224268+00', 'Lord of Gondor, The', 'LORD OF GONDOR', 1, 288, 9999, 107, 56, NULL, 44, '1972-01-01', 'This demonstration dance, for 2 men and 4 women, is divided into three parts:  

- 1st figure: 88 bars  

- 2nd figure: 128 bars (two repeats of 64 bars on alternate diagonals)  

- 3rd figure: 72 bars  ', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19502, '2019-07-27 17:57:37.831735+00', '2019-07-27 17:57:37.831735+00', 'Linden''s Diamond', 'LINDENS DIAMOND', 3, 32, NULL, 1, 4, 1, 349, '2019-05-01', 'Devised for the 60th Anniversary of Linden Scottish Country Dance Club.



Full instructions are given in the notes to the youtube videos.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19517, '2019-08-10 13:03:16.242507+00', '2019-08-16 09:42:41.369723+00', 'Jim''s Tangents', 'JIMS TANGENTS', 1, 32, NULL, 1, 3, 42, 11847, '2019-07-01', 'Devised at Sumer School Week 2, 2019 to commemorate Jim Stott''s retiral after four years as Summer School Director.', 47, '811/808/811/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19537, '2019-08-12 09:12:29.88485+00', '2019-08-12 09:12:29.88485+00', 'Ant Rant', 'ANT RANT', 2, 40, NULL, 1, 3, 42, 10719, NULL, '', 40, '800/442/442/480/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7133, '2002-03-02 23:00:00+00', '2019-08-12 09:22:27.493089+00', 'Whortleberry', 'WHORTLEBERRY', 2, 40, 9999, 1, 4, NULL, 267, '1991-01-01', 'This dance was entered in SCDDB as "Whortleberry" presumably as part of entering either the

<<ddpub:25th Anniversary>> or <<ddpub:If the Ghillie Fits>> publications.

And the tune was given as <<ddt:Jack''s Prize Winner>>.



However in <<ddpub:Homemade Dances, volume 2>> the title is given as "The Whortleberry" and the tune specified is <<ddt:Barley Bree>>.



', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19527, '2019-08-12 07:50:28.726313+00', '2019-08-12 09:30:17.610024+00', 'Brooks'' Strathspey, The', 'BROOKS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 11337, NULL, 'Written for Bob and Chris Brooks who devised the meanwhile figure of bars 9-16 while dancing in Wilma Fee''s Manhattan Beach class, 21 April 1998.



There seems to be a typo in bars 21-24 of the instructions where the order is given as ending 3,2,1 but should be 2,3,1 for the following reels.', 92, '888/888/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19544, '2019-08-14 10:16:41.251117+00', '2019-08-14 10:16:41.251117+00', 'Catherine Wheel, The', 'CATHERINE WHEEL', 1, 32, NULL, 1, 3, 42, 3583, '2017-01-01', 'Dedicated to my maternal grandparents, John Gibb of Muiravonside [1896-1966] and Catherine McIntyre Young [1894-1944], born in the Village of Dean.', 41, '800/633/655/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (261, '1997-08-22 22:00:00+00', '2019-08-30 16:52:25.485444+00', 'At The Edge of The Clear Running Burn', 'AT THE EDGE OF THE CLEAR RUNNING BURN', 2, 32, 9999, 1, 4, 1, 519, '1978-01-01', 'Devised for the wedding of Claire Robertson and Brian East in 1978. The title was devised to include their initials.', 80, '8888/8888/7777/8020', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19546, '2019-08-14 10:46:53.790883+00', '2019-08-16 06:50:01.101325+00', '6-O and a Dog', '6O AND A DOG', 2, 32, NULL, 2, 3, 18, 11570, '2017-11-10', 'Dedicated to Steff Eckert. Turning 60, enjoying life, her family and senior Paul, the family dog.', 83, '888/888/080/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19547, '2019-08-14 10:55:11.721474+00', '2019-08-16 06:52:35.047429+00', 'Day Out, A', 'DAY OUT', 3, 32, NULL, 2, 3, 18, 11570, '2019-01-01', '', 88, '822/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19545, '2019-08-14 10:41:13.911243+00', '2019-08-16 06:54:52.614046+00', 'Spinning Top, The', 'SPINNING TOP', 1, 32, NULL, 1, 4, 5, 11570, NULL, 'Dedicated to Rainer Schwarz.', 75, '8004/8888/8888/8228', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19610, '2019-09-02 22:49:35.216802+00', '2019-09-03 09:39:05.856717+00', 'Hallowed Moon, The', 'HALLOWED MOON', 1, 40, NULL, 1, 3, 42, 2634, '2001-12-01', 'Dance Crib compiled by the deviser, Shelagh Dempsey, December 2001', 53, '800/888/822/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19613, '2019-09-03 14:56:28.331083+00', '2019-09-03 14:56:28.331083+00', 'Frances, Our Treasure', 'FRANCES OUR TREASURE', 2, 32, NULL, 1, 3, 42, 555, '2017-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19615, '2019-09-03 19:25:51.862184+00', '2019-09-03 19:54:31.853434+00', 'VCS Ruby Jubilee, The', 'VCS RUBY JUBILEE', 3, 32, NULL, 1, 4, 1, 11508, '2017-01-01', 'Devised in 2017 to celebrate the 40th anniversary of the Flemish Caledonian Society in Ghent, Belgium (VCS – Vlaams Caledonische Society vzw founded in 1977)', 69, '8800/8880/8224/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19557, '2019-08-26 12:46:41.492558+00', '2019-09-23 19:30:58.000389+00', 'Double Sixty', 'DOUBLE SIXTY', 1, 32, NULL, 1, 3, 42, 11861, '2015-03-14', 'This dance and accompanying tune were written to celebrate Greg and Olga Reznick''s 120 (2x60) years of living, celebrated on March 14, 2015.', 61, '804/888/855/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19607, '2019-09-02 22:07:27.749216+00', '2019-11-20 09:22:50.620224+00', 'Hot Trod, The', 'HOT TROD', 1, 40, NULL, 1, 4, 2, 9998, NULL, 'Source: Minicrib only

', 80, '4884/8228/8448/8668/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19542, '2019-08-14 09:25:46.337645+00', '2020-03-29 18:11:26.013432+00', 'Trinity Knot, The', 'TRINITY KNOT', 1, 32, NULL, 6, 3, 18, 3583, '2018-11-01', 'A freely downloadable recording of music for this dance is available via <<http://www.fiddletree-music.com/johnturner/scdrecordings.html>>', 100, '888/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19514, '2019-08-06 09:08:04.764495+00', '2021-01-01 20:16:44.545181+00', 'Director Jim', 'DIRECTOR JIM', 3, 32, NULL, 1, 4, 1, 11847, '2019-07-01', 'Devised by Gordon Porter Summer School Week 2 2019 commemorating Jim Stott''s retiral after four years as Summer School Director, in St Andrews', 95, '8888/8888/8288/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19538, '2019-08-12 16:23:13.626673+00', '2020-05-08 17:18:50.15926+00', 'Paddy''s Milestone', 'PADDYS MILESTONE', 2, 32, NULL, 1, 3, NULL, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19612, '2019-09-02 23:53:46.470975+00', '2020-08-25 18:49:18.192439+00', 'Gigolette', 'GIGOLETTE', 2, 24, NULL, 1, 3, 42, 9998, NULL, 'Sole source - Minicrib', 42, '800/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19616, '2019-09-03 20:54:48.826411+00', '2020-11-27 18:17:48.627934+00', 'Eileen Rumble MBE', 'EILEEN RUMBLE MBE', 2, 64, NULL, 1, 4, 2, 11872, '2015-01-01', '', 80, '0880/8888/8668/8448/8888/8008/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19495, '2019-07-25 08:23:30.86039+00', '2021-04-06 11:27:37.130893+00', '33rd Priest''s Street', '33RD PRIESTS STREET', 3, 32, NULL, 1, 3, 42, 11841, '2016-03-07', 'The Stockholm RSCDS branch have their weekly dance at the address Prästgatan 33 (33rd, Priests’ street) in the Old Town of Stockholm. In the Scandinavian dance book PDF the name of the dance is incorrectly given as "The 33rd Priest" (which is added as an alias).



An as yet unnamed tune was composed for the dance by Mikael Georgii. You can listen to him playing it once through at <<https://www.youtube.com/watch?v=w74L9H_VBpM>>', 47, '880/844/822/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19568, '2019-08-30 18:33:41.342109+00', '2019-09-04 17:11:48.092366+00', 'New Lanark Strathspey, The', 'NEW LANARK STRATHSPEY', 3, 32, NULL, 1, 4, 1, 11865, NULL, 'Devised by Myra Gibson, Lanark Branch, to celebrate the occasion of New Lanark receiving “World Heritage Status”.', 81, '8668/8008/4888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19570, '2019-08-30 18:48:34.596413+00', '2019-09-04 21:38:42.547106+00', 'Oor Betty''s 80th', 'OOR BETTYS 80TH', 1, 32, NULL, 1, 4, 1, 11453, NULL, '', 100, '8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2582, '1997-09-03 22:00:00+00', '2019-08-16 00:02:41.252829+00', 'Gold Of Fairnilee, The', 'GOLD OF FAIRNILEE', 2, 32, 9999, 1, 3, 42, 13, NULL, 'From the deviser: *"I would like to thank the members of Sutton Coldfield RSCDS, and their friends,

for trying out these dances, and Barry Priddey for making this possible."*  



*“Atween the wet ground and the dry  

The gold of Fairnilee doth lie.”*  

This old verse is supposed to give a clue as to the whereabouts of a hoard of gold buried near the Eildon Hills.', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4841, '2001-03-13 23:00:00+00', '2019-08-18 10:51:59.136614+00', 'Muse Cottage', 'MUSE COTTAGE', 1, 40, 9999, 6, 3, 17, 389, '1988-03-26', 'Devised for Muriel Johnstone of Allanton, Scotland to commemorate her first visit to America and to thank her for all the beautiful Scottish music she shares with us.

', 95, '688/888/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18310, '2018-04-29 12:08:07.202223+00', '2019-08-16 07:41:33.868566+00', 'Marry Me, Again', 'MARRY ME AGAIN', 3, 32, NULL, 2, 3, 18, 11570, '2018-03-15', 'Deviser says: “Dedicated to Alfred Kolb. We ‘upgraded’ to full marriage exactly three years after our Registered Partnership even though the first time felt like THE marriage. The starting formation (The Rose Progression) is the connection to our original wedding dance, <<ddd:Imagine>>.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19549, '2019-08-16 17:04:24.767122+00', '2019-09-08 06:23:04.593488+00', 'Tactful Dancers', 'TACTFUL DANCERS', 1, 32, NULL, 1, 3, 42, 2973, '2016-08-01', 'Devised in honour of Elizabeth Woodbury who loves sailing.', 64, '844/666/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19597, '2019-09-02 15:06:36.549552+00', '2019-09-21 01:28:01.604961+00', 'Perfect Vision in 2020', 'PERFECT VISION IN 2020', 3, 40, NULL, 2, 3, 17, 11032, '2019-07-04', '', 60, '844/844/800/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19601, '2019-09-02 16:41:04.805228+00', '2022-03-21 16:49:29.454948+00', 'Let''s Go For A Whirl', 'LETS GO FOR A WHIRL', 1, 40, NULL, 2, 3, 17, 210, NULL, 'Can be danced as a Strathspey or as a Reel', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4248, '2002-12-31 23:00:00+00', '2019-08-29 08:36:10.399159+00', 'Maze, The', 'MAZE', 1, 40, 9999, 1, 3, 42, 1117, '1975-03-01', 'At the ceilidh preceding the annual London Branch workshop in March of 1975, the Glenfinnan dancers demonstrated this dance, and announced a contest to name it.  The winning entry, selected by the composer, was “The Maze”, suggested by the configuration of bars 17-32.



In the published original instructions both text and diagrams have errors.  The e-crib editors have received the corrections by a private e-mail from the deviser.   The essential correction is that on bar 16 1c finish on OPPOSITE sides (2x.1x.3x). From that position, 1c dance the full pattern [17-30], finishing on [31-32] by dancing to meet their partner on the midline (1W above, 1M below)  and facing 1/4 Right, ready for the RHA.  

  







', 60, '800/844/888/888/888', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (19620, '2019-09-03 21:59:41.880394+00', '2019-09-04 07:37:01.73408+00', 'Butterchurn, The', 'BUTTERCHURN', 2, 32, NULL, 1, 2, 76, 2634, '2000-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19575, '2019-08-30 19:38:14.072711+00', '2019-09-04 21:58:25.582594+00', 'Davidsons'' Farewell', 'DAVIDSONS FAREWELL', 3, 32, NULL, 1, 4, 2, 3432, '2008-10-01', 'On the occasion of Bob and Jil Davidson’s relocation to Florida and in honor of their many years of dedication and service to the Harrisburg Scottish Country Dance Society.

', 75, '8444/8888/8808/8048', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19567, '2019-08-30 13:05:40.303431+00', '2019-09-04 22:16:04.432771+00', 'Ms. Dean''s Fancy', 'MS DEANS FANCY', 2, 32, NULL, 2, 3, 17, 11864, NULL, 'In remembrance of Ms. Joan Dean a long time dancer and supporter of the Lyndhurst Group of the RSCDS,  Scottish Dancing and The Scottish Heritage Association of Northeast Ohio USA. Ms. Dean was a proud Veteran of the Royal Canadian Air Force.', 58, '880/800/880/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19632, '2019-09-05 19:35:37.218391+00', '2019-09-05 19:35:37.218391+00', 'Climbing Marguareis', 'CLIMBING MARGUAREIS', 4, 320, 10045, 3, 129, 35, 10612, '2019-01-01', 'The Punta Marguareis (It) or Pointe Marguareis (Fr) is a mountain in the Ligurian Alps, on the boundary between Italy and France; It is the highest peak of the Ligurian Alps.', 60, '00008/00888/88888/88008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13961, '2011-08-24 22:00:00+00', '2019-09-07 18:26:01.774569+00', 'Clement Street Reel, The', 'CLEMENT STREET REEL', 1, 32, NULL, 1, 2, 76, 954, '2004-06-01', 'Devised June 2004 by the San Francisco Youth class teachers, Susie Langdon Kass and Pat O''Brien. Originally, the dance was named "Maids in the Mirror" by the 2004 San Francisco Youth class dancers. The class met in a studio with mirrors on two sides. The class was all girls.  

We used this dance for one of our adjudication dances at the 2004 Pleasanton Scottish Games.  

The alternate title, "The Clement Street Reel", was given to the dance because the studio is on Clement Street. SLK', 50, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19662, '2019-09-22 16:17:22.615454+00', '2019-09-23 09:28:46.175626+00', 'Diamond in Sutton Coldfield, A', 'DIAMOND IN SUTTON COLDFIELD', 3, 32, NULL, 2, 3, 17, 3694, NULL, 'To celebrate 60 years of Scottish Country Dancing in the Royal Burgh of Sutton Coldfield', 88, '880/888/848/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19548, '2019-08-16 16:55:16.112741+00', '2021-03-31 19:33:29.454108+00', 'Felicity''s Frolic', 'FELICITYS FROLIC', 1, 32, NULL, 1, 3, 42, 2973, '2013-07-01', 'This may also be danced to jig or strathspey music.', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15235, '2013-11-12 18:51:48.839922+00', '2021-04-08 12:36:46.564044+00', 'Animals Lit Up Two by Two, The', 'ANIMALS LIT UP TWO BY TWO', 1, 40, NULL, 1, 102, 2, 3631, NULL, 'Dance devised for the wedding of Fiona Welland and Stephen Brockbank at Carbisdale castle on 20th February 2010.  Fiona is a vet, and Stephen works with lighting, hence the name.', 85, '8448/8008/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19550, '2019-08-16 20:21:42.673848+00', '2020-06-12 16:51:09.222712+00', 'Sum of All the Parts, The', 'SUM OF ALL THE PARTS', 3, 32, NULL, 2, 3, 17, 2973, '2019-06-01', 'Dedicated to Naomi Lasher, with huge gratitude for the use of her dance studio for training candidates for the RSCDS examinations.  The dance is named after an autobiography she has written.', 83, '880/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19625, '2019-09-04 08:28:59.099998+00', '2020-11-27 18:26:11.880993+00', 'Townsend''s Farewell To Sidholme', 'TOWNSENDS FAREWELL TO SIDHOLME', 2, 32, NULL, 1, 3, 42, 1368, NULL, 'Sole source:  Minicrib', 53, '800/888/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19673, '2019-09-26 10:56:12.291257+00', '2020-07-10 22:20:04.716959+00', 'Quick Brew', 'QUICK BREW', 1, 40, NULL, 1, 4, 2, 135, NULL, '', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19700, '2019-10-16 04:02:06.765475+00', '2019-10-16 13:46:01.272644+00', 'Rose Street, Thistle Street', 'ROSE STREET THISTLE STREET', 2, 32, NULL, 1, 2, 76, 11889, NULL, '', 0, '84/48/84/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14516, '2012-07-06 08:22:27.447576+00', '2019-08-21 11:57:49.79358+00', 'Ken McFarland''s Jig', 'KEN MACFARLANDS JIG', 2, 32, NULL, 1, 4, 1, 3101, NULL, 'Ken McFarland arranges and leads excursions for dancers in many places throughout the world. He brings

along top flight musicians and other guests such as John Drewry. I got to know John trudging through the ruins of Greek architecture in Turkey, exploring the beaches and caldera on Hawaii, and other places such as dining in a Swiss type chalet on a mountain lake in Ecuador or climbing a peak in the Andes to do a Scottish dance at the top. This dance is inscribed to Ken who as teacher and traveler is well known throughout the Scottish Dance community.', 56, '8000/0008/8088/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19585, '2019-09-01 16:33:26.208694+00', '2019-09-20 23:31:41.876435+00', 'Day in Prague, A', 'DAY IN PRAGUE', 1, 40, NULL, 1, 102, 2, 969, NULL, 'Music:  A vigorous hornpipe-like reel (or just a hornpipe!), preferably in a minor key to start.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19596, '2019-09-02 11:42:53.681957+00', '2019-09-02 21:56:04.920571+00', 'Home Farm Jig', 'HOME FARM JIG', 2, 32, NULL, 1, 3, 42, 11870, NULL, 'This dance was written for Nettie Merrick by her grandson Graham, named after Nettie’s family home. Harrow and District Caledonian Society.', 53, '880/888/800/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19606, '2019-09-02 21:11:51.010563+00', '2019-09-02 21:13:49.39885+00', 'Jo''s Square', 'JOS SQUARE', 2, 80, NULL, 4, 4, 3, 3597, NULL, 'Dance Crib compiled by the deviser, Sue Ayland', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19578, '2019-08-30 20:04:42.492394+00', '2019-09-04 22:08:25.581672+00', 'Scottish Responce, The', 'SCOTTISH RESPONCE', 3, 32, NULL, 2, 3, 17, 11719, NULL, 'Source: <<sspey:6022|strathspey message 6022>>. The (mis)spelling of "Responce" in the title is deliberate.', 83, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (257, '1998-10-26 23:00:00+00', '2019-08-27 22:15:37.593947+00', 'Assembly, The', 'ASSEMBLY', 1, 128, 9999, 4, 4, 3, 9998, NULL, 'Different versions of this dance are in circlation.  The one used for this entry has 128 bars.  There is a 144 bar version, in which [25-32] is replaced by [25-48] in which the Men repeat [1-24].



The versions have other differences too, like allemande replacing promenade, or differences in phrasing.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12143, '2005-04-11 22:00:00+00', '2019-11-15 15:31:06.096994+00', 'Baldovan Rant, The', 'BALDOVAN RANT', 1, 32, 9999, 9, 7, 87, 534, NULL, '', 43, '8538530/8448440/8448440/8000000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19618, '2019-09-03 21:17:26.751268+00', '2022-09-06 17:15:30.179859+00', 'Diamond Jig', 'DIAMOND JIG', 2, 80, NULL, 4, 4, 3, 11155, '2018-05-01', 'This dance, Diamond Jig (Robson), was devised by the Tawa SCD Club tutor, Maureen Robson, to celebrate the Tawa SCD Club''s 60th anniversary in 2018.



Music was especially composed for the dance by Wellington musician Peter Elmes. ', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19577, '2019-08-30 19:55:19.268173+00', '2022-12-22 18:27:04.33432+00', 'Jennifer McFarlane''s Wedding', 'JENNIFER MACFARLANES WEDDING', 3, 48, NULL, 3, 5, 16, 725, '2017-09-17', '', 73, '80000/88888/88880/88888/88888/82222', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14512, '2012-07-04 13:14:01.555807+00', '2019-08-21 02:45:20.327629+00', 'Phase Rule', 'PHASE RULE', 1, 32, NULL, 1, 3, 42, 3101, NULL, 'Notes:  

  - Bars 17-20 1st couple must take measured steps to be in the middle (halfway) on bar 19  

  - Bars 25-30 1st couple should make the tum in 3 bars leaving 3 bars to dance out the end and cast to 2nd place  



The New Haven Scottish Country Dance class since its founding has danced within a few blocks of the spot on Wall Street where J. Willard Gibbs spent his life (1839-1903). Educated at Hopkins Grammar School and Yale, he received the first doctorate in engineering ever given in the U.S.A. in 1863. He taught Latin for two years and Natural Philosophy for one year at Yale before spending three years in Paris, Berlin and Heidelberg. He returned to Yale in 1869 and in 1871 became Professor of Mathematical Physics.  



In 1878, he published the second part of his "Equilibrium of Heterogeneous Substances", one of the most important works in the history of chemistry. To quote Prof Frank H. MacDougall, M.f\. (Queen''s), Ph.D. (Leipzig) "Where F is the number of degrees of freedom of a system of C components in P phases in equilibrium F = C + 2 - P. This is the famous Phase Rule enunciated by Willard Gibbs". The phase rule is especially useful in the study of heterogeneous equilibria that are the bases of many important industrial processes. The Gibbs Medal of the American Chemical Society has been a yearly award to outstanding chemists starting with Svante A. Arrhenius in 1911.  



Gibb''s work in vector analysis is of import in pure mathematics. He applied it to find the orbit of a comet from just three observations. He made advancements in the electromagnetic theory of light, in statistical mechanics and in thermodynamics. He was greatly admired by such as Kirchoff, Helmholtz and James C. Maxwell. He was awarded the Copley Medal of the Royal Society, the most prestigious science prize of his day. ', 47, '800/888/866/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19552, '2019-08-21 22:46:20.008961+00', '2019-08-21 22:48:39.850266+00', 'Lady Crawfurd''s Reel', 'LADY CRAWFURDS REEL', 2, 64, NULL, 1, 4, 2, 11860, NULL, '', 78, '8880/8008/8888/8008/8888/8888/6666/6666', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14506, '2012-07-04 12:55:35.646761+00', '2019-08-21 22:22:30.954541+00', 'Stella Strathspey, The', 'STELLA STRATHSPEY', 3, 32, NULL, 2, 3, 17, 3101, NULL, 'This dance is inscribed to Stella Fogg who teaches Scottish Country Dancing all around the U.S.A. Stella also teaches in Scotland and in Canada. Raised in Gourock on the River Clyde near Glasgow, Stella has had as home base for more than 20 years Richmond, Virginia on the James River. She saves out some weekends to dance at Branch balls throughout eastern U.S A. where the branch members look forward to dancing with her. There is a warmth for fellow dancers and a love of dancing emanating from her that makes her a favorite in any set.  



Stella grew up ceilidh dancing and turned to Scottish Country Dancing in the Girl Guides. She married a US sailor and moved across the pond, initially to Maine, Brian''s home state. On a posting to Hawaii, Stella was encouraged by Mary Brandon to take her teaching certificate in Scottish Country Dancing. She did so and gained her preliminary certificate in Hawaii with Miss Milligan as the examiner. Some years later, while living in Richmond, Stella received her full certificate at TAC -the Teachers Association of Canada. Stella is also the deviser of several dances. ', 79, '880/884/808/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1898, '1998-07-09 22:00:00+00', '2019-08-21 23:24:39.273994+00', 'Easthampstead Park', 'EASTHAMPSTEAD PARK', 3, 32, 9999, 2, 3, 17, 270, NULL, '', 77, '888/850/888/805', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19554, '2019-08-23 16:56:26.725728+00', '2019-08-28 09:22:55.108581+00', 'Frank''s Birthday Reel', 'FRANKS BIRTHDAY REEL', 1, 32, NULL, 2, 3, 17, 11863, '2019-01-01', 'Dance devised by Ruth MacInnes and Peter Jamieson to mark the occasion of Frank Stephen’s 70th birthday, celebrated on 2nd August 2019 with a dance at Munlochy Hall. 



Music selected by Joy Bisset.



Notes: bars 9-24 are essentially modified Mairi’s wedding reels, with the 1s starting slightly advanced and then dancing a similar path to that danced in Australian Ladies.  Corners must clear the centre of the dance promptly to allow this, so twirls and hand pats are not recommended.

', 54, '840/844/844/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19621, '2019-09-03 22:12:44.434786+00', '2019-09-03 22:12:44.434786+00', 'Birthday Present, The', 'BIRTHDAY PRESENT', 3, 32, NULL, 1, 4, 13, 3597, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19622, '2019-09-03 22:18:11.548497+00', '2019-09-03 22:18:11.548497+00', 'Big Tam', 'BIG TAM', 1, 40, NULL, 1, 4, 1, 851, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19571, '2019-08-30 18:57:45.911444+00', '2019-09-04 21:42:19.082998+00', 'Sam the Man', 'SAM THE MAN', 2, 40, NULL, 1, 4, 1, 11866, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19572, '2019-08-30 19:09:15.118241+00', '2019-09-04 17:06:10.578042+00', 'Weaver Strathspey, The', 'WEAVER STRATHSPEY', 3, 32, NULL, 1, 4, 1, 3143, '2008-09-01', '', 78, '8008/8888/8888/8444', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19553, '2019-08-22 09:06:10.138522+00', '2019-09-14 23:50:58.214682+00', 'Dr Wagstaff''s Strathspey', 'DR WAGSTAFFS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 3775, '2019-08-20', 'Devised for Dr Karin Wagstaff', 50, '888/880/800/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6087, '2002-10-15 22:00:00+00', '2019-09-24 23:58:44.984115+00', 'Silver Sails', 'SILVER SAILS', 3, 96, 9999, 4, 4, 3, 93, '1977-01-01', 'Devised by Les Cumming of Canberra and District Branch of the R.S.C.D.S. And dedicated to the Sydney Branch of the R.S.C.D.S. On the occasion of their 25th Anniversary in 1977.



The dance has three 32-bar sections, [65-96] repeat [1-32].', 93, '8888/8888/8888/8888//6666/6666/6666/6666//8888/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8702, '2002-10-13 22:00:00+00', '2019-09-08 10:40:10.845139+00', 'Back on Track', 'BACK ON TRACK', 3, 40, 9999, 2, 3, 18, 1445, '2001-01-01', 'This dance is dedicated to Mrs. Frans Ligtmans, teacher fo the Eindhoven group, who recently, after a serius illness and operation went back home, well on the way to full recovery.', 73, '880  888  844  844  844', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (19573, '2019-08-30 19:19:21.184963+00', '2021-08-02 19:54:19.040939+00', 'Blue Shoes', 'BLUE SHOES', 1, 32, NULL, 1, 3, 42, 1234, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19588, '2019-09-01 21:01:15.358778+00', '2019-09-01 21:01:15.358778+00', 'Marcela', 'MARCELA', 3, 32, NULL, 2, 3, 17, 969, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19582, '2019-09-01 12:01:25.272213+00', '2019-09-01 22:19:45.052433+00', 'Neighbourliness', 'NEIGHBOURLINESS', 3, 48, NULL, 4, 4, 13, 11237, '2019-01-01', '', 88, '8888/8888/8888/2828/8282/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19595, '2019-09-02 10:55:34.809133+00', '2019-09-02 16:35:03.480321+00', 'Liam Thomas', 'LIAM THOMAS', 2, 32, NULL, 1, 3, 42, 11035, '2018-01-01', 'Source: MiniCrib and video.', 38, '800/880/800/808', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19590, '2019-09-01 23:16:52.450732+00', '2019-09-02 02:25:39.201126+00', 'Riverbank', 'RIVERBANK', 3, 32, NULL, 3, 5, 7, 370, NULL, 'Crib written by the deviser', 65, '84844/82842/80880/84844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19593, '2019-09-02 10:40:19.557537+00', '2019-09-02 10:40:19.557537+00', 'Meols Village Jig', 'MEOLS VILLAGE JIG', 2, 32, NULL, 2, 3, 17, 11000, '2017-01-01', '', 45, '432/432/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4637, '1997-09-09 22:00:00+00', '2022-08-12 10:45:09.654338+00', 'Monica''s Fancy', 'MONICAS FANCY', 2, 32, 9999, 1, 3, 42, 885, NULL, '', 69, '888/880/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19623, '2019-09-03 22:30:23.586991+00', '2022-12-22 18:19:54.796221+00', 'Andromeda', 'ANDROMEDA', 1, 48, NULL, 107, 8, NULL, 725, '2017-08-08', 'For two longwise sets of four couples, side by side.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19654, '2019-09-16 06:53:04.528563+00', '2019-09-16 06:53:04.528563+00', 'Spurtle Cat', 'SPURTLE CAT', 1, 48, NULL, 1, 3, 42, 11877, '2013-01-01', 'Devised by Victoria Lewis, 2013 ; revised 2018.  



Spurtle Cat is dedicated to Greg and Olga''s cat, Winona ---with homage to one of Greg''s favorite figures, the spurtle.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19580, '2019-09-01 11:31:30.674115+00', '2020-11-26 10:47:43.228097+00', 'Wedding Breakfast, The', 'WEDDING BREAKFAST', 1, 32, NULL, 5, 2, 76, 9998, NULL, 'Source: only Minicrib', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19576, '2019-08-30 19:48:03.418927+00', '2020-02-02 10:21:52.991884+00', 'Four Hand Star', 'FOUR HAND STAR', 1, 32, NULL, 5, 2, NULL, 9998, NULL, 'Easy Ceilidh dance: see videos



https://www.youtube.com/watch?v=WZOi8wmlHZk



https://www.youtube.com/watch?v=tQK0IaHCfto

', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19592, '2019-09-01 23:33:25.590208+00', '2020-01-20 00:31:40.845917+00', 'Red Arrows, The', 'RED ARROWS', 1, 32, NULL, 1, 3, 42, 370, '2017-01-01', '', 56, '800/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19581, '2019-09-01 11:56:31.955989+00', '2020-02-20 15:17:20.224153+00', 'Parallelogram', 'PARALLELOGRAM', 3, 32, NULL, 1, 102, 11, 11237, '2019-02-01', '', 88, '8008/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19599, '2019-09-02 16:17:04.269007+00', '2020-02-16 01:05:40.287758+00', 'Marion''s Welcome (To Ottawa)', 'MARIONS WELCOME TO OTTAWA', 1, 32, NULL, 2, 3, 18, 11871, '2015-08-01', 'Devised by Bryan Gordon to welcome Marion Hamilton to Ottawa in 2015



Dance Crib compiled by the deviser, Bryan Gordon, Aug 2017', 93, '484/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19594, '2019-09-02 10:49:19.86386+00', '2020-11-03 09:48:20.938446+00', 'Frances''s Goat Track', 'FRANCESS GOAT TRACK', 1, 32, NULL, 1, 4, 5, 11035, '2016-01-01', 'Source: MiniCrib and video.

There are copies of this dance in circulation which have  the title "Frances'' Goat Track" but the deviser has confirmed (Nov 2020) that she prefers "Frances''s Goat Track"', 44, '4400/4400/8888/8000', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19579, '2019-09-01 11:18:27.495192+00', '2020-11-26 10:45:40.18501+00', 'West Camel Reel', 'WEST CAMEL REEL', 1, 32, NULL, 1, 3, 42, 11238, NULL, 'Source: Minicrib only', 63, '888/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19583, '2019-09-01 13:59:07.699683+00', '2020-11-26 10:51:11.679439+00', 'Trip to Disnay, A', 'TRIP TO DISNAY', 1, 32, NULL, 1, 3, 42, 11868, '2015-01-01', 'Sole source: Minicrib', 45, '880/802/880/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19586, '2019-09-01 20:48:44.630989+00', '2020-11-26 10:54:00.725601+00', 'Tarbert Fair', 'TARBERT FAIR', 2, 32, NULL, 1, 4, 1, 1990, NULL, 'Source: Minicrib only', 66, '8888/8440/8044/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19591, '2019-09-01 23:28:05.209766+00', '2020-11-26 10:56:28.302537+00', 'Reel For Brenda', 'REEL FOR BRENDA', 1, 32, NULL, 1, 4, 1, 449, NULL, 'Source: Only Minicrib', 72, '8008/8448/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19605, '2019-09-02 21:04:55.0867+00', '2020-11-27 18:08:05.504964+00', 'Kalamunda 25', 'KALAMUNDA 25', 1, 32, NULL, 1, 4, 2, 841, NULL, '', 75, '8008/8448/8888/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19608, '2019-09-02 22:29:53.731234+00', '2020-11-27 18:10:14.79682+00', 'Highland Tour', 'HIGHLAND TOUR', 1, 32, NULL, 1, 3, 42, 11259, NULL, 'Sole source: Minicrib', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19600, '2019-09-02 16:28:15.848481+00', '2021-03-04 01:04:22.135446+00', 'Loki''s Dance', 'LOKIS DANCE', 2, 32, NULL, 1, 3, 42, 10959, '2014-04-01', 'Loki was a very affectionate dark gray & white cat who lived with our family for almost

15 years. He was named after the Norse god of mischief.  



_Recommended Music_: The Birlin Burkie CD: A'' the Best Fae Banffshire.', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3110, '1999-02-24 23:00:00+00', '2019-08-25 07:37:08.803592+00', 'Inverness Reel, The', 'INVERNESS REEL', 1, 144, 9999, 107, 56, 54, 392, NULL, 'The source of the alias "The Inverness Sixsome" is unclear, it is not on the original instructions. 



Under Music, the instructions state "Preferably use the same tune for each chorus, and one or more

tunes different from this for the figures." 



The original instructions were printed by TYPANLITH at the Pitman Press, Bath, probably as a leaflet. This text lists four sets of "chorus {16} plus Figure {16}", making 128 bars.  Other instructions in use add a final chorus {16}, making 144 bars.  



On Jan. 26, 2015, 10:30 p.m.  Heiko Schmidt (castle_ghost) wrote:



"I have a transcript of it (sent by Ron Mackey in 2007) - it is strangely written regarding this point:



At the top it says "4x32" which would be 128, but:



Then there is the description of the Chorus [16 bars] (not mentioning anything that it may not be danced)  followed by:



Figure 1: ‚St. Andrew’s Cross’ [16 bars] + Chorus [16 bars] Figure 2: ‚Spin Setting’ [16 bars] + Chorus [16 bars] Figure 3: ‚Half Reels’ [16 bars] + Chorus [16 bars] Figure 4: ‚Lines of Three’ [16 bars] + Chorus [16 bars]



Since there is no statement not to dance the 1st Chorus, and because there are remarks after the four other Choruses stating "[2nd]", "[3rd]", "[4th]" and "[5th]" that sums up to 144 bars.



Is there any information anywhere stating that the initial Chorus description is not intended to be danced? If yes, that would explain the 128 bars."



On this basis the editors have chosen to enter this as a 144 bar dance.

', 87, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19560, '2019-08-28 12:12:11.192251+00', '2019-08-29 09:40:28.599852+00', 'Be True to Yourself', 'BE TRUE TO YOURSELF', 3, 40, NULL, 2, 3, 17, 11237, '2018-05-01', 'In the past many lesbians and gay men have been, and in some places still are, pressured into contracting heterosexual marriages they really do not want. This dance is for those who have ended an undesirable relationship and found a more appropriate one.



1st couple are not suited to each other and quickly find that someone on their own side is more interesting. So they dance the Untie the Knot figure (from <<ddd:Fare Thee Well#16244>> devised by <<ddp:Kerr, Tom>>) and after a little further dalliance they each proceed to tie the Knot with a partner of the same sex. A long and happy life together passes in a flash and the two new pairs celebrate with a modified diamond (anniversary) poussette.

', 63, '804/880/808/808/808', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6243, '1998-07-08 22:00:00+00', '2019-08-29 19:49:50.302675+00', 'Spinning Wheel Reel, The', 'SPINNING WHEEL REEL', 1, 48, 9999, 1, 4, 15, 1816, '1976-01-01', 'The formations in the dance reminded the deviser of the movement of a large spinning wheel owned by a lady living in Ireland.', 94, '8888/8888/8888/8888/8888/6086', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19562, '2019-08-28 12:20:35.929922+00', '2019-08-28 13:49:33.22035+00', 'Cosi Fan Tutte', 'COSI FAN TUTTE', 2, 32, NULL, 1, 3, 42, 11237, '2017-09-01', '', 50, '840/644/644/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19561, '2019-08-28 12:16:36.830458+00', '2019-08-28 13:58:12.146354+00', 'Birling Dervishes, The', 'BIRLING DERVISHES', 1, 32, NULL, 1, 3, 42, 11237, '2017-01-01', '', 50, '800/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4992, '1997-08-22 22:00:00+00', '2019-08-29 20:20:15.534012+00', 'Northesk', 'NORTHESK', 3, 32, 9999, 1, 3, 42, 515, NULL, 'The river North Esk is a tributary of the river Esk which flows into the Firth of Forth at Musselburgh where the deviser was living at the time.', 63, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3753, '1998-07-08 22:00:00+00', '2019-08-30 16:20:58.37349+00', 'Law And Order', 'LAW AND ORDER', 1, 32, 9999, 1, 4, 2, 101, '1990-01-01', 'Devised for the wedding of Sarah McRae and Donnie Muirhead (a lawyer) ln May 1990.', 81, '8888/8008/8888/8448', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2762, '1997-08-20 22:00:00+00', '2019-08-29 21:41:23.168822+00', 'Hands Across The Sea', 'HANDS ACROSS THE SEA', 1, 32, 9999, 1, 3, 42, 101, '1990-01-01', 'Devised for the wedding (in Edinburgh) in September 1990 of Juliet Adamson (from Scotland) and Mark Davoren (from Australia), who were moving to Canada.', 56, '800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1590, '1997-08-20 22:00:00+00', '2019-08-30 14:51:58.176612+00', 'Dean Village Reel, The', 'DEAN VILLAGE REEL', 1, 32, 9999, 1, 3, 42, 101, '1993-01-01', 'Devised for the 70th birthday of John''s wife Christina. John and Christina lived in Dean Village, Edinburgh.', 56, '800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19709, '2019-10-24 16:31:22.032521+00', '2019-10-24 19:06:44.567608+00', 'President''s Fancy, The', 'PRESIDENTS FANCY', 1, 40, NULL, 1, NULL, 18, 11463, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19602, '2019-09-02 16:52:55.343817+00', '2022-08-15 11:51:51.411793+00', 'Keppoch Charm', 'KEPPOCH CHARM', 1, 32, NULL, 2, 3, 17, 210, NULL, 'Dance Crib compiled by the deviser, J. Duncan Keppie (<<https://www.scottish-country-dancing-dictionary.com/dance-crib/keppoch-charm.html>>).', 63, '840/888/800/808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5209, '2002-11-21 23:00:00+00', '2019-08-30 14:38:42.477693+00', 'Pelorus Jack', 'PELORUS JACK', 2, 32, 9999, 1, 3, 42, 352, '1993-01-01', '##>>

The dance title refers to a Risso’s dolphin, named after Pelorus Sound in Marlborough, New Zealand. From 1888 until 1912, the dolphin would pilot ships through French Pass, a particularly dangerous stretch of the Cook Strait. Although protected by an Act of Parliament of 1904, the dolphin disappeared after four Norwegian whaling ships passed through the Strait.  Wikipedia, however, offers: ‘research suggests that Pelorus Jack was an old animal; his head was white and his body pale, both indications of age, so it is likely that he died of natural causes’.



There is <<https://youtu.be/AgFQul3rlLk|archive footage>> of Pelorus Jack himself and also of <<https://youtu.be/qIg2H6gew7Y|Barry Skelton recounting the story>>.



Note that Risso''s dolphins are not the iconic animals everyone (or at any rate everyone who watched kids'' TV in the 1970s) knows from “Flipper”. They are bigger and have no “beak”.

##<<

', 47, '804  844  844  862', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (19569, '2019-08-30 18:41:33.778079+00', '2019-09-04 21:29:26.040308+00', 'Newcomer''s Jig', 'NEWCOMERS JIG', 2, 32, NULL, 2, 3, 17, 322, NULL, '', 44, '800/822/822/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19630, '2019-09-05 17:26:09.938854+00', '2020-10-04 14:45:20.870404+00', 'Jack''s Jig', 'JACKS JIG', 2, 48, NULL, 6, 3, 4, 952, '2010-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19629, '2019-09-05 17:19:19.028038+00', '2020-10-04 14:45:35.966127+00', 'Jack''s Strathspey', 'JACKS STRATHSPEY', 3, 32, NULL, 6, 3, 4, 952, '2010-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4421, '1998-07-09 22:00:00+00', '2021-05-15 20:34:19.83363+00', 'Miss Agnes Lowden', 'MISS AGNES LOWDEN', 3, 32, 9999, 2, 3, 94, 270, NULL, 'Dancing couples changes side on every repetition.



In the original publication, the name of this dance on the page of instructions was given as  "Miss Agness Lowden" while the table of contents has "Miss Agnes Lowden"  The deviser''s daughter, Alison Mitchell, prefers the more common spelling with a single S, "Miss Agnes Lowden".



<<scddb-not-identical:4420>>', 98, '886/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19574, '2019-08-30 19:23:43.340922+00', '2021-08-02 19:56:59.403365+00', 'Och Aye!', 'OCH AYE', 2, 32, NULL, 1, 3, 42, 10307, NULL, 'Originally entered as "Och, Aye!" the version on the OUSDS website is "Och Aye!". The former is now an alias.', 53, '880/800/888/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3838, '1997-04-03 22:00:00+00', '2019-09-08 12:47:07.183756+00', 'Little Cascade, The', 'LITTLE CASCADE', 2, 32, 9999, 1, 3, 42, 44, '1984-01-01', 'Devised during the evening of Wednesday the 1st of February, 1984 at Percy''s Reserve, Petone.  



Symbolism -  

1 - 16::

  The bubbling cascade in the valley behind the reserve.

17-24::

  The more gentle movement of the stream just before it enters a small lake.

25-32::

  The lake above the lawn where, for many years, the Wellington Region has held informal dancing during the summer months.', 42, '820/822/800/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19636, '2019-09-08 23:08:47.248118+00', '2019-09-08 23:37:48.279384+00', 'Office, The', 'OFFICE', 2, 32, NULL, 3, 5, 7, 2973, NULL, 'New dance, 2019, aka EH3 7AF for 5 couples.  Source: Dance List for Scotia Dancers August 12th 2019



', 67, '80800/88888/82842/84844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19556, '2019-08-26 12:38:23.300588+00', '2019-09-16 22:38:56.222587+00', 'Kate''s Apple Pie', 'KATES APPLE PIE', 2, 32, NULL, 1, 3, 42, 11861, NULL, '*Optional ending to get lst couple to the bottom of the set after 2nd repetition:*  

At the end of every second repetition, on bars 31 -32,1St couple accelerates at the end of the Comer Pass and Turn to cross by the left to finish at the bottom while the 3rd couple dances up one place to finish ready to circle with the couples above. (3rd man continues dancing while 3rd woman casts.)  





This dance was devised by Julia Wyrick for Kate Fletcher in appreciation for the delicious home baked pies she brings to the Berkeley socials. Julie wanted a modal tune to go with the dance, so Steve wrote "a la Mode" to go along with the pie!', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14921, '2013-05-30 15:13:44.029792+00', '2019-09-09 11:36:05.014443+00', 'Lover''s Lane', 'LOVERS LANE', 2, 32, NULL, 2, 3, 17, 1394, '2006-02-14', 'This dance was devised February 14,2006 to celebrate Valentine''s Day.



To be danced 3 x 32 or 6 x 32.  Can be danced in a 4C set (8 x 32), by using the modified [25-32] to change the progression to (2,1,3).', 46, '880/800/804/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19644, '2019-09-15 22:53:00.196328+00', '2019-09-16 23:37:55.162509+00', 'Second Home, A', 'SECOND HOME', 2, 32, NULL, 1, 2, 76, 10430, '2008-04-01', 'Devised by Lori Farrell Howard, April 22, 2008. Dedicated to the teachers and co-oping parents of Creative Play Center in Pleasant Hill, Califomia', 60, '88/44/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19663, '2019-09-23 08:47:43.600878+00', '2019-09-23 08:49:33.787504+00', 'Final City, The', 'FINAL CITY', 2, 32, NULL, 1, 3, 42, 635, '2015-01-01', '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2949, '1997-09-04 22:00:00+00', '2019-09-21 07:52:46.1231+00', 'Holborn March', 'HOLBORN MARCH', 11, 32, 9999, 1, 2, 76, 1000, NULL, 'A thirty two bar March for two couples in a longwise set, from Wright''s "Compleat Collection" (1740). The dance and music were originally published under the title "Princess Amelia" in 1731, in honour of a daughter of King George III.  



This dance is a March and should be walked throughout, except when setting. In the original instructions it says that the second strain of music is played twice, this is obviously incorrect, especially as it also indicates the wheels are danced right hands across halfway and back with the left

hand, which would not be particularly far to travel in sixteen bars.  



This dance is entered in the database as a medley but in <<http://my.strathspey.org/dd/issue/1766/|issue 1766>> it is claimed this is wrong - at least as it is danced by the US English Country Dance community.', -1, '80/08/88/80', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19637, '2019-09-09 21:02:40.636349+00', '2022-10-01 15:12:28.195561+00', 'Emmalien Jig', 'EMMALIEN JIG', 2, 32, NULL, 1, 3, 42, 10582, '2018-01-01', 'This dance is written in celebration of our friend Emma Trousdale’s 40th birthday', 52, '846/808/844/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19566, '2019-08-29 17:03:17.180057+00', '2022-04-26 15:10:50.147642+00', 'New Jubilee Jig, The', 'NEW JUBILEE JIG', 2, 32, NULL, 1, 4, 2, 401, NULL, '', 50, '4004/0440/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19563, '2019-08-28 12:28:08.56247+00', '2022-04-27 10:14:41.558514+00', 'Variations on a Theme', 'VARIATIONS ON A THEME', 3, 48, NULL, 2, 3, 18, 11237, '2019-06-01', 'This dance has tandem variations of the two couple bourrel (ie other options for three couple bourrels).', 89, '800/888/888/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19640, '2019-09-09 21:16:12.334323+00', '2022-10-01 18:26:55.006163+00', 'Stitches in time', 'STITCHES IN TIME', 3, 32, NULL, 1, 4, 1, 10582, '2018-01-01', 'This dance was devised for Margi Halkett in celebration of a milestone birthday', 81, '8888/8484/8888/8080', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19649, '2019-09-16 00:24:58.173663+00', '2019-09-16 00:33:20.16178+00', 'Coffee Rose of Saratoga, The', 'COFFEE ROSE OF SARATOGA', 3, 32, NULL, 2, 3, 17, 10786, '2014-01-01', 'Devised by Greg Reznick on the occasion of the marriage of Jacqueline Coffee and Mary Rose.', 83, '880/888/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19669, '2019-09-26 10:17:00.408163+00', '2019-09-26 10:17:00.408163+00', 'Bunty''s Party', 'BUNTYS PARTY', 2, 32, NULL, 1, 116, 13, 1075, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19645, '2019-09-16 00:10:24.092901+00', '2019-09-16 08:11:10.536954+00', 'Bernadette''s Bane', 'BERNADETTES BANE', 2, 40, NULL, 1, 3, 42, 10786, '2010-01-01', 'Devised by Greg Reznick for Bemadette Thill to honor her beautiful dancing, her wonderful observational skills, and a few of her pet peeves.', 72, '888/800/888/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19672, '2019-09-26 10:49:18.257666+00', '2019-09-26 10:49:18.257666+00', 'Ring of Kerry', 'RING OF KERRY', 1, 32, NULL, 2, 3, 17, 11883, NULL, '', 81, '888/484/808/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19656, '2019-09-16 06:58:15.224997+00', '2019-09-16 19:45:47.022884+00', 'Well-Oiled Machine, The', 'WELLOILED MACHINE', 2, 32, NULL, 1, 2, 76, 10430, '2016-01-01', '', 60, '88/08/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19658, '2019-09-16 21:11:36.520113+00', '2019-09-16 21:11:36.520113+00', 'Trip to the Zillertal, A', 'TRIP TO THE ZILLERTAL', 2, 32, NULL, 2, 2, 76, 11879, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19646, '2019-09-16 00:13:59.394052+00', '2019-09-16 21:41:40.569791+00', 'Carriage House, The', 'CARRIAGE HOUSE', 3, 32, NULL, 1, 2, 76, 1331, '2018-01-01', 'Devised by Bruce Herbold in memory of Greg Reznick.  



Greg and Olga went with us many times to hear our favorite musician, Richard Thompson, perform at the intimate theater of The Carriage House at Montalvo. Greg mastered one of Richard''s tunes on the guitar and performed it at the Scottish Dance Weekend at Asilomar, another of our shared favorite places. Greg is painfully missed.', 44, '80/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19559, '2019-08-26 14:13:23.670399+00', '2019-09-16 22:35:49.449372+00', 'From the Don to the Dee', 'FROM THE DON TO THE DEE', 3, 32, 9999, 1, 3, 42, 10786, '2013-01-01', 'Devised by Greg Reznick after driving from Strathdon to Deeside on the A93.', 62, '844/844/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19651, '2019-09-16 01:13:17.908074+00', '2019-09-16 22:48:44.103009+00', 'Barattewurst, La', 'BARATTEWURST', 2, 32, NULL, 1, 3, 42, 11876, NULL, '', 62, ' 800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19653, '2019-09-16 06:49:00.639329+00', '2019-09-16 23:26:55.236164+00', 'Polly''s Fancy', 'POLLYS FANCY', 3, 32, NULL, 1, 4, 2, 11876, '2012-01-31', 'Devised by Sandee Schultz and dedicated to Polly Paterson, January 31, 2012.', 75, '8008/8888/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19657, '2019-09-16 07:01:59.380532+00', '2019-09-16 23:49:46.929721+00', 'Willows'' Laughter, The', 'WILLOWS LAUGHTER', 3, 32, NULL, 4, 4, 1, 11878, '2015-01-01', 'At the end of the third time through, during the last four bars of music, drop your partner''s hand,

end with a bow/curtsey to your partner for two bars and then a bow/curtsey to your set for two

bars.



Recommended music: "King of the Fairies" performed by The St. Louis Ocamia Trio', 94, '8888/6666/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19659, '2019-09-17 11:57:07.600955+00', '2019-09-17 12:01:06.351433+00', 'Rosaland', 'ROSALAND', 3, 32, NULL, 1, 4, 2, 11778, '2019-01-01', '', 63, '8888/8000/8008/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19660, '2019-09-20 08:15:10.509097+00', '2019-09-20 08:24:00.145543+00', 'Just Do it', 'JUST DO IT', 4, 96, 3, 2, 3, 17, 11778, '2019-09-01', 'Suggested Music: A Gin and Tonic  



This dance consists of 32 bars of strathspey, danced three times through, and 32 bars of reel, danced three times through.', 75, '800/888/808/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19664, '2019-09-23 15:29:27.540235+00', '2019-09-23 22:07:11.38319+00', 'Hint of Spain, A', 'HINT OF SPAIN', 3, 32, NULL, 2, 3, 17, 3342, '2018-04-01', '', 67, '800/844/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5528, '2002-04-08 22:00:00+00', '2019-09-11 20:23:22.967019+00', 'Reel of the Edinburgh Military Tattoo, The', 'REEL OF THE EDINBURGH MILITARY TATTOO', 1, 56, 9999, 1, 4, NULL, 326, '1959-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19642, '2019-09-13 16:49:03.457241+00', '2019-09-14 23:34:17.359178+00', 'O''er the Mountains', 'OER THE MOUNTAINS', 3, 32, NULL, 1, 3, 42, 11875, '2017-01-01', 'Source Bluebonnet ball 2018 & Danciemation.', 44, '866/800/833/833', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17417, '2016-10-19 21:11:35.683599+00', '2019-09-12 00:38:48.911657+00', 'Pop! Goes The Weasel', 'POP GOES THE WEASEL', 2, 32, 9999, 1, 3, 42, 10912, NULL, 'An arrangement of the nursery rhyme tune would be eminently suitable as the name-tune for this dance. (For details see: <<http://www.scottish-country-dancing-dictionary.com/dance-crib/pop-goes-the-weasel.html|Scottish Country Dancing Dictionary>>)', 50, '800/844/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19643, '2019-09-13 19:03:02.756102+00', '2019-09-13 19:03:02.756102+00', 'Waverley Station Jig', 'WAVERLEY STATION JIG', 2, 32, NULL, 2, 3, 17, 3453, '2017-01-01', 'Written for the 2018 Bluebonnet Ball musicians, Waverley Station.  

David Knight and Liz Donaldson. 

Original tune by David Knight.



', 67, '888/820/880/824', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (883, '1997-08-31 22:00:00+00', '2019-09-12 18:35:33.071804+00', 'Busy Seamstress, The', 'BUSY SEAMSTRESS', 3, 32, 9999, 1, 3, 42, 35, NULL, 'A more recent, local sighting tells the story of a ghost that allegedly haunts the ancestral home of my husband''s people in the Jacob Shoemaker Home in the Village of Bridgeport (now part of Kitchener). She likes to sew and was reflected in an adjoining room through a corner dressing table mirror, busily

snip-snipping with her scissors, then disappearing into the kitchen. The tenant was frozen to the spot as she watched fascinated for some time. Her daughter saw the same apparition sitting quietly in a corner of the attic, and on another occasion two gentlemen were startled to see her in the same spot. I took a picture in the attic, hoping to catch an image on film, as has sometimes happened, but was disappointed.', 53, '400/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19756, '2019-10-29 10:55:52.699746+00', '2019-10-29 15:48:24.984737+00', 'Wheels for April Fools', 'WHEELS FOR APRIL FOOLS', 2, 48, NULL, 1, 4, 2, 11898, '2018-04-01', 'Recording downloadable from https://www.ballaratscd.com/audio.html', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19686, '2019-09-30 00:30:00.900452+00', '2022-08-15 13:29:37.03012+00', 'Falls of Lora', 'FALLS OF LORA', 1, 48, NULL, 1, 4, 2, 11266, NULL, '', 79, '8448/8448/4884/4884/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19652, '2019-09-16 06:46:11.424386+00', '2023-01-12 23:25:25.706721+00', 'Luna''s Twiddle', 'LUNAS TWIDDLE', 1, 40, NULL, 2, 3, 17, 11877, '2018-01-01', 'Devised by Victoria Lewis, 2013; revised 2018.  



Luna''s Twiddle is dedicated to my cat, Luna. "Twiddle" refers to Linda Henderson, whose instructions to "twirl" sounded like "twiddle".', 80, '840/848/888/448/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3327, '1997-10-29 23:00:00+00', '2019-09-13 22:58:02.689585+00', 'Noel Park', 'NOEL PARK', 1, 24, 9999, 1, 2, NULL, 9998, '1830-01-01', 'A twenty four bar Reel for two couples in a longwise set, from Voight''s "A Selection" Book 3. (1809).



Note in Whetherly Book 24: the same figures were published under the title ''John of Paris'' in J. P.

Boulogne''s "The Ballroom or Juvenile Pupil''s Assistant" (1830).



That dance is not identical to the "John of Paris'' associated with "Tom Thumb"and published in J. Daniel & Sons" "The Ballroom Companion" (1879).  



', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19611, '2019-09-02 22:54:55.730971+00', '2019-09-14 16:44:38.727947+00', 'Greyfriars'' Treasurer', 'GREYFRIARS TREASURER', 3, 32, NULL, 1, 4, 1, 9998, NULL, 'Sole source:  Minicrib

', 78, '8888/8888/8888/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19641, '2019-09-13 01:52:37.407844+00', '2019-11-20 09:07:00.711547+00', 'She''ll Be Right', 'SHELL BE RIGHT', 1, 32, NULL, 1, 3, 42, 11029, '2019-02-01', 'This dance was devised for Jeanette Stephan who carried on teaching and dancing with a painful broken left wrist.', 44, '800/844/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (956, '1997-11-24 23:00:00+00', '2020-03-09 10:52:16.268201+00', 'Calum Cam-Chosach', 'CALUM CAMCHOSACH', 4, 32, 8, 2, 2, 76, 270, NULL, '', 65, '88/88/88/77', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19648, '2019-09-16 00:21:54.110855+00', '2021-06-14 08:20:30.770222+00', 'Coffee Bean, The', 'COFFEE BEAN', 1, 40, NULL, 1, 2, 76, 10429, '2018-01-01', 'Devised by The New World Scottish Dancers - Lori Howard, Michael Howard, David Rouggly, Kathy Rouggly, Sandee Schultz, and Sharon Stewart



Greg and Olga Reznick traveled through California and Oregon, camping in their teardrop trailer named "The Coffee Bean".', 62, '48/88/88/88/84', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19677, '2019-09-26 11:27:00.196606+00', '2021-09-27 15:20:11.781545+00', 'Touch Me Not', 'TOUCH ME NOT', 2, 32, NULL, 1, 3, 42, 1075, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2322, '1997-09-02 22:00:00+00', '2019-09-13 20:16:58.299187+00', 'Queen''s Jig, The', 'QUEENS JIG', 2, 32, 9999, 1, 2, NULL, 397, NULL, 'Note in Whetherly book 24: The original instructions specified particular setting steps which are no longer in the Scottish repertoire. Possibly the nearest step to be used for the first sixteen bars would be the highland ''shake and travel step''.



John Walsh republished this dance with the same music under the title ''Princess of Hesse''s Jig''; he also republished the same figures with different music under the titles ''London Bridge'' and ''The Foxhunter''s Jig''.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5375, '1997-09-11 22:00:00+00', '2019-09-13 20:21:50.588325+00', 'Princess Of Hesse''s Jig TRANSFER LINKS TO DANCE 2322', 'PRINCESS OF HESSES JIG TRANSFER LINKS TO DANCE 2322', 2, 32, 9999, 1, 2, NULL, 397, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4712, '1997-09-09 22:00:00+00', '2019-09-13 20:29:29.873317+00', 'Richmond Ball', 'RICHMOND BALL', 1, 32, 9999, 1, 3, 42, 446, '1698-01-01', 'Note iin Whetherly book 24: this dance originally titled ''Mr Lane''s Maggot'' was another late addition by Henry Playford to the ninth edition of "The Dancing Master". From the 1718 issues on the dance was retitled ''Richmond Ball or Mr Lane''s Magot''.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1484, '1997-10-08 22:00:00+00', '2019-09-13 22:19:07.838762+00', 'Mrs Booth''s Minuet', 'MRS BOOTHS MINUET', 50, 32, 9999, 1, 3, 42, 9998, NULL, 'This dance appears twice in this publication, once as ''Drapers Maggot'' (page 6) and once as ''Mrs Booth''s Minuet'' (page 54).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1655, '1997-09-01 22:00:00+00', '2019-09-13 22:32:15.265318+00', 'Hiland Lass', 'HILAND LASS', 1, 16, 9999, 1, 2, NULL, 397, '1711-01-01', 'Official Alias: Hiland Lass', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3328, '1997-10-15 22:00:00+00', '2019-09-13 22:51:34.32621+00', 'Tom Thumb', 'TOM THUMB', 1, 24, 9999, 1, 2, NULL, 270, '1879-01-01', 'A twenty four bar Reel for two couples in a longwise set, from J. P. Boulogne''s TIThe Ballroom or Juvenile Pupil''s Assistant" (1830).



Note in Whetherly Book 24: these figures also appeared under the title "John of Paris'' in J. Daniel & Sons" "The Ballroom Companion" (1879).  That dance is not identical to the "John of Paris" associated with "Noel Park", and published under the title ''John of Paris'' in J. P. Boulogne''s "The Ballroom or Juvenile Pupil''s Assistant" (1830).

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19603, '2019-09-02 17:56:56.312827+00', '2019-09-14 17:40:30.48121+00', 'Tribute to Joyce, A', 'TRIBUTE TO JOYCE', 7, 96, NULL, NULL, 1, NULL, 238, NULL, 'A Highland Step Dance for Two Women. The dance is 96 bars with a 4 bar introduction.



The music is from the Celtic Experience CD (not yet in SCDDB), the tune is My Home Town, the musician is William Jackson.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19474, '2019-07-14 15:25:53.340025+00', '2019-09-14 09:31:22.961433+00', 'David Ross', 'DAVID ROSS', 1, 32, NULL, 2, 3, 17, 270, NULL, 'John Mitchell has also devised a 32 bar Jig with the same name which he published in Whetherly Book 9



Recommended tune: David Ross (composer not specified)', 67, '800/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19023, '2018-10-19 20:29:08.513026+00', '2019-09-14 17:52:57.25562+00', 'Ledbury Lassies, The', 'LEDBURY LASSIES', 2, 48, NULL, 2, 3, 17, 1069, '1988-01-01', 'Before appearing in the Hereford 40th anniversary book (as The Ledbury Lassies) this dance was originally entered in SCDDB as The Ledbury Ladies which is kept as a spelling alias.', 54, '888/888/844/844/800/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (139, '1998-01-04 23:00:00+00', '2019-09-14 18:33:22.084334+00', 'Anderson Rant, The', 'ANDERSON RANT', 1, 32, 9999, 1, 3, 42, 28, NULL, '', 50, '888/808/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8329, '2001-05-21 22:00:00+00', '2019-09-14 22:54:28.783156+00', 'Blue Route, The', 'BLUE ROUTE', 1, 32, 9999, 1, 3, 42, 2874, NULL, 'Avril devised this dance from a set of exercises she developed for a Delaware Valley Branch

workshop. The Blue Route is the local name for Interstate 476, which connects many of the

towns in which Branch events take place.', 62, '888/800/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8532, '1998-02-08 23:00:00+00', '2019-09-15 22:22:19.607405+00', 'Dean''s Delight, The', 'DEANS DELIGHT', 1, 32, 9999, 1, 3, 42, 146, NULL, 'For Benita and Brian Jewell to celebrate Brian''s appointment as Dean of the School of Medicine, Leeds.', 53, '888/808/844/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12202, '2005-04-16 22:00:00+00', '2019-09-15 21:43:44.234833+00', 'Early Gray TRANSFER LINKS TO DANCE 1875', 'EARLY GRAY TRANSFER LINKS TO DANCE 1875', 1, 32, 9999, 1, 3, 42, 270, NULL, 'This entry is very likely a mistaken duplicate of <<ddd:Earl Gray#1875>> - to be confirmed.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19661, '2019-09-21 10:25:20.76795+00', '2019-09-21 11:22:43.042372+00', 'Stock Exchange Country Dance, The', 'STOCK EXCHANGE COUNTRY DANCE', 2, 160, NULL, 1, 4, NULL, 11880, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19667, '2019-09-25 23:18:39.143494+00', '2019-09-25 23:18:39.143494+00', 'Pieces of Eight', 'PIECES OF EIGHT', 1, 32, NULL, 1, 4, 1, 678, NULL, '', 69, '8008/8888/8888/8000', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19670, '2019-09-26 10:22:43.975198+00', '2019-09-26 10:22:43.975198+00', 'With a Spring in your Step', 'WITH A SPRING IN YOUR STEP', 1, 32, NULL, 1, 3, NULL, 11882, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7283, '2001-11-21 23:00:00+00', '2019-09-26 10:43:47.461179+00', 'Joie de Vivre', 'JOIE DE VIVRE', 2, 32, 9999, 1, 3, 42, 64, NULL, '##>>

This is defined in the Concise Oxford Dictionary as *an exuberant enjoyment of life*.  

Origin: French, literally ''joy of living''.

##<<



The following corrections were included on a loose sheet "Notes on Dances by Bob Grant June 1996", when Book 39 was first sold in the Summer School bookshop:



9-12  ... and return to places with men facing up and women facing down', 62, '800  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (19749, '2019-10-28 22:51:52.080094+00', '2019-10-29 15:49:43.066946+00', 'Reavey Roundabout, The', 'REAVEY ROUNDABOUT', 3, 32, NULL, 2, 3, 18, 11904, NULL, 'Recording downloadable from https://www.ballaratscd.com/audio.html', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19668, '2019-09-26 10:12:07.101434+00', '2022-09-13 10:42:16.867726+00', 'Morgan Lundi', 'MORGAN LUNDI', 3, 32, NULL, 2, 3, 17, 11881, NULL, 'Pamela''s class met in the Morgan Institute on Mondays.', 92, '888/888/888/486', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19671, '2019-09-26 10:41:21.048954+00', '2022-09-13 10:56:22.268643+00', 'Strathspey for Mervyn, A', 'STRATHSPEY FOR MERVYN', 3, 32, NULL, 2, 3, 17, 11883, NULL, '', 81, '886/844/808/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19666, '2019-09-25 23:07:34.947508+00', '2022-11-30 19:37:41.719109+00', 'Queen of the Dance, The', 'QUEEN OF THE DANCE', 4, 64, 5, 1, 100, 2, 347, NULL, '', 100, '8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2012, '1997-09-02 22:00:00+00', '2021-10-09 22:30:03.094879+00', 'Mr Beveridge''s Maggot', 'MR BEVERIDGES MAGGOT', 1, 16, 9999, 1, 2, NULL, 446, '1696-01-01', '3/2 time



Note in Whetherly Book 24:  the original instructions for the last four bars are lead up hands abreast, half figure of eight through the second couple and cast off.

This dance also appeared in a later volume of "The Dancing Master" with different music, under the title ''Ever Happy".



Not really SCD, but some videos are at <<https://youtu.be/OxI616iJTqs>>, <<https://youtu.be/G9VvHYS95YM>>. The latter is described, in extensive youtube comments, as a simplified version.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19674, '2019-09-26 11:01:42.753221+00', '2019-09-26 11:01:42.753221+00', 'Altargative, The', 'ALTARGATIVE', 1, 40, NULL, 1, 3, 42, 11881, NULL, '', 60, '888/880/880/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19676, '2019-09-26 11:19:11.604398+00', '2019-09-26 11:19:11.604398+00', 'Knock, The', 'KNOCK', 3, 32, NULL, 1, 4, 1, 11883, NULL, '', 72, '4004/8444/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19678, '2019-09-26 14:26:30.699496+00', '2019-09-26 14:34:34.252951+00', 'Bill''s Clothes Pegs', 'BILLS CLOTHES PEGS', 2, 32, NULL, 1, 3, 42, 11885, '2019-01-01', 'Bill Ewen remembers how, as a child, he practised the piano on his Grandmother''s window sill, using clothes pegs as "pretend" keys.', 53, '800/888/866/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19679, '2019-09-26 14:40:41.335964+00', '2019-09-26 14:40:41.335964+00', 'Judy''s Jig', 'JUDYS JIG', 2, 32, NULL, 1, 3, 42, 463, '1995-01-01', '', 63, '880/844/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19680, '2019-09-26 14:46:59.483998+00', '2019-09-26 14:46:59.483998+00', 'Biscuit''s Visit', 'BISCUITS VISIT', 2, 32, NULL, 1, 3, 42, 463, '2018-01-01', 'For Biscuit, the ginger cat that visits 12 Coates Crescent when the weather is bad.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12996, '2006-10-30 23:00:00+00', '2019-09-26 17:23:34.277649+00', 'Langdon Knot, The', 'LANGDON KNOT', 3, 32, 9999, 1, 3, 42, 2701, '2006-01-01', 'For Susie Langdon Kass on the occasion of her significant birthday. Susie''s husband Sid commissioned the tune by Muriel Johnstone. Susie was my fIrst teacher (as she was for many dancers in the Bay Area) and is a tireless and enthusiastic promoter of Scottish Country Dancing. She is well known for teaching "The Langdon Knot" to any (and all) who have yet to learn this very secure way of tying shoelaces. The fIgure in bars 9-16 reminds me of tying a knot and is evocative of the central fIgure in John McAlpin, one of Susie''s favorite dances. A Ramsay herself, another of Susie''s favorites is Lady Lucy Ramsay, which is the source for the last 8 bars. (Tim Wilson)', 56, '800/888/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19228, '2019-03-08 18:09:46.819724+00', '2019-09-27 12:33:07.709821+00', 'Happy to See You', 'HAPPY TO SEE YOU', 2, 32, NULL, 5, 2, 76, 2688, '2017-01-01', 'Warm up dance written for the 10th anniversary international weekend course of the Budapest Scottish Dance Club.   

Couple face couple round the room.     





', 100, '88/88/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19681, '2019-09-27 21:36:30.510111+00', '2019-09-27 21:36:30.510111+00', 'Sara and Chuck', 'SARA AND CHUCK', 3, 32, NULL, 1, 3, 42, 390, NULL, 'Source: youtube video.', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19682, '2019-09-28 20:50:44.36563+00', '2019-09-28 22:34:46.168955+00', 'Islesman, The', 'ISLESMAN', 1, 32, NULL, 1, 3, 42, 2766, NULL, 'Written after reading Nigel Tranter’s book The Islesman about Angus Og MacDonald, who may be a very distant ancestor.', 53, '888/660/844/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19684, '2019-09-28 21:48:21.722032+00', '2019-09-28 22:38:34.199499+00', 'McCaig''s Tower', 'MACCAIGS TOWER', 1, 32, NULL, 1, 3, 42, 2766, NULL, 'When we were in Scotland we explored McCaig''s Tower in Oban. It has an interesting history and is a round building with no top. I liked the crossover hands across in the Jute Spinner''s Reel and wanted to try it up and down the set.', 62, '844/888/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19688, '2019-10-01 13:19:45.561967+00', '2019-10-14 14:26:05.854663+00', 'Hurray for Sarah May', 'HURRAY FOR SARAH MAY', 2, 32, NULL, 1, 3, 42, 1445, NULL, 'This dance was devised for Sarah May van Leersum, daughter of our friends Sjoerd and Sophie van Leersum.



There is now a <<ddt:Sarah May''s Jig|tune>> for this dance (previously "any good jig" was recommended).', 52, '802/808/880/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (658, '2002-02-27 23:00:00+00', '2019-10-16 21:26:44.592318+00', 'Bonnie Lass o'' Bon Accord, The', 'BONNIE LASS O BON ACCORD', 3, 64, 9999, 4, 4, 3, 108, '1964-01-01', '', 71, '0000/8080/0808/8888/8888/8888/8888/8888', 0, 1, 1, 0, 81);
INSERT INTO 'dance' VALUES (16787, '2015-10-14 15:31:25.597536+00', '2019-10-20 00:13:03.401065+00', 'Neighbours Day', 'NEIGHBOURS DAY', 1, 32, 9999, 1, 3, 42, 2682, '2015-03-29', 'Notes from The Johnsonville Collection:



Devised 29th March 2015 as a teaching dance for pas de Basque and corners.



The dance follows a very nice “neighbours’ day” where the Johnsonville Club danced at the Newlands Marae on Saturday 28th March, with a number of our new beginners involved. 



Recommened tune is “Kirk’s Hornpipe” and an excellent recording is by David South and his band in “Kardinia Capers” as “Set of Hornpipes” (track 1)', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19685, '2019-09-28 23:29:26.142166+00', '2019-10-20 22:25:28.536931+00', 'Catfulness', 'CATFULNESS', 2, 32, NULL, 1, 4, 1, 3135, '2019-01-01', 'Devised for the 75th birthday of Jannie Kramer of Geldermalsen.  Jannie has a passion for cats.', 59, '6060/0606/8888/8444', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19689, '2019-10-04 07:56:59.319936+00', '2019-10-04 21:07:36.617954+00', 'John McCormick', 'JOHN MACCORMICK', 3, 32, NULL, 1, 4, 2, 2682, '2019-09-20', 'Devised 20 September, 2019, but modified when danced with Johnsonville on 30th September. John is a friend who leads the Milwaukee group, and has done so for many years. This is a little note of thanks for his kindness in driving me from Milwaukee to O''Hare after I taught a class late on the night of 16th September. His favourite tune is tourbillon, and step is Strathspey. 



Recommended tune is "Red Plaid" (traditional) and I particularly like the set "Red Plaid/The Iron Man/The Banks of Spey" from Peter Elmes recording of "Glenys Pearce''s Strathspey" from the Lochiel Collection. Should this not be available, I would recommended tune "Miss Janet Laing''s Strathspey" by Nan Main, and either of the society''s recordings for book 22 would be good. Failing that use any reasonable recording of "The Balmoral Strathspey".

2', 77, '8888/8338/8668/8008', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15481, '2014-06-27 20:53:46.465157+00', '2019-10-17 00:37:18.211835+00', 'Caledonian Step, The', 'CALEDONIAN STEP', 2, 32, NULL, 1, 2, 76, 10971, NULL, 'Remembering good times with the "Caledonian Dancers" of Stratford, Ontario.  



This dance is very similar to <<ddd:Waterloo Welcome>>

', 69, '88/88/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19697, '2019-10-14 09:23:03.808012+00', '2019-10-17 22:13:22.847663+00', 'Reel for Margaret, A', 'REEL FOR MARGARET', 1, 48, NULL, 1, 3, 42, 851, NULL, 'Devised as a posthumus tribute to Margaret Scrymgeour, for all the work she did for Fowlis Village.



The local group taught by Muriel Boal has confirmed that the Crown Triangles figure of bars 9-14 only has two clockwise movements; 1c tuns third corner on bars 15-16. This solves the ambiguity of the original instructions,', 71, '888/888/866/866/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19725, '2019-10-28 11:23:12.577409+00', '2019-10-28 14:27:58.378268+00', 'Paco''s Wiggle Waggle Walk', 'PACOS WIGGLE WAGGLE WALK', 1, 32, NULL, 1, 3, 42, 11570, '2019-08-14', 'The dance is about walking my dog Paco, a Labrackel or Teckrador or whatever. Even though we take the same route, we never seem to be at the same place at the same time (bars 1-16, a mirror fugue), only when I have him on the leash (bars 17-20). And he is totally thrilled whenever we meet all the other dogs at the local dogs‘ playground (bars 21ff ).



Dedicated to Ilona Brown who inspired me to devise this dance.



Music Suggestion: Cramond Bridge (Robert Whithead and the Danelaw Band)  

Alternatives: Duncan MacCalman (Peter White and his Band) , Dumbarton Drums (Kenny Thomson And The Wardlaw Scottish Dance Band)', 48, '602/842/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10703, '2002-07-21 22:00:00+00', '2019-10-23 18:09:49.975127+00', 'Pint o'' Ale is Fain', 'PINT O ALE IS FAIN', 2, 32, 9999, 1, 3, 42, 2961, NULL, 'There are two versions of this dance.  The original instructions for bars 17-24 say:



1st couple dances a figure of eight on their own sides with 2nd and 3rd couples, giving left shoulders to 2nd couple to begin. For more advanced dancers, a reel of three on the sides may be substituted.



The diagrams and cribs of this entry show the "advanced" version.', 62, '888  888  888  800', 0, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (9499, '2001-07-30 22:00:00+00', '2019-09-29 10:36:51.421396+00', 'Gnomes'' Stone, The', 'GNOMES STONE', 2, 32, 9999, 1, 3, 42, 228, '1999-01-01', 'For the dancers at the Proitzer Müehle, Whitsun 1999.  



The “Gnomes’ Stone” (der Zwergenstein) near the Proitzer Müehle marks the entrance to the subterranean abode of a tribe of gnomes in a local folk tale.



At the Whitsun workshop, 1999, the Proitze dancers presented me with a beautifully illustrated children’s book by Susanne Laschütza, telling the story of the Gnomes’ Stone. This inspired the movements of the dance, starting with the gnomes surreptitiously grinding their corn at the Mill (bars 1–8) before being surprised by a group of farmers (beginning of bar 9) and having to retreat to their lair under the stone, pursued by the farmers (bars 9–16). In the tale, a farmer and his farm hand proceed to kidnap one of the gnomes as a children’s playmate; this gnome subsequently escapes overnight, and on the second attempt the farm hand vanishes in the gnomes’ cave, never to be seen again (most of this could be read into bars 17–28). Since that time, the entrance to the gnomes’ abode remains sealed, but the stone can be visited during an easy walk from the Mühle.



Note: The turn in bars 13–16 may be danced three quarters round instead of one and three quarters round if dancers do not feel the need to escape from a group of angry farmers.

8', 50, '880/844/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19144, '2019-01-13 11:51:42.102002+00', '2019-09-30 00:09:45.94663+00', '27th of October, The', '27TH OF OCTOBER', 2, 32, NULL, 1, 3, 42, 2766, '2013-07-01', 'Written in honor of Doug Schneider’s 70th Birthday on the 27th of October 2013.', 44, '660/660/888/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14401, '2012-01-21 08:07:05.051717+00', '2019-10-11 01:25:19.130172+00', 'Aviator, The', 'AVIATOR', 2, 32, NULL, 1, 3, 42, 10451, '2011-01-01', 'Note in Carola Fischer''s original instructions:  NB.  It is up to the dancing couple how far down they dance down and in which place they dance out between the standing men.  Where there is more than one set, the dancing couple may dance out through the gap in the men’s side in the set below.



Devised by Carola Fischer for Hans Prade on the occasion of his 80th birthday. Hans used to be a keen glider and my father nick-named him „The Aviator“. Hans once had the wonderful experience of being joined by a buzzard which took advantage of the thermal, flying at his wingtip and mirroring his movements. This dance depicts Hans taking off, banking round, enjoying his flight with the buzzard and then landing again safely. May the movements of this dance bring back those happy memories!



', 44, '800/846/846/822', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13127, '2006-12-05 23:00:00+00', '2019-10-11 21:42:41.783861+00', 'Autumn Rose', 'AUTUMN ROSE', 3, 32, 9999, 1, 3, 42, 1445, '2006-10-17', 'For my wife Claire on her birthday.  17 October 2006



The deviser acknowledges that the published instructions contain an error in bars 25-28.  1st couple should dance out between the women, not the men, ie:



25-28  1st couple lead out between 2nd and 3rd women, they divide and cast to finish 1st lady between 2nd couple at the top all face down and 1st man between 3rd couple at the bottom all face up', 53, '880/848/844/844', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (19384, '2019-06-02 12:40:30.380981+00', '2019-10-08 22:01:27.270806+00', 'New Shepherd''s Crook, The', 'NEW SHEPHERDS CROOK', 3, 40, NULL, 2, 3, 17, 10632, '2017-01-01', 'Devised by Zsolt Molnár for David Hall on the occasion of a "rather special birthday” May 2018. Dave was the mentor and "shepherd” during Zsolt’s SCD teaching certificate.', 77, '800/888/848/448/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19446, '2019-06-29 13:41:59.229606+00', '2019-10-02 00:15:06.88531+00', 'Basketweave Braid', 'BASKETWEAVE BRAID', 2, 32, NULL, 1, 3, 42, 2766, '2017-07-01', 'In Milanese lace (one type of bobbin lace I like to do), stitches are braids and basketweave is one of these braids that has many crossings.', 44, '800/866/866/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19693, '2019-10-11 20:50:19.847766+00', '2019-10-11 20:50:19.847766+00', 'Iron Horse Reel', 'IRON HORSE REEL', 1, 32, NULL, 1, 102, 11, 10640, NULL, '', 100, '8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19694, '2019-10-12 13:33:06.829166+00', '2019-10-12 13:33:06.829166+00', 'Sparkling Eyes', 'SPARKLING EYES', 2, 32, NULL, 1, 3, 42, 3453, NULL, 'This dance is a slightly modified version of <<ddd:Twa Sparkling Een>> by <<ddp:Boyd, Iain>> just changing the order of the hands across in bars 17-24 from right then left (in the original) to left then right here.', 63, '888/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19692, '2019-10-10 22:24:16.654175+00', '2019-10-10 23:04:44.962631+00', 'Leith Meets Edinburgh', 'LEITH MEETS EDINBURGH', 1, 32, NULL, 1, 3, 42, 10374, '2015-01-01', 'In honor of Catherine & John  Prentice, who started the annual Burns Supper of the Kitchener-Waterloo Branch 35 years ago.



E-crib derived from video and local crib', 56, '880/880/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19739, '2019-10-28 21:03:36.865301+00', '2019-10-28 21:03:36.865301+00', 'Golden Daze', 'GOLDEN DAZE', 3, 32, NULL, 1, 3, 42, 670, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19691, '2019-10-10 22:13:27.163219+00', '2020-02-25 22:19:35.642647+00', 'Dufftown Twirl, The', 'DUFFTOWN TWIRL', 1, 96, NULL, 4, 4, 3, 374, NULL, 'Music by Hebbie Gray.', 67, '8080/0808/8080/8888/0808/8080/0808/8888/4444/4444/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19701, '2019-10-20 20:59:09.403762+00', '2021-09-18 08:19:11.491057+00', 'Party at the French House, A', 'PARTY AT THE FRENCH HOUSE', 1, 40, NULL, 1, 3, 42, 11237, '2018-08-01', 'For Liz and Gordon Matthew who live in Geneva but also have a lovely house in France to which the Geneva Scottish Country Dancing Club get invited for summer parties. 



1st couple are the hosts, 2nd and 3rd couples are the guests. 2nd couple arrive a bit too early and get parked in top place as 1st couple survey their preparations. The hosts then encourage their guests to mingle on the sides as they dart across and back. 1st couple can then spend some quality time with each guest, working round from 4th to 1st corners. By this time the party has a developed a rowdier life of its own and the dance ends with a circle. ', 58, '840/888/844/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14426, '2012-05-05 08:39:45.640494+00', '2019-10-13 07:13:54.989277+00', 'Mrs Jappy''s Measure', 'MRS JAPPYS MEASURE', 3, 32, 9999, 1, 3, 42, 15, NULL, 'Dance devised by Bill Zobel as a tribute to Ruth Jappy of Delta, British Columbia, who has for decades been one of the world''s leading ambassadors for Scottish Country Dancing and its music.



NOTE: Since the original publication of "Dancing on Air" in 2011, bars [13-16] and [21-24] of this dance have been modified.  The formation is now "set to corner; turn corner BH".  The diagrams are correct.  ', 50, '880/833/833/866', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19695, '2019-10-13 12:17:12.996292+00', '2019-10-13 19:36:39.441856+00', 'Sunrise on Dean''s Bay', 'SUNRISE ON DEANS BAY', 3, 32, NULL, 1, 3, 42, 2998, '2019-07-01', '', 53, '800/844/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19698, '2019-10-14 11:02:45.752192+00', '2019-10-14 11:02:45.752192+00', 'Jim''s Circle of Friends', 'JIMS CIRCLE OF FRIENDS', 1, 96, NULL, 4, 4, 3, 851, NULL, 'This dance was written to celebrate Jim Boal’s 80th Birthday.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19708, '2019-10-24 16:29:36.558394+00', '2019-10-24 19:04:56.487397+00', 'Miss Alice of Oriel', 'MISS ALICE OF ORIEL', 4, 128, 2, 4, 4, 54, 11463, '1999-01-01', 'Devised for Alice Stainer''s birthday in 1999.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15434, '2014-05-09 22:02:57.577845+00', '2022-04-26 09:28:09.597715+00', 'Snow Eater, The', 'SNOW EATER', 2, 32, NULL, 1, 3, 42, 2680, NULL, 'Southern Alberta is known for its very strong winds, which can raise the temperature by 20 to 30 degrees in a very short time. This increase in temperature results in the melting of snow. These winds are known as Chinooks; thought to be taken from the First Nations word meaning Snow Eater.', 53, '880/822/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16873, '2016-02-25 00:20:26.302598+00', '2019-10-23 16:56:21.141992+00', 'Behind the Scenes', 'BEHIND THE SCENES', 2, 32, NULL, 1, 3, 42, 3379, NULL, 'Devised for Kathleen Johnston from Dufftown who has done so much work “behind the scenes” in the running of the Dufftown Scottish Country Dance Club



', 50, '888/840/822/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19703, '2019-10-23 21:26:39.115082+00', '2019-10-23 21:26:39.115082+00', 'Two Tui in a Kowhai Tree', 'TWO TUI IN A KOWHAI TREE', 1, 32, NULL, 1, 3, NULL, 11890, NULL, '', 44, '880/800/800/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19713, '2019-10-24 16:42:46.583526+00', '2019-10-24 19:14:17.722425+00', 'Romance Strathspey, The', 'ROMANCE STRATHSPEY', 3, 32, NULL, 2, 3, 17, 3454, '2000-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19714, '2019-10-24 16:46:28.939683+00', '2019-10-24 19:17:08.485646+00', 'Pelican Jig, The', 'PELICAN JIG', 2, 32, NULL, 1, 3, 42, 10367, '2000-01-01', 'Named for the Pelican in the front of Corpus Christie College, Oxford.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19715, '2019-10-24 16:48:54.39707+00', '2019-10-24 19:21:15.903734+00', 'Miss Millar''s Strathspey', 'MISS MILLARS STRATHSPEY', 3, 32, NULL, 1, 4, NULL, 11895, '1999-05-29', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19716, '2019-10-24 16:51:15.174939+00', '2019-10-24 19:23:44.406957+00', 'Lexicographer''s Delight, The', 'LEXICOGRAPHERS DELIGHT', 1, 32, NULL, 3, 5, 7, 11895, '2000-01-01', 'Dedicated to Samantha Schad', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19719, '2019-10-25 10:00:41.394335+00', '2019-10-25 10:38:07.715876+00', 'Wandering Thistle, The', 'WANDERING THISTLE', 3, 32, NULL, 1, 4, 2, 11896, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19721, '2019-10-25 10:08:16.856374+00', '2019-10-25 10:39:30.209217+00', 'Balboa Park Rant, The', 'BALBOA PARK RANT', 1, 32, NULL, 1, 4, 2, 11801, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19726, '2019-10-28 11:31:19.275217+00', '2019-10-28 16:27:30.847091+00', 'What d''ya want from me?', 'WHAT DYA WANT FROM ME', 1, 32, NULL, 1, 3, 42, 11570, '2019-08-14', 'I wrote this dance as a warm up dance for my class and wanted it to be „not too dull“.



Music Suggestion: Fight about the Fireside (Muriel Johnstone & Keith Smith)  

Alternatives: Peter & Madelaine Quince (The Danelaw Dance Band), Sutters of Selkirk (Colin

Dewar)', 47, '800/822/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19696, '2019-10-13 18:06:18.216403+00', '2019-10-25 20:39:25.074576+00', 'Janice Stevenson''s Strathspey', 'JANICE STEVENSONS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11887, NULL, 'The music, written as a tribute to Janice Stevenson by David Bowen, came first.  The dance was devised later, as posthumus tribute to Janice, in effect the dance was written for the tune rather than the other way round.



Dance Source: by phone from the Inverness branch. 

', 59, '888/880/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19718, '2019-10-25 09:50:25.898184+00', '2019-10-25 20:44:08.825999+00', 'Couple of Gems - Two by Forty, A', 'COUPLE OF GEMS  TWO BY FORTY', 3, 40, NULL, 1, 100, 22, 11863, '2019-09-01', 'Devised to celebrate Margaret and Derek Darnell’s Ruby Wedding Anniversary in September 2019.  The dance name mirrors this in the words "Two by Forty",

', 82, '8008/8888/8888/8888/8228', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19727, '2019-10-28 11:38:25.697384+00', '2019-10-28 14:29:23.311404+00', 'Tick Tock Goes the Clock', 'TICK TOCK GOES THE CLOCK', 2, 32, NULL, 1, 3, 42, 11570, NULL, 'In essence, this dance is a nod to the region where I grew up, the Black Forest. It‘s famous for its „Cuckoo Clocks“, and the „Tick Tock“ figure reflects the movement of the hands of the clock; the clock then has to be wound up to make it go round again...



Music Suggestion:

Oh Whistle and I''ll come tae ye, my lad (Muriel Johnstone''s Scottish Dance Band)  

Alternatives:

Bonnie Dundee (Sandy Legget), Two and two (Ron Kerr)', 66, '844/888/866/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19699, '2019-10-16 03:27:45.267776+00', '2020-11-27 18:41:42.512989+00', 'Miss Mary Elizabeth Wessel Walker', 'MISS MARY ELIZABETH WESSEL WALKER', 1, 32, NULL, 1, 4, 1, 11888, NULL, '', 56, '8860/8040/8080/8068', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19723, '2019-10-25 10:19:05.106838+00', '2020-04-07 23:35:04.130398+00', 'Kelly''s Journey', 'KELLYS JOURNEY', 1, 32, NULL, 1, 3, 42, 11801, '2016-09-01', 'For Kelly Milne, to celebrate the start of her gap-year adventures, driving around the United States in her RV with her husband, David. Bon Voyage', 48, '800/800/877/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19705, '2019-10-24 16:21:03.353189+00', '2020-12-04 17:46:23.616225+00', 'McGuffin, The', 'MACGUFFIN', 2, 32, NULL, 1, 3, 42, 11892, '2000-01-01', 'McGuffin is Alfred Hitchcock''s term for a Red Herring', 50, '808/880/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19712, '2019-10-24 16:38:37.958261+00', '2021-03-13 10:11:43.674413+00', 'City of Wisteria', 'CITY OF WISTERIA', 3, 32, NULL, 2, 3, 18, 2887, '2018-11-01', '*Peter Marshall writes* "The dance commemorates the 15th Anniversary, in autumn 2019, of Kasukabe Sugar Candie Scottish Dancing Group.  Kasukabe City is famous for its Wisteria, one of its trees is over 1200 years old, and there is a wide main street opposite the station named Wisteria Street.  Members of this group have always made me very welcome and so it is a pleasure to devise this dance for them."', 94, '888/888/888/882', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19735, '2019-10-28 18:34:42.848548+00', '2019-10-28 18:34:42.848548+00', '50th Aniversary Strathspey, The', '50TH ANIVERSARY STRATHSPEY', 3, 32, NULL, 2, 3, 17, 10466, '2019-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19740, '2019-10-28 21:06:42.481272+00', '2019-10-28 21:06:42.481272+00', 'Gold Rush Reel, The', 'GOLD RUSH REEL', 1, 32, NULL, 1, 3, 42, 670, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19744, '2019-10-28 21:38:54.582587+00', '2019-10-28 21:38:54.582587+00', 'Melbourne University', 'MELBOURNE UNIVERSITY', 3, 40, NULL, 1, 4, 1, 11900, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19745, '2019-10-28 21:47:16.061569+00', '2019-10-28 21:47:16.061569+00', 'Melbourne''s Golden Gallop', 'MELBOURNES GOLDEN GALLOP', 2, 32, NULL, 1, 3, 42, 11903, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19746, '2019-10-28 21:50:36.566471+00', '2019-10-28 21:52:56.209941+00', 'Memories of Marysville', 'MEMORIES OF MARYSVILLE', 3, 32, NULL, 1, 3, 42, 3520, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19748, '2019-10-28 22:09:48.545725+00', '2019-10-28 22:09:48.545725+00', 'Mount Buller Walk', 'MOUNT BULLER WALK', 3, 32, NULL, 3, 5, 41, 10773, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19750, '2019-10-28 22:55:03.364865+00', '2019-10-28 22:55:03.364865+00', 'Roaming the Campus', 'ROAMING THE CAMPUS', 1, 32, NULL, 1, 4, 1, 11900, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19751, '2019-10-29 10:06:41.938442+00', '2019-10-29 10:06:41.938442+00', 'Scotscraig Reel, The', 'SCOTSCRAIG REEL', 1, 40, NULL, 1, 3, 42, 10773, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19752, '2019-10-29 10:11:04.943328+00', '2019-10-29 10:11:04.943328+00', 'Victorian Gold', 'VICTORIAN GOLD', 3, 32, NULL, 1, 3, 42, 10766, '2018-07-24', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19755, '2019-10-29 10:27:58.355338+00', '2019-10-29 10:27:58.355338+00', 'Werribee River Reel, The', 'WERRIBEE RIVER REEL', 1, 32, NULL, 1, 3, 42, 11901, '2019-01-01', 'The Werribee River is one of three major rivers flowing into Port Philip Bay, Victoria', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19758, '2019-10-29 11:06:13.799895+00', '2019-10-29 11:06:13.799895+00', 'Yarra Strathspey, The', 'YARRA STRATHSPEY', 3, 32, NULL, 1, 4, 1, 3520, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19742, '2019-10-28 21:21:26.989463+00', '2019-10-29 15:46:34.270048+00', 'Jane''s Canadian Strathspey', 'JANES CANADIAN STRATHSPEY', 3, 32, NULL, 1, 4, 2, 11898, NULL, 'Recording downloadable from https://www.ballaratscd.com/audio.html', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19754, '2019-10-29 10:18:55.344013+00', '2019-10-29 15:47:50.708173+00', 'Wendouree Waters', 'WENDOUREE WATERS', 3, 32, NULL, 1, 3, 42, 11898, NULL, 'Recording downloadable from https://www.ballaratscd.com/audio.html

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19064, '2018-12-03 16:04:45.306494+00', '2021-03-13 20:19:10.368299+00', 'Jig for John Philip, A', 'JIG FOR JOHN PHILIP', 2, 40, NULL, 3, 5, 7, 3589, NULL, '', 77, '68686/48884/08080/84884/88888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11386, '2003-07-06 22:00:00+00', '2019-10-30 03:14:42.793263+00', 'Fifty Years On', 'FIFTY YEARS ON', 1, 32, 9999, 1, 3, 42, 48, NULL, 'For Anthony Payne on his 50th birthday.



Editor''s note [Eric Ferguson].  For 1st couple, the transition on bar 24 is awkward.  The dance would flow better if on [21-24] the second diagonal half reel of 4 had started with 1st couple facing 4th corner.  I wonder if this is a mistake in the instructions, which clearly say 2nd corner.   ', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19736, '2019-10-28 18:40:21.209303+00', '2019-10-31 17:34:28.758863+00', 'Friendship N E W S', 'FRIENDSHIP N E W S', 2, 32, NULL, 4, 4, 30, 11900, NULL, 'Meeting Friends from all points of the compass, and bringing them into your circle.', 84, '6666/8888/5555/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2077, '1998-07-08 22:00:00+00', '2021-06-09 08:37:35.6425+00', 'Faraway Isle, The', 'FARAWAY ISLE', 2, 48, 9999, 1, 100, 2, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was *a dance for the visit to Majorca*.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19741, '2019-10-28 21:16:25.001342+00', '2019-11-01 17:38:26.09261+00', 'I''ll Give It Five - O!', 'ILL GIVE IT FIVE  O', 1, 40, NULL, 4, 55, 95, 10433, NULL, '', 64, '80808/08088/44448/42442/88888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19728, '2019-10-28 18:00:24.543227+00', '2019-11-01 17:47:42.959796+00', 'All Roads Lead to the ''G', 'ALL ROADS LEAD TO THE G', 1, 64, NULL, 1, 4, 1, 10433, NULL, 'The ''G is Melbourne Cricket Ground

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19731, '2019-10-28 18:19:55.334216+00', '2020-01-10 09:30:38.888999+00', 'Bronzewing, The', 'BRONZEWING', 3, 32, NULL, 2, 3, 18, 11899, NULL, 'The Bronzewing is a native Australian pigeon.  In spring, the male does a courtship dance to attract the female, and this dance mimics many of those movements.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19732, '2019-10-28 18:24:32.056262+00', '2019-11-01 18:00:50.002679+00', 'Celebration Reel, The', 'CELEBRATION REEL', 1, 40, NULL, 3, 5, 16, 10773, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19734, '2019-10-28 18:32:07.591507+00', '2019-11-01 18:06:46.524494+00', 'Daylesford Reel, The', 'DAYLESFORD REEL', 1, 32, 9999, 1, 3, 42, 11898, NULL, 'Recording downloadable from https://www.ballaratscd.com/audio.html', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13077, '2006-11-10 23:00:00+00', '2019-11-04 12:51:55.135528+00', 'Torridon Lassies', 'TORRIDON LASSIES', 2, 40, 9999, 1, 3, 42, 884, '2006-01-01', 'Torridon is a small village in the Northwest Highlands of Scotland. However the name is also applied to the area surrounding the village, particularly the Torridon Hills, mountains to the north of Glen Torridon. It lies on the shore of Loch Torridon.



John Brenchley named this dance after Torridon Street in Perth, Western Australia, in an area where names of Scottish origin abound.



The original dedication in <<ddpub:The Kangaroo Paw#1009>> publication reads: *A dance for the lassies in our house which is situated in a street named Torridon Loop.*', 55, '844  844  844  844  888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (17816, '2017-06-22 11:07:26.162244+00', '2019-11-05 00:17:44.925437+00', 'Rope Spinner''s Reel, The', 'ROPE SPINNERS REEL', 1, 40, NULL, 1, 3, 42, 10907, '2012-04-01', 'A Roper Spinner is an old occupation in Scotland and refers to the maker of rope by braiding yams of cotton or flax.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19730, '2019-10-28 18:08:49.01946+00', '2020-01-10 00:15:46.948427+00', 'Ballarat Bertie''s Bounce', 'BALLARAT BERTIES BOUNCE', 1, 40, NULL, 1, 3, 42, 11898, NULL, 'Recording downloadable from https://www.ballaratscd.com/audio.html', 41, '440/820/633/633/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19738, '2019-10-28 20:56:25.252458+00', '2020-01-12 00:24:28.913986+00', 'Golden Age Strathspey, The', 'GOLDEN AGE STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11901, '2018-06-01', '', 63, '888/844/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11546, '2003-10-05 22:00:00+00', '2019-11-01 02:01:37.13882+00', 'Seattle Landing', 'SEATTLE LANDING', 3, 32, 9999, 2, 3, 17, 723, '1998-01-01', 'Inspiration for the dance was the tune of the same name written by Fred Moyes. Fred wrote the music for the Seattle Branch when he visited in February 1998. He came to buy an accordion and he played for a Branch monthly party while here.  



The alternate name for the dance is "Looking For a Latte", a reference to Seattle''s reputation as the "Latte Capital of the Universe".  



Explanation of the figures by David Vandegrift -  

Bars  

1 - 8 Wending one''s way through town in search of the best latte stand.  

9 - 16 Espressing the ground beans with the crema ( couple 1) rising to the top.  

17 - 24 Frothing the milk.  

25 - 32 Running the stir stick round the inside of the cup to scoop out the foam.', 83, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19764, '2019-11-02 13:32:19.078025+00', '2019-11-02 13:32:19.078025+00', 'Saltoun Place Gardens', 'SALTOUN PLACE GARDENS', 2, 32, NULL, 6, 118, 30, 11636, NULL, 'Saltoun Place Gardens is the gardens in the town of Fraserburgh, Scotland, where the deviser grew up.', 88, '888/888/888/642', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18785, '2018-10-05 13:31:37.669179+00', '2019-11-01 21:45:57.610005+00', 'Haunted House', 'HAUNTED HOUSE', 2, 32, NULL, 1, 3, 42, 2766, '2011-10-01', '', 58, '800/877/888/866', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10224, '2001-11-06 23:00:00+00', '2019-11-02 00:49:47.952908+00', 'Whirlpool, The', 'WHIRLPOOL', 3, 32, 9999, 2, 3, 17, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19766, '2019-11-02 13:45:11.40668+00', '2019-11-02 13:45:11.40668+00', 'Summers in Belger', 'SUMMERS IN BELGER', 2, 32, NULL, 1, 4, 2, 11636, NULL, 'The dance, devised by Jack Pressley, is for Margaret and Alex Summers who live in Cairnbulg (locally known as Belger) and have become the greatest of friends with Jamie and I.', 91, '2882/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19767, '2019-11-02 13:51:19.645611+00', '2019-11-02 13:51:19.645611+00', 'Cat''s Rugby Jig', 'CATS RUGBY JIG', 2, 32, NULL, 105, 53, 17, 11636, NULL, 'The dance was devised by Jack Pressley for Catherine Hines. Catherine, known as Cat, is an avid rugby player and originally hails from Los Alamos, New Mexico.', 92, '888/484/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19768, '2019-11-02 13:59:50.378552+00', '2019-11-02 13:59:50.378552+00', 'Adele''s Jig', 'ADELES JIG', 2, 40, NULL, 6, 53, 17, 11636, NULL, 'The dance, devised by Jack Pressley, was written for Adele Zhau who is a very talented student at the British International School, Charlotte, NC.', 100, '8/8/8/8/8', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18358, '2018-06-03 14:24:51.00372+00', '2019-11-02 14:03:09.920793+00', 'Claire Telford of Netherlie', 'CLAIRE TELFORD OF NETHERLIE', 3, 32, NULL, 2, 2, 76, 11636, NULL, 'The dance, devised by Jack Pressley, was written for Claire Telford.



It may be danced as a two couple demo or in a three or four couple set.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9767, '2002-04-03 22:00:00+00', '2019-11-02 08:50:10.406899+00', 'King''s Croft', 'KINGS CROFT', 1, 32, 9999, 107, 6, NULL, 104, '1994-01-01', '3 X 32 Reel for 3 two-couple sets in spokes of wheel formation, evenly spaced.  Devised for the RSCDS London Branch Demonstration Class. On their video the dance is referred to as The Bousfield Reel.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18364, '2018-06-03 14:46:46.629079+00', '2019-11-02 09:26:05.292634+00', 'Langside Capers', 'LANGSIDE CAPERS', 1, 32, NULL, 1, 3, 42, 11636, NULL, 'The dance was devised by Jack Pressley for the dancers who dance, regularly every Sunday, at the Church Hall in Longside (Langside), Aberdeenshire and, who engage some of the best Scottish musicians, but, most of all they create such a welcoming atmosphere that it is an absolute pleasure to attend their dances.  



"Caper" is the Doric word for dance.', 67, '886/888/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7096, '1997-09-17 22:00:00+00', '2019-11-02 09:32:36.876973+00', 'Whirlpool, The', 'WHIRLPOOL', 1, 32, 9999, 1, 2, NULL, 313, '1976-01-01', 'Deviser''s note:  The phrasing given for bars 25-32 is only approximate, intended to suggest a gradual closing in and speeding up, followed by an opening out and slowing down to allow the dancers to finish

comfortably in their places.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19761, '2019-11-02 10:00:41.87004+00', '2019-11-02 10:00:41.87004+00', 'Piccolina, La', 'PICCOLINA', 1, 32, NULL, 1, 3, 42, 11636, NULL, 'The dance, devised by Jack Pressley, was for Chiara and Patrick Architta who are returning to France. Patrick and Chiara were a great addition to any dance group and they were so much fun to dance with.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19762, '2019-11-02 10:09:20.038918+00', '2019-11-02 10:09:20.038918+00', 'Belger Quine, The', 'BELGER QUINE', 3, 32, NULL, 104, 2, 76, 11636, NULL, 'The dance, devised by Jack Pressley, was written for my wife Jamie Pressley who comes from Cairnbulg, Aberdeenshire, known locally as “Belger” and the word “Quine” is the Doric word for girl. The village of Cairnbulg which adjoins the village of Inverallochy is situated on the North-East coast of Scotland at one end of a beautiful bay of golden sand with the town of Fraserburgh being at the other end. The dance was written originally as a two couple demonstration dance. It may be danced as a two couple demo or in a three or four couple set.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19763, '2019-11-02 10:43:49.024402+00', '2019-11-02 10:43:49.024402+00', 'Hills of Home, The', 'HILLS OF HOME', 1, 32, NULL, 1, 100, 2, 11636, NULL, 'The dance, devised by Jack Pressley, was for Harry and Greta McCouaig who 

run some of the best dances in the Buchan area at Longside, Aberdeenshire 

every Sunday. They have created such a great atmosphere at their dances and 

book the best of Scotland’s musicians to play at their dances.

The name “Hills of Home” relate to the Ochil Hills in Clackmannanshire. The 

Ochil Hills dominated the scenery where Harry and Greta were originally from. 

Harry from Tillicoultry and Greta from Alloa.

', 78, '8888/8228/8888/8008', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19760, '2019-11-02 09:37:30.810858+00', '2019-11-02 14:04:56.110436+00', 'Taylor''s Grace, The', 'TAYLORS GRACE', 1, 32, NULL, 1, 3, 42, 11636, NULL, 'The dance, devised by Jack Pressley, was for Grace Taylor, who lives in New Aberdour, and is a music teacher and composer. Grace composed the music for my dance “<<ddd:Summers in Belger>>” and she is a regular at Scottish Country Dancing in the North East of Scotland.', 56, '844/866/822/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7679, '1998-01-04 23:00:00+00', '2019-11-18 16:26:03.487125+00', 'Diamond Set in Silver, A', 'DIAMOND SET IN SILVER', 3, 32, 9999, 1, 3, 42, 108, '1985-01-01', '', 47, '484/383/383/583', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13611, '2010-09-21 22:00:00+00', '2019-11-03 22:51:57.402472+00', 'City of Preston Reel, The', 'CITY OF PRESTON REEL', 1, 32, 9999, 1, 3, 42, 10241, '2009-01-01', 'Devised to celebrate Preston receiving City status.  Danced by the beginners'' class of 2008-2009', 53, '800/888/844/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6780, '1997-04-03 22:00:00+00', '2019-11-03 23:44:42.019963+00', 'Turra Coo, The', 'TURRA COO', 1, 32, 9999, 3, 5, 7, 313, NULL, 'A white cow, impounded and ordered to be sold to pay for insurance stamps that her owner had refused to buy, escaped during uproar at the auction and went careering through the streets of Turriff, eventually returning to her farm. A granite slab marks the place where the worthy creature was buried.', 80, '68886/88488/68486/84840', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19759, '2019-11-01 08:02:34.542881+00', '2019-11-04 13:41:02.937576+00', 'Owen Sutherland''s Reel', 'OWEN SUTHERLANDS REEL', 1, 40, NULL, 1, 3, 42, 10363, NULL, 'Devised in memory of Owen Sutherland, a much loved and appreciated member of Javea SCD who also enthusiastically attended the Iberian Gatherings for many years.



The preferred tune is <<ddt:Sutherland''s Reel>> (as recorded by <<ddp:#3018>> on <<dda:#115>>) but there is no connection to Owen Sutherland other than the surname.', 48, '844/888/800/822/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (303, '1997-04-03 22:00:00+00', '2019-11-04 19:14:14.414959+00', 'Auld Luckie', 'AULD LUCKIE', 3, 32, 9999, 1, 3, 42, 108, '1971-01-01', 'Auld Luckie was one of the leaflet dances John brought on his first Canadian dance tour.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19733, '2019-10-28 18:27:12.558695+00', '2020-06-05 17:17:01.582704+00', 'Curlicue', 'CURLICUE', 1, 32, NULL, 1, 3, 42, 11899, NULL, 'NB in the <<ddpub:#1547|2nd Canberra Book>> (2020) bars 17-24 vary from the version in <<ddpub:#1522>> (2019).', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12680, '2006-02-16 23:00:00+00', '2021-10-10 22:58:15.501558+00', 'Reel for Alice, A', 'REEL FOR ALICE', 1, 32, 9999, 3, 5, 16, 146, NULL, '', 40, '88800  80000  82222  88000', 1, 1, 1, 1, 40);
INSERT INTO 'dance' VALUES (19086, '2018-12-06 16:58:12.955626+00', '2019-11-06 00:56:46.224468+00', 'Jean''s Jig', 'JEANS JIG', 2, 32, NULL, 1, 3, 42, 3699, NULL, 'Devised for a friend who moved from Woodfarm to Kilkreggan.', 63, '844/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4491, '1998-09-29 22:00:00+00', '2019-11-09 14:23:42.853085+00', 'Miss Hadden''s Reel', 'MISS HADDENS REEL', 2, 32, 9999, 1, 3, 42, 319, '1967-01-01', 'Muriel Hadden was secretary of the RSCDS from 1943 to 1967 (!). The

story goes that the Society wanted to dedicate a dance to her and

offered her several to choose from; since she was not a dancer herself

(!!), she picked the one which looked nicest when danced.

', 69, '888  844  888  888', 0, 1, 0, 0, 91);
INSERT INTO 'dance' VALUES (66, '1998-04-29 22:00:00+00', '2019-11-05 01:07:44.996436+00', 'Albert''s Hornpipe', 'ALBERTS HORNPIPE', 1, 32, 9999, 2, 3, 17, 270, NULL, '', 92, '888/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1345, '1998-01-04 23:00:00+00', '2019-11-05 01:09:11.374094+00', 'Cork Hornpipe', 'CORK HORNPIPE', 1, 32, 9999, 1, 2, 76, 270, NULL, '', 100, '88/88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10093, '2001-09-20 22:00:00+00', '2019-11-05 14:03:25.357071+00', 'Clach Na Cudainn', 'CLACH NA CUDAINN', 3, 64, 9999, 4, 4, 1, 108, '2001-03-01', 'For Inverness Branch of the RSCDS. 



"Clacn na Cudain" means "Stone of the Tubs"  The stone with this name used to be at the top of the bank of the River Ness and the housewives of the neighbourhood rested their tubs of wet chothes on it while they recovered breath after doing their laundry and climbing the steep bank.  



The stone is now incorporated in the fabric of the Town House in Inverness.



One repeat from new places is probably enough for most dancers as this is a vigorous dance.', 72, '8888/4444/8888/4444/8484/4848/4444/6666', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8720, '1998-04-01 22:00:00+00', '2019-11-09 14:56:08.256877+00', 'Willbergs of Rechberg, The', 'WILLBERGS OF RECHBERG', 3, 40, 9999, 1, 4, 13, 2113, '1988-01-01', 'Devised for Karin and Hans Willberg.  The figures symbolize how Karin and Hans set out to spread SCD in Germany, how people met and travelled through dancing, and how they enjoyed dancing in their own groups, at larger gatherings and as ''one large family".', 93, '8642/8888/8888/8888/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8710, '2001-05-21 22:00:00+00', '2019-11-09 14:57:03.20609+00', 'Spinning Stones', 'SPINNING STONES', 1, 32, 9999, 1, 3, 42, 2113, '1991-01-01', '', 63, '800/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14985, '2013-07-23 09:15:47.971009+00', '2019-11-11 12:48:48.036743+00', 'Lady Irvine''s Jig', 'LADY IRVINES JIG', 2, 32, 9999, 1, 3, 42, 99, NULL, 'Devised in memory of Mabel, Lady Irvine, first chairman of St Andrews Branch.  A talented musician with a lifelong love of dancing she was wife of Sir James Irvine, Principal of St Andrews University from 1920 to 1952.', 50, '800/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18149, '2017-12-23 13:01:56.116449+00', '2019-11-07 09:51:28.844377+00', 'Scottish Experience, A', 'SCOTTISH EXPERIENCE', 3, 32, NULL, 1, 2, 76, 10971, NULL, 'The Strathspey is uniquely Scottish, and the Celtic reel speaks for itself.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14320, '2011-12-01 23:00:00+00', '2019-11-10 00:47:44.249356+00', 'Annat Cottage', 'ANNAT COTTAGE', 3, 40, NULL, 2, 3, 17, 3694, NULL, 'Annat Cottage is Sue Duckett’s holiday home in Blair Atholl





', 80, '888/484/484/484/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9497, '2001-07-30 22:00:00+00', '2019-11-10 00:08:24.908256+00', 'Swinmark Sixsome, The', 'SWINMARK SIXSOME', 1, 32, 9999, 107, 56, 30, 228, NULL, '“Swinmark” (“Boar’s Mark”, in the sense of “border region”) is the name of the area surrounding Proitze and the Mühle. In fact, the boar is part of the Proitzer Mühle’s logo—see the title page of this book.



This is a fun piece inspired by Derek Haynes’s dance "Domino Five". It proved quite hilarious in the pre-publication trials, but the dancers should by no means be encouraged to behave like wild pigs.', 87, '888/844/888/686', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19243, '2019-03-18 20:09:32.489081+00', '2019-11-07 10:31:08.988201+00', 'Salute to Antonius', 'SALUTE TO ANTONIUS', 2, 32, NULL, 1, 4, 1, 10648, '2019-01-01', 'To Tony Payne, whose email address is antonius, to show my appreciation of his unfailing support and encouragement with The Sunday Class, despite all that he has had to contend with in his own life', 56, '8040/8484/8484/8004', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7302, '1998-07-09 22:00:00+00', '2022-08-13 09:21:04.805272+00', '5-couple Fugue', '5COUPLE FUGUE', 1, 128, 9999, 3, 5, 3, 17, '1995-01-01', 'The former weblinks no longer exist.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16940, '2016-05-06 08:09:40.697782+00', '2021-01-04 12:27:43.051848+00', 'Lyn''s Labyrinth', 'LYNS LABYRINTH', 3, 32, NULL, 4, 4, 1, 10907, '2012-04-01', 'Devised for Lyn Edwards on her birthday.  Lyn is a long time dancer in the Queensland Branch.', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17255, '2016-09-04 12:06:15.642812+00', '2019-11-12 20:58:08.424196+00', 'Rennie''s Rant', 'RENNIES RANT', 3, 32, NULL, 1, 3, 42, 11336, NULL, 'The name of the dance is in honor of Jack Rennie, my first teacher when I started dancing here in 1973.  It wasn''t always easy to keep up the classes, but it was always Jack who would call and say he hadn''t seen me dancing in a while, and I would go back to class. I''ve had so much fun dancing over the years, thanks to a good start in Jack''s class in Santa Monica.', 47, '800/844/822/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18392, '2018-07-04 12:05:31.973101+00', '2020-06-24 10:36:53.480876+00', 'Gillian''s Dance', 'GILLIANS DANCE', 3, 70, NULL, 102, 5, 3, 11656, '2017-01-01', '10 bar phrases.   

For Gillian Wheadon’s 75th Birthday, September 2017', 90, '8,4,4,8,8/10,10,10,10,10/10,10,10,10,10/10,10,10,10,10/10,10,10,10,10/10,10,10,10,10/8,4,4,8,8', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18179, '2017-12-23 15:57:32.040124+00', '2019-11-10 10:25:43.271674+00', 'Bonjour la Dordogne', 'BONJOUR LA DORDOGNE', 1, 32, NULL, 3, 5, 7, 10971, NULL, 'During a holiday in the Dordogne Valley, we were welcomed by the local Scottish Dance group, “Les

danseurs celtiques”. This dance was devised and danced to celebrate that very meaningful experience,', 65, '44444/44444/80844/88888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17746, '2017-05-10 22:51:24.06649+00', '2019-11-12 23:39:40.864117+00', 'After Twenty Five Years (Higham)', 'AFTER TWENTY FIVE YEARS HIGHAM', 3, 32, 9999, 2, 3, 17, 11573, '2016-12-01', 'Devised by Pauline Beeson and Roger Gurtner with help from Elizabeth Cooper, Ann Newberry, Mick Madigan and David Davidson at Higham Hall, Cumbria, December 2016.', 56, '800/044/888/644', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15237, '2013-11-12 18:57:34.006288+00', '2021-08-28 16:24:59.697958+00', 'Collingwood Oaks, The', 'COLLINGWOOD OAKS', 3, 32, NULL, 1, 3, 42, 10720, NULL, 'Notes from Dunedin Book 6:



The dance was devised by Jen Wood in recognition of the 200th anniversary of the death of Admiral Cuthbert Collingwood on 7th March 1810. Collingwood was known to carry acorns to plant on country walks, in the hope of ensuring that the navy would always have a supply of oak for building ships.', 50, '822/866/880/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7560, '2002-08-27 22:00:00+00', '2019-11-15 00:11:22.467135+00', 'Indian River Strathspey', 'INDIAN RIVER STRATHSPEY', 3, 32, 9999, 6, 3, 18, 3191, NULL, '', 83, '888  844  888  844', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (18491, '2018-08-07 20:39:20.891707+00', '2019-11-15 00:15:44.263348+00', 'Ann Banan', 'ANN BANAN', 1, 32, NULL, 2, 3, 17, 10563, '2017-01-01', 'Written for Annie Sapucaia.', 41, '840/800/804/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13302, '2007-07-22 22:00:00+00', '2020-10-07 16:18:40.632825+00', 'Ottery St Catchpole Reel, The', 'OTTERY ST CATCHPOLE REEL', 1, 88, 9999, 4, 4, 3, 228, '2007-01-01', '', 50, '4040/8080/0404/0808/4444/4444/4444/4444/8080/0808/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3031, '1997-08-25 22:00:00+00', '2019-11-15 09:03:51.122848+00', 'Huntly Castle', 'HUNTLY CASTLE', 3, 32, 9999, 1, 3, 42, 108, '1977-01-01', 'John Drewry wrote in the original description:



*Huntly Castle, now a ruin, was formerly the seat of the Earls, later the Marquises of Huntly - the chiefs of Clan Gordon.*', 62, '880/880/888/888', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (8743, '1999-01-18 23:00:00+00', '2019-11-15 09:09:40.113951+00', 'Streets of Milan', 'STREETS OF MILAN', 2, 32, 9999, 1, 3, 42, 2161, NULL, 'The instructions for this dance are published in the <<dda:Take Your Partners For Vol 1#892|booklet accompanying the CD>> by <<ddp:Luke Brady''s Scottish Dance Band#10034>>.', 50, '800  844  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (9354, '2000-07-01 22:00:00+00', '2019-11-15 09:27:09.450091+00', 'Cati Ramsay', 'CATI RAMSAY', 1, 32, 9999, 1, 2, 76, 463, '1999-01-01', 'For Cati’s Birthday.



The instructions for this dance are published in the <<dda:Take Your Partners For Vol 3#1021|booklet accompanying the CD>> by <<ddp:Luke Brady''s Scottish Dance Band#10034>>.', 47, '40/80/88/88', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1661, '1997-09-01 22:00:00+00', '2019-11-13 01:37:25.776878+00', 'Dinton Fivesome, The', 'DINTON FIVESOME', 1, 32, 9999, 4, 55, 30, 826, NULL, '', 91, '884/884/884/532', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15041, '2013-08-02 19:28:22.57912+00', '2019-11-15 14:11:00.646014+00', 'Cooper Children, The', 'COOPER CHILDREN', 2, 40, NULL, 1, 3, 42, 10821, '2009-05-09', 'Devised by Hugh Porteous and the Caledonian Society of Sheffield Dance Class for the ASCDS Festival at Ollerton on 9th May 2009.



10 bar phrases



Note: Eric''s Crib shows the current version.  In an earlier version the deviser, for [19-20], wrote “turn their partner by the left hand to finish in the middle of the dance with the man below the woman”.  In another variant, 1c turn LH 1½  for [25-26]', 61, '10,8,6/10,4,4/10,8,8/10,10,10', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (13094, '2006-11-14 23:00:00+00', '2020-04-18 23:27:26.718649+00', 'Eigg, Muck and Rum', 'EIGG MUCK AND RUM', 1, 32, 9999, 105, 53, 18, 3734, NULL, 'Named for the three little islands in the inner Hebrides reached by ferry from Mallaig.', 77, '822/888/844/877', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19153, '2019-01-17 09:47:35.277398+00', '2019-11-13 09:07:09.537489+00', 'Dewy Fields', 'DEWY FIELDS', 3, 32, NULL, 1, 4, 1, 11502, NULL, 'A tribute to Betty Hildebrand.  

"When Dewy Fields Are Green" is a poem written by Betty''s grandfather, David Scott, and published in 1922.', 69, '8800/8080/8448/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (809, '1997-04-03 22:00:00+00', '2019-11-13 09:11:15.085203+00', 'Brighton Square', 'BRIGHTON SQUARE', 1, 160, 9999, 4, 4, 3, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4985, '2002-09-08 22:00:00+00', '2019-11-13 09:17:46.326692+00', 'North of the Grampians', 'NORTH OF THE GRAMPIANS', 1, 160, 9999, 1, 98, NULL, 380, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12594, '2005-11-01 23:00:00+00', '2019-11-13 16:15:51.868996+00', 'Redwood Arbor', 'REDWOOD ARBOR', 3, 32, 9999, 1, 3, 42, 2961, NULL, '', 53, '800/822/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16523, '2015-07-31 14:00:15.410892+00', '2019-11-13 22:54:05.924831+00', 'Orpington Caledonians', 'ORPINGTON CALEDONIANS', 1, 32, 9999, 1, 3, 42, 884, '1987-01-01', 'The dance was written in 1987 to commemorate the 50th anniversary of the Orpington and District Caledonian Society.', 48, '802/808/840/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19771, '2019-11-15 23:22:54.025889+00', '2019-11-15 23:23:41.742139+00', 'Thanks for All the Dancing', 'THANKS FOR ALL THE DANCING', 3, 32, NULL, 2, 3, 17, 11905, '2019-10-01', 'Dedicated to Maureen Robson, upon her retirement from 38 years of teaching the Tawa Scottish  Country Dance Club, Wellington, New Zealand. The club meets in the Redwood Hall, Tawa.



Further details and the instructions for the dance are available via the comment on the <<https://youtu.be/hodeZQ9-xoY|youtube video>>.', 67, '800/888/844/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19769, '2019-11-14 09:00:47.725194+00', '2019-11-14 09:03:27.419407+00', 'Muirland Briggses, The', 'MUIRLAND BRIGGSES', 4, 32, 1, 1, 3, 42, 2489, '2012-03-01', 'Devised by Chuck Snowdon in honor of Mike and Norma Briggs on the 35th anniversary of the John Muir Branch (WI) Ball, March 2012.', 47, '800/866/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13157, '2006-12-11 23:00:00+00', '2019-11-14 20:44:28.15404+00', 'Lady Is a Star, The', 'LADY IS A STAR', 3, 32, 9999, 1, 3, 42, 2766, '2006-02-01', '', 59, '866/888/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19770, '2019-11-14 22:30:04.985921+00', '2019-11-14 22:34:43.670318+00', 'Red Poppy, The', 'RED POPPY', 4, 128, 2, 4, 119, 3, 416, NULL, 'The source for this dance is the <<https://www.scottish-country-dancing-dictionary.com|Scottish Country Dancing Dictionary site>> who have helpfully published, <<https://www.scottish-country-dancing-dictionary.com/dance-crib/z-red-poppy.html|on this page>>, both the deviser''s original hand written instructions and a typed up copy.



It was devised to commemorate the 70th anniversary of the Battle of the Somme and first performed on 8 November 1986.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1009, '1997-04-03 22:00:00+00', '2022-11-07 17:32:42.635481+00', 'Captain E. G. Elder''s Medley', 'CAPTAIN E G ELDERS MEDLEY', 4, 80, 9999, 1, 4, 14, 270, NULL, 'Twice through only', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19775, '2019-11-18 20:13:32.144492+00', '2019-11-19 10:16:41.464667+00', 'Lancers, The', 'LANCERS', 10, 208, NULL, 4, 4, 3, 9998, NULL, 'One original text for this dance says: Top couple #1, with back to the music; 2nd couple to their right 4th couple to their left, 3rd couple (bottom couple) facing them.  _Editors'' note: This is the inverse of the normal SCD numbering._



It also says:  "There are five figures, each with an eight bar introduction, when partners bow to each other, then to their corners, except in figure 5, which begins with a Grand Chain".  In that "original" those five figures are different 24, 32 or 64 bar dances.



A very different description was published on a Dance List, there the dance has 4 repeats of one 48-bar figure, followed by a 16 bar Grand Chain.



It could be that there are in fact two distinct dances with the same name.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4709, '1997-09-09 22:00:00+00', '2019-11-15 20:56:46.975093+00', 'Mr George Gray''s Reel', 'MR GEORGE GRAYS REEL', 1, 32, 9999, 1, 3, 42, 1156, NULL, '', 48, '860/804/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7019, '2000-04-25 22:00:00+00', '2019-11-15 23:09:30.550488+00', 'Welcome to Dufftown', 'WELCOME TO DUFFTOWN', 2, 32, 9999, 1, 3, 42, 374, '1987-01-01', 'The instructions for this dance are published in the <<dda:Special Requests Volume 5#430|booklet accompanying the CD>> by <<ddp:Colin Dewar and his Scottish Dance Band#3023>>.', 66, '866  888  888  844', 0, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (14067, '2011-08-25 22:00:00+00', '2020-01-11 01:58:45.385082+00', 'One Over the Eight', 'ONE OVER THE EIGHT', 1, 32, NULL, NULL, 98, 4, 10433, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15569, '2014-08-20 11:32:06.431167+00', '2019-11-28 13:12:12.555075+00', 'Snowman, The', 'SNOWMAN', 1, 32, 9999, 1, 4, 1, 10913, NULL, '', 91, '8888/8888/8444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1232, '1997-12-29 23:00:00+00', '2021-06-21 08:43:47.841199+00', 'Miss Stevenson''s Fancy', 'MISS STEVENSONS FANCY', 3, 32, 9999, 1, 2, 76, 175, '1996-01-01', 'This dance introduces a new progression, the Divided Knot.  



This 2-couple dance can also be danced in sets of 3 couples if preferred or the numbers require it. ', 43, '44  44  80  88', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (17156, '2016-08-17 17:39:49.049144+00', '2019-11-18 22:28:25.876127+00', 'My Love, He''s Hame Again', 'MY LOVE HES HAME AGAIN', 3, 32, NULL, 1, 3, 42, 2823, '2007-07-01', 'Dedicated to CDR Eric H. MacKay, USNR, SC after his safe return from Iraq.', 69, '884/888/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19772, '2019-11-16 09:07:38.988494+00', '2019-11-16 09:13:07.990997+00', 'Capering Scarecrows, The', 'CAPERING SCARECROWS', 1, 32, NULL, 1, 3, 42, 11073, '2019-04-01', 'Further details and the instructions for the dance are available via the comment on the <<https://youtu.be/3Kw7IaXNJuE|youtube video>>.', 59, '744/866/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19773, '2019-11-16 17:56:17.121493+00', '2019-11-16 18:12:28.075255+00', 'Farewell to Tawa', 'FAREWELL TO TAWA', 3, 32, NULL, 2, 3, 18, 11155, '2019-10-16', 'Further details and the instructions for the dance are available via the comment on the <<https://youtu.be/jQeEeUSQHUs|youtube video>>. According to these, Maureen Robson "devised this dance on 16 October 2019 to note the end of my time of teaching at Tawa club".', 79, '888/844/844/884', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15241, '2013-11-12 19:24:18.11565+00', '2019-11-18 23:53:24.487078+00', 'Dunedin Ruby', 'DUNEDIN RUBY', 1, 40, NULL, 3, 5, 16, 518, '2011-01-01', '', 78, '88888/66466/66466/84888/80088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16962, '2016-05-31 00:09:32.247411+00', '2019-11-16 23:45:15.899623+00', 'Johnsonville Diamond, The', 'JOHNSONVILLE DIAMOND', 3, 32, NULL, 1, 2, 76, 2682, '2015-10-18', 'Devised  18/10/2015.   2015 was the diamond jubilee of the formation of the Johnsonville club, as best we can tell.  



Teaching Note:  In La Spirale, the cast of 1M and 2W should be tight else the covering will be lost.', 56, '66/80/88/88', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12855, '2006-09-12 22:00:00+00', '2019-11-16 21:16:17.770442+00', 'Gigue du Chat, La', 'GIGUE DU CHAT', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2236, '1998-05-31 22:00:00+00', '2019-11-19 09:41:22.10613+00', 'Flock of Geese, A', 'FLOCK OF GEESE', 2, 32, 9999, 3, 5, 21, 11817, '1989-09-09', 'The dance was devised for the wedding of Lance Ramshaw and Gail Wine in Boston, September 9, 1989, and was presented to them at their wedding celebration dance.  



It is a 5-couple dance based on "The Wild Geese".  This dance is rather similar to Olivia Robert''s »The Black Swans of Narrabeen«; the progression is different', 60, '80808  80808  80008  88808', 0, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (12179, '2005-04-13 22:00:00+00', '2019-11-17 22:08:23.650165+00', 'Curling Lassies', 'CURLING LASSIES', 4, 64, 5, 1, 4, 1, 108, '2002-09-01', 'Dance interpreted by John Drewry, August 2002.  An interpretation of instructions which were sent to me by Jackie Johnstone of Dumfries.  They were sent to him by someone in Vancouver B.C.    



Included were two tunes:  



    "Mrs Cuthbert of Selkirk", a strathspey composed by Nancy Dickson, and 

    A Reel which is the original tune for "The Duke of Perth".  



The interpretation is made more difficult because, in the diagram, squares seem to be used ot represent men and circles to represent the women, which is the opposite of the usual practice.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9942, '2001-06-05 22:00:00+00', '2019-11-17 22:52:27.64942+00', 'Cleikum Crozier, The', 'CLEIKUM CROZIER', 1, 32, 9999, 1, 3, 42, 101, NULL, 'For Innerleithen Scottish Country Dance Club. The Cleikum Crozier is the staff carried in the St. Ronan''s Day Pageant in Innerleithen, Tweeddale.', 50, '800/844/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8852, '2001-06-05 22:00:00+00', '2019-11-17 23:03:48.254951+00', 'Odd Couple, The', 'ODD COUPLE', 1, 32, 9999, 4, 5, 55, 101, NULL, 'For Tony and Betty Moretti from New Hampshire.', 63, '44448/44448/44448/44848', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (774, '1997-09-28 22:00:00+00', '2019-11-18 11:55:52.591858+00', 'Braw Wooer, The', 'BRAW WOOER', 2, 40, 9999, 1, 3, 42, 108, '1967-01-01', '10 bar phrases', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19774, '2019-11-18 18:23:29.881812+00', '2019-11-18 18:26:38.163954+00', 'Mr Patrick Chamoin', 'MR PATRICK CHAMOIN', 3, 32, NULL, 2, 3, 18, 11236, NULL, '', 79, '880/884/888/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7147, '2003-01-30 23:00:00+00', '2019-11-19 09:47:38.669702+00', 'Wild Geese, The', 'WILD GEESE', 2, 32, 9999, 1, 3, 42, 9998, NULL, '##>>

This is generally used as a reference to Irish soldiers who fought in the service of various foreign kings and monarchs, including some who supported both Jacobite risings. The legend is that when they died abroad, their souls were transformed into geese so that they could fly back to Ireland.

##<<



The 5-couple dance "A Flock of Geese" is based on this dance.', 44, '808  808  800  880', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (2394, '1998-09-29 22:00:00+00', '2019-11-19 23:20:47.860337+00', 'Gang the Same Gate', 'GANG THE SAME GATE', 3, 32, 9999, 1, 3, 42, 501, NULL, '##>>

More usually written as ''Gang the same gait''.  It means simply, "go the same way" in both the literal and figurative senses of the expression.

##<<



"Gate" in Scottish is related to the Scandinavian "Gata", meaning "Street".', 47, '800  833  833  888', 0, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (19655, '2019-09-16 06:55:21.850714+00', '2019-11-20 09:03:40.276274+00', 'TAC Team', 'TAC TEAM', 2, 32, NULL, 1, 4, 1, 10786, '2010-01-01', 'Devised by Greg Reznick and dedicated to the Unit 2 and Unit 3 teacher candidates at T.A.C. summer school 2010.', 69, '8008/8008/8088/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14717, '2013-02-21 16:35:58.322769+00', '2019-12-31 14:40:00.081992+00', 'Aztec Weave', 'AZTEC WEAVE', 2, 32, NULL, 105, 53, NULL, 1394, NULL, '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12913, '2006-10-19 22:00:00+00', '2022-04-25 20:17:07.960838+00', 'Ball Gown, The', 'BALL GOWN', 3, 32, 9999, 2, 132, 17, 3583, '2005-03-01', 'A freely downloadable recording of music for this dance is available via <<http://www.fiddletree-music.com/johnturner/scdrecordings.html>>', 75, '882/888/828/444', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4251, '1997-04-03 22:00:00+00', '2022-12-03 12:07:21.944614+00', 'McCalls'' Measure, The', 'MACCALLS MEASURE', 3, 40, 9999, 1, 4, 1, 200, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12850, '2006-09-12 22:00:00+00', '2021-01-08 11:52:58.427667+00', 'Fair Haired Cat', 'FAIR HAIRED CAT', 1, 32, 9999, 1, 3, 42, 2961, NULL, 'Dance Note: The transition between the left hands across and the rights and left bars 23-25 requires dancers to release hands early enough to end at the sidelines for the last figure. Visually it is an interesting transition.



Note: The fair-haired cat, mentioned in the title, is my favorite buff colored, orange cat named Cocoa.', 53, '800/866/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5372, '1997-09-11 22:00:00+00', '2021-01-09 12:10:50.643035+00', 'Princess'' Country Dance, The', 'PRINCESS COUNTRY DANCE', 1, 32, 9999, NULL, 2, NULL, 499, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4407, '1998-09-29 22:00:00+00', '2021-03-02 11:48:10.394148+00', 'Minard Castle', 'MINARD CASTLE', 1, 40, 9999, 1, 3, 42, 472, NULL, '(Pronounced »MIN-nard«, not »MY-nard«, according to Linda Gaul, via Dagmar Suhm.)  



<<http://www.minardcastle.com|Minard Castle>> is located on the north west shore of Loch Fyne near the road from Inveraray to Lochgilphead.

', 70, '844/888/888/888/888', 0, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (19633, '2019-09-06 20:41:54.817601+00', '2019-11-20 09:09:35.77284+00', 'Let''s Swap Sides', 'LETS SWAP SIDES', 3, 32, NULL, 1, 4, 1, 9998, NULL, 'Source:  Dance List for the 20190813 - Bo''ness Class', 77, '8888/8888/8220/8446', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19626, '2019-09-04 08:35:33.50143+00', '2019-11-20 09:14:06.856722+00', 'Hey Charlie', 'HEY CHARLIE', 3, 48, NULL, 1, 4, 1, 9998, NULL, 'Sole source: Minicrib', 42, '4444/4444/8000/8440/8440/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19589, '2019-09-01 22:07:54.721097+00', '2019-11-20 10:25:53.847763+00', 'Rosemary''s Retirement Reel', 'ROSEMARYS RETIREMENT REEL', 1, 96, NULL, 4, 4, 3, 11869, '2012-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19231, '2019-03-08 19:38:15.126089+00', '2019-11-20 10:41:08.284603+00', 'Me and My Partner', 'ME AND MY PARTNER', 1, 32, NULL, 1, 4, 1, 11225, NULL, 'In this dance everyone only dances with their partner, apart from the circle at the end.', 56, '8008/0880/8000/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19018, '2018-10-19 20:15:00.780159+00', '2019-11-20 23:21:33.623323+00', 'Nigel Carter''s Caper', 'NIGEL CARTERS CAPER', 3, 128, NULL, 4, 4, 3, 1069, '1995-01-01', '', 88, '8888 4444 8888 8888 8888 4444 8888 8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12963, '2006-10-25 22:00:00+00', '2021-01-04 18:06:45.944218+00', 'Drakensberg Stroll, The', 'DRAKENSBERG STROLL', 3, 32, 9999, 1, 3, 42, 3718, '2005-01-01', '', 59, '880/804/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19408, '2019-06-16 13:02:24.068259+00', '2019-11-24 13:37:39.195607+00', 'Tuna Bandit', 'TUNA BANDIT', 3, 32, NULL, 1, 4, 2, 2766, '2016-04-01', 'My husband opened a can of tuna and left it on the kitchen counter when he got called away to do something else. When he remembered it, he found our cat Sebastian chowing down.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14243, '2011-08-29 22:00:00+00', '2019-11-24 14:15:21.664485+00', 'Sandy''s Scotch Broth', 'SANDYS SCOTCH BROTH', 3, 32, NULL, 2, 3, 18, 3610, NULL, 'May also be danced as a 6x32 medley - 3x32 strathspey followed by 3x32 reel.



This dance is dedicated to my friend Sandy Gordon with whom I enjoy drinking good scotch. We both take great pleasure in dancing strathspeys and so I wrote this dance for him. The first time the club danced it, it was without a title and when the club member Catherine Bennett said the movement of the dance reminded her of scotch broth I thought it fit perfectly as a title.', 75, '888  800  844  888', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (12426, '2005-05-05 22:00:00+00', '2019-11-25 00:25:26.947447+00', 'Best Set in the Hall', 'BEST SET IN THE HALL', 2, 32, 9999, 1, 3, 42, 3605, '2003-01-01', 'To: Auckland Region President, Campbell MacKay, Nov. 2003.



The characteristic formation of this dance called "Set to corner and cast away" in SCDDB terminology or often addressed as "Best set in the hall formation" sometimes also as "Peter White formation", has first been introduced by Alec Hay in 1976 in his dance <<Peter White>> in Strathspey time.

The formation next occurred in Ron Wallace''s dance <<ddd:Aberdeen Hunt>>, another Strathspey.



Seemingly, the formation experienced a lift-off after it had been included into this dance, <<ddd:the best set in the hall>>, in Jig time in 2003 by Helen Greenwood and published in RSCDS Book 46.



Now there are more the 20 dances of all types (Strathspeys, Jigs, Reels and even a Medley) featuring this formation.', 50, '800  844  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (15455, '2014-05-26 20:51:01.891985+00', '2019-11-25 07:03:33.940144+00', 'Fifty-two Summers', 'FIFTYTWO SUMMERS', 4, 160, 10, 4, 4, 1, 10961, '2013-07-19', '', 80, '8080/0808/8888/8888/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19471, '2019-07-08 12:33:16.022083+00', '2019-11-26 01:26:19.91875+00', 'Anne MacGregor''s Strathspey', 'ANNE MACGREGORS STRATHSPEY', 3, 40, NULL, 2, 3, 17, 11181, '2019-07-08', 'Suggested music: Swithland Woods played by David Cunningham and his Scottish Dance Band', 50, ' 800/808/880/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14332, '2011-12-08 23:00:00+00', '2019-11-26 22:27:07.613112+00', 'Stargazers', 'STARGAZERS', 3, 32, 9999, 2, 3, 18, 2701, '2009-07-04', 'This dance was presented to Jane Turton and Michael Gregg on the occasion of  their wedding on July 4, 2009. One can easily see the stars in their eyes when they look at one another. On top of  that, Michael is an astronomer by profession.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19778, '2019-11-27 06:55:09.088334+00', '2019-12-17 22:05:50.744383+00', 'McGregor Strathspey', 'MACGREGOR STRATHSPEY', 3, 32, NULL, 2, 3, 17, 11690, NULL, 'The e-crib is provisional, it is based on information from a Dance List; the editors are still looking for an official description.  ', 83, '484/888/088/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5906, '1998-09-29 22:00:00+00', '2019-11-27 20:42:54.185844+00', 'Saw ye my Wee Thing', 'SAW YE MY WEE THING', 2, 32, 9999, 1, 2, 76, 9998, NULL, '', 52, '80/08/88/88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (15063, '2013-08-10 15:33:33.497891+00', '2019-11-28 10:39:54.267682+00', 'H.M.S. Veronica', 'HMS VERONICA', 3, 32, NULL, 1, 3, 18, 10831, NULL, '', 53, '840/888/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15067, '2013-08-10 15:40:31.60641+00', '2019-11-28 10:53:41.531625+00', 'Clive Square', 'CLIVE SQUARE', 1, 32, NULL, 4, 5, 6, 2980, NULL, '', 55, '88888/04048/40408/82222', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19777, '2019-11-26 10:50:07.351874+00', '2019-11-28 16:39:15.544375+00', 'Tesla Coil, The', 'TESLA COIL', 3, 32, NULL, 1, 3, 42, 11676, NULL, 'Dedicated to Holger Crucius to celebrate his 50th birthday. Music composed by Sabine Schmitz (according to the <<https://youtu.be/mSwUqFtub5w|video>>).', 50, '800/844/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19780, '2019-11-28 17:14:51.777856+00', '2019-11-28 17:15:24.882948+00', 'Strathspey for Ewe, A', 'STRATHSPEY FOR EWE', 3, 32, NULL, 1, 4, 5, 11909, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4135, '1997-12-03 23:00:00+00', '2020-01-11 01:59:32.257295+00', 'Rosalie''s Rant', 'ROSALIES RANT', 2, 32, 9999, NULL, 98, NULL, 593, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16241, '2015-05-01 12:46:13.613611+00', '2020-01-11 23:49:29.055617+00', 'Tom Foolery', 'TOM FOOLERY', 3, 32, 9999, 2, 3, 17, 84, '2006-01-01', 'Bars 25-32 have the Full Switch', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18437, '2018-07-19 10:46:11.48182+00', '2022-04-26 01:34:38.327465+00', 'Summer in Sherbrooke', 'SUMMER IN SHERBROOKE', 3, 32, NULL, 2, 3, 18, 10907, '2011-08-01', 'Inspired by the TAC Summer School in Sherbrooke, Quebec. The ''La Baratte'' and the ''Bourrel'' provide the French connection with this Province in Canada.', 92, '888/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19085, '2018-12-06 13:04:27.145605+00', '2022-05-22 22:16:21.048765+00', 'Abbot House', 'ABBOT HOUSE', 1, 80, NULL, 4, 4, 3, 10882, '2015-09-01', 'The notes say that "Abbot House is the oldest surviving building in Dunfermline, other than the Abbey, and dates back to at least 1561. It was one of the few buildings to survive the great fire of Dunfermline in 1624, and over its history has been (amongst other things) a town house, a metal workshop and a naval officers'' club. In the 1970s, it was used as a doctor''s surgery, where the deviser''s mother was based as a student nurse."', 95, '8888/7777/7777/8888/8888/8888/8888/8888/4848/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19080, '2018-12-06 12:30:57.234627+00', '2021-03-13 21:13:13.312099+00', 'Queen Margaret''s Crown', 'QUEEN MARGARETS CROWN', 1, 96, NULL, 4, 4, 3, 11757, NULL, '', 67, '8888/8080/8080/8080/0808/0808/0808/6666/4444/6666/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16628, '2015-08-27 13:45:23.219116+00', '2021-04-25 22:19:26.38115+00', 'Ever Hopeful', 'EVER HOPEFUL', 3, 32, NULL, 1, 100, 11, 3703, NULL, '', 88, '8888/8888/0880/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19776, '2019-11-26 00:54:25.703092+00', '2021-10-20 06:54:12.478399+00', 'Breizh Merry Dancers of Servel, The', 'BREIZH MERRY DANCERS OF SERVEL', 2, 32, NULL, 1, 3, 42, 11181, '2019-11-26', '', 47, '800/844/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19779, '2019-11-28 17:06:35.063719+00', '2019-11-28 17:16:11.471869+00', 'Birthday Bee', 'BIRTHDAY BEE', 2, 32, NULL, 1, 3, 42, 11906, NULL, 'Dance devised by the "Lost  Sheep" Scottish country dancers Bochum in August  2015. (Bees and cake were Susanne''s idea.) This dance is dedicated to Sabine Riese, called Bine (english bee) who enjoys celebrating birthday, friendship and summer by dancing. Happy birthday!', 50, '800/888/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15056, '2013-08-07 20:43:34.606955+00', '2019-11-28 17:19:07.390213+00', 'Books and Maps', 'BOOKS AND MAPS', 4, 128, 2, 4, 4, 3, 10828, NULL, 'Devised for the wedding of Susan and Bastiaan. Both started SCD with Skua Dubh and fell in love at the Frankfurt Spring Ball. Susan is a librarian, Bastian a surveyor, hence the title. As both are fans of Terry Pratchell, we suggest shouting OOK! while clapping hands at the start of the Reel. ', 100, '8888  8888  8888  8888  8888  8888  8888  8888', 1, 1, 1, 0, 50);
INSERT INTO 'dance' VALUES (15073, '2013-08-10 15:47:42.845667+00', '2019-11-28 17:45:37.911056+00', 'Reel for Pania, A', 'REEL FOR PANIA', 1, 40, NULL, 1, 3, 42, 2980, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15071, '2013-08-10 15:45:46.636791+00', '2019-11-28 18:30:08.968831+00', 'Cruising Emerson Street', 'CRUISING EMERSON STREET', 2, 32, NULL, 1, 3, 42, 10831, NULL, '', 61, '800/888/888/868', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19781, '2019-11-28 23:39:31.35311+00', '2019-11-28 23:45:57.880864+00', 'Jim''s Strathspey', 'JIMS STRATHSPEY', 3, 80, NULL, 1, 4, NULL, 479, NULL, 'The information for this dance comes from this <<https://youtu.be/gZhszMden04|youtube video>> which calls it "Jim''s Strathspey" and attributes it to <<ddp:Rae, Jim>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17622, '2017-02-27 15:00:11.996493+00', '2019-11-29 00:58:16.782548+00', 'Council of Europe Jig, The', 'COUNCIL OF EUROPE JIG', 2, 32, NULL, 2, 3, 17, 11181, '2017-02-27', 'Devised by Roland Telle, February 2017, for The Scottish Country Dance Group in Strasbourg (SSCDG).', 54, '800/844/844/804', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19784, '2019-12-01 09:13:11.809838+00', '2019-12-01 10:21:00.957484+00', 'Malt Shovel, The', 'MALT SHOVEL', 1, 40, NULL, 1, 3, 42, 21, NULL, 'Source: MiniCrib.', 65, '888/888/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19783, '2019-12-01 09:10:14.052797+00', '2019-12-01 10:22:09.230268+00', 'Speyside Reel, The', 'SPEYSIDE REEL', 1, 32, NULL, 2, 3, 17, 127, NULL, 'Source: MiniCrib.', 75, '886/844/822/868', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19788, '2019-12-02 23:54:03.998855+00', '2019-12-02 23:54:03.998855+00', 'Eight on the Sixteen', 'EIGHT ON THE SIXTEEN', 1, 32, NULL, 1, 3, 42, 11911, NULL, '', 50, '800/888/800/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19204, '2019-02-28 00:04:04.794787+00', '2019-12-01 15:02:46.358925+00', 'Jump for Joy', 'JUMP FOR JOY', 1, 40, NULL, 1, 3, 42, 11793, '2018-01-01', 'For Mrs Joy Bradshaw, who taught me not only how to dance, but to love to dance.', 80, '800/688/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12786, '2006-06-14 22:00:00+00', '2019-12-01 20:24:05.667181+00', 'Ben Vrackie', 'BEN VRACKIE', 1, 96, 9999, 4, 4, 3, 1113, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12097, '2005-03-16 23:00:00+00', '2019-12-01 20:34:54.675203+00', 'Betty''s Birthday', 'BETTYS BIRTHDAY', 1, 32, 9999, 107, 111, 30, 1047, NULL, 'The dance is for four couples plus a single lady (Betty), and is danced four times through. Starting as B1234, the progression is: 2L[2M+B]413, The original 1st lady doesn''t get to dance the Betty position.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (451, '2002-03-03 23:00:00+00', '2020-01-08 11:00:01.324155+00', 'Bel Fearsed', 'BEL FEARSED', 1, 48, 9999, 4, 4, 46, 572, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19787, '2019-12-02 23:50:36.152534+00', '2019-12-02 23:50:36.152534+00', 'Stone Boats of Bronte, The', 'STONE BOATS OF BRONTE', 3, 32, NULL, 1, 3, 42, 11910, NULL, '', 53, '804/880/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11654, '2004-01-14 23:00:00+00', '2019-12-03 01:25:30.39577+00', 'Blythe and Cheerie', 'BLYTHE AND CHEERIE', 3, 16, 9999, 2, 2, 76, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2536, '1998-01-05 23:00:00+00', '2020-08-04 22:33:59.529464+00', 'Glenfinnan Gathering', 'GLENFINNAN GATHERING', 1, 32, 9999, 4, 118, 18, 82, NULL, '', 78, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (189, '1998-04-13 22:00:00+00', '2019-12-03 18:46:47.018936+00', 'Anniversary, The', 'ANNIVERSARY', 4, 64, 5, 1, 4, 1, 249, '1983-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (501, '1997-11-27 23:00:00+00', '2019-12-03 18:54:12.036563+00', 'Bide A Wee', 'BIDE A WEE', 4, 64, 17, 1, 4, 1, 81, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (560, '1997-04-03 22:00:00+00', '2019-12-03 19:07:36.365593+00', 'Blacksmith, The', 'BLACKSMITH', 1, 40, 9999, 1, 4, 1, 270, NULL, '', 85, '8888/8008/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1127, '1997-12-21 23:00:00+00', '2019-12-03 19:33:35.327117+00', 'Celtic Cross, The', 'CELTIC CROSS', 3, 32, 9999, 4, 4, 13, 9, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1231, '1997-08-31 22:00:00+00', '2019-12-03 21:54:09.034601+00', 'Cleveland Hornpipe', 'CLEVELAND HORNPIPE', 1, 32, 9999, 1, 4, 2, 543, NULL, '', 69, '4884/8008/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1696, '1997-04-03 22:00:00+00', '2019-12-04 11:12:17.971225+00', 'Dorney Wood', 'DORNEY WOOD', 3, 80, 9999, 1, 4, 22, 104, NULL, '', 85, '8888/0880/8448/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2163, '1997-09-02 22:00:00+00', '2019-12-04 23:06:16.024463+00', 'Fifty Glorious Years', 'FIFTY GLORIOUS YEARS', 2, 64, 9999, 4, 4, 46, 678, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10766, '2002-07-24 22:00:00+00', '2019-12-06 11:16:52.034783+00', 'Katrelian Strathspey', 'KATRELIAN STRATHSPEY', 3, 96, 9999, 4, 4, 3, 1, '1999-01-01', '', 83, '8888/8888/8888/8888/8080/8080/0808/0808/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12651, '2005-12-21 23:00:00+00', '2019-12-06 11:24:48.617713+00', 'See You Later', 'SEE YOU LATER', 3, 32, 9999, 6, 3, 4, 3412, NULL, 'The women do not progress but get a new partner each time. The men progress one place anticlockwise 231.', 75, '444/444/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12810, '2006-07-28 22:00:00+00', '2019-12-06 11:31:15.982393+00', 'Dance for Marjorie, A', 'DANCE FOR MARJORIE', 3, 32, 9999, 2, 3, 17, 1167, '2006-01-13', 'Written for Marj Potter.', 75, '880  888  844  808', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (12896, '2006-10-12 22:00:00+00', '2019-12-06 11:35:51.198262+00', 'Reverend Sandy Mailer', 'REVEREND SANDY MAILER', 1, 32, 9999, 1, 4, 1, 3715, NULL, '', 94, '8888/8888/8488/6688', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15792, '2015-01-15 16:24:32.632207+00', '2019-12-09 14:07:18.326877+00', 'Blythest Lilt, The', 'BLYTHEST LILT', 3, 32, 9999, 6, 3, 17, 210, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (241, '1997-04-03 22:00:00+00', '2020-08-02 06:39:36.396367+00', 'Arran Sword Dance', 'ARRAN SWORD DANCE', 7, 96, 9999, 1, 1, NULL, 82, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (308, '1997-08-31 22:00:00+00', '2020-08-29 11:55:30.600669+00', 'Auretti''s Dutch Skipper', 'AURETTIS DUTCH SKIPPER', 2, 32, 9999, 1, 2, 76, 453, '1756-01-01', '', 43, '80/08/44/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8309, '1998-01-12 23:00:00+00', '2021-03-20 19:44:02.813688+00', 'Aon''s a Dha', 'AONS A DHA', 1, 32, 9999, 1, 2, 76, 2018, NULL, '', 60, '88/88/80/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19789, '2019-12-08 04:57:28.052935+00', '2020-07-19 00:41:02.035988+00', 'Salute to Mrs Mac', 'SALUTE TO MRS MAC', 1, 32, NULL, 1, 3, 42, 11155, '2016-08-15', 'Devised to celebrate my mother’s 105th birthday on Sunday 30 October 2016.  She was always called Mrs Mac by her friends and colleagues.





', 56, '888/844/800/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19782, '2019-12-01 09:05:21.052665+00', '2022-02-18 02:53:06.978656+00', 'Strathspey for Helen', 'STRATHSPEY FOR HELEN', 3, 32, NULL, 2, 3, 17, 11166, NULL, 'Source: MiniCrib.', 50, '808/080/800/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (64, '1997-04-03 22:00:00+00', '2022-05-22 15:36:51.539496+00', 'Alastair Fitzmaurice', 'ALASTAIR FITZMAURICE', 2, 32, 9999, 1, 4, 1, 418, NULL, 'Incsribed "To Alastair Fitzmaurice of Mitcham, Victoria".', 88, '8888/6868/8484/4888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12902, '2006-10-12 22:00:00+00', '2022-11-23 23:57:45.586176+00', 'St Andrews Castle', 'SAINT ANDREWS CASTLE', 1, 32, 9999, 1, 3, 42, 11233, '1999-11-01', '', 53, '800/822/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6571, '1997-09-16 22:00:00+00', '2022-12-06 09:57:54.776922+00', 'Three Naked Men', 'THREE NAKED MEN', 2, 48, 9999, 1, 3, 30, 108, '1984-01-01', 'Drewry advises doing this once per couple in a set of "2, 3, 4, 5 or even 6" couples with a set one larger than the number of active couples. His instructions (followed by the E-crib) are for 3 couples in a 4 couple set.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19786, '2019-12-02 22:37:18.929479+00', '2019-12-08 22:55:50.88238+00', 'Welcome to St Columba''s', 'WELCOME TO ST COLUMBAS', 2, 32, NULL, 5, 2, 76, 3580, '2013-09-01', 'Round the room: 1st couples face anticlockwise, 2nd couples face clockwise.



The dance celebrates 130 years of worship at St Columba''s Church of Scotland, Pont St, London SW1X 0BD.



The original church was built in 1884 and reconstructed after the second world war. It has an architecture in a distinctivelty Swiss style.



The church is also  a well known venue for Scottish Country Dancing and its own group, St Columba''s Dancers welcome everyone to join them on the Winter Monday dance evenings. Details are on their website <<https://stcolumbasdancers.org>>.



The dance was requested by the group''s convener at the time, Denise Haugh, who chose the name of the dance.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1315, '2003-01-27 23:00:00+00', '2019-12-12 09:11:13.874586+00', 'Compliment, The', 'COMPLIMENT', 3, 32, 9999, 1, 2, 76, 146, NULL, 'For Muriel and Bill Zobel', 60, '88/66/66/88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (10747, '2002-07-24 22:00:00+00', '2019-12-09 13:27:10.929609+00', 'Ruby Years, The', 'RUBY YEARS', 1, 32, 9999, 2, 2, 76, 3176, '1995-03-01', 'The instructions say *danced 6 times in a 3 couple set.*



Devised to commemorate the 40th anniversary of Brighouse SCDC.', 58, '66/66/88/88', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13070, '2006-11-10 23:00:00+00', '2019-12-10 08:05:09.676449+00', 'Kangaroo Paw, The', 'KANGAROO PAW', 1, 32, 9999, 1, 3, 42, 884, '2006-01-01', '', 56, '800  888  822  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (12828, '2006-08-27 22:00:00+00', '2019-12-10 22:39:34.018807+00', 'Osborne Percentage, The', 'OSBORNE PERCENTAGE', 2, 32, 9999, 6, 3, 46, 831, NULL, '', 83, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17462, '2016-11-04 01:17:19.089161+00', '2019-12-11 23:50:16.751115+00', 'Pudsey Bear', 'PUDSEY BEAR', 2, 32, NULL, 1, 4, 1, 11413, NULL, 'May be danced in a 3 or 4 couple set.', 75, '8888/4444/4444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19795, '2019-12-13 13:07:07.003517+00', '2020-11-12 00:58:02.749971+00', 'A.J.''s Jig', 'AJS JIG', 2, 32, NULL, 1, 3, 42, 2701, '2019-11-19', 'For Andrew Clyde on the occasion of his 16th birthday on November 3, 2019. As his full name is Andrew John, his nickname is A.J. He and his family celebrated the event at the San Francisco branch’s annual Asilomar weekend workshop. Andrew shares his energy and enthusiasm on the dance floor with his partners and other dancers in the set. Such a joy!', 56, '880/808/808/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17392, '2016-09-30 23:21:03.916066+00', '2019-12-12 21:16:50.508377+00', 'Windmills of Spain, The', 'WINDMILLS OF SPAIN', 1, 32, NULL, 1, 4, 2, 11375, NULL, 'This is the original version of this dance, and is called "The Windmills of Spain" (note: with ''The'').  It will be included in a forthcoming <<ddpub:#1492|book>> commemorating the annual Iberian SCD gatherings. 



A later version of this dance appears on this database as the reel "<<ddd:Windmills of Spain#9906>>" (note: no ''The''). 



', 72, '8008/8448/4004/8888/4224', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19792, '2019-12-12 10:53:51.356871+00', '2021-11-24 14:03:16.480413+00', 'Phare de Cordouan, Le', 'PHARE DE CORDOUAN', 3, 32, NULL, 2, 3, 17, 11912, NULL, 'The “Phare de Cordouan” is the oldest lighthouse in France (opened in 1611) and is still in activity. It watches over the estuary of the Gironde and the Atlantic Ocean. 

I dedicate this dance to all the teachers and musicians who have been, and still are, my beacons (“mes phares” in French) in the world of Scottish Country Dancing. ', 50, '800/844/800/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9906, '2001-06-13 22:00:00+00', '2019-12-12 21:17:33.737319+00', 'Windmills of Spain', 'WINDMILLS OF SPAIN', 1, 32, 9999, 1, 4, 11, 2906, NULL, 'This is a later version of the reel "<<ddd:The Windmills of Spain# 17392>>" (note: with ''The'').  That original version also appears on this database, and will be included in a forthcoming <<ddpub:#1492|book>> commemorating the annual Iberian SCD gatherings. 

', 84, '8888/8008/8888/8668', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4174, '1997-09-08 22:00:00+00', '2021-01-06 16:25:13.101137+00', 'Marie''s Jig', 'MARIES JIG', 2, 40, 9999, 1, 4, 1, 439, NULL, 'Marie''s Jig was on the programme for a dance on December 7, 2019 in the Ngaio town hall, Wellington, New Zealand. The dance was in honour of the Tawa SCD Club tutor, Maureen Robson, who is retiring as club tutor after 38 years. The late Marie Malcolm tutored the Ngaio SCD Club in Wellington.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4827, '2001-09-13 22:00:00+00', '2020-12-13 19:08:51.655671+00', 'Muirland Willie', 'MUIRLAND WILLIE', 2, 32, 9999, 1, 3, 42, 9998, NULL, 'The music for this dance derives from the eponymous song which appeared, for example, in the *Tea Table Miscellany* (1726) published by the Scottish poet and publicist, Allan Ramsay (1684-1758). The music and lyrics (13 stanzas) can be seen on the University of Glasgow''s web site at <<http://special.lib.gla.ac.uk/teach/music/home.html#ramsay>>.

', 58, '888/888/820/880', 1, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (19794, '2019-12-13 13:01:31.417119+00', '2019-12-13 13:13:56.027288+00', 'Still and Always', 'STILL AND ALWAYS', 3, 32, NULL, 1, 3, 42, 2701, '2019-01-01', 'For Tom and Margaret Ward on the occasion of their anniversary. Although 2019 isn’t a 0 or 5 year anniversary, Margaret was moved to request a dance that honored their strong and loving marriage. Tom and Margaret share their respect and kindness with all on the dance floor. The dance, as yet unnamed, was presented at the Jean Patrick Memorial Dance on August 31, 2019. On the following morning, Tom shared the dance title above.', 56, '800/888/888/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6221, '2000-01-20 23:00:00+00', '2020-07-11 16:42:29.962436+00', 'Southern Stars', 'SOUTHERN STARS', 3, 96, 9999, 101, 6, 3, 156, NULL, 'This is a hexagonal set, so many of the figures produce a Y-shaped pattern with the same orientation on each iteration.', 88, '888888 /808080/888888/484848/888888/484848 / 080808/888888/848484/888888/848484 / 888888', 1, 1, 1, 1, 175);
INSERT INTO 'dance' VALUES (16423, '2015-06-02 13:58:52.04961+00', '2019-12-13 19:49:30.701471+00', 'Xmas Lights', 'XMAS LIGHTS', 1, 64, 9999, 1, 4, 1, 165, NULL, '', 69, '7777/6666/8888/4444/8800/8080/8004/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19796, '2019-12-14 13:51:43.025023+00', '2019-12-14 13:51:43.025023+00', 'Holly Rigg, The', 'HOLLY RIGG', 3, 32, NULL, 2, 2, 76, 210, NULL, 'Source: the youtube videos. One of them shows the dance in strathspey time, the other has reel in the title but is actually danced to jig music.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19793, '2019-12-13 12:55:33.303859+00', '2020-04-10 06:03:52.520502+00', 'Wright Back Home', 'WRIGHT BACK HOME', 1, 32, NULL, 1, 3, 42, 2701, '2019-01-01', 'To celebrate Elizabeth Wright’s return to San Francisco after many years in France.', 58, '880/864/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11235, '2003-03-09 23:00:00+00', '2019-12-14 16:15:10.111352+00', 'Corrieyaireag', 'CORRIEYAIREAG', 3, 32, 9999, 1, 2, 76, 2018, NULL, 'On the video the dance name is spelled as "Corrieyearach".', 60, '66/66/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11236, '2003-03-09 23:00:00+00', '2019-12-14 16:22:34.274621+00', 'Corrie Cas', 'CORRIE CAS', 1, 32, 9999, 1, 2, 76, 2018, NULL, 'A crib is available at <<https://www.scottish-country-dancing-dictionary.com/dance-crib/corrie-cas.html>>.', 52, '44/44/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10198, '2001-11-06 23:00:00+00', '2019-12-14 16:34:27.567163+00', 'Mountains of the Moon', 'MOUNTAINS OF THE MOON', 3, 32, 9999, 9, 7, 36, 2018, NULL, 'A crib is available at <<https://www.scottish-country-dancing-dictionary.com/dance-crib/mountains-of-the-moon.html>>. May also be danced in a 5 couple set.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15787, '2015-01-15 15:47:52.558218+00', '2019-12-14 17:32:02.203414+00', 'Run Rigg, The', 'RUN RIGG', 1, 32, 9999, 2, 3, 17, 210, NULL, '', 92, '888/888/888/088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13544, '2009-12-15 23:00:00+00', '2020-01-07 10:34:44.649787+00', 'Fireworks Reel, The', 'FIREWORKS REEL', 1, 32, NULL, 1, 3, 42, 228, '2009-08-24', 'This dance was originally written with the Reel of Seven recording in mind, so use that if you have it. The RSCDS recording is pretty dull by comparison. – Anselm', 44, '800/822/822/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19584, '2019-09-01 14:04:46.114892+00', '2022-07-30 11:32:39.583451+00', 'Together In Kippo', 'TOGETHER IN KIPPO', 3, 32, NULL, 2, 3, 17, 210, NULL, 'Source: Crib by deviser (<<https://www.scottish-country-dancing-dictionary.com/dance-crib/together-in-kippo.html>>).', 67, '800/888/844/808', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14343, '2011-12-12 23:00:00+00', '2019-12-15 21:08:31.036909+00', 'De''il Amang the Gaylors', 'DEIL AMANG THE GAYLORS', 1, 32, NULL, 8, 4, 30, 1862, '2007-01-01', 'Devised for Ian and the rest of the Gaylor clan of Madison, Wisconsin



Can be danced in a 6- or 8-couple set



In an 6C set, the progression of couples resembles the progression of individuals in a normal 2C/3L set



In an 8C set, the progression of couples resembles the progression of individuals in a normal 2C/4L set



', 75, '888800/444400/888800/888800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8872, '1998-12-16 23:00:00+00', '2019-12-16 17:13:02.847769+00', 'Twine weel the Plaiden', 'TWINE WEEL THE PLAIDEN', 3, 32, 9999, 2, 3, 17, 2018, '1998-01-01', '', 67, '800/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8847, '1998-12-16 23:00:00+00', '2019-12-16 17:28:33.644354+00', 'Taobh ri taobh', 'TAOBH RI TAOBH', 1, 32, 9999, 1, 3, 42, 2018, '1998-01-01', '"Taobh ri taobh", which literally means "Side by side" in Gaelic, refers here to the hand-in-hand reels of three. "Taobh ri taobh" should be pronounced as "Toeuv ree toeuv" in English with the following conventions:

  "oeu" is as in the French "coeur"; and

  "ee" is as in "beet".

See "Gaelic Dance Names" for more information on Gaelic spelling and pronunciation



Crib written by the devisers

', 56, '880/888/880/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4638, '1998-09-30 22:00:00+00', '2019-12-16 17:43:43.890216+00', 'Monifieth Star, The', 'MONIFIETH STAR', 1, 48, 9999, 1, 2, 76, 9998, NULL, '', 52, '84/84/84/84/80/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9239, '2000-01-16 23:00:00+00', '2019-12-18 23:59:07.592899+00', 'Snow Butterfly, The', 'SNOW BUTTERFLY', 2, 32, 9999, 1, 3, 42, 108, '1997-01-01', '', 56, '880/880/880/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (22, '2001-04-26 22:00:00+00', '2019-12-18 16:42:08.634021+00', 'Achnacarry House', 'ACHNACARRY HOUSE', 2, 32, 9999, 1, 3, 42, 127, NULL, 'Dance inscribed to Alan Cameron, home on vacation from New Zealand.

"Achnacarry House" is the seat of the Chief, Cameron of Locheil.

Inverness-Shire.', 47, '800  833  833  888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (19798, '2019-12-18 19:23:22.295083+00', '2019-12-18 19:23:22.295083+00', 'Reel Tay Dancers, The', 'REEL TAY DANCERS', 1, 40, NULL, 1, 3, 42, 851, NULL, 'Source: <<https://youtu.be/AfTzYTB031g|youtube video>> and <<https://www.scottish-country-dancing-dictionary.com/dance-crib/reel-tay-dancers.html>>. The dance was devised in 2019 to commemorate the Tay Dancers 100th video.', 60, '800/888/888/844/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13313, '2007-07-26 22:00:00+00', '2020-06-24 10:43:33.737171+00', 'See You in Arran', 'SEE YOU IN ARRAN', 1, 32, 9999, 1, 3, 42, 3776, '2007-05-23', '”Set and Rotate” normally begins with couples joining nearer hands on the sidelines, but I prefer this variation with couples facing diagonally (not joining hands) as described in “The Westminster Reel”.  



This dance is dedicated to Christine Hastie and Maggie Westley and all the other people, who helped to organise this great weekend.  

What a good idea to organise a dancing event at the Isle of Arran!', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13306, '2007-07-26 22:00:00+00', '2020-06-24 10:40:50.336739+00', 'Dancing on Water', 'DANCING ON WATER', 3, 32, 9999, 1, 4, 2, 3776, '2007-05-31', 'This dance was first tried out during a small occasion in Beelen (near Muenster, Germany) in June 2007. We used a small room adjacent to the organiser''s house. I subsequently learned that the wooden floor covers their former small indoor swimming pool.  

This inspired me to call this dance: “Dancing on Water”.', 69, '8448/8448/8008/4884', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3472, '1998-04-12 22:00:00+00', '2020-08-06 15:19:57.488564+00', 'Kilrymont', 'KILRYMONT', 3, 32, 9999, 1, 3, 42, 62, '1983-01-01', 'Devised October 1983. This is the ancient name of St Andrews. Bob devised the dance for Georgina Finlay and notes that the figure 8 progression was devised in the early 1980''s by Ben Stein of Burlington, Vermont.', 37, '880/800/822/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11405, '2003-08-14 22:00:00+00', '2019-12-18 13:45:14.826871+00', 'Liam''s Jig', 'LIAMS JIG', 2, 32, 9999, 1, 3, 42, 153, '2002-01-01', '', 63, '880/808/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12924, '2006-10-19 22:00:00+00', '2020-06-27 21:13:10.125903+00', 'Irish in the Rain', 'IRISH IN THE RAIN', 2, 32, 9999, 1, 3, 42, 3583, '2005-01-01', 'A freely downloadable recording of music for this dance is available via <<http://www.fiddletree-music.com/johnturner/scdrecordings.html>>', 37, '800/844/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6133, '1997-04-03 22:00:00+00', '2019-12-18 09:28:16.354486+00', 'Skamb Linnet', 'SKAMB LINNET', 1, 32, 9999, 3, 5, 7, 109, NULL, 'This is a 5C variant on Lamb Skinnet', 55, '80800  80800  80088  80888', 0, 1, 1, 0, 55);
INSERT INTO 'dance' VALUES (16206, '2015-04-15 10:02:27.281087+00', '2019-12-18 09:29:24.592624+00', 'Meet Me Mondays', 'MEET ME MONDAYS', 2, 32, NULL, 5, 2, NULL, 10759, '2011-11-07', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16745, '2015-09-19 17:33:31.372522+00', '2019-12-18 09:45:12.615911+00', 'Glenrothes', 'GLENROTHES', 1, 40, 9999, 1, 3, 42, 595, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19797, '2019-12-16 23:53:40.755072+00', '2020-04-22 20:32:10.251405+00', 'Peter Price''s Strathspey', 'PETER PRICES STRATHSPEY', 3, 32, NULL, 3, 5, 21, 11035, NULL, '', 61, '77077/80808/80880/82228', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2383, '1997-04-03 22:00:00+00', '2020-08-04 21:20:30.693909+00', 'Gallant Weaver, The', 'GALLANT WEAVER', 1, 32, 9999, 1, 3, 42, 129, NULL, '', 50, '800/844/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19136, '2019-01-08 15:17:43.602555+00', '2021-06-15 05:10:55.481181+00', 'Easy Peasy Rights and Lefts', 'EASY PEASY RIGHTS AND LEFTS', 2, 32, NULL, 1, 4, 1, 11035, '2015-01-01', '', 47, '6660/6660/8000/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14370, '2011-12-16 23:00:00+00', '2021-01-30 22:53:06.978422+00', 'Cape Disappointment Light', 'CAPE DISAPPOINTMENT LIGHT', 3, 32, NULL, 1, 4, 1, 10592, NULL, 'Explanation  

01-08   The waves of the ocean, and ships in the shipping lanes.  

09-16   A storm brewing.  

17-24   The revolving light of the lighthouse shining through the storm.  

25-32   The ships are able to navigate the sandbars without incident.', 81, '8484/8800/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13739, '2011-07-10 22:00:00+00', '2021-07-21 09:01:43.91137+00', 'I Q 100', 'I Q 100', 1, 32, 9999, 1, 3, 42, 10368, NULL, 'This dance is offered as an antidote to the many complex dances on the current repertoire.', 53, '888/800/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19799, '2019-12-19 21:06:50.262753+00', '2019-12-19 21:29:30.571957+00', 'Cockermouth Floods of 2009', 'COCKERMOUTH FLOODS OF 2009', 3, 40, NULL, 1, 4, 1, 11913, NULL, 'Source: the video (<<https://www.youtube.com/watch?v=xinlsBaz5mc>>) which gives the symbolism:

*In November 2009 the gem town of Cockermouth in Cumbria was devastated by floods.*

*This dance symbolises the floods rising, the rescues, the  community cooperation and the return of the town to normal.*', 70, '2222/8888/8888/8440/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12122, '2005-03-26 23:00:00+00', '2019-12-19 21:38:52.818289+00', 'Kiwi Magic', 'KIWI MAGIC', 1, 32, 9999, 4, 4, 1, 9998, NULL, '', 88, '4444/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19800, '2019-12-19 22:21:09.986802+00', '2019-12-19 22:21:09.986802+00', 'Galpin''s Clock', 'GALPINS CLOCK', 2, 32, NULL, 1, 3, 42, 11744, NULL, 'Source: youtube video (<<https://youtu.be/YBcyeOSCbS0>>) which says that the dance was

*named for the clock constructed by Henry Galpin (c. 1882) in the Observatory Museum on Bathurst Street, Grahamstown. Devised to celebrate the 40th anniversary of the Grahamstown Scottish Country Dance Group.*', 56, '800/866/866/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19801, '2019-12-20 10:57:08.755998+00', '2019-12-20 10:57:08.755998+00', 'St. Andrews Sixsome, The', 'SAINT ANDREWS SIXSOME', 4, 64, 22, NULL, NULL, NULL, 175, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16072, '2015-02-18 16:49:00.21985+00', '2019-12-20 13:51:29.416716+00', 'Nevskiy Prospekt', 'NEVSKIY PROSPEKT', 3, 32, NULL, 2, 3, 18, 228, '2015-02-18', 'Written for my teaching trip to St Petersburg, February 2015.



This dance also works in a 4-couple set although the progression is unusual. Don''t do it in a 7-couple set.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14580, '2012-10-02 09:32:04.478968+00', '2019-12-20 19:13:59.723314+00', 'Tribute to the Broadswords', 'TRIBUTE TO THE BROADSWORDS', 3, 96, NULL, 4, 4, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2035, '1997-09-29 22:00:00+00', '2020-01-08 10:55:52.571341+00', 'Fair Maid Of Perth', 'FAIR MAID OF PERTH', 3, 32, 9999, 1, 4, 1, 885, NULL, '', 56, '8888/8260/8000/8440', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18711, '2018-10-03 01:14:49.097596+00', '2022-12-10 10:07:56.807069+00', 'Christmas Candy', 'CHRISTMAS CANDY', 3, 32, NULL, 1, 3, 42, 2766, '2012-11-01', 'This is a dance I wrote for the upcoming Christmas season.', 44, '800/888/800/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17402, '2016-10-04 23:21:29.58017+00', '2019-12-26 00:29:44.694292+00', 'Those Eyes', 'THOSE EYES', 2, 32, NULL, 1, 2, 76, 1331, '2014-01-01', 'The dance is about dancing with your eyes, even when merely stepping up and down.  



Gazing Into her Bold Eyes. 

At lunch with two Scottish Dance teachers, Sheena MacQueen and Bruce Herbold, who both emphasize the social aspects of dancing in their teaching, James was unable to resist this pun when Sheena and Bruce made eye contact across the table. This tune was inspired by that moment.





Eyes on the Prize                                                      

After Bruce devised a dance for "Gazing into Her Bold Eyes," James wrote this to fit with the first tune, allowing a transition out of the unusual harmonic structures into a more standard modality.  Light and cheerful, the mood shifts away from the more dangerous flirtation of the first tune.





Curve in the Dark                                                      

James wrote this tune the summer after graduating from high school. It brings back memories of hot summer nights in Livermore when friends were a few minutes'' walk away, and the anticipation of something new and unknown loomed in the future.

', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19447, '2019-06-29 13:43:44.096654+00', '2019-12-26 17:03:29.385103+00', 'Milanese Lace', 'MILANESE LACE', 1, 32, NULL, 3, 5, 41, 2766, '2017-08-01', 'Milanese lace is a patterned tape lace and these figures remind me of making this lace.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11588, '2003-11-29 23:00:00+00', '2019-12-22 01:36:27.245721+00', 'Celtic Line, The', 'CELTIC LINE', 2, 32, 9999, 2, 3, 42, 411, '2001-01-01', 'Set inverts after each repetition and re-starts from other end.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17624, '2017-03-01 10:01:09.794739+00', '2019-12-22 03:55:49.045538+00', 'Statuary Falls', 'STATUARY FALLS', 3, 32, NULL, 2, 3, 18, 11455, NULL, 'Source: Danciemaetion', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11351, '2003-06-11 22:00:00+00', '2019-12-22 20:13:25.280337+00', 'Bonnie Lass o'' Fyvie', 'BONNIE LASS O FYVIE', 1, 32, 9999, 1, 3, 42, 1243, '2001-10-01', 'Ivy used to categorise dances by their title as ''male'' or ''female'' in order to remember who "went first".

For example, "General Stuart''s Reel" is ''male'' and the man starts the dance. When discussing "The

Wood of Fyvie", published by Jack McConachie, Ivy indicated it was a ''female'' dance because "Fyvie

includes Ivy." That comment is the inspiration for this dance. The women always dance in front of

their partner and15t woman begins the sequence starting at bar 17.', 56, '888/888/440/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19802, '2019-12-22 22:14:10.074235+00', '2019-12-22 22:14:10.074235+00', 'Robert Mackintosh', 'ROBERT MACKINTOSH', 3, 160, NULL, 2, 3, 3, 3165, NULL, 'Demonstration dance, published with many options. 



For the purposes of a crib this is not needed, but the whole dance is much indebted to MAISY WILLIAMS and her “Saxmundham Reel” published in that pioneering scheme “Scottish Dance Archives” January 1980, as “Set Dance 6”. I very much enjoyed dancing this, and Green Ginger’s enthusiastic and excellent playing Scottish Dance music. So, maybe it is part of my memory of the pleasures of dancing, and of the partnership bond with Sandra and her memories of Orkney. Hence the use of the title word ‘Connection’. Personal, very. ', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11364, '2003-06-11 22:00:00+00', '2019-12-22 23:21:56.798712+00', 'My Delight', 'MY DELIGHT', 3, 32, 9999, 1, 4, 5, 352, NULL, '', 50, '8000/8880/8080/0808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11359, '2003-06-11 22:00:00+00', '2019-12-24 02:37:45.916895+00', 'Ready to Dance', 'READY TO DANCE', 2, 32, 9999, 1, 3, 42, 3354, NULL, 'When Aline submitted her dance, she said, "I can always picture Ivy, eagerly watching the dance,

counting the bars, ready to move on cue as it came time."', 50, '800/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8719, '1998-04-01 22:00:00+00', '2019-12-30 01:01:11.501807+00', 'Twixt Bruce and Dee', 'TWIXT BRUCE AND DEE', 3, 32, 9999, 2, 3, 18, 1331, '1980-01-01', 'This dance was composed in the early 1980s for Bruce and Dee, two members of my class in Sacramento.  I presented the dance to them as a wedding gift.  I lost all track of it until this year when Roland Telle of the e-cribs team asked if I could give him directions for the dance, as it was in the dance database with only a list of figures. Using my memory of the first half and the list of figures for the second half I reconstructed the dance.  It may differ from its original formation, but I always liked the flirtatiousness of the opening 8 bars.', -1, '888/888/880/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1108, '1997-04-03 22:00:00+00', '2019-12-30 22:50:16.771509+00', 'Cecil McCausland', 'CECIL MACCAUSLAND', 2, 48, 9999, 1, 3, 42, 270, NULL, '', 45, '660/880/840/880/820/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (641, '1997-04-03 22:00:00+00', '2019-12-31 12:23:02.470741+00', 'Bonnie Brig', 'BONNIE BRIG', 3, 32, 9999, 1, 4, 1, 270, NULL, '', 94, '8888/8888/8888/8088', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19805, '2020-01-04 23:52:18.593233+00', '2020-01-24 12:05:12.144849+00', 'Tree to Go', 'TREE TO GO', 3, 32, NULL, 2, 3, 17, 9998, NULL, 'Taken from an Incomplete source', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (759, '1997-04-03 22:00:00+00', '2019-12-31 21:00:36.821001+00', 'Braidley''s House', 'BRAIDLEYS HOUSE', 2, 32, 9999, 5, 4, NULL, 270, NULL, '', 100, '8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19806, '2020-01-04 23:55:09.819499+00', '2020-01-04 23:55:09.819499+00', '20-20 Vision', '2020 VISION', 1, 32, NULL, 1, 3, 42, 11914, NULL, 'Source: MiniCrib.', 50, '800/866/866/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2715, '1997-04-03 22:00:00+00', '2020-01-01 01:45:45.901224+00', 'Haddie In The Pan, The', 'HADDIE IN THE PAN', 1, 32, 9999, 1, 3, 42, 101, NULL, 'Dedicated to Fran. MacCulloch', 53, '800/888/888/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2364, '1997-05-17 22:00:00+00', '2021-06-06 10:03:48.714258+00', 'Furth O'' Clyde', 'FURTH O CLYDE', 3, 32, 9999, 2, 3, 17, 181, '1989-01-01', 'Devised: 1989', 75, '800  888  888  808', 1, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (13559, '2010-01-19 23:00:00+00', '2020-01-01 03:54:11.196692+00', 'Old School Strathspey, The', 'OLD SCHOOL STRATHSPEY', 3, 32, NULL, 1, 100, 2, 347, NULL, '', 87, '8888/8888/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (833, '1997-04-03 22:00:00+00', '2020-01-01 23:44:23.651107+00', 'Brooch Of Lorne, The', 'BROOCH OF LORNE', 3, 32, 9999, 1, 3, 42, 13, NULL, '', 63, '800/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (890, '1998-07-08 22:00:00+00', '2020-01-02 10:14:59.042301+00', 'By Sea And by Land', 'BY SEA AND BY LAND', 3, 32, 9999, 1, 4, 2, 13, NULL, '', 88, '8888/8888/8008/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19809, '2020-01-05 00:14:57.145886+00', '2020-01-05 00:14:57.145886+00', 'Worbarrow Bay', 'WORBARROW BAY', 3, 32, NULL, 2, 3, 17, 10338, '2013-01-01', '', 96, '884/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12799, '2006-07-02 22:00:00+00', '2020-01-02 23:01:19.328251+00', 'Chocolate Factory, The', 'CHOCOLATE FACTORY', 2, 32, 9999, 1, 4, 1, 3694, NULL, 'The chocolate factory was founded in the 1870s by George Cadbury who wanted to take his workers out of the dirt and grime of a large Victorian city and build them a new place in the country to live and work. Between 1878 and 1906 he built a factory, village and school in the green fields of Kings Norton, outside the city of Birmingham and called it Bournville. Bournville is now within the city of Birmingham but the factory and the parks are still there. The Branch class meets near there on a Tuesday evening.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17824, '2017-06-22 17:03:24.86043+00', '2020-01-05 22:39:25.753699+00', '''Tree Tops'' Strathspey, The', 'TREE TOPS STRATHSPEY', 3, 32, NULL, 1, 4, 2, 10907, '2012-05-01', 'This dance was devised whilst enjoying the surrounds of the Tree Tops Resort, Coffs Harbour in Northern NSW, Australia.', 78, '5555/8888/8008/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10317, '2002-01-08 23:00:00+00', '2020-01-11 01:58:09.056836+00', 'Maple Leaf Strathspey', 'MAPLE LEAF STRATHSPEY', 3, 40, 9999, NULL, 3, NULL, 2913, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1278, '1997-04-03 22:00:00+00', '2020-01-08 11:09:47.265547+00', 'Colin''s Rebel Rant', 'COLINS REBEL RANT', 1, 48, 9999, 1, 4, 1, 377, NULL, '', 42, '8800/8800/8220/8000/8220/8080', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1449, '1997-04-03 22:00:00+00', '2020-01-08 11:28:22.922197+00', 'Crossways Capers', 'CROSSWAYS CAPERS', 2, 32, 9999, 1, 4, 1, 190, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1186, '1997-04-03 22:00:00+00', '2022-08-11 23:06:54.380837+00', 'Chinese Breakdown', 'CHINESE BREAKDOWN', 1, 48, 9999, 1, 3, 42, 270, NULL, '', 58, '880/808/888/844/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1461, '1997-08-31 22:00:00+00', '2022-10-13 11:17:32.941999+00', 'Crystal Jig', 'CRYSTAL JIG', 2, 32, 9999, 1, 3, 42, 179, NULL, '', 69, '844/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19811, '2020-01-06 07:24:32.683945+00', '2020-01-06 07:31:59.972318+00', 'Bytown Lass, A', 'BYTOWN LASS', 3, 32, NULL, 1, 3, 42, 10374, NULL, 'Bytown is the birth place of Mida Betty Lecocq. We know it now as Ottawa our nation’s capital. Mida Betty started dancing in Kitchener in 1984. Over the years we have become very good friends; we have both had similar ups and downs in our lives over the years. I hope we can share many more good times on the dance floor. Mida Betty enjoy.  



Suggested Music.  Invercaulds Reel. On the R.S.C.D.S Book 11. C.D. John Renton and his S.C.D.B.', 56, '800/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6936, '1997-09-16 22:00:00+00', '2020-01-11 02:00:31.877412+00', 'Water Garden, The', 'WATER GARDEN', 2, 40, 9999, NULL, 6, NULL, 333, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14515, '2012-07-06 08:15:34.396989+00', '2020-01-05 08:24:35.81136+00', 'Young Lady of Threadneedle Street, The', 'YOUNG LADY OF THREADNEEDLE STREET', 2, 32, NULL, 1, 3, 42, 3101, NULL, '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19808, '2020-01-05 00:10:18.60538+00', '2020-01-05 10:32:50.139514+00', 'Twesledown', 'TWESLEDOWN', 2, 32, NULL, 1, 3, 42, 10338, '2018-04-01', 'Source: MiniCrib.



The dance was devised to include the slip knot and the bourell in jig time, and was originally conceived while travelling home from Fleet along the winding road over Twesledown.', 72, '888/866/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19810, '2020-01-05 11:13:45.273589+00', '2020-01-05 11:18:53.523558+00', 'Krutushka', 'KRUTUSHKA', 1, 32, NULL, 2, 3, 17, 11915, '2019-06-26', '', 71, '840/880/880/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16225, '2015-05-01 09:49:01.780903+00', '2020-01-11 23:46:13.7293+00', 'Bonnie Lass O'' Grasse, The', 'BONNIE LASS O GRASSE', 1, 40, 9999, 1, 3, 42, 84, '2011-01-01', 'Bars 33-40 have the Left Hand Switch', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20081, '2020-09-04 13:25:16.649033+00', '2020-09-04 13:25:16.649033+00', '5D for Wiebke', '5D FOR WIEBKE', 1, 32, NULL, 3, 55, 95, 10612, '2020-01-01', '', 70, '00800/44844/88888/88888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5252, '1997-09-18 22:00:00+00', '2020-01-12 02:44:01.141675+00', 'Piece of Cake', 'PIECE OF CAKE', 1, 32, 9999, 1, 4, 1, 96, NULL, 'May be danced as a Reel or Jig', 53, '4444/4444/4884/8112', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7582, '1998-01-05 23:00:00+00', '2020-01-12 02:03:57.231071+00', 'Anniversary Reel', 'ANNIVERSARY REEL', 1, 32, 9999, 1, 3, 42, 413, NULL, 'Devised to commemorate the 25th Anniversary of the Teachers'' Association (Canada).', 59, '448/888/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19729, '2019-10-28 18:04:19.075862+00', '2020-01-12 12:43:14.66415+00', 'Amberley', 'AMBERLEY', 3, 32, NULL, 2, 3, 18, 3520, NULL, 'Amberley Retreat and Conference Centre is situated in 20 acres of natural bush overlooking the Yarra River in Lower Plenty in Melbourne. The Melbourne and District Branch has held an annual weekend school in these beautiful surroundings since 2013.', 44, '404/880/404/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19804, '2020-01-04 23:42:13.505335+00', '2020-01-28 12:16:35.194759+00', 'Lucky Seven', 'LUCKY SEVEN', 2, 32, NULL, 5, 1, 4, 9998, NULL, 'Ceilidh.  Type uncertain (source incomplete)', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1894, '1997-09-01 22:00:00+00', '2020-03-01 10:22:54.95357+00', 'Easiest Dance, The', 'EASIEST DANCE', 1, 32, 9999, 5, 2, 76, 828, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7873, '1997-12-03 23:00:00+00', '2020-09-05 10:12:57.23402+00', 'Oakbank''s Tribute to Christian', 'OAKBANKS TRIBUTE TO CHRISTIAN', 2, 32, 9999, 1, 3, 42, 811, NULL, '', 50, '844/844/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11366, '2003-06-16 22:00:00+00', '2020-10-13 19:06:28.990352+00', 'Black Leather Kilt', 'BLACK LEATHER KILT', 1, 40, 9999, 1, 100, 2, 671, '2003-01-01', '"For Alan Paterson’s somethingth birthday" ', 85, '8888  8888  8888  8448  8008', 1, 1, 1, 1, 85);
INSERT INTO 'dance' VALUES (20156, '2020-12-07 18:08:17.187562+00', '2020-12-07 18:08:17.187562+00', 'Million Dollar View, The', 'MILLION DOLLAR VIEW', 2, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19812, '2020-01-06 10:41:18.608072+00', '2020-01-06 10:41:18.608072+00', 'Garden Wedding, A', 'GARDEN WEDDING', 2, 40, NULL, 1, 4, 2, 952, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19813, '2020-01-06 11:45:02.5733+00', '2020-01-06 11:45:02.5733+00', 'Mersea Island Strathspey, The', 'MERSEA ISLAND STRATHSPEY', 3, 32, NULL, 1, 2, 76, 9998, NULL, 'Source: <<https://youtu.be/GCIDX_yOYUI|youtube video>> (from 2:40 to 3:40) by the Colchester Scottish Dance & Ceilidh Club.', 69, '88/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8349, '2002-06-02 22:00:00+00', '2020-01-06 16:03:48.453083+00', 'Dancing Out of Habit', 'DANCING OUT OF HABIT', 2, 32, 9999, 1, 3, 42, 108, '1996-10-01', 'Drewry''s Note: 



Devised for Robert Baird.



Robert, for a time, taught Scottish Country Dancing at a Catholic boys school. Girls from a neighbouring school were brought in as partners. At an end-of-term party, the monks, who taught at the school, joined in the dancing too. One of them danced on to a slippery part of the floor and went all his length. His habit flew up over his head giving a "non-divine revelation" to all present. Happily he was a good sport and, picking himself up, continued to dance.', 61, '16,14,0/888/888', 0, 1, 1, 0, 77);
INSERT INTO 'dance' VALUES (19814, '2020-01-06 15:48:37.238996+00', '2020-01-06 16:08:35.130877+00', 'Mimosa Menagerie, The', 'MIMOSA MENAGERIE', 3, 32, NULL, 4, 4, 1, 3723, NULL, 'Source: <<https://youtu.be/viuecohwweA|youtube video>> by the Buenos Aires Scottish Country Dancers.', 88, '8484/8888/8888/4848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19815, '2020-01-06 16:12:21.948636+00', '2020-01-06 16:12:21.948636+00', 'Maple Flow', 'MAPLE FLOW', 1, 32, NULL, 1, 3, 42, 3723, NULL, 'Source: <<https://youtu.be/e3ISPXjavkc|youtube video>> by the Buenos Aires Scottish Country Dancers.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14102, '2011-08-25 22:00:00+00', '2020-09-26 08:00:28.516477+00', 'Jig for Eric and Margaret, A', 'JIG FOR ERIC AND MARGARET', 2, 32, NULL, 1, 3, 42, 217, NULL, '', 44, '800/800/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19816, '2020-01-06 22:47:53.381826+00', '2020-11-28 10:49:11.578079+00', 'Bottoms up', 'BOTTOMS UP', 101, 32, NULL, 3, 5, 16, 9998, NULL, 'Unofficial source (crib only)', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11969, '2004-12-15 23:00:00+00', '2022-01-14 20:38:51.215996+00', 'Nimbus 2002', 'NIMBUS 2002', 1, 80, 9999, 4, 4, 3, 2792, '2002-01-01', 'You devise the ending (last 8 bars).', 95, '7777/7777/6666/8888/ 8888/8888/8888/ 8888/8888/ 8888/', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19803, '2019-12-31 16:39:45.685894+00', '2022-04-18 23:24:08.563686+00', 'Six Teas a Day', 'SIX TEAS A DAY', 1, 32, NULL, 1, 3, 42, 11350, '2013-12-13', 'This dance was devised by Mathias Ferber and presented by Raphaëlle, Axel and Emma Orgeret, James Fairbairn, Sam Schad, Mélissa Meunier, Nils and Mathias Ferber for Christiane Orgeret’s 60th birthday party, held on December 21st 2013.  

Christiane is known to drink about 6 cups of tea a day, probably the secret of her good health!', 56, '844/800/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5480, '2002-03-03 23:00:00+00', '2022-05-22 14:10:54.20233+00', 'Ray Milbourne', 'RAY MILBOURNE', 1, 32, 9999, 1, 102, 11, 175, '1976-01-01', '<<ddp:Milbourne, Ray>> is a pianist who played with various bands including Frank Reid''s. He was also the founding secretary of the National Association of Accordion & Fiddle Clubs.



First published in *Scottish Dance Archives*, September 1976.



Some sources, including the Scottish Dance Archives, mention a Reel "Glenfiddich" by Derek Haynes, identical to "Ray Milbourne".  It is not clear if this is a mistake, or if Derek first wrote this dance under that name, and then changed the name to avoid a name collision with the "Glenfiddich" by Hugh Foss.



', 81, '8008/8448/8888/8888', 0, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (19817, '2020-01-06 23:06:09.907173+00', '2020-01-08 09:43:48.181992+00', 'Chapelloise, La', 'CHAPELLOISE', 99, 16, NULL, 5, 1, 4, 9998, NULL, 'Ceilidh dance.  Source incomplete (crib only).



See <<https://en.wikipedia.org/wiki/Chapelloise|this wikipedia article>> for the history of this dance which was probably derived from the Gay Gordons.  [https://en.wikipedia.org/wiki/Chapelloise]', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6880, '1998-04-24 22:00:00+00', '2020-01-08 11:38:26.357968+00', 'Victorian Virgins, The', 'VICTORIAN VIRGINS', 3, 32, 9999, 1, 4, 1, 108, '1995-01-01', 'Drewry devised this dance one morning while staying in Melbourne. He asked his hosts if they would like to do *"a virgin dance, i.e. one untouched by human foot."* The idea amused them and, liking the dance, they gave it its title!.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3257, '2000-11-12 23:00:00+00', '2020-01-08 17:39:33.443858+00', 'Jig for Liz, A', 'JIG FOR LIZ', 2, 32, 9999, 1, 3, 42, 129, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19818, '2020-01-09 09:53:54.721886+00', '2020-01-09 09:53:54.721886+00', 'Tenders, The', 'TENDERS', 1, 32, NULL, 1, 3, 42, 2476, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7555, '1997-05-24 22:00:00+00', '2020-01-11 01:00:57.23665+00', 'Dunoon Barn Dance', 'DUNOON BARN DANCE', 50, 16, 9999, 5, 1, 54, 9998, NULL, '', 100, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2947, '1998-10-26 23:00:00+00', '2020-01-09 21:53:39.201421+00', 'Hogmanay Jig', 'HOGMANAY JIG', 2, 32, 9999, 1, 3, 42, 33, '1967-01-01', 'The deviser calls the chain figure for bars 25-32 a “Horseshoe chain”.  It is related to a "Snowball Chain starting form the bottom", but with changes in phrasing and some  several movements in the second half.', 66, '888/888/444/888', 1, 1, 1, 0, 81);
INSERT INTO 'dance' VALUES (19819, '2020-01-10 14:44:56.189609+00', '2020-01-10 14:49:23.017886+00', 'Farewell to Zakopane', 'FAREWELL TO ZAKOPANE', 2, 32, NULL, 1, 3, 42, 11916, '2019-09-01', 'Written on the way back from a Scottish Dancing weekend in Zakopane, Poland in September 2019.', 58, '864/808/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8190, '1997-12-27 23:00:00+00', '2020-01-11 01:54:51.15567+00', 'Castle Rocks', 'CASTLE ROCKS', 4, 192, 3, NULL, 98, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8388, '1997-12-28 23:00:00+00', '2020-01-11 01:31:55.043312+00', 'Black Diamonds', 'BLACK DIAMONDS', 2, 32, 9999, 1, 3, 42, 2015, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9117, '1999-08-12 22:00:00+00', '2020-01-11 01:56:27.892779+00', 'Glasgow Lasses Reel, The', 'GLASGOW LASSES REEL', 1, 64, 9999, NULL, 2, NULL, 2670, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8799, '1998-10-22 22:00:00+00', '2020-01-11 01:56:39.251457+00', 'Horseshoe Reel', 'HORSESHOE REEL', 1, 32, 9999, NULL, 3, NULL, 1193, '1991-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19060, '2018-12-03 15:56:48.395555+00', '2021-03-13 20:08:27.415309+00', 'Skeely Skipper, The', 'SKEELY SKIPPER', 2, 40, NULL, 2, 3, 17, 687, '2016-01-18', 'The dance takes its title from the opening lines of the ballad Sir Patrick Spens  

The King sits in Dunfermline toun,  

Drinkin the blude-reid wine  

''O whaur will I get a skeely skipper  

Tae sail this new ship o mine?''', 80, '840/880/888/888/668', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14170, '2011-08-26 22:00:00+00', '2021-03-19 01:42:55.718802+00', 'David Slater''s Highland Reel', 'DAVID SLATERS HIGHLAND REEL', 1, 96, NULL, 99, 2, NULL, 304, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19737, '2019-10-28 20:42:58.878745+00', '2020-01-12 13:07:58.835562+00', 'Glenbarry Lad, The', 'GLENBARRY LAD', 1, 32, NULL, 3, 5, 7, 10459, NULL, 'Dedicated to George Cooper, a founding member of the Melbourne and District Branch of the Royal Scottish Country Dance Society. George was the inaugural Treasurer of the Branch and in total served as Treasurer for 26 years; he currently holds the position of Assistant Treasurer. He received the Society Scroll in 2002. Accomplished dancer in both the Highland and Scottish Country Dancing traditions, George is also musician (bagpipes and accordion), teacher and tutor. He was born in the small town of Glenbarry, near Banff in the north east of Scotland. June''s suggested music includes the tune ''Miss Forbes'' Farewell to Banff'' composed by Isaac Cooper 1754-1820 (no relation to George).  



Devised by June lnwood (1934-2018).  



June received her Full Certificate in Melbourne in 1985. She taught at the Boxhill & District Scottish Society class for over 30 years, as well as at Branch weekend and day schools and the Celtic Group. She was Secretary of the Melbourne and District Branch Teachers'' Panel and a committee member of the Australian Teachers'' Association. She possessed a vast musical knowledge and a quirky sense of humour and those two attributes are well demonstrated by her music choice for the dance.', 58, '80800/63663/63663/84844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13719, '2011-07-08 22:00:00+00', '2020-09-19 20:40:06.968743+00', 'Triangle Lass, The', 'TRIANGLE LASS', 3, 32, NULL, 6, 3, 18, 3323, '2007-01-01', 'Dedicated to Monica, who grew up on "Triangle Road".



Suggested recording: "The Swelkie" (See You Jimmy #4) or "Sands of Forvie"', 100, '888  888  888  888', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (19747, '2019-10-28 21:59:08.776121+00', '2020-01-12 17:08:13.870174+00', 'Minestrone', 'MINESTRONE', 2, 32, NULL, 1, 3, 42, 11899, NULL, 'What better to eat in winter in multi-cultural Melbourne than minestrone, which, like this dance, contains a little of everything.', 55, '844/868/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14744, '2013-03-23 08:42:36.077226+00', '2020-01-12 20:20:25.743988+00', 'Midhowe Broch', 'MIDHOWE BROCH', 1, 64, NULL, 2, 3, NULL, 3165, '1988-01-01', 'A slightly modified version of this dance, "Gurness Broch" is marked as an alias.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1403, '1997-04-03 22:00:00+00', '2020-01-12 21:26:36.839601+00', 'Craigtoun Park', 'CRAIGTOUN PARK', 1, 32, 9999, 1, 2, 76, 28, NULL, '', 60, '80/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19551, '2019-08-21 22:06:09.904566+00', '2020-01-12 22:24:20.101831+00', 'Thursday Dram, The', 'THURSDAY DRAM', 3, 32, NULL, 2, 3, 17, 11183, '2019-05-01', '“Devised by Marion Bennett for William Williamson.”



DEVISED:2019-05', 75, '800/880/888/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5232, '1997-04-03 22:00:00+00', '2020-01-13 00:46:41.727807+00', 'Peter White', 'PETER WHITE', 3, 32, 9999, 1, 3, 42, 173, '1976-05-18', 'Preferred music: Iron Gray, by Peter White and his Scottish Dance Band.  The lead tune is marked below as the favourite.



The characteristic formation of this dance called "Set to corner and cast away" in SCDDB terminology or nowadays often addressed as "Best set in the hall formation" sometimes also as "Peter White formation", has first been introduced by Alec Hay in 1976 in this dance, <<ddd:Peter White>>, in Strathspey time.

The formation next occurred in Ron Wallace''s dance <<ddd:Aberdeen Hunt>>, another Strathspey.



Seemingly, the formation experienced a lift-off after it had been included into the dance <<ddd:the best set in the hall>> by Helen Greenwood in 2003, this time in Jig time and published in RSCDS Book 46.



Now there are more than 20 dances of all types (Strathspeys, Jigs, Reels and even a Medley) featuring this formation.', 56, '888  844  844  844', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (4309, '1998-11-25 23:00:00+00', '2020-01-13 10:25:13.794236+00', 'Menzies'' Rant, The', 'MENZIES RANT', 1, 32, 9999, 1, 109, NULL, 339, '1749-01-01', 'The Gaelic version of the title is no longer officially used by the RSCDS.



##RSCDS-DI:omit-ta



The dance description in older editions of Book 7 has several errors, one is making a BH turn 1 1/2 on [21-24] instead of once only.  Use a new edition or the Pocket Books.  Eric.', 56, '44  88  84  88', 0, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (6823, '1997-08-19 22:00:00+00', '2020-01-15 10:09:44.396939+00', 'Two Of The Best', 'TWO OF THE BEST', 2, 96, 9999, 4, 4, 3, 104, '1990-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10505, '2002-04-29 22:00:00+00', '2020-01-15 18:31:37.14043+00', 'Lazy Piper, The', 'LAZY PIPER', 1, 32, 9999, 1, 3, 42, 3110, '1996-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19687, '2019-10-01 08:00:43.232641+00', '2020-01-13 16:34:02.479044+00', 'Geneva Dancers, The', 'GENEVA DANCERS', 2, 32, NULL, 1, 3, 42, 11262, '2019-09-01', '', 62, '880/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16672, '2015-08-27 18:15:33.290826+00', '2020-05-17 01:40:50.257961+00', 'Fairlee Frolic', 'FAIRLEE FROLIC', 3, 32, NULL, 3, 5, 7, 10568, '2014-10-01', 'Holly Boyd writes:  "This dance was actually written as a 5 couple dance originally and is really fun as such. Is there some way to have it show up on the database as a 5 couple dance? If the choice is 3c or 5c, I''d rather it be 5c".



Both cribs are for the 5c version.



The description of the 5C version is available from Holly Boyd as a DOCX file.', 70, '80800/82842/88888/80888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4301, '1997-04-03 22:00:00+00', '2020-06-16 21:19:38.324864+00', 'Melville Castle', 'MELVILLE CASTLE', 1, 32, 9999, 1, 3, 42, 13, NULL, 'The original publication has this dance as a jig, but the recommended tune is in 2/4 reel time.', 47, '800/844/822/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19826, '2020-01-17 13:48:42.654743+00', '2020-06-28 21:05:55.850549+00', 'Busy B', 'BUSY B', 1, 32, NULL, 1, 3, 42, 11155, '2017-06-21', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2477, '1997-04-03 22:00:00+00', '2020-01-15 01:16:42.787857+00', 'Girl Guide Ramble, The', 'GIRL GUIDE RAMBLE', 1, 40, 9999, 1, 4, 1, 35, '1985-01-01', 'In summer 1986 there was a gathering of the Silver Birch Girl Guide leaders from the Kitchener / Waterloo area and other leaders from Ireland, Scotland, England and the Continent.  Pam Boaz, from the K-W SCD group, had an interesting idea to take to them a Scottish Country Dance that inexperienced dancers could do.', 72, '4444/4444/8888/8888/8444', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13100, '2006-11-14 23:00:00+00', '2020-01-26 17:46:51.279517+00', 'Dragonflies', 'DRAGONFLIES', 3, 32, 9999, 107, 55, 57, 1394, NULL, 'Set: 2 dancers face line of 3



I use Susie Petrov''s 5x32S set from her vinyl album "Hold the Lass Till I get Her"



Peter Price', 80, '88000/88888/88888/84848', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10678, '2002-07-21 22:00:00+00', '2020-01-20 00:02:00.031555+00', 'Miller''s Crossing', 'MILLERS CROSSING', 2, 32, 9999, 1, 3, 42, 2961, '1998-01-01', 'For Ken and Cathleen Miller, wonderful dancers in the Soquel Class.



In the "advanced" version, 2c+3c dance two successive half reels3 across.  In the first half reels, 2M & 3W will be the "lead dancers" (the first to pass the incoming 1C dancer).  In the second half reel, 2W & 3M wil be the lead dancers.  That phrasing differs from that of a full reel3, where the same dancer leads in both halves. The path danced remains normal, but during bars 3-6 2M+3W must slow down, and 2W+3M speed up, to pass their partners correctly in the middle on bar 7.  ', 44, '800/888/800/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16906, '2016-03-16 20:11:49.385044+00', '2020-02-15 16:23:24.247867+00', 'Portland Mermaid, The', 'PORTLAND MERMAID', 3, 32, NULL, 2, 3, 18, 1167, '2015-10-04', 'For Lou Hanson who persuaded us into hydro-therapy at TAC Portland 2012.

', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17050, '2016-06-23 21:16:11.643479+00', '2020-03-23 11:07:33.249299+00', 'Look! No Hands!', 'LOOK NO HANDS', 1, 32, NULL, 1, 3, 42, 10254, NULL, 'This was devised as a joke for the Tayside Scottish Country Dance Club, Newport. Three members of the club broke an arm within a relatively short time! ', 44, '444/800/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17136, '2016-07-10 22:32:08.910138+00', '2020-10-21 20:04:04.921024+00', '192 Miles Home', '192 MILES HOME', 2, 48, NULL, 4, 4, 1, 11300, NULL, 'This dance was written while the deviser was travelling the 192 miles from South Wales back to her home city, Brighton & Hove.

', 66, '8000/8202/8020/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4737, '1997-04-03 22:00:00+00', '2021-04-14 13:58:16.098254+00', 'Mrs Betty Stobbie', 'MRS BETTY STOBBIE', 3, 32, 9999, 1, 4, 1, 418, NULL, '', 100, '8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4014, '2000-05-04 22:00:00+00', '2021-05-01 21:05:28.690969+00', 'Macdonald of Sleat', 'MACDONALD OF SLEAT', 2, 120, 9999, 1, 4, 3, 9998, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15530, '2014-07-14 11:10:08.026468+00', '2020-01-17 18:49:29.93435+00', 'Bourtree Reel, The', 'BOURTREE REEL', 1, 32, NULL, 1, 3, 42, 1415, NULL, '', 50, '800/880/888/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14342, '2011-12-12 23:00:00+00', '2020-01-18 04:50:29.107485+00', 'Rosie''s Ceilidh', 'ROSIES CEILIDH', 2, 32, NULL, 5, 2, NULL, 2408, '2007-07-01', 'Devised July 2007 for Audrey McClellan''s new book in her Scottish Island Novels series.', 88, '66  66  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (5580, '2002-08-05 22:00:00+00', '2020-01-16 19:40:19.011432+00', 'Ring of Brogar, The', 'RING OF BROGAR', 3, 32, 9999, 1, 100, 11, 313, NULL, 'The Ring of Brogar is now more commonly spelled The Ring of Brodgar (see <<http://www.orkneyjar.com/history/brodgar/>>) but Brogar was the spelling used by <<ddp:#313>> in the original publication.



There is also a dance <<ddd:The Ring of Brodgar#10774>> by <<ddp:#175>>.', 81, '8888/8008/8448/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19830, '2020-01-17 14:00:49.803813+00', '2020-01-17 14:00:49.803813+00', 'Fine Wool Shawl, A', 'FINE WOOL SHAWL', 3, 80, NULL, 4, 4, 3, 11155, '2014-01-23', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6473, '1997-09-14 22:00:00+00', '2020-01-17 21:13:19.552047+00', 'Tartan Bib, A', 'TARTAN BIB', 2, 32, 9999, 1, 3, 42, 1124, '1987-05-10', 'Robert Anapol, then aged 20 months, adopted on Mother''s Day 1987, received a tartan bib as part of a "welcome to New York" gift from the Brooklyn Royal Scottish Country Dancers.', 66, '888/888/844/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19831, '2020-01-18 11:15:20.826612+00', '2020-01-18 11:15:20.826612+00', 'Ethel Enkel''s 100th Birthday', 'ETHEL ENKELS 100TH BIRTHDAY', 4, 128, 2, 4, 4, 1, 10568, '2019-12-01', '32 bars danced twice in strathspey, then twice in reel time.', 94, '8888/8888/8888/4848', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17983, '2017-09-26 21:53:25.779659+00', '2020-01-18 09:38:17.021025+00', 'Sausage Machine, The', 'SAUSAGE MACHINE', 1, 32, 9999, 1, 4, 1, 9998, NULL, 'This dance has been attributed to <<ddp:Ian Brockbank>> in some places. However, according to Ian it isn''t by him.', 62, '8000/8888/8888/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18597, '2018-09-15 19:59:34.485241+00', '2020-04-18 22:56:05.407562+00', 'Shepherd''s Delight', 'SHEPHERDS DELIGHT', 2, 32, NULL, 1, 100, 2, 11706, NULL, '', 75, '8008/8888/8008/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19822, '2020-01-17 13:44:08.428777+00', '2020-07-19 12:13:29.530926+00', 'Woodland Wedding', 'WOODLAND WEDDING', 3, 40, NULL, 2, 3, 17, 11155, '2016-11-18', '', 83, '844/888/888/866/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19828, '2020-01-17 13:58:53.826527+00', '2020-02-24 23:39:43.32351+00', 'Farewell to the Irwell', 'FAREWELL TO THE IRWELL', 1, 32, NULL, 1, 2, 76, 11155, '2017-04-22', 'Devised on Saturday 22 April 2017 for an evening for Moggie Grayson to celebrate her arrival in

New Zealand 50 years ago. Moggie came from Manchester. The River Irwell forms the boundary

between Manchester and Salford and empties into the River Mersey near Irlam.  



Recommended recorded music - "Selection of Reels", disc 1, track 3 on "Celtic Fire in the Music"

played by Bobby Brown and The Scottish Accent.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19823, '2020-01-17 13:45:28.217802+00', '2022-09-06 14:54:01.756207+00', 'Spinner and The Weaver, The', 'SPINNER AND THE WEAVER', 2, 32, NULL, 1, 4, 2, 11155, '2017-07-25', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19824, '2020-01-17 13:46:33.576868+00', '2022-09-06 15:01:20.65188+00', 'Wilds of Wannie, The', 'WILDS OF WANNIE', 1, 40, NULL, 1, 3, 42, 11155, '2017-03-16', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3397, '1997-08-24 22:00:00+00', '2022-11-13 23:02:03.59305+00', 'Karin''s Strathspey', 'KARINS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 175, '1991-01-01', 'Devised for Karin Willberg of Rechberg, Germany, who has received the Society''s Scroll of Honour



Instructions in the Carnforth 2 collection indicate dancers turn BH almost once round and "open out" into 4 hands round to the left. Video does not show this - it is a performance interpretation.', 50, '880  833  833  866', 1, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (19825, '2020-01-17 13:47:20.172078+00', '2022-09-06 15:04:27.203248+00', 'More than Friends', 'MORE THAN FRIENDS', 3, 32, NULL, 1, 4, 2, 11155, '2002-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19827, '2020-01-17 13:57:36.351983+00', '2022-09-06 15:07:07.69253+00', 'Plessey Woods', 'PLESSEY WOODS', 3, 40, NULL, 2, 3, 17, 11155, '2011-12-10', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19829, '2020-01-17 14:00:00.558295+00', '2022-09-06 15:10:03.120779+00', 'Radcliffes of Dilston, The', 'RADCLIFFES OF DILSTON', 2, 32, NULL, 1, 3, 42, 11155, '2013-09-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12638, '2005-11-10 23:00:00+00', '2021-01-11 23:02:55.647045+00', 'Festival Frolic', 'FESTIVAL FROLIC', 4, 64, 5, 4, 2, NULL, 2408, NULL, 'Start in diamond formation: M facing M on the sides with their P to their R on the midline.', 100, '88  88  88  88', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (10663, '2002-07-21 22:00:00+00', '2021-02-06 13:01:11.350914+00', 'Alan J Smith', 'ALAN J SMITH', 2, 32, 9999, 1, 3, 42, 3170, NULL, 'Note: the NHJ on bar 8 was added later by Andrew, see <<sspey:53343|Strathspey message 53343>> of 2008-08-08, see also <<sspey:53353|53353>>.', 56, '804/888/822/888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (5471, '1997-09-12 22:00:00+00', '2021-04-02 17:07:54.454744+00', 'Rangitoto', 'RANGITOTO', 2, 40, 9999, 4, 4, 46, 506, '1981-08-01', 'The dance represents the volcanic mass of Rangitoto. an island in the Hauraki Gulf close to Auckland City.

The "Schiehallion" reels represent water lapping against the shores of the island.', 80, '8888/4444/8888/8888/8080', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20410, '2021-07-30 09:13:21.313115+00', '2021-07-30 09:13:21.313115+00', 'Jean''s Wee Calamity', 'JEANS WEE CALAMITY', 3, 0, NULL, NULL, NULL, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7226, '1997-04-03 22:00:00+00', '2020-01-22 23:50:24.188909+00', 'Woodhill Court', 'WOODHILL COURT', 1, 48, 9999, 1, 100, 2, 108, '1975-02-02', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14140, '2011-08-26 22:00:00+00', '2020-01-23 10:16:22.579661+00', 'Thurling Strathspey, The', 'THURLING STRATHSPEY', 3, 96, NULL, 4, 4, 3, 74, '2005-08-01', 'The dance was written in honour of Arnold and Joan Thurling to recognise their 40 year association with the Wollongong White Heather Scottish Country Dancers and the presentation to Arnold of the Royal Scottish Country Dance Society Branch Award on 6th August 2005.', 69, '8080/8888/0808/8888/8080/8080/0808/0808/6666/8484/4848/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5615, '1997-09-12 22:00:00+00', '2020-01-19 22:14:59.288738+00', 'Road to Rothesay, The', 'ROAD TO ROTHESAY', 1, 32, 9999, 2, 3, 17, 137, NULL, 'In the original instructions, the formation in [9-16] is referred to as Pass Half Round.', 69, '844/800/866/868', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5301, '2002-11-26 23:00:00+00', '2020-01-20 09:28:04.164628+00', 'Pleasance, The', 'PLEASANCE', 3, 32, 9999, 2, 3, 18, 13, NULL, '', 47, '806/860/800/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8360, '2002-06-03 22:00:00+00', '2020-01-21 08:38:00.855132+00', 'Olympians, The', 'OLYMPIANS', 2, 32, 9999, 1, 100, 2, 108, '1996-03-01', 'Devised in March 1996 for the RSCDS Atlanta Branch to celebrate their city being named the venue for the Centennial Olympic Games.', 75, '8888/8008/8888/8008', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19833, '2020-01-21 07:09:57.935514+00', '2020-01-22 09:09:36.968474+00', 'Autumn in Kazan', 'AUTUMN IN KAZAN', 3, 32, NULL, 2, 3, 18, 11919, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14584, '2012-10-02 09:48:51.61079+00', '2020-01-22 09:42:39.681327+00', 'Sheringham Strathspey, The', 'SHERINGHAM STRATHSPEY', 3, 32, NULL, 1, 100, 11, 1415, NULL, 'When I was asked to teach at the Norwich day school we stayed with Gwynneth and Gerald Sibilia in the

town of Sheringham. Unfortunately, having arrived on Friday night in thick fog, it wasn’t until Sunday

morning when we were leaving that the fog had lifted and we got to see any of the town.', 88, '0880/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11517, '2003-10-02 22:00:00+00', '2020-01-22 18:23:03.580887+00', 'Fluin Lane', 'FLUIN LANE', 3, 32, 9999, 4, 4, 1, 3380, NULL, '', 81, '8080/8888/6666/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11392, '2003-07-06 22:00:00+00', '2020-01-24 10:29:43.871831+00', 'Crossing the Brook', 'CROSSING THE BROOK', 1, 32, 9999, 1, 3, 42, 146, NULL, '', 47, '444/444/888/840', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19834, '2020-01-23 23:44:22.924097+00', '2020-01-24 12:05:34.491317+00', 'Tim''rous Beastie', 'TIMROUS BEASTIE', 1, 32, NULL, 1, 4, 1, 11920, NULL, 'Heather Hodgson wrote:  An easy little dance that I found out about in 2014 and that I typically tend to include on our Burns Night Social dance programme.







', 69, '8800/8000/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3360, '1997-09-05 22:00:00+00', '2020-01-25 14:10:54.37111+00', 'Joy For Ann', 'JOY FOR ANN', 3, 64, 9999, 4, 4, 3, 1033, NULL, '', -62, '8888/8080/8080/8080/4444/0808/0808/0808/4444', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11828, '2004-10-31 23:00:00+00', '2020-01-26 08:52:06.665107+00', 'Four of Diamonds', 'FOUR OF DIAMONDS', 2, 32, 9999, 105, 54, 2, 2677, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9040, '2001-05-03 22:00:00+00', '2020-01-26 00:38:22.740874+00', 'Geordies'' Diamond Reel, The', 'GEORDIES DIAMOND REEL', 1, 32, 9999, 1, 3, 42, 146, '1998-01-01', 'For Joyce and Jack Brown who celebrated their Diamond Wedding

in 1998.', 53, '846/864/880/844', 0, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (6206, '2002-03-02 23:00:00+00', '2020-01-26 00:07:48.301862+00', 'Sound of Iona, The', 'SOUND OF IONA', 3, 32, 9999, 1, 3, 42, 13, '1979-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11829, '2004-10-31 23:00:00+00', '2020-01-26 08:55:04.246754+00', 'This One''s Four Isobel', 'THIS ONES FOUR ISOBEL', 3, 32, 9999, 4, 54, 2, 2677, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7397, '1997-04-04 22:00:00+00', '2020-01-26 16:17:46.883989+00', 'Flower of The Queen, The', 'FLOWER OF THE QUEEN', 3, 32, 9999, 1, 3, 42, 173, '1975-09-12', '', 69, '880/888/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19837, '2020-01-26 17:02:01.775466+00', '2020-01-26 17:07:19.511065+00', 'Steve Wyrick''s Fiddle', 'STEVE WYRICKS FIDDLE', 2, 32, NULL, 1, 3, 42, 11861, '2019-01-01', '', 63, '844/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19832, '2020-01-19 11:37:47.156457+00', '2020-02-03 22:12:29.527208+00', 'Bealach na Ba', 'BEALACH NA BA', 3, 32, NULL, 1, 3, 42, 2973, '2019-09-01', 'Bealach na Ba is a mountain pass in north-west Scotland reached by a zig-zagging road.  The name means ‘pass of the cattle’ in Gaelic. The dance and tune were commissioned by Katherine and Justin

Giacoletti with a donation to Pinewoods Camp, which contains many of their favorite zig-zag paths and

fondest memories, and is being published to celebrate their 25 th wedding anniversary.', 53, '880/844/844/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11821, '2004-10-21 22:00:00+00', '2020-12-29 11:41:39.05721+00', 'Drumadoon Bay', 'DRUMADOON BAY', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 63, '844/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19898, '2020-03-23 17:39:31.175445+00', '2020-08-08 23:59:52.866998+00', 'Corona Virus Reel, The', 'CORONA VIRUS REEL', 1, 32, NULL, 2, 3, 17, 11925, '2020-03-15', 'No hands are given during dance at all.', 75, '808/888/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10928, '2002-11-13 23:00:00+00', '2021-04-03 12:18:28.988503+00', 'Forrest Lassies, The', 'FORREST LASSIES', 1, 32, 9999, 4, 4, 1, 3216, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (365, '1998-07-08 22:00:00+00', '2020-10-13 18:18:50.449249+00', 'Ballemuir Strathspey, The', 'BALLEMUIR STRATHSPEY', 3, 32, 9999, 1, 100, 2, 108, '1993-01-01', '', 81, '8448/8888/8888/0880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17146, '2016-07-12 22:13:13.504009+00', '2020-10-21 20:16:28.317564+00', 'Peep at the Jubilee, A', 'PEEP AT THE JUBILEE', 1, 32, NULL, 1, 3, 42, 9998, NULL, 'A reel in 2/4 time from "Twenty Four Country Dances For the Year 1770", and taught by Jimmie Hill', 30, '550/550/802/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20157, '2020-12-07 18:09:11.577826+00', '2020-12-07 18:09:11.577826+00', 'Salute to Wigtown', 'SALUTE TO WIGTOWN', 2, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10438, '2002-04-24 22:00:00+00', '2021-01-18 23:22:41.966905+00', 'Starry Eyed Laddie, The', 'STARRY EYED LADDIE', 2, 32, 9999, 3, 5, 7, 2973, NULL, 'Adapted from the Starry-Eyed Lassie - RSCDS Book 23', 85, '86860/88888/88888/60688', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12092, '2005-03-16 23:00:00+00', '2021-01-16 19:25:40.379241+00', 'Deil amang the Heather, The', 'DEIL AMANG THE HEATHER', 1, 32, 9999, 2, 3, 17, 1047, '1998-09-14', 'Dedicated to Val Spittle.', 63, '840/880/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7247, '1998-09-29 22:00:00+00', '2022-10-23 20:41:58.530036+00', 'Yellow-Haired Laddie, The', 'YELLOWHAIRED LADDIE', 100, 64, 9999, 1, 4, 1, 198, '1725-01-01', '', 30, '8000/8000/0800/0800/8000/8000/8440/8004', 1, 1, 0, 0, 29);
INSERT INTO 'dance' VALUES (10884, '2002-10-23 22:00:00+00', '2022-12-22 18:29:40.453132+00', 'Nina Foulkes'' Reel', 'NINA FOULKES REEL', 1, 32, 9999, 4, 4, 46, 725, NULL, 'Ruary writes:  Circle round & back Advance & retire twice Turn partner RH and back LH 1st cpl dance through, cast down and lead back', 81, '8888/8888/8888/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3792, '1998-07-08 22:00:00+00', '2021-05-15 11:17:01.354311+00', 'Leven Bridge', 'LEVEN BRIDGE', 1, 32, 9999, 1, 4, 11, 372, NULL, 'The River Leven runs through the village of Great Ayton (North Yorkshire).', 88, '8008/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4337, '1997-09-09 22:00:00+00', '2021-04-18 11:05:22.139608+00', 'Merry Uplanders, The', 'MERRY UPLANDERS', 2, 32, 9999, 5, 2, 76, 207, '1983-01-01', 'Dance devised for the pupils of Upland School, Bexley-heath. Music by Robin Ellis.', 81, '88/88/44/66', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (708, '1998-01-11 23:00:00+00', '2021-06-29 09:42:10.191695+00', 'MacLeod''s Tables', 'MACLEODS TABLES', 2, 32, 9999, 1, 3, 42, 175, '1994-01-01', 'MacLeod''s Tables are twin hills south-west of Dunvegan, on the isle of Skye.', 56, '888  808  800  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (20476, '2021-09-12 10:35:24.629964+00', '2021-09-12 10:35:24.629964+00', 'Charles and Tomoko', 'CHARLES AND TOMOKO', 3, 32, NULL, 2, 3, 17, 2682, '2020-11-16', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17309, '2016-09-09 10:03:19.059079+00', '2020-01-27 11:37:14.269713+00', 'Speedy Life in Paris', 'SPEEDY LIFE IN PARIS', 1, 32, NULL, 1, 3, 42, 11346, NULL, 'On 2020-01-25 the question was put to Alienor: i\Is this dance a reel or a jig?  Your book, both the original and the second edition, have it as a reel; the recommended music at http://music.rscdsparis.fr/files/SpeedyLifeInParis.pdf is definitely a jig.  In correspondance in March 2016, there were several mentions of this dance, both as jig and , but the outcome seemed to be reel. Now the deviser has replied that it is now a Jig.



Today 2020-01-27 the book editor, Aliénor, added:  There was some debate recently about this particular mistake. As the editor, I think the dance should stay a reel. The deviser''s opinion was to go for what causes the least trouble.  I have asked the composer to write an actual reel, which will be published as soon as she agrees.







', 47, '800/822/866/866', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13934, '2011-08-22 22:00:00+00', '2020-01-28 21:41:34.001947+00', 'Windswept Moors, The', 'WINDSWEPT MOORS', 3, 32, NULL, 2, 3, 17, 146, NULL, '', 69, '808  880  822  868', 0, 1, 1, 0, 68);
INSERT INTO 'dance' VALUES (10482, '2002-04-19 22:00:00+00', '2020-02-01 01:58:34.86263+00', 'Ladies and Gents', 'LADIES AND GENTS', 1, 40, 9999, 1, 3, 42, 1394, '1998-09-29', 'Devised to give equal time to Men''s and Ladies'' Chains', 40, '840/880/804/808/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14182, '2011-08-26 22:00:00+00', '2020-02-01 02:21:34.690567+00', 'Dancing Piper, The', 'DANCING PIPER', 1, 32, NULL, 1, 3, 42, 127, NULL, 'Dance devised for Jimmy Reid, ex Black Watch Piper



', 56, '880/888/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19838, '2020-01-29 22:53:36.828844+00', '2020-01-29 23:31:03.508793+00', 'Middleton High', 'MIDDLETON HIGH', 3, 32, NULL, 5, 1, 4, 2488, '2005-06-01', 'Mixer Strathspey.  Single circle Round the Room of couples facing in, M on L of W.    

Best for five couples or more – minimum three, with 4 couples the progression fails.   

Composed for fundraising performance by Middleton High School (Wisconsin) for drama students attending that year''s Edinburgh Fringe Festival.   







', 94, '34/43/44/44', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13583, '2010-08-07 22:00:00+00', '2020-01-30 10:41:42.57158+00', 'Forty-five Years On', 'FORTYFIVE YEARS ON', 1, 40, NULL, 1, 4, 1, 3384, '2009-01-01', '', 59, '8008/8888/8448/8220/8002', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (1114, '2000-09-02 22:00:00+00', '2020-01-31 18:04:33.572943+00', 'Celebration Jig, The', 'CELEBRATION JIG', 2, 32, 9999, 1, 3, 42, 146, '1994-01-01', '', 66, '826/888/866/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19841, '2020-02-04 10:07:28.056673+00', '2020-02-11 15:37:37.200152+00', 'Fools of Rogie, The', 'FOOLS OF ROGIE', 1, 32, NULL, 1, 100, 2, 2169, NULL, 'This dance is for Lois New and the Albany, NY class of the Boston Branch.  The Falls of Rogie has long been a favorite at their balls. We thought they might like something a little different for the encore.', 81, '8008/8888/8888/8448', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3479, '1998-01-05 23:00:00+00', '2020-02-01 09:17:28.736598+00', 'Kinburn Park', 'KINBURN PARK', 1, 40, 9999, 1, 3, 42, 1043, NULL, 'Kinburn Park lies between University Hall of St Andrews University and the various halls where Summer School classes are held. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19839, '2020-02-01 17:36:51.829655+00', '2020-02-01 17:36:51.829655+00', 'Twyford Down', 'TWYFORD DOWN', 3, 32, NULL, 2, 3, 17, 10338, '2015-05-01', '', 92, '888/888/448/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19840, '2020-02-01 17:40:15.167777+00', '2020-02-01 17:40:15.167777+00', 'It''s a Cinch', 'ITS A CINCH', 1, 32, NULL, 7, 113, NULL, 10338, '2019-09-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1273, '1997-04-03 22:00:00+00', '2020-02-04 02:54:02.249144+00', 'Coilsfield House', 'COILSFIELD HOUSE', 3, 32, 9999, 1, 4, 1, 173, '1967-09-09', 'In the Howick Club''s first collection of Alec''s dances, the instructions of this dance have an error for 1c on [29-32] (lead down instead of cast) ', 88, '8888/8888/8888/8080', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14709, '2013-02-01 10:53:21.695863+00', '2020-02-02 10:35:32.346362+00', 'Ruby Revels', 'RUBY REVELS', 1, 32, NULL, 2, 3, 17, 3317, NULL, '', 83, '880/888/808/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13837, '2011-08-21 22:00:00+00', '2020-02-02 11:03:43.143639+00', 'Alexanders'' Ruby', 'ALEXANDERS RUBY', 3, 40, NULL, 2, 3, 17, 872, '1996-01-01', 'Devised in 1996 for the Ruby Wedding Anniversary of Rona and Charlie Alexander, long standing members of the Bournemouth Branch.  Some sources misspell the dance''s name as Alexander''s Ruby.



The original instructions do not say how the Grand Chain starts.  To avoid confusion, the cribs have added a choice.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2247, '1997-09-02 22:00:00+00', '2020-02-03 15:08:33.10423+00', 'Flower of Yarrow, The', 'FLOWER OF YARROW', 3, 32, 9999, 2, 3, NULL, 13, NULL, '', 63, '800/822/877/837', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8312, '1998-01-12 23:00:00+00', '2020-02-04 01:55:05.152988+00', 'Spanish Four', 'SPANISH FOUR', 3, 32, 9999, 1, 2, 76, 2018, NULL, 'The instructions for the Espagnole [25-32] differ from the official RSCDS version: both the W and M, when leaving the W side, have NHJ instead of RHJ.   ', 30, '66/66/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (624, '1997-04-03 22:00:00+00', '2020-02-06 15:05:38.363758+00', 'Bold Mary', 'BOLD MARY', 1, 32, 9999, 1, 3, 42, 51, NULL, 'The dance is dedicated to Dwayne and Mary McQuilliams, and to the boat they live on, Bold Mary.', 41, '800/822/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15656, '2014-10-04 01:05:58.508451+00', '2020-02-12 09:27:51.728847+00', 'Mrs Rae of Westerton', 'MRS RAE OF WESTERTON', 3, 32, NULL, 2, 3, 17, 11021, '2006-10-12', 'Devised by Marion McIntosh, the current dance teacher at Westerton, for 12th October 2006 - The 75th Anniversary of the founding, by Janet Rae, of Westerton Scottish Country Dance Club.    



Mrs Rae attended one of Miss Milligan''s classes in the city of Glasgow, and persuaded her to come to Westerton with a few of her stalwarts to set up the club. It was only a small wooden hut at the time, and so many people turned up that half of them had to dance outside in the street.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5757, '1997-04-03 22:00:00+00', '2020-03-21 08:31:32.309231+00', 'Rubber Duck''s Jig, The', 'RUBBER DUCKS JIG', 2, 32, 9999, 3, 5, 16, 48, NULL, '', 70, '48884/88888/08880/00808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20158, '2020-12-07 18:10:34.542349+00', '2020-12-07 18:10:34.542349+00', 'Siesta Key Jig, The', 'SIESTA KEY JIG', 2, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14904, '2013-05-27 16:46:51.286213+00', '2020-10-02 09:36:36.382827+00', 'Silverwood', 'SILVERWOOD', 3, 32, NULL, 3, 5, 7, 10430, NULL, 'Suggested music:

"5x32 Strathspeys", on Miss Ogilvie''s Fancy, by Green Ginger', 88, '88880/88888/86866/86866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19899, '2020-03-23 17:47:30.256385+00', '2020-11-28 11:03:35.008027+00', 'Coronadance', 'CORONADANCE', 1, 48, NULL, 4, 4, 13, 11926, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20178, '2020-12-07 20:00:14.959056+00', '2020-12-07 20:00:43.009216+00', 'Please Join the Dance', 'PLEASE JOIN THE DANCE', 3, 40, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1701, '1997-04-03 22:00:00+00', '2021-05-21 07:44:45.233421+00', 'Dorothy''s Wedding', 'DOROTHYS WEDDING', 1, 32, 9999, 1, 3, 42, 13, NULL, 'The figures of this dance represent the bride and groom first with their own families, then meeting each other''s; the wedding procession and a true lover''s knot.', 63, '888/888/880/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20179, '2020-12-07 20:01:44.396369+00', '2020-12-07 20:01:44.396369+00', 'Dance From the North', 'DANCE FROM THE NORTH', 1, 32, NULL, 1, 2, 76, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4199, '1997-10-27 23:00:00+00', '2020-03-09 10:53:04.42163+00', 'Martlets Reel', 'MARTLETS REEL', 2, 40, 9999, 1, 3, 42, 270, NULL, '10 bar phrases', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10772, '2002-09-25 22:00:00+00', '2021-02-05 12:58:52.043157+00', 'Eight of Diamonds, The', 'EIGHT OF DIAMONDS', 1, 32, 9999, 107, 122, 30, 175, NULL, 'The reprint of the 5th Carnforth book add the note  "Note that dancers number 2 and 3 simply change places with each other every 32 bars."  The other dancers thus return to places after 6 times through.



If [31-32] is replaced by "the new centres change places" the progresssion goes fully round in 8 times through"', 69, '48848448/88808088/08888808/44462642', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14536, '2012-08-15 09:09:26.149881+00', '2020-02-05 15:54:41.964458+00', 'Orwell Lodge Strathspey', 'ORWELL LODGE STRATHSPEY', 3, 32, NULL, 2, 3, 17, 550, NULL, '»Dedicated to Jane Purves.«



The author writes:  Please note there is a mistake in Orwell Lodge Strathspey as published in the Jubilee book.   On bar 16 there is no right shoulder pass - first couple just finish the second half reel on the sidelines.   See http://scottishdance.net/dances/Book/OrwellLodgeStrathspey.pdf   (This is Ian''s site.).



Note (additional to the book and the Manual). collected by Helen Russell from staff teaching The Diamond Jubilee book at Summer School 2012. 



13 -16   1st couple dance a half reel of four with second corners and finish all on opposite sides in the order 3,1,2. 1.st couple do not pass by the right as stated in the original instructions.



27 -28   2nd couple must turn once round in two bars.



', 79, '880  844  888  848', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (3168, '1997-09-04 22:00:00+00', '2020-02-05 16:31:41.21792+00', 'Itchenor Reel', 'ITCHENOR REEL', 1, 32, 9999, 1, 4, 1, 1014, '1988-01-01', 'Written for the West Wittering Reel Club.', 84, '8888/8888/2882/0888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10694, '2002-07-21 22:00:00+00', '2020-02-07 00:26:54.453893+00', 'Friday the 13th', 'FRIDAY THE 13TH', 2, 32, 9999, 4, 4, 4, 2961, NULL, 'Deviser''s Notes: Easy / Mmoderate dance. Couples will change partners after the each time through. This

dance adds interest by mixing couples up and getting them back together without being too difficult for less

experienced dancers.', 62, '8080/0808/8888/4444', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11171, '2003-02-12 23:00:00+00', '2020-02-10 09:48:02.8168+00', 'Bluebells of Brownsham, The', 'BLUEBELLS OF BROWNSHAM', 3, 48, 9999, 1, 114, 2, 3314, NULL, 'Devised for Julia and Anthony Barnes. Music composed by Josephine Pickering.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15331, '2014-01-22 10:31:06.51848+00', '2020-02-08 13:21:47.355604+00', 'First Snowdrops', 'FIRST SNOWDROPS', 2, 32, NULL, 1, 2, 76, 10913, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (184, '2003-01-28 23:00:00+00', '2020-02-07 21:20:01.076309+00', 'Anniversary Reel, The', 'ANNIVERSARY REEL', 1, 48, 9999, 1, 3, 42, 35, NULL, 'Written in honour of the 25th Wedding Anniversary of Catherine and John Prentice  



Legend:  

1-8 Catherine Simpson and John Prentice were married in Edinburgh, Scotland, 25 years ago, starting

out hand in hand looking hopefully to the future.  

9-20 In due time Brian and Heather came along and tagged after mother and father.  

21-24 They crossed the ocean and made a new place for themselves in Canada.  

25-48 They look back on 25 years of happy involvement with family, an ever-widening circle of friends,

and their special love, Scottish Country Dancing.



Note: No e-crib has been made as the instructions are not clear enough.', 55, '800/808/737/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15570, '2014-08-20 11:42:35.746387+00', '2020-02-08 13:40:27.939121+00', 'Snow in October', 'SNOW IN OCTOBER', 3, 32, 9999, 1, 2, 76, 10913, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9860, '2001-06-04 22:00:00+00', '2020-02-08 19:52:11.486729+00', 'Geoff of Morland', 'GEOFF OF MORLAND', 2, 32, 9999, 1, 100, 11, 2891, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7577, '2002-04-08 22:00:00+00', '2020-02-08 20:03:31.452543+00', 'Margaret Williams'' Strathspey', 'MARGARET WILLIAMS STRATHSPEY', 3, 32, 9999, 1, 100, 2, 127, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7215, '1998-07-08 22:00:00+00', '2020-02-08 20:06:23.903192+00', 'Wolf''s Return to Badenoch, The', 'WOLFS RETURN TO BADENOCH', 1, 32, 9999, 1, 100, 2, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Jennifer Wilson of Elgin.



He also adds the note: *When "leading out" in second and 3rd positions during the double figure

of eight (Bars 9-16), 1st and 4th couples, and 2nd and 3rd couples

can join hands very briefly with the other man or woman.*', 88, '8888/8888/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1001, '1998-04-05 22:00:00+00', '2020-02-08 20:27:40.796498+00', 'Capercaillie, The', 'CAPERCAILLIE', 2, 32, 9999, 1, 100, 2, 313, NULL, '', 69, '8008  8448  8448  8448', 0, 1, 0, 0, 68);
INSERT INTO 'dance' VALUES (694, '1998-07-08 22:00:00+00', '2020-02-08 20:33:16.954365+00', 'Border Barque, The', 'BORDER BARQUE', 3, 40, 9999, 1, 100, 11, 313, NULL, '', 75, '8888  0880  0880  4884  8888', 1, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (551, '1998-07-08 22:00:00+00', '2020-02-08 20:36:44.021323+00', 'Black Potts', 'BLACK POTTS', 3, 32, 9999, 1, 100, 2, 104, '1987-01-01', '', 88, '8888  4444  8888  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (4209, '1999-04-21 22:00:00+00', '2020-02-09 21:25:11.107531+00', 'Mary Hamilton', 'MARY HAMILTON', 3, 32, 9999, 1, 100, 2, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for the members of the Hamilton, Ontario Branch of the RSCDS.', 94, '8888/8888/8448/8888', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (16876, '2016-02-25 00:31:20.9174+00', '2020-02-10 00:48:55.552435+00', 'Joanna''s Jig', 'JOANNAS JIG', 2, 32, NULL, 5, 2, 4, 3379, NULL, '2 facing 2 round the room with women on the man’s right. 

1st couple are facing anti-clockwise and 2nd couple are facing clockwise.



Devised for the deviser’s wife Joanna.



Original tune: “Gary and Joanna Coull’s Wedding” by James Alexander.

', 75, '88/80/08/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5063, '1997-09-10 22:00:00+00', '2021-08-09 07:39:03.249451+00', 'Old Mill', 'OLD MILL', 2, 32, 9999, 1, 3, 42, 480, '1983-05-30', 'The Tuesday night Scottish class in Burlington VT is held at DVM in the Old Mill, a classroom building with no water wheel.', 53, '880/808/840/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8505, '2002-03-11 23:00:00+00', '2020-02-09 19:04:21.694857+00', 'Lydia''s Lilt', 'LYDIAS LILT', 1, 32, 9999, 1, 100, 2, 28, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15649, '2014-10-01 23:35:56.060058+00', '2020-02-10 15:46:59.072657+00', 'Water of Leith, The', 'WATER OF LEITH', 3, 32, 9999, 1, 4, 2, 515, NULL, '', 56, '8080/8080/8484/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9634, '2002-04-10 22:00:00+00', '2020-02-10 11:37:18.942489+00', 'Findlays'' Jig, The', 'FINDLAYS JIG', 2, 32, 9999, 1, 3, 42, 146, '2000-01-01', 'For Faustina and Ian Findlay.', 50, '800  888  440  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (4435, '1997-12-28 23:00:00+00', '2020-02-10 15:42:01.348538+00', 'Busy Ann', 'BUSY ANN', 2, 32, 9999, 1, 2, 76, 872, NULL, '', 69, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10855, '2002-11-01 23:00:00+00', '2020-02-10 15:43:59.873549+00', 'Snowdrops', 'SNOWDROPS', 3, 32, 9999, 2, 3, 17, 227, '1999-02-01', 'This dance is meant as an exercise in Grand Chain and in Rights and Lefts with a lot of attention for the giving of hands and the polite turns.  When I wrote it, the snowdrops were popping up around my house.', 58, '800  888  800  808', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (8481, '1997-12-28 23:00:00+00', '2020-02-10 15:51:09.610829+00', 'Golden Bracken (24-bar version)', 'GOLDEN BRACKEN 24BAR VERSION', 1, 24, NULL, 1, 3, 42, 872, NULL, 'This dance was originally published in "Stepping Out Part 3" as a 24-bar dance, and later republished in "A Second Graded Book" with an added "circle and back" at the end, making it a 32-bar dance.', 46, '800  844  866', 1, 1, 1, 1, 61);
INSERT INTO 'dance' VALUES (652, '1998-09-29 22:00:00+00', '2020-02-10 21:02:37.539376+00', 'Bonnie Ina Campbell', 'BONNIE INA CAMPBELL', 3, 32, 9999, 1, 3, 42, 417, NULL, 'George Will is from the Vancouver Branch', 56, '800/888/888/844', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (8600, '1998-01-13 23:00:00+00', '2020-03-05 00:28:30.174829+00', 'Drookit Mousie, The', 'DROOKIT MOUSIE', 3, 32, 9999, 1, 2, 76, 2018, NULL, '', 52, '88/80/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (212, '1998-07-08 22:00:00+00', '2020-05-15 14:54:34.040191+00', 'Ardgilzean', 'ARDGILZEAN', 3, 32, 9999, 1, 100, 2, 108, '1975-02-02', '', 81, '8008  8888  8888  8448', 0, 1, 0, 0, 81);
INSERT INTO 'dance' VALUES (19900, '2020-03-23 17:52:02.105541+00', '2020-08-12 07:46:46.661553+00', 'Hand Sanitizer Strathspey, The', 'HAND SANITIZER STRATHSPEY', 3, 32, NULL, 2, 3, 18, 11927, NULL, 'The standard figures such as "hands round" and poussette are here danced without taking hands.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20088, '2020-09-30 13:38:55.866551+00', '2020-10-05 17:03:18.835159+00', 'Donna''s Dancing Shoes', 'DONNAS DANCING SHOES', 1, 32, NULL, 1, 3, 42, 10907, '2014-02-01', 'Devised to celebrate the wedding of Donna Rynne and John Boyle in February 2014.', 50, '800/888/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20159, '2020-12-07 18:11:30.563217+00', '2020-12-07 18:11:30.563217+00', 'Trillium Jig, The', 'TRILLIUM JIG', 2, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13821, '2011-08-04 22:00:00+00', '2020-02-13 16:42:44.099566+00', 'Ullinish Lodge', 'ULLINISH LODGE', 3, 32, NULL, 4, 2, 46, 2245, NULL, 'The square set has four couples, but at any time (except for the final 4 bars) only 1c+3c or 2c+4c are dancing.  ', 53, '8080/8080/8080/8080 ending 8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1569, '1997-04-03 22:00:00+00', '2020-02-13 16:53:37.929983+00', 'David Findlay''s Jig', 'DAVID FINDLAYS JIG', 2, 32, 9999, 1, 4, 1, 94, NULL, '', 91, '8888/8888/0884/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15633, '2014-09-29 13:14:34.80428+00', '2020-02-12 14:54:30.137178+00', 'Welcome to Bridport', 'WELCOME TO BRIDPORT', 1, 32, NULL, 1, 3, 42, 2893, '2000-06-30', 'Devised by Leslie Broughton in June 2000.  Leslie was a long-standing member of the group, who provided a new dance for every occasion!', 73, '886/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15632, '2014-09-29 13:08:24.971214+00', '2020-02-12 14:59:51.337016+00', 'St. Michael''s Jig', 'SAINT MICHAELS JIG', 2, 32, NULL, 1, 4, 2, 11006, '1998-01-01', 'Robert Dawson, one of the original members of the group. Together with his wife, Margaret, Robert staged many dances for charity, and he particularly enjoyed researching lesser known dances for these events. Unfortunately for Bridport Scottish Dancers, the Dawsons now live by the Moray Firth.', 94, '8888/8888/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13507, '2009-11-21 23:00:00+00', '2020-02-13 00:42:48.32019+00', 'Whale''s Moo, The', 'WHALES MOO', 1, 32, 9999, 1, 3, 42, 1269, '2007-01-01', 'Whale''s Moo is a rock formation along the Moray coastline in Portknockie. The huge stack is connected to another formation by a sloping rock arch, variously described as a sinking ship, bow and fiddle or a whale''s tail.  Variously called the Whale''s Mouth, Whale''s Moo, or Faal''s Moo - it resembles the open mouth of a singing whale. 



The Whale''s Moo is a cave which penetrates the buttress with openings on both the shore and seaward sides thus making a natural archway. A large pool to the right of the beach opening is the Whale''s Moo Pot.', 53, '800/844/888/488', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11181, '2003-02-12 23:00:00+00', '2021-01-11 12:56:45.033545+00', 'Ropemakers'' Strathspey, The', 'ROPEMAKERS STRATHSPEY', 3, 40, 9999, 1, 4, 1, 3318, '2002-03-01', '1-8     Represents *stretching the flax.*  

9-16   Represents *spinning the flax into cord.*  

17-24 Represents *walking the ropes (setting up the cord on a ropewalk).*  

25-32 Represents *twisting the cords into ropes/hawsers.*  

33-40 Represents *the finished rope/hawser.*  



Devised by Sarah Prone Ashby (formerly Prone) to commemorate the rope-making tradition in the town of Bridport, Dorset, home of Bridport Scottish Country Dancers.', 75, '4444/8888/8888/8440/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15637, '2014-09-29 13:39:58.877002+00', '2020-02-12 16:33:44.24718+00', 'Bridport Reel of Seven', 'BRIDPORT REEL OF SEVEN', 1, 96, NULL, 107, 112, 3, 11009, '2003-06-01', 'A demonstration dance for three men and four women to accommodate an extra woman.  



To start, 2M is in the middle, the other form a circle around him.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15654, '2014-10-04 00:43:41.665849+00', '2020-02-12 16:41:37.836268+00', 'Bus Pass, The', 'BUS PASS', 2, 32, NULL, 1, 3, 42, 11019, '2010-11-01', '1 - 4    The ladies waiting for the bus (the men)



5 - 8    The ladies getting on the bus after dancing for joy having waited for so long for one to come along.



9 - 16  Travelling on the bus.



17-20  The wheels of the bus.



21-24  The BUS PASS.



25-32  Leaving the bus and returning home after the journey', 64, '666/888/888/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11183, '2003-02-12 23:00:00+00', '2020-02-12 16:46:00.560457+00', 'Lannion Link, The', 'LANNION LINK', 3, 40, 9999, 1, 4, 1, 3319, '2002-01-01', 'Devised by Caroline Morgan-Smith to celebrate the 2002 visit of the Scots Bonnet Club of Lannion to Bridport... Revised December 2016.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20161, '2020-12-07 18:13:27.946533+00', '2020-12-07 18:13:27.946533+00', 'Loyalist Jig, The', 'LOYALIST JIG', 2, 32, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19155, '2019-01-17 10:04:59.451238+00', '2020-02-15 02:43:29.254473+00', 'Golden Years, The', 'GOLDEN YEARS', 3, 32, NULL, 1, 3, 42, 209, '1995-03-16', 'Dedicated to Mac and Mary Gray on the occasion of their 50th Wedding Anniversary 16th March, 1995.

The dance depicts:

1-8 The marriage of Mac & Mary.

9-16 Their journey to Canada.

17-32 Their unending help, support and encouragement shown to each other, their family and to all people they have encountered, whether Scottish country dancers, work colleagues, skaters, or students.', 62, '8000/8880/8440/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13985, '2011-08-24 22:00:00+00', '2020-02-16 01:33:52.9687+00', 'Reel for Poggy, A', 'REEL FOR POGGY', 1, 40, NULL, 1, 2, 76, 954, NULL, 'The reels in this dance are like the reels in ''''The Lads of Saltcoats" in Miss Milligan''s Miscellany,

Volume 2. Bars 27-32 are like a figure danced often in English Country dancing, "three changes

of a circular hey." I was looking for an interesting two-couple dance that ends with a circle. I

love dances that end with circles.



The dance was used by the San Francisco Scottish Country Dance Class adjudication team at

the Pleasanton Scottish Games in 2002. The dance is named in memory of my mother, known

by everyone as "Poggy".-SLK', 55, '80/84/84/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15130, '2013-09-20 14:54:52.362458+00', '2020-02-16 01:35:33.086405+00', 'Carding of the Wool', 'CARDING OF THE WOOL', 2, 32, 9999, 1, 4, 1, 10860, NULL, '', 72, '8888/8000/8444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20411, '2021-07-30 09:14:21.710569+00', '2021-07-30 09:14:21.710569+00', 'Merry Marian', 'MERRY MARIAN', 1, 0, NULL, NULL, NULL, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19901, '2020-03-23 18:45:47.79777+00', '2020-08-12 09:36:16.440789+00', 'No Hands!', 'NO HANDS', 3, 40, NULL, 2, 3, 18, 10568, NULL, '', 69, '844/888/844/888/800', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20180, '2020-12-07 20:15:45.20059+00', '2020-12-07 23:23:11.990623+00', 'Dither, The', 'DITHER', 1, 32, NULL, 2, 3, 17, 10971, NULL, '', 67, '800/888/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6464, '1997-09-14 22:00:00+00', '2021-04-17 20:25:32.05794+00', 'Tapsalteerie', 'TAPSALTEERIE', 1, 40, 9999, 107, 6, 89, 82, NULL, 'For two side-by-side three couple sets. After each turn, men and women have swapped sides. Six turns are needed so that everyone dances as a centre dancer.', 67, '444444/008800/888888/444444/888888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20303, '2021-04-05 09:11:36.406762+00', '2021-04-06 23:28:26.130955+00', 'Lambton Worm, The', 'LAMBTON WORM', 1, 32, NULL, 1, 3, 42, 11029, NULL, 'The Lambton Worm is a well-known folk song from County Durham and is from close to Chester-le-Street inland from Sunderland, near where I was born. The song is at the end of this Book.', 63, '888/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15631, '2014-09-29 13:04:36.944714+00', '2021-08-02 19:41:01.822099+00', 'Fox on the Hill, The', 'FOX ON THE HILL', 3, 32, NULL, 1, 3, 42, 1904, NULL, '', 47, '880/800/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20477, '2021-09-12 10:41:12.129497+00', '2021-09-12 10:41:12.129497+00', 'Spanish Ghost', 'SPANISH GHOST', 3, 32, NULL, 1, 4, 1, 2682, '2020-11-08', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11047, '2002-11-24 23:00:00+00', '2020-02-26 12:01:40.695829+00', 'Wagonwheel Strathspey', 'WAGONWHEEL STRATHSPEY', 3, 80, 9999, 4, 4, 3, 3255, '1988-01-01', 'Devised by Elsie Fourie (née Scott, born near Aberdeen), Pretoria, South Africa; 1988



The winning entry in the competition held by the Pretoria Branch to submit a dance to the RSCDS for publication in their booklet of dances from around the world, "Frae A'' The Airts".



In commemoration of early South African pioneers who trekked in ox-wagons to the interior of the country and crossed over the Drakensberg Mountains. The ox-wagon is symbolic to South Africa and the Voortrekker Monument is surrounded by a wall of 64 stone ox-wagons depicting the laager of wagons which the pioneers formed when in fear of an attack. The formations in the dance represent the turning of the wheels and the spokes of the wheels.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3896, '1998-07-06 22:00:00+00', '2020-03-09 11:02:09.157951+00', 'Lodge Hill', 'LODGE HILL', 2, 64, 9999, 3, 5, 7, 270, NULL, '', 67, '88886/84844/84884/82842/80800/84844/84884/80800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16011, '2015-02-09 13:38:55.867639+00', '2022-05-07 21:48:00.356655+00', 'Sky Top Jig, The', 'SKY TOP JIG', 2, 32, 9999, 2, 2, 76, 11070, '2000-01-01', 'See <<https://my.strathspey.org/dd/issue/2786/|issue 2786>> for some notes about this dance.', 60, '44/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2172, '1997-04-03 22:00:00+00', '2022-08-12 08:29:12.447652+00', 'Fingal''s Fancy', 'FINGALS FANCY', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 56, '844/800/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (533, '1997-08-28 22:00:00+00', '2020-02-17 12:45:34.342553+00', 'Black Bear, The', 'BLACK BEAR', 1, 32, 9999, 1, 3, 42, 695, NULL, 'David Cullison came to Atlanta from Memphis in 1987. He soon won the heart and hand of fellow dancer Nancy Cline, and they were married in a never-to-be-forgotten ceremony under a tree in Cades Cove, Tennessee, on the Saturday of the 1988 Gatlinburg Games. Afterwards, the new Cullisons were piped back across the meadow to the tune ''The Black Bear," chosen in graceful  acknowledgement of those year-round denizens of the Smoky Mountains, and, says David, "Because I like it".



David is the Atlanta Branch''s newest teacher. He attended candidate classes at Thistle School, and passed his preliminary examination in April, 1991. In addition to being a good Scottish country dancer, he has also done some Highland dancing, and enjoys English Country Dancing. He borrowed the central sequence of figures in this dance - ½ ladies'' chain, reel of four, ½ ladies chain - from a Contra Dance. David cautions 2nd couple to stay awake during bars 13-28 as their participation in bars 29-32 is crucial.



', 53, '840/848/808/848', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19845, '2020-02-17 15:31:14.989466+00', '2020-02-17 17:25:53.293297+00', 'Reverend Robin Walford, The', 'REVEREND ROBIN WALFORD', 1, 40, NULL, 1, 3, 42, 11157, '2019-01-01', 'Devised as a tribute to Robin Walford who passed away in January 2020 (having been able to enjoy the dance the previous year).', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2229, '1997-04-03 22:00:00+00', '2020-02-21 09:38:52.861065+00', 'Flirtation Jig, The', 'FLIRTATION JIG', 2, 32, 9999, 1, 3, 42, 259, NULL, 'A 32 bar slow Jig for three couples.', 37, '444/444/660/840', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3558, '1998-09-29 22:00:00+00', '2021-01-09 12:12:32.94997+00', 'Flora, La', 'FLORA', 2, 32, 9999, 1, 3, 42, 483, '1790-02-01', '', 53, '880  800  888  866', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (16892, '2016-03-04 23:59:12.618714+00', '2020-02-19 02:14:49.558128+00', 'Knot on a ferry', 'KNOT ON A FERRY', 1, 32, NULL, 5, 1, 4, 401, NULL, 'Information taken from the Toronto video.', 100, '8/8/8/8', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5497, '1998-11-29 23:00:00+00', '2020-02-20 22:09:04.305654+00', 'Red House', 'RED HOUSE', 1, 40, 9999, 1, 2, 76, 446, '1731-01-01', 'The RSCDS published Red House as 40 bars. For a wide ranging discussion of the 48 bar version mentioned in some versions of Playford and implications for the music, see this <<sspey-thread:24426|Strathspey mailing list thread>>.', 41, '80  80  80  84  84', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (19847, '2020-02-19 21:31:35.506252+00', '2020-02-20 22:58:21.668283+00', 'Margaret Allen of Cumbrae', 'MARGARET ALLEN OF CUMBRAE', 1, 32, NULL, 1, 3, 42, 2787, NULL, 'Devised for Mrs Margaret Allen. For many years Margaret has been the teacher and mainstay of the Cumbrae Scottish Country Dancing Association, affiliated to the Royal Scottish Country Dance Society. Margaret also teaches a weekly class in Largs. In 2006 she started the Millport Weekend, now a regular event in the country dance calendar. The traditional tune was arranged by Meryl Thomson.', 50, '800/844/888/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19846, '2020-02-19 04:59:06.017386+00', '2020-02-19 05:23:58.113105+00', 'Third Time Lucky', 'THIRD TIME LUCKY', 3, 32, NULL, 2, 3, 17, 3342, NULL, '', 63, '804/880/844/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8380, '2002-03-03 23:00:00+00', '2020-02-19 12:51:40.386202+00', 'Inveralmond Reel, The', 'INVERALMOND REEL', 1, 32, 9999, 1, 3, 42, 2986, '1994-01-01', 'To celebrate the 10th anniversary of the Branch Class held at Inveralmond  Community High School.', 72, '866/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19850, '2020-02-20 11:42:11.013081+00', '2020-02-20 11:42:11.013081+00', 'Peggy of Rossmay', 'PEGGY OF ROSSMAY', 3, 32, NULL, 2, 3, 18, 9998, NULL, 'Devised by a member of the Helensburgh and District branch (see <<http://rscds-helensburgh.org.uk/photos-2/video/>>). Information derived from their video.', 75, '800/888/880/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7575, '2001-12-17 23:00:00+00', '2020-02-21 16:04:14.786706+00', 'Craigmin Brig', 'CRAIGMIN BRIG', 2, 40, 9999, 1, 100, 2, 127, NULL, 'Devised for Sandy Sandison, a Buckie man like myself.



<<https://en.wikipedia.org/wiki/Craigmin_Bridge|Craigmin Brig>>, built in the early 1770''s, is a wildly picturesque, two-storeyed, wavy parapeted practical folly, which stands at the entrance to Letterfourie House outside Buckie.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19849, '2020-02-20 00:38:38.266566+00', '2020-03-01 16:49:01.601194+00', 'Marjory Watson''s Strathspey', 'MARJORY WATSONS STRATHSPEY', 3, 40, NULL, 1, 4, 2, 2890, '2020-01-01', 'Devised for Marjory''s 77th birthday.', 90, '8888/8888/8888/8008/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15963, '2015-02-03 17:39:14.697397+00', '2020-02-21 23:38:49.741413+00', 'John of the Old Mill', 'JOHN OF THE OLD MILL', 3, 32, 9999, 1, 3, 42, 11061, NULL, 'Devised in memory of John Matthew', 47, '800/844/866/808', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2315, '1997-04-03 22:00:00+00', '2020-02-22 00:51:14.20305+00', 'Four Stringer, The', 'FOUR STRINGER', 3, 32, 9999, 1, 3, 42, 129, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3615, '1998-09-29 22:00:00+00', '2021-03-13 16:27:48.614472+00', 'Lady Louisa Macdonald''s Strathspey', 'LADY LOUISA MACDONALDS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 457, '1797-01-01', '', 48, '402  888  844  844', 0, 1, 1, 1, 64);
INSERT INTO 'dance' VALUES (14540, '2012-08-16 20:14:35.066874+00', '2020-03-19 01:13:51.291611+00', 'Tom Cole''s Rant', 'TOM COLES RANT', 2, 32, NULL, 1, 3, 42, 2682, '2011-10-10', 'Modified 2/11/2011. Tom is a very keen dancer and a stalwart of the "advanced" tuesday group. 

A suitable recording is by The Carfuffle Ceilidh Band, Muckle Carfuffle, track 1.', 66, '888/866/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11939, '2004-12-07 23:00:00+00', '2021-05-28 01:03:05.252021+00', 'Cambridge Spring Fling, The', 'CAMBRIDGE SPRING FLING', 1, 40, 9999, 1, 3, 42, 854, '2004-01-01', '', 69, '800/844/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (802, '2001-03-13 23:00:00+00', '2021-06-28 10:35:17.19214+00', 'Trip to Paradise', 'TRIP TO PARADISE', 3, 32, 9999, 1, 3, 42, 401, '1998-10-13', '', 63, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11370, '2003-06-26 22:00:00+00', '2020-02-28 17:19:34.298312+00', 'Queen''s Quadrille, The', 'QUEENS QUADRILLE', 1, 128, 9999, 4, 4, 3, 246, '2002-01-01', '##RSCDS-DI:bars:16+96+16', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19851, '2020-02-23 11:17:32.531612+00', '2020-02-23 13:24:51.192873+00', 'Rudyard''s Reel', 'RUDYARDS REEL', 1, 32, NULL, 1, 3, 42, 671, '2015-09-14', 'Music: Kipling’s Rant by Anne Hooper.    

I heard Anne Hooper and Jacqueline Schwab play this tune at a concert of Scottish music in Wellfleet, Mass. and immediately wanted to write a dance to go with it. I hope she approves of the result!    



Note: This is a revised version of the dance (14th September 2015). ', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9531, '2002-09-22 22:00:00+00', '2020-02-25 19:14:44.421767+00', 'North Herts Reel', 'NORTH HERTS REEL', 1, 32, 9999, NULL, NULL, NULL, 308, NULL, 'DANCE WITHDRAWN.



In Feb. 2020 Sue Petyt wrote to the SCDDB editors:



North Herts Reel is missing from my website because it was not very good and didn''t really work very well. Even the most experienced dancers found it impractical so I have abandoned it!



Thank you for your enquiry.  



Keep Dancing  

Sue Petyt  

sue@suepetyt.me.uk

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14851, '2013-05-18 23:51:26.857272+00', '2020-02-22 21:56:12.126513+00', 'Leap in the Dark', 'LEAP IN THE DARK', 1, 40, 9999, 1, 3, 42, 17, '2004-01-01', 'The dance was listed as "Leap in the Dark (McGregor''s)" in Martin Sheffield''s earlier 140 dances collection.



The reason is that Martin Sheffield originally intended to call the dance "McGregor''s Leap", which he found out already existed as the title of a dance. Although the ''working title'' was only used in his own dance group in the very beginning, the add-on "(McGregor''s)" was meant to establish the connection for those who knew the local working title. This add-on was not meant to be a part of the official title.



', 52, '484/444/888/444/884', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19857, '2020-03-02 13:08:06.334704+00', '2020-03-02 13:08:06.334704+00', 'Pika''s Revenge', 'PIKAS REVENGE', 2, 32, NULL, 1, 3, 42, 11370, NULL, '', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20470, '2021-09-11 23:09:59.759207+00', '2021-09-11 23:09:59.759207+00', 'Seventeenth Wing, The', 'SEVENTEENTH WING', 1, 32, NULL, 1, 4, NULL, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3140, '1997-08-21 22:00:00+00', '2023-01-20 11:12:33.521754+00', 'Island Chain, The', 'ISLAND CHAIN', 2, 32, 9999, 1, 3, 42, 108, '1991-07-01', ' Inscribedf "for the dancers in New Zealand".



', 62, '888/844/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11043, '2002-11-24 23:00:00+00', '2020-02-26 13:34:20.316658+00', 'Thursday Evening in Pretoria', 'THURSDAY EVENING IN PRETORIA', 3, 32, 9999, 1, 4, NULL, 3251, '1973-01-01', 'This dance has part A and part B, each 32 bars, and is danced ABAB.  The progressions are 2341 for A ans 2143 for B. That would lead to 3214 at bar 64, with 2+4 not moing.  Needs to be checked.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15965, '2015-02-03 18:10:03.647501+00', '2020-02-23 08:54:28.88722+00', 'Dance for June, A', 'DANCE FOR JUNE', 3, 32, 9999, 1, 3, 42, 2889, '2008-01-01', 'Devised in recognition of June Scott being awarded the RSCDS Scroll.  June was for many years a well known teacher of SCD in East Lothian.', 56, '888/844/880/880', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9291, '2000-01-16 23:00:00+00', '2020-02-23 21:55:33.281424+00', 'Dogsbody', 'DOGSBODY', 3, 32, 9999, 1, 109, NULL, 501, '1995-01-01', 'In memory of Norman Shimkin and other Dogsbodies', -1, '44/', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8525, '2002-04-14 22:00:00+00', '2020-02-28 17:46:56.9164+00', 'Spinning Wheel, The', 'SPINNING WHEEL', 1, 32, 9999, 4, 5, 16, 2078, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20412, '2021-07-30 09:15:12.859857+00', '2021-07-31 08:51:56.261597+00', 'Patrick''s Wee Jaunt', 'PATRICKS WEE JAUNT', 1, 0, NULL, NULL, NULL, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19855, '2020-02-28 11:29:45.1843+00', '2020-02-28 11:31:55.177417+00', 'Sur la Route de la Soie', 'SUR LA ROUTE DE LA SOIE', 1, 32, NULL, 2, 3, NULL, 11922, '2012-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3632, '1997-04-03 22:00:00+00', '2020-02-28 13:59:40.41667+00', 'Lady of the Lake, The', 'LADY OF THE LAKE', 2, 48, 9999, 1, 3, 42, 44, '1964-01-01', '"The Lady of the Lake" was devised for Tom Drysdale and Pam Westwood who were married in 1964 at Knox Presbyterian Church, Wanganui.



At the deviser''s request no crib is available.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8736, '1999-10-24 22:00:00+00', '2020-02-28 17:13:50.533157+00', 'St Andrews Links', 'SAINT ANDREWS LINKS', 2, 40, 9999, 1, 3, 42, 17, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7731, '1997-12-03 23:00:00+00', '2020-02-28 21:32:27.496294+00', 'Golden Belles', 'GOLDEN BELLES', 2, 32, 9999, 1, 4, 22, 28, '1993-03-01', 'Danced on the occasion of the 50th Anniversary of the 37th Northern Ireland Company Girl''s Brigade, Shore Street Presbyterian Church, Donaghadee, March, 1993', 75, '8008/8888/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20162, '2020-12-07 18:26:34.147289+00', '2020-12-07 18:26:34.147289+00', 'Great White North, The', 'GREAT WHITE NORTH', 2, 40, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19843, '2020-02-05 21:34:30.569597+00', '2020-12-24 22:27:15.01107+00', 'Jack-Jack the Incredible', 'JACKJACK THE INCREDIBLE', 1, 32, NULL, 1, 3, 42, 3583, '2018-10-01', 'Dedicated to our younger grandson - after he learns to walk, I hope he will learn to dance!



A freely downloadable recording of music for this dance is available via <<http://www.fiddletree-music.com/johnturner/scdrecordings.html>>', 50, '880/880/880/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18953, '2018-10-12 20:25:28.554955+00', '2020-12-28 11:01:15.617952+00', 'Two Wise Old Owls - male', 'TWO WISE OLD OWLS  MALE', 3, 32, NULL, 1, 3, 42, 558, '2015-09-01', 'Dedicated to Meinhard Reiser for his Two Wise Old Owls anniversary', 50, '822/844/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9487, '2000-09-04 22:00:00+00', '2021-01-19 00:33:41.198529+00', 'Y2Chaos', 'Y2CHAOS', 2, 32, 9999, 1, 4, 1, 2766, '1999-09-01', 'This dance is a lighthearted spoof of the feeling of impending chaos caused by the approaching date 1/1/2000.', 56, '8080/8080/0808/4848', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10285, '2001-12-13 23:00:00+00', '2021-08-06 20:50:49.28112+00', 'Puffin''s Reel', 'PUFFINS REEL', 1, 32, 9999, 1, 3, 18, 2975, '2001-01-01', '', 56, '844/800/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20479, '2021-09-12 12:35:29.550712+00', '2021-09-12 12:35:29.550712+00', 'Best Dolphin in the Pod', 'BEST DOLPHIN IN THE POD', 2, 40, NULL, 1, 4, 11, 2682, '2021-06-18', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19856, '2020-02-29 15:58:12.727058+00', '2020-02-29 16:12:27.670859+00', 'Tower of London, The', 'TOWER OF LONDON', 3, 32, NULL, 4, 4, 13, 11237, '2018-12-01', 'The figure in bars 17-24 is supposed to evoke the central “White Tower” part of the Tower of London with a small tower at each corner all surrounded by an outer wall. The two handed turns represent the towers while the intervening inner and outer chases are the walls. Three of the four towers are square - only the one at the north-east corner (between 1st and 2nd places) is round. So those concerned with architectural exactitude can make their turns at the other corners as square as possible, for example making angles at the half bar points.  Those keen on symbolism may see sceptres and orbs or loops of a crown in bars 1-8 and 9-12. Bars 25-32 were inspired by the end of <<ddd:Vana Tallinn>> by <<ddp:Garbuzov, Vladimir>>.', 88, '4444/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14909, '2013-05-27 22:24:31.782852+00', '2020-02-29 16:19:22.968888+00', 'Blue Butterfly', 'BLUE BUTTERFLY', 3, 32, NULL, 2, 3, 17, 10793, '1999-01-01', 'Unpublished?', 53, '822/888/844/808', 1, 1, 1, 0, 62);
INSERT INTO 'dance' VALUES (15233, '2013-11-12 18:43:05.113443+00', '2020-02-29 23:58:11.123313+00', 'St Andrew''s Square, Edinburgh', 'SAINT ANDREWS SQUARE EDINBURGH', 2, 32, NULL, 4, 4, 1, 523, '2008-11-01', 'Devised to commemorate the restoration of St Andrew''s Square and its opening to the public. The first half of the dance depicts the title, the second half shows how people can move through the Square around the Melville Monument. Bars 9 to 16 are similar to the movement in <<ddd:Follow Me Home>>, and bars 25 to 32 are similar to the first reel-time figure in <<ddd:Schiehallion>>.', 75, '8888/8888/0808/8080', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15246, '2013-11-12 19:32:25.299286+00', '2020-03-01 00:03:18.455805+00', 'Jig for Jim and Joe, A', 'JIG FOR JIM AND JOE', 2, 32, NULL, 3, 5, 7, 518, NULL, 'Dance devised for Jim Gardner and Joe Wake, for a celebration to mark their 70th birthdays. It can also be danced with 7 couples to represent their 70 years,', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17371, '2016-09-16 17:44:53.56554+00', '2020-03-02 13:11:33.517546+00', 'McBains'' Fancy', 'MACBAINS FANCY', 3, 32, NULL, 3, 5, 7, 11364, '1996-04-01', 'To James and Peggy McBain of McBain of Tucson, Arizona in appreciation of their support of Scottish Country Dance and the Seven Pipers Scottish Society, and so much more. James McBain is the 22nd Hereditary Chief of Clan McBain, Worldwide. He and his wife are avid Scottish Country Dancers and

supporters of the Seven Pipers Scottish Society of Tucson and the RSCDS, Tucson Branch.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13915, '2011-08-22 22:00:00+00', '2020-03-02 13:19:04.975118+00', 'Illusive Eclipse', 'ILLUSIVE ECLIPSE', 2, 32, NULL, 1, 3, 42, 3254, '2002-12-01', 'Devised by Terry Lynne Harris. Pretoria, December 2002.  



I wrote this after the total solar eclipse of 4 December 2002. I made the trip to the area of totality in South Africa''s Limpopo Province, but the eclipse proved illusive, thanks to cloud cover and rain. Very disappointing indeed. ', 50, '800/844/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10352, '2002-02-16 23:00:00+00', '2020-03-01 13:48:43.400569+00', 'Hugh Roberts'' Strathspey', 'HUGH ROBERTS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 515, '2001-09-01', 'Hugh Roberts was well known and well loved in Edinburgh and the Lothians.  A mainstay of the Boggs Country Dance Club and other clubs of the district, he helped and encouraged a great many dancers and spectators alike.  He was always smiling and joking and was a great ambassador for the world of Scottish Country Dancing.  Hugh died in August 2001. He will be remembered with great affection by those who knew him.  This dance is devised in his honour.', 69, '844/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8932, '2003-01-02 23:00:00+00', '2020-03-02 22:59:06.963534+00', 'Hyperactive Reel, The', 'HYPERACTIVE REEL', 1, 32, 9999, 1, 3, 42, 11923, '1990-01-01', 'Devised at Pinewoods Camp, Plymouth, Massachusetts, USA in 1990.   

   

For "1st couple down and up" in bars 1-8, "Simply Dancing" published by Newcastle RSCDS in 2007 uses the word "dance", and the RSCDS Graded Book 2, 2010 changes it to "lead".  ', 56, '800/880/888/888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (11804, '2005-12-21 23:00:00+00', '2020-03-01 17:04:01.449853+00', 'OXO', 'OXO', 1, 32, 9999, 1, 4, 1, 3412, NULL, 'This may also be danced as a Jig or a Strathspey', 53, '8800/0880/0088/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (150, '1997-08-28 22:00:00+00', '2020-03-02 10:00:05.850014+00', 'Angstroms'' Anniversary, The', 'ANGSTROMS ANNIVERSARY', 4, 32, 1, 2, 3, 18, 632, NULL, 'Dedicated to John and Jane Angstrom in observance of the fifth anniversary of their wedding.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10912, '2002-11-11 23:00:00+00', '2020-03-03 19:06:50.722322+00', 'Kirsty''s Ceilidh', 'KIRSTYS CEILIDH', 2, 32, 9999, 5, 56, NULL, 3210, '1983-01-01', '', 100, '888  888  888  888', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (11799, '2004-09-16 22:00:00+00', '2021-01-19 22:00:31.081207+00', '18! 18!', '18 18', 1, 40, 9999, 1, 4, 1, 10611, NULL, 'This dance was written by the children of Macclesfield Scottish Country Dance Group for the 18th Wigan Thistle society festival of dance for young people. Teacher J F Bradbury', 54, '8800/0880/8000/8888/8222', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (56, '1998-09-27 22:00:00+00', '2020-08-02 06:35:29.85419+00', 'Airie Bennan', 'AIRIE BENNAN', 2, 32, 9999, 3, 5, 7, 129, '1966-01-01', 'Airie Bennan is a <<https://www.streetmap.co.uk/place/Airie_Bennan_in_Dumfries_and_Galloway_369611_688611.htm|small hill south west of Dalry>> where Hugh Foss lived.', 60, '88880  80800  84884  80800', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (12518, '2005-08-29 22:00:00+00', '2020-03-04 17:27:39.847463+00', 'Banks o'' Doon, The', 'BANKS O DOON', 3, 80, 9999, 4, 4, 3, 3625, NULL, '', 70, '8888/8888/8080/0808/8484/4848/4444/4444/6666/6666', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12506, '2005-08-21 22:00:00+00', '2020-03-04 17:57:52.018693+00', 'Chuckwagon Reel, The', 'CHUCKWAGON REEL', 1, 88, 9999, 4, 4, 3, 3618, '1998-01-01', '', 64, '8080/8080/8080/0808/0808/0808/8080/8888/0808/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9219, '2002-04-14 22:00:00+00', '2020-03-05 00:00:20.438419+00', 'Silver Safari', 'SILVER SAFARI', 3, 64, 9999, 4, 4, 46, 108, '1998-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20163, '2020-12-07 18:27:39.818595+00', '2020-12-08 01:12:49.057497+00', 'Wheels and Reels', 'WHEELS AND REELS', 2, 40, NULL, 4, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12735, '2006-05-07 22:00:00+00', '2020-12-28 13:21:52.807598+00', 'Marine Four-Step', 'MARINE FOURSTEP', 11, 16, 9999, 5, 1, NULL, 1998, NULL, 'Crib derived from various Bo''ness dance lists (eg <<https://my.strathspey.org/dd/list/28651/>>).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12574, '2005-11-01 23:00:00+00', '2021-01-01 13:50:31.066227+00', 'Oh! It''s That One', 'OH ITS THAT ONE', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 53, '804/840/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14545, '2012-08-28 10:11:14.194224+00', '2021-01-20 15:05:40.290814+00', 'Six Mile Road from Pitlochry', 'SIX MILE ROAD FROM PITLOCHRY', 4, 64, 5, 1, 4, 2, 10648, NULL, '', 67, '8008/8668/8008/4448/8008/8888/8888/8004', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20264, '2021-03-12 16:17:23.521389+00', '2021-03-12 16:20:24.631514+00', 'St Peter''s Cross', 'SAINT PETERS CROSS', 3, 32, NULL, 107, 4, NULL, 635, '2019-01-01', 'The dance was written as an introduction to the Axum Reel, and first taught at the Anno Domini Folk festival in St Petersburg in 2019.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20239, '2021-03-02 19:36:31.516814+00', '2021-03-04 13:58:35.497884+00', 'Dixon''s Day', 'DIXONS DAY', 2, 40, NULL, 1, 3, 42, 1445, '2017-01-01', 'To celebrate Keith Dixon’s 60th birthday, many happy returns!', 56, '800/844/880/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20413, '2021-07-30 09:16:21.581836+00', '2021-07-30 09:16:21.581836+00', 'Wedding in Paradise', 'WEDDING IN PARADISE', 3, 0, NULL, NULL, NULL, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19393, '2019-06-06 23:38:10.979883+00', '2020-03-05 09:50:13.662424+00', 'Wee Lassie fae Gourock, The', 'WEE LASSIE FAE GOUROCK', 3, 32, NULL, 1, 100, 2, 3583, '2005-01-01', 'This dance is dedicated to my very good friend, compatriot and dance adventure travelling companion, Stella Fogg.



In astronomy, a co-orbital configuration is a configuration of two or more astronomical objects (such as asteroids, moons, or planets) orbiting at the same distance, or very similar distances, from their primary.  [Wikipedia]  In these reels, 1st and 4th women are in co-orbital configuration!  



Descriptions of the "Double Slide Poussette" and "Co-Orbital Reels of Four" figures used in this dance can be found at <<http://scd-richmond.org/dances/formations/RichmondFormations.html>>



The name of the dance in the Richmond video is given as "There was a wee lassie frae Gourock".



A freely downloadable recording of music for this dance is available via <<http://www.fiddletree-music.com/johnturner/scdrecordings.html>>', 94, '8888/8888/8888/6666', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17343, '2016-09-14 13:09:45.050895+00', '2020-03-05 10:06:09.474211+00', 'Set & Drink', 'SET AND DRINK', 1, 32, NULL, 1, 4, 1, 635, '2011-02-28', 'This dance was written after hearing of the idea of “Set & Drink” while recovering from the course and final ball in St Petersburg, February 2011. The “recovery” took place in a large snooker club next to the dance centre. Apparently Moscow dancers have introduced “Yo Ho Ho” to the dancers in St Petersburg, but the clap after dancing RH across (before coming back LH) is their own invention!



I did wonder whether the music should be something suitably Russian which started slowly (as a Strathspey), which gradually speeded up so that by the 4th repeat it had turned into a rousing reel – probably a step too far, so I would recommend just using suitable reels!



A crib for this dance is available via the <<https://www.scottish-country-dancing-dictionary.com/dance-crib/set-and-drink.html|SCD dictionary>> site.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15444, '2014-05-19 14:57:00.620248+00', '2020-03-06 21:03:41.515857+00', 'Janice', 'JANICE', 3, 32, NULL, 2, 3, 18, 2408, '2013-06-01', 'Devised in June 2013 by Lara Friedman-Shedlov (lfriedmanshedlov [at] gmail.com) for Janice Lacock, now of Madison, Wisconsin.



Music:   "I would prefer a traditional-style Strathspey (not an air); there is no designated tune as of yet."

', 71, '888/800/866/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12960, '2006-10-25 22:00:00+00', '2020-03-07 10:56:18.875779+00', 'Ammonites and Terns', 'AMMONITES AND TERNS', 2, 48, 9999, 3, 5, 7, 3718, '2005-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16194, '2015-04-12 15:13:54.348843+00', '2020-03-05 18:51:24.643199+00', 'This is BirthDay', 'THIS IS BIRTHDAY', 1, 40, NULL, 5, 1, 4, 10759, '2013-01-01', 'Devised by Judith Kowalczik on Martin''s Birthday in 2013.    



The instructions published online in the publication Potters Pairs) are in error on bars 21-24.  The correct instructions follow here.



40 bar Reel for couples in a circle     

Each man has his lady on his right, all facing in.   

1 - 8 All ladies advance for two steps and retire for two steps. All men repeat finish facing partner.   

9 - 16 All dance back to back with partner. All, giving right hands, turn partner once round.   

17 - 24 All pass partner right shoulder in one bar, pass next person left shoulder in one bar and, giving right hands, turn next person halfway in two bars.  Repeat bars 17 - 20 to finish in the original place facing partner again.   

25 - 32 All dance 4 slip steps diagonally to the left ( clap on bar 28) and 4 slip steps back into the circle to finish back to back with partner. Giving left hands, turn next person once round.   

33 - 40 All dance hands to the right!   





', -90, '4/8/8/8/8', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4543, '1998-09-30 22:00:00+00', '2020-03-07 16:50:08.060748+00', 'Miss Margaret Hill', 'MISS MARGARET HILL', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19859, '2020-03-08 22:13:00.563335+00', '2020-03-08 22:35:04.461894+00', 'Stuck in the train', 'STUCK IN THE TRAIN', 1, 32, NULL, 105, 54, 11, 10759, '2018-03-01', 'The idea to the dance came on the way back from the wedding of Ramona and Matthias. Four dancers from Oldenburg got stuck in the ICE between Munich and Ingolstadt due to braking issues in the train in front of them. They waited one and a half hours until the passengers from the other train where finally safely evacuated into their train. Afterwards the train was jam-packed except for just a tiny little space on the corridor, just fitting for four dancers in a line....', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19131, '2018-12-29 02:47:50.045513+00', '2020-05-27 10:19:37.597933+00', 'Fifty Years Together', 'FIFTY YEARS TOGETHER', 5, 48, NULL, 2, 2, 76, 3583, '2007-06-08', 'There should be no extra space between one set and the next down the room.



A freely downloadable recording of music for this dance is available via <<http://www.fiddletree-music.com/johnturner/scdrecordings.html>>', 59, '88/88/80/88/88/82', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19858, '2020-03-07 17:16:26.091295+00', '2020-09-22 16:43:12.585001+00', 'Reinventing the Wheel', 'REINVENTING THE WHEEL', 2, 32, NULL, 6, 3, 18, 10811, NULL, 'Source <<http://rscds-twincities.org/programs/perfrep1718.pdf>> and <<https://youtu.be/l0luUCQ6ygc|youtube video>>.  The dance can also be performed as a reel. ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19842, '2020-02-05 21:09:39.224146+00', '2020-12-24 22:06:48.832595+00', 'Schoolgirls Together', 'SCHOOLGIRLS TOGETHER', 1, 40, NULL, 4, 4, 13, 3583, '2018-10-01', 'For the significant March 2019 birthday of the deviser''s oldest friend (in elapsed time), Helen [Angus] Millar – who would undoubtedly hasten to tell you (even after all these years) that she is still six weeks younger than me!



A freely downloadable recording of music for this dance is available via <<http://www.fiddletree-music.com/johnturner/scdrecordings.html>>', 1, '8888/8888/8888/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5041, '1998-07-06 22:00:00+00', '2021-07-20 08:48:42.191627+00', 'Oidhche Chaluinn', 'OIDHCHE CHALUINN', 3, 32, 9999, 5, 56, 76, 270, NULL, 'On bars 25-32, the men effectively dance a complete figure of eight trace, whilst the ladies dance half

rights and lefts and half a reel of three, to finish with original partners, facing in the same direction. The

trios, having progressed, will all be facing a new trio for the repeat.', 59, '484/282/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20414, '2021-07-30 10:08:17.720066+00', '2021-07-30 10:08:17.720066+00', 'Aileen''s Schiehallion', 'AILEENS SCHIEHALLION', 4, 0, NULL, NULL, NULL, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18084, '2017-11-23 14:25:21.537699+00', '2020-03-09 15:20:40.312491+00', 'Daughter of Bon Accord', 'DAUGHTER OF BON ACCORD', 1, 32, 9999, 1, 3, 42, 3729, '2013-01-01', 'Devised by Val Mitchell, Hawkes Bay East Coast Region. 

This dance is dedicated to the memory of Madge Laing, inspirational teacher and friend.



The dance is called Daughter of Bon Accord because Madge is originally from Aberdeen and Bon Accord is the motto of the city of Aberdeen.



Suggested music: 

Selection of reels (Track 13, disc 2) Celtic Fire in the Music, Bobby Brown & the Scottish Accent.', 90, '808/888/868/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13052, '2006-11-02 23:00:00+00', '2020-03-09 15:29:02.653033+00', 'White Rabbit, The', 'WHITE RABBIT', 1, 32, 9999, 1, 3, 42, 352, '2002-01-01', '', 66, '840/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19865, '2020-03-09 16:16:10.048096+00', '2020-03-09 16:16:10.048096+00', 'Hundreds of Wild Geese', 'HUNDREDS OF WILD GEESE', 2, 32, NULL, 1, 3, 42, 10568, '2019-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19868, '2020-03-09 16:25:58.925737+00', '2020-03-09 16:25:58.925737+00', 'JP and Sunny''s Jig', 'JP AND SUNNYS JIG', 2, 32, NULL, 1, 4, 2, 10568, '2018-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19879, '2020-03-10 07:36:04.28915+00', '2020-11-28 10:59:22.748566+00', 'Théa''s Welcome', 'THEAS WELCOME', 3, 32, NULL, 2, 3, 17, 10568, '2017-12-01', 'Théa''s Welcome can be danced in a 5 couple set.', 67, '840/840/808/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19873, '2020-03-09 17:31:59.91652+00', '2020-03-09 17:31:59.91652+00', 'Making Friends', 'MAKING FRIENDS', 1, 32, NULL, 1, 3, 42, 10568, '2017-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19722, '2019-10-25 10:13:36.075097+00', '2020-03-11 01:00:34.671603+00', 'Jaunty Jeanne', 'JAUNTY JEANNE', 1, 32, NULL, 1, 4, 1, 11361, '2015-07-01', 'This dance is dedicated to Jeanne Moody, a talented San Diego teacher who has shared her love of dance with many beginner classes.



', 87, '8888/8888/8888/8224', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20480, '2021-09-12 12:39:31.81328+00', '2021-09-12 12:39:31.81328+00', 'Maureen Sullivan''s Medley', 'MAUREEN SULLIVANS MEDLEY', 4, 128, 2, 4, 4, NULL, 2682, '2021-04-10', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19874, '2020-03-09 17:34:21.831104+00', '2020-03-22 23:35:02.813827+00', 'Perfect Match, A', 'PERFECT MATCH', 2, 32, NULL, 7, 113, 4, 10568, '2019-09-01', 'Written as an ‘everyone’ dance at Katie and Alistair’s wedding.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19880, '2020-03-11 11:13:37.305679+00', '2020-03-11 11:13:37.305679+00', 'There''s Something about Triangles', 'THERES SOMETHING ABOUT TRIANGLES', 1, 32, NULL, 6, 3, 42, 10568, '2018-06-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19881, '2020-03-11 11:15:04.645089+00', '2020-03-11 11:15:04.645089+00', 'Totem Park', 'TOTEM PARK', 1, 48, NULL, 1, 4, 1, 10568, '2017-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19882, '2020-03-11 11:17:33.650707+00', '2020-03-12 09:25:56.030021+00', 'Trip to Italy, A', 'TRIP TO ITALY', 2, 32, NULL, 3, 5, 7, 10568, '2018-06-01', 'This may also be danced in a 3 couple or 7 couple set.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10619, '2002-06-30 22:00:00+00', '2020-03-13 10:34:41.458493+00', 'Saint Patrick''s Jig', 'SAINT PATRICKS JIG', 2, 32, 9999, 1, 3, 42, 28, NULL, '', 50, '800/888/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8191, '1998-01-04 23:00:00+00', '2020-03-28 09:05:59.085457+00', 'Buchaille Etive Mhor', 'BUCHAILLE ETIVE MHOR', 3, 48, 9999, 1, 4, NULL, 9998, NULL, 'The usual spelling of this mountain at the head of Glen Etive is Buachaille Etive Mhor (or Buachaille Etive Mòr). SCDDB follows the spelling "Buchaille" used in the original publication, both on the title page and the dance instructions.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19884, '2020-03-11 11:28:01.528892+00', '2020-04-20 07:43:46.755407+00', 'Dance for Chloe, A', 'DANCE FOR CHLOE', 2, 32, NULL, 1, 2, 76, 11052, '2018-11-01', 'This dance is for Sunny and JP’s little girl born in November 2018.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19886, '2020-03-11 11:31:09.891202+00', '2020-04-18 22:31:33.471461+00', 'Sparrows'' Spring Branch, The', 'SPARROWS SPRING BRANCH', 3, 32, NULL, 2, 3, 18, 11675, '2018-05-01', 'Don was inspired by the sparrows flying around in the tree outside as he lay on the floor doing his back exercises. He calls all those ‘gypsy’ moments the anti-spurn.', 44, '800/844/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19860, '2020-03-09 15:32:47.112327+00', '2020-03-19 23:02:27.358694+00', 'Bernie''s Triumph', 'BERNIES TRIUMPH', 3, 32, NULL, 1, 3, 42, 10568, '2019-08-01', '', 63, '888/844/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19887, '2020-03-11 14:57:50.424117+00', '2020-03-13 01:30:13.924865+00', 'Reunion, The', 'REUNION', 2, 32, NULL, 1, 4, 1, 11874, '2016-08-01', 'Devised by Sue Ronald as an opening dance for a ‘Not dancing with your partner’ class at the New Hampshire Highlands Weekend, August 2016.



I saw the movement described in bars 1-8 and 17-24 in the dance Pudsey Bear by Louise Macdougall. ‘Detour chase’ is my name for the movement.  The advance and retire of bars 25-28 symbolize the Reunion.



Music:  Any lively single jig', 75, '4444/8888/4444/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19889, '2020-03-13 12:05:15.2723+00', '2020-03-13 12:05:15.2723+00', 'Leaps and Loops', 'LEAPS AND LOOPS', 2, 40, NULL, 1, 4, NULL, 11534, '2020-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10726, '2002-07-24 22:00:00+00', '2020-03-13 10:20:40.962107+00', 'Saint Patrick''s Strathspey', 'SAINT PATRICKS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 28, NULL, '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1806, '1997-04-03 22:00:00+00', '2020-03-15 21:43:29.434163+00', 'Dumyat', 'DUMYAT', 3, 32, 9999, 1, 2, 76, 108, '1968-01-01', '', 64, '84/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19890, '2020-03-14 18:41:38.249876+00', '2020-03-16 10:02:11.079295+00', 'Russian Fly, The', 'RUSSIAN FLY', 1, 32, NULL, 1, 4, 11, 10912, NULL, '', 97, '8668/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19891, '2020-03-14 18:54:07.539877+00', '2020-03-16 10:05:17.28356+00', 'Scottish Midge, The', 'SCOTTISH MIDGE', 1, 32, NULL, 1, 4, 11, 10912, NULL, '', 94, '8448/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19861, '2020-03-09 15:42:28.334379+00', '2020-03-22 00:13:42.376039+00', 'Bishop Hall', 'BISHOP HALL', 2, 32, NULL, 1, 3, 42, 10568, '2017-09-01', 'Written as a thank you to Maggie, Duncan and Ailsa Keppie for a lovely week at Scotch on the Rocks in Nova Scotia.  



The music I use for this dance is Gloria’s Wee Hug (track # 5 from The Devil’s Quandry – Deby Benton Grosjean). It fits the dance and is delightful for listening and dancing.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19878, '2020-03-09 22:27:19.243275+00', '2020-11-09 05:06:23.502583+00', 'Nur gucken, nicht anfassen', 'NUR GUCKEN NICHT ANFASSEN', 3, 32, NULL, 1, 3, 42, 11997, NULL, 'Source used : Dance List for SF Hildesheim - <<https://my.strathspey.org/dd/list/23114/|Mitbringsel Hannover 2019-06-18a>>', 47, '800/844/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4185, '1997-04-03 22:00:00+00', '2022-10-26 08:14:59.149225+00', 'Market Square', 'MARKET SQUARE', 1, 64, 9999, 4, 4, 3, 28, NULL, 'This dance is frequently done as a S64+R64 medley, as described in Minicrib.', 75, '8888/6666/6666/8888/8080/0808/4444/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19870, '2020-03-09 16:34:13.548121+00', '2022-12-05 23:49:55.217671+00', 'Missing Triplet, The', 'MISSING TRIPLET', 3, 32, NULL, 6, 3, 17, 10568, '2019-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19877, '2020-03-09 17:38:42.848636+00', '2020-03-22 00:47:47.050832+00', 'Synchronous Simplicity', 'SYNCHRONOUS SIMPLICITY', 3, 32, NULL, 1, 3, 42, 10568, '2019-05-01', 'Inspired by events at Pawling 2019.', 69, '844/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19862, '2020-03-09 15:44:19.037106+00', '2020-05-27 01:53:41.885405+00', 'Celtic Harmonies', 'CELTIC HARMONIES', 1, 32, NULL, 7, NULL, NULL, 10568, '2019-10-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19871, '2020-03-09 16:35:45.833106+00', '2020-09-28 09:30:21.653505+00', 'Oh, How We''ve Danced!', 'OH HOW WEVE DANCED', 2, 32, NULL, 1, 2, 76, 10568, '2019-05-01', 'It was our 40th anniversary in 2019. A reason to celebrate.', -1, '44/44/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20164, '2020-12-07 18:29:45.425945+00', '2020-12-07 18:29:45.425945+00', 'Honour Your Partner', 'HONOUR YOUR PARTNER', 2, 48, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20265, '2021-03-12 16:32:57.967571+00', '2021-03-12 17:35:48.399123+00', 'St Petersburg Metro, The', 'SAINT PETERSBURG METRO', 1, 32, NULL, 4, 4, NULL, 635, '2010-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10456, '2002-11-18 23:00:00+00', '2021-09-19 22:37:12.553425+00', 'Bonavista', 'BONAVISTA', 1, 40, 9999, 1, 4, 2, 3091, '1997-01-01', '', 70, '8008/8888/8888/8008/8008', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17424, '2016-10-19 21:50:10.988218+00', '2020-03-16 10:12:48.916511+00', 'Unsullied Saltire, The', 'UNSULLIED SALTIRE', 3, 32, 9999, 2, 3, 17, 10912, NULL, 'This dance is so-named because it emphasizes the essential character of the saltire; it uses only the basic 2-bar element of the figure, repeated six times, starting and finishing with the dancers in the "textbook" positions.



A saltire, Saint Andrew''s Cross, is a heraldic symbol in the form of a diagonal cross or letter ex (X). Saint Andrew is said to have been martyred on just such a cross.



The Flag of Scotland, also known as the Saint Andrew''s Cross or more commonly The Saltire (because it has the form of a saltire), is the national flag of Scotland. As the national flag, the Saltire differs from the Royal Standard of Scotland in that it is the Saltire which is the correct flag for all individuals and corporate bodies to fly in order to demonstrate both their loyalty and Scottish nationality. It is also, where possible, flown from Scottish Government buildings every day from 8am until sunset, with certain exceptions. 



(Source: <<http://www.scottish-country-dancing-dictionary.com/dance-crib/unsullied-saltire.html|Scottish Country Dancing Dictionary>>)', 79, '844/888/844/848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17398, '2016-10-04 22:27:10.597587+00', '2020-03-17 02:16:50.91257+00', 'Jig Is Up, The', 'JIG IS UP', 2, 32, NULL, 1, 3, 42, 1393, '2014-01-01', 'Challenged by David Newitt to write something other than “another beautiful waltz tune”, Patti wrote The Jig Is Up, with a nod to David’s tune, Changing Lights. 



The name Changing Lights arose from a story only the composer seems to find very amusing: Friend was driving through San Francisco with her boyfriend. Stopped at a red light, she had to look away from the road, so asked, “Tell me if the light changes”.  After a moment’s thought he replied, “Yes, the light changes”. Said she, “Grrr”.  Light turned green and they proceeded to the next light, which turned yellow, then red.  Said he (in voice of wonder), “Wow - this one changes too!” 

', 70, '882/888/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17396, '2016-10-04 15:42:38.559665+00', '2021-07-20 09:34:37.065178+00', 'Dancin'' in the Rain', 'DANCIN IN THE RAIN', 3, 32, NULL, 4, 4, 4, 1331, '2014-01-01', 'On each repetition, women progress one place counter-clockwise while men progress clockwise, all end in original places at the end of the fourth time through.  Partners begin beside each other on first and third repetitions and across from each other on second and fourth repetitions. 



Thanks to Alec Hay for the unnamed figure that he introduced in his dance Peter White and to Helen Greenwood who popularized the figure in her dance Best Set in the Hall.  But note that the movement in 25-32 is similar but NOT the same.



 

', 81, '8484/8888/4444/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19894, '2020-03-20 10:10:12.331645+00', '2020-03-20 10:10:12.331645+00', 'Winged Messenger, The', 'WINGED MESSENGER', 1, 32, NULL, 1, 3, 42, 555, NULL, 'Source: the <<https://youtu.be/J7uZByAVI7k|youtube video>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19897, '2020-03-23 17:33:27.967556+00', '2020-08-12 10:47:35.517264+00', 'Bug, The', 'BUG', 1, 32, NULL, 1, 3, 42, 11150, NULL, '', 56, '800/844/888/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18576, '2018-09-11 07:11:04.914026+00', '2020-03-19 23:20:31.486591+00', 'DODGEM Reel', 'DODGEM REEL', 1, 32, 9999, 2, 3, 17, 11702, '2018-01-01', 'The dance was devised by Bexi and Gabor for David Hall for his very special birthday as a present along with a voucher of a dedicated private use of the whole dodgem facility in Böhmischer Prater, Wien.



The MOTTO of the dance: accidents can happen only accidentally!



If ''danced'' in dodgems take 16 bars of music for each 8 bars section (i.e. R 3x64 bars).



Music: The Wiggle in the Middle by Christina Hood

', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14387, '2011-12-27 23:00:00+00', '2021-01-29 23:40:05.758559+00', 'Florrie''s Fancy', 'FLORRIES FANCY', 2, 32, NULL, 1, 4, 1, 3517, '2008-06-01', 'The description says "A 32 bar jig for 3, 4 or 5 couples in a longwise set".  



This dance was devised by Helen Beaney, and the music by John Barnes, in celebration of the 70th birthday of Florrie Halliday, Hon. Secretary of Dublin Scottish Country Dance Club, in June 2008.  Florrie died in August 2018.', 75, '8000  8000  8888  8888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (3037, '1998-10-12 22:00:00+00', '2020-03-20 21:03:19.910438+00', 'Hypochondriac''s Delight, The', 'HYPOCHONDRIACS DELIGHT', 3, 32, 9999, 1, 3, 42, 348, '1991-01-01', 'A dance with no hands.', 63, '800/822/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19893, '2020-03-19 18:27:34.992856+00', '2020-03-19 19:03:45.411408+00', 'Macadam Reel, The', 'MACADAM REEL', 1, 32, NULL, 1, 4, 2, 2701, '2001-01-01', 'The dance was inspired by a conversation during the long wait for the dance hall to be unlocked on a chilly evening in April. While chatting in the parking lot, we agreed that there should be a dance to keep us warm. The requirements were that it be quicktime, have as many couples active as possible, and not require the use of hands as they would be keeping warm in pockets or under arms. Michael Bentley suggested the name for the parking lot, and of course, it should be dedicated to Kathleen McAdam one of the warmest members of the San Francisco branch.', 100, '888/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1616, '1997-09-01 22:00:00+00', '2020-03-20 21:16:38.596363+00', 'Den O''Mains, The', 'DEN OMAINS', 2, 32, 9999, 1, 3, 42, 176, NULL, '', 56, '844  844  844  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (19864, '2020-03-09 15:56:59.11806+00', '2020-03-22 00:40:11.67345+00', 'Dance for Andrew', 'DANCE FOR ANDREW', 2, 32, NULL, 1, 3, 42, 10568, '2018-10-01', 'Written to celebrate the life of Andrew Carruthers, a staunch supporter of the Scottish Country dance community in Montreal and an all round great guy. We miss him.  



', 63, '880/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20467, '2021-09-11 23:08:22.149813+00', '2021-09-12 08:50:36.561725+00', '24th Summer, The', '24TH SUMMER', 3, 32, NULL, 4, 4, NULL, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11613, '2003-12-04 23:00:00+00', '2022-04-26 09:34:08.967589+00', 'Windy Lane, The', 'WINDY LANE', 1, 32, 9999, 1, 3, 42, 2682, '1994-01-01', 'Devised September, 1994 and modified in November, 1994.  

The title was suggested by leaves swirling along a Titahi Bay street in a strong southerly.  



Bars 1-8 represent the swirling leaves.  



Suitable music - "The Inverness Country Dance" recorded by The Ron Gonnella Strings with George MacIlwham on "The Lad O'' Kyle" (AB 008), side 1, track 7.', 50, '224/880/880/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19895, '2020-03-20 12:06:44.565984+00', '2022-04-26 20:21:35.696763+00', 'Road to Ayr', 'ROAD TO AYR', 1, 48, NULL, 3, 5, 7, 10971, NULL, 'Source: <<https://youtu.be/IAhAXFbOGV8|youtube video>>.', 93, '88888/88888/88888/88888/88880/80888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20506, '2021-10-09 08:42:35.557911+00', '2022-08-15 14:54:21.487825+00', 'Frenchman''s Hat, The', 'FRENCHMANS HAT', 3, 32, NULL, 1, 4, 1, 352, '2007-11-07', '', 78, '8228/2882/8888/8488', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19876, '2020-03-09 17:37:29.458237+00', '2020-03-22 01:27:51.932819+00', 'Sleepy Sunny and JP', 'SLEEPY SUNNY AND JP', 1, 32, NULL, 1, 3, 42, 10568, '2018-04-01', 'Sunny enjoys the dances Sleepy Maggie and J.B. Milne. I chose the parts of those dances that I like and put them together to celebrate Sunny and JP’s BIG NEWS.', 59, '840/808/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19896, '2020-03-22 01:52:45.101116+00', '2020-03-22 01:59:50.468698+00', 'Robin E.P.''s Rant', 'ROBIN EPS RANT', 3, 32, NULL, 1, 3, 42, 11181, '2020-03-22', '', 56, '800/888/866/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19911, '2020-03-25 00:39:27.662909+00', '2020-03-25 00:39:27.662909+00', 'CREB - it''s Good for You', 'CREB  ITS GOOD FOR YOU', 4, 32, 1, 2, 3, NULL, 11932, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19912, '2020-03-25 00:47:30.716303+00', '2020-03-25 00:47:30.716303+00', 'Autumn Mist', 'AUTUMN MIST', 3, 32, NULL, 1, 4, NULL, 3511, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2467, '1997-04-03 22:00:00+00', '2021-06-19 23:13:44.829963+00', 'Gillechallum', 'GILLECHALLUM', 2, 32, 9999, 1, 4, 2, 352, '1991-04-26', 'The dance notes say that Gillechallum is derived from two gaelic words signifying the servant of St Columba from which we get the name Malcolm.', 81, '8008/8888/8888/8448', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19875, '2020-03-09 17:36:03.576862+00', '2020-03-24 00:30:20.784082+00', 'Skye and Sochi', 'SKYE AND SOCHI', 1, 40, NULL, 2, 3, 17, 10568, '2018-07-01', 'This dance was written to go with the music for Montréal Diamond Anniversary Reel—‘Turnbulls’ of

Saskatchewan’—on Nick and Laura’s CD Encore Une Fois. Therefore it goes 6 times through with

each couple getting a second chance to get it right.  

The dance is dedicated to Ruth Turnbull’s two dogs. My friend, Joanne Turnbull, is Ruth’s twin sister. So it is also dedicated to Ruth and Joanne.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19883, '2020-03-11 11:18:53.773783+00', '2020-03-24 00:50:16.968611+00', 'Trip to Taiwan, A', 'TRIP TO TAIWAN', 1, 32, NULL, 2, 3, 17, 10568, '2019-03-01', 'Celebrating a visit with my niece and her family in Taipei. A long trip to get there and back but a wonderful way to spend a vacation except there was no dancing!', 75, '888/840/844/848', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19914, '2020-03-25 00:53:41.982005+00', '2020-03-25 00:53:41.982005+00', 'Dragon''s Milk', 'DRAGONS MILK', 3, 32, NULL, 1, 3, NULL, 3511, '2014-09-23', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19915, '2020-03-25 00:57:56.76098+00', '2020-03-25 00:57:56.76098+00', 'Fairy Pools, The', 'FAIRY POOLS', 1, 32, NULL, 1, 3, NULL, 11933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19916, '2020-03-25 01:01:11.598478+00', '2020-03-25 01:01:11.598478+00', 'Hame in the East, A', 'HAME IN THE EAST', 3, 32, NULL, 1, 3, NULL, 3511, '2007-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19917, '2020-03-25 01:02:50.519546+00', '2020-03-25 01:02:50.519546+00', 'Hooty Hollow', 'HOOTY HOLLOW', 1, 32, NULL, 1, 3, NULL, 3511, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12020, '2005-02-13 23:00:00+00', '2020-03-24 13:20:32.911358+00', 'Ferguson''s Fancy', 'FERGUSONS FANCY', 4, 32, 1, 1, 3, 42, 777, NULL, 'Note: This dance was devised in honor of the fortieth wedding anniversary of Jim and Donna Ferguson of Kimbolton, Ohio. The music was written by Etienne Ozorak as a gift to Jim and Donna and is published with his permission', 56, '844/844/888/844', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (19907, '2020-03-24 22:12:51.479407+00', '2020-03-24 22:12:51.479407+00', 'Axiomatic', 'AXIOMATIC', 1, 32, NULL, 1, 4, 1, 11929, NULL, 'Suggested music is *The Left-Handed Fiddler.*', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19909, '2020-03-24 22:26:16.122908+00', '2020-03-24 22:26:16.122908+00', 'Braided Voices', 'BRAIDED VOICES', 1, 32, NULL, 1, 3, NULL, 11931, NULL, 'The basic story behind this dance is that Noel read about a Science Magazine "Dance Your Dissertation"

challenge to graduate students (in the sciences) to choreograph dance versions of their dissertations, which they could then video record and submit to the magazine to compete for a prize. Ethnomusicology is not one of the eligible disciplines (too much humanities, not enough social science), but Noel challenged both me and Xiaowen to Dance Our Dissertations anyway. "Braided Voices" is basically the dance re-mix of my dissertation, "Braided Voices: Women Cantors in Non-Orthodox Judaism." Up until the 1970s, Jewish cantors were almost universally men. Women began to trickle into the profession, slowly at first, but now have achieved at least 50% representation in the non-Orthodox cantorate. For the most part, they work easily and well with their male counterparts, and with their male and female rabbis, and their congregations have accepted them with enthusiasm.  



_Bars 1 - 8_ shows Jewish liturgical practice up until the middle of the twentieth century. The men get all the action, and the women sit on the sidelines and watch.  

_Bars 9 - 16_ shows women beginning to get involved in the cantorate. At first, it''s just one or two, but the movement picks up steam, and women cantors begin to work with (often) male rabbis.

_Bars 17 - 24_ refer to the title. I loved the very feminine, yet very practical, image of hair braids, which is why I chose it for the title of my dissertation. And reels of three kind of remind me of three-stranded braiding.

_Bars 25 - 32_ depicts the kind of aesthetic that you see in a lot of liberal synagogues today, in which

worship is designed to be very participatory and to involve the rabbi, the cantor, the congregation, men, women, children, as many people as possible. It''s a worship aesthetic largely pioneered by women rabbis and women cantors, and American congregations really seem to like it.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19918, '2020-03-25 01:05:45.098969+00', '2020-03-25 01:05:45.098969+00', 'Jedburgh Arches, The', 'JEDBURGH ARCHES', 3, 32, NULL, 1, 3, NULL, 11933, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19919, '2020-03-25 08:11:36.112309+00', '2020-03-25 08:11:36.112309+00', 'Lacing Ghillies', 'LACING GHILLIES', 1, 32, NULL, 1, 3, 42, 11934, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19920, '2020-03-25 08:16:01.330202+00', '2020-03-25 08:16:01.330202+00', 'Mincemeat', 'MINCEMEAT', 1, 32, NULL, 3, 5, 59, 11930, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19921, '2020-03-25 08:18:45.361058+00', '2020-03-25 08:18:45.361058+00', 'Mutton Skinnet', 'MUTTON SKINNET', 2, 32, NULL, 3, 5, 7, 3511, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19922, '2020-03-25 08:24:01.506894+00', '2020-03-25 08:24:01.506894+00', 'One Dance, One Book', 'ONE DANCE ONE BOOK', 2, 32, NULL, 104, 2, NULL, 11932, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9929, '2001-06-05 22:00:00+00', '2020-03-25 15:38:02.788617+00', 'Three Millstones, The', 'THREE MILLSTONES', 1, 32, 9999, 3, 5, 7, 101, '1995-01-01', 'For demonstration with the groups visiting the international festival run by Dunedin Dancers in 1995.



*NB the original instructions for bars 5-8 say "1st and 3rd couples turn one and three quarter times giving right hands". However this does not fit with the following RH across. Both diagram and crib assume the turn should be one and a quarter times.*', 70, '80800/84844/84844/88888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19906, '2020-03-24 22:08:32.214505+00', '2020-04-14 12:15:50.046293+00', 'Dance for Dorothy, A', 'DANCE FOR DOROTHY', 1, 32, NULL, 1, 4, 2, 11928, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19913, '2020-03-25 00:51:08.535264+00', '2020-05-05 06:59:59.228409+00', 'Doug''s 70th', 'DOUGS 70TH', 3, 96, NULL, 4, 4, NULL, 2766, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20165, '2020-12-07 18:31:02.587804+00', '2020-12-07 18:31:02.587804+00', 'Point-Counterpoint', 'POINTCOUNTERPOINT', 2, 48, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20052, '2020-07-18 09:47:15.498073+00', '2020-07-18 09:48:00.819905+00', 'Mainly Douglas', 'MAINLY DOUGLAS', 2, 32, NULL, 1, 3, 42, 635, NULL, 'Malcolm Brown devised this *to teach phrasing, to show how if you are moving (or preferably even accelerating) at the end of bar 24, then the last 8 bars becomes easier - I called the dance "Mainly Douglas" (the last 24 bars occur in "<<ddd:#4548>>").*

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19903, '2020-03-23 18:56:17.736377+00', '2020-08-12 08:50:54.107228+00', 'Pandemonic!', 'PANDEMONIC', 1, 32, NULL, 2, 3, 17, 11570, '2020-03-01', '', 77, '864/888/088/088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8166, '1998-11-01 23:00:00+00', '2021-01-23 23:29:31.984329+00', 'Teddy Bears'' Picnic, The', 'TEDDY BEARS PICNIC', 2, 32, 9999, 1, 4, 1, 2010, NULL, '<<scddb-not-identical:9896>>', 64, '4442  8644  8888  4244', 0, 1, 1, 1, 64);
INSERT INTO 'dance' VALUES (20305, '2021-04-05 09:15:07.668219+00', '2021-04-06 13:04:45.069763+00', 'Ben Nevis', 'BEN NEVIS', 1, 32, NULL, 3, 5, 16, 11029, NULL, 'This dance is to celebrate Tricia Ashley’s 70th Birthday.', 55, '80800/80800/80044/88888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19910, '2020-03-24 22:30:16.676155+00', '2022-08-22 23:05:26.972294+00', 'Corinne''s Caper', 'CORINNES CAPER', 6, 32, NULL, 1, 3, 42, 2766, NULL, 'Written in memory of Corinne McArdle who was a regular and active member of our Branch for many years.  



Suggested music is *Broadford Bay* from A Skye Collection.', 53, '840/880/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10909, '2002-11-02 23:00:00+00', '2022-12-22 18:23:25.279004+00', 'Coldingham Sands', 'COLDINGHAM SANDS', 3, 32, 9999, 1, 4, 1, 725, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10858, '2002-11-01 23:00:00+00', '2021-03-17 07:06:32.886258+00', 'Dance for Frans, A', 'DANCE FOR FRANS', 3, 40, 9999, 1, 4, 1, 3120, '2002-03-01', 'Dedicated to Frans Ligtmans on her birthday, in due gratitude for many years of inspired teaching.





', 95, '8888/8888/8888/8888/0888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20304, '2021-04-05 09:13:45.706865+00', '2021-04-06 23:11:58.50777+00', 'Westward Bound', 'WESTWARD BOUND', 101, 32, NULL, 1, 3, 42, 11029, NULL, 'This dance is written for Alice Cuneo who is heading west to Perth to be closer to her family.', 58, '800/844/866/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19923, '2020-03-25 08:26:45.597411+00', '2021-05-21 05:05:43.950883+00', 'Remembering Ingrid', 'REMEMBERING INGRID', 2, 32, NULL, 1, 3, 42, 3511, NULL, '', 58, '880/808/846/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19908, '2020-03-24 22:20:17.674684+00', '2020-03-28 11:12:25.482937+00', 'Bicycle Reel', 'BICYCLE REEL', 1, 40, NULL, 1, 4, 2, 11930, NULL, 'Each figure is a 4-bar phrase. A slow reel is best for this one!  



On the name of the dance: While learning French in Switzerland, I would consistently replace the phrase “faire du velo” (“to ride the bicycle”) with “faire *le* velo” (“to do the bicycle”). A friend pointed out that my mistake made it sound as though I was in fact trying to be a bicycle, and that was the inspiration for this dance.', 95, '8888/4884/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19924, '2020-03-29 11:37:06.369953+00', '2020-04-11 11:47:23.782892+00', 'San Diego Welcome', 'SAN DIEGO WELCOME', 3, 32, NULL, 5, 2, 30, 11896, '1985-02-01', 'Devised for the occasion of San Diego’s Ninth Annual Mini-Institute and Ball as a means of greeting old friends and new dancers while the dance is taking place.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19926, '2020-03-29 11:44:55.698567+00', '2020-03-29 11:44:55.698567+00', 'Another Covid-19 Dance', 'ANOTHER COVID19 DANCE', 2, 48, NULL, 4, 4, 1, 11935, '2020-03-01', '', 80, '8404/8888/4444/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20166, '2020-12-07 18:32:35.948225+00', '2020-12-07 18:32:35.948225+00', 'Well-Oiled Machine, The', 'WELLOILED MACHINE', 2, 40, NULL, 3, 5, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19933, '2020-03-29 19:55:47.625875+00', '2020-03-29 20:01:00.661011+00', 'Battle of Harlaw, The', 'BATTLE OF HARLAW', 1, 64, NULL, 1, 100, 11, 9998, NULL, 'Source: <<https://youtu.be/pCE2eqy3V-A|youtube video>> (from 2:46 and 8:14).', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19936, '2020-03-30 00:51:51.640146+00', '2020-04-08 23:54:35.22051+00', 'Sierra Trails', 'SIERRA TRAILS', 3, 32, NULL, 4, 4, 13, 11361, '2017-12-01', 'Dedicated to Art and Emily Lee, two longtime San Diego Branch and Sierra Club members, December 1987. Revised December 2017.', 75, '8888/8888/8080/0808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19940, '2020-03-30 02:27:40.049422+00', '2020-04-09 00:24:04.525318+00', 'Queen of Hearts', 'QUEEN OF HEARTS', 1, 32, NULL, 1, 4, 1, 11801, '2019-05-01', 'The first couple draws a heart in bars 1-8, then after retiring to fourth place, the remainder is danced by the 2nd, 3rd, and 4th couples only.  *Off with their heads…*  ', 64, '8000/2888/0888/0888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19942, '2020-04-02 23:19:56.993797+00', '2020-12-28 20:17:40.635809+00', 'Celtic Wheel, The', 'CELTIC WHEEL', 2, 40, NULL, 4, 4, 1, 12008, '2016-05-12', '', 80, '4444/4444/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19934, '2020-03-30 00:39:11.890942+00', '2020-04-11 05:15:01.578411+00', 'Paradise Dream', 'PARADISE DREAM', 2, 32, NULL, 1, 3, 42, 11939, '2017-01-01', 'This dance began as a dream while camping in Paradise, Michigan. It was inspired by the beautiful autumn foliage and the twirling, dancing leaves falling in the wind.', -1, '880/880/448/448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19932, '2020-03-29 19:05:55.628394+00', '2020-06-15 22:54:15.487921+00', 'Autumn Celebration', 'AUTUMN CELEBRATION', 3, 32, NULL, 2, 3, 18, 3646, NULL, 'Source: <<https://youtu.be/yYElb1PUijQ|youtube video>> (where it is referred to as Autumn Wedding).', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14860, '2013-05-19 11:29:57.009942+00', '2020-04-01 00:44:41.655708+00', 'Old Friends Return', 'OLD FRIENDS RETURN', 1, 32, 9999, 1, 3, 42, 17, '1991-01-01', '', 63, '844/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19941, '2020-04-01 21:04:41.47551+00', '2020-04-01 21:04:41.47551+00', 'Middle Way Rant', 'MIDDLE WAY RANT', 1, 32, NULL, 4, 4, 30, 10910, NULL, 'Devised for non-SCD music: Thulbion’s album Twilight Bound # 9 (Gravel Walk/Andy Renwick''s Ferret/Old Mountain Road). There is a 16 bar introduction followed by a 4x32 dance. All progress one place round, but 2nd & 4th couples change partners each repeat.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19925, '2020-03-29 11:42:55.203783+00', '2020-04-15 18:28:38.32301+00', 'At Long Last', 'AT LONG LAST', 2, 40, NULL, 1, 3, 42, 11361, '1993-01-01', 'Dedicated to John Thoburn (a Quaker) and Tina Mello on the occasion of their wedding, May 30, 1993   



Suggested music: “Merrily Danced the Quaker’s Wife” Scottish Dance Masters Vol 1, by Ron Gonnella and Andrew Rankine



', 50, '880/800/844/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19930, '2020-03-29 13:18:22.606333+00', '2020-08-12 21:45:45.764146+00', 'Groundhog Day', 'GROUNDHOG DAY', 1, 32, NULL, 1, 3, 42, 11643, '2019-01-01', '', 56, '888/800/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19927, '2020-03-29 11:56:38.924424+00', '2020-08-12 21:31:33.579159+00', 'Covid-19 Reel', 'COVID19 REEL', 1, 32, NULL, 1, 3, 42, 11936, '2020-03-01', 'Hands free, of course.', 40, '888/888/800/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19929, '2020-03-29 12:11:30.524907+00', '2020-12-27 11:59:40.114104+00', 'Fergus and His Ladies', 'FERGUS AND HIS LADIES', 2, 40, NULL, 2, 3, 17, 11937, '2020-03-01', 'This dance was inspired by a runner duck we once owned who was very popular with the female ducks in our flock. Fergus led his lady ducks everywhere, and they followed! Because ducks have no hands, there is no giving of hands anywhere in the dance.', 73, '666/844/444/666/788', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19931, '2020-03-29 13:29:20.824459+00', '2021-02-18 18:23:16.175172+00', 'Left in Isolation Jig', 'LEFT IN ISOLATION JIG', 2, 32, NULL, 107, 1, 3, 11938, '2020-03-01', 'Those on facebook may be able to see a video of this dance <<https://www.facebook.com/100006768944029/videos/2674756116093327/?t=0|here>>.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17251, '2016-09-04 11:03:23.727856+00', '2022-05-01 18:06:31.495757+00', 'Mistress Mary', 'MISTRESS MARY', 3, 32, NULL, 2, 3, 18, 3308, '2015-01-01', 'This dance is dedicated to <<ddp:#50|Mary Brandon>>, longtime Dance Mistress of the Los Angeles Branch Demonstration Team. She was an inspiring and demanding teacher, who taught me the value of learning Scottish Country Dancing well. She encouraged me to become a teacher and supported me in my endeavor to do so.



The formation Corner Change & Chase is a variation on one Mary devised for <<ddd:Founders’ Reel#8775>>, a dance commemorating the founding of the Los Angeles Branch, which is published in her book “<<ddpub:Dances with a Difference#394>>".', 62, '444/088/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20275, '2021-03-13 22:04:01.564702+00', '2022-08-15 14:46:50.450399+00', 'Guinea Pigs', 'GUINEA PIGS', 3, 32, NULL, 2, 3, 18, 2887, '2020-08-21', '"This dance is dedicated to the set of dancers (the guinea pigs) who tried out some dancing, including this one, with 2 metre minimum distancing on August 21st 2020."', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14832, '2013-05-18 11:43:51.26544+00', '2022-08-15 08:11:08.270974+00', 'April Antics', 'APRIL ANTICS', 2, 40, 9999, 2, 3, 18, 17, '2006-01-01', '', 92, '804/888/884/628/664', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4273, '1998-04-12 22:00:00+00', '2022-12-03 12:03:51.917644+00', 'McLaughlin''s Reel', 'MACLAUGHLINS REEL', 1, 32, 9999, 1, 3, 42, 15, '1992-01-01', 'The original tune, “Mr. and Mrs. McLaughlin of San Diego” and the strathspey tune “Marjorie Easton McLaughlin” were composed as a gift for Marjorie and Richard McLaughlin for their wedding on the 18th of January 1992, at which Muriel was a surprise guest, at the appropriate moment emerging from an automatic dishwasher box.   



The lively music seemed to match the nature of the recipients and the dance is written in the same vein, as Richard frequently expresses a preference for fast moving, good going dances!

', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (755, '1997-04-03 22:00:00+00', '2021-07-04 19:48:27.32533+00', 'Braes of Yarrow, The', 'BRAES OF YARROW', 3, 32, 9999, 1, 4, 1, 313, NULL, 'The title is from the poem Yarrow Unvisited by William Wordsworth:  

"Whate''er betide, we''ll turn aside,  

And see the Braes of Yarrow."  ', 94, '8888/8888/8484/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20481, '2021-09-12 12:44:37.704241+00', '2021-09-12 12:44:37.704241+00', 'Riversdale', 'RIVERSDALE', 2, 32, NULL, 9, 7, 66, 2682, '2021-01-07', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8814, '2001-09-06 22:00:00+00', '2020-04-05 22:27:43.469504+00', 'Skaters'' Strathspey', 'SKATERS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 2405, '1996-01-01', 'The purpose of this dance is to perform the strathspey on ice skates. To this end, we used as many

continuously flowing formations as we could. So that nobody freezes, we wanted all four couples moving

as much as possible. We also wanted to be able to dance this on a regular dance floor, as well as on ice.', 91, '8888/8888/8888/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8167, '1998-11-01 23:00:00+00', '2020-04-06 15:47:45.003855+00', 'Bouncing Braids', 'BOUNCING BRAIDS', 1, 32, 9999, 1, 3, 42, 2012, '1988-05-21', 'This dance was presented to Carol Mortimer and Peter Schut on the occasion of their wedding day,

May 21, 1988.', 44, '800/822/866/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2102, '1997-09-02 22:00:00+00', '2020-04-06 18:10:33.700652+00', 'Farewell To The Plaidies', 'FAREWELL TO THE PLAIDIES', 3, 32, 9999, 1, 3, 42, 889, '1985-01-01', 'This dance was dedicated to Gene MacKinnon by the Ceilidh Dancers of Ardbrae in May, 1985.  



Suitable music is "Lady Charlotte Bruce" on Broadswords, 33SR153.', 63, '880/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5765, '1998-09-29 22:00:00+00', '2020-04-07 15:33:15.116726+00', 'Rudha Dubh', 'RUDHA DUBH', 1, 48, 9999, 1, 2, 76, 476, NULL, 'The title "Rudha Dubh" means something like *Dark Headland* or *Black Point* (from gaelic *Rudha* and also "Rubha": headland, promontory, point [of land] and *dubh* meaning dark or black - rf. Carmichael et al., 2014, *Gaelic Place Names of Arrochar Parish*).



It remains unclear which "Rudha Dubh" is referred to, because the dance description does not specify a specific one.



There are several places named Rudha Dubh throughout Scotland like on the coast of the Isle of Islay near Lower Killeyan, a small promontory on the north-west corner of Isle of Bute, another on the East cost of the Isle of Tiree, one with a lighthouse built on near Scalasaig on the Isle of Colonsay, or the Black Point jutting into Loch Grunabhat. 



A famous one involves the SS Politician which ran aground the cliffs of Rudha Dubh at island of South Uist in the Sound of Eriskay in 1941 with a cargo including 28000 cases of malt whisky. This event gave the inspiration for the novel "Whisky Galore" and the movie "Whisky Galore!".', 57, '66  66  44  88  88  88', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (9107, '2001-11-21 23:00:00+00', '2020-04-09 13:05:20.298792+00', 'EH3 7AF', 'EH3 7AF', 2, 32, 9999, 1, 3, 42, 146, '1998-01-01', '##>>

EH3 7AF is the postcode for the RSCDS headquarters in Coates Crescent in Edinburgh.



The dance is often referred to informally as *The Postcode Dance*.

##<<

', 47, '800  888  822  844', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (19724, '2019-10-25 10:33:17.424867+00', '2020-04-07 23:17:39.30788+00', 'Midsummer Moon', 'MIDSUMMER MOON', 3, 32, NULL, 2, 2, 76, 11897, '2014-06-01', 'Suggested tune: The Forth Bridge by W. Blythe.  



This dance was devised in June 2014 on the night of a full moon when the beginner’s class only had three dancers plus the instructor. The class had been learning Delvine Side; I think the inspiration is clear. A student, Jodi McEdward, coined the name. It is written as a 6x32 strathspey so that the standing couple always defines the set during the double figures of eight. If numbers do not allow, by all means, dance it as an 8x32 strathspey.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17760, '2017-05-24 21:45:19.892593+00', '2020-04-10 23:06:47.558006+00', 'Diamonds Are Forever Dancing', 'DIAMONDS ARE FOREVER DANCING', 3, 32, NULL, 2, 3, 17, 1331, '2017-04-01', 'Roy and Janet are well-beloved members of the community.  I first met Janet at teacher training in St. Catherine’s Ontario in 1986; she and Roy have brightened my dancing life ever since.  This dance was written at the request of their children and presented at the April 2017 Scottish Country Dance party in Mountain View.



The dance begins with a knot to commemorate the start of their marriage and continues with diamond imagery to celebrate the 60 years since the knot was tied. The poussette at the end is the most romantic figure in Scottish Country Dance.', 58, '880/844/800/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20482, '2021-09-12 12:46:43.988382+00', '2021-09-12 12:46:43.988382+00', 'Freeman of Auchtermuchty, The', 'FREEMAN OF AUCHTERMUCHTY', 1, 184, NULL, 1, 4, NULL, 2682, '2020-05-03', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19945, '2020-04-09 21:32:36.475423+00', '2020-04-09 21:32:36.475423+00', 'Our Dancing Queen', 'OUR DANCING QUEEN', 2, 32, NULL, 1, 3, 42, 2863, NULL, 'Source: MiniCrib.', 63, '844/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19946, '2020-04-09 21:37:22.791669+00', '2020-04-09 21:37:22.791669+00', 'Weather Permitting', 'WEATHER PERMITTING', 2, 32, NULL, 1, 3, 42, 9998, NULL, 'Source: MiniCrib.', 47, '800/822/888/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19947, '2020-04-09 21:53:08.90961+00', '2020-04-09 21:53:08.90961+00', 'Blairgowrie 70', 'BLAIRGOWRIE 70', 2, 32, NULL, 1, 3, 42, 1327, NULL, '', 56, '800/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19948, '2020-04-09 21:56:13.279249+00', '2020-04-09 21:56:13.279249+00', 'Scotts of Torrisdale, The', 'SCOTTS OF TORRISDALE', 1, 32, NULL, 1, 3, 42, 1327, NULL, '', 50, '800/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19949, '2020-04-09 22:11:58.109359+00', '2020-04-09 22:11:58.109359+00', 'Diamond Jubilee 2012', 'DIAMOND JUBILEE 2012', 2, 32, NULL, 1, 4, 1, 3384, NULL, '', 73, '8888/8080/8888/8222', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19950, '2020-04-09 22:17:49.319385+00', '2020-04-09 22:17:49.319385+00', 'Savage Cavy, The', 'SAVAGE CAVY', 1, 40, NULL, 1, 3, 18, 11941, NULL, '', 65, '888/888/888/880/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19944, '2020-04-09 16:33:40.349234+00', '2020-04-10 18:32:14.695757+00', 'Three Bernadettes, The', 'THREE BERNADETTES', 2, 32, NULL, 2, 3, 17, 1502, '2013-01-01', 'Dance devised by Muriel Johnstone for Bernadette Lange, one of the three Bernadettes who met while attending TAC Summer School at Mount Allison University, Sackville, New Brunswick in 2013.



The <<https://youtu.be/PTAz97GHkGk |youtube video>> refers to the dance as "The 3 Bernadettes" which is added as an alias.', 74, '555/888/888/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19951, '2020-04-11 10:32:12.141747+00', '2020-04-11 10:41:47.300161+00', 'Fast Friends', 'FAST FRIENDS', 2, 32, NULL, 1, 2, 76, 2701, '2019-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3788, '1998-09-29 22:00:00+00', '2021-06-27 09:02:12.300504+00', 'Let''s Meet Again', 'LETS MEET AGAIN', 3, 32, 9999, 1, 2, 76, 477, NULL, 'According to a note in Book 23, when originally published, bars 21–24 were ‘advance and retire’ (two bars each way) but this was very soon changed to one step each way twice.', 64, '84/88/88/88', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (19953, '2020-04-12 21:21:25.429634+00', '2020-04-12 21:27:44.166646+00', 'Blarney Stone, The', 'BLARNEY STONE', 1, 32, NULL, 4, 4, 46, 9998, NULL, 'Source: <<https://youtu.be/wqXASAuDPYQ|youtube video>> from Dufftown.', 56, '4040/8080/8080/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8917, '1999-01-05 23:00:00+00', '2020-05-04 14:59:45.312786+00', 'Hill House of Helensburgh, The', 'HILL HOUSE OF HELENSBURGH', 3, 32, 9999, 1, 2, 76, 440, '1993-09-26', 'Devised the day after "Birl for Bob Campbell".   



The Hill House, in Helensburgh, Scotland, was designed by Charles Rennie MacIntosh.  It is now owned by the National Trust for Scotland, and has more visitors than any other Trust property.', 60, '88/66/66/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19943, '2020-04-06 15:18:39.101517+00', '2020-04-13 16:05:54.312243+00', 'Sixty Forty Split', 'SIXTY FORTY SPLIT', 1, 32, NULL, 1, 3, 42, 10374, '2020-01-01', 'To commemorate 100 years of dancing in Waterloo County. The Kitchener Waterloo Branch of the RSCDS celebrates 60 years. Blair Scottish Country Dancers celebrate 40 years. Looking forward to many more years of dancing with both groups.', 50, '840/888/822/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20167, '2020-12-07 18:34:31.360966+00', '2020-12-07 18:34:31.360966+00', 'Bicycle Strathspey, The', 'BICYCLE STRATHSPEY', 3, 32, NULL, 1, 2, 76, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20276, '2021-03-13 22:09:26.178651+00', '2021-03-13 22:09:26.178651+00', 'In the Twinklin'' of an Eye', 'IN THE TWINKLIN OF AN EYE', 1, 40, NULL, 3, 5, 16, 12029, NULL, '"Written in the coronavirus pandemic.  The title indicates how quickly our lives can change."', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11873, '2004-10-31 23:00:00+00', '2021-04-05 11:13:05.673251+00', 'Rampant Unicorn Strathspey, The', 'RAMPANT UNICORN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 479, '2003-10-01', 'Devised: 2003-10', 56, '880/844/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19939, '2020-03-30 02:07:12.399604+00', '2020-04-12 23:05:12.085515+00', 'On The Fly', 'ON THE FLY', 1, 32, NULL, 1, 3, 42, 11940, '2020-01-01', 'Tune: “Marjorie’s Fleet-Footed Departure” composed by Judi Nicolson ©Deeay Music  

Devised by Amy Hoffman, 2020  

The tune was inspired by frantic, early morning packing at the end of the 2014 TAC Summer School in Greeley, Colorado. Due to an unfortunate mishap with an alarm clock, Marjorie awoke to find she had 25 minutes to pack and catch the shuttle to the airport. Thanks to Judi’s determined efforts everything was tossed into the suitcase and Marjorie made it out the door – she even managed to brush her teeth!  

The dance just came to the devisor one day while thinking of something totally different. It was written, so to speak, on the fly. The hope is it can be danced lightly and whimsically, as it was written. The dance and tune have found each other now.

', 38, '800/880/880/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13916, '2011-08-22 22:00:00+00', '2020-04-13 08:47:10.266818+00', 'Jubilee Challenge, The', 'JUBILEE CHALLENGE', 2, 32, NULL, 1, 3, 42, 635, NULL, 'Devised by <<//my.strathspey.org/dd/person/635|Malcolm Brown>>. Dunnington, UK', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13579, '2010-08-07 22:00:00+00', '2020-04-13 08:48:52.920324+00', 'Homecoming Dance, The', 'HOMECOMING DANCE', 1, 32, NULL, 1, 4, 1, 3183, NULL, '', 56, '8000  8440  8044  8888', 0, 1, 1, 0, 56);
INSERT INTO 'dance' VALUES (1773, '1998-11-15 23:00:00+00', '2020-04-13 08:51:06.622053+00', 'Duchess of Atholl''s Slipper, The', 'DUCHESS OF ATHOLLS SLIPPER', 3, 32, 9999, 1, 2, 76, 9998, NULL, '', 52, '84  84  80  88', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (19954, '2020-04-13 09:10:07.24317+00', '2020-04-13 09:19:12.006521+00', 'Silver Love', 'SILVER LOVE', 3, 32, NULL, 2, 3, 17, 11225, '2017-01-01', 'For the 25th wedding anniversary of Helena and João.', 71, '800/844/848/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19308, '2019-05-11 11:07:24.908631+00', '2020-04-13 09:23:03.856635+00', 'Curia Lazy Weasel, The', 'CURIA LAZY WEASEL', 3, 40, NULL, 2, 3, 18, 11225, '2019-01-01', '', 83, '800/888/888/488/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18508, '2018-08-18 10:13:50.004113+00', '2020-04-13 12:05:16.36418+00', 'Welcome to Northern Italy, A', 'WELCOME TO NORTHERN ITALY', 1, 64, NULL, 4, 4, 13, 3698, '2010-01-01', '', 69, '8080/8080/0808/0808/6666/8888/6666/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19955, '2020-04-13 19:07:29.175352+00', '2020-04-13 19:16:47.045003+00', 'Pumps', 'PUMPS', 2, 32, NULL, 1, 3, 42, 11225, NULL, '', 37, '800/633/633/555', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13914, '2011-08-22 22:00:00+00', '2020-04-15 09:29:39.788754+00', 'Happy Anniversary', 'HAPPY ANNIVERSARY', 2, 32, NULL, 1, 2, 76, 64, '2007-08-01', 'Devised by Irene van Maarseveen. Pretoria, August 2007.  



In commemoration of the 35th Anniversary of the RSCDS Pretoria Branch, 2007. Inspired by the dance The Happy Meeting (RSCDS Book 29). ', 69, '44/44/84/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4133, '2002-04-08 22:00:00+00', '2020-04-16 09:51:27.275143+00', 'Mantua Makers', 'MANTUA MAKERS', 1, 32, 9999, 1, 3, 42, 129, '1968-01-01', '', 62, '880  888  888  808', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (5466, '1997-04-03 22:00:00+00', '2020-04-16 13:20:15.257612+00', 'Rambling Pitchfork, The', 'RAMBLING PITCHFORK', 2, 48, 9999, 1, 3, 42, 270, NULL, 'Los Angeles Branch chair Ann McBride (a native of Northern Ireland herself): a "rambling pitchfork" is an itinerant laborer, meaning something like a migrant-worker farmhand.', 57, '800/844/888/844/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5465, '1998-01-04 23:00:00+00', '2020-04-16 13:21:33.585594+00', 'Rambling Pitchfork, The', 'RAMBLING PITCHFORK', 1, 32, 9999, 1, 3, 42, 44, '1970-07-12', 'Devised on Sunday 12th July, 1970. The title is that of an Irish reel. Iain devised the dance after Noeline and he had inadvertently danced a chase instead of the figure of eight in "Corn Rigs" during an evening at the Buchan Street Club in Christchurch - hence the choice of name.  



Suitable recorded music is any arrangement for "Corn Rigs" particularly that of Stan Hamilton.  



Los Angeles Branch chair Ann McBride (a native of Northern Ireland herself): a "rambling pitchfork" is an itinerant laborer, meaning something like a migrant-worker farmhand.', 44, '888/800/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19489, '2019-07-24 20:31:40.915216+00', '2020-04-17 00:45:24.756953+00', 'Winds of Lanzarote', 'WINDS OF LANZAROTE', 1, 32, NULL, 1, 3, 42, 11838, '2004-01-01', 'Devised while being on vacation on Lanzarote – one of the Canary Islands – a very windy place at this occasion.', 44, '800/844/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19869, '2020-03-09 16:29:59.891868+00', '2020-04-18 00:37:59.554869+00', 'Little Donnie in the Pig Pen', 'LITTLE DONNIE IN THE PIG PEN', 1, 48, NULL, 2, 3, 17, 10568, '2017-04-01', 'I heard a tune with this name on Facebook and wrote a dance to go with it. I could never find the tune again but kept the dance.', 81, '800/888/822/844/848/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17670, '2017-03-24 15:13:25.804609+00', '2020-04-17 23:45:21.215183+00', 'Reel of the 88th', 'REEL OF THE 88TH', 1, 40, 9999, 2, 3, 17, 11469, NULL, 'For Mamie Shoolbraid''s 88th birthday in 1989, Derek Bickerton of the Hawaii Branch, devised the playful compilation of figures of eight.', 50, '808/080/440/440/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15435, '2014-05-09 22:09:02.546519+00', '2020-05-12 22:54:30.851214+00', 'Lilibet''s Strathspey', 'LILIBETS STRATHSPEY', 3, 32, 9999, 1, 4, 2, 10595, '2012-06-01', 'Written for Her Majesty, Queen Elizabeth II, in celebration of her Diamond Jubilee. June 2012.

<p>The meaning behind the figures of Lilibet’s Strathspey:

<br>Bars 1-8: Individuals in their families interact with friends, communities and countries.

<br>Bars 9-24: The countries of the Commonwealth are interlinked and are working together in harmony.

<br>Bars 25-32: The people of the world celebrate The Queen’s Diamond Jubilee.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12366, '2005-04-27 22:00:00+00', '2020-12-25 16:47:39.401529+00', 'On Sylvan Lake', 'ON SYLVAN LAKE', 2, 128, 9999, 4, 4, 3, 3583, '2004-05-01', 'A freely downloadable recording of music for this dance is available via <<http://www.fiddletree-music.com/johnturner/scdrecordings.html>>



This dance was dedicated to Ellen Sears of the New York Branch after a memorable Pawling Weekend that she chaired.', 88, '8888/8888/8888/8888/8888/8888/8080/4444/8888/8888/0808/4444/8888/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12908, '2006-10-12 22:00:00+00', '2021-01-05 14:57:41.832246+00', 'Whitewater on the James', 'WHITEWATER ON THE JAMES', 1, 32, 9999, 1, 3, 42, 3583, '2004-01-01', 'A freely downloadable recording of music for this dance is available via <<http://www.fiddletree-music.com/johnturner/scdrecordings.html>>', 58, '828/880/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13309, '2007-07-26 22:00:00+00', '2020-04-18 23:18:44.208832+00', 'Girardet House', 'GIRARDET HOUSE', 3, 32, 9999, 4, 4, 13, 3778, '2005-07-01', 'For Svenja who was my partner when this dance was first tried

For Susanne who was my partner when this dance first appeared on the EMO ball programme 2007



Girardet House is a disused printing works in Essen, which has now been turned into a shopping centre.  It has an Irish pub where the EMO dancers go after their training sessions.



Initially, the name of this dance was misspelled Giradet House.  This name is kept a "spelling alias" to help searches using the misspelled name. The web URL still uses that name (april 2016).



The dance first had the name "EVAG" subtitled "Meals on Wheels". EVAG is the local transport authority Essener Verkehrs Aktiengesellschaft (E.V.A.G.).  The nickname came from a mistake made by the translation programme in my computer, which translated the name of the city, Essen, where I live as "meals". The sub-title has nothing to do with food for Senior Citizens, one of which I am myself.  Essen, Summer 2005

', 75, '4444/4444/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20468, '2021-09-11 23:08:57.794195+00', '2021-09-12 08:51:02.310039+00', 'Red Deer Reel, The', 'RED DEER REEL', 1, 32, NULL, 4, 4, NULL, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17769, '2017-05-29 09:07:56.761835+00', '2023-02-23 12:23:58.520749+00', 'Jaywalking', 'JAYWALKING', 2, 40, NULL, 1, 3, 42, 3772, '2016-05-07', 'Devised as a tribute to the late Jay Fourie.', 63, '880/844/866/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14135, '2011-08-25 22:00:00+00', '2020-04-21 20:26:07.235339+00', 'Bryan and Nori''s Wedding', 'BRYAN AND NORIS WEDDING', 1, 64, NULL, 2, 3, 17, 10449, '1998-11-23', 'Devised to celebrate the wedding of Bryan and Noriko in Tokyo on Monday 23rd November 1998.



The booklet says "Music for this dance can be found on "The Foaming Sea" by Da Fustra (HRMCD002)".  This CD has no music named for this dance, but track 2 is a 6 x 32 Reels that starts with the tune Billy Thom''s Reel.                  ', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19885, '2020-03-11 11:29:24.741438+00', '2020-04-19 13:06:12.015312+00', 'Holly, Would You Pick The Music', 'HOLLY WOULD YOU PICK THE MUSIC', 1, 32, NULL, 2, 3, 17, 11924, '2019-01-01', '', 56, '800/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19957, '2020-04-19 20:00:18.808207+00', '2020-04-19 20:00:18.808207+00', 'Leiden Nuptials', 'LEIDEN NUPTIALS', 3, 32, NULL, 1, 3, 42, 11634, '2019-10-01', 'Devised for Arthur Govan and Marc Weide on the occasion of their wedding.', 47, '880/800/888/44', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5354, '2001-11-21 23:00:00+00', '2020-04-20 16:59:06.010519+00', 'Prince Charles of Edinburgh', 'PRINCE CHARLES OF EDINBURGH', 1, 160, 9999, 4, 4, 3, 846, '1949-01-01', 'The following corrections were included on a loose sheet "Notes on Dances by Bob Grant June 1996", when Book 39 was first sold in the Summer School bookshop:



Fig 1.  17-24  1st and 3rd men face out



Fig 2.  15-16  Use setting to turn''inwards'' to face corner



1-16 (2nd time)  Couples 2 and 4 - no polite turn at end of 1/2 rights and lefts



Tulloch Swing:  It is more usual for couples to link arms, hands cupping elbows, ladies holding dresses and men with free arm raised.  Men 2 cuts and women 2 changes of feet to change direction', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (154, '1997-09-05 22:00:00+00', '2020-04-21 16:21:58.446945+00', 'Angus Reel, The', 'ANGUS REEL', 1, 128, 9999, 4, 4, 3, 633, '1949-01-01', '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (769, '1998-11-14 23:00:00+00', '2020-04-21 16:33:18.408352+00', 'Bratach Bana', 'BRATACH BANA', 1, 32, 9999, 1, 3, 42, 108, '1964-01-01', '##>>

The dance is named for the tune of the same name which John Drewry referred to as *a Gaelic song with a very catchy tune*. This tune was, and is, used by many bands in various reel sets, in addition to being the lead tune for this dance.  



The Gaelic name translates loosely as White Banner and is usually taken to refer to the Fairy Flag of Dunvegan kept at Dunvegan Castle, the seat of Clan Macleod on the Isle of Skye. The flag is the subject of numerous legends.



Note by John Drewry on [27-28]:  I am indebted to Derek Haynes for suggesting this improvement in the dance, originally I had 1st couple and their second corners turning with 2 pas de basque, while retaining promenade hold. 



##<<



Note on [27-28]: O. Otto says best variant is corners in PdB, 1c in SkCh', 47, '800  888  822  844', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (19866, '2020-03-09 16:20:15.322179+00', '2020-04-22 23:56:43.794435+00', 'Jig for Mary Jane, A', 'JIG FOR MARY JANE', 2, 32, NULL, 1, 3, 42, 10568, '2018-10-17', 'I was teaching a dance class on the day that marijuana was legalized across Canada. I felt that deserved a dance. I had just come back from the Ottawa weekend workshop and was inspired by Whig Maleeries, by Derek Ivory in the Imperial Society Book, a dance that Geoffrey Selling taught at that workshop. The serpentine is from Queen City Salute by Dale Birdsall in Book 37.', 58, '804/848/888/666', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14010, '2011-08-24 22:00:00+00', '2020-05-09 07:22:15.008435+00', 'Through the Looking Glass', 'THROUGH THE LOOKING GLASS', 1, 32, NULL, 2, 3, 18, 3753, NULL, 'This may also be danced in a 4 couple set with no changes.', 67, '844/888/804/840', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9125, '2002-08-29 22:00:00+00', '2020-04-23 19:04:47.161968+00', 'Seite an Seite', 'SEITE AN SEITE', 1, 32, 9999, 1, 3, 42, 348, '1995-11-01', '"Seite an Seite" was created in honor of the marriage of Coletta Hill and Armin Busse in March, 1996.  



Recommended Music  

*Loch Leven Castle* on Duncan Smith and Susan Worland''s "Dancin'' Music".', 49, '800/822/884/884', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19959, '2020-04-24 16:40:47.550716+00', '2020-04-24 17:05:19.342547+00', 'Interesting Times', 'INTERESTING TIMES', 4, 128, 2, 4, 4, 13, 10568, '2020-03-01', 'Written while remembering a lovely dance week in Sorrento just before the Covid-19 pandemic.  Interesting times there. Interesting times after.', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19958, '2020-04-24 13:08:44.255617+00', '2020-10-13 20:09:07.142789+00', 'Reel for Renato, A', 'REEL FOR RENATO', 1, 40, NULL, 1, 100, 1, 10568, '2020-03-01', 'Our dancing holiday in Sorrento was cut short by Covid-19, a virus that was spreading throughout the world.  Renato, the hotel owner/manager kept us safe and helped us all get back home.  Despite the problems, it was a great holiday.  This dance will remind me of the camaraderie and joy of dancing that we shared while in Sorrento.', 75, '8800/8888/8888/8484/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17695, '2017-04-01 19:52:29.645606+00', '2020-05-10 09:38:07.826431+00', 'Daily Commute, The', 'DAILY COMMUTE', 4, 64, 5, 1, 3, 42, 10961, '2015-09-01', '', 55, '824/866/866/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19962, '2020-04-27 22:02:28.439415+00', '2020-04-27 22:02:28.439415+00', 'Clapping with the Neighbours', 'CLAPPING WITH THE NEIGHBOURS', 1, 32, NULL, 105, 53, 18, 11509, '2020-04-01', '', 89, '484/888/868/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12053, '2005-02-23 23:00:00+00', '2020-04-28 14:55:05.690789+00', 'Trip to Chicago', 'TRIP TO CHICAGO', 2, 48, 9999, 2, 3, 18, 2408, '2004-01-01', 'Devised 2004 by Lara Friedman-Shedlov, of the Twin Cities Branch, in appreciation of the many happy hours spent dancing at the Chicago Branch’s balls and workshops. Well worth the road trips!  



NOTE: Bars 25-28 and 41-44 are quite quick. The couple in front needs to move more quickly than they think in order to give the couple following enough time to get to place, and the following couple need to stay right behind the leading couple.  



Suggested music: “Eilean Donan Castle,” on the Highlander Music Scottish

Dances Volume 11 (Roy Hendrie and his Scottish Dance Band).', -1, '888/840/844/808/', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19966, '2020-04-27 22:38:14.560114+00', '2020-04-27 23:08:26.496078+00', 'And for the Young Ones', 'AND FOR THE YOUNG ONES', 2, 32, NULL, 4, 2, 4, 11509, '2016-03-01', 'This is a version of the dance with the same name previously published in RSCDS Book 51, but for only 2 couples.', 100, '88/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10590, '2002-06-04 22:00:00+00', '2020-04-28 19:24:39.259179+00', 'Ratcatcher''s Reel, The', 'RATCATCHERS REEL', 1, 32, 9999, 1, 3, 42, 316, NULL, 'This dance was devised for David Rye from West Wales who lists among his many talents and professions, the role of Ratcatcher.', 56, '884/848/862/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19240, '2019-03-11 21:02:15.403761+00', '2022-12-13 23:14:03.95368+00', 'You Are Not Alone', 'YOU ARE NOT ALONE', 3, 32, NULL, 2, 3, 18, 10759, '2019-03-01', 'Devised in March 2019 by Judith Kowalczik and dedicated to Keith Rose and the Scottish Country Dancers from Bedford to say thank you for their support, openness to new ideas and their bravery to take up the challenge of dancing „The Paranoid Jig“ with „Corners Chase and Turn“ in quick time as one of the first groups!', 50, '800/844/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19972, '2020-05-09 22:47:16.719281+00', '2022-08-17 18:45:59.764382+00', 'Romance in St Andrews', 'ROMANCE IN ST ANDREWS', 3, 32, NULL, 2, 3, 17, 11946, NULL, 'The dance was written to mark the occasion of the Royal marriage of Kate Middleton and Prince

William, who met in St Andrews, as well as to celebrate Shelley’s own romantic association with the town. Both she, and fellow Torontonian Fiona Collinson (nee Jamison) – another member of the Georgina Finlay demonstration team – came with a group of Finlay dancers from Toronto over a decade ago to attend Summer School at St Andrews University. It was there that they met their future Scottish husbands, and eventually settled.



', 47, '880/800/844/848', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8918, '1999-01-05 23:00:00+00', '2020-04-27 23:13:27.636948+00', 'Jig for Anne and Tom, A', 'JIG FOR ANNE AND TOM', 2, 32, 9999, 1, 3, 42, 440, '1994-09-01', 'Devised on September 25, 1994, to commemorate the engagement of Anne Quirk and Tom Lightfoot, members of the St. Andrew ’s group.', 50, '800/888/880/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7137, '1997-04-03 22:00:00+00', '2020-04-30 09:06:24.7202+00', 'Wi'' A'' The Honours Three', 'WI A THE HONOURS THREE', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 63, '800/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19448, '2019-06-29 13:44:54.792034+00', '2020-04-29 00:20:40.40462+00', 'Follow the Mouse', 'FOLLOW THE MOUSE', 2, 32, NULL, 1, 3, 42, 2766, '2017-08-01', 'We’ve had mice in the house lately and the cats have been very attentive to them.', 49, '840/880/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2815, '1998-07-06 22:00:00+00', '2020-04-29 14:56:32.917534+00', 'Haunting of Bisham Abbey, The', 'HAUNTING OF BISHAM ABBEY', 4, 48, 9, 1, 4, 5, 270, NULL, '', 64, '8000/8844/8000/8888/6848/8448', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4481, '1997-04-03 22:00:00+00', '2020-04-29 21:45:25.951395+00', 'Miss French of Tayside', 'MISS FRENCH OF TAYSIDE', 3, 32, 9999, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6508, '1997-04-03 22:00:00+00', '2021-05-16 09:40:07.382126+00', 'Thack Cottage, The', 'THACK COTTAGE', 3, 32, 9999, 1, 4, 1, 270, NULL, '', 75, '8888/4444/4444/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16941, '2016-05-09 09:22:20.750641+00', '2020-05-01 14:53:23.387253+00', 'Kumihimo', 'KUMIHIMO', 1, 32, NULL, 1, 3, 42, 2766, '2016-03-01', 'I recently learned to do kumihimo and this dance reminds me of the movements in working the braids. Kumihimo means gathered threads.', 50, '800/866/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16916, '2016-04-15 16:42:43.400968+00', '2020-05-03 05:59:02.340572+00', 'St Albans Reel', 'SAINT ALBANS REEL', 1, 32, NULL, 1, 3, 42, 2766, '2009-06-01', 'Suggested music is Pinewoods Reel from Gie Us Tullochgorum.', 38, '840/840/800/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19968, '2020-05-03 10:13:25.811282+00', '2020-05-03 10:13:25.811282+00', 'Sir David Lindsay Of The Mount''s Strathspey', 'SIR DAVID LINDSAY OF THE MOUNTS STRATHSPEY', 3, 32, NULL, 6, 53, 18, 99, '1990-01-01', 'Devised to commemorate Sir David Lindsay of the Mount (1490-1555), Scottish poet and Lord Lyon King of Arms.', 92, '888/848/884/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19967, '2020-05-03 10:03:53.760194+00', '2020-05-03 11:20:16.293478+00', 'Jumping Joan', 'JUMPING JOAN', 2, 32, NULL, 6, 53, 18, 99, '1990-01-01', '', 100, '888/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18808, '2018-10-05 21:33:35.450877+00', '2020-05-12 21:36:12.224057+00', 'Ladies of a Certain Age', 'LADIES OF A CERTAIN AGE', 1, 32, NULL, 1, 3, 42, 2766, '2011-03-01', 'This dance was written in honor of the six ladies from Toronto who visited our class on March 22nd, 2011 and introduced themselves as "''golf widows'' of a certain age."', 56, '844/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19983, '2020-05-30 18:38:50.762979+00', '2020-05-30 18:41:28.101505+00', 'Ballare a Bologna', 'BALLARE A BOLOGNA', 4, 64, 5, 2, 2, 76, 3690, '2020-05-29', 'Dedicated to <<ddp:#11948>> and his family who have been dancing in Bologna during the current COVID-19 pandemic for all of us who at this time are not able to do so.', 62, '88/88/88/84', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17577, '2017-02-03 17:13:09.118312+00', '2020-05-12 21:50:38.893427+00', 'Toronto Volunteers, The', 'TORONTO VOLUNTEERS', 1, 32, NULL, 1, 3, 42, 10959, '2016-01-01', '', 58, '844/855/888/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (572, '1998-07-06 22:00:00+00', '2020-06-28 21:23:01.25488+00', 'Bliadhna Mhath Ur', 'BLIADHNA MHATH UR', 2, 48, 9999, 1, 4, 1, 270, NULL, 'The name means "A Happy New Year"



As an alternative to crossing on the first bar, a second chord may be played to permit first and third

couples to cross and commence by dancing in and down, this variation being more in accordance with

modern practice.', 77, '8888/8888/4444/8888/4444/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13722, '2011-07-09 22:00:00+00', '2020-09-19 21:01:15.737015+00', 'Diane''s Dilemma', 'DIANES DILEMMA', 1, 32, NULL, 1, 2, 76, 175, NULL, 'Alias: "The Gaviscon Girl".



Haynes adds two footnotes: 



For Diane Rooney and all those who are so busy they don''t know what to do next.    





Since there is very little rest in this dance the less energetic may prefer to dance in 3-couple sets.', 60, '66  88  66  88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (6649, '1997-04-03 22:00:00+00', '2021-05-18 22:30:16.091308+00', 'Top of Ben Lomond, The', 'TOP OF BEN LOMOND', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 69, '888/888/880/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19965, '2020-04-27 22:30:44.434406+00', '2021-08-13 09:33:18.275968+00', 'School At Home', 'SCHOOL AT HOME', 3, 32, NULL, 104, 2, 76, 11509, '2020-04-01', 'We’ve just had five whole weeks of school at home for our two children, which was quite interesting and… different. But I must admit I’m glad to have now two weeks holidays!', 94, '66/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19964, '2020-04-27 22:25:42.855241+00', '2021-08-14 03:16:01.870057+00', 'Football Time', 'FOOTBALL TIME', 1, 32, NULL, 104, 2, 76, 11509, '2020-04-01', 'During this period at home (Coronavirus 2020), we have a lot of time to spend with the family, and at the request of my son Xavier, the four of us are playing football nearly every day, which can actually be great fun. He’s not very found of dancing, but he accepted to participate so that we could be two couples and try out this dance.', 100, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19960, '2020-04-24 23:43:36.046559+00', '2020-05-04 21:34:46.677264+00', 'All Shall Be Well', 'ALL SHALL BE WELL', 3, 32, NULL, 2, 3, 18, 11237, NULL, '“All shall be well and all manner of things shall be well” was the motto of Julian of Norwich, a 14th century woman who survived the Black Death and later became an anchoress, walling herself up in the tower of St Julian’s church after a series of religious visions. She described her views of a benevolent loving deity to those visiting her cell and also in a book, the earliest surviving work by a woman writing in English. This was suppressed by the church, but copies were preserved by an order of nuns until its popular rediscovery in the 20th century. In these times of mass self-isolation even atheist dance devisers may take comfort from her optimism.



As a woman known by a male name, she is represented here by both members of 1st couple who are isolated in the centre for bars 17-24. The last 8 bars depict the ringing of church bells. Although hands would normally be taken here, this phrase may also be danced hands free. The dancers should align in geometric cross shapes at the end of bars 13, 15 and 19.', 92, '844/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3123, '1997-12-28 23:00:00+00', '2020-05-05 00:32:11.561795+00', 'Iona Strathspey', 'IONA STRATHSPEY', 3, 64, 9999, 103, 2, 76, 121, '1993-01-01', 'This is a complicated display dance, which must be taught from the original.  There is little use for a crib.  A diagram might be useful.  



Danced once or twice through, and then followed by a 12-bar coda.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10270, '2001-11-25 23:00:00+00', '2020-05-08 07:57:38.544565+00', 'It All Started in DeKalb', 'IT ALL STARTED IN DEKALB', 4, 32, 1, 1, 3, 42, 2766, '2001-11-01', 'I started dancing in September 1994 at Fermilab with a group that had started in DeKalb, IL a few years earlier. This dance captures my experiences that first night. The first dance I danced was De''il Amang the Tailors, which is reflected in bars 1-8. Later that night the more experienced dancers danced Mairi''s Wedding as a demo for us newcomers. It was that dance that hooked me on Scottish Country Dancing - I wanted to dance that dance! And bars 17-32 are Mairi''s Wedding reels as I prefer to dance them.', 44, '880/800/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6159, '1997-04-03 22:00:00+00', '2022-08-03 07:20:33.697574+00', 'Smith''s a Gallant Fireman', 'SMITHS A GALLANT FIREMAN', 3, 32, 9999, 1, 4, 2, 270, NULL, '', 81, '8008/8888/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19961, '2020-04-27 21:54:49.054813+00', '2022-08-15 13:58:36.586543+00', 'Lockdown Set, The', 'LOCKDOWN SET', 2, 32, NULL, 6, 53, 18, 11509, '2020-04-01', '', 100, '888/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7132, '1997-04-03 22:00:00+00', '2022-11-26 00:07:39.648562+00', 'Who Fears to Speak of the 98', 'WHO FEARS TO SPEAK OF THE 98', 1, 32, 9999, 5, 4, NULL, 270, NULL, 'Editor’s note to the 2021 edition

The original instructions stated a ladies'' chain for second and third couple in bars 17-32. This would be

an impractically long way for the ladies on the diagonal, such that we suggest a men''s chain would be

more appropriate and achieve the same effect.', 100, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19969, '2020-05-05 22:26:20.558208+00', '2020-05-05 22:26:20.558208+00', 'Perthshire Gentleman, The', 'PERTHSHIRE GENTLEMAN', 2, 32, NULL, 1, 3, 42, 316, NULL, '', 53, '840/888/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19970, '2020-05-05 22:33:22.443558+00', '2020-05-05 22:33:22.443558+00', 'Flirt in Isolation', 'FLIRT IN ISOLATION', 3, 32, NULL, 2, 3, 17, 11035, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12052, '2005-02-23 23:00:00+00', '2020-05-07 08:34:37.989367+00', 'Miss Catharine Blair', 'MISS CATHARINE BLAIR', 3, 32, 9999, 1, 4, 1, 787, '2003-01-01', 'In celebration of Miss Catharine Blair’s 82nd birthday, May 25th, 2003. Catharine is one of the original members of the Chicago Branch.', 97, '8668/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1342, '1997-10-15 22:00:00+00', '2020-10-10 12:13:51.265362+00', 'Mr Cosgill''s Delight', 'MR COSGILLS DELIGHT', 1, 16, 9999, 1, 2, NULL, 1000, '1740-01-01', 'Originally entered in SCDDB with title "Coreli''s Gavot" and alias "Mr Cosgill''s Delight" but these are now swapped as the latter is the preferred title (and the former seems misspelled).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13263, '2007-02-27 23:00:00+00', '2020-05-08 17:14:26.04145+00', 'Colin Dewar''s Hornpipe', 'COLIN DEWARS HORNPIPE', 6, 32, 9999, 1, 3, 42, 2419, '2006-05-01', '»Anything the younger generation can do, we can do! Hip Hop, that is! They should try it.«



A dancer owns a copy of the original book, with a loose sheet dated 2008 from Rob Sargent stating that the name of this dance was changed to Colin Dewar’s Hornpipe.   The editors have incorporated that change on this page, leaving Hip Hop Hornpipe as an alias.





HORNPIPE

DEVISED:2006-05', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12158, '2005-04-11 22:00:00+00', '2020-05-09 23:28:20.542586+00', 'Broom and Bracken', 'BROOM AND BRACKEN', 3, 32, 9999, 3, 5, 7, 2525, NULL, 'The dance was republished in The Scottish Banner of August 1997.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12068, '2005-02-23 23:00:00+00', '2020-05-09 23:47:12.705031+00', 'Friday Night at Barbara and Tom''s', 'FRIDAY NIGHT AT BARBARA AND TOMS', 1, 32, 9999, 1, 3, 42, 2766, '2004-12-01', 'Barbara Cool and Tom Senior offer their house for rehearsals for the branch demo team Friday nights throughout the year. This dance is to honor their generosity.', 63, '822/866/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18806, '2018-10-05 19:37:48.659914+00', '2020-05-12 21:44:28.150014+00', 'Wee Reely Progressed', 'WEE REELY PROGRESSED', 3, 32, NULL, 1, 4, 1, 11723, NULL, '', 62, '8888/8800/8080/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19986, '2020-06-04 20:59:06.800241+00', '2020-06-05 17:09:12.613908+00', 'Canberra Bluebell Logo, The', 'CANBERRA BLUEBELL LOGO', 2, 32, NULL, 6, 3, 18, 11956, NULL, '', 75, '444/444/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20000, '2020-06-04 21:45:17.440183+00', '2020-06-04 22:13:03.518952+00', 'Winter in Wasdale', 'WINTER IN WASDALE', 3, 32, NULL, 4, 4, 1, 11237, '2020-04-01', 'The turns and hands across may be danced hands free.', 94, '8484/8888/8888/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20168, '2020-12-07 18:35:51.696701+00', '2020-12-07 18:35:51.696701+00', 'Courtly Strathspey, A', 'COURTLY STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6489, '1997-11-18 23:00:00+00', '2021-01-09 12:04:38.25343+00', 'Tayport Beauty', 'TAYPORT BEAUTY', 2, 32, 9999, 1, 2, 76, 499, NULL, 'According to <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-029-October-1966.pdf|The Thistle, issue 29>>, devised by David Anderson of Dundee (c1850-c1911).', 60, '44  88  88  88', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (19201, '2019-02-25 12:50:16.519992+00', '2021-02-20 13:14:09.594621+00', 'Zsófi''s Delight', 'ZSOFIS DELIGHT', 2, 32, NULL, 1, 3, 42, 316, '2019-01-01', '', 56, '844/844/888/880', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20263, '2021-03-12 16:15:50.291396+00', '2021-03-12 16:15:50.291396+00', 'St Peter One', 'SAINT PETER ONE', 1, 32, NULL, 1, 4, 1, 635, '2009-01-01', 'This dance was written for my very first beginner’s course in St Petersburg in 2009, to teach some of the basics, including the idea of progression. The dance works equally well in a three or five couple set.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20277, '2021-03-13 22:16:28.199509+00', '2021-03-13 22:16:28.199509+00', 'Keep Your Distance', 'KEEP YOUR DISTANCE', 3, 32, NULL, 2, 3, 17, 2887, NULL, 'Dance specifically devised with adapted figures to maintain 2m distance from other dancers.

Where formations are listed for the dance they are the originals the actual figures were adapted from.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (633, '1998-11-10 23:00:00+00', '2021-05-01 19:53:49.152111+00', 'Bonnie Anne', 'BONNIE ANNE', 2, 96, 9999, 1, 4, 3, 9998, NULL, 'Some scepticism about the origin of the dance and its name is <<http://folkdancemusings.blogspot.com/2019/06/bonnie-anne-scotland.html|expressed here>>.', 73, '16 16 16 16   16 14 12 10   4444  8888  4444  4444  8888  8888  8888', 0, 1, 1, 0, 72);
INSERT INTO 'dance' VALUES (2807, '1998-11-19 23:00:00+00', '2021-10-11 22:46:15.622175+00', 'Haste to the Wedding', 'HASTE TO THE WEDDING', 2, 32, 9999, 1, 2, 76, 9998, NULL, '', 52, '80  08  88  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (20508, '2021-10-09 08:44:45.414119+00', '2021-10-14 15:17:10.437184+00', 'Against the Tide', 'AGAINST THE TIDE', 1, 32, NULL, 1, 3, 42, 352, '2008-04-04', '', 50, '800/888/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3942, '1998-07-09 22:00:00+00', '2020-05-14 22:53:37.086897+00', 'Lord Macpherson of Drumochter', 'LORD MACPHERSON OF DRUMOCHTER', 2, 32, 9999, 3, 5, 16, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (159, '2002-08-25 22:00:00+00', '2020-05-15 10:11:18.899021+00', 'Anna Holden''s Strathspey', 'ANNA HOLDENS STRATHSPEY', 3, 32, 9999, 1, 2, NULL, 108, '1991-01-01', '', 64, '88  88  88  84', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (19974, '2020-05-11 22:45:52.748143+00', '2021-08-10 18:01:17.889087+00', 'Dancing Not-in-the-Park', 'DANCING NOTINTHEPARK', 1, 32, NULL, 1, 4, 1, 440, '2011-06-30', 'This may also be danced as a Strathspey.

Devised to thank Teresa Lockhart for her “Not-in-the-Park” night at Bishop Strachan School, to make up for a cancelled night of Dancing In The Park.', 78, '4444/8888/8888/8444', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6928, '1999-05-09 22:00:00+00', '2020-05-15 10:53:52.174307+00', 'Wasatch Mountain Reel, The', 'WASATCH MOUNTAIN REEL', 1, 32, 9999, 3, 5, 7, 1309, '1990-01-01', 'Inscribed to the Wasatch Mountain Club, whose lodge at 8500'' has been the scene of many SCD parties.



A hike in the Wasatch Mountains:  

  1 - 8   The cliffs of Devil''s Castle  

 9-16    Cecret Lake  

17-24   Hiking up mountains and glissading down snowfields  

25-32   The switchbacks in the trails  ', 55, '88088/08880/80008/80800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6885, '2002-04-19 22:00:00+00', '2020-05-15 16:42:36.328182+00', 'Village Reel', 'VILLAGE REEL', 3, 32, 9999, 1, 2, 76, 263, '1794-01-01', '', 52, '88  80  80  88', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (17715, '2017-04-23 06:46:48.399528+00', '2020-05-27 13:10:20.74841+00', 'Trembling String, The', 'TREMBLING STRING', 3, 32, NULL, 2, 2, 76, 3583, '2014-08-01', 'This dance was written as a signature dance for the Lighted Ha’ Ball held annually in the Apple Barn, Valle Crucis NC at the Jink & Diddle School of Scottish Fiddling.', 67, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16579, '2015-08-26 09:44:45.503874+00', '2022-12-02 21:59:26.052879+00', 'Daisy Chain', 'DAISY CHAIN', 4, 128, 13, 4, 4, 3, 234, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17693, '2017-04-01 19:49:00.558873+00', '2022-12-14 16:07:37.272772+00', 'Old Packhorse Bridge, The', 'OLD PACKHORSE BRIDGE', 1, 32, NULL, 1, 3, 42, 10961, '2015-04-01', '', 50, '800/888/664/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3422, '2002-03-02 23:00:00+00', '2023-01-10 11:41:17.345656+00', 'Kelpie of Loch Coruisk, The', 'KELPIE OF LOCH CORUISK', 1, 32, 9999, 9, 7, 66, 313, NULL, 'It will be found that dancers alternate as leading and supporting couples, except that after dancing in 2nd place they will dance as supporting couple again in 7th place. This dance was devised to dance to records that play only seven times through.', 71, '8484844  16 12 16 12 16 12 12  8080800', 1, 1, 0, 0, 71);
INSERT INTO 'dance' VALUES (1943, '1999-05-09 22:00:00+00', '2021-07-12 07:57:40.406301+00', 'Elegant Tern, The', 'ELEGANT TERN', 3, 32, 9999, 1, 3, 42, 1309, '1993-11-01', 'Inscribed to Holly Fuchs.  One of the joys of the San Francisco Branch''s Asilomar weekend is being able to go bird watching at dawn along the beach. Holly''s comment, when I returned from one early-morning bird walk and reported that I had seen my first Elegant Tern, was "An Elegant Tern? That would make a great name for a dance."   



The strathspey two-hand turn is the most elegant turn I know.



', 47, '770/707/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16656, '2015-08-27 17:52:58.71454+00', '2020-05-17 01:24:18.607478+00', 'Muddy Dog Run', 'MUDDY DOG RUN', 1, 32, NULL, 1, 3, 42, 10568, '2014-10-01', 'MISPRINT: The author states that the book has a misprint in bars 9–16.  That should read:



9 – 16	1st couple dance the track for corner pass and turn WHILE 1st corners turn right hand half way and dance out to opposite corner on bars 9 - 12.  2nd corners repeat on bars 13 – 16.  1st couple finish facing their partner’s first corner position (= their first corner person)



A DOCX file with the correct text has been circulated, but printed books with the error are still around.  The cribs in this database are correct.  





The dance was inspired by the name of a back country road that we saw while biking in Vermont with the Kents.  How could I not write a dance with that name?   October 2014









', 47, '800/844/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (805, '1997-11-18 23:00:00+00', '2021-05-01 19:59:13.487988+00', 'Brig o'' Doon', 'BRIG O DOON', 3, 96, 9999, 2, 3, 3, 9998, NULL, 'This dance was collected at Dalmellington in the early 19th Century. It was a great favourite at the balls in that district.', 67, '40/404/800/484  /888/888/888/888    400  400  888  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (20169, '2020-12-07 18:44:11.623857+00', '2020-12-07 18:44:11.623857+00', 'Croydon Strathspey, The', 'CROYDON STRATHSPEY', 3, 32, NULL, 2, 3, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3996, '2002-08-25 22:00:00+00', '2020-05-20 20:09:35.416404+00', 'Nothing in Common', 'NOTHING IN COMMON', 3, 32, 9999, 2, 2, 76, 589, '1994-01-01', 'Information adapted from the publication:



The tune for the dance is MHBHM by Muriel Johnstone. MHBHM are the initials of Susi''s parents, Margaret Hay Bradbrook and Hans Mayr. They say they have nothing in common, hence the title of the dance!



The dance was devised by Susi Mayr on the occasion of her parents'' 40th Wedding Anniversary on 7th August 1994, for which the original tune was commissioned.', 69, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (19979, '2020-05-21 09:41:16.517369+00', '2020-05-27 13:37:47.06719+00', 'Law Society of Scotland 70th Anniversary Jig', 'LAW SOCIETY OF SCOTLAND 70TH ANNIVERSARY JIG', 2, 32, NULL, 1, 2, 76, 11951, NULL, '', 47, '88/84/80/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11073, '2002-12-01 23:00:00+00', '2020-06-03 22:20:54.703496+00', 'Florrie''s Fancy', 'FLORRIES FANCY', 1, 40, 9999, 1, 3, 42, 3277, '1991-01-01', '', 48, '800/822/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17918, '2017-08-09 11:55:47.328782+00', '2020-06-16 15:47:55.148664+00', 'Homemade Jam', 'HOMEMADE JAM', 3, 32, NULL, 1, 116, 11, 11237, '2017-04-01', 'This dance is for Annie Dufaut, an active member of both Geneva and Fourqueux SCD groups.  She enjoys picking fruit and making jam, but does not like eating it, so her friends get the benefit of this tasty hobby.



A recording by Marian Anderson of the music for this dance is available via <<https://my.strathspey.org/u/murrough/recording/>>.', 94, '8888/8448/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19977, '2020-05-20 19:29:21.615267+00', '2020-08-15 07:40:24.657235+00', 'Irene''s Fancy', 'IRENES FANCY', 3, 32, NULL, 1, 4, 1, 11949, '1993-09-27', '', 69, '8444/8888/8000/8488', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20509, '2021-10-09 08:45:35.63066+00', '2021-10-14 15:37:38.295363+00', 'One Hot Christmas', 'ONE HOT CHRISTMAS', 2, 32, NULL, 1, 3, 42, 352, '2005-12-15', '', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (794, '1999-11-01 23:00:00+00', '2020-05-24 23:47:58.849868+00', 'Bridge of Nairn', 'BRIDGE OF NAIRN', 3, 32, 9999, 1, 3, 42, 442, '1757-01-01', 'Nairn is a town on the Moray Firth, north-east of Inverness. It is a tourist resort famous for its golf courses, an annual jazz festival, and one of the largest Highland games in the North. Charlie Chaplin used to go there for his annual holidays.



King James VI. of Scotland (James I. of England) visited Nairn in 1589 and used to boast afterwards that there was a town in his kingdom with a high street so long that the people at one end couldn''t understand the language of those at the other. At the time Nairn consisted of two separate settlements, one Gaelic-speaking and one Scots-speaking.

', 38, '800  822  822  844', 0, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (19437, '2019-06-28 19:04:36.462144+00', '2020-05-26 01:02:28.640113+00', 'Needlelace', 'NEEDLELACE', 1, 32, NULL, 1, 3, 42, 2766, '2017-05-01', 'The figures in this dance remind me of needlelace stitches.', 56, '888/822/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18714, '2018-10-03 09:54:39.354113+00', '2020-05-26 01:25:22.683912+00', 'Comfort and Joy', 'COMFORT AND JOY', 2, 32, NULL, 1, 3, 42, 2766, '2015-12-01', 'Celebrating the holiday season.', 53, '888/422/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18251, '2018-03-11 09:18:13.675444+00', '2020-05-26 09:18:57.722834+00', 'Walk With Me', 'WALK WITH ME', 2, 32, NULL, 1, 3, 42, 11605, NULL, '“Devised for Ramona Zohm and Matthias Rank on the occasion of their wedding on 9th March 2018. In tribute to both of them dancing on both sides, the first couple is encouraged to change sides by advancing in setting step on bars 31-32, dancing the second time through from opposite sides.”', 42, '600/800/888/808', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16769, '2015-09-22 20:53:38.417694+00', '2020-05-26 11:43:01.416369+00', 'Wirral Rambler', 'WIRRAL RAMBLER', 3, 32, NULL, 1, 4, 1, 3584, '2009-06-01', 'Ken danced with RSCDS Wirral Branch during a visit to the UK in May and June 2009. Inspired by the warm welcome he received he devised the above dance which he presented to the Branch on his departure. Many thanks Ken.

', 61, '8008/8888/0880/8222', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2257, '1999-11-01 23:00:00+00', '2020-05-26 16:49:36.33619+00', 'Fly not yet', 'FLY NOT YET', 2, 48, 9999, 1, 2, 76, 9998, NULL, '', 57, '80/80/88/88/88/88', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3160, '1997-09-04 22:00:00+00', '2020-05-27 00:09:36.441067+00', 'It''ll Be Alright on The Night', 'ITLL BE ALRIGHT ON THE NIGHT', 1, 32, 9999, 1, 3, 18, 678, NULL, 'Note:  The position after once through are (3,1x,2x)  



2nd and lst couples rel}eat from new IJositions but men dance ladies'' figures and vice versa. For bars 29-32, second time through, 1st, 2nd and 4th couples dance haH Reel of Three giving nearer hands to partners as they meet.  



If danced as an encore once each couple, 2nd couple start on opposite sides in 2nd place and dance bars 1-28 from second time through then bars 29-32 from first time through.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1864, '1999-11-01 23:00:00+00', '2020-05-27 00:19:43.918528+00', 'Duran Ranger, The', 'DURAN RANGER', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'The Duran Ranger is a Salmon Fly.', 41, '800  880  822  880', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (2024, '1998-09-29 22:00:00+00', '2020-05-27 08:43:53.985658+00', 'Express, The', 'EXPRESS', 2, 40, 9999, 1, 3, 42, 9998, NULL, 'Button and Whitaker''s   Le Sylphe, 1814', 60, '888/888/800/880/888', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (6634, '2000-05-04 22:00:00+00', '2020-05-27 17:35:46.621318+00', 'Todlen Hame', 'TODLEN HAME', 2, 32, 9999, 1, 3, 42, 432, '1816-01-01', '', 50, '880  888  880  800', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (19981, '2020-05-24 08:19:34.302741+00', '2022-08-20 19:38:03.64988+00', 'Jewel in the Crown', 'JEWEL IN THE CROWN', 3, 40, NULL, 1, 4, 1, 10714, '1995-05-21', 'Dedicated to the Consummate Teacher of Teachers. May 21st 1995 at Descanso.', 63, '4444/6666/4444/6666/4844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12241, '2005-04-17 22:00:00+00', '2022-12-19 14:35:46.344879+00', 'Royal Divorce', 'ROYAL DIVORCE', 3, 32, 9999, 1, 3, 42, 11719, '1996-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20001, '2020-06-04 21:46:57.518529+00', '2022-12-22 18:28:31.001149+00', 'Milky Way, The', 'MILKY WAY', 2, 40, NULL, 1, 4, 2, 725, NULL, 'May be danced as a reel or a jig.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6957, '2000-09-05 22:00:00+00', '2020-05-29 01:43:27.229052+00', 'Waverley', 'WAVERLEY', 2, 48, 9999, 1, 3, 42, 432, NULL, 'Source:  Twenty Four Country Dances with Figures by Mr Wilson for the year 1816.  



Note: on each second repetition of the dance, 1st couple dance out between 2nd and 3rd men and, retaining nearer hands, dance down to fourth place as 3rd couple step up.', 69, '444/444/880/880/888/800', 1, 1, 1, 1, 61);
INSERT INTO 'dance' VALUES (3953, '2000-02-21 23:00:00+00', '2020-05-29 01:53:32.74769+00', 'Lord Rosslyn''s Fancy', 'LORD ROSSLYNS FANCY', 2, 32, 9999, 1, 3, 42, 432, NULL, 'Source:  Dances for 1813, published by Button and Whitaker, 1813.', 62, '880/888/880/888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (6739, '1998-02-23 23:00:00+00', '2020-05-29 18:29:19.619704+00', 'Trip to Tobermory, A', 'TRIP TO TOBERMORY', 3, 24, 9999, 1, 2, 76, 108, '1963-01-01', '', 63, '84/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16820, '2015-11-07 02:19:59.748868+00', '2020-05-30 10:18:20.454372+00', 'After Supper Sweeper, The', 'AFTER SUPPER SWEEPER', 3, 32, NULL, 2, 3, 17, 11224, '2015-01-01', 'All the information on this dance comes from the video, which gives the description:



1 - 4-    1st couple (with brooms) sweep down the middle  

5 - 8     1st couple cast up and sweep up the sidelines to top place, while 2nd and 3rd couples dance back to back.  

9 - 16   1st, 2nd and 3rd couples dance mirror reels of three on their own sides  

17 - 24 1st couple dance a fig of eight with a difference round the 2nd couple. – 1st woman crosses down between the 2nd couple, up round 2nd man and across the set (passes the broom to 2nd woman) and casts into 2nd place, while 1st man dances across the set, around 2nd woman, up between 2nd couple (passes the broom to 2nd man) and down around 2nd man and into 2nd place. 2nd couple move up on bars 23 and 24.  

25 - 28 1st and 3rd couples dance half rights and lefts.  

29 – 32 1st and 3rd couples turn with both hands (with rubbish bags) one and a half times to own sides. 



Repeat with new top couple.



', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14264, '2011-09-10 22:00:00+00', '2020-05-31 20:42:58.947913+00', 'Restless Sea, The', 'RESTLESS SEA', 3, 48, NULL, 2, 3, 17, 1228, '2005-02-01', 'For the Bognor Regis S.D.C', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4940, '1997-08-24 22:00:00+00', '2020-06-20 19:43:48.3998+00', 'Newby Circle, The', 'NEWBY CIRCLE', 1, 32, 9999, 5, 2, NULL, 175, '1991-01-01', 'In memory of Bill Newby who contributed so much to Scottish Country Dancing in South Lakeland', 75, '80  08  88  88', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (1772, '1997-12-03 23:00:00+00', '2020-10-10 12:16:53.758962+00', 'We''ll Wed and We''ll Bed', 'WELL WED AND WELL BED', 2, 24, 9999, 1, 2, NULL, 446, '1710-01-01', 'Originally entered in SCDDB with title "Dublin Bay" and alias "We''ll Wed and We''ll Bed" but these are now swapped as the latter is the preferred title.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20170, '2020-12-07 18:45:13.010837+00', '2020-12-07 18:45:13.010837+00', 'Taffy''s Tricks', 'TAFFYS TRICKS', 3, 32, NULL, 2, 3, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20278, '2021-03-13 22:20:12.622132+00', '2021-03-13 22:20:12.622132+00', 'Lakeland at Night', 'LAKELAND AT NIGHT', 1, 32, NULL, 2, 3, NULL, 12029, '2020-08-01', 'Dance specifically devised with adapted figures to maintain 2m distance from other dancers. Where formations are listed for the dance they are the originals the actual figures were adapted from.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18875, '2018-10-07 12:35:47.423213+00', '2020-05-30 23:33:04.016976+00', 'Ammolite', 'AMMOLITE', 3, 32, NULL, 1, 3, 42, 2766, '2016-11-01', 'Ammolite is a fossil of an ammonite and is found only in southern Alberta. It makes lovely jewelry and my husband bought me a piece and had it made into a necklace for me. Ammonite shells spiral out from the center and the figure in bars 1-8 seems to me to spiral.', 41, '880/804/633/633', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7652, '1998-04-24 22:00:00+00', '2021-07-20 08:39:28.36981+00', 'Colonel is a Lady, The', 'COLONEL IS A LADY', 2, 40, 9999, 1, 3, 42, 108, '1988-01-01', 'This dance was written as a reel but was later changed to jig time.



Susi Mayr posted in https://www.strathspey.org/lists/strathspey@strathspey.org/t/43426/



Here''s some additional information from Atsuko Clement:



"At the time of Muriel''s retiral  during Summer School, Bill made up a tune

in jig time for her.  At the same time John made a dance in reel time for

her.  Then both discovered that each made up a dance or tune.  So, they agreed

to match up the dance and tune.  Hence the original of dance was a reel,

but now it is a jig."



Susi', 65, '808/888/888/888/880', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4147, '1997-08-20 22:00:00+00', '2020-05-31 10:25:35.947916+00', 'Marchmont Eightsome, The', 'MARCHMONT EIGHTSOME', 1, 96, 9999, 4, 4, 3, 101, '1993-01-01', '', 92, '8888/8888/8888/8888/8888/8080/0808/8888/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4362, '2003-01-27 23:00:00+00', '2020-05-31 20:41:09.650605+00', 'Midlothian', 'MIDLOTHIAN', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8023, '1998-01-04 23:00:00+00', '2020-05-31 20:42:04.02713+00', 'Bees in the Heather, The', 'BEES IN THE HEATHER', 3, 32, 9999, 2, 3, 17, 1374, NULL, '', 81, '888/888/044/868', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18321, '2018-05-02 18:18:40.36535+00', '2020-05-31 20:43:21.868057+00', 'Memories are made of this', 'MEMORIES ARE MADE OF THIS', 1, 40, NULL, 1, 4, NULL, 11139, '2012-02-22', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9722, '2000-11-17 23:00:00+00', '2020-05-31 21:19:58.389604+00', 'Saint Andrew''s Day', 'SAINT ANDREWS DAY', 2, 40, 9999, 1, 2, NULL, 2824, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14572, '2012-09-13 16:04:18.061968+00', '2020-06-02 01:12:33.035042+00', 'Wee Dram Before Tea, A', 'WEE DRAM BEFORE TEA', 3, 32, NULL, 1, 3, 42, 10593, NULL, 'For more advanced dancers, reels of three may be substituted in bars 17-24.



When we traveled through Scotland, my husband and I began a tradition of enjoying our new surroundings each day by having ‘a wee dram before tea’. It was very relaxing – like this dance.

', 44, '880/880/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14573, '2012-09-13 16:05:22.998979+00', '2020-06-02 22:52:32.907329+00', 'Katherine''s Birthday', 'KATHERINES BIRTHDAY', 1, 32, NULL, 1, 2, 76, 10593, '2006-10-30', 'The dance is inscribed to Katherine Mackenzie on her 12th birthday, October 30, 2006.  



Suggested Music: Marilyn’s Reel from the CD “The Devil’s Quandary”.', -1, '80/88/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12445, '2005-06-05 22:00:00+00', '2020-06-03 22:22:06.497563+00', 'Mary Wattum''s Reel', 'MARY WATTUMS REEL', 1, 32, 9999, 1, 3, 42, 929, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20171, '2020-12-07 18:46:21.358084+00', '2020-12-07 18:46:21.358084+00', 'Seaside Frolic', 'SEASIDE FROLIC', 3, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19985, '2020-06-04 20:53:35.161249+00', '2020-06-04 20:53:35.161249+00', 'Barley Twist, The', 'BARLEY TWIST', 1, 48, NULL, 1, 4, 13, 11955, NULL, '', 58, '8880/8880/4444/4444/0448/4408', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19994, '2020-06-04 21:26:03.916412+00', '2020-06-04 21:26:03.916412+00', 'Birthday Cake, The', 'BIRTHDAY CAKE', 1, 32, NULL, 1, 3, 42, 3723, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19996, '2020-06-04 21:32:32.855476+00', '2020-06-04 21:32:32.855476+00', 'Here We Go', 'HERE WE GO', 3, 32, NULL, 1, 3, 42, 3723, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19997, '2020-06-04 21:37:04.681561+00', '2020-06-04 21:37:04.681561+00', 'Scotch Eggs', 'SCOTCH EGGS', 3, 32, NULL, 2, 3, 17, 3723, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19998, '2020-06-04 21:40:45.133378+00', '2020-06-04 21:40:45.133378+00', 'Touch and Go', 'TOUCH AND GO', 2, 40, NULL, 1, 3, 42, 3723, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19999, '2020-06-04 21:45:01.440307+00', '2020-06-04 21:45:01.440307+00', 'White Rose (of Christmas), The', 'WHITE ROSE OF CHRISTMAS', 3, 32, NULL, 1, 3, 42, 3723, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19990, '2020-06-04 21:08:39.332208+00', '2020-06-05 17:29:08.001216+00', 'Kelly''s Bush', 'KELLYS BUSH', 1, 32, NULL, 1, 2, 76, 325, NULL, 'Late last century, Kelly’s Bush, a small parcel of government land in Sydney overlooking the Parramatta River, on the Hunter’s Hill/Woolwich peninsula, was deemed redundant to requirements. Strong protests from the local residents, and others, saved it from development, and it has been retained as a pleasant riverside park, enjoyed by all.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19991, '2020-06-04 21:12:43.721796+00', '2020-06-05 17:41:38.452447+00', 'Orchard, The', 'ORCHARD', 3, 32, NULL, 2, 3, 17, 11585, NULL, 'The <<ddpub:#1547|2nd Canberra Book>> suggests using "Silver Grey” Track 7 from the CD “Haste Ye Back” Muriel Johnstone’s Scottish Dance Band. However track 7 on that CD is actually "Hope Little''s Strathspey". There is a recording of Silver Grey by Luke Brady. It is not clear which is intended.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19993, '2020-06-04 21:18:25.160278+00', '2020-06-05 18:10:38.525941+00', 'Winter Wanders', 'WINTER WANDERS', 2, 32, NULL, 1, 3, 42, 11890, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20224, '2021-02-21 15:44:37.409966+00', '2021-02-21 15:57:54.724532+00', 'Knight''s Honour', 'KNIGHTS HONOUR', 3, 32, NULL, 1, 3, 42, 440, '2020-07-28', 'Devised in memory of Susan Knight.', 59, '888/822/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17703, '2017-04-02 08:44:31.222168+00', '2021-01-19 16:26:30.680599+00', 'Yowdendrift', 'YOWDENDRIFT', 1, 40, NULL, 1, 3, 42, 11164, '2017-01-01', '‘Yowdendrift’ is a Scots word meaning snow being blown by the wind.', 49, '880/828/880/800/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14310, '2011-11-04 23:00:00+00', '2020-10-13 09:45:01.357358+00', 'Over the Water to Charlie', 'OVER THE WATER TO CHARLIE', 7, 96, 9999, NULL, 51, NULL, 401, '1991-12-01', 'Step Dance. [For the country dance see <<ddd:#5136>>].   



Notes prepared by Ron Wallace, 1991  



Sources:  

Highland and Traditional Scottish Dances, D.G. MacLennan  

            Scottish National Dance Company, leaflet  

             National Dance Book of the Scottish Dance Teachers Alliance  

             Hebridean Solo Dances, Jack McConachie  



', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19984, '2020-06-04 19:47:02.916746+00', '2020-12-06 10:21:29.478701+00', 'Jig for Julian, A', 'JIG FOR JULIAN', 2, 32, NULL, 1, 3, 42, 11286, NULL, 'To remember Julian Crawford, enthusiastic Scottish Country dancer and long-time member of Ardoch Church Scottish Country Dance Group, Braco, Perthshire, who sadly died on Monday March 9 2020, following a long illness. Julian loved putting all kinds of twirls and birls into his dancing so some of them are included in this dance in his memory.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19995, '2020-06-04 21:28:58.190117+00', '2021-05-10 17:20:50.571905+00', 'Cardigan Back 80', 'CARDIGAN BACK 80', 2, 40, NULL, 1, 3, 42, 3723, NULL, '', 60, '808/844/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20510, '2021-10-09 08:46:29.987623+00', '2021-10-09 08:46:29.987623+00', 'Wish is Granted, A', 'WISH IS GRANTED', 3, 32, NULL, 1, 4, 13, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19987, '2020-06-04 21:01:59.861579+00', '2020-06-05 17:19:55.720358+00', 'Effsiesse', 'EFFSIESSE', 1, 32, NULL, 1, 3, 42, 11955, NULL, 'Effsiesse is a courtship dance, in the manner of “Catch the Wind”. The name derives from the idea behind each of the 8 bar phrases and forms the mnemonic FCSC:- Beginning with flirting in the parallel reel where dancers get the briefest of moments of eye contact with partners as they cover across the set. Then the dancing couple’s chase – more flirting as the woman leads, and man follows, some indecision as they turn away and towards each other dancing up the set until the woman turns to meet her partner. Then the 1st couple’s solo (hands held throughout), and finally the others join in for a celebratory circle.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19988, '2020-06-04 21:03:57.740896+00', '2020-06-05 17:23:15.529879+00', 'Hands Across the Sea', 'HANDS ACROSS THE SEA', 1, 32, NULL, 1, 3, 42, 11957, NULL, 'Note: The dance can also be danced in three-couple sets. 3C or 4C sets should be arranged so that each has at least one other similar sized set beside it. This allows bars 9–12 to be modified so that 1st woman and 3rd man dance right hands across with 1st man and 3rd woman from the adjacent set (and thereafter return to continue dancing in their own sets). The right hands across with dancers from the adjacent set represents "Hands Across the Sea".', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19989, '2020-06-04 21:07:08.475748+00', '2020-06-05 17:27:16.910402+00', 'Jeannie o'' Langside', 'JEANNIE O LANGSIDE', 2, 48, NULL, 4, 55, 38, 325, NULL, 'Devised by Olivia Roberts (RSCDS Sydney) “for my friend Jeannie, who lived near the site of the Battle of Langside (1568) in which troops loyal to Mary, Queen of Scots, were defeated, after the Queen was forced to abdicate (on account of the questionable murder of her second husband, Lord Darnley). The district is now a suburb of Glasgow”.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18446, '2018-07-19 14:18:28.324636+00', '2020-06-05 17:34:59.489287+00', 'Let''s Bike it', 'LETS BIKE IT', 2, 40, NULL, 1, 3, 42, 10907, NULL, 'Devised for Gregor and Sheila Wills, who enjoy bike riding as one of their pastimes. Note: At the beginning of the third time through, as the new 1st couple cast, the old 1st couple cast to fourth place and the 2nd and 4th couples step up.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19992, '2020-06-04 21:15:12.587394+00', '2020-06-05 17:58:37.669284+00', 'Tangle o'' the Isles, The', 'TANGLE O THE ISLES', 3, 32, NULL, 1, 4, 2, 11956, NULL, 'Notes from the book:



To be danced with “braggart in your step”.



The name of the dance is taken from the song “The Road to the Isles”, written for a tune that was collected on the Hebridean island of Barra:



*Sure by Tummel and Loch Rannoch and Lochaber I will go,*  

*By heather tracks wi’ heaven in their wiles*  

*If it''s thinkin'' in your inner heart the braggart''s in my step,*  

*You''ve never smelled the tangle o'' the Isles.*



The dance is a memento of a survey of “tangle” (seaweed) ecology undertaken long ago in the tide race along the Loch Obe gorge on Barra’s east coast. All dancers move ceaselessly throughout, simulating perpetual swirling of tangle fronds in the turbulence of tide and wave. Bars 1-8 represent movement of tangle fronds during the ebb and flow of the tide; in 9-16 they swirl away and back again as waves surge and recede; in 17-24 they are in a whirlpool with marginal eddies and in 25-32 they are displaced by turbulence and rotate in new locations, awaiting the next tide.', 100, '8888/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3986, '1998-09-29 22:00:00+00', '2020-06-06 17:22:43.300311+00', 'Lucy Campbell', 'LUCY CAMPBELL', 1, 32, 9999, 1, 2, 76, 9998, NULL, 'The RSCDS publication "Scottish Country Dances Books 13-18" states that this dances originates from *an old book of Scottish and Irish dances (title page lost)*.  [Thus, if somebody knows more of the whereabouts of this book, please let us know by hitting the "Submit Correction/Addition" button.]', 62, '88  88  64  88', 1, 1, 1, 1, 90);
INSERT INTO 'dance' VALUES (7939, '1997-09-13 22:00:00+00', '2020-06-07 17:14:48.016934+00', 'Sea Anemone', 'SEA ANEMONE', 3, 32, 9999, 1, 3, 42, 667, NULL, 'Some curious information shared by Bruce Herbold on June 6, 2020 on the Web:

The dance was taught before it was named so the teacher called it "sine nomine" (''nameless'') which became "Sea Anemone" when it was time to name the dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8110, '1997-10-13 22:00:00+00', '2020-06-09 14:41:55.985601+00', 'Traquair House', 'TRAQUAIR HOUSE', 1, 40, 9999, 1, 3, 42, 371, NULL, 'Via e-mail, From: Benjamin Stein, Burlington, Vermont USA, Dancers@Compuserve.Com, on 13 Oct 1997: This dance, though modern in form, uses all traditional figures, reflecting the long tradition of Traquair House, located in the Borders between Innerleithen and Peebles. It is the legendary home of the Stewarts of Traquair, contains the oldest house in continuous habitation in Scotland and was visited several times by Mary Queen of Scots, an ardent dancer.



', 55, '800  844  844  888  888', 0, 1, 1, 0, 73);
INSERT INTO 'dance' VALUES (20003, '2020-06-09 21:09:55.555828+00', '2020-06-09 21:09:55.555828+00', 'Shine on Scotland', 'SHINE ON SCOTLAND', 3, 32, NULL, 1, 4, 2, 99, '2008-01-01', 'To commemorate the 60th anniversary of Marie Curie Cancer Care (1948–2008)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20004, '2020-06-09 21:12:31.80917+00', '2020-06-09 21:12:31.80917+00', 'Daffodil Jig, The', 'DAFFODIL JIG', 2, 32, NULL, 1, 3, 42, 99, '2008-01-01', 'To commemorate the 60th anniversary of Marie Curie Cancer Care (1948–2008)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20005, '2020-06-09 22:10:08.456435+00', '2020-06-09 22:10:08.456435+00', 'Fingle-Fangle, The', 'FINGLEFANGLE', 2, 32, NULL, 107, 55, NULL, 99, '1988-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20007, '2020-06-09 22:13:12.498477+00', '2020-06-09 22:13:12.498477+00', 'Razzle-Dazzle Reel, The', 'RAZZLEDAZZLE REEL', 1, 32, NULL, 107, 55, NULL, 99, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20008, '2020-06-09 22:15:09.662974+00', '2020-06-09 22:15:09.662974+00', 'Mixter-Maxter Medley', 'MIXTERMAXTER MEDLEY', 4, 32, 1, 107, 55, NULL, 99, '1993-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3251, '2000-11-12 23:00:00+00', '2020-07-07 11:00:13.344959+00', 'Jig for Heather, A', 'JIG FOR HEATHER', 2, 32, 9999, 1, 3, 42, 347, NULL, 'In memory of Heather Walsh who was a guest on several of the deviser''s Holiday Fellowship trips and died in December 1992 after a short illness.', 53, '880/880/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17397, '2016-10-04 16:02:11.513877+00', '2020-06-10 07:46:15.975698+00', 'Excited States', 'EXCITED STATES', 1, 32, NULL, 1, 3, 42, 11387, '2016-01-01', 'This dance is dedicated to the dancers in the San Francisco Bay Area who are still eager to dance Petronella after dancing for a full evening. Upon request, the musicians are often happy to play it after the final waltz, and commonly two or more sets spontaneously form and dance it eight times through with mostly-controlled abandon.  The title refers to the arrangement of electrons that occurs after energy is added to an atom or molecule. Such excited states are often unstable until they release the energy and return to the ground state.', 64, '808/888/882/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1438, '1997-08-31 22:00:00+00', '2020-06-10 13:00:47.908797+00', 'Cropie''s Strathspey', 'CROPIES STRATHSPEY', 3, 32, 9999, 2, 3, 17, 270, NULL, '', 56, '660/880/824/228', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20009, '2020-06-12 13:01:09.187142+00', '2020-06-12 13:01:09.187142+00', 'Kaiwaka Returns', 'KAIWAKA RETURNS', 1, 32, NULL, 1, 3, 42, 11903, '2020-01-01', 'Posted on Facebook SCD Teachers by Elaine Goldthorpe, 9 June 2020', 53, '800/822/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20011, '2020-06-14 22:46:37.525181+00', '2020-06-14 22:46:37.525181+00', 'Currall Reel, The', 'CURRALL REEL', 3, 40, NULL, 1, 4, 1, 11585, NULL, 'Information derived from the <<https://youtu.be/lwNxNARAwKQ|youtube video>>.', 73, '8888/8888/8400/8440/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7572, '1997-09-02 22:00:00+00', '2020-06-21 09:01:00.511905+00', 'Falls of Clyde, The', 'FALLS OF CLYDE', 4, 64, 9999, 5, 56, 76, 50, '1979-01-01', 'The sailing ship "Falls of Clyde" was launched on December 12, 1878, in Port Glasgow, Scotland, and was used for decades to transport sugar from Hawaii to California. The dance was devised in 1979 to honor the ship and to support community efforts to preserve and restore it.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20006, '2020-06-09 22:11:54.726838+00', '2020-06-19 12:56:57.831691+00', 'Quinary Strathspey, The', 'QUINARY STRATHSPEY', 3, 32, NULL, 107, 55, 16, 99, '1993-01-01', '', 80, '88880/88844/84488/44888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13780, '2011-07-24 22:00:00+00', '2020-06-14 23:15:03.58877+00', 'Room One', 'ROOM ONE', 2, 32, NULL, 2, 3, 17, 2682, '2011-07-05', 'Devised 5th July 2011. This came after teaching a class of 9 and 10 year old children, and wanting to write a dance which had elements of Noeline O’Connor’s “Kingston Flyer” and Tang’s “A Trip to Gatlinberg.” The young dancers were confused with progressions so I sought to write a simple dance for them.  

I use any reasonable 6 by 32 J, and for the class I used an unobtainable (and amazing) 6 by 32 recording of “Todlen Hame” recorded long ago by Jimmy Shand on a 45.', 75, '888/444/444/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13782, '2011-07-24 22:00:00+00', '2020-06-14 23:23:11.924826+00', 'Xiaowen', 'XIAOWEN', 2, 48, NULL, 2, 3, 17, 2682, '2010-07-25', 'Devised 25 July, 2010. Given to Xiaowen Yu (daughter of Monica). The first 16 bars are taken from a a dance devised by Iain Boyd which in turn uses an idea by Alec Hay. Recommended music is “An’ Thou Wert My Only Dear” preferably played ABABAB, and there is no recording of this with only 3 repetitions.

The RSCDS recording of Book 21 by John Renton and his band, track 3 is an excellent 8 by 32 version. Acceptable alternative music would be “Balcomie House” as recorded by e.g. The Lothian Band (“In Strict Tempo”, track 1) or The Irvine Valley SCD Band (Favourite SCD’s Vol 3, Teacher’s Choice, track 11)', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18288, '2018-04-23 23:32:42.544897+00', '2020-06-16 15:48:28.992694+00', 'Fidèle de Lausanne, La', 'FIDELE DE LAUSANNE', 3, 32, NULL, 6, 3, 18, 11237, '2018-03-01', 'Dedicated to Vanessa de Schoene who has been faithfully caring for the Scottish Country Dance group in Lausanne almost since time immemorial.



A recording by Marian Anderson of the music for this dance is available via <<https://my.strathspey.org/u/murrough/recording/>>.', 83, '800 888 888 888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13575, '2010-05-30 22:00:00+00', '2020-06-16 18:28:49.895103+00', 'Tokyo 25th Reel, The', 'TOKYO 25TH REEL', 1, 32, 9999, 1, 3, 42, 246, '2009-03-01', 'A dance devised to mark the Silver Jubilee of the Tokyo branch of the RSCDS.', 59, '800/888/888/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20013, '2020-06-16 19:48:56.845401+00', '2020-06-16 19:48:56.845401+00', 'Class of ''13', 'CLASS OF 13', 1, 40, NULL, 3, 5, 7, 11415, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20014, '2020-06-16 19:53:59.488647+00', '2020-06-16 19:53:59.488647+00', 'Jim Stott''s Strathspey', 'JIM STOTTS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11415, NULL, '', 56, '880/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20015, '2020-06-16 19:59:11.337656+00', '2020-06-16 19:59:11.337656+00', 'Red and Gray', 'RED AND GRAY', 1, 32, NULL, 1, 2, 76, 11415, NULL, 'Devised for James Gray who requested it feature <<ddd:Red House>> reels.', 52, '80/88/84/84', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20016, '2020-06-16 20:06:24.654591+00', '2020-06-16 20:06:24.654591+00', 'Gael Forse Reel', 'GAEL FORSE REEL', 1, 32, NULL, 1, 3, 42, 11415, NULL, 'Devised for Gael Forster who requested a reel with set to corners and partner.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20020, '2020-06-16 20:42:41.044856+00', '2020-06-16 20:42:41.044856+00', 'Punting on the Cam', 'PUNTING ON THE CAM', 3, 32, NULL, 1, 4, 1, 11415, NULL, 'Devised for Tom Ibbotson.', 81, '8888/8080/8888/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20023, '2020-06-16 20:57:46.015058+00', '2020-06-16 20:57:46.015058+00', 'Daniela''s Reel', 'DANIELAS REEL', 1, 40, NULL, 1, 3, 42, 11415, NULL, '', 40, '880/800/880/822/822', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20024, '2020-06-16 21:04:11.061118+00', '2020-06-16 21:04:11.061118+00', 'Carol-Ann''s Jig', 'CAROLANNS JIG', 2, 32, NULL, 1, 3, 42, 11415, NULL, 'For Carol-Ann Stewart.', 50, '646/484/880/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20026, '2020-06-16 21:28:18.277568+00', '2020-06-16 21:28:18.277568+00', 'Gill with a "G"', 'GILL WITH A G', 3, 32, NULL, 1, 4, 1, 11415, NULL, 'For Gill Jennings, "teacher and my Teaching Certificate mentor, in appreciation of her efforts in teaching Scottish country dancing to the Sutton Coldfield Branch".', 84, '4444/8888/8488/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19675, '2019-09-26 11:12:42.909083+00', '2020-07-08 11:34:21.536693+00', 'Moments in Time', 'MOMENTS IN TIME', 3, 32, NULL, 1, 4, 1, 135, NULL, 'Moments in Time - The moment when the toe meets the ground to the beat of the music.', 81, '8888/8448/8888/8080', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20018, '2020-06-16 20:18:14.400282+00', '2022-07-09 11:32:29.977475+00', 'Martine Guilbert Strathspey', 'MARTINE GUILBERT STRATHSPEY', 3, 32, NULL, 1, 4, 1, 11415, NULL, '', 66, '8800/8228/8888/4084', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20022, '2020-06-16 20:53:35.540632+00', '2022-07-09 18:55:23.576481+00', 'Harry''s Reel', 'HARRYS REEL', 1, 40, NULL, 1, 3, 42, 11415, NULL, 'For Harry Richmond.', 50, '880/844/844/800/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20021, '2020-06-16 20:47:49.490508+00', '2022-07-09 13:12:07.979011+00', 'Reel for Annette, A', 'REEL FOR ANNETTE', 1, 32, NULL, 1, 102, 1, 11415, NULL, 'For Annette Lotz.', 91, '8888/8888/6464/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1958, '1997-04-03 22:00:00+00', '2022-08-11 23:20:22.911664+00', 'Ellen Richard''s Delight', 'ELLEN RICHARDS DELIGHT', 2, 256, 9999, 1, 4, 3, 270, NULL, '', 88, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20025, '2020-06-16 21:19:33.802538+00', '2022-07-11 15:14:18.51285+00', 'Jig for Robert, A', 'JIG FOR ROBERT', 2, 32, NULL, 2, 3, 17, 11415, NULL, 'For Robert Templeton. "He requested a dance in quicktime containing tandem rights and lefts for 3 couples, a progression which, I believe, he invented."', 52, '800/888/622/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20012, '2020-06-16 18:21:53.60926+00', '2022-10-03 23:01:23.413104+00', 'Freedom from Lockdown', 'FREEDOM FROM LOCKDOWN', 1, 32, NULL, 1, 2, 76, 11961, '2020-04-01', 'This dance is about being able to dance with our friends and family again. It helps us remember having fun and making memories like we did before Corona forced us all to stop dancing for a while.

', 69, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20027, '2020-06-16 21:51:42.820077+00', '2020-06-16 21:51:42.820077+00', 'Corona Dance, The', 'CORONA DANCE', 2, 32, NULL, 7, 113, 4, 11232, '2020-06-11', 'Written on 11 June 2020 to mark the first physical get-together for Brussels Dance Scottish after 3 months of lockdown due to COVID-19. Incidentally, the dance also mimics the relief of the virus (circle with tentacles).



Being inspired by “Jig to the Music”, the music for this dance can of course be used, but any good and cheerful jig or reel will do. “Scotch Circle” (6x32R) from the CD by Alastair Fraser & Muriel Johnstone “Just as it Was 1”, track 2) would be my suggestion.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18245, '2018-02-21 17:14:51.864304+00', '2020-06-17 15:04:35.082264+00', 'Bubbly and Cake', 'BUBBLY AND CAKE', 1, 32, NULL, 1, 3, 42, 11094, '2018-02-01', 'Devised on the occasion of Peter Dixon''s 80th birthday in February 2018.

2018 is also the 60th anniversary year of South East Herts Scottish Country Dance Society of which he has been a member since 1959', 56, '800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20029, '2020-06-17 23:24:42.40631+00', '2020-06-17 23:24:42.40631+00', 'Fare Ye Weel', 'FARE YE WEEL', 1, 32, NULL, 1, 3, 42, 11164, NULL, 'Devised as farewell to Keith Paterson, who danced in our Dresden group for five years.', 47, '800/888/844/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1051, '1997-04-03 22:00:00+00', '2021-08-05 09:57:03.544595+00', 'Carrick Lass, The', 'CARRICK LASS', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 50, '800/884/848/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20028, '2020-06-17 23:18:41.899286+00', '2020-07-15 08:34:56.7673+00', 'Take Two', 'TAKE TWO', 4, 128, 10047, NULL, 1, NULL, 11164, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11724, '2004-06-17 22:00:00+00', '2020-06-21 09:41:38.523265+00', 'Dear David', 'DEAR DAVID', 3, 32, 9999, 1, 3, 42, 3439, NULL, 'Stella Fogg devised "Dear David" after she overheard someone tell Mary,

"David was such a dear man".  Mary''s face lit up, and she agreed that

David was a "very dear man," who was also a superb teacher whose

patience with beginners was amazing, and a tireless promoter of Scottish

Country Dancing.  Stella first met David and Mary in Hawaii in the

mid-seventies and through the years they became close friends.', 53, '800/888/866/844', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (12247, '2005-04-19 22:00:00+00', '2020-06-21 10:16:29.412787+00', 'Dominie, The', 'DOMINIE', 3, 64, 9999, 1, 4, 22, 50, '1962-01-01', '"Dominie" is a Scots word for teacher.  Also known as "Mackay of

Barrhead," Mary Brandon devised this dance in 1962, to honor Harvey

Mackay Barnes, "High School Teacher Extraordinaire and Chairman of the

Scottish Country Dance Camp Committee in Vancouver, BC.', 88, '8181 8888 8888 8888 8888 8888 4444 8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6056, '1997-09-14 22:00:00+00', '2020-06-21 13:20:01.195298+00', 'Shoolbraids Jig, The', 'SHOOLBRAIDS JIG', 2, 40, 9999, 1, 4, 2, 1270, NULL, 'Rena Drennan devised this dance as a tribute "to Mrs. Mamie Shoolbraid and Mary Shoolbraid Brandon for all their dedication and devotion to teaching Scottish Country Dancing in Leslie, Fife." The dance was first

published in the The Melbourne Dance Book Volume 2.', 38, '5005/4444/4114/4444/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20034, '2020-06-23 14:57:57.303097+00', '2020-06-24 10:29:50.824546+00', 'Cocktails at Hogmanay', 'COCKTAILS AT HOGMANAY', 2, 40, NULL, 4, 55, 35, 11570, '2019-12-20', 'I wrote this dance for a group of dancers who I celebrated New Year‘s Eve with. Person#5 is the straw to mix everything, on the last four bars this dancer adds the half orange to the glass.



4 dancers in a square set, dancer #5 on #1s right hand side.', 56, '44848/40408/44488/04048/44448', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2719, '1997-09-03 22:00:00+00', '2020-06-27 10:14:39.947921+00', 'Hadrian''s Wall', 'HADRIANS WALL', 1, 40, 9999, 1, 3, 42, 175, NULL, '“Hadrian''s Wall” was listed in Napier''s index, as a 40 bar reel by Derek Haynes, with no other details.  The following description is copied from private notes 



(1-8)       1C cross RH, cast, 1/2 fig. of 8 round 2nd couple, (finish facing 1st corners) 



(9-16)     1C, diagonal reel of 4 with 1st corners. (1C finish in 2nd place on opposite sides) 



(17-24)   1C set and cast off; 1/2 fig. of 8 round 3C. (finish: 2C at top facing in and down; 3C in 2nd place facing out and down; 1C in 3rd place facing in and up)

 

(25-32)   2C; 3C and 1C cross-over reels on opposite sides, 1C cross up from 3rd place to start 



(33-40)   cross-over reels on own sides. 1C cross up from 3rd place to start (1C finish in 2nd place on own sides) 



Note that if 1c finish in 3rd place, the progression becomes (2,3,1), fitting a 3-couple set.





Derek did not include this dance in any of the “Carnforth Collection" books.  Maureen Haynes, Derek’s widow, wrote: "I have found the details of the dance Hadrian''s Wall devised by Derek. It has almost been like looking for hidden treasure!  It is a 40 bar Reel for 3 couples in a 3 couple set, devised when he was still a member of the Liverpool Branch with a tune written by K. Macaulay Jones, also of Liverpool Branch, who also wrote the tune for Neidpath Castle. It would appear that the dance was never actually published and in a list that Derek put together himself of all the dances that he had devised that one is not mentioned. And as he did not include it in his Carnforth Collections I can only presume that he did not think it worthy of publication. Perhaps he chose to forget it!"



As mentioned in Glendarroch SCD Sheet No.34 on <<https://www.rscdslondon.org.uk/sdata/dances/glendarroch/spey.pdf>>  from 1969, the dance "Hadrian''s Wall" was rearranged by Derek Haynes to produce "The Spey in Spate". Possibly, Derek preferred the new dance, and thus did not include "Hadrian''s Wall" in the Carnforth Collection, published about 20 years later, while including "The Spey in Spate" in his Carnforth book 3.', 50, '800/844/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13643, '2010-11-11 23:00:00+00', '2020-06-24 10:39:40.200792+00', 'Examination Fever', 'EXAMINATION FEVER', 2, 32, 9999, 1, 3, 42, 3776, '2007-08-02', 'This dance is dedicated to a number of friends (in alphabetic order):  



Eva-Maria Beckmann, Antje Böttcher, Birgit Frie, Gabrielle Funhoff, Chris Houston-Dewilde, Dirk Kölbl, Daniéle Landrieau, Luitgard Merkens, Anika McGregor, Birgit Röhricht, Antoine Rousseau, Thomas Stork, Sjoerd van Leersum, Iryna Zhurakovska and Claudia Zyla  



who attended different Units of the RSCDS Teaching Certificate in Summer and Autumn 2007.', 83, '808/880/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20033, '2020-06-23 14:48:42.730382+00', '2020-06-25 06:09:22.447998+00', 'Irish Clover, The', 'IRISH CLOVER', 3, 40, NULL, 2, 3, 17, 11570, '2020-05-19', 'This dance is dedicated to Anika Lange and Wolfgang Hahn on the occasion of their wedding. The four half reels represent the Irish clover, as Ireland is special to them, as much as is Scottish Country Dancing. The last figure - of course - is „walking down the aisle.“



Second couple is dancing couple.

', 68, '686/686/282/282/288', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20077, '2020-08-27 20:26:45.800361+00', '2020-09-03 07:57:55.379782+00', '1508, or the Complaint of the Black Knight', '1508 OR THE COMPLAINT OF THE BLACK KNIGHT', 2, 32, NULL, 1, 2, 76, 11980, NULL, 'This dance was written by a committee of multiple RSCDS Twin Cities Branch Members and named after the address of the house where the dance was devised, which happens to be the publication date of the oldest surviving book printed in Scotland, the Complaint of the Black Knight by John Lydgate.', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12842, '2006-09-12 22:00:00+00', '2020-06-27 21:28:24.931922+00', 'Tie-Dyed and Gone to Heaven', 'TIEDYED AND GONE TO HEAVEN', 2, 32, 9999, 1, 3, 42, 3646, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13676, '2011-03-28 22:00:00+00', '2020-07-17 17:16:58.470291+00', 'Schorsch Lusky''s Strathspey', 'SCHORSCH LUSKYS STRATHSPEY', 3, 32, NULL, 1, 2, 76, 228, '2011-03-28', 'For Hans-Georg »Schorsch« Lusky, on the occasion of his »significant« birthday in March, 2011.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1013, '1997-08-31 22:00:00+00', '2020-08-03 06:36:00.345+00', 'Captain Henderson''s Hornpipe', 'CAPTAIN HENDERSONS HORNPIPE', 1, 32, 9999, 2, 3, 17, 746, NULL, 'This dance was devised to honour Captain Donald Henderson, the oldest member of any club inthe Hunter Valley Branch of the R.S.C.D.S. He continued dancing till shortly before his deathearly in 1981 at the age of 93. He was born in the north of Scotland, going to sea at the age of15, and was a four times "Cape Horner". He settled in Newcastle, New South Wales, becomingHarbour Master. He was loved and respected by all.', 92, '888/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13745, '2011-07-11 22:00:00+00', '2020-09-20 08:36:33.310161+00', 'Trip to Fanwood', 'TRIP TO FANWOOD', 2, 32, NULL, 1, 3, 42, 2973, '2006-10-01', 'Devised in October 2006 on the occasion of being invited to teach the „Happy Soles‟ in Fanwood, NJ.



Music

Any good jig. A recording that fits the dance is Flights of Fancy, on the Boston Branch Celebrate 50 CD.', 44, '800  822  822  888', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (6236, '1998-07-09 22:00:00+00', '2020-08-07 09:28:57.508239+00', 'Spey In Spate, The', 'SPEY IN SPATE', 1, 32, 9999, 2, 3, 17, 175, '1968-01-01', 'Devised in 1968, and first published as Glendarroch SCD Sheet No. 34 in 1969.



As mentioned in the <<https://www.rscdslondon.org.uk/sdata/dances/glendarroch/spey.pdf|Glendarroch Sheet>>, is a rearrangement of Derek Haynes'' earlier dance "Hadrian''s Wall".

Possibly, Derek Haynes liked the "The Spey in Spate" dance better, which might explain why "The Spey in Spate" did enter the devisor''s Carnforth Collection books published in the 1990ies, while "Hadrian''s Wall" did not.', 58, '888  800  844  800', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (6037, '1997-04-03 22:00:00+00', '2021-05-01 21:09:16.450439+00', 'Shepherd''s Crook, The', 'SHEPHERDS CROOK', 3, 72, 9999, 107, 53, 3, 9998, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20511, '2021-10-09 08:47:07.654466+00', '2021-10-09 08:47:07.654466+00', 'Stuck in the Rain', 'STUCK IN THE RAIN', 2, 32, NULL, 1, 3, NULL, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18046, '2017-11-10 16:35:37.510322+00', '2021-07-26 09:06:47.638591+00', 'Flower Lady, The', 'FLOWER LADY', 3, 32, NULL, 2, 3, 17, 2874, '2016-11-01', 'This dance is dedicated to Marie-Noëlle Dubey whose beauty of character was reflected in the floral arrangements she made each year for the Geneva Spring Dance.

', 54, '808/880/800/804', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18208, '2018-01-13 10:59:33.284261+00', '2020-06-28 10:44:24.535439+00', 'My Golden Bear', 'MY GOLDEN BEAR', 2, 32, NULL, 1, 4, 2, 2682, '2016-08-05', 'For my wife Kristin, my bear, for her 60th birthday; especially in appreciation of her work in

Johnsonville’s “golden” year.  



Recommended music is ''Dovecote Park'' by James Braidwood played AABB. Unfortunately there is no recorded music of this tune in the correct form. Thus for recorded music I suggest "Mrs Seller''s Favourite" by Charles Grant which is the lead tune for "Off She Goes in the North", and either the recordings of David Anderson and his S. D. B. (Highlander Music Vol.8) or Colin Dewar (Music for Book 18) or (best of all) Stan Hamilton (Memory Lane) would be appropriate. The music needs to be very steady to enable the central figure.', 63, '8448/8448/8008/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (52, '1997-09-02 22:00:00+00', '2020-06-28 19:37:13.045194+00', 'Ainster Fisherman', 'AINSTER FISHERMAN', 1, 32, 9999, 1, 4, 1, 270, NULL, '', 69, '8840/8888/8884/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17501, '2016-12-31 14:06:48.574714+00', '2020-06-28 21:08:46.640098+00', 'Change Your Shoes Faster', 'CHANGE YOUR SHOES FASTER', 2, 32, NULL, 1, 3, 42, 10934, NULL, 'This dance was created as a warmup dance where the second and third couples could join in late after putting on their shoes. It was devised for Swarthmore Folk Dance Club and the teachers who started me off, Terry Harvey and Joanna Reiner.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1176, '1998-07-09 22:00:00+00', '2020-07-01 13:58:17.082615+00', 'Cherrybank Gardens', 'CHERRYBANK GARDENS', 3, 32, 9999, 2, 3, 17, 108, '1991-01-01', 'The original <<ddpub:#211|Bankhead>> book for bars 11-12 has *"1st couple cross over giving left hands"* presumably to the sides with the subsequent hands across starting from there though that is not specified. The more recent republication by the RSCDS in <<ddpub:#1523>> changed that to 1st couple turning 3/4 left hands.', 90, '880  884  808  888', 0, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (17594, '2017-02-15 19:55:04.964475+00', '2020-07-01 17:22:44.501928+00', 'John Riddet''s Reel', 'JOHN RIDDETS REEL', 2, 32, NULL, 1, 3, 42, 1582, '2012-07-01', 'In the <<ddpub:#1351|Corberry II book>> this dance is called "John Riddet''s Reel" on the page describing the dance but "John Riddet''s Jig" on the index page. The latter is added as an alias.



In the book the tune is given as "John Riddet''s Jig" which is presumably the one entered in SCDDB as <<ddt:#13688>>.', 66, '822/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17609, '2017-02-16 09:01:21.344156+00', '2020-07-01 17:24:56.56601+00', 'Symmetrical Jig, The', 'SYMMETRICAL JIG', 2, 32, NULL, 1, 100, 2, 1582, '2010-01-01', 'In the <<ddpub:#1351|Corberry II book>> this dance is called "The Symmetrical Jig" (with double m) on the page describing the dance but "The Symetrical Jig" (one m) on the index page. The latter is added as an alias.



Devised by Peter Clark in 2010 to take to Northern Virginia Weekend.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (205, '1997-09-22 22:00:00+00', '2020-07-01 18:42:26.933357+00', 'Archduke John of Austria', 'ARCHDUKE JOHN OF AUSTRIA', 3, 32, 9999, 1, 3, 42, 270, NULL, '', 79, '888/884/880/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20035, '2020-07-01 19:13:48.199412+00', '2020-07-01 19:13:48.199412+00', 'Home and Away', 'HOME AND AWAY', 2, 32, NULL, 1, 3, 42, 515, NULL, 'Source: MiniCrib.', 56, '800/866/866/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18662, '2018-09-24 23:02:25.204846+00', '2020-07-04 10:21:56.458622+00', 'Ashley In Wonderland', 'ASHLEY IN WONDERLAND', 3, 32, NULL, 1, 3, 42, 11237, '2017-05-01', 'An earlier version of this dance had leading across with the left hand from the men’s side in bars 9-16  (as used in the 4 couple version of this figure in <<ddd:Kyle Castle>>). With only 3 couples as in this dance, using right hands from both sides is more symmetric. Those in 2nd place always cross in front.', 62, '800 888 888 888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15646, '2014-10-01 23:20:05.539364+00', '2020-07-04 11:28:52.649365+00', 'Pink Triangle, The', 'PINK TRIANGLE', 3, 32, 9999, 6, 6, 69, 523, '2012-12-01', 'In this progression, all dancers return to their original places after three repetitions of the dance.



From the comments on the Edinburgh <<https://youtu.be/-j4K2DaVSHg|youtube video>>:

*This dance was devised by Tim Bolton-Maggs, RSCDS Edinburgh, for Sid Taylor who was intrigued to hear about the Edinburgh Gay Gordons so commissioned one of her folk music friends to write ''The Pink Triangle''. Sadly, Sid died of cancer before the dance was premièred at the Gay Gordons'' ceilidh in December 2012. The original tune, “<<ddt:#13006>>” was written by <<ddp:#11016>>.*

', 100, '888888/888888/888888/888888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20037, '2020-07-05 09:44:01.66064+00', '2020-07-05 09:44:01.66064+00', 'Teagan''s Triumph', 'TEAGANS TRIUMPH', 3, 32, NULL, 3, 5, NULL, 952, NULL, 'Source: <<https://youtu.be/JBSHkKaULqo|youtube video>>. According to the introduction in the video, the dance is one of a trio devised to mark the 500th performance of the Red Thistle Dancers. It is named after one of the deviser''s grandchildren.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20036, '2020-07-05 09:36:37.6903+00', '2020-07-05 09:54:42.498386+00', 'Lively Liam''s Jig', 'LIVELY LIAMS JIG', 2, 40, NULL, 1, 4, 28, 952, NULL, 'Source: <<https://youtu.be/JBSHkKaULqo|youtube video>>. According to the introduction in the video, the dance is one of a trio of dances devised to mark the 500th performance of the Red Thistle Dancers. It is named after one of the deviser''s grandchildren.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20038, '2020-07-05 09:53:53.027915+00', '2020-07-05 09:55:41.510956+00', 'Rowan''s Reel', 'ROWANS REEL', 1, 40, NULL, 4, 4, 54, 952, NULL, 'Source: <<https://youtu.be/JBSHkKaULqo|youtube video>>. According to the introduction in the video, the dance is one of a trio of dances devised to mark the 500th performance of the Red Thistle Dancers. It is named after one of the deviser''s grandchildren. This is a once through non-progressive dance.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20030, '2020-06-18 12:16:19.972766+00', '2020-07-06 07:42:54.369077+00', 'Lonesome Reel, The', 'LONESOME REEL', 4, 64, 5, 4, 51, 54, 10912, '2020-01-01', 'The dance can also be performed with 2, 3 or 4 dancers, replacing the ghosts in the order 3 2 4.', 100, '8/8/8/8', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20039, '2020-07-06 07:38:13.706165+00', '2020-07-06 07:43:19.433375+00', 'Onesome Reel, The', 'ONESOME REEL', 4, 64, 5, 4, 51, 54, 10912, '2020-01-01', 'The dance can also be performed with 2, 3 or 4 dancers, replacing the ghosts in the order 3 2 4.', 100, '8/8/8/8', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10701, '2002-07-21 22:00:00+00', '2020-07-06 16:51:16.615645+00', 'Oot wi'' the Auld', 'OOT WI THE AULD', 2, 40, 9999, 1, 4, 1, 2961, NULL, '', 85, '8888/8888/8888/8000/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20040, '2020-07-06 19:18:42.328184+00', '2020-07-06 19:29:02.571612+00', 'AJ''s Reel', 'AJS REEL', 1, 32, NULL, 1, 3, 42, 11963, NULL, 'Source <<https://youtu.be/t-bPczzdtas|youtube video>> via the <<http://rscds-helensburgh.org.uk/photos-2/video/|Helensburgh RSCDS website>>. Written for the deviser''s granddaughter.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20042, '2020-07-08 21:33:06.227224+00', '2020-07-08 21:33:06.227224+00', 'Dancers'' Companions', 'DANCERS COMPANIONS', 2, 32, NULL, 1, 3, 42, 11035, NULL, 'Devised in honour of the Dictionary & Mini Crib website teams who do so much work on behalf of dancers all around the world.', 56, '844/822/866/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20043, '2020-07-08 21:43:49.825411+00', '2020-07-08 21:43:49.825411+00', 'Twisted then Chaperoned', 'TWISTED THEN CHAPERONED', 3, 32, NULL, 1, 3, 42, 11035, NULL, 'Source: <<https://youtu.be/T8CBQ9t0CLs|youtube video>>.', 56, '880/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20044, '2020-07-11 06:32:13.557047+00', '2020-07-11 06:47:19.967242+00', 'We''ll Meet Again', 'WELL MEET AGAIN', 3, 32, NULL, 2, 3, 17, 11965, '1993-01-01', '', 92, '888/484/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16002, '2015-02-06 17:49:04.995983+00', '2020-07-11 11:19:56.203035+00', 'Young at Heart', 'YOUNG AT HEART', 1, 32, 9999, 2, 3, 17, 703, '2005-07-16', 'Devised for Pat Young for her 60th birthday on July 16,2005. Pat, who was a former long

time resident of New Orleans, has found her new home in the mountains of North Carolina. Besides

being an iron horse in making sure that Thistle School runs smoothly, her love of cartoons and

children will always make her "young at heart. "', 75, '844/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20045, '2020-07-12 12:32:16.448831+00', '2020-07-12 12:32:16.448831+00', 'Sir Andy Murray of Dunblane', 'SIR ANDY MURRAY OF DUNBLANE', 1, 40, NULL, 1, 4, 1, 11966, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12837, '2006-09-03 22:00:00+00', '2020-07-12 16:14:21.171038+00', 'Maskin Rung, The', 'MASKIN RUNG', 1, 32, 9999, 3, 5, 7, 1763, '1973-01-01', 'The Maskin Rung is the pole used to stir whisky malt. A song with this title appears in The Scottish Folksinger by Norman Buchan and Peter Hall. It tells of a maiden who fools an unwanted suitor by dressing up a maskin rung and leaning it against a tree; he thinks it is she and tries to woo her. This song resembles the Child ballad "The Broomfield Wager."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20047, '2020-07-12 14:50:21.095628+00', '2020-07-12 16:48:39.029511+00', 'Trip to St Andrews, A', 'TRIP TO ST ANDREWS', 3, 32, NULL, 3, 5, 21, 9998, NULL, 'Source <<https://youtu.be/4cQ-vaS3Nsc|youtube video>> (from 1:19).', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5843, '1998-11-25 23:00:00+00', '2020-07-13 09:38:52.209601+00', 'Saint Nicholas Boat, The', 'SAINT NICHOLAS BOAT', 2, 48, 9999, 1, 3, 42, 108, '1977-01-01', 'John Drewry wrote in the original description:



*A Jig containing a reel of three in couples with each man following his

partner. This figure is found in traditional dances from Orkney and

Shetland. (See Flett and Flett "Traditional Dancing in Scotland"

page 204, Diagram 9.5)*', 62, '880  888  888  888  880  880', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (12882, '2006-10-10 22:00:00+00', '2020-07-13 20:01:36.12614+00', 'Greetings from Saint Ninians', 'GREETINGS FROM SAINT NINIANS', 1, 48, 9999, 2, 3, 17, 3122, '1990-06-01', '', 68, '844/844/804/840/864/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18664, '2018-09-25 21:56:49.606879+00', '2020-07-16 15:00:25.586846+00', 'Sugar and Spice', 'SUGAR AND SPICE', 3, 32, NULL, 1, 102, 11, 11672, '2002-01-01', 'This temporary entry was derived from the Minicrib, as the dance was needed for a List.  Eric  Sept. 2018', 75, '8008/8448/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20041, '2020-07-08 14:57:36.355826+00', '2021-05-13 21:47:15.901869+00', 'Sparkling Sixty', 'SPARKLING SIXTY', 1, 40, NULL, 1, 3, 42, 952, NULL, 'Devised to celebrate the 60th Annual International Folk Dance camp at Stockton, California (2007).', 50, '800/844/888/880/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18391, '2018-07-01 14:26:58.101181+00', '2020-07-16 23:32:14.510707+00', 'Kildalton Cross', 'KILDALTON CROSS', 3, 40, NULL, 1, 3, 42, 3347, '2004-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20051, '2020-07-16 23:35:33.640888+00', '2020-07-16 23:35:33.640888+00', 'Green Light Moments', 'GREEN LIGHT MOMENTS', 1, 32, NULL, 5, 2, NULL, 11968, NULL, 'Source: <<https://youtu.be/vNwUmaMwTXA|Youtube video>>. From the youtube comments: *when you time arrival at traffic light just right — and never have to stop!*', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20050, '2020-07-16 23:02:54.263982+00', '2021-02-21 20:02:47.252296+00', 'Isolated Weasel, The', 'ISOLATED WEASEL', 1, 32, NULL, 1, 3, 42, 11035, '2020-04-01', '', 50, '844/888/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6091, '1998-09-30 22:00:00+00', '2021-05-01 22:14:26.38984+00', 'Silver Tassie, The', 'SILVER TASSIE', 3, 32, 9999, 1, 3, 42, 108, '1966-01-01', '##>>

This title, meaning the silver cup, is usually referenced to the first lines of the song *My Bonie Mary* by Robert Burns:



*Go, fetch to me a pint o’wine,  

And fill it in a silver tassie  

That I may drink, before I go,  

A service to my bonie lassie*



This, however, is probably Burns’ reworking of an older ballad attributed to Alexander Lesly of Edin, which opens:



*Ye’ll bring me here a pint of wine,  

A server and a silver tassie,  

That I may drink, before I gang,  

A health to my ain bonny lassie*

##<<', 62, '888  808  888  880', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (16479, '2015-07-09 00:37:27.17837+00', '2020-07-18 23:47:42.445592+00', 'Pipped at the Post', 'PIPPED AT THE POST', 1, 32, NULL, 1, 3, 42, 11155, '2014-09-01', 'Found on YouTube with the following description; this is a "stub" entry till a crib can be made.  Eric Ferguson, 2015-07-09





Pipped at the Post. Scottish country dancing reel, Tawa SCD Club

Pat Reesby

Gepubliceerd op 27 sep. 2014



PIPPED AT THE POST (R3X32) Maureen Robson



1 - 4 1st and 2nd couples dance four hands across. 1st woman faces out.



5 - 8 1st woman followed by 1st man casts down to 2nd place and across the set to finish with 1st couple in 2nd place on opposite sides. Ist woman facing out. 2nd couple move up on bars 7 & 8.



9 - 12 1st and 3rd couples dance left hands across and again 1st woman faces out.



13 – 16 1st woman casts up to top place followed closely by 1st man and curves down to finish facing 2nd woman. 2nd couple move down on bars 15 & 16.



17 - 24 1st couple with 1st woman leading dance a reel of three in tandem with the 2nd couple passing 2nd woman by the left to begin the reel. On passing the 2nd woman 1st couple turn left about so the 1st man is leading. 2nd couple finish the reel by curving into top place.



25 - 32 1st couple dance a reel of three in tandem with 3rd couple with the 1st man passing 3rd woman by the left to begin. On passing 3rd woman again on the opposite side of the dance 1st couple turn right about so the 1st woman is leading to finish in 2nd place on own sides. 1st woman stays facing out to begin the dance again.



''Pipped at the Post'' is a 32-bar reel devised by Maureen Robson, tutor of the Tawa SCD Club in Tawa, Wellington, New Zealand. It was danced at the club''s annual dance on September 27, 2014 in the Ngaio town hall.



Local musician and accordionist Peter Elmes wrote original music for the dance, and was joined by John Smith, Aileen Logie and Mary MacDonald on the night.



For one or two of the dancers, it was their first time at a club dance for they have been dancing less than a year.', 44, '840/804/880/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19145, '2019-01-16 23:12:56.742676+00', '2020-07-19 17:52:48.988266+00', 'Alice Ferguson of Seaforth', 'ALICE FERGUSON OF SEAFORTH', 2, 32, NULL, 1, 4, 1, 11356, '2008-01-01', 'For Alice Ferguson on the occasion of a special birthday and to thank her for her many years of devoted convener-ship of the Seaforth Scottish Country Dance class in Nova Scotia.', 59, '8000/8044/8844/4888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11331, '2003-06-03 22:00:00+00', '2021-07-05 07:30:46.889571+00', '1 Past Midnight', '1 PAST MIDNIGHT', 1, 32, 9999, 1, 3, 42, 352, '2000-01-01', 'I had this dance hallf complete running around in my mind. I finished it off and wrote it down at 1 minute past midnight 1st Jan 2000', 38, '800/844/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19149, '2019-01-16 23:34:18.163567+00', '2020-07-20 23:37:14.615728+00', 'Blind Date to Thistle Dew', 'BLIND DATE TO THISTLE DEW', 1, 32, NULL, 1, 4, 1, 11502, '2005-05-17', 'This dance was devised by Jean Miller to celebrate the 25th wedding anniversary of Glen and Yvonne Leduc, May 17, 2005, based on how they met.  



1-4     Glen and Yvonne take off one night on a blind date  

5-8     They meet other people there whom they know  

9-12   They mix around and meet other people at the party  

13-16 They dance with other people  

17-24 They give each other the once over - good eye contact here  

25-28 They acknowledge the fact that - "Hey, maybe this is the one for me!"  

29-32 They dance into the sunset and have been dancing together ever since!!!  

Long may they dance together.', 31, '8004/8400/8000/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20295, '2021-04-04 21:57:58.654871+00', '2021-04-05 08:44:39.292743+00', 'Misses Jessie & Nansie Reid of Dingwall, The', 'MISSES JESSIE AND NANSIE REID OF DINGWALL', 3, 32, NULL, 1, 4, 1, 9998, NULL, '', 78, '8888/6446/8448/8088', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20053, '2020-07-23 11:47:43.85154+00', '2020-07-23 12:50:40.126244+00', 'Crossing the Tantramar', 'CROSSING THE TANTRAMAR', 3, 32, NULL, 1, 3, 42, 2488, NULL, 'Dedicated to Judith (Jude) McCall, 1952 - 2020  



The Tantramar is the name given to the marshes on the border between New Brunswick and Nova Scotia, as well as to a tidal river to the south of Sackville, New Brunswick. The McCalls crossed the Tantramar frequently on their journeys to and from Sackville, especially when dancing in Seaforth, Nova Scotia (Halifax area). It was always a welcome point coming home, that the journey''s end was near.', 66, '866/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9661, '2000-09-18 22:00:00+00', '2020-07-23 23:58:56.69972+00', 'Aunt Anna''s Fancy', 'AUNT ANNAS FANCY', 1, 32, 9999, 1, 3, 42, 1268, '1990-01-01', 'Dance written by Doug Schneider in 1990 in memory of his great aunt, Anna Schneider, on her death at age 96.', 50, '888/800/880/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6725, '1997-09-16 22:00:00+00', '2020-07-25 22:50:32.437386+00', 'Trip to Lunenburg, A', 'TRIP TO LUNENBURG', 1, 32, 9999, 1, 3, 42, 209, NULL, 'The trip to Lunenburg on the "lower road" or Highway #3 as it is known, is beautiful, but winding. You can see some of the best coastline if you can take your eyes off of the road long enough. A beautiful trip for any passengers.', 41, '800/800/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20048, '2020-07-13 09:46:55.510544+00', '2020-07-24 10:30:33.311492+00', 'Noli Me Tangere', 'NOLI ME TANGERE', 3, 32, NULL, 1, 4, 2, 11967, '2020-07-01', 'Devised by Kirsten Steinbach, July 2020, on the occasion of the first post-Corona-lockdown open air social dancing of the Freiburg Scottish Country Dancers. Special thanks go to Jens Heckmann for suggesting the appropriate name.', 44, '4004/0440/8008/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20054, '2020-07-24 09:11:23.848452+00', '2020-07-25 03:52:13.98978+00', 'Freiburg Scottish Country Dancers'' Frolic, The', 'FREIBURG SCOTTISH COUNTRY DANCERS FROLIC', 3, 32, NULL, 2, 3, 17, 11969, '2018-01-01', 'Devised by José R. Solera Ureña on 18th July and 15th August 2018 in honour of his dancing friends, the Freiburger Scottish Country Dancers.', 77, '800/864/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (975, '1997-04-03 22:00:00+00', '2020-08-03 06:25:11.414051+00', 'Campbell of Duntroon', 'CAMPBELL OF DUNTROON', 2, 32, 9999, 1, 4, 1, 249, NULL, '"Campbell of Duntroon" was devised by Peter McBryde when visiting Canberra, Australia, in the early 1970s. It refers to Robert Campbell (1769-1846), born Greenock, Inverclyde. In 1825 Campbell was granted land in an area of New South Wales that is now the Australian Capital Territory (Canberra) and called it ''Duntroon'' after the family castle, Duntrune Castle on Loch Crinan in Argyll, Scotland. Duntroon House is now the Officer''s Mess for the Royal Military College, Duntroon.', 81, '8888  8448  6666  8268', 0, 1, 1, 0, 81);
INSERT INTO 'dance' VALUES (20070, '2020-08-21 22:02:45.030994+00', '2020-08-24 08:47:15.025928+00', 'Bleecker Reel, The', 'BLEECKER REEL', 1, 40, NULL, 6, 53, 42, 11976, '2016-01-01', 'Bleecker Street is in New York''s Greenwich Village.



Dancers are numbered anti-clockwise around the set.', 93, '844/888/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20172, '2020-12-07 18:51:42.880585+00', '2020-12-08 12:09:38.961989+00', 'Very Special Moment, A', 'VERY SPECIAL MOMENT', 3, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (98, '1998-01-05 23:00:00+00', '2020-12-27 17:01:21.804245+00', 'All The King''s Men', 'ALL THE KINGS MEN', 1, 32, 9999, 5, 2, 76, 209, NULL, '', 75, '44/44/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10924, '2002-11-12 23:00:00+00', '2021-06-06 12:12:24.354739+00', 'Hunter''s Jig', 'HUNTERS JIG', 2, 32, 9999, 1, 2, 76, 1268, '1997-01-01', 'Written by Doug Schneider in 1997 and named in honor of Hunter Way, a dancer with Twin Cities Branch of the Royal Scottish Country Dance Society.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6800, '2002-11-14 23:00:00+00', '2020-07-26 09:13:52.95175+00', 'Twenty-first of September', 'TWENTYFIRST OF SEPTEMBER', 1, 40, 9999, 1, 3, 42, 263, '1796-01-01', '21 September 1745 is the date of the battle of Prestonpans (east of

Edinburgh). According to popular mythology, the Scots under Bonnie

Prince Charlie, the »Young Pretender«, fought the English (under Sir

John Cope) and prevailed, which from the Scots'' point of view made the

»battle« a major victory although even in 18th-century terms it should

more properly be considered a skirmish.



During the Jacobite rising of 1745, most of the British army was

engaged fighting the French on the Continent in the war of the

Austrian succession. For Charles Edward Stuart, otherwise known as

»Bonnie Prince Charlie«, this provided a welcome opportunity to try to

recover »his« kingdom of Great Britain and Ireland. The battle of

Prestonpans was the Jacobite army''s first encounter with a

hastily-recruited Loyalist army consisting mostly of inexperienced and

badly-equipped troops, and started a campaign that at first appeared

quite victorious but found a dismal end at Culloden the year after.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20055, '2020-07-26 19:29:08.200413+00', '2020-07-26 19:46:30.655198+00', 'Back to School', 'BACK TO SCHOOL', 1, 32, NULL, 1, 3, 42, 2863, NULL, '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6196, '1998-07-08 22:00:00+00', '2020-07-27 20:32:26.475705+00', 'Song of the Sea, The', 'SONG OF THE SEA', 3, 32, 9999, 1, 4, 2, 108, '1971-01-01', '', 88, '8080/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11780, '2004-09-08 22:00:00+00', '2020-07-27 21:57:16.554934+00', 'Five Stars', 'FIVE STARS', 1, 40, 9999, 3, 5, 7, 108, '2003-01-01', 'Note by John Drewry: *This dance is a 5-couple version of "<<ddd:Los Molinos>>". Dancers can choose which version they prefer.*', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19163, '2019-01-17 11:04:42.861832+00', '2020-07-28 05:20:23.558728+00', 'Porter is Passed, The', 'PORTER IS PASSED', 3, 40, NULL, 4, 4, 4, 425, '1997-04-30', 'Presented to Brenda Porter on the special occasion of her passing the Teacher''s Certificate examination', 100, '8888/8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4149, '1997-09-08 22:00:00+00', '2020-07-29 07:07:16.802807+00', 'Margaree Valley Jig, The', 'MARGAREE VALLEY JIG', 2, 32, 9999, 1, 2, 76, 209, NULL, 'The Margaree Valley is in the heart of Cape Breton Highlands. A beautiful part of Nova Scotia with high

mountains surrounding rolling fields and meandering rivers good for salmon and trout fishing. Truly "Gods

Country".', -1, '88/88/80/44', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20471, '2021-09-12 10:04:20.314721+00', '2021-09-12 10:04:20.314721+00', 'Spring Chick Waltz Mixer', 'SPRING CHICK WALTZ MIXER', 5, 16, NULL, 5, NULL, 4, 2682, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9663, '2000-09-18 22:00:00+00', '2022-12-19 00:59:08.665585+00', 'Bricks of Madison, The', 'BRICKS OF MADISON', 2, 32, 9999, 1, 2, 76, 1268, '1992-01-01', 'Dance written by Doug Schneider in 1992; dedicated to Mike and Norma Briggs of Madison, Wisconsin, who once received a postcard from overseas addressed to "Mr. & Mrs. Bricks".', -1, '55/55/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5279, '1997-09-11 22:00:00+00', '2020-07-28 16:03:52.696772+00', 'Piper''s Glen, The', 'PIPERS GLEN', 3, 32, 9999, 1, 3, 42, 209, NULL, 'Piper''s Glen is a small valley in the centre of the Margarees in Cape Breton. The dirt road from the highway is sometimes hazardous, but a beautiful scene of towering mountains meets the eye at every curve of the road, as it winds through the highlands. Suddenly the vista changes to green fields, cows grazing and a meandering river. Far off, the distant sound of a lone piper in the hills. Imagination, maybe the wind, could be, but who knows.', 44, '822/822/880/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7360, '1997-04-04 22:00:00+00', '2020-07-31 21:56:33.511755+00', 'Celtic Clasp, The', 'CELTIC CLASP', 1, 32, 9999, 1, 4, 1, 352, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5174, '1997-12-21 23:00:00+00', '2020-07-28 20:36:05.921015+00', 'Passing The Porter', 'PASSING THE PORTER', 1, 32, 9999, 1, 3, 42, 425, '1993-08-01', 'For Brenda Porter on the occasion of attaining her Preliminary Teacher''s Certificate.', 50, '880/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19161, '2019-01-17 10:43:46.716399+00', '2020-07-29 05:58:00.782377+00', 'Mr John Wood of Bedford, Nova Scotia', 'MR JOHN WOOD OF BEDFORD NOVA SCOTIA', 3, 32, NULL, 2, 3, 17, 11503, '2009-12-01', 'Devised for John Wood (Christmas 2009), the Dancing Master of The Thistle Scottish Country Dancers', 77, '888/880/822/868', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20058, '2020-07-31 09:46:41.853769+00', '2020-07-31 11:09:29.392982+00', 'Trixi''s Favourite Toy', 'TRIXIS FAVOURITE TOY', 2, 32, NULL, 1, 3, 42, 11971, '2020-07-01', 'At the request of Kirsten Steinbach, this dance is dedicated to our late family dog Trixi, referring to its tug toy. The formations of chase, advance and retire mirror Trixi’s behaviour when running after the toy as well as the to-and-fro movement when trying to pull it out of our hands.  



Devised by Jens Heckmann on the occasion of the second post-lockdown dance of the Freiburg Scottish Country Dancers in July 2020.', 44, '800/888/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (371, '1998-03-16 23:00:00+00', '2020-08-02 23:13:20.792038+00', 'Balmaclellan', 'BALMACLELLAN', 2, 48, 9999, 1, 4, 1, 129, '1969-01-01', '', 68, '8040/8884/8444/4848/8224/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20056, '2020-07-28 21:28:35.701927+00', '2021-08-02 03:21:17.792983+00', 'Let''s Get This Sorted!', 'LETS GET THIS SORTED', 3, 32, NULL, 1, 3, 100, 11970, '2020-07-01', '', 44, '800/888/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20059, '2020-08-01 20:13:17.894624+00', '2020-08-01 20:13:17.894624+00', 'Post-Pandemic Reel, The', 'POSTPANDEMIC REEL', 1, 32, NULL, 1, 3, 42, 11973, '2020-01-01', '', 53, '800/822/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (91, '1997-09-06 22:00:00+00', '2020-08-02 06:37:08.358619+00', 'Alister McAlister', 'ALISTER MACALISTER', 3, 32, 9999, 1, 3, 42, 129, '1968-01-01', '', 57, '840/884/828/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (498, '1997-04-03 22:00:00+00', '2020-08-02 23:20:52.683033+00', 'Beyond the Black Stump', 'BEYOND THE BLACK STUMP', 2, 40, 9999, 5, 1, 4, 151, '1973-01-01', 'Video 1 is in error (see the note), it changes the dance to 32 bars, the last 8 bars being 4 bars of Promenade and 4 of Grand Chain. ', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20060, '2020-08-02 17:46:06.301043+00', '2020-08-07 15:12:50.297364+00', 'All Together', 'ALL TOGETHER', 3, 32, NULL, 2, 3, 17, 11974, '2014-11-01', 'Devised in November 2014 for two men of the Y.Y.Family (a dance group in Fujisawa, Japan). *It is a great pleasure for all the members that they have recovered quite well.*', 83, '888/888/844/808', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1077, '1997-04-03 22:00:00+00', '2020-08-03 06:56:16.756238+00', 'Castles in the Air', 'CASTLES IN THE AIR', 3, 32, 9999, 1, 3, 42, 129, NULL, '', 56, '888  822  880  866', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (20057, '2020-07-29 20:03:07.073656+00', '2020-09-01 12:06:03.440976+00', 'One Hundred and Fifty plus Fifty', 'ONE HUNDRED AND FIFTY PLUS FIFTY', 4, 128, 2, 4, 4, 3, 952, NULL, 'Demonstration dance to celebrate the 150th anniversary of the Caledonian Society Highland Games and 50th anniversary of San Francisco Branch in 2015.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5238, '1998-04-19 22:00:00+00', '2020-09-02 17:50:15.84859+00', 'Petra''s Fancy', 'PETRAS FANCY', 1, 32, 9999, 1, 3, 42, 227, '1989-09-01', 'Advanced level.



For Petra a quick version of Fair Donald, a dance she taught with great success in the beginners'' class.', 50, '800  844  844  888', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (20417, '2021-07-30 21:32:51.452994+00', '2021-07-30 21:32:51.452994+00', 'Bowled a Maiden Over', 'BOWLED A MAIDEN OVER', 2, 0, NULL, NULL, NULL, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20422, '2021-08-01 04:22:15.896471+00', '2021-08-01 04:36:00.206096+00', 'Arthur''s Reel', 'ARTHURS REEL', 1, 32, NULL, 3, 5, 7, 11970, '2014-09-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13122, '2006-11-28 23:00:00+00', '2020-08-03 08:32:22.271141+00', 'José Solera''s Farewell to Aberdeen', 'JOSE SOLERAS FAREWELL TO ABERDEEN', 3, 32, 9999, 2, 3, 17, 3286, '2005-09-01', 'Devised by Alison Smith in honour of Aurora member José Solera on his return to Spain in September 2005. Our friend wholeheartedly embraced the local culture while in Scotland. José says "During my stay in Aberdeen, I was blessed by the friendship of Aurora members who introduced me to the local culture. I love Scotland''s hospitable self, its land and people, its language and music. This dance was a truly wonderful leaving present and I feel deeply honoured that it has been chosen for Aurora ''s 10th anniversary dance book."', 45, '880/880/802/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20061, '2020-08-03 08:58:20.497861+00', '2020-08-03 09:34:16.824435+00', 'Gypsy Crown', 'GYPSY CROWN', 3, 32, NULL, 2, 3, 18, 11975, '2020-04-01', 'Published in The Postie''s Jig, newsletter of the Western Australia Branch of the RSCDS.  Volume 41 Number 3, August 2020', 63, '800/844/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3066, '1998-01-05 23:00:00+00', '2020-08-06 14:59:33.73706+00', 'Illabo Reel', 'ILLABO REEL', 1, 32, 9999, 5, 56, 76, 151, NULL, 'This dance evolved because I was asked for a dance like the Dashing White Sergeant, but without setting steps, on an occasion when I couldn''t recall Highland Reel with any certainty.  It is useful for an introduction to reels of three. 



Note by Eric Ferguson, 2015-02.  The published instructions for [17-24] read : "Each boy dances three hands across with his right hand partner and the girl opposite her." The crib and the diagram follow this, but it looks as if "and repeat this to the left" has been omitted by mistake.



', 100, '888/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20062, '2020-08-03 09:37:57.209177+00', '2020-08-03 10:17:13.513397+00', 'One More Time', 'ONE MORE TIME', 1, 32, NULL, 1, 2, 76, 777, '2020-05-26', '', 69, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2150, '1997-04-03 22:00:00+00', '2020-08-03 20:26:18.438444+00', 'Fiddler''s Rant', 'FIDDLERS RANT', 1, 32, 9999, 2, 3, 17, 160, NULL, 'This dance was originally entered in the database as for 3 couples in a 4 couple set. However the instructions summarised in the contributed crib are for a 3 couple set so the database entry has been updated accordingly.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1322, '1997-08-31 22:00:00+00', '2020-08-04 00:25:04.333681+00', 'Contrary Kate', 'CONTRARY KATE', 2, 32, 9999, 7, 1, NULL, 151, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1838, '1998-11-14 23:00:00+00', '2020-08-04 00:50:40.675965+00', 'Dundee Whaler, The', 'DUNDEE WHALER', 3, 32, 9999, 1, 4, 1, 82, NULL, 'Bob Donald, editor of the Ormskirk Memorial Edition, adds the following in the concluding "Notes for Teachers": 



Bars 25-32.  The question posed here is whether in this sequence of changes across the dance, the dancers should slip into place or turn in with a polite turn. The answer is quite unequivocal. The dancers SLIP into place.



The reason is that in this figure, Roy is representing the tacking to and fro of the ship and therefore the line followed by the leading dancers to the foot of the set has sharp changes of direction just as the ship would have.

', 59, '0808/8888/8080/6222', 0, 1, 1, 0, 59);
INSERT INTO 'dance' VALUES (19892, '2020-03-17 23:01:33.116259+00', '2020-08-12 09:35:32.208658+00', 'Careful, Not Crazy', 'CAREFUL NOT CRAZY', 2, 32, NULL, 1, 3, 42, 2766, '2020-03-01', 'In response to a call for hands-free dances during the Coronavirus scare and the insanity of people buying way too much and clearing store shelves in panic.', 44, '800/444/888/822', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6357, '1997-09-14 22:00:00+00', '2021-05-14 14:25:56.055628+00', 'Strawberry Bank', 'STRAWBERRY BANK', 1, 128, 9999, 4, 4, 3, 270, NULL, '', 97, '8888/8888/8888/8888/6666/6666/8888/8888/8888/8888/8888/8888/8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3025, '1997-09-04 22:00:00+00', '2020-08-05 14:23:19.249653+00', 'Hunter''s Run, The', 'HUNTERS RUN', 2, 32, 9999, 1, 4, 13, 1009, NULL, '_1-8_  

The age-old chase around the world, he chases her, she chases him; the others do their social whirl around they go and back again.  

_9-16_  

Cut loose and wander end for end just have a try with someone new and smile and greet the new-found friend then give two hands for a little twirl.  

_17-24_  

Old friends are best, so change a new to faithful mate go back again with friendly set the link renew and two hand turn to make amend.  

_24-32_  

The tops have made their big resolve down aisle they go while all applaud, escaped they do a fast revolve others sedately in and out.', 59, '8888/6006/4260/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2557, '1997-09-03 22:00:00+00', '2020-08-05 11:42:39.956681+00', 'Glenmore Rant', 'GLENMORE RANT', 1, 48, 9999, 107, 126, NULL, 105, NULL, 'A progressive dance for eleven dancers.  8 women stand as a 4C set; 3 men on the midline.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2552, '1997-09-06 22:00:00+00', '2020-08-05 11:43:15.245882+00', 'Glenlochar', 'GLENLOCHAR', 1, 64, 9999, 1, 4, 1, 129, '1966-01-01', '', 59, '8000/8800/8880/0048/8048/4406/6488/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3325, '1997-04-03 22:00:00+00', '2020-08-06 15:16:26.503456+00', 'John of Badenyon', 'JOHN OF BADENYON', 3, 48, 9999, 1, 4, 1, 129, NULL, 'No e-crib was made as this dance is unlikely to be danced except as a demonstration', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7778, '1997-09-06 22:00:00+00', '2020-08-06 15:18:34.623907+00', 'Kenny Paul of West Linton', 'KENNY PAUL OF WEST LINTON', 3, 32, 9999, 1, 3, 42, 167, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3524, '1997-11-25 23:00:00+00', '2020-08-06 15:23:43.105947+00', 'Kishmul''s Castle', 'KISHMULS CASTLE', 4, 128, 20, 1, 4, 3, 82, NULL, '', 75, '8888/2222/4444/4444/8888//8888/8008/4004/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2534, '1997-04-03 22:00:00+00', '2020-08-05 13:25:59.979536+00', 'Glenfiddich Strathspey', 'GLENFIDDICH STRATHSPEY', 3, 32, 9999, 1, 3, 42, 129, NULL, '', 59, '880/848/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3786, '1998-11-14 23:00:00+00', '2020-08-06 15:37:30.878603+00', 'Let''s Have a Ceilidh', 'LETS HAVE A CEILIDH', 1, 32, 9999, 1, 4, 2, 62, '1974-01-01', '', 78, '8008  8888  8888  8228', 0, 1, 0, 0, 78);
INSERT INTO 'dance' VALUES (3979, '1999-07-25 22:00:00+00', '2020-08-06 15:53:39.80036+00', 'Luck To Loyne', 'LUCK TO LOYNE', 1, 40, 9999, 3, 5, 16, 175, NULL, 'First published on a Glendarroch SCD Sheet in 1969', 68, '84448/80808/80808/88088/60688', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5409, '1997-09-11 22:00:00+00', '2020-09-02 18:11:25.477988+00', 'Quatorze Juillet, Le', 'QUATORZE JUILLET', 2, 32, 9999, 1, 3, 42, 108, '1989-01-01', 'Official Alias: Fourteenth of July', 69, '888/888/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6991, '1997-09-17 22:00:00+00', '2020-09-04 10:43:57.30474+00', 'Wedding, The', 'WEDDING', 1, 32, 9999, 1, 4, 1, 1284, NULL, '', 53, '8444/8444/8000/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20173, '2020-12-07 18:53:13.555306+00', '2020-12-08 12:12:27.134802+00', 'Dancing Memories', 'DANCING MEMORIES', 3, 40, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3314, '1998-04-12 22:00:00+00', '2021-05-23 20:41:36.699874+00', 'John Anderson''s Reel', 'JOHN ANDERSONS REEL', 1, 32, 9999, 1, 3, 42, 62, '1963-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2826, '1997-09-03 22:00:00+00', '2021-05-31 09:46:37.083499+00', 'He Danced Awa''', 'HE DANCED AWA', 2, 32, 9999, 1, 2, 76, 129, '1966-01-01', 'NOTE: With young children dancing, the Petronella turn may be omitted and slip steps substituted.', 60, '44/88/88/88', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1823, '1997-09-01 22:00:00+00', '2021-07-13 23:05:22.428788+00', 'Duncan''s Dance', 'DUNCANS DANCE', 4, 32, 1, 1, 4, 1, 848, NULL, '', 97, '8888/8888/8888/8686', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20418, '2021-07-30 21:34:02.465584+00', '2021-07-30 21:34:02.465584+00', 'Dillys McMillan''s Strathspey', 'DILLYS MACMILLANS STRATHSPEY', 3, 0, NULL, NULL, NULL, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20423, '2021-08-02 02:51:41.847428+00', '2021-08-02 03:07:12.799852+00', 'Portarlington Beckons', 'PORTARLINGTON BECKONS', 3, 32, NULL, 3, 5, NULL, 12052, '2016-01-01', 'Devised by Arthur Kingsland, Hunter Valley Branch.  

Written for dancers at the 2016 Traditional Social Dance Association of Victoria Spring Dance Weekend held in Portarlington, Victoria, Australia', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20421, '2021-07-31 04:30:37.403877+00', '2021-10-05 11:00:43.127584+00', 'Garrigues Strathspey', 'GARRIGUES STRATHSPEY', 3, 32, NULL, 1, 3, 42, 2497, '2021-07-01', 'This dance was written in honor of the 60th Wedding Anniversary of Pat and Chuck Garrigues, longtime Scottish Country dancers in Milwaukee, Wisconsin, USA.', 44, '800/888/800/880', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20512, '2021-10-09 08:48:01.460308+00', '2021-10-12 08:57:06.406442+00', 'From Nova Scotia', 'FROM NOVA SCOTIA', 1, 32, NULL, 1, 3, 42, 352, '2007-11-08', '', 44, '822/822/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20514, '2021-10-11 22:12:26.961288+00', '2021-10-15 22:47:24.779484+00', 'Lock-in Dance, The', 'LOCKIN DANCE', 2, 32, NULL, 1, 4, 1, 12073, '2020-01-01', '', 53, '8000/8888/8000/8444', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20518, '2021-10-12 07:44:34.815956+00', '2021-10-18 15:47:36.498993+00', 'Jewel in the Crown, A', 'JEWEL IN THE CROWN', 3, 32, NULL, 4, 4, 1, 572, NULL, '', 100, '8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3980, '1998-11-07 23:00:00+00', '2020-08-06 15:54:43.431347+00', 'Luckenbooth Brooch, The', 'LUCKENBOOTH BROOCH', 2, 32, 9999, 1, 3, 42, 101, '1968-01-01', '<<imgt:luckenbooth-brooch.jpg|Luckenbooth Brooch|200x300:right>>

In the Old Town of Edinburgh, from the 15th century or so, there used

to be enclosed stalls/workshops along the main street (today often called »Royal Mile«), near

St Giles Cathedral,

where various tradesmen such as goldsmiths and silversmiths offered their wares.

For obvious reasons these stalls could be locked up at night and were thus referred

to as »luckenbooths« (as in, »locking booths«). The city got rid of them in the 1810s.



The »Luckenbooth brooch« is a traditional Scottish piece of jewellery that

symbolises love and devotion and is produced and sold by jewellers in Edinburgh.

It is generally made of silver and features a crown above a heart (or two

intertwined hearts). Posher versions of the brooch can sport (semi)precious stones and/or

are made of gold instead, and variations of the design include thistles or St Andrew''s crosses.

The name exists since approximately the 18th century.



In addition to serving as love tokens, Luckenbooth brooches were also used as charms

to fend off the »evil eye« or protect babies from harm.

Interestingly, from the mid-18th century these brooches were a popular trade/barter object

with American Indians such as the Iroquois, and ended up as part of various traditional

Native American outfits of the 18th and 19th century.



*Photograph by Anselm Lingnau. Thanks to Marie Schwarz for the loan of the brooch.*', 56, '880  808  888  844', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (4701, '1998-01-05 23:00:00+00', '2020-08-07 03:50:31.69383+00', 'Mr Alexander Laing', 'MR ALEXANDER LAING', 1, 32, 9999, 1, 3, 42, 129, NULL, '', 51, '860/800/888/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4941, '1998-01-05 23:00:00+00', '2020-08-07 08:50:44.668785+00', 'Newcastle', 'NEWCASTLE', 1, 64, 9999, 4, 4, NULL, 129, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20065, '2020-08-09 12:00:47.770535+00', '2020-08-09 18:17:38.552549+00', 'Pieces of Eight', 'PIECES OF EIGHT', 2, 32, NULL, 2, 3, 17, 2682, '2020-03-04', 'Devised 4/3/2020, as a relatively simple fugal dance with the movement of “Ladies of Dunse” as a basis.  Note also that it is a palindrome, so I could have called it the “The Palindrome of Dunse”.  Whilst it is not difficult, the dancers will need to concentrate like they do with e.g.  “The Stow Alert”. The tandem figure of eight movements need the leading couples not to be tardy.  Recommended tune is “The Dancing Master” and a good recording is from the CD “Jig for Joy” from the Music Makars.', 50, '800/880/808/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5330, '2001-09-13 22:00:00+00', '2020-08-07 08:53:44.586438+00', 'Postie''s Jig', 'POSTIES JIG', 2, 32, 9999, 1, 4, 2, 82, NULL, 'The second edition of the Ormskirk Memorial Edition says (on page 21, under »Some Notes for Teachers«):



>  Bars 9–24::

>    In this sequence of couples crossing the dance and changing places up and down tha [sic]

>    dance, there is some ambiguity as to who should make the arches, and who should dance

>    under them. Again there is a simple rule, which is;

>

>    When going across the dance, the MEN make the arch always and when changing places

>    up and down, THE COUPLE COMING UP THE DANCE PUT THEIR HANDS UP AND THE

>    COUPLE COMING DOWN THE DANCE KEEP THEIR HANDS DOWN. [Emphasis in the original.]

', 62, '8008/8448/8448/8008', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (5951, '1997-04-03 22:00:00+00', '2020-08-07 09:15:26.049204+00', 'Scottish Barn Dance', 'SCOTTISH BARN DANCE', 2, 48, 9999, 5, 1, NULL, 151, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6239, '1997-09-14 22:00:00+00', '2020-08-07 09:29:52.131196+00', 'Speyside Reel, The', 'SPEYSIDE REEL', 4, 96, 9999, 1, 2, NULL, 175, NULL, 'Glendarroch Sheet 7 had a typed correction pasted over the original attribution and reading as follows: - replacement text - Adapted by Derek Haynes from a Threesome Reel devised (1958) by Mr. & Mrs. L. Kemp, Stockton-on-Tees (formerly of Aberdeen)”.  That dance was probably named *The Aberdeen Medley*.  ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6294, '1998-01-11 23:00:00+00', '2020-08-07 09:40:25.408099+00', 'Stealing The Stone', 'STEALING THE STONE', 1, 64, 9999, 4, 4, 1, 82, NULL, '', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6592, '1997-09-16 22:00:00+00', '2020-08-07 09:51:00.759606+00', 'Thrums Cairn, The', 'THRUMS CAIRN', 1, 32, 9999, 1, 3, 42, 129, '1970-01-01', '', 49, '800/888/800/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4835, '2002-05-04 22:00:00+00', '2021-06-12 10:57:36.069583+00', 'Muriel''s Fancy', 'MURIELS FANCY', 2, 40, 9999, 1, 4, 1, 1253, NULL, 'Devised by Margaret Rowe with grateful thanks to Muriel Rimmer and her Scottish Country Dance Band, "The Tartan Sett", for the many happy hours of friendship and music she shared with us from 1976, both at home and abroad.', 77, '6446/8888/8888/8000/8888', 1, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (16113, '2015-02-24 14:18:20.629481+00', '2020-08-07 10:12:39.364643+00', 'Waiting for the Daffodils', 'WAITING FOR THE DAFFODILS', 3, 32, 9999, 1, 4, 1, 11096, NULL, 'Suitable recorded music:

"Bothkennar", Bobby Brown and the Scottish Accent, The Bobby Brown Collection, CD1, Track 13', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6954, '1998-01-05 23:00:00+00', '2020-08-07 10:15:22.664705+00', 'Wattle Valley Reel, The', 'WATTLE VALLEY REEL', 1, 96, 9999, 4, 126, NULL, 151, NULL, ' 8 girls stand in a square facing out whilst 4 boys make a smaller square in the middle facing inwards. (see diagram 1). ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6367, '1997-09-14 22:00:00+00', '2020-08-08 11:18:56.312671+00', 'Sturt''s Desert Rose', 'STURTS DESERT ROSE', 2, 32, 9999, 1, 2, NULL, 125, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20063, '2020-08-09 11:54:59.365441+00', '2020-08-09 11:55:16.30678+00', 'Allison Kay', 'ALLISON KAY', 2, 32, NULL, 1, 3, NULL, 2682, '2020-02-27', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6818, '1998-01-04 23:00:00+00', '2021-04-05 10:43:30.482029+00', 'Two Black Cats', 'TWO BLACK CATS', 1, 32, 9999, 1, 4, 1, 1329, NULL, '', 66, '5005/8888/1854/8088', 1, 1, 0, 1, 65);
INSERT INTO 'dance' VALUES (20419, '2021-07-30 21:35:46.723128+00', '2021-07-30 21:35:46.723128+00', 'Donald Mhor', 'DONALD MHOR', 1, 0, NULL, NULL, NULL, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20519, '2021-10-12 07:52:40.46167+00', '2021-10-18 17:32:01.354986+00', 'Jersey Gals, The', 'JERSEY GALS', 2, 40, NULL, 1, 3, 42, 12076, NULL, '', 53, '888/880/844/844/822', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17805, '2017-06-22 10:58:12.390964+00', '2020-08-15 09:29:23.078234+00', 'Carol''s Strathspey', 'CAROLS STRATHSPEY', 3, 32, NULL, 2, 3, 18, 10907, '2011-12-01', 'A dance for Carol Aitken, my teaching mentor.', 92, '888/844/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20066, '2020-08-09 12:18:46.175281+00', '2020-08-09 12:18:46.175281+00', 'Snakes and Ladders', 'SNAKES AND LADDERS', 3, 32, NULL, 1, 4, NULL, 2682, '2020-04-08', 'Devised 8/4/2020, whilst at home in Lockdown for Covid-19, and following a long discussion on the Snake Pass movement on the Strathspeymailing list.  Recommended tune is Donald Maclean’s Farewell to Oban byArchibald  McNeill  and  a  good  recording  is  for  the  lead  tune  of  ”LeavingBenbecula” in the ”Craigievar Dances” by Nicol McLaren and The GlencraigScottish  Dance  Band.   Acceptable  alternative  tune  is  Miss  Janet  Laing’sStrathspey by Nan Main, and David’s Cunningham’s recording for Book 22is a good recording.  Else choose a traditional Strathspey which is steady andhas well-defined 4 bar phrases.  



_Teaching Notes_  

Having  now  taught  this  dance  I  moved  it  from  the  be-ginning of the book to late in the book.  The central figure seems hard for people  to  visualize,  and  requires  strong  steps.   I  would  practice  the  figuesfor all couples.  This makes the dance quite fragile.  Also the dancers mustensure that they finish the reels by the end of bar 24 before the 1½ turns.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20067, '2020-08-09 12:23:15.555439+00', '2020-08-09 12:23:15.555439+00', 'Great Teddy Bear Hunt, The', 'GREAT TEDDY BEAR HUNT', 2, 32, NULL, 1, 4, 2, 2682, '2020-03-04', 'Devised  4/3/2020.   Whilst  in  covid-19  lockdown  houses  have  putteddy bears into windows and around houses in New Zealand motivatinng the“great teddy bear hunt.”  Recommended tune is “The Teddy Bear’s Picnic”(John W. Bratton) composed in 1907.  There is a nice recording called “FeteChampetre” by David Hall and his band and another called “Pink Panda’sPicnic” by Gordon Shand and his Scottish Dance Band.  



The figures reflect the various COVID-19 Levels of shutdown in New Zealand.1-8 is level 4, where we can only be in our own house bubble (Kristin (mywife) and I), 9-16 is level 3, where we can invvolve others but only a slightlybibber bubble, in this case my youngest son and his fiance’ (although we alsoinvolved Loralee, but deviser’s licence), 17-28 is level 2 where we come outof our houses and can involve small groups, and 29-32 is level 1, where wecan touch others, and don’t have social distancing.  



_Teaching Notes_  

Obviously this is a fugue and may take a wee bit of workespecially with the reels.  These should be thought of as “Last of the Laird" reels except for the bottom couple.  The tandem figure of eight movement need the second couple not to be tardy.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20068, '2020-08-09 15:21:31.475013+00', '2020-08-09 15:24:38.533055+00', 'Muir''s Rambles', 'MUIRS RAMBLES', 1, 32, NULL, 2, 3, 17, 1862, '2003-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1255, '2004-05-06 22:00:00+00', '2020-08-09 15:38:43.786082+00', 'Nancy Holland''s Strathspey', 'NANCY HOLLANDS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 1862, '2004-03-01', 'Devised March 2004 by Mike Briggs. The back-to-back half reels of four, the turn left about on a leftward setting step followed by a left hand turn halfway, and the left-hand lead up, are included in honor of Terry Glasspool, who led the John Muir (Wisconsin) Branch’s first workshop in December 2003.  The dance originally had no name: the naming rights were bought by Carol Buelow, our branch secretary, in an auction to raise funds for the branch.  She named the dance for Nancy Holland, chairperson of the branch.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20286, '2021-03-28 23:42:15.573028+00', '2021-08-23 18:22:38.06443+00', 'Ready to Begin Again', 'READY TO BEGIN AGAIN', 2, 32, NULL, 1, 2, 76, 440, '2011-03-26', 'Devised on March 26, 2011, after several people suggested that this would be a good title for a dance.', 60, '88/44/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3729, '1999-08-09 22:00:00+00', '2022-08-20 18:28:29.316361+00', 'Lassie wi'' The Yellow Coatie, The', 'LASSIE WI THE YELLOW COATIE', 1, 32, 9999, 1, 2, 76, 9998, NULL, '<<scddb-not-identical:3730>>', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6902, '1997-09-16 22:00:00+00', '2022-11-01 17:49:43.295272+00', 'Waiting for Joyce', 'WAITING FOR JOYCE', 2, 32, 9999, 1, 4, 1, 82, NULL, 'Dedicated to Joyce Taylor.', 50, '8000/8484/8484/8000', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20064, '2020-08-09 11:57:42.20694+00', '2022-12-04 13:46:59.204116+00', 'John Markham''s Rant', 'JOHN MARKHAMS RANT', 1, 32, NULL, 1, 3, 42, 2682, '2020-04-06', 'Inscribed "John Markham is a longstanding member of the Johnsonville SCD Club, and longstanding friend."', 56, '800/888/888/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17602, '2017-02-15 20:09:30.599189+00', '2020-08-15 07:24:19.823532+00', 'Noble Hill Jig, The', 'NOBLE HILL JIG', 2, 32, NULL, 1, 4, 1, 1582, '2011-01-01', 'May be danced as a 4 couple dance in a 4 couple set, or as a 3 couple dance in a 3 couple set.



Devised by Pat Clark, the class musician, and members of the group in 2011.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17604, '2017-02-15 20:12:03.553242+00', '2020-08-15 13:06:11.712178+00', 'Rachel and Tom Fenwick', 'RACHEL AND TOM FENWICK', 3, 32, NULL, 2, 3, 17, 1582, NULL, 'For Rachel and Tom Fenwick, on their Golden Wedding Anniversary, February 2013 The first two formations indicate the anniversary year. Devised by Pat Clark 2012', 79, '800/888/884/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17588, '2017-02-15 19:43:58.3835+00', '2020-08-15 14:23:28.339076+00', 'Chasing a Rainbow', 'CHASING A RAINBOW', 4, 32, 8, 1, 4, 1, 815, '2011-09-01', 'Devised for Bryan and Irene McGhee (North Virginia Branch) who went on holiday in the Inner Hebrides with Peter and Pat. For two days of showery weather, we seemed to chase the rainbows in the sky while on the winding roads of Mull and Skye.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17584, '2017-02-15 19:32:07.314238+00', '2020-08-15 14:41:07.855118+00', 'Alasdair''s Fancy', 'ALASDAIRS FANCY', 1, 32, NULL, 4, 4, 13, 1582, '1991-01-01', 'A dance in celebration of Alasdair’s 18th birthday (York) – now in Glasgow Branch.', 94, '8888/8686/8686/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3794, '1997-09-07 22:00:00+00', '2020-08-16 15:47:08.669769+00', 'You Must Stir It and Stump It', 'YOU MUST STIR IT AND STUMP IT', 2, 32, 9999, 1, 3, 42, 99, NULL, 'Originally devised to please myself under the title ‘Lewis Derrick’s Hornpipe’ (these were figures that I liked dancing in the 1970s). When it came to publication in the 1980s I was firmly told by my friends that it was exceedingly conceited to write a dance for yourself, so to silence the critics I changed the tempo and the title using W. S. Gilberts words from Ruddigore relating to the excessively self-effacing Robin Oakapple: ‘If you wish in this world to advance, your merits you’re bound to enhance, You Must Stir It and Stump It and blow your own trumpet or trust me you haven’t a chance’ – hah!', 53, '800/822/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20069, '2020-08-17 22:26:01.921685+00', '2020-08-17 22:26:01.921685+00', 'Campsie Glen', 'CAMPSIE GLEN', 3, 32, NULL, 1, 2, 76, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2901, '1997-04-03 22:00:00+00', '2020-08-19 09:01:43.049982+00', 'High Park Blacksmith, The', 'HIGH PARK BLACKSMITH', 1, 40, 9999, 1, 3, 42, 99, '1986-01-01', '', 63, '888/888/880/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20071, '2020-08-22 20:37:15.484154+00', '2020-08-23 19:39:45.528226+00', 'Farewell to Perth', 'FAREWELL TO PERTH', 3, 32, NULL, 2, 3, 17, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9462, '2000-05-21 22:00:00+00', '2020-08-23 20:39:41.848025+00', 'Cullen Skink', 'CULLEN SKINK', 3, 32, 9999, 1, 100, 2, 108, '1999-01-01', '', 75, '8448/8448/8448/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14820, '2013-04-29 14:14:24.240435+00', '2020-08-23 20:44:30.572443+00', 'Yaezakura', 'YAEZAKURA', 3, 32, NULL, 1, 4, 2, 10783, NULL, 'Yaezakura Is Japanese For Double Cherry Blossoms.



Saitama Prefecture is listed as having 3 of Japan''s Top 100 Cherry Blossom Spots, in Kumagaya Sakuratsutsumi, Omiya Park Saitama and Nagatoro.



In the middle of spring, after Someiyoshino, the most popular single petal cherry blossoms are over, Yaezakura, double petalled cherry blossoms start to bloom with their gorgeous pink flowers.



Yaezakura is also the word used to describe the final moments in salt production (because the bubbling salt resembles double cherry blossoms) in the Agehama style of salt making, as has been practised in Noto Peninsula in Ishikawa Prefecture for over 500 years. ', 94, '8888/8888/8888/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19114, '2018-12-11 17:33:50.755296+00', '2020-08-24 18:44:32.717522+00', 'Vana Tallinn', 'VANA TALLINN', 3, 48, NULL, 4, 4, 13, 11527, '2018-12-01', 'Symbolism:



1-4: Tall Hermann and first impressions from Old Town



5-8: Castle’s towers and walls



9-12: Walking up the streets and gates of Old Town



13-16: Pulling back from the castle’s walls to have ability to see more.



17-24: Visiting Kiek in de Kök and Fat Margaret towers



25-32: Roofs of houses and towers



33-40: Walking down the streets and gates of Old Town



41-48: Hall square with Christmas fair



The dance was presented to the local group at the second weekend "Bridge to the West" in Tallin, on December, 8, 2018



Original music composed by Anna Kovaleva.', 83, '8888/2828/8888/6666/5555/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17230, '2016-09-03 21:27:32.467872+00', '2020-08-24 18:49:20.024317+00', 'From Paper to Pearl', 'FROM PAPER TO PEARL', 3, 32, NULL, 1, 3, 42, 11035, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15603, '2014-09-03 14:54:56.436151+00', '2020-08-24 19:02:52.091543+00', 'April in the Algarve', 'APRIL IN THE ALGARVE', 2, 32, NULL, 1, 100, 2, 1359, NULL, 'Stub entry; source = Minicrib. Please inform the editors if you can supply further information, in particular an original description.', 69, '8008/8448/8888/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20072, '2020-08-25 09:37:33.569728+00', '2020-08-25 09:37:33.569728+00', 'Dance for an Elf', 'DANCE FOR AN ELF', 1, 32, NULL, 1, 3, 42, 11977, '1992-05-29', '', 42, '800/860/808/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20073, '2020-08-25 09:44:42.111588+00', '2020-08-25 09:51:43.825626+00', 'For Anika', 'FOR ANIKA', 3, 32, NULL, 4, 4, 13, 10451, '2020-01-01', 'For Anika Lange', 81, '5555/5555/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20075, '2020-08-25 10:02:43.959178+00', '2020-08-26 08:27:43.898558+00', 'Magic Roundabout, The', 'MAGIC ROUNDABOUT', 1, 32, NULL, 4, 5, 30, 10451, NULL, 'for Petra Wolf-Meszaros', 80, '58883/48884/48884/48884', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20076, '2020-08-26 14:13:02.985375+00', '2020-08-26 14:14:06.849128+00', 'Trip to Pukerangi, A', 'TRIP TO PUKERANGI', 1, 48, NULL, 1, 4, 1, 11979, '1993-01-01', 'Devised by Loralee Hyde and Maureen Robson while ona trip on the train up the Taieri Gorge with a group of dancers from Dunedin Summer School 1992/3.



1  - 8  The meeting of the group at the Dunedin Railway Station  

9 - 16  The winding track  

17 - 24  The tunnels and viaducts  

25 - 32  The notches (steep gullies)  

33 - 40  The transfer of the engine to the other end of the train.  

41 - 48  The quick return trip to Dunedin.', 64, '8888/8080/8222/8888/8000/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20078, '2020-08-28 21:08:54.434997+00', '2020-08-28 21:39:16.090597+00', 'Christmas at Bleecker', 'CHRISTMAS AT BLEECKER', 3, 32, NULL, 6, 53, 17, 11976, '2019-01-01', 'Dancers are numbered anti-clockwise around the set.', 100, '888/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (186, '1997-04-03 22:00:00+00', '2020-08-29 11:49:36.255704+00', 'Anniversary Strathspey', 'ANNIVERSARY STRATHSPEY', 3, 32, 9999, 3, 5, 16, 28, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (946, '1997-08-24 22:00:00+00', '2020-08-29 12:55:36.921009+00', 'Callanish', 'CALLANISH', 3, 96, 9999, 4, 4, 3, 108, '1994-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1646, '1997-11-27 23:00:00+00', '2020-08-30 09:07:14.102907+00', 'Diamond Jubilee Medley, The', 'DIAMOND JUBILEE MEDLEY', 4, 80, 4, 4, 4, 3, 28, '1983-01-01', 'This dance commemorates the Sixtieth Anniversary of the formation of the Royal Scottish Country Dance Society.  The first figure represents the beginning and the progression of the Society, with two dancers travelling in two directions to dance with others until all are dancing. The grand chain shows the links of the Branches, followed by a wheel, which breaks to include opposite dancers signifying how the Society continues to spread round the world.  The star includes everyone in a ring of friendly hand-giving, so typical of Scottish Country Dancing.  Finally, a circle of diamonds is followed by an all round poussette in the shape of a large diamond which symbolises the Diamond Jubilee.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13758, '2011-07-12 22:00:00+00', '2020-08-30 21:34:25.440561+00', 'Grand Central Station', 'GRAND CENTRAL STATION', 2, 32, NULL, 1, 3, 42, 2973, NULL, 'Devised in December 2008. 



As this is quite a busy dance, particularly bars 17-24, it brought an image of Grand Central Station to mind.



Music

Any busy jig. A suitable recording is ‘The Alder Burn‘, Dancing Forth, Gordon Shand and his Scottish Dance Band, track 4.', 66, '804/888/888/888', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (13383, '2009-11-05 23:00:00+00', '2020-08-31 11:32:23.963309+00', 'Crossing the Ohiwa Bar', 'CROSSING THE OHIWA BAR', 2, 32, NULL, 1, 4, 1, 3586, NULL, 'The “legend” of Ohiwa Bar. It is the fairly notorious entrance to the Ohiwa harbour. It is only able to be crossed in certain tidal conditions.



1 - 8. No way through  

9 - 16. The tide turns  

17 - 24. Running between the breakers  

25 - 32. Through the channels to home

', 62, '8088/8888/8800/8000', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3925, '1997-09-08 22:00:00+00', '2020-08-31 15:14:25.431771+00', 'Lord Beaverbrook''s Mirror Reel', 'LORD BEAVERBROOKS MIRROR REEL', 1, 48, 9999, 1, 4, 1, 9998, NULL, '', 71, '8008/8448/8448/8888/8440/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15310, '2013-12-19 10:50:07.417628+00', '2020-08-31 16:13:33.559007+00', 'Torridon Cross, The', 'TORRIDON CROSS', 2, 48, 9999, 1, 100, 11, 884, '2013-08-01', 'This dance started off as a four couple variation of Torridon Lassies but soon developed a life of its own.', 77, '8008/8668/8888/8448/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4634, '1998-07-08 22:00:00+00', '2020-09-01 14:04:52.168726+00', 'Monday Night', 'MONDAY NIGHT', 2, 32, 9999, 1, 100, 2, 1147, NULL, '', 62, '8008/8888/8008/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6354, '1997-09-14 22:00:00+00', '2020-09-03 17:54:49.080927+00', 'Strathspey for Mrs & Mrs John Day, A', 'STRATHSPEY FOR MRS AND MRS JOHN DAY', 3, 40, 9999, 1, 3, 42, 264, NULL, '', 56, '844/802/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17223, '2016-09-03 20:01:27.652941+00', '2020-09-01 15:41:29.459455+00', 'Hurricane Watch', 'HURRICANE WATCH', 1, 32, NULL, 1, 2, 76, 9998, NULL, 'This dance is for those Florida dancers who will show up for class regardless of the weather. ', 56, '88/88/22/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5035, '1997-09-28 22:00:00+00', '2020-09-02 11:42:12.257606+00', 'Officer And a Gentleman, An', 'OFFICER AND A GENTLEMAN', 1, 32, 9999, 1, 3, 42, 591, '1984-01-01', '', 50, '800/888/808/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5224, '1998-07-08 22:00:00+00', '2020-09-02 17:28:43.691252+00', 'Perthshire Maiden, The', 'PERTHSHIRE MAIDEN', 3, 32, 9999, 1, 102, 2, 13, NULL, '', 94, '8888/8888/8888/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6785, '1997-09-16 22:00:00+00', '2020-09-04 08:50:12.36898+00', 'Twa Bonnie Lassies', 'TWA BONNIE LASSIES', 3, 32, 9999, 1, 3, 42, 272, NULL, '', 44, '822/822/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13500, '2009-11-21 23:00:00+00', '2020-12-25 21:41:06.078331+00', 'Heid o'' the Brae, The', 'HEID O THE BRAE', 2, 96, 9999, 107, 56, 3, 1269, '2007-01-01', '808/848/808/848//383/383/484/484//808/848/808/848)  (W 81%; M 50%)', 71, '(808/848/808/848//383/383/484/484//808/848/808/848)  (W 81%; M 50%)', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (14053, '2011-08-25 22:00:00+00', '2020-09-06 11:35:33.35261+00', 'Spurtle King, The', 'SPURTLE KING', 3, 32, NULL, 1, 3, 42, 10430, NULL, 'Written for <<ddp:#10786>> - according to <<https://youtu.be/DHwRtMgPQfI|this video>>.', 44, '844/848/800/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8202, '1997-12-27 23:00:00+00', '2020-09-06 19:53:08.022684+00', 'Charlestown Chaser', 'CHARLESTOWN CHASER', 2, 32, 9999, 1, 4, 1, 2015, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8573, '1998-10-20 22:00:00+00', '2020-09-07 08:50:40.989104+00', 'Monterey Mixer', 'MONTEREY MIXER', 1, 32, 9999, 5, 56, NULL, 723, '1986-01-01', 'Devised by and for Elinor to teach at the Sunday morning general class at the 1987 Asilomar Weekend. Elinor wanted a dance to go with the tune "Oh I do like to be beside the seaside…” She worked it out at home singing the song which is a famous holiday song in the UK. ', 83, '484  484  888  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (8924, '1999-02-14 23:00:00+00', '2020-09-07 09:05:49.881252+00', 'Cal Tais', 'CAL TAIS', 2, 48, 9999, 1, 3, 18, 2559, NULL, '', 50, '800/844/866/822/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8931, '2001-06-05 22:00:00+00', '2020-09-07 09:13:55.634867+00', 'Hoolet, The', 'HOOLET', 1, 32, 9999, 1, 100, 11, 101, NULL, 'For Fiona Gardner''s 40th birthday. Fiona is very fond of owls, and has a large collection.', 88, '8888/8888/8008/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13732, '2011-07-10 22:00:00+00', '2020-09-07 12:13:17.437787+00', 'Norfolk Broads Hornpipe', 'NORFOLK BROADS HORNPIPE', 1, 32, 9999, 1, 3, 42, 10362, '2006-01-01', 'Devised to describe the erratic progress of the floating gin palaces on the Norfolk Broads at the height of the season.', 50, '880/844/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9190, '2000-01-10 23:00:00+00', '2020-09-07 23:14:42.824311+00', 'Three Score Years and Ten', 'THREE SCORE YEARS AND TEN', 3, 32, 9999, 1, 3, 42, 196, NULL, '', 44, '880/822/822/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9290, '2000-01-16 23:00:00+00', '2020-09-08 16:48:18.495547+00', 'Cashcrom, The', 'CASHCROM', 3, 32, 9999, 1, 2, 76, 501, '1991-01-01', '25-28

1st and 2nd couples set on the sides with nearer hands joined and then "cross link". This differs from "set and link" in that 2nd couple finish in the middle of the dance in first place facing down with the woman on the man''s right, while 1st couple finish in the middle of the dance in second place facing up with the woman on the man''s left.



A Cashcrom is a back-breaking one-man foot plough.', 60, '84/88/84/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9654, '2000-09-14 22:00:00+00', '2020-09-09 12:54:22.242396+00', 'Reel for My Spouse, A', 'REEL FOR MY SPOUSE', 1, 32, 9999, 2, 3, 17, 525, NULL, '', 58, '800/888/844/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19971, '2020-05-07 08:46:14.848524+00', '2020-09-09 14:31:50.177695+00', 'Conical Chronicles', 'CONICAL CHRONICLES', 1, 32, NULL, 2, 98, 3, 11944, '2020-05-01', 'Source: <<https://youtu.be/hbCJqaD6ylY|youtube video>>. For 1 couple and 4 cones. Devised especially for dancing in a lockdown bubble where the road works have paused.



It may also be danced with real people as a 3 couple dance in a 4 couple set in which case bars 9-16 are reflection reels instead of reflection figures of 8.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10155, '2001-10-23 22:00:00+00', '2020-09-10 10:43:40.258408+00', 'Bay and Bayan', 'BAY AND BAYAN', 1, 32, 9999, 1, 3, 42, 108, '2000-01-01', '', 59, '888/822/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10171, '2001-10-23 22:00:00+00', '2020-09-10 18:19:50.927906+00', 'Wooden Horse, The', 'WOODEN HORSE', 2, 32, 9999, 2, 3, 17, 108, NULL, '', 56, '880/808/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10174, '2001-10-23 22:00:00+00', '2020-09-10 18:31:29.296089+00', 'Tapsalteerie', 'TAPSALTEERIE', 4, 96, 3, 4, 4, 3, 272, NULL, '', 96, '8080/8888/8888/8888/8888/8888/8888/8888/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20472, '2021-09-12 10:09:13.795781+00', '2021-09-12 10:09:13.795781+00', 'Khandallah Town Hall, The', 'KHANDALLAH TOWN HALL', 3, 32, NULL, 1, 3, 42, 2682, '2021-04-21', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18854, '2018-10-06 19:50:19.53221+00', '2022-03-16 00:25:45.482791+00', 'Gillian and Joe Wheadon', 'GILLIAN AND JOE WHEADON', 3, 32, NULL, 1, 4, 13, 2682, '2018-08-20', 'Gillian and Joe Wheadon have been very kind to us in our German visits. Being tour guides, driving us everywhere and being great fun. This is a present for them. Recommended tune is "Red Plaid" (traditional) and I particularly like the set "Red Plaid/The Iron Man/The Banks of Spey" from Peter Elmes recording of "Glenys Pearce''s Strathspey" from the Lochiel Collection. Should this not be available, I would recommended tune "Miss Janet Laing''s Strathspey" by Nan Main, and either of the society''s recordings for book 22 would be good. Failing that use any reasonable recording of "The Balmoral Strathspey".', 81, '8484/8080/8888/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18772, '2018-10-05 08:40:59.608751+00', '2020-09-11 21:35:12.087623+00', 'Ghost and Mary Jo, The', 'GHOST AND MARY JO', 2, 32, NULL, 107, 55, 30, 2766, '2014-01-01', 'Mary Jo asked for a dance with a permanent ghost for when there are only 5 people for dancing and this is what I came up with.', 57, '800/880/844/620', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10708, '2002-07-21 22:00:00+00', '2020-09-12 21:59:12.945378+00', 'Sister Blanche of St. Andrew''s', 'SISTER BLANCHE OF ST ANDREWS', 2, 32, 9999, 1, 3, 42, 2961, NULL, '', 44, '800/888/800/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10754, '2002-07-24 22:00:00+00', '2020-09-12 22:12:05.142172+00', 'Road to Glasgow, The', 'ROAD TO GLASGOW', 1, 32, 9999, 1, 3, 42, 930, '1997-01-01', '', 63, '844/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10765, '2002-07-24 22:00:00+00', '2020-09-12 22:57:41.335007+00', 'Mo''s Farewell', 'MOS FAREWELL', 1, 40, 9999, 8, 6, 83, 1, '1998-01-01', '', 67, '888888/800000/888888/080000/888888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19978, '2020-05-20 19:36:53.655061+00', '2020-09-13 08:07:47.634182+00', 'Mrs Edna Lindsay', 'MRS EDNA LINDSAY', 99, 32, NULL, 1, 3, 42, 11950, NULL, 'Devised by D. Walker “to commemorate Mrs Lindsay’s attendance at every IVFDF so far”

(IVFDF is the Inter-Varsity Folk Dance Festival).

Mrs L was the pianist in a band led by Vic Smeltzer and he wrote the tune.



This is a quicktime dance but it is not known if it is a jig or a reel.', 50, '888/844/800/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20420, '2021-07-30 21:36:49.984731+00', '2021-07-30 21:36:49.984731+00', 'Janie of Braemar', 'JANIE OF BRAEMAR', 3, 0, NULL, NULL, NULL, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13748, '2011-07-11 22:00:00+00', '2020-09-20 08:44:22.632854+00', 'Lady Liberty', 'LADY LIBERTY', 1, 32, NULL, 1, 3, 42, 2973, '2003-01-01', 'Devised in 2003, with the tune „Staten Island‟ in mind. The name of the dance was chosen for its association with the tune: the Statue of Liberty is close to the north coast of Staten Island in New York harbour.', 44, '800/888/822/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15438, '2014-05-09 22:23:02.933135+00', '2021-08-10 18:41:54.046857+00', 'Amhuinnsuidhe Castle', 'AMHUINNSUIDHE CASTLE', 3, 32, NULL, 1, 3, 42, 10959, '2012-10-01', 'Pronounced: ave-an-soo-ee.



<p>Amhuinnsuidhe Castle, Isle of Harris, was built in 1867 by the Earl of Dunmore.', 50, '840/833/833/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9294, '2000-01-16 23:00:00+00', '2021-09-07 08:43:51.4258+00', 'L. A. XXth Anniversary', 'L A XXTH ANNIVERSARY', 1, 32, 9999, 1, 3, 42, 501, '1986-01-01', 'There is no date given for the dance. Originally SCDDB just used the publication date (1999) but according to <<https://my.strathspey.org/dd/issue/2614/|issue 2614>> it was devised in 1986.', 64, '864  888  844  888', 0, 1, 0, 0, 85);
INSERT INTO 'dance' VALUES (13391, '2009-11-08 23:00:00+00', '2020-09-17 08:30:13.146915+00', 'Dancing for Pleasure', 'DANCING FOR PLEASURE', 3, 40, NULL, 2, 3, 17, 10372, NULL, '»Devised by Patricia Blair of Chemainus, British Columbia.



Dedicated to the 50th Anniversary of TAC. We all love to dance and enjoy the coming together for such special celebrations.«

', 73, '888/800/844/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4354, '1998-01-12 23:00:00+00', '2020-09-13 21:12:43.4425+00', 'Micmac Rotary, The', 'MICMAC ROTARY', 1, 96, 9999, 4, 4, 3, 108, '1982-01-01', 'According to Bruce Herbold (in <<https://my.strathspey.org/dd/issue/2171/|issue 2171>>) this dance was first published in the 1983 Autumn collection (though not currently listed in the SCDDB entry for that publication).



*In that 1983 publication (and as we usually dance it in the San Francisco area because Mr Drewry taught it here at a workshop in about 1983) it is suggested that, if the dance is to be danced twice, that the women change partners into the neighboring set during the closing promenade and then change back at the end of the second time through. At the workshop IIRC Mr Drewry explained that this was prompted by teh fact that where it was first danced two dance halls were connected by a wide doorway, but that the two halls were not big enough for two sets so he added the swap of partners as each couple passed heh doorway. Knowing Mr Drewry this might be embellishment, but it is how we dance it here.*



*I think it might also be worth noting that this is the first dance with La Baratte.*', 79, '8080/8888/0808/8888/4444/4444/8888/8888/8888/6666/6666/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7037, '1998-09-29 22:00:00+00', '2020-09-13 21:49:53.763691+00', 'Well Done Jack', 'WELL DONE JACK', 2, 32, 9999, 1, 3, 42, 11982, '1718-01-01', 'SCDDB originally attributed this dance to "unknown" in 1719.  However George Williams in <<https://my.strathspey.org/dd/issue/2170/|issue 2170>> reports that:



*According to "The Playford Assembly" (Graham Christian, 2015) "Well Done Jack" was devised by Nathanial Kynaston and first published in Walsh''s "Twenty Four New Country Dances for the Year 1718" (rather than 1719) which was written by Kynaston.*



The version published by the RSCDS differs from that done in the English Country Dance tradition which is illustrated in <<https://youtu.be/jmr0SQUzqCI|this video>>. At around 1:00 the commentator describes a figure that "the Scottish dancers call Set and Link". However, curiously, the RSCDS version does not actually include that figure.

', 50, '880/880/888/800', 0, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (11014, '2002-11-24 23:00:00+00', '2020-09-14 15:15:37.986245+00', 'Broadway Welcome', 'BROADWAY WELCOME', 1, 32, 9999, 1, 3, 42, 930, NULL, '', 52, '820/888/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11224, '2003-03-09 23:00:00+00', '2020-09-15 08:16:43.068867+00', 'Don''t Touch the Door Lewie', 'DONT TOUCH THE DOOR LEWIE', 2, 32, 9999, 6, 118, 4, 3312, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12323, '2005-04-27 22:00:00+00', '2020-09-15 09:29:04.115825+00', 'Miss Ross of Ross', 'MISS ROSS OF ROSS', 3, 32, 9999, 1, 3, 42, 3577, NULL, '', 52, '880/844/844/666', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12196, '2005-04-14 22:00:00+00', '2020-09-16 09:07:15.849647+00', 'Dressed in Green and Gold', 'DRESSED IN GREEN AND GOLD', 3, 32, 9999, 1, 4, 1, 80, '2002-01-01', 'Dedicated to Diana K. Hooper .... Australia''s Best Export .... for a very special birthday', 69, '8008/8888/8228/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18503, '2018-08-13 16:42:51.005904+00', '2020-09-16 09:26:18.33422+00', 'Mount Maxwell Strathspey – Saltspring Island', 'MOUNT MAXWELL STRATHSPEY  SALTSPRING ISLAND', 3, 32, NULL, 2, 3, 17, 80, '2007-01-01', 'For the Saltspring Island Club, especially Laura and Harvey Moore. With thanks for all their generous hospitality and friendship. - HISCD



The title of this dance is given as just "Mount Maxwell Strathspey" in the index of <<ddpub:#1466>> but in full as "Mount Maxwell Strathspey – Saltspring Island" on the dance page. The shorter version is added an alias.', 64, '888/888/880/882', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13212, '2007-01-02 23:00:00+00', '2020-09-16 22:35:05.444801+00', 'Cairngorm Strathspey, The', 'CAIRNGORM STRATHSPEY', 3, 32, 9999, 3, 5, 16, 815, '2006-01-01', '', 82, '88088/88088/88888/08884', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13216, '2007-01-02 23:00:00+00', '2020-09-16 22:43:25.688292+00', 'Ladies in Green', 'LADIES IN GREEN', 2, 32, 9999, 1, 4, 1, 80, '2006-01-01', 'Inscribed to “The Delta Borderers” and their Spring Fling which occurs each year close to March 17th with Bobby Brown and the Scottish Accent playing. It is an evening to remember.



Ladies: please wear a touch of green i.e. an emerald necklace, a Hermes scarf in soft tones of green and gold, jade earrings in a silver setting etc etc .....', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13393, '2009-11-08 23:00:00+00', '2020-09-17 08:33:16.715612+00', 'Joanie''s Hornpipe', 'JOANIES HORNPIPE', 1, 32, NULL, 1, 3, 42, 3599, NULL, '»Deviser''s notes::

  Bars 17-24 are a variation of ›inverted triangles‹ as published by the R.S.C.D.S. See

  <<ddd:The Nurseryman>>, devised by S. Brown, Preston.



  Bars 25-30 are all pas de basque danced with a two hand hold in the centre of the set.



Devised by John Reeves, Peterborough, Ontario. This wee dance is dedicated to Joan Plumb Schmidt whose favourite dance is <<ddd:Jessie''s Hornpipe>>. We met at TAC Summer School in 1985 at the ball practice during <<ddd:J. B. Milne>>. Since then we have been fortunate to have been able to attend every TAC Summer School held in the East.«

', 50, '800/888/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13553, '2010-01-19 23:00:00+00', '2020-09-18 16:33:40.808997+00', 'Handsel, The', 'HANDSEL', 2, 32, NULL, 1, 3, 42, 347, NULL, '', 47, '880/840/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9903, '2002-02-16 23:00:00+00', '2021-03-27 19:03:11.1672+00', 'Where the Almond meets the Tay', 'WHERE THE ALMOND MEETS THE TAY', 3, 32, 9999, 1, 4, 1, 276, NULL, 'Renamed by the deviser in February 2017.  The previous name was "Where the River Almond Flows".', 80, '8448/8888/8248/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13693, '2011-06-27 22:00:00+00', '2020-09-19 11:38:50.437384+00', 'New Irish Rover, The', 'NEW IRISH ROVER', 1, 32, NULL, 1, 4, 11, 228, NULL, 'Devised: 2003-04', 81, '8448/8448/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20082, '2020-09-18 22:44:59.487885+00', '2021-02-06 18:16:23.697769+00', 'Proitzer Mühle', 'PROITZER MUHLE', 2, 32, NULL, 1, 3, 42, 3342, '2020-08-01', 'The deviser(s) write:

*I first saw “Dance to each corner and set” in a diamond formation in the dance <<ddd:#8674>> by Johnstone from the Loreburn IV collection. I liked the idea, so devised this dance for the Central German Branch AGM und weekend at the Proitzer Mühle, August 2020.*', 55, '844/888/808/860', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13139, '2006-12-05 23:00:00+00', '2021-08-16 12:47:54.733654+00', 'Committee Meeting, The', 'COMMITTEE MEETING', 1, 32, 9999, 1, 3, 42, 104, '2003-05-01', 'Despite living in the home counties, the Committee of the Argyll Scottish Dancing Group held their Committee Meeting on Arran in May 2003. This dance is devised for the Committee and their friends who shared this holiday with them.', 63, '888/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13750, '2011-07-11 22:00:00+00', '2020-09-20 08:57:56.258606+00', 'Balance On-Line', 'BALANCE ONLINE', 3, 32, NULL, 1, 100, 11, 2973, '2003-03-01', 'Devised in March 2003 to celebrate the 10th Anniversary of the Strathspey Server. The strathspey balance in line figure (see below for instructions) across the top and bottom of the set, and then on the sides, depicts the connections among dancers around the world through the Internet, thanks to the Strathspey Server.



Music:  John Stephen of „Chance Inn‟ (Fitchet‟s SD Collection, page 7). A suitable recording for this dance is the Selection of Strathspeys, Track 11 of Any Good Dance, Any Good Tune, by Bobby Brown and The Scottish Accent.



Strathspey Balance in Line (devised by <<ddp:Levy, Milton#501>>).



Two bars of music; strathspey (common schottische) setting.Handing as follows:  On bar 1, those with left hands joined in the middle drop left hands and all, moving to the right, join left hands under right hands, then drop right hands.  Those moving into the middle of the line join right hands.  Repeat moving to the left on bar 2, joining right hands under left hands.', 81, '8668/8448/8668/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13767, '2011-07-12 22:00:00+00', '2020-09-21 11:14:06.098986+00', 'Wembley''s Gem', 'WEMBLEYS GEM', 3, 32, NULL, 1, 3, 42, 10375, NULL, 'Devised for Gillian Collis by Patricia Hamilton with contributions from the Wembley and District Scottish Association dance class. 



Gillian and her husband Peter are the longest serving members of the Association having joined in 1961. Gillian has been President twice, Honorary Secretary and, since the early 1980s the teacher of the dance class. Gillian is passionate about good cover and eye contact with your partner while dancing, and parallel reels were included in this dance for this very purpose. Gillian is a wonderful ambassador for the Association and signs her name GEM Collis, hence the title of this dance - Wembley’s Gem.



tune at http://www.wdsa.co.uk/Gillian Collis Strathspey.PDF', 63, '844/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13773, '2011-07-13 22:00:00+00', '2020-09-21 11:30:04.738287+00', 'Shevock, The', 'SHEVOCK', 3, 32, NULL, 3, 5, 7, 2973, '2009-05-01', 'Devised May 2009, in honour New York Branch stalwart Sheila Wilson, on the occasion of her receiving the RSCDS Branch Award. James Stevenson-Mathews wrote the tune in honour of Sheila. The tune and the dance are named after a small stream in her native village of Insch in Scotland.

Dance modified in April 2010.



Music

The Shevock, by James Stevenson-Mathews', 71, '88888/80800/84884/82844', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3115, '1997-09-04 22:00:00+00', '2020-09-21 12:25:54.352794+00', 'Inveruglas Water', 'INVERUGLAS WATER', 1, 32, 9999, 1, 3, 42, 316, NULL, 'A little bit of background information to the dance provided by its deviser:



Some years back David''s parents had a holiday at or near Inveruglas Water and loved it so much that his mother, <<https://my.strathspey.org/dd/person/1830/|Mary Queen>>, wrote the tune "<<https://my.strathspey.org/dd/tune/3953/|The Inveruglas Reel>>". 

David liked it and wrote the dance to go with it. ', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13804, '2011-07-26 22:00:00+00', '2020-09-22 08:33:46.448458+00', 'Erlangen Reel, The', 'ERLANGEN REEL', 1, 32, NULL, 1, 3, 42, 854, '2009-01-01', 'Erlangen in southern Germany has a young group of energetic dancers, for whom I taught a day school in 2009. I thought this rather energetic dance might suit them. Bars 9-24 are inspired by bars 9-24 of ''The Colonel'' as interpreted by the RSCDS in their 75th Anniversary leaflet.



One version of the music can be found at <<http://www.folktunefinder.com/tunes/392214/>> [though that link now seems broken and possibly should be replaced by <<http://www.folktunefinder.com/tunes/27880>>?]', 56, '800  888  888  844', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (13841, '2011-08-21 22:00:00+00', '2020-09-22 08:41:41.01956+00', 'Rona''s Celebration', 'RONAS CELEBRATION', 3, 32, NULL, 1, 4, 1, 872, '1998-12-10', 'Devised to celebrate the 65th birthday of Rona Alexander, a member of Bournemouth Branch of the RSCDS 10 December 1998', 66, '8888/8008/0880/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13860, '2011-08-21 22:00:00+00', '2020-09-22 19:27:37.192812+00', 'Carmichael Square', 'CARMICHAEL SQUARE', 1, 40, NULL, 4, 4, 13, 3699, NULL, '*The instructions for this dance, faithfully abbreviated in the MiniCrib, describe bars 9-14 and 17-22 as 6 bars of reel of 4 across. The original middle couples end on the sides behind them. However the original side couples must not pass LSh on bar 6 of the reel so they start the half LH across in front of the person they were originally facing. With the music at the bottom:*  

*Bar 9.........................Bar 15......................Bar 17*  

*2W 3M 3W 4M........3W 4M 2W 3M........3W 2M 4W 3M*  

*2M 1W 1M 4W........1M 4W 2M 1W........1M 2W 4M 1W*  ', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (386, '1998-04-29 22:00:00+00', '2020-09-27 08:47:39.139702+00', 'Banks Hornpipe', 'BANKS HORNPIPE', 1, 32, 9999, 1, 3, 42, 270, NULL, '', 45, '800/860/822/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20083, '2020-09-22 18:15:12.577729+00', '2020-09-23 09:26:22.329101+00', 'Printing Lads, The', 'PRINTING LADS', 3, 32, NULL, 2, 3, 17, 3120, '1998-07-01', 'Dance for the wedding of Kees and Henk, and also Henk''s birthday, on 13 August 1998', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11437, '2003-09-16 22:00:00+00', '2020-09-27 08:48:44.591691+00', 'Bungee Plunge, The', 'BUNGEE PLUNGE', 1, 48, 9999, 1, 4, 13, 3373, '1997-01-01', 'Dance devised by Tina Dornbusch on the occasion of Sally''s 75th birthday, when she tried bungee jumping for the first time.', 35, '0008/0008/0008/0028/0088/4428', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1354, '1997-08-31 22:00:00+00', '2020-09-27 10:00:09.06238+00', 'Coronation, The', 'CORONATION', 1, 64, 9999, 4, 4, NULL, 270, NULL, '', 78, '8080/8484/8484/8888/8888/8484/4848/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20097, '2020-09-30 16:00:12.046329+00', '2020-10-08 16:35:58.761223+00', 'Tantalizing Treats', 'TANTALIZING TREATS', 3, 32, NULL, 1, 3, 42, 11971, '2020-07-01', 'The title refers to the first 16 bars mirroring the vain attempt of contacting one''s partner. Tantalizing as the circumstances of the corona crisis are, it seemed to cover the present situation many dancers are in.

', 44, '440/440/808/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17537, '2017-01-05 10:45:56.961327+00', '2020-09-27 19:51:43.388919+00', 'Humours of California', 'HUMOURS OF CALIFORNIA', 3, 32, NULL, 1, 3, 42, 515, '2015-06-01', 'Devised by John Wilkinson June 2015.



Dedicated to Marian Anderson and Max Ketchin on the occasion of their wedding. They live in the

village of California, near Falkirk in Scotland. John kindly permitted the Belfast Branch to include

the "Humours of California" strathspey in their 70th anniversary book.', 47, '800/880/855/855', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4710, '1997-09-09 22:00:00+00', '2020-10-10 12:24:32.414291+00', 'Mr Hamilton of Wishaw''s Reel', 'MR HAMILTON OF WISHAWS REEL', 1, 32, 9999, 1, 3, 42, 1157, '1799-01-01', 'The original title in the <<ddpub:#474|book>> was "Washaw" but this seems likely to be a spelling mistake. The original is kept as a spelling alias.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14038, '2011-08-25 22:00:00+00', '2020-12-26 10:01:01.706652+00', 'Birdham Pool', 'BIRDHAM POOL', 2, 40, NULL, 1, 3, 42, 347, NULL, '', 50, '800/844/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13760, '2011-07-12 22:00:00+00', '2021-10-04 07:01:37.897391+00', 'Scotia Swing', 'SCOTIA SWING', 2, 32, NULL, 1, 3, 42, 2973, '2009-11-01', 'Devised November 2009. 



This dance is dedicated to Scotia Dancers of New York City, where we dance on Monday evenings and where I was teaching when this dance was first tried out.



Music   Any good jig. A suitable recording is ‗Welcome to Dufftown‘, Nice to See You, Ian

Cruickshanks and his Band, track 11.', 44, '800/822/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14374, '2011-12-16 23:00:00+00', '2020-09-27 20:10:04.837421+00', 'It''s Kosher', 'ITS KOSHER', 1, 32, NULL, 1, 100, 2, 10588, NULL, 'In September 2008, Glenayre Club of Coquitlam, BC moved to the Burquest Jewish Corntnunity

Centre, which has a lovely wooden floor in contrast to the many years we danced on a tiled

cement floor. The title is a somewhat tongue in cheek description of our club finally getting to

dance on the ''real thing''.



Suggested Music: Set of 4 x 32 Reels" on Diamond Jubilee CD, track # 14



[ed.] Devisors added note: I created this dance for a mixture of beginner and experienced

dancers, just to get the beginners following a track of right shoulder reels of three. The ladles

lead for the whole eight bars.', 75, '8008/8888/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14414, '2012-03-08 16:39:06.100364+00', '2020-09-27 20:31:03.40067+00', 'Quick Shot', 'QUICK SHOT', 1, 32, NULL, 1, 4, 1, 10517, NULL, 'Progression is 2341 with 1s on opposite side.  8 times through.  All couples "switch gender" as needed.', 66, '8800/8880/8444/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19863, '2020-03-09 15:52:04.528594+00', '2020-09-28 04:02:48.360289+00', 'Charming Molly', 'CHARMING MOLLY', 2, 32, NULL, 1, 3, 42, 10568, '2019-08-01', 'Charming Molly was the name of the ship that Elizabeth Woodbury’s paternal grandmother''s family were on from Dorchester (Boston) to Annapolis Royal, Nova Scotia, in May 1760.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19867, '2020-03-09 16:22:17.253101+00', '2020-09-28 04:29:11.917068+00', 'John McCormick of Loomis, Wilson and Hollidale', 'JOHN MACCORMICK OF LOOMIS WILSON AND HOLLIDALE', 1, 32, NULL, 1, 3, 42, 10568, '2019-08-01', 'This dance is written for my friend John McCormick. It is always a pleasure to see him at the TAC teachers’ weekend and the summer school.', 70, '880/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14476, '2012-06-15 04:39:16.623699+00', '2020-09-28 21:17:06.000118+00', 'Be my Partner', 'BE MY PARTNER', 3, 40, NULL, 1, 4, 11, 3661, '2006-01-01', 'A present to Judit Kerner and Áron Diószegi for their wedding', 80, '8888/0880/8888/8888/8008', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20086, '2020-09-29 01:22:05.415251+00', '2020-09-29 01:27:51.638587+00', 'Old Bushmills Blend', 'OLD BUSHMILLS BLEND', 1, 32, NULL, 1, 3, 42, 479, '1990-01-01', 'Devised on the occasion of the ''Old Bushmills International Sports Academy''

', 41, '800/800/844/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14479, '2012-06-15 04:54:19.870025+00', '2020-09-29 07:58:11.004909+00', 'Wedding in August', 'WEDDING IN AUGUST', 2, 40, NULL, 1, 4, 2, 3661, '2011-08-01', 'A  present for Ania Horváth and Mátyás Szili on their wedding', 75, '8448/8888/8008/8888/8008', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17718, '2017-04-30 09:16:27.986133+00', '2020-09-29 09:07:22.053292+00', 'Band of Friends', 'BAND OF FRIENDS', 2, 32, NULL, 107, 2, 4, 3325, '2019-01-01', 'A Mixer dance danced five times through.



This dance is dedicated to the friendship shown by its members to each other and guests alike as the enduring bedrock of the Berkhamsted Strathspey and Reel Club.



Devised originally in 2016, bars 25-32 revised in 2019.

', 88, '88/88/44/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20087, '2020-09-30 13:28:17.357573+00', '2020-09-30 13:28:17.357573+00', 'Romsey Rant, The', 'ROMSEY RANT', 4, 0, NULL, 8, 6, NULL, 9998, '2014-01-01', 'Demonstration medley by the New Forest Scottish Dancers.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20092, '2020-09-30 15:25:06.95292+00', '2020-10-05 16:55:16.391685+00', 'Dancing on the Green', 'DANCING ON THE GREEN', 1, 32, NULL, 1, 3, 42, 11971, '2020-07-01', 'Another dance written for the Freiburg Scottish Country Dancers during the corona weeks in which no hands are given throughout the dance. The title refers to the venue, which is a partly overgrown parking lot outside the St. Georg church assembly hall in Freiburg - St. Georgen. Special thanks go to Kirsten Steinbach for suggesting the title of the dance.', 38, '800/888/800/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14670, '2013-01-21 23:45:18.927307+00', '2020-10-01 18:14:35.420507+00', 'Sketcher, The', 'SKETCHER', 1, 32, NULL, 1, 3, 18, 10714, NULL, 'For Mary Ellen Clark, San Gabriel area.



Unusual progression: 1c+2c+4c repeat; finishing (3,4,1,2) and 1c step down to (3,4,2,1); 3c starts the 3rd time through.  Can be danced in a 3c set with no changes', 53, '800  822  888  888', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (20093, '2020-09-30 15:29:53.867793+00', '2020-10-05 17:25:08.14578+00', 'Keep Calm and Carry On', 'KEEP CALM AND CARRY ON', 2, 32, NULL, 1, 3, 42, 11971, '2020-07-01', 'Yet another dance according to the coronavirus requirements – no giving of hands involved. The title echoing a British WWII motto was chosen as it seemed to fit the present climate.', 47, '800/804/808/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20094, '2020-09-30 15:35:59.935124+00', '2020-10-05 19:12:06.724289+00', 'Those Endless Winding Roads', 'THOSE ENDLESS WINDING ROADS', 1, 32, NULL, 1, 3, 42, 11971, '2020-07-01', 'The dance was inspired by a car trip on a bendy country road up the Black Forest to reach the parking lot below the hiking trail leading to the Köhlergartenkopf, which offers a fantastic view into the Rhine Valley. And oh - pardon the pun, please.', 56, '800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20096, '2020-09-30 15:54:00.841547+00', '2020-10-06 00:59:40.105148+00', 'Endless Summer', 'ENDLESS SUMMER', 1, 32, NULL, 1, 3, 42, 11971, '2020-07-01', 'The corona lockdown eventually led to the feeling of an endless summer.', 56, '880/888/880/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20095, '2020-09-30 15:42:42.681654+00', '2020-10-25 08:35:39.106015+00', 'Let''s All Join In', 'LETS ALL JOIN IN', 3, 48, NULL, 1, 4, 1, 11971, '2020-07-01', 'This dance is compatible with coronavirus restrictions, but it can also be danced including the giving of hands, once the crisis is over. The title refers to the eventual involvement of all dancers during the first 16 bars.', 63, '8008/2882/8008/8888/8066/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20108, '2020-10-04 14:09:58.903628+00', '2020-10-04 14:09:58.903628+00', 'Californian Bumpkin, The', 'CALIFORNIAN BUMPKIN', 1, 96, NULL, 4, 111, 3, 952, '2014-08-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20602, '2022-01-07 18:18:34.033307+00', '2022-01-07 18:18:34.033307+00', 'Jingle Bells Country Dance, The', 'JINGLE BELLS COUNTRY DANCE', 1, 32, NULL, 1, 4, 1, 11514, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20098, '2020-09-30 16:07:11.186149+00', '2020-10-12 18:46:48.817531+00', 'If All the Snow Goes up in Flames Its Ashes Yet Remain', 'IF ALL THE SNOW GOES UP IN FLAMES ITS ASHES YET REMAIN', 2, 32, NULL, 1, 3, 42, 11971, '2020-07-01', 'The title of the dance is a rough translation of a line from the play “The Weavers” by Gerhart Hauptmann, expressing desperate optimism – well needed in times of virus pandemics. The name of the play also mirrors the formations of the half figures of eight and the reels of three.', 69, '888/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20174, '2020-12-07 18:56:32.339202+00', '2020-12-07 18:56:32.339202+00', 'Hello to Brittany', 'HELLO TO BRITTANY', 3, 40, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20089, '2020-09-30 13:45:15.807574+00', '2020-12-24 19:31:33.471348+00', 'Helvellyn', 'HELVELLYN', 3, 32, NULL, 4, 4, 1, 11237, '2020-02-01', '', 88, '8484/8888/8484/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20090, '2020-09-30 13:48:31.637662+00', '2020-12-24 19:32:47.999492+00', 'It''s All Turned Out Perfectly', 'ITS ALL TURNED OUT PERFECTLY', 2, 32, NULL, 1, 102, 2, 11237, '2019-11-01', 'This dance was submitted for the London Branch 90th anniversary competition. Unfortunately it did not please the judges. But I still like it - as did those who tested it originally. So, with permission of London Branch, I decided to publish it anyway.', 78, '6666/8888/2882/4884', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19429, '2019-06-28 17:16:15.280575+00', '2020-10-02 19:56:05.667349+00', 'Between Two Lakes', 'BETWEEN TWO LAKES', 3, 32, NULL, 1, 100, 2, 11237, '2018-09-01', 'This is for Liz and <<ddp:#11262|Colin Anderson>> who teach at and help organise dance groups in Annecy and Geneva which are both cities beside lakes named after them. 2nd and 3rd couples stay in their own halves of the set representing the groups in each city, while 1st and 4th couples, representing the double lives of Liz and Colin, constantly flit between them.', 88, '8008/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20079, '2020-08-30 20:40:38.003316+00', '2020-10-04 14:36:20.544973+00', 'Ebb and Flo''', 'EBB AND FLO', 1, 80, NULL, 4, 119, 3, 952, '2017-08-01', 'Source: <<https://youtu.be/PoPPm467DdA|Red Thistles video>>. The name of the dance is given as *Ebb and Flow* on the video, but *Ebb and Flo''* in the book. The description of the dance is written assuming each trio is one man between two women but many other combinations are possible.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (597, '1997-04-03 22:00:00+00', '2020-10-02 21:03:44.475121+00', 'Blue Toon, The', 'BLUE TOON', 3, 32, 9999, 1, 3, 42, 108, '1982-01-01', 'For Gary Morris of Wellington, N.Z.



Some of Gary''s forebears came from Peterhead, which is called "The Blue Toon".', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20031, '2020-06-19 23:06:11.017943+00', '2020-10-02 23:00:06.725526+00', 'Terviseks', 'TERVISEKS', 1, 32, NULL, 1, 4, 5, 11527, NULL, 'The title of the dance means "Cheers" or "Good Health" in Estonian. The deviser presented this dance "to our Estonian dancers during weekend in Tallinn December 2019".



Source: <<https://youtu.be/bh6LB0TN6hw|youtube video>>.', 72, '8040/8484/8808/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (389, '1998-09-29 22:00:00+00', '2020-10-03 12:26:18.187188+00', 'Banks of Allen, The', 'BANKS OF ALLEN', 2, 32, 9999, 1, 2, 76, 9998, NULL, 'This dance has been published as a reel, but the tune is quite obviously a jig. Recent RSCDS publications correct this error.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14952, '2013-06-23 18:52:42.146556+00', '2020-10-03 18:09:24.796675+00', 'Washing Line, The', 'WASHING LINE', 3, 48, NULL, 4, 4, 30, 10799, '2008-04-01', 'Devised in honour of Rod Sharp''s 80th Birthday



Twice through, second time 2c+4c leading.', 83, '8080/0808/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20101, '2020-10-03 21:00:29.919849+00', '2020-10-03 21:00:29.919849+00', 'Pavel Krepak''s Jig', 'PAVEL KREPAKS JIG', 2, 32, NULL, 1, NULL, 42, 11529, '2020-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20102, '2020-10-03 21:50:04.066031+00', '2020-10-03 21:50:04.066031+00', 'Marianna''s Strathspey', 'MARIANNAS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 952, '2004-07-01', 'Devised to celebrate Marianna Harvey''s birthday to a <<ddt:#10684|tune>> specially composed by Muriel Johnstone.', 47, '800/844/822/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20103, '2020-10-03 21:56:48.41539+00', '2020-10-03 21:56:48.41539+00', 'Armin''s Dance', 'ARMINS DANCE', 1, 40, NULL, 3, 5, 7, 952, '2014-01-01', '"To celebrate a very important birthday for Armin Busse, with grateful thanks for many years of loyalty and great dancing."', 60, '84840/88880/80800/88880/80800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20105, '2020-10-03 22:24:39.329619+00', '2020-10-03 22:25:27.287343+00', 'Forty-Something Reel, The', 'FORTYSOMETHING REEL', 1, 40, NULL, 2, 3, 17, 952, '2015-01-01', 'For the 40th anniversary of the Red Thistles dancers - though the name and emblem of the group came after its formation, hence the "Forty-Something".



NB the title is given in the book as "Forty-Something" on the dance instruction page, but "Forty Something" without hyphen, in the index. The latter is added as an alias.', 83, '888/855/855/888/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20106, '2020-10-03 22:37:48.47135+00', '2020-10-03 22:37:48.47135+00', 'Jonathan''s Farewell', 'JONATHANS FAREWELL', 3, 32, NULL, 1, 2, 76, 952, '2016-09-01', 'Devised on the occasion of Jonathan Lovell''s retirement from active participation as a Red Thistle dancer, September 2016.', 58, '82/88/88/84', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20107, '2020-10-03 22:44:31.595011+00', '2020-10-03 22:44:31.595011+00', 'Rosemary''s Reel', 'ROSEMARYS REEL', 1, 32, NULL, 2, 3, 18, 952, '2016-01-01', 'Modified in 2016 based on an original dance written for Rosemary Thorne in 1986.', 67, '800/888/844/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16889, '2016-02-29 15:05:33.932374+00', '2020-10-04 10:34:00.369432+00', 'Otters In Kenick Burn', 'OTTERS IN KENICK BURN', 2, 32, NULL, 1, 3, 42, 11237, '2015-06-01', 'Alternating tandem reels were first invented for <<ddd:The Flight of the Falcon#2222|falcons>> and later reused for <<ddd:Pelorus Jack#5209|dolphins>> but they do very nicely for otters as well. Here 1st couple are the otters. The supporting couples are rocks in the pools for bars 1-8, then fish being chased in bars 9-24 (lucky 2nd couple escape but the hapless 3rd couple get caught, metaphorically eaten and their remains neatly discarded in the corner - sorry!) and finally in bars 25-32 they are flotsam eddying with little vortices in the wake of the departing otters.



The dance was originally a reel, but was later changed to be a jig.', 53, '800/864/864/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20104, '2020-10-03 22:11:16.598747+00', '2020-10-04 21:05:41.038072+00', 'Cairngorm Magic', 'CAIRNGORM MAGIC', 1, 40, NULL, 1, 3, 42, 952, '2014-02-01', 'This may also be danced as a Ladies set. This version is shown on the Red Thistles DVD accompanying the book of dances. Some videos of this dance refer to it as The Magic of Cairngorms.', 51, '800/855/888/888/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16770, '2015-09-22 21:07:43.873989+00', '2020-10-16 22:27:12.438567+00', 'White Cart, The', 'WHITE CART', 3, 32, NULL, 2, 3, 17, 2673, NULL, 'The White Cart is from the Laurieston Collection 3 of dances by Alice McLean. Laurieston is a district in the Gorbals area situated south of the River Clyde, in the Scottish city of Glasgow.



The White Cart is the name of a river running 2 miles due south of Laurieston. It joins The Black Cart before running into the River Clyde. ', 67, '840/888/844/804', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20121, '2020-10-06 13:38:15.5602+00', '2020-10-15 05:01:52.969813+00', 'Robert Shaw''s Strathspey', 'ROBERT SHAWS STRATHSPEY', 3, 32, NULL, 6, 3, 18, 1415, NULL, 'This dance is dedicated to Robert Shaw, my first pipe major when I moved to Glasgow. He taught me a huge

amount about competing pipe bands, and led the bands I played in with him to many prizes.', 83, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20109, '2020-10-04 14:15:06.91179+00', '2020-10-04 14:15:06.91179+00', 'Corn Rigs and Variations', 'CORN RIGS AND VARIATIONS', 1, 32, NULL, 107, 98, NULL, 952, NULL, 'Variations of <<ddd:Corn Rigs#1348>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20521, '2021-10-12 15:42:11.004424+00', '2022-09-23 19:54:05.39397+00', 'Giant''s Causeway, The', 'GIANTS CAUSEWAY', 3, 32, NULL, 101, 117, 104, 12076, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15640, '2014-10-01 22:15:38.30429+00', '2020-10-12 11:27:49.357023+00', 'Eric''s Reel', 'ERICS REEL', 1, 32, 9999, 1, 3, 42, 550, NULL, 'Unfortunately the dance was published without background notes.



The Eric in question is Eric Liddell, the runner made famous by the film

"Chariots of Fire". The dance was written for a beginners class which

met in the Eric Liddell Centre in Morningside, Edinburgh. It was the 9th

October 2012, their 3rd class of the season. I was introducing them to

setting, and I wanted a dance with plenty of practice for setting that

contrasted with the other dance that evening (Bonnie Geordie''s Wig), but

didn''t require any figures we hadn''t encountered yet.



Seonaid Lynn was musician for the class that evening, and when she heard

I had written a new dance for the class, she decided to write a tune to

go with it, which she also premiered that night; this is the tune which

Graeme Munro plays on the CD to accompany the RSCDS Edinburgh Branch

90th Anniversary book.', 50, '800/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12369, '2005-04-27 22:00:00+00', '2020-10-13 19:28:45.308621+00', 'Padre Donald Wallace', 'PADRE DONALD WALLACE', 1, 32, 9999, 1, 100, 2, 678, NULL, 'Rev. Group Captain Donald Wallace was Padre at the Royal Caledonian Schools in Bushey, Hertfordshire. When he retired, the school asked Janet (who taught dancing at the school) to devise a dance for  Donald

as he was so interested in dancing. The dance has shaking hands and chasing round movements because he was always going around the world meeting people and shaking hands with everyone. The dance is a little bit tricky. The children at the Royal Caledonian School performed it for Donald and he loved it. Brian and Pat Hamilton composed a tune, also titled Padre Donald Wallace.  



Rev. Group Captain Donald Wallace''s Obituary is available in the Telegraph at

<<https://www.telegraph.co.uk/obituaries/2018/06/04/reverend-group-captain-donald-wallace-obituary/>>', 75, '8448/8888/8448/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16069, '2015-02-15 14:26:29.834971+00', '2020-10-14 22:00:39.164288+00', 'Cooper''s Great-Auntie Millicent and Great-Uncle Max, The', 'COOPERS GREATAUNTIE MILLICENT AND GREATUNCLE MAX', 2, 40, NULL, 1, 3, 42, 228, '2015-02-15', '10-bar phrases.



After <<ddd:The Wee Cooper o'' Fife>>, <<ddd:The Cooper''s Wife@Mitchell>>, <<ddd:The Cooper''s Wife@Will|another Cooper''s Wife>> and <<ddd:The Cooper Children>>, here''s a chance to meet even more members of the family.



Devised at the Central Germany Branch''s Carnival workshop 2015.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9170, '2001-05-20 22:00:00+00', '2020-10-18 09:52:36.921705+00', 'Barbara''s Littlebeck Scramble', 'BARBARAS LITTLEBECK SCRAMBLE', 3, 32, 9999, 3, 5, 7, 11988, NULL, '"Barbara''s Littlebeck Scramble was devised by Graham Williams from Whitby. Graham held a Walk, BBQ and Dance every year for 30 years in the village of Littlebeck and Barbara used to lead a walk each year from the village hall and back for about an hour arriving back in time for a BBQ followed by a dance."

*Information supplied by Ian Barbour.*', 82, '88888  88888  81810  84885', 0, 1, 0, 0, 81);
INSERT INTO 'dance' VALUES (20120, '2020-10-06 13:36:15.382384+00', '2020-10-16 05:15:59.374872+00', 'Ally''s Book of Sayings', 'ALLYS BOOK OF SAYINGS', 1, 32, NULL, 1, 3, 42, 1415, NULL, 'This dance is dedicated to Ally McLaughlin who was the pipe major of the Scottish Fire and Rescue Service

Pipe Band for four years. He had a rather unique turn of phrase, which led someone in the band to create a

Facebook page collating his sayings.', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8083, '1997-09-18 22:00:00+00', '2020-10-17 10:46:48.718803+00', 'Winstanley House', 'WINSTANLEY HOUSE', 3, 32, 9999, 1, 3, 42, 598, NULL, 'My ancestors lived in the small parish of Winstanley, Lancashire, England for more than 200 years. On a recent trip to England, while travelling throught the area. I came upon a private road with the name Winstanley House on the gate. (Deanna Saint Amand)', 38, '800/880/880/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16877, '2016-02-25 00:34:47.454146+00', '2020-10-17 20:29:29.628493+00', 'Olive Mitchell', 'OLIVE MITCHELL', 3, 32, NULL, 1, 3, 42, 3379, NULL, 'Bars		Description



1 – 4	1st couple set to each other and cross over passing right shoulder to face out.



5 – 8	1st man and 2nd woman turn right hand one and a half times while 1st woman and 2nd man turn left hand one and a half times.



9 – 16	1st man with 3rd couple and 1st woman with 2nd couple dance left hands across.  1st man with 2nd couple and 1st woman with 3rd couple dance right hands across.



17 – 24	1st couple set to each other.  1st man casts off to finish between the 3rd couple while 1st woman casts up to finish between the 2nd couple.  1st couple turn both hands 1 ¼ times to finish in 2nd place on their own sides.



25 – 32	2nd, 1st and 3rd couples dance six hands round and back.





Repeat having passed a couple.

', 53, '840/888/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16881, '2016-02-25 00:45:55.960531+00', '2020-10-17 20:38:03.629437+00', 'Islesburgh Reel, The', 'ISLESBURGH REEL', 1, 32, NULL, 1, 3, 42, 3379, NULL, 'The Islesburgh Community Centre is the hub of the Shetland Accordion & Fiddle Festival which is held every October







Bars		Description



1 – 8	1st couple set to each other, cross over giving right hands, cast off one place and turn with the left hand to face first corners.  2nd couple step up on bars 5 and 6.



9 – 16	1st couple set to first corners and turn right hand to face second corners.  1st couple set to second corners and turn left hand to finish with 1st man between 2nd couple facing down and 1st woman between 3rd couple facing up.



17 – 24	1st couple change over giving right hands and cast to the right to finish in 2nd place.  1st man dances half a figure of eight up round 2nd couple while 1st woman dances half a figure of eight down round 3rd couple.



25 – 32	2nd, 1st and 3rd couples set twice.  1st couple turn 1 ½ times with the right hand.





Repeat having passed a couple.







Original Tune: “Walking on the Moon” by Addie Harper.

', 38, '800/844/800/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17027, '2016-06-11 21:51:06.736013+00', '2020-10-18 10:18:40.850761+00', 'Flower of Forfar', 'FLOWER OF FORFAR', 2, 32, NULL, 4, 4, NULL, 9998, NULL, 'The dance has a 4-bar intro, 1st 2 bars of the tune plus 2 bars on one note.



The original description is for a 32 bar dance in a square set.  The "Angus SCD Book" page with this description has "4x40 4C Square set" in the title.  The sheet music and Minicrib also specify 32 bars.  We think the "40" is probably a typo, so SCDDB has entered this as a 32 bar dance..  





This dance represents a flower of which the centre is represented by central stars, and the petals by exchanges of dancers between the inner and outer rings. Bowing to the centre represents the closing of the flower in the evening and opening in the morning. The Men moving round one place defines the circumference of the flower.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17054, '2016-06-23 21:32:12.448128+00', '2020-10-18 11:38:36.870764+00', 'Sugar House Wynd', 'SUGAR HOUSE WYND', 2, 32, NULL, 1, 3, 42, 10254, NULL, 'The name of the old street, Sugarhouse Wynd, recalls the 18th Century sugar-refining

business in Dundee. The first manager in the Sugar House was a Mr Wiedemann,

whose daughter Sarah - after moving to London - married a Mr Robert Browning.

Their son was the poet of the same name.', 56, '844/888/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17125, '2016-07-04 15:21:03.981241+00', '2020-10-19 10:00:27.825804+00', 'Dancing in the Kitchen', 'DANCING IN THE KITCHEN', 1, 32, NULL, 2, 3, 17, 10578, NULL, 'A dance designed to be danced in a very limited space.



Dedicated to Brenda George and Sheila Hibbert, who have given me many a cup of tea, and to Sue Woodhall, who was seen dancing in the kitchen as she dried the dishes.', 69, '800/888/882/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20175, '2020-12-07 18:58:02.049601+00', '2020-12-07 18:58:02.049601+00', 'Away We Go to the North', 'AWAY WE GO TO THE NORTH', 3, 32, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20131, '2020-10-10 21:33:47.291204+00', '2020-11-13 10:57:38.229192+00', 'Our Red Zone Strathspey', 'OUR RED ZONE STRATHSPEY', 3, 32, NULL, 1, 2, 76, 10568, '2020-10-01', 'Devised to introduce Red House reels in a "red zone" during the second wave of the pandemic.', 60, '88/88/88/80', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20516, '2021-10-11 22:30:05.097582+00', '2021-10-11 22:30:05.097582+00', 'Wullie McPherson''s Reel', 'WULLIE MACPHERSONS REEL', 1, 32, NULL, 1, 3, 42, 575, '2020-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20111, '2020-10-04 14:45:51.116848+00', '2020-10-04 14:45:51.116848+00', 'Jack''s Dance', 'JACKS DANCE', 4, 80, 10049, 6, 3, NULL, 952, '2010-01-01', 'This dance was original devised as a medley but each part can stand alone and are known as <<ddd:Jack''s Strathspey#19629>> and <<ddd:Jack''s Jig#19630>>. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20112, '2020-10-04 14:53:30.844108+00', '2020-10-04 14:53:30.844108+00', 'Morning Mist', 'MORNING MIST', 3, 40, NULL, 4, 4, 4, 952, '1985-04-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12476, '2005-07-21 22:00:00+00', '2020-10-04 14:55:30.644228+00', 'Mr Smith''s Delight', 'MR SMITHS DELIGHT', 3, 40, 9999, 4, 4, NULL, 952, '2005-01-01', 'Jenifer Kelly writes:    

Notes for teachers on the dances in the Anniversary Suite.   

As I devised these dances I had a particular teaching point in mind for each of them.  



These teaching notes can be found at 

<<http://rscds-sf.org/resources/dances/Anniversay%20Suite%20Notes.pdf>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20113, '2020-10-04 14:59:02.57207+00', '2020-10-04 14:59:02.57207+00', 'Scottish Spirit', 'SCOTTISH SPIRIT', 2, 40, NULL, 5, 113, 4, 952, '2015-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20115, '2020-10-04 15:32:24.78612+00', '2020-10-04 20:45:29.682281+00', 'Summer''s End Suite', 'SUMMERS END SUITE', 4, 0, NULL, NULL, NULL, NULL, 952, NULL, 'A suite of three performance dances:  

August: 40-bar jig for six women  

September: 32-bar strathspey for two sets of three couples  

October (also called Michael Bentley''s Bodhrán):  88-bar reel for six dancers in a wider than usual, longwise set  

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20114, '2020-10-04 15:10:05.893434+00', '2020-10-04 15:25:02.854779+00', 'Thornes Among the Thistles, The', 'THORNES AMONG THE THISTLES', 2, 64, NULL, 4, 4, 1, 952, '1982-01-01', 'For the slsters Kathleen (Kay) and Rosemary Thorne, who danced with The Red Thistle Dancers for many years.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20116, '2020-10-04 15:36:36.177527+00', '2020-10-04 15:36:36.177527+00', 'Unravelling', 'UNRAVELLING', 3, 32, NULL, 1, 2, 76, 952, '2014-01-01', 'Dance for two couples in which one''s partner is ignored. May be danced as a strathspey or a medley.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19126, '2018-12-17 12:19:41.040708+00', '2020-10-04 20:26:42.350118+00', 'Reflections on Woodhall Loch', 'REFLECTIONS ON WOODHALL LOCH', 3, 32, NULL, 1, 130, 2, 11237, '2013-05-01', 'The top two and bottom two couples in the set are dancing reflected patterns (hands across, turns, reels and the Targe) with some minor distortions coming from precedence as dancers cross the “water line” between 2nd and 3rd places. Those coming up from the water (3rd and 4th places) always cross before those dropping down from the air (1st and 2nd places).



Woodhall Loch is in Dumfries and Galloway, Scotland. Its southern shoreline is part of the grounds of Laurieston Hall which is home to a self-sufficient community that also holds residential events for external groups. The London Gay Gordons has held several Scottish Country Dance weeks there. The inspiration for this dance came on one of those events and the title from seeing almost perfect reflections on the loch.', 93, '4884/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15578, '2014-08-26 19:37:01.502789+00', '2020-10-09 13:18:53.173306+00', 'Climbing Mont Ventoux', 'CLIMBING MONT VENTOUX', 4, 64, 5, 1, 4, 1, 10992, '2013-01-01', 'The dance is a collective project by Clan McBédoin, a small SCD group in Provençe. This is based at Bédoin, a village at the foot of Mt. Ventoux, an iconic mountain for cyclists world-wide.  The idea was to celebrate the climbing of Mont Ventoux by the Tour de France (the 100th edition of the world toughest long-distance cycle race) on 14 July 2013.  The original concept for this dance (in Sept 2012) came from Christopher Macrae.  The group''s teacher, Erika Ritzau, worked together with the team and colleagues on a suitable choreography. The first half (strathspey tempo) represents the turning of the bike wheels and gears, as the cyclists are slogging up this awesome climb, with each couple in turn finally getting to the top. The second half (in reel tempo) starts with a brief victory dance by the first couple after they reach the summit, then they whiz down to the bottom, at Bédoin. 



The only videos at present on UTube were recorded at Pitlochry in April 2013.  They shows the medley being danced twice through only, as for demonstration purposes; but it is more satisfactory for the dancers to do it four times through so that each couple can "climb Mt. Ventoux". In November 2013, original music was composed for our signature dance by Alex Ross, leader of an Edinburgh Ceilidh Band. A fresh video has just (on 1 Feb 2015, in Montpellier) been made of the dance set to Alex Ross''s music : we hope it will soon be available on U-Tube. 

', 72, '8888/8888/4444/4444/8000/8888/0808/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20117, '2020-10-04 21:51:56.724582+00', '2020-10-04 21:51:56.724582+00', 'Passing By', 'PASSING BY', 3, 32, NULL, 2, NULL, NULL, 952, '2007-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20118, '2020-10-04 22:46:48.123475+00', '2020-10-04 22:46:48.123475+00', 'Cross Purposes', 'CROSS PURPOSES', 2, 32, NULL, 2, 3, 17, 9998, NULL, 'Source: <<https://youtu.be/b5KRA-RIrig|Red Thistles youtube video>>.', 81, '686/286/882/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8559, '1998-07-08 22:00:00+00', '2020-10-13 19:04:46.266002+00', 'Boundary Cottage', 'BOUNDARY COTTAGE', 3, 32, 9999, 1, 100, 2, 347, NULL, 'Revision to bars 3-4 (September 2019):  These figures are not mirrored:



Bars 1 - 4        1st couple with 2nd couple, 3rd couple with 4th couple, set. 1st man and 2nd woman, giving both hands, turn to finish, 1st man in 2nd man''s place and 2nd woman in 1st woman''s place. 2nd man casts up one place and 1st woman casts off one place. At the same time, 3rd woman and 4th man, giving both hands, turn to finish, 4th man in third place women''s side and 3rd woman in fourth place men''s side, 3rd man casts off to fourth place on women''s side and 4rd woman casts up to third place on men''s side.', 78, '8888/8888/4444/8228', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17073, '2016-06-26 15:09:21.048005+00', '2020-10-19 09:45:15.624309+00', 'Christine''s Diamond Reel', 'CHRISTINES DIAMOND REEL', 1, 32, NULL, 1, 3, 42, 2887, NULL, '', 59, '844/888/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20133, '2020-10-21 19:32:09.665688+00', '2020-10-21 19:32:09.665688+00', 'Winsome Reel, The', 'WINSOME REEL', 4, 64, 5, 4, 51, 54, 10912, '2020-01-01', '', 100, '8/8/8/8', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20119, '2020-10-05 10:48:16.544665+00', '2020-10-05 10:48:16.544665+00', 'Under the Wire', 'UNDER THE WIRE', 1, 40, NULL, 4, 4, 13, 9998, NULL, 'Demonstration dance.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20091, '2020-09-30 15:12:51.893387+00', '2020-10-05 16:36:46.41486+00', 'Hello in July', 'HELLO IN JULY', 3, 32, NULL, 1, 3, 42, 11971, '2020-07-01', 'This dance was meant as a welcome dance after weeks of lockdown due to the coronavirus, involving only figures which require no giving of hands throughout.

Special thanks go to Kirsten Steinbach for suggesting the title, being a play on words with the figure hello-and-goodbye-setting.', 41, '800/888/822/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15064, '2013-08-10 15:36:04.55323+00', '2020-10-05 19:11:42.2928+00', 'Christine Rayner''s Strathspey', 'CHRISTINE RAYNERS STRATHSPEY', 3, 40, NULL, 4, 4, 1, 2980, NULL, '', 75, '6060/0606/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20124, '2020-10-06 13:46:43.583013+00', '2020-10-12 10:15:29.462088+00', 'Young Diamonds', 'YOUNG DIAMONDS', 1, 96, NULL, 4, 4, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2296, '1997-09-02 22:00:00+00', '2020-10-06 14:59:25.382198+00', 'Forth Bridge, The', 'FORTH BRIDGE', 3, 32, 9999, 2, 3, 17, 270, NULL, '', 61, '680/808/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15290, '2013-12-10 13:57:24.552965+00', '2020-10-06 15:46:15.720466+00', 'Five Golden Decades', 'FIVE GOLDEN DECADES', 3, 80, NULL, 3, 5, 3, 10901, NULL, 'The 5 couples represent the 5 decades of Bristol RSCDS. The dance is designed with 5 sections using a

*snowball effect* whereby the number of couples dancing represent the number of decades. In between each decade is a chorus involving all members of the set representing the zero of the decades.', 80, '00800/88888/08080/88888/80808/88888/88088/88888/88888/88888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15334, '2014-02-10 10:16:00.832764+00', '2020-10-08 10:22:02.27946+00', 'Octogenarian Dancer, The', 'OCTOGENARIAN DANCER', 3, 80, NULL, 4, 4, 3, 3477, NULL, 'Added from MiniCrib, to avoid a crib mismatch between this dance and <<ddd:The Octogenarian>> by Norman Churnside.', 60, '8080/8888/0808/0808/0808/8080/8080/8080/0808/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15372, '2014-03-17 23:17:21.777859+00', '2020-10-09 08:13:24.3677+00', 'Riding the Wave', 'RIDING THE WAVE', 3, 32, NULL, 1, 100, 1, 10898, NULL, '', 81, '8888/8800/8484/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20130, '2020-10-09 13:22:39.36081+00', '2020-10-09 14:10:31.768908+00', 'Iain Lindsay''s Farewell to Hungary', 'IAIN LINDSAYS FAREWELL TO HUNGARY', 4, 128, 10050, 1, 4, NULL, 3661, '2020-10-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15591, '2014-08-30 23:10:37.37012+00', '2020-10-10 10:20:35.774367+00', '2 PM', '2 PM', 2, 32, NULL, 1, 4, 1, 10995, '2009-01-01', '*I was shown a dance attributed to George Meikle  for his son’s wedding. I was told the sons name was Peter.  I felt a couple of tweaks would make it even better, and I apologise that the title fails to make the acknowledgement intended…..such is life!!*



', 66, '8040/8080/8888/8088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14949, '2013-06-23 18:37:33.271417+00', '2020-10-10 18:55:58.531667+00', 'Jim the Dancing Janny', 'JIM THE DANCING JANNY', 3, 32, NULL, 2, 3, 17, 3358, NULL, 'Devised for Jim Calder, former janitor at St Ronan''s School. Jim had his arm in a sling at the time so the men do not use their left hands in this dance.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20122, '2020-10-06 13:39:46.098122+00', '2020-10-12 10:11:46.64896+00', 'Bellahouston', 'BELLAHOUSTON', 1, 40, NULL, 1, 4, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20128, '2020-10-06 14:20:55.20909+00', '2020-10-12 10:14:58.843913+00', 'Conor''s Cattle Grid', 'CONORS CATTLE GRID', 4, 128, 22, 1, 4, NULL, 1415, NULL, 'Repeat in strathspey and twice in reel time.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15429, '2014-05-07 22:41:51.482773+00', '2020-10-10 10:14:04.022871+00', 'Radical Road, The', 'RADICAL ROAD', 1, 128, NULL, 4, 4, 3, 518, NULL, '88/88/

1 - 8		All face ptnr - pass R, L, R, L then turn ptnr RH

9 - 16	Repeat back home

/80/08/

17 - 24	In waltz hold top cps slip to opp. end (men BTB), Repeat Ls 		BTB

25 - 32	Side cps Repeat.

/88/88/88/88/88/88/88/88/

33 - 40	Head M in centre While rest Circle, pivot, chase back

41 - 48 	top 4, bottom 4 LHA, RHA

49 - 56	Side M Repeat

57 - 64	Side 4s LHA, RHA

65 - 72	Head Ls repeat

73 - 80	Heads RHA, LHA

81 - 88	Side Ls repeat

89 - 96	Sides RHA, LHA

/80/80/

97 - 112	Repeat 17 - 32

/88/88

113  - 128	Repeat 1 - 16

', 87, '88/88//80/08//88/88/88/88//88/88/88/88/80/08/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20125, '2020-10-06 14:04:20.320427+00', '2020-10-12 10:13:11.150218+00', 'Miss Moneypenny''s Jig', 'MISS MONEYPENNYS JIG', 2, 32, NULL, 1, 3, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20132, '2020-10-17 17:36:24.432952+00', '2020-10-17 17:36:24.432952+00', 'As Good as Ever', 'AS GOOD AS EVER', 1, 32, NULL, 1, 3, NULL, 635, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20126, '2020-10-06 14:04:59.157907+00', '2020-10-12 10:16:04.991715+00', 'Bloomsbury Gold', 'BLOOMSBURY GOLD', 3, 32, NULL, 1, 3, NULL, 11984, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20127, '2020-10-06 14:06:04.894298+00', '2020-10-12 10:16:50.58699+00', 'Trip to St Mathieu, A', 'TRIP TO ST MATHIEU', 1, 32, NULL, 1, 4, NULL, 1415, NULL, 'Alternative title: RECALCULATING', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20129, '2020-10-06 14:21:42.857153+00', '2020-10-12 10:17:20.109805+00', 'Rainbows over Bethlehem', 'RAINBOWS OVER BETHLEHEM', 1, 32, NULL, 1, 3, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20123, '2020-10-06 13:41:57.132912+00', '2020-10-12 10:19:53.420976+00', 'Strathclyde Strathspey, The', 'STRATHCLYDE STRATHSPEY', 3, 32, NULL, 1, 4, NULL, 1415, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15642, '2014-10-01 22:21:28.541297+00', '2020-10-12 16:23:18.127917+00', 'Nickie-Tams', 'NICKIETAMS', 2, 32, 9999, 1, 3, 42, 416, NULL, '', 63, '800/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2475, '1997-09-03 22:00:00+00', '2020-10-13 18:38:26.165429+00', 'Ginzton Frolic, The', 'GINZTON FROLIC', 1, 40, 9999, 2, 104, 18, 952, NULL, '', 90, '888/444/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16215, '2015-04-21 21:57:05.233733+00', '2020-10-15 08:33:10.494511+00', 'Diamond Celebration', 'DIAMOND CELEBRATION', 3, 32, NULL, 1, 4, 11, 2741, NULL, '', 81, '8008/6666/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5391, '1997-08-28 22:00:00+00', '2020-10-22 20:22:30.204374+00', 'Merrie Reel, The', 'MERRIE REEL', 1, 32, 9999, 1, 2, 76, 594, '1994-01-01', '', 52, '80/88/88/80', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20135, '2020-10-23 09:13:45.763755+00', '2020-10-23 09:13:45.763755+00', 'Rennie''s Bridge', 'RENNIES BRIDGE', 2, 32, 9999, 1, 2, 76, 10912, '2020-01-01', '', 60, '80/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19902, '2020-03-23 18:52:39.08262+00', '2020-11-08 07:50:44.80658+00', 'Pandemic Reel, The', 'PANDEMIC REEL', 1, 32, NULL, NULL, 51, 54, 11322, NULL, 'A 32-bar reel for any number of dancers in their own living rooms   



1-8 Dancers cast off behind own couch, dance around the end & back to place.  

9-16 Do-Si-Do around coffee table, then slip step away from the coffee table & back.  

17-24 Dance down the hallway, into the kitchen, grab a beverage* & dance back to place.  

25-32 Set while placing the beverage on the coffee table, turn on the spot twice (using Pas de Basque), then retire to the couch, sit, and enjoy.  



*Wine, beer, whiskey, or other beverage of choice', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20154, '2020-12-07 18:04:54.950501+00', '2020-12-07 18:04:54.950501+00', 'Dance Along, Then', 'DANCE ALONG THEN', 2, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20136, '2020-10-23 15:03:39.904502+00', '2020-10-23 15:17:20.116898+00', 'Dogs in Heaven', 'DOGS IN HEAVEN', 2, 32, NULL, 1, 3, 42, 11967, NULL, 'This dance is dedicated to all dogs and dog lovers, but especially to lovely Trixi and Bingo, who used to find themselves in heaven in this world when they were spoilt with treats and who are now playing together in dog heaven.', 56, '800/888/088/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17326, '2016-09-12 19:59:50.945327+00', '2020-10-26 18:58:12.282499+00', 'Maestra, La', 'MAESTRA', 3, 32, NULL, 1, 4, 1, 23, '2011-05-01', 'Commissioned by Dale Horn as a tribute to Sonja Horn – honoring her leadership of the Thistle Orchestra and finishing with a flourish of windmills to salute Sonja’s homeland, The Netherlands. ', 62, '8000/8444/8888/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20139, '2020-11-04 10:31:18.403413+00', '2020-12-01 17:50:41.853945+00', 'Twisted Yet Again', 'TWISTED YET AGAIN', 2, 32, NULL, 1, 3, 42, 11035, NULL, '', 59, '880/844/866/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14218, '2011-08-26 22:00:00+00', '2020-10-30 20:50:06.709138+00', 'Peterborough Chorister', 'PETERBOROUGH CHORISTER', 3, 32, NULL, 1, 3, 42, 1089, NULL, 'Dedicated to the deviser''s father, the Reverend Canon Eric Walter Scott. 

As a young boy he entered King''s School in Peterborough and sang in the choir twice daily, eventually becoming head chorister, the school itself being associated with Peterborough Cathedral and having officially changed its name in 2011 to The King''s (The Cathedral) School from King''s School, Peterborough.

Thereafter Eric Scott attended Saint John''s College at nearby Cambridge University as a choral scholar.

', 63, '888/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3380, '1997-04-03 22:00:00+00', '2020-10-31 12:46:56.059457+00', 'Juniper Jig', 'JUNIPER JIG', 2, 32, 9999, 1, 3, 42, 13, NULL, '', 63, '800/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17612, '2017-02-16 09:07:59.874594+00', '2020-11-07 10:50:33.912339+00', '70th Anniversary Celebration', '70TH ANNIVERSARY CELEBRATION', 2, 32, NULL, 1, 3, 42, 1582, NULL, '', 56, '800/844/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17656, '2017-03-13 12:51:10.266513+00', '2020-11-07 22:25:05.077675+00', '3 J''s Jig', '3 JS JIG', 2, 32, NULL, 1, 3, 42, 10240, '2015-09-01', 'The 3 Js are June Hewitson, Jill Burrows and Judy Grimsey – Although all born in different decades

they have formed a strong friendship through their love of Scottish Country Dancing and have

spent many happy hours travelling to and from dances together over the years! However I am

happy for everyone who has found friendship through Scottish Country Dancing to think that this is

for them… (especially if their name starts with a J!!!).  Jill Burrows September 2015', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20140, '2020-11-10 17:36:20.534758+00', '2020-11-10 17:36:47.429528+00', 'Fields of Bow, The', 'FIELDS OF BOW', 3, 32, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20205, '2021-01-16 18:53:44.144174+00', '2021-01-23 21:57:05.449744+00', 'Whirlwind, The', 'WHIRLWIND', 1, 64, NULL, 6, 112, NULL, 9998, NULL, 'Triangular set with a seventh dancer in the centre.



The only source is the <<https://youtu.be/PHNM3P8HVR0|youtube video>>.



<<scddb-not-identical:12789;13179;13729;16505>>

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18103, '2017-12-09 18:15:58.583593+00', '2020-11-12 10:35:49.618888+00', 'Placid Pace', 'PLACID PACE', 3, 32, NULL, 4, 4, 13, 11576, '2017-08-01', 'When filmed the dance was still being tweaked hence some of the experimentation occurring. It was written by Laura Wheater in response to Marc''s story about a close encounter of the slow kind with an amazonian sloth. Thus the 3 clawed toes in the air and the slow reel.



Crib is accurate and is correct.', 56, '8080/8080/8080/4848', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18206, '2018-01-13 10:42:00.185023+00', '2020-11-13 12:55:10.497745+00', 'Tizzy of Tadpoles, A', 'TIZZY OF TADPOLES', 1, 32, NULL, 1, 4, 2, 11582, NULL, '"Bills Tadpoles'' played by Jennifer Wilson on ''A Dancing Master Remembered''', 56, '8008/4664/6446/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18209, '2018-01-13 11:42:42.202223+00', '2020-11-14 10:34:15.881681+00', 'Fire Hose Reel', 'FIRE HOSE REEL', 1, 32, NULL, 1, 3, 42, 11583, '2010-06-06', 'Suggested music: Set of reels recorded by Marian Anderson''s Scottish Country Dance Band on "Belfast Branch – diamond Jubilee"



Devised during Queen''s Birthday Weekend School at Ototohanga. At this school, the Saturday evening dance program was put on the wall directly above the fire hose, and the sign "Fire Hose Reel" was positioned as if it was the last dance on the programme. We couldn''t pass by the opportunity of devising a dance – with hoses (the reels of three and the castings) and a circle to represent the hose reel itself.', 56, '888/800/808/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18237, '2018-02-05 23:57:04.005695+00', '2020-11-14 10:41:56.594779+00', 'Rookie''s Jig', 'ROOKIES JIG', 2, 32, NULL, 2, 3, 17, 10805, '2018-02-03', '', 43, '432/432/880/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20137, '2020-11-04 10:12:08.787213+00', '2020-12-01 22:03:56.052953+00', 'Tall Guy''s Strathspey, The', 'TALL GUYS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11035, '2020-01-01', '', 50, '804/808/822/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20176, '2020-12-07 18:58:55.530106+00', '2020-12-07 18:58:55.530106+00', 'Canadian Greeting', 'CANADIAN GREETING', 3, 32, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20138, '2020-11-04 10:23:33.979408+00', '2020-12-28 10:58:46.81816+00', 'Our Key to Florence', 'OUR KEY TO FLORENCE', 3, 32, NULL, 1, 4, 1, 11035, NULL, '', 50, '8800/8440/8008/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20522, '2021-10-12 17:15:49.294975+00', '2021-10-12 17:15:49.294975+00', 'Freedom Reel, The', 'FREEDOM REEL', 1, 32, NULL, 1, 3, 42, 11436, '2020-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20517, '2021-10-11 22:40:00.183609+00', '2021-11-23 09:52:42.028717+00', 'Cardwell Bay', 'CARDWELL BAY', 2, 32, NULL, 1, 3, 42, 12074, '2020-01-01', 'Dance devised by Evelyn Redmond for the Basic Skills class as an introduction to half reels of four with corners.  

Cardwell Bay lies within the larger Gourock Bay in Inverclyde, just south of Greenock, my birthplace and childhood home.', 47, '660/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18289, '2018-04-24 17:51:49.92914+00', '2020-11-14 10:54:44.25083+00', 'Falkirk Wheel, The', 'FALKIRK WHEEL', 3, 64, NULL, 4, 4, 14, 10599, NULL, 'Dance devised by Anne Scobie, Brussels Dance Scottish, and dedicated to Margaret Lambourne, a dear dancing friend, on the occasion of her 70th birthday.  



I first saw the Falkirk Wheel in motion on Margaret''s laptop which gave me the inspiration for this dance. It shows the boats getting into position, the Wheel moving round and the boats changing places.', 72, '8080/8888/0808/8888/6666/8888/0808/8080', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20144, '2020-11-14 11:36:08.29484+00', '2020-11-14 11:36:08.29484+00', 'Dardagny Reel, The', 'DARDAGNY REEL', 1, 32, NULL, 2, 2, 76, 2874, NULL, '', 50, '80/88/88/80', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20145, '2020-11-14 11:42:44.648761+00', '2020-11-14 11:42:44.648761+00', 'Jobelmann Jig, The', 'JOBELMANN JIG', 2, 32, NULL, 1, 3, 42, 2874, '2020-01-01', '', 50, '800/888/888/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18342, '2018-05-21 08:49:22.461034+00', '2020-11-15 12:08:44.663957+00', 'Maypole Dance, The', 'MAYPOLE DANCE', 2, 96, NULL, 4, 4, 3, 2682, '2018-03-27', 'Devised 27 March 2018 for our "midwinter" themed night with the theme of Spring into Autumn, to which club members bring families. Our motif was the Maypole..... Revised 10/4/2018 with the help of the Tuesday group. Recommended music is that used commonly for "Nottingham Lace", that is traditional tune "Hebridean Milking Song" and e.g. "The Cockle Gatherers" or other traditional sets of tunes. Any of the recordings by Ian Muir, Frank Reid or the Lothian Band would be excellent. (If no such recording is available, it could be danced as a jig in which case I would use "The Argyll Square" (or "Bonnie

Ann" if desperate).)  



Teaching Notes: If using the non-alternative version, it is helpful to get the men and ladies to dance their parts of 9-16 separately.', 81, '8888/8888/8888/8888/8888/7777/7777/4444/4444/8080/0808/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18499, '2018-08-13 16:29:40.826504+00', '2020-11-15 12:35:01.209743+00', 'Glens of Antrim, The', 'GLENS OF ANTRIM', 2, 32, NULL, 1, 3, 42, 80, '1992-01-01', 'Inscribed to Ruth and Alex Jappy of Delta, BC in celebration of all the fun and friendship they have brought to SCD over the years.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2110, '2002-04-10 22:00:00+00', '2020-11-15 13:42:56.582144+00', 'Father Connelly''s Jig', 'FATHER CONNELLYS JIG', 2, 64, 9999, 1, 4, 1, 108, '1990-01-01', '(Author''s notes)



NOTE The dance is really two dances each of 32 bars. Bars 9-24 of each dance are similar. 1st couple dance the first part with 2nd and 3rd couples and the second part with 3rd and 4th couples. Either part could be danced separately as a normal  8 X 32 bar dance. The reason for this unusual structure is that the tune contains 64 bars and it was thought that this arrangement would make it less tiring for the dancers than an 8 X 64 bar dance.



In the half right and left on the diagonal it is essential for the dancers to be in the side lines before changing places with the left hand to leave the centre of the set free for the other dancers.', 66, '8800/8880/8880/8880/8000/8088/8088/8088', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (18402, '2018-07-13 10:10:03.281419+00', '2020-11-15 19:03:36.410625+00', 'Knight in Flowing Tartan, The', 'KNIGHT IN FLOWING TARTAN', 3, 48, NULL, 1, 100, 1, 11662, NULL, '"This dance is dedicated to a person known locally as St Anton (actually our dear friend Dr Anton Korobeinikov from St Petersburg, who had never missed an opportunity to make us happier) - and an idea of a diamond poussette for four couples. It was first danced on the floor of the bedroom by the collection of brooches (the usual silent victims!) and then in class by our patient friends (they were too polite to complain). Try it at your own peril, but it feels less complicated and more flowing than it seems."', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20148, '2020-11-16 09:27:20.746131+00', '2020-11-19 19:02:22.630365+00', 'Gold in the West', 'GOLD IN THE WEST', 1, 32, NULL, 1, 3, 42, 884, '2019-05-01', 'For Rena Gold, to celebrate a significant birthday.', 44, '800/822/822/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18636, '2018-09-18 20:59:20.884248+00', '2020-11-19 19:22:06.502999+00', 'Jo''s Garden', 'JOS GARDEN', 4, 64, 5, 1, 4, 1, 11710, '2014-07-01', 'As the strathspey and reel sections differ slightly, this dance has been classified as a 4x64 Medley rather than as a 8 x 32 alternating strathspey/reel.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2789, '2002-03-03 23:00:00+00', '2021-05-31 10:17:22.828693+00', 'Harbour City, The', 'HARBOUR CITY', 1, 40, 9999, 1, 4, 1, 349, NULL, '"Wellington, our Capital City, is situated on a beautiful harbour."', 70, '8080/8080/8888/8080/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18285, '2018-04-21 21:30:35.223852+00', '2022-10-01 18:29:07.214407+00', 'Terry is Tea-rrific', 'TERRY IS TEARRIFIC', 2, 32, NULL, 1, 4, 2, 10582, '2017-01-01', '"Terry is Tea-rrific" was written as a tribute to Terry McBurnie, his Mom-in-law who attends the class in Fish Hoek and makes the tea for all dancers during the break in the class.', 59, '8008/8228/8448/8008', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20142, '2020-11-14 11:27:08.11706+00', '2022-11-02 12:59:54.958059+00', 'Airbus Jig, The', 'AIRBUS JIG', 2, 32, NULL, 1, 3, 42, 2874, '2020-01-01', '', 44, '800/880/880/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20141, '2020-11-14 11:16:11.649961+00', '2022-12-12 09:19:02.955656+00', '1st February', '1ST FEBRUARY', 2, 32, NULL, 1, 2, 76, 3342, '2009-10-01', 'May be danced as jig or reel.', 60, '88/88/80/88 ', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14598, '2012-11-07 10:37:41.02952+00', '2020-11-20 00:35:38.730763+00', 'George''s Strathspey', 'GEORGES STRATHSPEY', 3, 40, NULL, 1, 100, 2, 3325, '2012-04-20', 'Devised to mark the 80th birthday of George Bateson on 20th April 2012. George along with his brothers founded the Berkhamsted Strathspey & Reel Club and with his wife Alison has steered the club on a steady course for sixty years.  (This dance was first danced as a demonstration by club members for George on 24th April after the club AGM in 2012).', 90, '8448/8888/8888/8888/4884', 1, 1, 1, 1, 90);
INSERT INTO 'dance' VALUES (19202, '2019-02-25 17:23:12.926298+00', '2020-11-23 10:37:19.80282+00', 'Jig for Joan, A', 'JIG FOR JOAN', 2, 40, NULL, 3, 5, 7, 11721, '2017-01-01', 'Devised in honour of Joan Davidson, who founded the St Cyrus class and taught it for 25 years.', 60, '80800/84884/80800/80800/88888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19238, '2019-03-10 01:19:29.016295+00', '2020-11-25 09:58:47.864401+00', 'Fran MacCulloch', 'FRAN MACCULLOCH', 3, 32, NULL, 1, 4, 2, 101, '1985-01-01', 'Devised by John Bowie Dickson while he was in Montréal, to honour Fran MacCullough who was a founding member of the RSCDS Montréal Branch.

 

', 84, '2882/8888/8888/4884', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20155, '2020-12-07 18:07:06.364376+00', '2020-12-07 18:07:06.364376+00', 'Down the Clyde to Tighnabruaich', 'DOWN THE CLYDE TO TIGHNABRUAICH', 2, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20177, '2020-12-07 18:59:59.024257+00', '2020-12-07 18:59:59.024257+00', 'On the Spur of the Moment', 'ON THE SPUR OF THE MOMENT', 3, 32, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20143, '2020-11-14 11:31:55.62698+00', '2021-10-26 14:37:18.881825+00', 'Arlette''s Fancy', 'ARLETTES FANCY', 2, 32, NULL, 2, 3, 17, 3342, '2014-10-01', 'May be danced as jig or reel.', 38, '800/880/800/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2415, '1998-09-29 22:00:00+00', '2020-12-06 18:24:31.828218+00', 'Gates of Edinburgh, The', 'GATES OF EDINBURGH', 1, 32, 9999, 1, 3, 42, 453, '1750-01-01', 'There are various opinions concerning the name of this dance. One

school of thought claims that the »gates« are the gates of the town

which are opened in the morning and closed at night – hence the giving

of hands in the reels of three. This sounds very plausible if one

disregards the fact that the city of Edinburgh was never fortified and

thus did not actually feature such gates.



The other school of thought notes that the word »gate«, in Scots, does

not actually mean »gate« as in »big door«, but »street« (from the

Scandinavian *gatan*) – as evidenced by well-known Edinburgh street

names such as Cowgate or Canongate. A »gate«, the big door, would be a

»port«, as in in the song about John Graham of Claverhouse,

a.k.a. »Bonnie Dundee«:



> Come fill up my cup, come fill up my can,  

> Saddle my horses and call out my men,  

> And it''s Ho! for the west _port_ and let us gae free,  

> And we''ll follow the bonnets o'' Bonnie Dundee!



So according to this theory the »gates of Edinburgh« are really the

»streets of Edinburgh«.

', 75, '888  888  888  888', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (16, '1997-08-28 22:00:00+00', '2020-12-07 13:00:35.509918+00', 'Absence of Forethought', 'ABSENCE OF FORETHOUGHT', 2, 24, 9999, 5, 2, NULL, 401, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10412, '2002-03-24 23:00:00+00', '2020-12-07 13:03:09.632632+00', 'Emily''s Reel', 'EMILYS REEL', 1, 32, 9999, 1, 3, 42, 2711, '1995-01-01', '', 59, '822/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10407, '2002-03-24 23:00:00+00', '2020-12-07 13:04:39.808108+00', 'Andrew''s Excel Reel', 'ANDREWS EXCEL REEL', 1, 32, 9999, 1, 2, 76, 1268, NULL, 'The Excel Development Corporation of Minneapolis, headed by Andrew Berton, produces board games. This dance was intended to have the feel of four players on a board. Published in 1995 by the RSCDS Twin Cities Branch in 20 Years 20 Dances.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17872, '2017-06-23 09:20:27.828855+00', '2020-11-28 00:23:02.53049+00', 'Irish Washer, The', 'IRISH WASHER', 4, 32, 10040, 1, 4, 11, 10907, NULL, 'The front load washer in our Dublin ''digs'' was a godsend after nine days on the road. Christine

knew how to drive a ''front loader'', however, this washer was not a Melbourne washer, it was

Christine''s nemesis!', 81, '8888/6226/6666/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20010, '2020-06-12 20:28:30.428797+00', '2020-11-28 11:12:26.004866+00', 'Gateway to Northland', 'GATEWAY TO NORTHLAND', 3, 32, 9999, 1, 4, 1, 12005, '2020-01-01', 'Posted on Facebook SCD Teachers by Elaine Goldthorpe, 9 June 2020 as a medley but changed  later.', 44, '844/808/880/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6173, '2002-11-26 23:00:00+00', '2020-12-03 10:25:33.654516+00', 'So on the Ocean', 'SO ON THE OCEAN', 2, 32, 9999, 2, 3, 17, 425, NULL, 'For Jessica Beveridge on her departure to Australia, November, 1994. *The quotation from which the name of the dance was derived is by Henry Wadsworth Longfellow*.', 85, '808/846/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20150, '2020-12-04 11:10:25.51242+00', '2020-12-04 11:12:17.455071+00', 'Cyprus Delight', 'CYPRUS DELIGHT', 1, 32, NULL, 3, 5, 41, 12007, NULL, '', 60, '80008/88888/80008/82428', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10690, '2002-07-21 22:00:00+00', '2020-12-05 00:07:51.279365+00', 'Braes of Cuillin', 'BRAES OF CUILLIN', 2, 32, 9999, 1, 3, 42, 2961, NULL, 'Note: 2nd and 3rd couple will have to stay alert for the reels. The beginning figure gives them time to think about how they are going to start. ', 50, '800/888/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2250, '2001-09-13 22:00:00+00', '2020-12-06 11:18:03.538441+00', 'Flowers of Edinburgh', 'FLOWERS OF EDINBURGH', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'In the old days the city of Edinburgh was less famous for its greenery

than for the smoke and bad stench pervading the Old Town, which gave

rise to its nickname, »Auld Reekie« (Old Smoky). The tenements of the

Old Town did not feature the indoor sewage disposal technology that we

are accustomed to today, and it was by no means uncommon for the good

citizens of Edinburgh to greet the early morning by emptying the

content of their chamber pots out of a 5th-story window with the

cheery cry of »Gardyloo« (from the French *gardez, l''eau*, or »Watch

out, some water«) to warn hapless passers-by. Hence, one

interpretation of the title of this dance views it as a kind of

super-euphemism for these »blooms« of crudity and tastelessness. More

delicate and tender sources prefer to relate the title to the young

ladies of the city.

', 31, '800  800  800  880', 1, 1, 1, 1, 41);
INSERT INTO 'dance' VALUES (2302, '1999-10-27 22:00:00+00', '2020-12-06 11:25:55.730963+00', 'Foula Reel, The', 'FOULA REEL', 2, 48, 9999, 1, 4, 1, 9998, NULL, 'This dance comes from Shetland.



The combined edition of RSCDS Books 1-6 notes that »The number of bars in this dance is flexible. It has also been published as a 40 bar [sic] dance«.', 66, '8000/8220/8002/8888/8888/8888', 1, 1, 1, 1, 48);
INSERT INTO 'dance' VALUES (2321, '1998-11-14 23:00:00+00', '2020-12-06 11:31:51.053642+00', 'Foxhill Court', 'FOXHILL COURT', 3, 32, 9999, 1, 3, 42, 108, '1976-01-01', 'John Drewry dedicated this dance to <<http://my.strathspey.org/dd/person/860/|Audrey Hinchcliffe>> of Foxhill Court, Leeds.



The tune to the dance, "Miss Audrey Hinchcliffe''s Strathspey" by Jimmy Shand is obviously dedicated to the same person.



(In John Drewry''s original description in his Canadian Book, the family name is missing the 2nd "c".)', 62, '880/12 12 12/444/844', 0, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (12131, '2005-04-10 22:00:00+00', '2021-01-24 05:20:11.216466+00', 'Allingham Strathspey, The', 'ALLINGHAM STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2525, '2001-12-21', 'Devised for Doug and Jan Allingham  

long time members of the Tayside Scottish Country Dance Social Group', 44, '888/840/804/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16869, '2016-02-11 21:55:52.440233+00', '2020-12-07 13:07:07.540534+00', 'Lost 40, The', 'LOST 40', 2, 40, NULL, 1, 3, 42, 10811, '2015-04-01', 'Devised by Janet McKernan in 2015 for the 40th Anniversary of the RSCDS Twin Cities (Minnesota) Branch  



Today, less than two percent of Minnesota’s forested land contains virgin or “old growth” timber. Fortunately, there still exists an area in Northern Minnesota that was never touched by the loggers or 

developers of the late 1800s. This property is called the "Lost 40" and it is home to one of the last

stands of virgin, "old-growth" Red and White Pine in Minnesota. Some of these trees are well over 300 

hundred years old.  



In 1882, a land surveyor by the name of Josiah A. King, and his three-man crew surveyed a six square mile area between Moose and Coddington Lakes in what is now the Chippewa National Forest but they ended up plotting Coddington Lake about a half mile further northwest than it was actually located. Josiah’s crew’s error is Minnesota’s great fortune. As a result, these towering pines were mapped as a body of water, and the virgin pine in this area was overlooked by the hungry logging companies. It is now protected by the State of Minnesota.', 56, '800/822/877/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20152, '2020-12-07 18:02:24.846525+00', '2020-12-07 18:02:24.846525+00', 'Be quick About It', 'BE QUICK ABOUT IT', 2, 32, NULL, 2, 3, 18, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20151, '2020-12-07 17:48:16.316863+00', '2020-12-07 18:00:30.715464+00', 'Market Day', 'MARKET DAY', 2, 32, NULL, 1, 2, 76, 10971, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20160, '2020-12-07 18:12:29.144878+00', '2020-12-07 18:12:29.144878+00', 'Single Malt', 'SINGLE MALT', 2, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20149, '2020-11-26 18:33:16.495042+00', '2021-11-11 19:04:21.625072+00', 'Amelia Frances Charlotte Wood', 'AMELIA FRANCES CHARLOTTE WOOD', 2, 32, NULL, 2, 3, 17, 10568, '2020-09-01', 'Written to celebrate Katie and Alistair’s new baby.



The figures in 1-8 and 17-24 are a variation on the <<ddd:Seann Triubhas Willichan#5982>> variation that Dale and Polly Birdsall devised and put into the dance <<ddd:One More Time#20062>>.



Originally intended as a strathspey but later changed to a jig.', 67, '880/880/808/808', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3323, '1998-11-14 23:00:00+00', '2020-12-07 21:50:28.246975+00', 'John McAlpin', 'JOHN MACALPIN', 3, 32, 9999, 1, 3, 42, 129, NULL, 'According to *The Thistle* <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-028-May-1966.pdf|no. 28 (May 1966)>>:



> The ideas in this dance came from fencing. But it is not a “fencing lilt”. The origin is only of historical

> interest and does not affect the manner of dancing.

>

> Bars 1–4 represent a one-two, where a fencer feints on one side of his opponent''s blade and

> disengages to make the real attack on the other side. Bars 5–8 represent one-two-deceive

> (get a fencer to explain this). When one fencer retires his opponent usually advances. This inspired

> bars 17–24. Sometimes fencers rush up so close to each other that they have to be separated by the

> referee. This is known as a corps-à-corps. Hence bars 25–32.

>

> The tune was chosen first. Then the fencing ideas were poured into the mould.', 51, '800  822  777  888', 1, 1, 1, 0, 67);
INSERT INTO 'dance' VALUES (19619, '2019-09-03 21:26:25.979201+00', '2020-12-07 23:33:59.70481+00', 'Delta Borderers'' 25th, The', 'DELTA BORDERERS 25TH', 3, 32, NULL, 2, 3, 17, 3536, '2003-01-01', 'Devised by Ruth Jappy, Vancouver, for The Delta Borderers’ Spring Fling on March 15, 2003 –

celebrating 25 years of happy dancing.', 79, '880/822/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20183, '2020-12-08 00:35:31.95685+00', '2020-12-08 00:35:31.95685+00', 'Far from Home', 'FAR FROM HOME', 1, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20184, '2020-12-08 00:36:28.577804+00', '2020-12-08 00:36:28.577804+00', 'Parisian Holiday', 'PARISIAN HOLIDAY', 1, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20185, '2020-12-08 00:38:27.274323+00', '2020-12-08 00:38:27.274323+00', 'Moonlight on the Water', 'MOONLIGHT ON THE WATER', 1, 48, NULL, 2, 3, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20186, '2020-12-08 00:39:12.040828+00', '2020-12-08 00:39:12.040828+00', 'Comfortable Reel, A', 'COMFORTABLE REEL', 1, 32, NULL, 4, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20187, '2020-12-08 00:39:56.931578+00', '2020-12-08 00:39:56.931578+00', 'Going Nowhere', 'GOING NOWHERE', 1, 32, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20189, '2020-12-08 00:41:13.821285+00', '2020-12-08 00:41:13.821285+00', 'Wind Abeam, The', 'WIND ABEAM', 1, 40, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20190, '2020-12-08 00:41:59.124377+00', '2020-12-08 00:41:59.124377+00', 'Castle Kilbride', 'CASTLE KILBRIDE', 1, 40, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20191, '2020-12-08 00:42:46.381441+00', '2020-12-08 00:42:46.381441+00', 'Sunshine and Snow', 'SUNSHINE AND SNOW', 1, 40, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20192, '2020-12-08 00:43:41.550999+00', '2020-12-08 00:43:41.550999+00', 'Lacing the Ghillies', 'LACING THE GHILLIES', 1, 40, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20193, '2020-12-08 00:45:02.018526+00', '2020-12-08 00:45:02.018526+00', 'Who Goes There?', 'WHO GOES THERE', 1, 96, NULL, 4, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20194, '2020-12-08 01:23:28.554512+00', '2020-12-08 01:23:28.554512+00', 'Summer''s End', 'SUMMERS END', 3, 32, NULL, 1, 3, 42, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20195, '2020-12-08 01:26:04.337053+00', '2020-12-08 01:26:04.337053+00', 'Getting Things Sorted', 'GETTING THINGS SORTED', 3, 40, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20188, '2020-12-08 00:40:34.627764+00', '2020-12-08 01:35:37.370074+00', 'No Surprises', 'NO SURPRISES', 1, 32, NULL, 1, 4, NULL, 10971, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4935, '1998-09-29 22:00:00+00', '2020-12-14 09:33:58.010094+00', 'New Waterloo Reel, The', 'NEW WATERLOO REEL', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'Book 26 credits this dance to the *New Lanark Collection* of Robert Owen. New Lanark was a cotton-processing “model village” on the river Clyde south-east of Glasgow which was essentially owned by Owen, who was a social reformer as well as an entrepreneur and believed in keeping his workers entertained in a wholesome fashion, which apparently included dancing. There is no evidence that Owen himself wrote the dance; he probably underwrote the publication of the dance book.



However, the Combined RSCDS *SCD Books 25-30* state: The source previously given for this dance is *The Collection of Robert Owen* but we have not been able to verify this.', 55, '880  824  888  880', 0, 1, 0, 0, 72);
INSERT INTO 'dance' VALUES (20153, '2020-12-07 18:03:49.774209+00', '2020-12-09 00:55:03.108652+00', 'Chipmunks on the Deck', 'CHIPMUNKS ON THE DECK', 2, 32, NULL, 1, 3, 42, 10971, NULL, '', 61, '840/888/888/684', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4483, '1997-04-03 22:00:00+00', '2020-12-13 11:53:46.593126+00', 'Miss Gibson''s Reel', 'MISS GIBSONS REEL', 3, 32, 9999, 1, 3, 42, 200, NULL, 'Notes and suggestions on the choreography by the e-crib team member who analysed this dance:  On [7-8] 1c turns »above 1st place«; in a crowded hall it may help if also 2c steps down on [5-6].  The transition on [17] is awkward, 1c finish [16] in the middle facing W side, and 1M has to double back towards M side. 1M could instead dance a bit ahead of 1W, and 1c make a fast RH turn to enter the reels.  Possible variations to the dance are for 1M to give Lsh to 2M (i.e. mirror reels); or for 1c to give Rsh to 2cnr position, and turn RH on [21-24].', 56, '844  844  844  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (4728, '1998-09-29 22:00:00+00', '2020-12-13 12:59:41.441231+00', 'Mr Wilson''s Hornpipe', 'MR WILSONS HORNPIPE', 1, 32, 9999, 1, 3, 42, 432, '1816-01-01', 'The Society dance can be traced back to Thomas Wilson'' *A Companion to the Ballroom*, London, 1816. Here it is published as *Mrs Wilson''s Hornpipe*.', 44, '808  840  822  844', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (20196, '2020-12-08 11:44:10.731315+00', '2021-03-05 09:40:08.567613+00', 'Hailin'' Harris', 'HAILIN HARRIS', 2, 32, NULL, 1, 3, 42, 10959, '2019-09-01', 'Devised for the Tarbert, Isle of Harris dancers, who meet at the Harris Hotel on Wednesday nights. Title

suggested after a particularly heavy hail storm.', 53, '800/888/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8693, '1998-03-31 22:00:00+00', '2021-01-07 18:18:36.416463+00', 'Niagara Gorge', 'NIAGARA GORGE', 3, 40, 9999, 2, 3, 17, 2115, NULL, 'To celebrate the 40th annual weekend of the Hamilton (Ontario) branch of the RSCDS.



For many years Hamilton branch has held its annual weekend at Niagara Falls (Ontario). On the 40th annual weekend Bill Zobel devised and taught a dance which had Horseshoe Falls as its theme. To continue the theme this dance was devised to depict the spectacular Niagara Gorge. Forty bars were chosen in honour of the 40th weekend.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4032, '2001-09-13 22:00:00+00', '2020-12-10 00:00:19.648128+00', 'Machine without Horses, The', 'MACHINE WITHOUT HORSES', 2, 32, 9999, 1, 3, 42, 453, '1772-01-01', '##>>

In his book, *Scotland through her country dances*, George Emmerson argues that the 1772 date of the dance and tune is well before the invention of any ‘horseless carriage’ and concludes that the dance title refers to a sedan chair. While the argument seems sound, it should also be noted that the first steam engines date from around 1700. 

##<<



Walter Ligon has pointed out the following pertinent excerpt for 19 October 1769 from *The Life of Samuel Johnson* by James Boswell:



There was a pretty large circle this evening. Dr. Johnson was in very good humour, lively, and ready to talk upon all subjects. Mr. Fergusson, the self-taught philosopher, told him of a new invented machine which went without horses: a man who sat in it turned a handle, which worked a spring that drove it forward. "Then, Sir, (said Johnson,) what is gained is, the man has his choice whether he will move himself alone, or himself and the machine too."', 44, '804/840/880/880', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (5818, '1997-09-13 22:00:00+00', '2020-12-14 17:37:59.28454+00', 'Saint Columba''s Reel', 'SAINT COLUMBAS REEL', 3, 32, 9999, 2, 3, 18, 101, NULL, 'The dance is dedicated to the Lakeshore Group, Montreal', 67, '800/844/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6197, '1998-07-08 22:00:00+00', '2020-12-17 22:36:18.568967+00', 'Song of the Waves, The', 'SONG OF THE WAVES', 3, 32, 9999, 8, 105, 62, 313, NULL, 'Because of the unusual progression, all are back in original places after three turns of the dance; couples never move between odd- and even-numbered places.', 79, '800008  888888  848848  888888', 0, 1, 0, 0, 79);
INSERT INTO 'dance' VALUES (12479, '2005-07-24 22:00:00+00', '2020-12-16 01:25:03.794417+00', 'Buckeye''s Reel', 'BUCKEYES REEL', 1, 32, 9999, 1, 3, 42, 2766, '2005-01-01', 'Bryan Luce introduced me as briefer at a dance by saying I had written a dance for him, his wedding, his dog, his wife’s cat, but not his guinea pig, Buckeye. So, I wrote this dance to fill that void. Also, I hail from Ohio, the Buckeye State.', 58, '820/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20181, '2020-12-07 23:08:00.539788+00', '2021-02-28 19:38:24.283039+00', 'Ruth Jappy''s Return to Glen Ravine', 'RUTH JAPPYS RETURN TO GLEN RAVINE', 2, 32, NULL, 1, 3, 42, 709, '1968-01-01', '', 44, '660/660/840/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8094, '2001-11-20 23:00:00+00', '2020-12-19 11:22:55.662639+00', 'Gloomy Winter, The', 'GLOOMY WINTER', 3, 32, 9999, 1, 3, 42, 550, '1996-01-01', 'Comment from the deviser Ian Brockbank in the The Badger Sett, and in similar form in the earlier New Scottland 50th Anniversary Book:

<BR>This dance was written for Sophia Marriage and presented to her on the occasion of her 25th birthday. It was published in the New Scotland 50th Anniversary Book.





Some useful information from a discussion on the Strathspey list in July 2017:

<BR>The dance starts with 1st lady followed by her partner to cast off, finishing in 2nd place on partner''s side, followed by a one and three quarters turn giving left hands.

<BR>Robb Quint asked whether the transition should be danced by the lady (a) dancing into the sidelines pulling back right shoulder to face partner or (b) pulling back left shoulder to face in and down to start the left hand turn.

<BR>Angus Henry answered that he had checked this with Ian Brockbank in 1997 when the dance was published, and Ian confirmed that the woman was intended to pull right shoulder back.





Please note, there exists a variation on this dance, named “<<ddd:Gloomy Winter''s Noo Awa''#11707>>”. Ian Brockbank came up with this modification, because (according to his statement) bars 9-16 didn’t really work when tried with New Scotland and Dunedin – they require too much careful phrasing. However, the dancers from San Gabriel Valley like the original. (For more information on the modified version see the extra information there.)

', 44, '800  844  844  844', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (8630, '2001-11-27 23:00:00+00', '2020-12-19 14:59:18.096373+00', 'Fermat''s Bicycle', 'FERMATS BICYCLE', 3, 40, 9999, 1, 4, 13, 2031, NULL, 'This dance was devised for the Erlanger SCD group by Alice Silverberg and Karl Rubin in August of 1994. They had been working here for a term as mathematicians at the university. Over 350 years ago, Pierre de Fermat (1601-1665) stated a mathematics conjecture, which became known as Fermat''s Last Theorem. Andrew Wiles (whose first PhD student was Karl) announced a proof of the conjecture in June of 1993. The dance was written in honor of Wiles'' announcement of a proof of Fermat''s Last Theorem. The bicycle motif that occurs in the dance (note the wheels and spokes) commemorates the fact that Erlangen is a very bicycle-friendly town. ', 72, '8686  0808  8888  4884  6262', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (20197, '2020-12-20 22:55:10.41011+00', '2020-12-20 22:55:10.41011+00', 'Virtual Happiness', 'VIRTUAL HAPPINESS', 3, 32, NULL, 2, 3, 18, 10568, '2020-12-01', 'This dance is written to thank all the scd dance groups, musicians, tech wizards and teachers who are putting a great deal of time and effort into keeping Scottish Country dancing alive and well during this pandemic.  From the RSCDS weekly Wednesday classes to the smallest online groups (like mine), we are keeping dancers connected and, hopefully, in shape until we can return to normal.

', 92, '844/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9648, '2002-02-26 23:00:00+00', '2020-12-21 12:16:57.26561+00', 'Spinning Your Wheels', 'SPINNING YOUR WHEELS', 1, 32, 9999, 1, 4, 2, 2802, NULL, 'One description advises both tune "The Ashludie Rant" (a Jig) and a recording "Let''s Have a Ceilidh" (a Reel), so it is not clear if this dance is a Jig or a Reel.  We are looking for the original description.', 94, '8888  8888  8888  4884', 0, 1, 0, 0, 93);
INSERT INTO 'dance' VALUES (9829, '2001-10-21 22:00:00+00', '2020-12-21 16:38:03.815021+00', 'Knottah (''nother dance)', 'KNOTTAH NOTHER DANCE', 1, 40, 9999, 1, 4, 2, 2605, '2001-01-01', 'Published on Strathspey 29 April 2001 by Norman Dahl at the deviser''s request. »we think that the »Linked double half figure of 8« may be a new formation«.', 82, '8888  8888  8228  8008  8888', 0, 1, 0, 0, 82);
INSERT INTO 'dance' VALUES (16850, '2016-01-18 15:55:34.264882+00', '2020-12-28 11:33:28.138023+00', 'M&M''s Jig', 'MANDMS JIG', 2, 32, 9999, 1, 3, 42, 11035, '2011-11-01', 'This dance was devised in early November 2011 after a trip to Auckland to celebrate our 34th wedding anniversary. It coincided with a dance at the Auckland Town Hall where we enjoyed the wonderful music of Marian Anderson and Max Ketchin along with 280 other dancers. The title of this dance, of course, is in honour of Marian & Max!', 50, '884/884/800/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16512, '2015-07-26 10:15:27.680837+00', '2021-01-04 04:11:54.316587+00', 'I Wonder Why', 'I WONDER WHY', 1, 32, NULL, 1, 3, 42, 3355, NULL, 'Devised for Jan Sohnray  



When Jan joined the Zurich Scottish Country Dance Club, he had problems with learning the step pas de basque and was frustrated. One evening, when he came to class, I told him I had devised a simple dance especially for him. There are 16 pas de basque steps in the dance and Jan said, "I wonder why". Hence, the title.', 50, '800/880/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20291, '2021-03-31 21:05:38.018418+00', '2021-03-31 21:28:59.875106+00', 'Hazel''s Highland Laddie', 'HAZELS HIGHLAND LADDIE', 1, 136, NULL, 4, 5, NULL, 12031, NULL, 'Demonstration dance for eight women and two men. Source <<https://youtu.be/dNnuRrZR5vc|youtube video>>.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7265, '2000-04-25 22:00:00+00', '2020-12-22 23:20:50.993099+00', 'Ysobel', 'YSOBEL', 3, 32, 9999, 1, 3, 42, 108, '1973-01-01', 'John Drewry added this note when publishing »Ysobel«: »This dance, devised in 1973, was used by the Publications Committee in that year as the basis for the reel <<ddd:Mrs Stewart of Fasnacloich>> – a dance which has always disappointed me – I do not like left shoulder reels of four and I think that setting should come at the beginning of a phrase rather than at the end. My feeling, for a long time, has been that Mrs. Stewart was never the same woman again after she was interfered with by the committee! I am publishing the dance in its original form in the hope that dancers will enjoy it this way.«', 62, '880  888  844  888', 0, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (10697, '2002-07-21 22:00:00+00', '2020-12-24 03:41:30.560617+00', 'Kittens in the Hoose', 'KITTENS IN THE HOOSE', 1, 32, 9999, 1, 3, 42, 2961, NULL, 'This dance was inspired by the many lively foster kittens running through my house. ', 44, '800/888/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10534, '2002-05-01 22:00:00+00', '2020-12-24 10:11:51.197694+00', 'Turbulence', 'TURBULENCE', 3, 40, 9999, 3, 5, 7, 74, '1996-01-01', 'The movement "Corner pass and turn" is by John Drewry, and described in the Notes in The

Bankhead Book Part 3. The dancing couple pass the corners they are facing who dance

towards the centre. The corners turn right hand on bar 2 and dance back to place on bars 3

and 4 as the dancing couple pass the corners, again by the right shoulder, to the centre of the

dance.  



The Tourbillon progression is by Barry Priddey and appears in <<ddd:Sands of Morar#5885>>, Book 45.  



"The Eddy" is a movement devised by Mary-Jane Lawrie for her dance "<<ddd:The Selwyn

Strathspey>>". As originally devised it was for three couples and has been adapted for five

couples in this dance.', 88, '88880  88888  88888  84848  80888', 0, 1, 0, 0, 88);
INSERT INTO 'dance' VALUES (14, '1997-04-03 22:00:00+00', '2020-12-27 12:31:58.776304+00', 'Abernethy Jig, The', 'ABERNETHY JIG', 2, 32, 9999, 1, 3, 42, 417, NULL, 'See <<ddd:Abernethy Lassies>> for background information on Abernethy.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10704, '2002-07-21 22:00:00+00', '2020-12-24 22:17:32.129215+00', 'Rivers End', 'RIVERS END', 3, 32, 9999, 1, 3, 42, 2961, NULL, 'The dance was written for the end of the semester of the newly-formed Ben Lomond Class, held near the San Lorenw River.', 41, '800/880/884/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10715, '2002-07-21 22:00:00+00', '2020-12-25 06:22:45.341666+00', 'Yvette''s Reel', 'YVETTES REEL', 1, 32, 9999, 1, 3, 42, 2961, NULL, 'Yvette''s real name is Laura Wilson. I had three Lauras in my class at one point and needed to make a distinction between them. Yvette was the nickname chosen, much to Laura Wilson''s amusement. ', 38, '880/800/800/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10714, '2002-07-21 22:00:00+00', '2020-12-26 03:37:18.483605+00', 'Yo-Yo Tweedly', 'YOYO TWEEDLY', 1, 32, 9999, 1, 3, 42, 2961, NULL, 'Mr. Tweedly, once a member of the San Francisco Branch, often returns to the Bay Area and then back again to his home in Scotland. He was complaining about the commute and commented that he felt like a yo-yo. See if you can spot the yo-yo figure in this dance.', 44, '800/844/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9227, '2000-01-16 23:00:00+00', '2021-04-05 21:37:45.638555+00', 'Cabot Trail, The', 'CABOT TRAIL', 3, 32, 9999, 1, 4, 14, 108, '1997-01-01', 'The Cabot Trail is a famous tourist route along the north shore of Cape Breton Island in Nova Scotia. John Cabot (Giovanni Caboto, 1450-1498) was born in Genoa but settled as a merchant in Bristol. He set out from Bristol in the “Matthew” in 1497 (500 years ago) and, after sailing 52 days, landed on Cape Breton Island.', 100, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6439, '1997-04-03 22:00:00+00', '2020-12-25 22:41:06.245447+00', 'Take It Or Leave It', 'TAKE IT OR LEAVE IT', 3, 80, 9999, 4, 4, 3, 99, NULL, '', 78, '8888/8888/8080/8080/8888/8888/0808/0808/0888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13751, '2011-07-11 22:00:00+00', '2020-12-26 09:56:17.506964+00', 'Green Street', 'GREEN STREET', 3, 40, NULL, 2, 3, 17, 2973, '2008-05-01', 'Presented to the RSCDS New Haven Branch Challenge Class at the Green Street Arts Centre, Middletown, Connecticut, May 2008.



Music:  A very suitable recording is the Flodigarry Strathspey, on Dancing Fingers 3, by Muriel Johnstone.', 60, '800  866  844  866  800', 0, 1, 0, 0, 60);
INSERT INTO 'dance' VALUES (11565, '2003-11-01 23:00:00+00', '2020-12-26 02:20:43.451723+00', 'Railwayman, The', 'RAILWAYMAN', 2, 32, 9999, 1, 3, 42, 1445, NULL, 'This dance was written for our dancing friends Jim and Aline Cook from Richmond (UK), who are both fond of trains (steam or otherwise), but Jim is by far the fondest.

', 53, '844  888  822  844', 0, 1, 0, 0, 70);
INSERT INTO 'dance' VALUES (14549, '2012-09-02 16:19:43.153573+00', '2020-12-26 10:31:37.722484+00', 'Grand March and Trip to Cabramurra', 'GRAND MARCH AND TRIP TO CABRAMURRA', 1, 32, NULL, 1, 4, 1, 9998, '1991-01-01', 'The sole source for this dance is a Ball programme found on a website in Cabramurra, NSW, Australia, on 30 May 1992.  The programme included many other, more common, dances.  No information on the background of the programme or on the devisers was given, though it is told that the “Trip to Cabramurra” was a once-only get-together of some local SCD groups. 



Grand March and Trip to Cabramurra         4C Reel, 832	



1-	1C turn RH and cast off one place (2C moving up); 1C turn LH and cast up (2C moving down)



9-	1C+2C RA once round; 1C with NHJ dance to foot of set turn inwards and face up (2C+3C+4C step up, 2C+4C face down and 3C faces up)



17-32	  Up and down the mountain  - a series of changing places which commences with 4C+2C making an arch and the other couples dancing under, 1C+3C then make an arch and the process is repeated till all are back in place. (Note that 2 bars are used to turn in to face up or turn out to face down at the ends of the set, and you need to use all 16 bars.)



', 66, '8000  8400  8888 8888', 0, 1, 1, 0, 65);
INSERT INTO 'dance' VALUES (100, '1997-08-09 22:00:00+00', '2020-12-27 17:06:17.875866+00', 'Allan Nixon''s Reel', 'ALLAN NIXONS REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 69, '888/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (129, '2002-02-26 23:00:00+00', '2020-12-27 18:50:58.270408+00', 'An'' Gearasdan', 'AN GEARASDAN', 2, 32, 9999, 1, 3, 42, 108, '1982-01-01', 'Gearasdan Dubh Inbhir Lochaidh (the Black Garrison of Inverlochy) is the Capital of Lochaber. The fort, built at the narrow entrance to the Great Glen, was named after the reigning monarch, William III, and called Fort William, but the Gaelic name "An Gearasdan" (the garrison) and the English equivalent "The Fort" continue to be the names by which it is known to the Gaelic-speaking people of the Highlands and Islands. (from a note supplied by Jessie Taylor)', 50, '800/888/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (202, '1997-08-24 22:00:00+00', '2020-12-27 19:24:48.916423+00', 'Arbeadie', 'ARBEADIE', 3, 32, 9999, 1, 3, 42, 108, '1981-01-01', '', 67, '851/888/888/877', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17701, '2017-04-02 08:42:32.16872+00', '2021-01-11 12:04:40.235637+00', 'Georgian Earrings, The', 'GEORGIAN EARRINGS', 3, 32, NULL, 2, 3, 17, 11164, '2016-10-01', 'From the book:

*Among other things, a girandole may refer to an earring or brooch featuring three dangling jewels hanging from a central piece, a style that was especially popular in the Georgian era, when Scottish Country Dancing also developed. Here, the two lines of three dancers are reminiscent of such items of jewellery.*', 77, '888/882/844/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18006, '2017-10-12 11:46:18.950343+00', '2020-12-28 20:01:43.823131+00', 'Lion''s Head', 'LIONS HEAD', 1, 40, 9999, 107, 55, 6, 11220, '2014-01-01', 'The name of the dance refers to both the mountain Lion''s Head which along with Table Mountain welcomes visitors to Cape Town, as well as the crest of the Clan Macgregor which is also the Lion''s Head. This dance was devised for Dame Judith Macgregor, British High Commissioner to South Africa, to celebrate her first visit to the Cape Town Caledonian Society for our Burn''s Night Supper. We were later to learn that both Judith and her husband John are enthusiastic Scottish Country dancers who would regularly join us on the dance floor. This dance turned out not be the first one devised in their honour — Susi Mayr had devised "The Ambassador''s Reel" for them when John was the ambassador to Austria.	

	

Christof, who is now 15 years old, composed five reel tunes for this project on request and initially they were just named one, two, three, four and five. This was the fifth tune and when it was linked to this dance, retaining "Five" as the title seemed quite apt.

', 68, '88888/44448/88888/80044/04840', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16791, '2015-10-14 15:51:00.90042+00', '2020-12-28 20:23:58.528884+00', 'Moggie and The Fish', 'MOGGIE AND THE FISH', 1, 48, NULL, 2, 3, 17, 2682, NULL, 'Notes from The Johnsonville Collection:



Devised 27th May 2014. The Sheepskin Hey is a similar figure from traditional English Country Dancing, in dances like Picking Up Sticks. This is about 23 of the figure. My wife Kristin, and I, learned of the figure whilst dancing with a medieval dance group in Cambridge (UK), the Capriol Dancers.  



Recommended tune is “Miss Gayton’s Hornpipe”. A suitable recording is “The Sound of Harris” by  Andrew Rankine and his Band. 



The dance is given to Moggie Grayson who found my fish kilt pin, which I lost at the local Viking Ball, and mailed it home to me, along with the following poem:



On Finding Rod’s Kilt Pin



Said the fishy to the tablecloth   

Please look down here at me  

I jumped off Rodney’s kilt and landed way below his knee  

Please pick me up and save me  

From an agonizing fate  

I could b e crushed ’neath heavy feet  

And then I would b e “late"  

O, happy day, and bless the gentle hand that made me fly  

Adventure now awaits me  

In a postman’s bag to lie  

En route to Downey’s household  

And reunion so gay  

Please pin me tight and off we’ll go  

To dance another day.



Moggie Grayson, 19 May, 2014', 67, '888/888/444/444/444/444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20198, '2020-12-28 20:49:40.412799+00', '2020-12-28 20:49:40.412799+00', 'Jolly Right', 'JOLLY RIGHT', 4, 256, 10000, 1, 4, 1, 3113, '2005-02-01', 'For Birgitta Penner.', 72, '8800/8840/8880/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18535, '2018-08-26 23:28:34.095626+00', '2020-12-28 20:51:24.301462+00', 'Littlecroft Strathspey', 'LITTLECROFT STRATHSPEY', 3, 32, NULL, 1, 4, 1, 11690, NULL, 'This dance was devised to mark the 60th birthday of Ingrid. Littlecroft is the name of the home which Ingrid and Christopher have shared for over three quarters of their married life.', 56, '8800/8080/8484/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20199, '2020-12-28 21:00:41.032961+00', '2020-12-28 21:00:41.032961+00', 'Windmill Reel, The', 'WINDMILL REEL', 1, 32, NULL, 4, 55, 35, 11744, '2015-05-03', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17176, '2016-08-20 08:05:18.496701+00', '2020-12-28 23:38:34.112333+00', 'Amanda''s Birthday Dance', 'AMANDAS BIRTHDAY DANCE', 3, 40, NULL, 1, 4, 2, 10907, '2015-11-01', 'Devised for Amanda Peart', 90, '8888/8008/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5605, '2001-05-20 22:00:00+00', '2020-12-29 11:44:43.276006+00', 'Road to Ben Hope, The', 'ROAD TO BEN HOPE', 3, 32, 9999, 1, 3, 42, 227, '1992-10-01', 'Level: (very) advanced.



Suggested tune: a beautiful but strong strathspey.  



Recorded music:  H.I.S.C.D.  Largo Bay is suitable.



Bars 25-32 are John Drewry''s Circle.  I would like to thank John for it, and suggest that it gets a name.  "Cosmic Circle" might be a good idea, as it shrinks and then falls apart.





Note: »The Road to Ben Hope (demonstration dance)«, 	3C/3L S 48, in Two by Two p7 has no crib.', 56, '804  888  888  888', 0, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (15430, '2014-05-08 09:17:30.769872+00', '2020-12-29 14:58:45.624919+00', 'Battle of Trafalgar, The', 'BATTLE OF TRAFALGAR', 1, 40, NULL, 107, 6, 74, 10951, '2014-02-01', 'The dancers are arranged as two, side by side, 3 couple sets, i.e. 4M, 5M and 6M are back to back with 1L 2L and 3L. The first set, couples 1, 2 and 3 represents the English fleet, the second set with couples 4, 5 and 6 represents the French and Spanish fleet.



Devised by Keith Rose for a Scottish Dancing holiday to Conil de la Frontera on the Costa de la Luz, Spain which is about 8 miles from Cape Trafalgar. The Battle of Trafalgar was fought on 21 October 1805 when Admiral Nelson attacked the larger combined French and Spanish fleets using a new strategy of attacking perpendicularly to the line of enemy ships.', 90, '888888 888000 888888 888888 888888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14260, '2011-09-09 22:00:00+00', '2020-12-30 17:06:59.040202+00', 'Navy Lark, The', 'NAVY LARK', 1, 32, NULL, 1, 3, 42, 1228, '2010-11-25', 'The idea for the dance came from the Navigating Officer of HMS Troutbridge, Sub

Lieutenant Phillips, whose instructions to CPO Pertwee were invariably “Left hand

down a bit Chief” usually followed by a crash. I thought about having an eight bar

melee at the end but decided on simplicity.', 56, '800/888/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (609, '1998-10-18 22:00:00+00', '2020-12-31 00:06:57.927167+00', 'Bob o'' Footdee', 'BOB O FOOTDEE', 1, 32, 9999, 1, 4, 2, 108, NULL, 'In this dance 3C & 4C start on opposite sides.



Footdee (pronounced "Fittie") was originally a fishing village on the north shore of the mouth of the River Dee.  It has long been absorbed into the City of Aberdeen.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15833, '2015-01-18 13:59:23.473831+00', '2020-12-31 11:39:40.376546+00', 'Montpellier Jig, The', 'MONTPELLIER JIG', 2, 32, 9999, 1, 4, 1, 1582, '2008-03-01', 'A simple starter dance devised for the Montpellier Group in March 2008.', 72, '8888/8000/8888/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14338, '2011-12-08 23:00:00+00', '2020-12-31 11:52:01.497243+00', 'Come let us Dance', 'COME LET US DANCE', 1, 32, NULL, 1, 3, 42, 9998, NULL, 'Found on the Twin Cities Ball Programme 2002 at http://www.rscds-twincities.org/annualball02.html.  

It names its source as "Strathtay Album (variation)", but is very different from "Come let us Dance and Sing" by Iain Boyd in that album.  Could it be as variation on some other dance in that album?  E. T. Ferguson; editor.

', 59, '880  808  888  866', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (13828, '2011-08-05 22:00:00+00', '2020-12-31 11:54:12.511917+00', 'Reely Easy Strathspey', 'REELY EASY STRATHSPEY', 3, 32, NULL, 1, 3, 42, 1113, NULL, 'This dance was devised to teach reels on the side. Setting before and after the reels prepares the dancers to start the reels and allows for a chance to regain orientation after completion.

', 56, '880/888/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10666, '2002-07-21 22:00:00+00', '2020-12-31 14:25:05.358858+00', 'Corbies o'' the Fort', 'CORBIES O THE FORT', 2, 32, 9999, 1, 3, 42, 2961, '1999-01-01', 'This is dedicated to the Fort Worden Workshop in September, 1999.', 50, '862/888/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12576, '2005-11-01 23:00:00+00', '2021-01-01 10:02:15.756908+00', 'Away to the West', 'AWAY TO THE WEST', 3, 32, 9999, 1, 4, 1, 13, NULL, '', 88, '8888/8888/8080/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8500, '2002-02-28 23:00:00+00', '2021-03-18 12:45:26.412143+00', 'Bonny Lads of Earley, The', 'BONNY LADS OF EARLEY', 1, 32, 9999, 1, 3, 42, 13, NULL, '', 59, '822/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11395, '2003-07-06 22:00:00+00', '2021-01-25 13:46:26.088547+00', 'In Campbell Country', 'IN CAMPBELL COUNTRY', 3, 32, 9999, 1, 4, 1, 146, NULL, '', 56, '888/840/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1634, '1998-01-15 23:00:00+00', '2023-02-12 15:58:15.367188+00', 'Devil''s Elbow, The', 'DEVILS ELBOW', 1, 32, 9999, 1, 3, 42, 372, '1981-09-01', 'This dance was originally entitled "The Whirligig ". To avoid confusion with an existing dance of the same name, it has been retitled. The original version used in its own locallity had a different bars 25-32.', 56, '800/888/888/844', 1, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (12923, '2006-10-19 22:00:00+00', '2021-01-02 16:12:58.782189+00', 'Heart of Midlothian F.C., The', 'HEART OF MIDLOTHIAN FC', 2, 32, 9999, 1, 3, 42, 3583, '2004-04-01', 'A freely downloadable recording of music for this dance is available via <<http://www.fiddletree-music.com/johnturner/scdrecordings.html>>  



Devised by Moira Turner, SCD-Richmond VA, April 2004, for my dad, James Randall Duffy, born on The Pleasance, Edinburgh, in 1915.  Despite growing up in the Irish-Scots immigrant community of the Cowgate, he was one of The Heart of Midlothian FC’s staunchest supporters ever and a member of the Edina HSC.  ‘Forever and Ever’ was a spirit song popular with Hearts’ fans in the mid-1950s.  The title was borrowed for the dance’s signature tune.', 56, '804/844/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7062, '1998-01-05 23:00:00+00', '2021-01-01 17:02:13.193303+00', 'Westward Ho!', 'WESTWARD HO', 1, 40, 9999, 1, 3, 42, 1361, NULL, '1-8 Life in settled areas. There are two ideas at work here: (1) the "chain" symbolizes the bonds people feel in traditional patterns of life: and (2) the box-like shape indicates the closed-in feelings of those who yearn to leave.  

9-16 Decision to relocate. The "cross and cast" demonstrates the decision to leave home and family, and the "1/2 figure eight" represents packing and final preparations for the trip.  

17-24 Travel across the continent. This reel symbolizes the ins and outs, ups and downs of the journey.  

25-32 Arrival in new territory. Once again, two ideas for one figure: (1) the pattern depicts exploration of the new found territory: and (2) these eight bars of setting portray exuberance in reaching the great Pacific Northwest.  

33-40 Celebration of Washington statehood. The two reels on the side represent the dancers'' celebration of their new status as citizens of Washington State.', 63, '888/800/888/822/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13620, '2010-10-08 22:00:00+00', '2021-01-01 18:53:22.030767+00', 'Another Woodland Wander', 'ANOTHER WOODLAND WANDER', 2, 32, 9999, 1, 4, 1, 10256, NULL, '', 56, '8800/8800/8000/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4684, '1997-11-27 23:00:00+00', '2021-01-01 22:04:47.888956+00', 'Mount Saint Helens', 'MOUNT SAINT HELENS', 4, 32, 1, 1, 4, 1, 399, NULL, 'The dance starts with cracks opening deep beneath the mountain. Warm waters percolate upward, with small steam emissions. (March-April 1980.) The cracks open more, magma approaches the surface to culminate in the climactic eruption of May 18, 1980. Vancouver, Washington, 35 miles from Mount St. Helens, was the headquarters of the U.S. Geological Survey and Forest Service teams during the eruption. The VANCOUVER, USA INTERMEDIATE DANCE CLASS devised this dance commemorating the explosion, all the more appropriate since one of the class members, a geologist, worked on the volcano. Now, eight years after the eruption, the Mount St. Helens National Monument is open for all to view and climb the natural wonder of Washington.', 84, '4668/4668/4888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19543, '2019-08-14 09:48:51.526052+00', '2021-01-02 11:48:27.366705+00', 'World''s End Close', 'WORLDS END CLOSE', 3, 40, NULL, 2, 3, 17, 3583, '2018-10-01', 'A freely downloadable recording of music for this dance is available via <<http://www.fiddletree-music.com/johnturner/scdrecordings.html>>



This dance is named for the close off the High Street, Edinburgh (opposite John Knox’ House) where my father’s sister and her family lived when I was a little girl. It is dedicated to my cousin, Margaret [Milbourne] Levins, a competitive ballroom dancer, who grew up on the Royal Mile and who has taken the initiative to keep in touch with an entire generation of a Scottish family, which has been spread over four continents for the past forty years.

', 63, '880/880/880/808/408', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2013, '1997-09-02 22:00:00+00', '2021-01-02 13:39:01.704522+00', 'Evergreen Fairs', 'EVERGREEN FAIRS', 2, 32, 9999, 1, 3, 42, 880, NULL, 'Fairs traditionally have been a way for rural people to gather together to exchange news, display their crafts and skills, and enjoy themselves. The gaiety and amusement keep fairs popular in our more urban society and guarantee that we will continue to enjoy them in the future.', 56, '880/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12918, '2006-10-19 22:00:00+00', '2021-01-02 16:06:32.626349+00', 'Child with Three Surnames, The', 'CHILD WITH THREE SURNAMES', 2, 32, 9999, 1, 3, 42, 3583, '2006-01-01', 'A freely downloadable recording of music for this dance is available via <<http://www.fiddletree-music.com/johnturner/scdrecordings.html>>



"Devised to celebrate the prospective arrival of our first grandchild".', 56, '880/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20200, '2021-01-02 19:41:20.686658+00', '2021-01-02 19:41:20.686658+00', 'It''s Only Logical', 'ITS ONLY LOGICAL', 4, 64, 5, 4, 4, 46, 1862, '2009-05-01', 'Inscribed to <<ddp:Rod Downey#2682>>, Logician and Dancer Extraordinaire.



Repeat the whole dance once. Note, couples retain their number throughout so the dance shifts one place counterclockwise with each change of tempo.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14601, '2012-11-15 20:22:02.268454+00', '2021-01-02 22:29:53.014962+00', '60th Celebration, A', '60TH CELEBRATION', 3, 32, NULL, 2, 121, 17, 3183, '2009-04-01', 'A dance devised by Anne Thorn in April 2009 to celebrate the 60th anniversary of the

Helensburgh Scottish Country Dancing Club.



The tune: “Thistle of Scotland” (Trad), previously indicated, has been removed; it is a Reel and the dance is a Strathspey.', 96, '888/888/888/488', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20201, '2021-01-03 11:08:13.043155+00', '2021-01-03 11:08:13.043155+00', 'Jig for Kathleen, A', 'JIG FOR KATHLEEN', 2, 32, NULL, 1, 3, 42, 9998, NULL, 'Found on the programme for the S. Dorset Caledonian Society Highland  Ball in 2006.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20202, '2021-01-03 11:11:06.777417+00', '2021-01-03 11:11:06.777417+00', 'Reel Friend, The', 'REEL FRIEND', 3, 32, NULL, NULL, 4, NULL, 2197, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14787, '2013-04-07 19:45:41.794669+00', '2021-01-03 13:16:03.439187+00', 'We''re Fifty!', 'WERE FIFTY', 3, 32, NULL, 1, 4, 1, 3183, NULL, 'Bars 1 - 16 represent the number 50  

Bars 17 - 24 represent the fact that Scottish Country Dancing is a social activity that encourages people to meet new people, mix and form new friendships/acquaintances.  ', 66, '5555/8008/8888/0844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13229, '2007-01-22 23:00:00+00', '2021-01-03 15:48:20.414799+00', 'Four Ducks in a Row', 'FOUR DUCKS IN A ROW', 2, 32, 9999, 105, 54, 13, 2677, NULL, 'For <<ddp:#11719|Norma and Mike Briggs>>. Description available in <<sspey:47869|strathspey list message 47869>>.



Another crib for the dance can also be found as part of the <<http://sprott.physics.wisc.edu/mscd/ball08cheat.doc|crib sheet>> for the Madison SCD Annual Ball in 2008.', 91, '8444/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14791, '2013-04-07 19:54:58.139779+00', '2021-01-03 16:39:28.004+00', 'Isle of St Kilda, The', 'ISLE OF ST KILDA', 2, 32, NULL, 1, 3, 42, 3183, '2010-09-01', 'Devised by Anne Thorn in September 2010 for her husband who had the privilege of travelling to, and working on, the island of St. Kilda in the late 1970s early 1980s. St Kilda was evacuated 80 years ago in 1930 and bequeathed by the Marquess of Bute to The National Trust for Scotland in 1957.', 56, '880/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3058, '1998-01-05 23:00:00+00', '2021-01-04 12:42:23.417211+00', 'Ian Powrie''s Farewell To Scotland', 'IAN POWRIES FAREWELL TO SCOTLAND', 3, 64, 9999, 1, 4, 3, 991, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12636, '2005-11-08 23:00:00+00', '2021-01-11 23:10:23.962373+00', 'Glint of Gold, A', 'GLINT OF GOLD', 3, 32, 9999, 1, 4, 2, 2101, '1997-01-01', 'Devised for Margaret Cowie of the Buckie Class on her 50th Birthday in 1997. ', 81, '8448/4884/8888/4884', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12628, '2005-11-08 23:00:00+00', '2021-01-12 11:53:27.860777+00', 'Diagonal Symmetry', 'DIAGONAL SYMMETRY', 2, 32, 9999, 1, 3, 42, 3647, NULL, '', 47, '800/844/844/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20575, '2021-12-19 12:27:20.188945+00', '2021-12-19 12:27:20.188945+00', 'Breakout in Room 7', 'BREAKOUT IN ROOM 7', 2, 32, NULL, 5, 2, NULL, 9998, NULL, 'This dance was part of the RSCDS Spring Fling event.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20203, '2021-01-03 21:05:25.719943+00', '2022-12-22 18:26:15.664113+00', 'Farewell to Hugh', 'FAREWELL TO HUGH', 1, 32, NULL, 1, 3, 42, 725, NULL, 'Information derived from the <<https://youtu.be/o02LrOf6gJk|youtube video>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17903, '2017-07-27 14:13:25.287177+00', '2021-01-04 13:27:17.470392+00', 'Name''s Bond, The', 'NAMES BOND', 3, 32, 9999, 1, 4, 2, 10648, '2013-01-01', 'From the dance''s web page:



This dance was devised after an exchange of very silly e-mails about secret agents and espionage. The movement in bars 9-16 could be called ‘The Espionage’ ..... 



The idea is that 1st Man is James Bond or some other secret agent and, helped by his lady friend (partner), he is looking for ‘The Third Man’. At no point should 1st Man have clear sight of 3 rd  Man. At the end of 32 bars 3M is in 4th place and has changed sides (isn''t that what these secret agents do in films?). 1st couple are now in 3rd place so our erstwhile James Bond becomes The Third Man (who, of course, ends up changing sides!). On the final turn, the original 3rd couple will be in top place (and still on opposite sides) so the last ''James Bond'' is actually female  - this is the 21st century after all! When the dance ends, all 4 couples are on opposite sides. 



It fits the music which Nicol McLaren recorded for Alison Rose which includes the Pink Panther theme tune. ', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15097, '2013-08-26 08:53:54.673839+00', '2021-01-04 15:19:11.366695+00', 'Pride of Dunblane, The', 'PRIDE OF DUNBLANE', 1, 32, NULL, 5, 113, 4, 550, '2013-07-17', 'A 32 bar Reel for couples in a large circle around the room, facing in, à la ''Lucky Seven'' or ''Circassian Circle''.

Tributes to Andy Murray come in all shapes and sizes - cakes, flowers, and now a dance. Dancers at Linlithgow Scotch Hop were the first to enjoy a new Scottish dance ''The Pride of Dunblane'' written to celebrate his achievements in becoming Britain''s first Wimbledon men''s singles champion for 77 years.



I have followed Andy Murray''s career since his Wimbledon debut, and I have always been impressed by his dedication and talent as he worked his way into the top four. This year at Wimbledon he looked like he could finally go all the way, so when John contacted me on the day of the semi-finals to suggest writing a dance the ideas started flowing. I tried to create a simple dance which everyone could enjoy so that Andy''s achievements could be celebrated at ceilidhs up and down the country.



The dance is written to fit the Wimbledon theme tune and includes movements inspired by Andy''s Wimbledon journey, including Centre Court, retrieving a drop shot and the ever-present towel.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13206, '2006-12-11 23:00:00+00', '2021-01-04 16:10:04.06603+00', 'Bubble Sort', 'BUBBLE SORT', 1, 32, 9999, 1, 4, 4, 2766, '2005-08-01', 'My original goal was to create a dance named Chaos Reigns that seemed to be complicated, but from which order formed at bar 32 with everyone changing partners, ala Caddam Wood; however in this dance people are back with partners after the second time through and, thus, don’t dance with everyone else. When this dance occurred to me, the ending figure seemed so much like a computer bubble sort that I renamed the dance. It isn’t clear to me whether the figure in bars 17-24 can be danced in reel time; if it can, this dance is actually a better reel than a strathspey. If the figure doesn’t work in reel time, then Fill the Fetters is strong strathspey music that easily carries the dance.', 92, '6666/8888/8888/7887', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13080, '2006-11-10 23:00:00+00', '2021-01-04 17:03:27.459062+00', 'Avon Valley Strathspey, The', 'AVON VALLEY STRATHSPEY', 3, 40, 9999, 4, 4, 14, 884, '2006-01-01', '*From the book:* The Avon River has its source in Wickepin, Western Australia, and is over 260km in length. It becomes the Swan River and flows through Perth to the Indian Ocean at Fremantle.



Note that in Western Australia, the "Av" in "Avon" is pronounced as in the word "have".', 90, '8484/8888/8888/8484/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13003, '2006-11-01 23:00:00+00', '2021-01-04 17:16:35.261122+00', 'Bramble Jelly', 'BRAMBLE JELLY', 2, 32, 9999, 1, 3, 42, 244, '2005-01-01', '19th may 2005 In the last few weeks of class I tried out The Bramble Bush. It has such nice music but I thought that it would have been a little different if devised recently. One of the problems for our newcomers was to dance the CPCP at the required speed. So I re-devised it and tried it out as ''Bramble Jelly''. It seemed to be appreciated so I offer it here for your judgement.', 41, '800  844  822  844', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (13830, '2011-08-05 22:00:00+00', '2021-01-05 11:58:48.636917+00', 'Wee Walter''s Wander', 'WEE WALTERS WANDER', 3, 32, NULL, 1, 2, 76, 1113, NULL, 'This dance was devised as a teaching dance for reel of four.', 40, '80/82/88/84', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12950, '2006-10-25 22:00:00+00', '2021-01-05 15:09:44.166266+00', 'Dancing on Water', 'DANCING ON WATER', 1, 32, 9999, 1, 3, 42, 3718, '2004-01-01', '', 50, '808/880/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15419, '2014-04-11 20:19:25.508183+00', '2021-01-05 16:17:00.74381+00', 'Twice around the Beacons', 'TWICE AROUND THE BEACONS', 4, 128, 2, 4, 4, 54, 10945, NULL, 'Devised by Pat Harvey, Roding Reel Club, and dedicated to Geoff Palmer of Salisbury to thank him for the very successful house parties he ran at Nythfa House for 10 years.



With thanks to <<ddp:Chris Dewhurst#1526>> for composing the music for “Twice Around The Beacons”.

', 75, '8888/8888/8888/4444/4444/4444/4444/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17781, '2017-06-04 21:50:26.881145+00', '2021-01-05 16:53:05.767616+00', 'Nimbus 2017', 'NIMBUS 2017', 4, 160, 10, 4, 4, 54, 11489, '2017-03-01', 'Waltham Scottish Country Dance Group at the ASCDS Festival, Nottingham 06 May 2017. Music: Neil Barron and his Band.



Nimbus 2017 depicts a game of Quidditch from Harry Potter. The game is fast, so the team decide to practise slowly (Strathspey), shake hands and then play for real. The Schiehallion reels show one team (the men) racing quickly ahead, followed closely by the other team (women). Then the teams reorganise and try to set up their next plays (hands across and casting off); suddenly the women are in the lead on the reels, and the men are chasing behind. The interlocking half reels of four and turning are further evidence of skilful players trying to outsmart each other on the pitch, before the first man then holds the Golden Snitch aloft in victory at the end!



Nimbus 2017 is a Medley version of Nimbus 2002 by Vicky Goodloe, Kentucky, USA. The adaptation of dance was suggested by John Aitken of The Waltham Scottish Country Dance Group and Vicky has now dedicated the new Dance to this Group who performed it for the first time at the 37th Association of Scottish Country Dance Societies (ASCDS) Festival in 2017.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4531, '1997-04-03 22:00:00+00', '2021-01-05 18:56:40.914911+00', 'Miss Laura Andrew', 'MISS LAURA ANDREW', 3, 32, 9999, 1, 4, 2, 108, '1982-01-01', 'Described by Drewry as a "Pastoral". For the New York Branch of the RSCDS.', 81, '8888/8888/8448/8008', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20240, '2021-03-03 01:08:08.21864+00', '2021-03-31 19:19:06.643003+00', 'Tribute to John D.', 'TRIBUTE TO JOHN D', 3, 40, NULL, 4, 4, 1, 1445, NULL, 'This dance was devised as a tribute to John Drewry, the devisor of the rondel, and also to see whether a bourrel in a square would work.', 80, '8080/8888/0808/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15774, '2015-01-11 14:48:24.169424+00', '2021-03-25 23:43:45.915137+00', 'Golden Memories', 'GOLDEN MEMORIES', 3, 32, 9999, 1, 3, 42, 440, '2003-05-01', 'Devised on the occasion of the golden wedding anniversary of David and Margaret Hawkins.', 56, '844/848/840/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12880, '2006-10-08 22:00:00+00', '2021-01-07 12:05:06.856755+00', 'Glasgow Reel', 'GLASGOW REEL', 1, 32, 9999, 1, 3, 42, 10720, '2005-01-01', 'Jen Wood writes:  I''m pretty sure I wrote this dance :) .  It was written for the 50th anniversary of the Glasgow University Scottish Country Dance Club in 2005, so was only ''published'' in the cribs for the ball - but it is finally going to be properly published when Dunedin Book 6 comes out in March 2013.

', 50, '800/888/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11656, '2004-01-14 23:00:00+00', '2021-01-07 15:02:39.277714+00', 'Irish Drover', 'IRISH DROVER', 3, 32, 9999, 1, 3, 42, 2018, NULL, 'The first 8 bars are taken directly from the Irish Rover, making the Irish Drover a useful precursor to that widely popular, but more challenging dance. We recommend the Gypsy Rover in Gaelic College SCD Book #02 as a way to learn the last 8 bars of the Irish Rover.', 75, '844/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (301, '1998-09-29 22:00:00+00', '2021-12-20 15:38:52.80937+00', 'Auld Lang Syne', 'AULD LANG SYNE', 3, 32, 9999, 1, 3, 42, 432, NULL, '', 45, '860  880  880  822', 1, 1, 1, 1, 60);
INSERT INTO 'dance' VALUES (2506, '1998-11-14 23:00:00+00', '2021-01-08 21:18:10.511038+00', 'Glayva', 'GLAYVA', 2, 32, 9999, 1, 2, 76, 108, '1976-01-12', 'Touted by its manufacturer, Whyte & Mackay, as “the best liqueur in

the world™”, Glayva is a beverage containing malt whisky,

Mediterranean tangerine juice, almonds, honey, spices and other

ingredients and is prepared to a secret recipe invented in 1947 by the

Edinburgh whisky merchant, Ronald Morrison. The name derives from the

Gaelic *glè math*, meaning “very good”.



This dance by the same name is one of the first, if not the

first, dance featuring the “espagnole” formation. Note that the

espagnole, taking up the final 8 bars of the dance, is basically

identical to the first or second 8 bars of the dance rotated by 90°.



John Drewry wrote in the original description that the dance was for Mary Prentice''s Birthday 12th January, 1976, in Ibiza.', 69, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (3580, '1999-11-01 23:00:00+00', '2021-01-09 12:07:11.035824+00', 'Ladies'' Fancy', 'LADIES FANCY', 2, 32, 9999, 1, 2, 76, 9998, NULL, 'Though "collected in Angus", the RSCDS publication "Scottish Country Dances Books 13 to 18" also refers to "D Anderson''s Ball-Room Guide c. 1886".



An <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-030-December-1966.pdf#page=7|article in Thistle 30>> by the Fletts gives some background and reconstruction of the original instructions.', 56, '62/84/88/88', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (11720, '2004-04-29 22:00:00+00', '2021-01-09 21:50:44.356297+00', 'There are no Kangaroos in Austria (Basic Version)', 'THERE ARE NO KANGAROOS IN AUSTRIA BASIC VERSION', 2, 32, 9999, 2, 3, 17, 10292, NULL, 'The basic version may be used as introduction before teaching the <<ddd:There are no Kangaroos in Austria (Advanced Version)>>.



There is a video of the advanced version at the webpage for <<http://www.rscdsvienna.org/book/|The Vienna Book>>.', 61, '880/800/808/448', 1, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (13357, '2009-08-02 22:00:00+00', '2021-09-23 20:44:46.291977+00', 'Magic of Merrill, The', 'MAGIC OF MERRILL', 1, 32, 9999, 1, 3, 42, 2099, NULL, 'Lead tune: I recommend the Cape Breton version of “Return from India,” as in Jerry Holland''s (first) Collection of Fiddle Tunes. Be warned that early editions of this collection have a repeat mark at the end of bar 8 that you should ignore; the first eight bars are A, the remaining four bars repeated are B, and you make 32 bars by playing ABAB. Note also that Jerry or his Cape Breton colleagues have altered the tune significantly from the older version that is found on page 8 of Kerr’s First Collection of Merry Melodies, including swapping the A and B parts.', 64, '873  888  844  888', 1, 1, 0, 0, 85);
INSERT INTO 'dance' VALUES (9425, '2000-07-26 22:00:00+00', '2021-01-18 22:59:48.69026+00', 'Dancing on Parnassus', 'DANCING ON PARNASSUS', 4, 64, 5, 4, 4, 13, 2701, '1999-01-01', 'This dance is dedicated to Bruce Herbold and Patti Cobb in honor of their wedding. Bruce first taught this dance to a class which met on Parnassus Avenue. Michele Winter suggested the name in reference to the piano keyboard exercises "Gradus ad Parnassum" (The Steps to Parnassus) and her feeling that due to the square set formation we were gods dancing on top of the mountain. The music by Janet Kurnick is pure ambrosia.', 79, '8010/8080/8888/8888/8620/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11774, '2004-09-04 22:00:00+00', '2021-01-20 10:11:32.328166+00', 'Nether Rumgally', 'NETHER RUMGALLY', 1, 88, 9999, 4, 98, NULL, 3449, '2004-01-01', 'Danced with 4 couples and four singles.



Written as thanks to John and Sheena Sturrock of Nether Rumgally, Fife (»Mari Gold« is a pseudonym).  

The preferred Music is The Oddfellows by J Scott Skinner.  

The recommended recording is ''The Summer Assembly''  on  ''Cairngorms'', played by M.Johnstone & K.Smith.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11707, '2004-03-09 23:00:00+00', '2021-01-20 18:43:31.672822+00', 'Gloomy Winter''s Noo Awa''', 'GLOOMY WINTERS NOO AWA', 3, 32, 9999, 1, 3, 42, 550, '2001-01-01', 'Comment from the deviser Ian Brockbank in the The Badger Sett, and in similar form in the earlier New Scottland 60th Anniversary Book:



This is a variant on the dance “<<ddd:The Gloomy Winter#8094>>” which I gave to Sophia for her 25th birthday and which was published in the New Scotland 50th Anniversary Book. 

Bars 9-16 didn’t really work when tried with New Scotland and Dunedin – they require too much careful phrasing – so I came up with this modification. However, San Gabriel Valley like the original.

Written for Sophia Marriage and presented to her on the occasion of her 30th birthday in December, 2001, with love from Ian Brockbank.

', 50, '800  888  844  844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (13638, '2010-11-10 23:00:00+00', '2021-01-09 21:55:03.365485+00', 'There are no Kangaroos in Austria (Advanced Version)', 'THERE ARE NO KANGAROOS IN AUSTRIA ADVANCED VERSION', 2, 32, 9999, 1, 4, 28, 10292, NULL, 'Every 16 bars there is a new top couple starting the first 16 bars of basic pattern, while third couple starts the second 16 bars of basic pattern (cf. basic version of the dance). Thus, starting in the order 1234, after 16 bars we have 2413 (couples 2 and 1 now dancing), after 32 bars 4321 (couples 4 and 2 now dancing) after 48 bars 3142 (couples 3 and 4 now dancing), after 64 bars the dances finishes back in the order 1234. All couples have danced the two parts of the basic pattern once.



Note 1: The upper half of the set is regarded as the Northern Hemisphere, where the cyclones move anticlockwise, hence all the movements are anticlockwise; the lower half, "Down Under", is regarded as the Southern Hemisphere, with clockwise spiraling cyclones.



Note 2: The fugue resembles the reversed seasons in the Hemispheres, with shared conditions only in spring and autumn.



This dance was devised for Eva and Brian, who moved from Austria to Australia, by friends from the Vienna Branch (Felix Hamelbeck and Beatrix Wepner). It was an honour that they joined the group though only for a short time.



For teaching one may start with the <<ddd:There are no Kangaroos in Austria (Basic Version)>> before switching to the advanced version.



There is a video of the dance at the webpage for <<http://www.rscdsvienna.org/book/|The Vienna Book>>.', 87, '8888/8448/8888/4884', 0, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (1155, '1997-04-03 22:00:00+00', '2021-01-10 09:23:04.869745+00', 'Chari''s Twist', 'CHARIS TWIST', 1, 32, 9999, 1, 3, 42, 361, '1990-03-01', 'Dedicated to Chari Wurtzel who, in moments of crisis, is partial to the phrase, "Don''t get your

knickers in a twist."', 47, '880/800/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3628, '1997-09-07 22:00:00+00', '2021-01-10 16:59:19.716486+00', 'Ladie Nellie Wemys', 'LADIE NELLIE WEMYS', 2, 48, 9999, 1, 3, 42, 270, NULL, 'The dance has the title "Ladie Nellie Wemys" in the original book and uses a tune of almost the same name which is normally spelled "Lady Nellie Wemyss". The latter spelling is added as an alias.



John Mitchell''s daughter Alison writes:

*John was a stickler for detail, and "Ladie" would not have been accidental. However, I can well believe that he took the name from a recording of the tune that just "happened" to use that spelling, instead of "Lady". Certainly, the two are equivalent; but the title is correct as originally published.*

', 56, '884/884/811/888/811/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12687, '2006-02-16 23:00:00+00', '2021-01-11 11:14:26.730016+00', 'Kildonan Sands', 'KILDONAN SANDS', 3, 32, 9999, 2, 3, 17, 146, '2002-01-01', '', 69, '844/844/822/868', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12751, '2006-05-11 22:00:00+00', '2022-12-22 18:28:49.514876+00', 'Miss Mary Gray''s Fancy', 'MISS MARY GRAYS FANCY', 3, 32, 9999, 1, 4, 1, 725, '1997-01-01', '', 47, '8888/8000/8220/8000', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12006, '2005-02-01 23:00:00+00', '2022-12-22 18:31:56.772904+00', 'Stirling Castle', 'STIRLING CASTLE', 1, 32, 9999, 7, 98, NULL, 725, '2003-01-01', 'Possible error!  A pdf of "Stirling Castle" from a publication "Clapyerhands ''n Stampyerfeet" describes a very different dance from the one of the attached Minicrib.  This needs sorting out.  Eric Ferguson, 7 feb. 2017.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12624, '2005-11-08 23:00:00+00', '2021-01-12 12:05:39.495546+00', 'Jerusalem Farm Youth Hostel', 'JERUSALEM FARM YOUTH HOSTEL', 1, 32, 9999, 1, 3, 42, 3647, NULL, 'Jack Hamm wrote on 6th dec 2013:



Do you know where the dance Jerualem Farm Youth Hostel originated? The first youth hostel I visited in England was in Lancashire and was called Jerusalem Farm Youth Hostel. It was frequented by a group which included a piper and Scottish Dance Master.The group met there on many weekends and they organised Scottish Dancing for the night. I am wondering whether that was the place of origin of the dance Jerusalem Farm Youth Hostel.', 50, '800/866/866/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11979, '2005-01-19 23:00:00+00', '2021-01-15 10:50:52.140862+00', 'Professor''s Nightmare, The', 'PROFESSORS NIGHTMARE', 2, 32, 9999, 1, 3, 42, 10667, NULL, '', 50, '888/880/808/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20204, '2021-01-12 19:34:04.084113+00', '2021-01-12 19:39:35.283103+00', 'Honours of Scotland, The', 'HONOURS OF SCOTLAND', 4, 0, 9998, 107, 6, 3, 531, '1994-01-01', 'A medley devised for music composed by <<ddp:Gonnella, Ron#1615>> to mark the display of the Honours of Scotland (crown jewels) in Edinburgh Castle. It is in three parts: The Crown Air, The Sceptre Strathspey and The Sword Reel.



The start of the <<https://my.strathspey.org/dd/dancevideo/7753/|Edinburgh RSCDS video>> explains the symbolism.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12608, '2005-11-08 23:00:00+00', '2021-01-13 20:20:22.777895+00', 'Audrey''s Barbed Wire Dress', 'AUDREYS BARBED WIRE DRESS', 3, 32, 9999, 1, 3, 42, 3647, NULL, '', 56, '822/822/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9017, '1999-04-24 22:00:00+00', '2021-01-13 20:39:13.488615+00', 'Betty Wilde''s Delight', 'BETTY WILDES DELIGHT', 1, 32, 9999, 1, 3, 42, 2599, '1998-01-01', 'Dedicated to Betty Wilde for her continued support - with love from the Caberfiedh Junior Dancers

©1998', 48, '555/555/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12613, '2005-11-08 23:00:00+00', '2021-01-14 11:26:15.57996+00', 'Marjory''s Strathspey', 'MARJORYS STRATHSPEY', 3, 40, 9999, 4, 4, 13, 3647, NULL, '', 70, '4444/4444/8484/8484/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2005, '1997-09-02 22:00:00+00', '2021-01-16 18:49:05.04952+00', 'Ethel Mary''s Jig', 'ETHEL MARYS JIG', 2, 64, 9999, 6, 3, NULL, 108, '1988-01-01', '"A dance to mark the 95th Birthday of Ethel Mary Moss of cap Pele, New Brunswick who lived, at one time, in Asfordby, Melton Mowbray. I attended Melton Mowbray Grammar School so we have a territorial connection."



The instructions have three figures: 3x16 + 16 + 32 bars (96 bars in all) but suggest that for demonstration purposes the first figure may be done just once (ie 64 bars in all).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11513, '2003-10-02 22:00:00+00', '2021-01-16 15:06:28.740237+00', 'Drunken Party, The', 'DRUNKEN PARTY', 2, 40, 9999, 1, 100, 1, 2894, NULL, 'According to <<sspey:71683|strathspey list message 71683>> it seems the original instructions for this dance are lost so the MiniCrib is the only source.



When contacted in early 2021, Gordon confirmed being the deviser of this dance, but he does not have any original instructions himself; it was so long ago that he can’t even remember how they went. The dances were never tried out at his local dance group.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12083, '2005-03-15 23:00:00+00', '2021-01-16 19:58:22.227806+00', 'Gold and Silver Strathspey', 'GOLD AND SILVER STRATHSPEY', 3, 32, 9999, 1, 4, 11, 9998, NULL, '<<scddb:not-identical:13569>>', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6930, '1997-09-16 22:00:00+00', '2021-01-21 11:46:13.124958+00', 'Washington''s Columbia River', 'WASHINGTONS COLUMBIA RIVER', 4, 64, 5, 1, 4, 3, 1339, NULL, 'This dance starts in a longwise set for the Strathspey part then moves into a square set at the start of the Reel part.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11640, '2004-01-14 23:00:00+00', '2021-01-21 22:55:14.325115+00', 'Windmill of Croydon, The', 'WINDMILL OF CROYDON', 3, 32, 9999, 1, 4, 2, 3417, NULL, '', 88, '8888/8008/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11481, '2003-09-22 22:00:00+00', '2021-01-24 12:10:27.879431+00', 'Huncote Jig', 'HUNCOTE JIG', 2, 32, 9999, 2, 3, 17, 511, NULL, '', 67, '844/888/888/868', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11478, '2003-09-22 22:00:00+00', '2021-01-24 12:16:23.672242+00', 'If at First', 'IF AT FIRST', 3, 32, 9999, 2, 3, 17, 3378, NULL, 'The inscription on the book states: Several years ago, Leicester Branch ran a competiton to devise a dance (a four-couple strathspey) to fit a tune called “Daunder in the Glen” composed by one of our members. My contribution was not successful, but on the principle of “if at first you don’t succeed, try, try again", I adapted it for a three-couple set and submitted it for this book. This is the result.', 67, '880/800/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20206, '2021-01-22 08:09:44.636612+00', '2021-01-22 08:14:13.712446+00', 'Zoomers, The', 'ZOOMERS', 3, 32, NULL, 1, 3, 42, 440, '2020-07-03', 'For Keith and Deirdre Bark to thank them for their Zoom classes.', 56, '880/844/808/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19973, '2020-05-09 23:07:43.46712+00', '2021-01-22 08:58:42.075149+00', 'Award of Excellence, The', 'AWARD OF EXCELLENCE', 1, 32, NULL, 1, 3, 42, 440, '2018-02-27', 'For Laurie McConachie



ANN CAMPBELL — A word of explanation about the dance — Laurie visited me a couple of weeks ago and as she was leaving she mentioned a long-standing joke with someone on the Board, I forget who, about when was she getting an award of excellence. So, while she was driving home I was devising the dance.', 53, '444/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11477, '2003-09-22 22:00:00+00', '2021-01-24 12:26:43.005174+00', 'Default Setting?', 'DEFAULT SETTING', 2, 32, 9999, 1, 3, 42, 2973, '2003-01-01', 'From <<sspey:37563|Strathspey Message 37563>> · 21 Jan 2004 01:39:48.   I also like Caberfei - and ''The Abbot of Unreason''. (I''ve not yet come across Bold Mary). With inspiration from these dances, and from Anselm''s Anniversary Challenge, I devised a dance entitled ''Default Setting?'' which I posted on the strathspey list a few months ago. 



Music: H.I.S.C.D. #8.  This is the recording: Kiss under the Stairs, Jig, 8 × 32 bars, Played by Bobby Brown, Alasdair Fraser and others.', 50, '844  800  844  888', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (11440, '2003-09-22 22:00:00+00', '2021-01-24 12:44:23.607898+00', 'Tigger Bounce, The', 'TIGGER BOUNCE', 2, 32, 9999, 1, 3, 42, 2766, '2003-04-01', 'This dance is written for Sven Leyffer, who dances with enthusiasm and élan and who seems to have springs in his feet like Tigger from Winnie the Pooh. Sven likes to twiddle and birl and first couple has a chance to twiddle in the half reels of three and a chance to birl in bars 29-32.', 52, '880/880/774/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11399, '2003-07-06 22:00:00+00', '2021-01-24 13:17:51.828144+00', 'Scribe, The', 'SCRIBE', 2, 32, 9999, 1, 3, 42, 146, NULL, '', 52, '866/860/848/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12265, '2005-04-24 22:00:00+00', '2021-01-23 07:07:29.604818+00', 'Happy Anniversary Jig, The', 'HAPPY ANNIVERSARY JIG', 2, 32, 9999, 1, 2, 76, 2525, '2002-04-11', 'To Esther and Bill Goodfellow in celebration of their 30th Wedding Anniversary.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5527, '1997-11-30 23:00:00+00', '2021-01-23 21:20:52.611548+00', 'Star o'' Rabbie Burns, The', 'STAR O RABBIE BURNS', 1, 0, 9999, 1, 4, 3, 9, NULL, '<<scddb-not-identical:20208>>



The source for this dance entry was probably <<sspey:9741|strathspey message 9741>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20473, '2021-09-12 10:13:09.907656+00', '2021-09-12 10:13:09.907656+00', 'Bit on the Side, A', 'BIT ON THE SIDE', 1, 32, NULL, 1, 3, 42, 2682, '2020-11-14', 'For teaching set to and turn corners followed by reels on the side.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12626, '2005-11-08 23:00:00+00', '2022-07-16 19:43:50.844939+00', 'Valerie & Bill''s Wedding', 'VALERIE AND BILLS WEDDING', 3, 32, 9999, 4, 4, 4, 3647, NULL, 'A dance in which the Bride and Groom greet, mingle and dance with the guests.



Men have a new partner with each repetition. Men progress clockwise Ladies remain in original place.

', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11530, '2003-10-02 22:00:00+00', '2022-09-23 17:08:08.936965+00', 'Overdue Jig, The', 'OVERDUE JIG', 2, 32, 9999, 1, 4, 11, 316, NULL, 'This dance is dedicated to Miss Anne Bradburn who has been a good friend for over twenty years and for whom a dance is long "overdue".', 69, '8228/8668/8448/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12527, '2005-08-29 22:00:00+00', '2022-12-11 00:31:50.010985+00', 'Marjorie Stewart''s Jig', 'MARJORIE STEWARTS JIG', 2, 40, 9999, 2, 3, 17, 9998, NULL, '', 54, '844/800/844/877/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4642, '1997-11-27 23:00:00+00', '2021-05-06 20:08:44.51056+00', 'Montreal Rendezvous', 'MONTREAL RENDEZVOUS', 4, 32, 1, 1, 3, 42, 62, '1966-07-01', '<<scddb-not-identical:13360>>



Devised July 1966 and was completed in a rush for the competition organised by the Society''s Deep River Branch for their Centennial Collection, in which it appears.', 50, '800/888/844/844', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3770, '1997-09-07 22:00:00+00', '2021-01-25 16:33:29.515324+00', 'Legacy, The', 'LEGACY', 2, 32, 9999, 1, 3, 42, 632, NULL, '<<scddb-not-identical:3769>>



In memory of Miss Jean C. Milligan', 56, '888/888/800/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11682, '2004-02-18 23:00:00+00', '2021-01-27 10:01:24.051292+00', 'Megan''s Fancy', 'MEGANS FANCY', 2, 32, 9999, 1, 3, 42, 3423, '1998-01-01', 'This dance was inspired by Giorgio''s daughter, Megan, in the Winter of 1998.', 41, '800/800/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20208, '2021-01-22 21:40:48.564995+00', '2021-03-27 22:22:22.647573+00', 'Star o'' Rabbie Burns, The', 'STAR O RABBIE BURNS', 1, 0, NULL, 1, 4, NULL, 555, NULL, '<<scddb-not-identical:5527>>



Starts in a longwise set but is later a square.



Currently the only source for the dance is <<https://my.strathspey.org/dd/issue/2216/|SCDDB issue 2216>>.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2529, '1997-09-03 22:00:00+00', '2021-01-27 16:48:43.103939+00', 'Glendaruel''s Return To Aschaffenburg, The', 'GLENDARUELS RETURN TO ASCHAFFENBURG', 1, 40, 9999, 1, 4, 1, 957, '1984-07-01', 'Dancl! devised to commemorate the visit of the Glendaruel S.C. Dance Band and Glendaruel Dancers to Perth''s twin town of Aschaffenburg in Bavaria in July 1984.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11686, '2004-02-18 23:00:00+00', '2021-01-28 10:29:13.303634+00', 'Nancy''s Delight', 'NANCYS DELIGHT', 3, 32, 9999, 1, 3, 42, 3423, '1999-01-01', 'Dedicated to teacher, Nancy Pryce, February, 1999', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20209, '2021-01-25 09:53:52.933521+00', '2021-05-01 22:52:17.461111+00', 'Perth Assembly', 'PERTH ASSEMBLY', 4, 96, NULL, 7, 122, 3, 9998, NULL, 'Collected by Mary Isdale MacNab', 100, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6107, '1998-01-04 23:00:00+00', '2021-06-19 23:43:22.275049+00', 'Siol Mhorgan', 'SIOL MHORGAN', 1, 32, 9999, 1, 3, 42, 352, '1991-05-18', 'Inscribed "for Esther Mackay". The dance notes say that the title is the gaelic name from which Mackay is derived (race of Morgan) via Macaodh to Mackaoi to Mackay.', 67, '888/888/868/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19820, '2020-01-14 16:08:49.884423+00', '2021-07-14 08:47:25.28361+00', 'Katrina''s Caper', 'KATRINAS CAPER', 1, 40, NULL, 1, 2, 76, 9998, NULL, 'Devised for Katrina Johnson.



The instructions (page 6 of an unknown booklet) name no deviser, and have an error *[set | turn | set]* for bars 13-16. ', 77, '80/88/88/88/88', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20207, '2021-01-22 10:54:59.772216+00', '2021-08-10 17:59:57.020134+00', 'Corona Borealis Reel, The', 'CORONA BOREALIS REEL', 1, 32, NULL, 1, 3, 42, 12011, '2020-09-01', '', 47, '800/888/844/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15764, '2015-01-11 12:45:07.67752+00', '2021-01-27 17:07:38.20017+00', 'Honorary Scot and the Highlander''s Daughter, The', 'HONORARY SCOT AND THE HIGHLANDERS DAUGHTER', 1, 32, 9999, 1, 3, 42, 440, '2005-01-22', 'Devised on January 22 2005, for Keith and Deirdre Bark.  



At the ASTA Burns Supper that year there was a storm and the person who was to give the “Immortal Memory” speech was unable to get there.  Keith stepped into the breach and during his speech he admitted that he was English but said he felt he was an honorary Scot and had married a highlander’s daughter.', 56, '880/888/808/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20216, '2021-02-05 16:30:25.714709+00', '2021-02-05 16:30:25.714709+00', 'Shupashkar Reel', 'SHUPASHKAR REEL', 1, 32, NULL, 2, 3, 17, 12018, NULL, 'Source: <<https://my.strathspey.org/dd/list/28896/|dance list 28896>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11697, '2004-02-18 23:00:00+00', '2021-01-29 08:18:40.385847+00', 'Kiss of the Humming Bird', 'KISS OF THE HUMMING BIRD', 1, 32, 9999, 1, 3, 42, 3429, NULL, 'In Portugese. the humming bird is called the kissing bird.  

The figure used in bars 5-8 and 29-32 (half turn & twirl) suggest the kiss.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11193, '2003-02-15 23:00:00+00', '2021-01-29 22:28:38.181415+00', 'Weary Willie''s Reel', 'WEARY WILLIES REEL', 1, 32, 9999, 1, 100, 11, 21, NULL, 'The tune is called "Weary Willie''s Reel"

In Highlander Collection vol 1 the dance is called "Wearie Willie''s Reel"

As this may be a misprint, I have left the name unchanged.  ETF 2011-10-30', 81, '8008/8888/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10967, '2002-11-18 23:00:00+00', '2021-01-30 11:15:15.040555+00', 'Betty''s Delight', 'BETTYS DELIGHT', 3, 32, 9999, 1, 3, 42, 671, '1990-01-01', 'Inscribed to Elizabeth Anne Hounsfield for the occasion of her 50th birthday.', 49, '800/800/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20212, '2021-01-29 23:25:19.703765+00', '2021-01-31 10:11:25.793682+00', 'Dublin''s Dancing Fiddler', 'DUBLINS DANCING FIDDLER', 2, 32, NULL, 1, 3, 42, 10795, '2017-09-01', 'to celebrate the 16th birthday of Anna Dallas, who sometimes joins her grandparents, the regular musicians at Dublin Scottish Country Dance Club, and sometimes dances with us.

', 47, '800/804/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10941, '2002-11-14 23:00:00+00', '2021-02-01 17:17:35.920066+00', 'That Glaikit Waste of Space!', 'THAT GLAIKIT WASTE OF SPACE', 1, 32, 9999, 1, 4, 2, 108, '2002-01-01', '', 88, '6666/6666/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20210, '2021-01-29 22:54:49.207469+00', '2021-01-29 23:00:48.410475+00', 'Voulez-vous danser?', 'VOULEZVOUS DANSER', 1, 32, NULL, 1, 3, 42, 11193, '2018-11-13', 'To celebrate the fiftieth birthday of Helen McGinley on 13 November 2018. Helen is a member of the Dublin Scottish Country Dance Club. ', 50, '844/800/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10914, '2002-11-11 23:00:00+00', '2021-02-02 17:01:32.232145+00', 'Moderator''s Welcome, The', 'MODERATORS WELCOME', 2, 32, 9999, 4, 4, 13, 3212, '1997-01-01', '', 88, '8888/8888/8888/4444', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20214, '2021-02-03 13:14:52.768609+00', '2021-02-03 13:14:52.768609+00', 'St Michael''s Well', 'SAINT MICHAELS WELL', 2, 32, NULL, 1, 3, 42, 12016, NULL, '', 34, '800/800/840/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10891, '2002-10-20 22:00:00+00', '2021-02-03 15:33:41.038003+00', 'Dancing Around', 'DANCING AROUND', 3, 32, 9999, 1, 4, 2, 108, '2002-01-01', '', 94, '8888/8888/8888/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20211, '2021-01-29 23:06:18.803338+00', '2021-01-29 23:16:16.739586+00', 'Mischief Mastered', 'MISCHIEF MASTERED', 2, 32, NULL, 1, 3, 42, 10795, '2019-11-28', 'To celebrate Pascal Faurie’s graduation on 28th November 2019 from the National College of Ireland with an MSc in Cyber Security.  



The tune Maître ès Mystères (Informatique) was composed by Professor John Barnes.  



In Harry Potter and the Prisoner of Azkaban, Harry is given the Marauder’s Map. When he has finished using it, he has to tap it with his wand and say ‘Mischief managed’. The title of the dance is a play on this and Pascal’s Master’s degree, as Pascal is both a great fan of Harry Potter and a mischievous person (in a good way!). The dance is designed to give him scope for mischief in the form of birling, high fives and climbing on the windowsill.', 50, '800/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10818, '2002-09-10 22:00:00+00', '2021-02-04 13:14:39.021861+00', 'Off to Pastures New', 'OFF TO PASTURES NEW', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 50, '800/888/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20217, '2021-02-05 16:35:12.89101+00', '2021-02-05 19:40:07.043633+00', 'Final Fling, The', 'FINAL FLING', 1, 32, NULL, 1, 3, 42, 12019, NULL, 'Source: <<https://my.strathspey.org/dd/list/28896/|dance list 28896>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5362, '1998-11-11 23:00:00+00', '2021-12-20 15:39:47.163181+00', 'Prince of Orange', 'PRINCE OF ORANGE', 2, 16, 9999, 5, 2, NULL, 9998, NULL, '', 100, '88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (10938, '2003-01-16 23:00:00+00', '2022-08-18 09:12:27.548958+00', 'Oompah, Oompah, Shove it Up your Joompah!', 'OOMPAH OOMPAH SHOVE IT UP YOUR JOOMPAH', 1, 32, 9999, 2, 2, 76, 108, '2002-05-01', '', 56, '84/88/88/44', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14184, '2011-08-26 22:00:00+00', '2021-02-04 17:30:35.422699+00', 'Shooting Lodge, The', 'SHOOTING LODGE', 2, 48, NULL, 1, 4, 2, 127, NULL, 'Devised for Richard and Gillian Ovey of Hernes Farm Estate, Henley.  



The "Shooting Lodge" is a redeveloped part of the farm steading where we dance on Friday evening.', 71, '8008/8888/8888/8008/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10784, '2002-08-06 22:00:00+00', '2021-02-05 12:34:07.16173+00', 'Contra Temp Reel', 'CONTRA TEMP REEL', 1, 48, NULL, 1, 2, 30, 3180, '2001-01-01', 'This dance is published a 2C/4L dance, but as first time through 1c ends in 4th place (progression 2341) it is in fact a 4C/4L dance. The instructions then continue with "The dance starts again with the new top couple being a couple one and every other couple is also a first couple."   



Editor''s note:  That is obviously incomplete; it is impossible for both 1c and 3c to finish at the bottom.  One must assume that 1c ends in 3pl and 3c in 4pl (progression 2413).  Then the final positions after 8 times through are (4,2,1,3).  The initial (1,2,3,4) is never reached.  This point needs to be looked at more closely.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10760, '2002-08-06 22:00:00+00', '2021-02-06 11:15:14.138168+00', 'Galloping Gordon', 'GALLOPING GORDON', 1, 32, 9999, 1, 3, 42, 1, '1998-01-01', 'In memory of Gordon Brown, 1927 - 1998.', 56, '800/888/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10653, '2002-08-25 22:00:00+00', '2021-02-06 13:02:18.716177+00', 'Mr Iain Stuart Robertson', 'MR IAIN STUART ROBERTSON', 1, 32, 9999, 1, 3, 42, 3168, NULL, '', 59, '840/880/888/888', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (10599, '2002-06-04 22:00:00+00', '2021-02-06 13:44:02.6871+00', 'Ali''s Jig', 'ALIS JIG', 2, 32, 9999, 1, 3, 42, 316, '1990-10-22', 'Devised for my eldest daughter Alison, born on 22nd October 1990', 50, '800  844  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (10543, '2002-05-02 22:00:00+00', '2021-02-07 10:59:12.029591+00', 'Dr Margaret Underwood''s Strathspey', 'DR MARGARET UNDERWOODS STRATHSPEY', 3, 32, 9999, 2, 3, 17, 9998, NULL, '', 92, '888/848/848/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10519, '2002-04-30 22:00:00+00', '2021-02-08 10:52:09.605339+00', 'Neko''s Reel', 'NEKOS REEL', 1, 32, 9999, 1, 4, 1, 520, NULL, 'This reel was written for Kimberley Osberg and her parents, kind friends in the Seattle area.  The name in the title is Japanese, and is pronounced nee-koh.', 53, '8000/8800/8800/4888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17970, '2017-09-25 20:51:55.969078+00', '2021-02-08 10:14:39.612289+00', 'Manderley Weasel', 'MANDERLEY WEASEL', 1, 32, NULL, 1, 3, 42, 10568, '2015-07-01', 'I saw a weasel while I was out walking the dog at Manderley. I had been preparing to teach a couple of dances with weasel reels so felt this was a sign I should write one of my own.', 70, '882/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10506, '2002-04-29 22:00:00+00', '2021-02-08 12:55:39.879965+00', 'Beauly in Bloom', 'BEAULY IN BLOOM', 1, 32, 9999, 1, 4, 2, 3111, '1997-01-01', 'Dance was devised by the late Frances Grant, dance teacher for the Kilmorack class for almost 3 decades and founding member of Glen Orrin Dancers, for Beauly Firth and Glens Trust, St. Andrews Night November 1997. After her death in May 2019, the original instructions for the dance were found by her sister Eleanor Gunn.



', 75, '8008/8888/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10435, '2002-03-26 23:00:00+00', '2021-02-09 09:34:39.742192+00', 'Jennie''s Strathspey', 'JENNIES STRATHSPEY', 3, 32, 9999, 2, 3, 17, 3086, NULL, 'For Jennie Cross on her retirement from teaching.



Jennie Cross was a founding committee member of the Royal Tunbridge Wells Branch. Until her retirement in 2001, she also organised Scottish Country Dance classes through the Women''s Institute in nearby Groombridge, ensuring a steady stream of recruits to the Branch.', 50, '800  804  840  808', 0, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (10406, '2002-08-06 22:00:00+00', '2021-02-09 12:15:24.561125+00', 'Last But One', 'LAST BUT ONE', 3, 32, 9999, 2, 3, 17, 534, NULL, 'As the name perhaps implies, short Strathspeys can be useful towards the end of a dance programme where 8 X 32s are definitely out of place.', 67, '880/888/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10195, '2002-07-21 22:00:00+00', '2021-02-10 14:22:40.578374+00', 'Lady in Red', 'LADY IN RED', 3, 32, 9999, 1, 3, 42, 2961, '2000-01-01', 'The Lady in Red is Muriel Johnstone', 50, '862/844/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9656, '2001-06-12 22:00:00+00', '2021-02-10 14:57:16.376548+00', 'Happy Couple, The', 'HAPPY COUPLE', 2, 40, 9999, 1, 3, 42, 2788, '1998-01-01', 'This dance was devised for the marriage of Sylvia Smith and Frank Malcolm. Sylvia has been a stalwart member of the Branch demonstration team for many years as well as being a highly respected teacher of both adults and children. The music was written for the dance by Freda Phillipson. The dance and the music were performed for the first time at a dance celebrating their wedding on 18th April 1998.', 45, '800/880/808/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10151, '2001-11-07 23:00:00+00', '2021-02-11 10:24:22.662689+00', 'Glasgow Anniversary Jig', 'GLASGOW ANNIVERSARY JIG', 2, 32, 9999, 1, 3, 42, 2938, NULL, '', 58, '662/844/866/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10111, '2001-10-04 22:00:00+00', '2021-02-12 11:01:27.302305+00', 'Mrs Clancy''s Strathspey', 'MRS CLANCYS STRATHSPEY', 3, 32, 9999, 1, 4, 2, 10450, '1996-07-31', 'For Mrs. Clancy''s 87th birthday, 31 July 1996.  Mrs Clancy danced this dance before being told its name!', 67, '8888/8220/8002/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10096, '2002-10-20 22:00:00+00', '2021-02-12 11:21:46.561776+00', 'Octopussy', 'OCTOPUSSY', 1, 32, 9999, 1, 4, 2, 108, '2000-01-01', 'Note 3:

Originally I wrote this dance as a reel but, when the dancers in

Nova Scotia tried out the dance, they thought that it went better as a

strathspey.

In view of this, I have left the choice of tempo to the performers.

lf the dance is danced as a medley, it could be done twice as a

strathspey and then twice as a reel. lf this is done, each couple will

dance once from an end position and once from a middle position in

each tempo.', 88, '6666/8888/6666/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10067, '2001-09-09 22:00:00+00', '2021-02-12 18:49:09.341109+00', 'Sapphire Wedding Anniversary Reel', 'SAPPHIRE WEDDING ANNIVERSARY REEL', 1, 32, 9999, 1, 3, 42, 127, NULL, '', 53, '800/888/880/488', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17959, '2017-09-25 19:15:53.77143+00', '2021-02-13 10:41:24.785246+00', 'Dance to the Music', 'DANCE TO THE MUSIC', 2, 32, NULL, 1, 3, 42, 10568, '2015-07-01', 'Celebrating TAC summer school in Virginia, USA. The first eight bars are taken from a Wes Clindinning tribute class.', 69, '880/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17960, '2017-09-25 19:17:51.853436+00', '2021-02-13 12:36:55.687385+00', 'Dog Stalker, The', 'DOG STALKER', 3, 32, NULL, 2, 3, 17, 10568, '2015-05-01', 'I wrote this for Joanne Turnbull after spending a few days with her. She has never met a dog that she did not like. Ever.', 62, '840/808/880/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10052, '2001-11-25 23:00:00+00', '2021-02-13 12:46:36.913422+00', 'Old Spedling Castle''s Ghost''s Dance, The', 'OLD SPEDLING CASTLES GHOSTS DANCE', 2, 32, 9999, 1, 3, 42, 479, '2000-01-01', 'The Old Spedling Castle´s Ghost´s Dance is a dance where the ''standing'' bottom man or top lady takes the part of the ghost to enter the dance. Thus, it is somehow a dance for 3 couples and a ghost in a 4 couple longwise set.



It was first tried at a dance workshop in 2000 led by Jim Rae at the Kuckucksnest (=cuckoo''s nest) in Schl&uuml;chtern, Germany. After a few more changes it was then published in his "A Dancing Tour Volume 2" in 2004.



The recording of the tune by Green Ginger named "<<http://my.strathspey.org/dd/recording/4971/|The Old Spedling Castle''s Ghost''s Dance>>" (also mentioned by Jim Rae in "A Dancing Tour Volume 2") is only four times through. Thus, this recording might not be well suitable, if one wants to perform the dance the full eight times through in one go.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14711, '2013-02-04 00:52:44.598501+00', '2021-02-14 17:14:07.542858+00', 'Scarborough Castle', 'SCARBOROUGH CASTLE', 3, 32, NULL, 1, 3, 42, 104, '2012-03-01', 'Devised for the 40th Scarborough weekend.', 62, '880  844  888  888', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (9890, '2001-05-30 22:00:00+00', '2021-02-15 11:19:39.223796+00', 'Rubies & Thistles', 'RUBIES AND THISTLES', 1, 40, 9999, 1, 4, 1, 1324, NULL, '', 66, '4884/8888/0880/8220/8446', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20223, '2021-02-21 15:37:34.086927+00', '2021-02-21 15:39:15.180609+00', 'Well Tuned Ear, A', 'WELL TUNED EAR', 1, 40, NULL, 1, 3, 42, 440, '2020-12-04', 'Devised for Don Bartlett, on the occasion of his new CD The Well Tuned Piano.', 42, '800/833/833/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20603, '2022-01-07 18:25:19.222193+00', '2022-01-07 18:25:19.222193+00', 'Some Flowers for You...', 'SOME FLOWERS FOR YOU', 1, 32, NULL, 1, 4, 5, 11514, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9881, '2001-06-04 22:00:00+00', '2021-02-15 18:23:50.366272+00', 'Proud Father, The', 'PROUD FATHER', 4, 32, 1, 1, 3, 42, 2894, NULL, 'According to strathspey list message 71683 it seems the original instructions for this dance are lost so the MiniCrib is the only source.



When contacted in early 2021, Gordon confirmed being the deviser of this dance, but he does not have any original instructions himself; it was so long ago that he can’t even remember how they went. The dances were never tried out at his local dance group', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (712, '1997-04-03 22:00:00+00', '2021-02-15 19:43:39.024464+00', 'Boriston Ness', 'BORISTON NESS', 2, 64, 9999, 1, 4, NULL, 9998, NULL, 'Originally SCDDB attributed this dance to <<ddp:Thurston, Hugh A#392>> but according to <<https://my.strathspey.org/dd/issue/2228/|issue 2228>> the deviser was reported as unknown in the original Thistle #16 article - although similar to Thurston''s <<ddd:Rosslyn Castle#5697>>. It was probably devised around 1962.



The tune was originally given as <<ddt:#2737>> but is now corrected to the similarly named, but apparently not identical, <<ddt:#9833>>.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10458, '2002-04-06 22:00:00+00', '2021-08-05 22:28:24.527012+00', 'Haggarty''s Brig', 'HAGGARTYS BRIG', 3, 32, 9999, 1, 4, 11, 1760, '2001-09-01', 'Devised in honor of my grandparents, Richard Haggarty and Christina Wallace Haggarty (my Nana) who between them served nearly 40 years on West Lothians’ County Council.  In their honour a new bridge was built between Stoneyburn and Addiwell, over the Briech Water where they used to meet while courting. The bridge is named Haggarty’s Brig.', 94, '8888/8888/4884/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9759, '2002-04-02 22:00:00+00', '2021-02-20 21:07:02.100586+00', 'Jackdaw, The', 'JACKDAW', 2, 32, 9999, 1, 4, 2, 104, '1995-11-01', 'Devised for Margaret Williams on the occasion of her special birthday!

(Margaret and David live in Jackdaw Close - hence the name)', 88, '8888/8008/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6355, '1997-09-14 22:00:00+00', '2021-02-17 16:28:00.05098+00', 'Strathtummel', 'STRATHTUMMEL', 4, 128, 9999, 4, 4, NULL, 392, NULL, 'For the full description refer to The Thistle No.18, published in April 1964 (check online link).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9850, '2002-05-06 22:00:00+00', '2021-02-18 11:05:30.3587+00', 'Double Diamond Rant, The', 'DOUBLE DIAMOND RANT', 1, 32, 9999, 1, 4, 1, 200, NULL, '', 69, '6666/6666/8888/8000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9851, '2002-11-13 23:00:00+00', '2021-02-18 11:14:22.707217+00', 'Dusk to Dawn', 'DUSK TO DAWN', 1, 32, 9999, 1, 3, 42, 1, '1999-01-01', 'Started in September 1990, the first ten years for Clynnog Thistle Scottish Dance Group covered the last decade (Dusk) of the 20th century and into the first (Dawn) of the 21st century.', 50, '800/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15460, '2014-06-09 16:13:23.111093+00', '2021-04-17 16:50:14.120157+00', 'London Celebration, A', 'LONDON CELEBRATION', 1, 32, NULL, 5, 2, 76, 104, '2012-04-10', 'Written to celebrate The Olympic Games London 2012. It was published in the London Branch magazine, "<<ddpub:Reel, The#73>>", <<https://www.rscdslondon.org.uk/wp-content/uploads/2013/09/120410Reel280.pdf#page=5|Issue 280>>.



Dance also found on the Chiswick video collection.



', 87, '88/88/44/88', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11204, '2003-02-16 23:00:00+00', '2021-02-19 16:31:46.328594+00', 'Mrs Litten''s Reel', 'MRS LITTENS REEL', 1, 32, 9999, 1, 2, 76, 3325, '1975-01-01', 'Mrs Litten was caretaker at Potten End Village Hall, where the Berkhamsted Strathspey & Reel Club has danced for many years: Mrs Litten was caretaker from July 1957 until her retirement in March 1975. This

dance was dedicated to her as a reminder of the happy association that the club enjoyed with her over those years. On her retirement this dance was presented in a frame to Mrs Litten by the Children’s Class, who then

danced it for her. The club ran a Children’s Class for many years in 1960s & 70s under the instruction of Colin Garrett, Rosemary Crawford and Stephen Webb.', 56, '80/88/84/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10668, '2002-07-21 22:00:00+00', '2021-02-19 17:23:04.881726+00', 'Deby''s Fiddle', 'DEBYS FIDDLE', 2, 32, 9999, 1, 3, 42, 2961, '1998-01-01', 'This dance is dedicated to fiddler and dancer Deby Benton Grosjean, an outstanding musician who occasionally plays for parties and balls for the San Francisco Branch. Deby is also West Coast Scottish Fiddle Champion and an instructor at Alasdair Fraser'' s Valley of the Moon Scottish Fiddling School', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20218, '2021-02-18 18:15:03.720227+00', '2021-04-19 10:21:40.698624+00', 'Whigmaleerie', 'WHIGMALEERIE', 2, 40, NULL, 1, 3, 42, 9998, NULL, 'This dance, not to be confused with <<ddd:Whigmaleeries#7090>> (plural) by <<ddp:Ivory, Derek#618>>, is of unknown origin. In an <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-302-Electronic.pdf#page=11|article in The Reel 302>> Mervyn Short asks if anyone has further information about it.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20219, '2021-02-19 19:27:08.652006+00', '2021-02-19 19:27:08.652006+00', 'Ring of Celebration', 'RING OF CELEBRATION', 1, 32, NULL, 7, NULL, 4, 270, '2012-01-01', 'Devised in celebration of the 2012 Olympic Games in London.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20225, '2021-02-21 16:03:50.784558+00', '2021-08-23 16:24:41.026342+00', 'My Friend Margo', 'MY FRIEND MARGO', 1, 32, NULL, 1, 3, 42, 440, '2020-05-04', 'Devised on May 4, 2020 in honour of my dear friend Margo Lewick.', 44, '404/404/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17720, '2017-04-30 09:49:23.489358+00', '2021-02-20 10:21:04.422456+00', 'Reel for London, A', 'REEL FOR LONDON', 1, 32, NULL, 5, 56, NULL, 3325, '2012-01-01', 'To commemorate the London 2012 Olympics



Bars 13-16 & 17-20 depict the Olympic Rings,  

Bars 1-4 & 21-24 depict the Olympic Flame.  

Most other figures are simple forward movements which are similar to the many forward actions occurring in races.  

Steps: Skip change-of-step is used throughout except for Bars 17-20 when slip step is used.', 100, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9787, '2001-03-13 23:00:00+00', '2021-02-20 20:17:37.738978+00', 'Knotwork', 'KNOTWORK', 2, 40, 9999, 1, 3, 42, 3179, '2001-01-01', 'The Pilling diagram in the 8th edition is in error, see the supplement to the 8th edition for the correct one.', 55, '844  888  800  844  888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (9755, '2000-12-17 23:00:00+00', '2021-02-20 21:11:18.959692+00', 'Bob''s Assembly', 'BOBS ASSEMBLY', 3, 32, 9999, 2, 3, 17, 1024, '1998-01-01', 'Devised by Jill Wing to honour Bob Taylor, a founder member of the Brockville Scottish Country Dancers, who celebrated his 60th birthday in April 1998 and retired from Dupont Canada at that time.', 75, '844/088/484/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20221, '2021-02-20 21:24:46.455978+00', '2021-02-20 21:28:50.731794+00', 'Witches Reel', 'WITCHES REEL', 1, 32, NULL, 1, 4, 1, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20222, '2021-02-20 21:35:07.421659+00', '2021-02-20 21:37:02.358638+00', 'Santa Claus is Coming To Town', 'SANTA CLAUS IS COMING TO TOWN', 1, 32, NULL, 7, 1, NULL, 11114, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11195, '2003-02-16 23:00:00+00', '2021-02-21 03:02:51.104293+00', 'Albert''s Welcome (to Potten End)', 'ALBERTS WELCOME TO POTTEN END', 2, 48, 9999, 4, 4, 13, 3325, '1987-01-01', 'The original name was "Albert''s Welcome to Potten End".  The deviser has since shortened the name to "Albert''s Welcome", but the old name will still often appear in records.



This dance is dedicated to Albert Williams who as President from 1985-1987, and with the support of his wife Molly, contributed much to the Berkhamsted Strathspey & Reel Club. The dance depicts friendship and social cheerfulness.', 83, '5111  8888  4444  12 12 12 12  6666  8888', 0, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (9710, '2000-11-13 23:00:00+00', '2021-02-21 10:52:37.541926+00', 'Barbara''s Celebration', 'BARBARAS CELEBRATION', 1, 32, 9999, 1, 3, 42, 447, '1991-01-01', 'Devised in celebration of retuming to Scottish Country Dancing after a cancer operation, by Barbara Rendle-Braime. Somerset West.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9875, '2001-06-04 22:00:00+00', '2023-02-05 18:08:14.622525+00', 'Miss Irene Whyte''s Strathspey', 'MISS IRENE WHYTES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2893, NULL, 'Published in the Diamond Jubilee Collection of the RSCDS Inverness and District Branch: http://my.strathspey.org/dd/publ/1027/', 56, '800/866/866/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11196, '2003-02-16 23:00:00+00', '2021-04-03 11:48:27.467582+00', 'Anniversary Medley', 'ANNIVERSARY MEDLEY', 4, 128, 2, 4, 4, 3, 3325, '1992-01-01', 'Anniversary Medley was formerly called Forty Years devised to commemorate the Fortieth Anniversary of the Berkhamsted Strathspey & Reel Club in 1992. 



The patterns in the dance reflect the starburst of a celebratory firework.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5325, '1997-09-11 22:00:00+00', '2021-04-19 11:03:29.0622+00', 'Port of Vancouver', 'PORT OF VANCOUVER', 3, 88, 9999, 1, 4, NULL, 1207, NULL, 'This was originally published in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-010-January-1963.pdf|The Thistle issue 10>> but was later corrected in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-012-March-1963.pdf|The Thistle issue 12>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20220, '2021-02-20 04:09:06.222936+00', '2021-04-19 19:35:21.138196+00', 'On the Other Side of the Mirror', 'ON THE OTHER SIDE OF THE MIRROR', 3, 48, NULL, 2, 3, 18, 44, '2019-04-27', '', 67, '800/888/844/800/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2413, '1997-09-03 22:00:00+00', '2021-02-26 18:49:58.232533+00', 'Gassy Jack''s Eightsome', 'GASSY JACKS EIGHTSOME', 4, 128, 2, 4, 4, 3, 50, '1965-01-01', 'The square formation should be wide for the strathspey. At the end of the Strathspey as the couples dance back to place, the size of the set should be reduced for the reel.



When Vancouver was just a small settlement at the mouth of the Fraser

River, it was known as Gastown - named after a well-known local

character, Gassy Jack Deighton. The Vancouver Branch Demonstration Team

first performed this dance for Miss Jean Milligan''s visit to Vancouver

in October, 1966. 

The dance was first published in Hugh Thurston''s Thistle (https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-037-October-1968.pdf#page=3|issue 37>>).', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19631, '2019-09-05 19:06:14.400443+00', '2021-02-21 19:51:47.62185+00', 'Red Squirrel Strathspey, The', 'RED SQUIRREL STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11035, NULL, 'The video, including the deviser, shows couples taking hands where possible during the reel though this is not  specified in the instructions.



The video is also named just The Red Squirrel though the instructions have The Red Squirrel Strathspey. The former is added as an alias.', 56, '888/800/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19138, '2019-01-08 15:22:23.50439+00', '2021-02-22 00:37:00.057098+00', 'Flowering Heather, The', 'FLOWERING HEATHER', 3, 32, NULL, 2, 3, 17, 11035, '2016-10-01', 'When teaching a Diamond Poussette to first year dancers, it is hard to find a dance that doesn’t have multiple foot changes to deal with. This is one of the more challenging formations for new dancers and, try as I might, the only dances that I could find that came close were “The Lammermuir Hills” and “The Walled Garden” (by that magic devisor Roy Goldring), but these two also had foot changes.  This straightforward dance was devised especially for our new dancers at the Lower Hutt Club to practice an all-round strathspey Poussette without having to deal with a foot change at all.  



Devised in October 2016, which is spring in New Zealand.  The end of the dancing season is approaching and our New Dancers are starting to try more difficult formations.  Earlier in the year, Damon and I had a trip to the UK and found ourselves in the Lammermuir Hills in Scotland walking through some “Flowering Heather” which was very beautiful.  A day to remember - so this dance is also a reminder of that very day. ', 65, '880/770/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20226, '2021-02-22 09:20:13.42522+00', '2021-02-22 13:40:51.004543+00', 'Anyu''s Birthday', 'ANYUS BIRTHDAY', 4, 128, 2, 104, 2, 76, 508, '2021-02-09', '“Anyu” is Hungarian for “mom,” and the dance was dedicated to Zsófia József’s mother on her birthday.  

First taught on Zoom on February 9, 2021 for the Bo’Ness class.  



"I was inspired by "Tea for Two" in the book "Always Enough to Dance." (Ellie Briscoe said)



Suitable recorded music: “Bon Viveur,” on Jim Lindsay’s RSCDS recording for Book 52.', 81, '66/66/84/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9557, '2001-04-02 22:00:00+00', '2021-02-22 11:38:38.058059+00', 'Winter Wooing', 'WINTER WOOING', 1, 32, 9999, 1, 3, 42, 2783, '1999-01-01', 'This dance is dedicated to Bruce Herbold and Patti Cobb on the occasion of their wedding.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18076, '2017-11-21 13:30:58.710839+00', '2021-02-23 12:11:48.826849+00', 'St Andrew''s Day', 'SAINT ANDREWS DAY', 2, 48, NULL, 1, 4, 1, 11537, '1949-01-01', 'This is the original version of this dance.  There is also an easier to dance version modified to 64 bars (<<https://my.strathspey.org/dd/dance/18023/|Dance 18023>>)



The original publication, Two National Dances of Scotland, describes this dance on the cover page, on the title page and on the dance description page as a Reel while the music, in the same publication and with the same title, composed by the dance deviser is in 6-8 time, i.e. a Jig.



This dance is discussed in RSCDS London Branch''s The Reel, 

(<<https://www.rscdslondon.org.uk/wp-content/uploads/2017/11/Reel-301-electronic.pdf|Issue 301>>  and <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-302-Electronic.pdf|Issue 302>>)', 54, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4141, '1997-09-08 22:00:00+00', '2021-03-08 15:58:57.85278+00', 'Maple Sugar Jig', 'MAPLE SUGAR JIG', 2, 32, 9999, 5, 2, NULL, 1098, '1976-08-01', 'Two women facing clockwise to two men in a circle round the room.



"Ann Sheppard was awarded the DANS (Dance Nova Scotia) Challenge Trophy for the best original mixer dance, Maple Sugar Jig, at the 21st Nova Scotia Dance Camp in August, 1976. A former member of the Fredericton Scottish Country Dance Group, she now lives in Australia."', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13380, '2009-11-05 23:00:00+00', '2021-03-02 12:28:39.468931+00', 'MacDonald of the Eastern Isles', 'MACDONALD OF THE EASTERN ISLES', 3, 32, NULL, 2, 3, 17, 10357, '2003-05-20', 'Dedicated to Masako (Marchan) and Yukio Naitoh, the co-founder and the leader of the Tokyo Scottish

Bluebell Club, who are also recognized as members of MacDonald Family.  

The dance and tune are devised to celebrate the 20th anniversary of the Tokyo Scottish Bluebell Club

held on 31st May 2003.', 56, '808/808/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20274, '2021-03-13 21:59:31.662586+00', '2021-03-13 21:59:31.662586+00', 'Buoys and Gulls', 'BUOYS AND GULLS', 3, 32, NULL, 1, 4, 2, 2887, '2020-08-01', '"Inspiration for the title was recalling seaGULLS landing on or near BUOYS in a harbour. Any similarity to BOYS and GIRLS is, of course, purely co-incidental."



Dance specifically devised with adapted figures to maintain 2m distance from other dancers.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9536, '2002-02-26 23:00:00+00', '2021-04-05 20:33:39.018632+00', 'Teviot Square', 'TEVIOT SQUARE', 2, 48, 9999, 4, 4, 46, 550, '2000-01-01', '', 64, '8888  8080  4141  7171  4444  8888', 1, 1, 1, 1, 63);
INSERT INTO 'dance' VALUES (20604, '2022-01-07 18:27:47.838226+00', '2022-01-07 18:27:47.838226+00', 'Summer-Night Ball, A', 'SUMMERNIGHT BALL', 3, 32, NULL, 1, 4, 1, 11514, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3030, '1997-04-03 22:00:00+00', '2022-12-26 20:34:20.511035+00', 'Huntly Reel, The', 'HUNTLY REEL', 4, 80, 10051, 1, 98, NULL, 9998, NULL, 'Collected from John Gordon of Truro, Nova Scotia, Canada. This dance was a favourite in Aberdeenshire during the 17th century, and later revived in Canada.



It was originally entered, incorrectly, in the database as The Huntley Reel. This is kept as a (mis)spelling alias.  

  

First published by Mary Isdale MacNab/Elizabeth Sutorius in a leaflet in 1961.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20227, '2021-02-22 19:05:55.639995+00', '2022-12-26 18:53:47.419727+00', 'Anniversary Twostep', 'ANNIVERSARY TWOSTEP', 1, 16, NULL, 7, 113, 4, 12245, '1851-01-01', 'Ceilidh dance. Two circles, men facing out, women facing in.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3948, '1997-04-05 22:00:00+00', '2021-06-11 15:39:08.076637+00', 'Lord of the Isles', 'LORD OF THE ISLES', 3, 0, 9999, 1, 4, NULL, 9998, NULL, 'There is some doubt (see <<https://my.strathspey.org/dd/issue/2293/|issue 2293>>) that this dance was actually collected by <<ddp:MacNab, Mary Isdale#242>>. It was added in the original version of SCDDB and linked to the set of her dances but does not actually appear there so may be a mistaken entry.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8919, '1999-01-05 23:00:00+00', '2021-02-23 01:01:01.171285+00', 'Merry Christmas', 'MERRY CHRISTMAS', 2, 32, 9999, 1, 4, 1, 440, '1994-12-14', 'Devised on December 14, 1994, the day of the St. Andrew''s Christmas dance.', 56, '8440/8044/8888/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8912, '1999-01-05 23:00:00+00', '2021-02-26 08:47:41.835526+00', 'Salute to Robert Burns', 'SALUTE TO ROBERT BURNS', 1, 32, 9999, 1, 4, 1, 440, '1995-01-01', 'Devised on January 18, 1995.  



This dance tells a story about Robert Burns, well known for his interest in the opposite sex.  



In the first eight bars he sees a young lady making her way to the same social function (a Scottish country dance function of course) to which he is going. In the next eight bars he mingles with the other guests, keeping an eye on the young lady. In the third figure he gets an introduction, and in the final figure they dance together. ', 63, '8000/8888/8888/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2617, '1997-09-03 22:00:00+00', '2021-02-26 10:09:25.320651+00', 'Goulden''s Farewell To California', 'GOULDENS FAREWELL TO CALIFORNIA', 2, 48, 9999, 1, 3, 42, 793, '1981-01-01', 'Publisher''s note:  

This dance was presented at Asilomar Weekend, 1981. The Gouldens, who met dancing twenty plus years ago, postponed their departure for France so that they might attend the Asilomar conference one last time. Thanks to Eugene Bissell for writing up the dance and contributing it to this collection. The editor altered the wording from "woman" to "lady" for consistency within the collection only.', 58, '800/844/844/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9469, '2001-12-17 23:00:00+00', '2021-02-23 20:46:42.581444+00', 'Didgeridoos of Dunvegan, The', 'DIDGERIDOOS OF DUNVEGAN', 2, 40, 9999, 1, 3, 42, 108, '1999-08-01', '"for all who pipe McLeod and clear!"



The Doonooch Aboriginal Dancers from Australia came to the Aberdeen International Youth Festival. Seven of the ten dancers were McLeods. The report in the local press was headed "Folk Group is McLeod and Clear"!', 60, '880/888/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1211, '1997-08-31 22:00:00+00', '2021-02-26 18:21:15.560279+00', 'Circassian Mixer', 'CIRCASSIAN MIXER', 3, 16, 9999, 1, 2, 76, 779, NULL, 'A description of this dance appears in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-032-May-1967.pdf#page=3|issue 32 of The Thistle magazine>> where it is described as a medley.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8915, '1999-01-05 23:00:00+00', '2021-02-24 13:26:38.909249+00', 'Callum Ross Campbell', 'CALLUM ROSS CAMPBELL', 1, 32, 9999, 1, 4, 1, 440, '1996-01-01', 'Devised on April 7, 1996, to welcome the arrival of Callum Ross Campbell, first child of Gary and Donna Campbell, members of the St. Andrew''s of Brampton Scottish Country Dance group.', 81, '8484/8888/8484/8484', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9407, '2001-06-12 22:00:00+00', '2021-02-24 19:42:36.066648+00', 'Brian''s Bairns', 'BRIANS BAIRNS', 2, 32, 9999, 4, 4, 1, 2741, '1999-01-01', 'From the original description:



> As part of Edinburgh Branch''s 75th Anniversary celebrations the chairman, Brian Harry,

> held a reception for members in the Royal College of Physicians.

> 

> Two teams of children from Branch classes gave a demonstration which included this dance,

> specially written for the occasion by Isobel Cook.



This dance is a Jig.  It is correctly described on the contents page of the Five Anniversary Dances booklet and the music is in 6-8 time.  The description with the instructions is wrong and should say "A Jig for 4 couples in a square set".', 69, '4444/4444/6666/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20229, '2021-02-23 01:24:16.899969+00', '2021-02-25 00:16:05.547575+00', 'Aloha ''Oe', 'ALOHA OE', 3, 32, NULL, 1, 3, 42, 12021, NULL, '', 56, '822/822/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8910, '1999-01-05 23:00:00+00', '2021-02-26 00:20:57.548989+00', 'Den Mother, The', 'DEN MOTHER', 3, 80, 9999, 4, 4, 3, 440, '1996-01-01', 'Devised in honour of the 80th birthday of Mrs Marjorie Coulter, founder of St. Andrew''s of Brampton, and affectionately known as the den mother. ', 79, '8888/4000/8000/8404/8888/8888/8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20262, '2021-03-12 15:53:18.739324+00', '2021-03-12 15:53:18.739324+00', 'Highland Cathedral', 'HIGHLAND CATHEDRAL', 3, 80, NULL, 107, 8, NULL, 635, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9388, '2000-05-11 22:00:00+00', '2021-02-26 00:50:35.227429+00', 'Northern Harmony', 'NORTHERN HARMONY', 2, 32, 9999, 1, 3, 42, 2723, '1983-01-01', 'Comment by deviser Gregor Trinkaus-Randall on Scottish Country Dance teachers Facebook page, July 2018



Please note that during bars 5-12 in Northern Harmony in Celebrating Fifty Years, couples 2 & 3 are doing rights and lefts while the first couple does their track. This was only recently caught by me, the author, because I never taught it from that book. Please put in an errata slip.  



Gregor Trinkaus-Randall started dancing in Boston in 1974. While living in Wisconsin, he and his wife, Vickery, founded the Madison group, which is now an affiliated group of the RSCDS. Gregor is a Boston Branch teacher and has danced wifh the Demonstration Team and the New Caledonians performing group. Tom Pixton chose the title tune from among his own compositions.', 63, '844/866/866/888', 0, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (4529, '1998-12-17 23:00:00+00', '2021-03-16 23:18:58.881533+00', 'Miss Kirsty Campbell', 'MISS KIRSTY CAMPBELL', 2, 32, 9999, 1, 3, 42, 440, '1993-09-25', '', 56, '844/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15778, '2015-01-11 15:44:38.418716+00', '2021-03-12 16:43:38.520224+00', 'First of August, The', 'FIRST OF AUGUST', 7, 136, 9999, NULL, 51, NULL, 12024, NULL, 'This Hebridean Step-dance was devised by Ewen MacLachlan (1799-1879) in 19th century. (It was not Jack McConachie although he did publish it with other dances.)



The possibly best description of the dance is to be found in Traditional Step-Dancing in Scotland by JF&TM Flett (1996) on pp102-108.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20270, '2021-03-12 16:44:39.465011+00', '2021-03-12 16:44:39.465011+00', 'Wheels and Legs', 'WHEELS AND LEGS', 1, 32, NULL, 1, 3, 42, 635, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20271, '2021-03-12 16:46:16.389214+00', '2021-03-12 16:46:16.389214+00', 'Wheels in Samara', 'WHEELS IN SAMARA', 1, 40, NULL, 1, 4, NULL, 635, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20272, '2021-03-12 16:47:30.193869+00', '2021-03-12 16:47:30.193869+00', 'Who follows in Samara?', 'WHO FOLLOWS IN SAMARA', 1, 32, NULL, 1, 4, NULL, 635, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19063, '2018-12-03 16:03:09.271538+00', '2021-03-13 20:15:17.248972+00', '90 Years On', '90 YEARS ON', 3, 40, NULL, 1, 4, 1, 11753, '2016-01-01', 'This dance was devised to celebrate the achievements of dancers in Dunfermline over nine decades. The transition from a longwise set to a square set was inspired by the dance Autumn in Appin from RSCDS Book 31, which celebrated the Society''s 60th Anniversary.', 80, '8440/8880/8844/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (677, '1997-04-03 22:00:00+00', '2022-06-26 21:41:57.297996+00', 'Bonnie Wee Glen', 'BONNIE WEE GLEN', 2, 32, 9999, 5, 2, 76, 392, NULL, 'Attributed to Hugh Thurston, but in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-039-February-1969.pdf#page=4|issue 39 of The Thistle>> it is given as "by John Geddes".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (823, '1997-04-03 22:00:00+00', '2022-12-22 17:28:41.296256+00', 'Broadswords of Lochiel, The', 'BROADSWORDS OF LOCHIEL', 7, 80, 9999, 1, 98, NULL, 9998, NULL, 'This is a regimental dance, collected in Prince Edward Island, Canada. Published by Elizabeth Sutorius in 1961.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7548, '1999-12-21 23:00:00+00', '2021-02-26 19:20:05.078455+00', 'Highland Schottische', 'HIGHLAND SCHOTTISCHE', 3, 8, 9999, 5, 1, 54, 9998, NULL, 'Ceilidh dance.  Source: collected by Mary Stoker.



More information: see URL page for this dance.



Another article about this dance appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-053-October-1972.pdf#page=2|issue 53 of The Thistle magazine>>.', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4317, '1997-09-09 22:00:00+00', '2021-02-26 19:22:30.854026+00', 'Merrick, The', 'MERRICK', 4, 128, 2, 4, 2, 3, 392, NULL, 'Diamond set: 1M (above) faces 2M on midline; 2W on M side, 1W on W side.

This is a 2C demonstration dance.

It was devised as an informal tribute to Hugh Foss.', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4738, '1997-09-10 22:00:00+00', '2021-02-26 22:43:11.920564+00', 'Mrs Bingham''s Fancy', 'MRS BINGHAMS FANCY', 1, 32, 9999, 1, 3, 42, 1158, NULL, 'This country-dance was composed by Beryl MacMillan in honour of Mrs. Thomas Bingham. (Mrs. Bingham introduced R.S.C.D.-type country-dancing to the Vancouver area some forty years ago now, and was an active teacher until quite recently). The music was specially composed by Bob MacMillan: the tunes are "Mrs. Bingham‘s Fancy", “Ceperley Park", ”Harwood House" and "Lady Aberdeen". The titles will have pleasant associations for all VAncouver dancers. If any reader would like the original music, we will pass requests

on to Bob. Those who use gramophone records can substitute band 5 of side 2 of Dominion LP 1255 ("Scottish Country Dances" by the Dunedin Scottish dance band).', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20233, '2021-02-28 23:55:51.381172+00', '2021-03-01 01:05:26.030745+00', 'Ashbourne Woods', 'ASHBOURNE WOODS', 3, 32, NULL, 2, 3, 17, 12021, NULL, 'Ashbourne is the name of a property in Chenequa near my hometown. The property has a sign by their long wooded drive, but the hills block the view of the actual house. When I was young, I liked to imagine what lay beyond Ashbourne woods. In the dance, I imagine kids hiding and playing in the woods, sweeping around the trees and going through the woods hand-in-hand. I like how the active dancers share touching moments with each other, but also with the "trees."', 63, '800/866/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20232, '2021-02-28 20:23:59.082886+00', '2021-02-28 20:23:59.082886+00', 'Sound of Harris Ferry, The', 'SOUND OF HARRIS FERRY', 1, 32, NULL, 104, 2, 76, 10912, '2021-02-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16630, '2015-08-27 13:47:37.665817+00', '2021-02-27 12:58:31.172565+00', 'Wheeling in the Wind', 'WHEELING IN THE WIND', 2, 32, NULL, 1, 3, 42, 3703, NULL, 'Devised by Pam Stephens, inspired while watching the sea birds continually swirling and turning in the wind above the ocean waves.', 56, '808/888/282/668', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9162, '2002-04-08 22:00:00+00', '2021-02-28 09:38:57.627031+00', 'No Mean Feet', 'NO MEAN FEET', 4, 32, 1, 1, 3, 42, 2677, NULL, '"Dedicated to Maureen Vivino, longtime renegade and leader of the Ithaca Scottish Country Dancers; an all round good dancer, great friend, and noted vegetarian. The name of the dance came up during an after-dance get together and, to me, is suggestive of the ability and the attitude that she brings to her own dancing and the spirit she inspires in others. The dance was inspired by her cast off in tandem modification, for a demo, to a Strathspey That Shall Remain Nameless."

', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20182, '2020-12-07 23:16:15.406523+00', '2021-03-01 15:46:27.090363+00', 'Friday Night Musician, The', 'FRIDAY NIGHT MUSICIAN', 1, 32, NULL, 1, 3, 42, 440, '2010-06-08', 'Devised by Ann Campbell on June 8, 2010 for Gordon Hamilton who was in charge of the music for his wife Jean''s Friday evening class.', 50, '880/880/808/808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10281, '2001-11-29 23:00:00+00', '2021-03-01 22:14:50.724244+00', 'Owen''s Ramble', 'OWENS RAMBLE', 3, 32, 9999, 1, 4, 1, 2969, NULL, 'Devised by Ron Hankes shortly after the occasion of his grandson Owen''s first steps, to depict Owen''s ramble about the house with a tired grandfather close be­hind.', 91, '8888/8888/8444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20236, '2021-03-01 22:52:52.279405+00', '2021-03-01 23:12:04.232954+00', 'Dancing Bonnie', 'DANCING BONNIE', 4, 80, 4, 1, 3, 42, 2497, NULL, 'Devised for the anniversary of Bonnie Aguilar''s 50 years of dancing.', 69, '888/880/088/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20235, '2021-03-01 21:13:53.395876+00', '2021-03-01 23:45:47.21813+00', 'Applecross Strathspey', 'APPLECROSS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10621, '2013-08-01', 'To celebrate the Golden Wedding of Alastair and Carol Cuthbertson, Berkhamsted August 2013', 44, '800/888/800/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20237, '2021-03-02 09:44:16.44011+00', '2021-03-02 09:58:19.883253+00', 'Maid of the Isles', 'MAID OF THE ISLES', 3, 40, NULL, 1, 3, 42, 11360, NULL, 'Dance devised by Sheila Karolak and named for her Shetland Sheepdog, Isla, Maid of the Isles.', 75, '880/800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12406, '2005-05-01 22:00:00+00', '2021-03-02 10:23:12.821394+00', 'Charlie''s Calling', 'CHARLIES CALLING', 2, 32, 9999, 4, 4, NULL, 3598, '2005-01-01', 'This dance was first danced at the Harpenden Ball in 2005 and was written as a tribute to her late father Charlie Miller.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20266, '2021-03-12 16:35:00.560978+00', '2021-03-12 17:58:52.500383+00', 'Trip to Moscow, A', 'TRIP TO MOSCOW', 3, 32, NULL, 103, 2, 76, 635, '2008-01-01', 'Bars 9-16 were inspired by Anna Holden’s Strathspey – RSCDS Book 42.  



The dance was written for the first Moscow branch weekend school in 2008 – Irene Bennett was the other teacher, with Ken Martlew and Barbara Manning as the musicians.  



I wanted to teach a dance that included the Tourbillon, a formation that I really like, and this was the result.  



Pat Clark composed a tune for the dance, titled “September in Moscow”.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20234, '2021-03-01 12:23:40.170097+00', '2022-12-22 18:27:21.10995+00', 'Kerfuffle', 'KERFUFFLE', 1, 40, NULL, 6, 3, 18, 725, '2018-01-01', '', 87, '800/888/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2317, '2002-04-28 22:00:00+00', '2023-01-27 19:40:03.392665+00', 'Foursome Reel', 'FOURSOME REEL', 4, 64, 5, 107, 2, NULL, 9998, NULL, 'The number of bars is fairly arbitrary, except that (a) the reel should be repeated the same number of times as the strathspey, and (b) the total number of times should be a multiple of two so that dancers will finish in original places, with own partners.



An article about the Foursome Reel appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-055-February-1973.pdf#page=2|issue 55 of The Thistle magazine>>.', 100, '88  88  88  88', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (2360, '1998-11-28 23:00:00+00', '2021-03-02 20:51:00.332726+00', 'Fugal Fergus', 'FUGAL FERGUS', 2, 48, 9999, 1, 3, 42, 129, '1963-01-01', 'Fugue. Men dance 8 bars behind the ladies.

This is the only dance described in <<ddpub:#406|Roll Back the Carpet>>, a delightful and interesting book that analyses a large variety of possible SCD figures. It is in the section "Counterpoint" which was first published in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-075-October-November-1963.pdf#page=4|issue 75>> of The Reel magazine.



See also <<ddd:Waverley>>.



Anselm Lingnau writes: "While we''re on the subject of Fugal Fergus, it''s probably worth mentioning that it is a derivative of the dance Waverley (or Fergus McIver) from RSCDS Book 15. The chases from the original are fairly evident in Foss''s adaptation, as is the setting and crossing (even though in Fugal Fergus it goes across the dance, while in Waverley it goes up and down).  Waverley also features the poussette and double triangles, which Fugal Fergus does not.  Fugal Fergus is dance #1 in Hugh Foss''s book The Waverley Fugues, which contains 12 "fugal" dances of increasing complexity, and it is the only one in the book based on an existing dance.  As an exercise in devising dances, The Waverley Fugues remains unsurpassed, and  it offers many interesting challenges for advanced dancers.  My personal favourites are Rob Roy (#6) and Dugald Dalgetty (#9)...."

', 60, '888/888/888/888/884/000', 1, 1, 1, 0, 80);
INSERT INTO 'dance' VALUES (13705, '2011-07-04 22:00:00+00', '2021-03-03 16:32:13.336289+00', 'Passing the Torch', 'PASSING THE TORCH', 2, 32, NULL, 1, 100, 2, 479, '2007-01-01', 'Devised: 2007



This dance was devised by Jim Rae and is dedicated to Masako (Marchan) Okada Naitoh to celebrate

her receiving the Royal Scottish Country Dance Society''s Scroll ofHonour in 2007. The title reflects the

many years that Marchan has devoted passed on the tradition of, and love for, Scottish country dancing

that was passed to her by DrJean Milligan so many years ago', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20242, '2021-03-04 11:11:15.287532+00', '2021-03-05 19:14:30.408773+00', 'Dancing Kelpie, The', 'DANCING KELPIE', 1, 40, NULL, 1, 3, 42, 10959, '2014-10-01', 'For Teresa Lockhart:  

Kelpies lurk on the shores of Scottish lochs, waiting for a victim who they then capture & take to their

watery home & are reputed to devour. Teresa, like a Kelpie, is a shape shifter, taking on many tasks within

SCD, including inviting the unwary into the dance.  



_Recommended Music_: Anstruther Lassies CD: Memories of Fife', 66, '800/833/844/833/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20241, '2021-03-03 23:52:57.030744+00', '2021-03-04 00:18:42.94714+00', 'Green Road, The', 'GREEN ROAD', 3, 32, NULL, 2, 3, 18, 10959, '2020-06-01', 'The Green Road is the remains of an older road, running through the crofts and townships of South

Harris. In 1940 the new road was built around the east coast and the old one fell into disuse. The road is

green as it is covered with green turf and moss. The sheep keep the grass cropped short. As children

we thought it a very mysterious and interesting road which led over the hills. In actuality it was the way

our father and his siblings would have travelled in the 1920s on their way to Rodel to catch the boat to

school and university on the mainland.  



_Recommended music_: 3x32 version of Calum’s Road or use Colin Dewar: Ruthven collection: Calum’s Road. Strathspey (4x32)', 83, '880/888/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20249, '2021-03-04 12:20:31.533633+00', '2021-03-04 12:20:31.533633+00', 'July The Twenty-Fourth (1970)', 'JULY THE TWENTYFOURTH 1970', 2, 40, NULL, 3, 5, NULL, 10959, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20243, '2021-03-04 11:14:04.779236+00', '2021-03-06 16:43:05.158329+00', 'Dun Haakon', 'DUN HAAKON', 2, 40, NULL, 1, 3, 42, 10959, '2017-10-01', 'Dun Haakon or Castle Moil is a ruined castle located near Kyleakin on the Island of Skye.  

Built by the Vikings before the 10th century, while the western Isles was a Viking Kingdom.  

Subsequently owned by Clan MacKinnon, who rebuilt it as a Tower House in the 15th century.  

According to local tradition, The castle had a chain or thick rope, across the narrow Kyle Akin and collected tolls from passing ships. Their alternative was to sail around the Island of Skye through the dangerous waters of the Minch.', 50, '800/633/888/633/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9051, '2002-10-28 23:00:00+00', '2021-03-06 12:20:13.484843+00', 'Kinning Park', 'KINNING PARK', 2, 48, 9999, 1, 3, 42, 1415, NULL, '', 54, '800/888/633/888/633/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9026, '1999-04-24 22:00:00+00', '2021-03-06 12:55:15.000044+00', 'J.A.G.''s Welcome to Torremolinos', 'JAGS WELCOME TO TORREMOLINOS', 2, 32, 9999, 1, 3, 42, 2600, '1999-01-01', 'For Janette, Alice and George, whose hard work and organisation has meant the continuation of our happy dancing holidays at Torremolinos, January 1999.', 56, '844/888/844/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20244, '2021-03-04 11:16:06.316612+00', '2021-03-07 10:11:11.820956+00', 'Taransay', 'TARANSAY', 3, 40, NULL, 2, 3, 17, 10959, '2011-01-01', 'Taransay: is an island off the west coast of the Island of Harris in the Outer Hebrides. Nothing between

it and the Americas but the rolling Atlantic. My grandmother’s parents, on both sides of her family,

came from Taransay. They relocated to Harris and Lewis in the 1830s.  



_Music_: Mike Briggs - Crossing to the Mainland or alternative CD We Twa: track #9 “Ian & Joan MacKenzie''s Strathspey”', 55, '840/822/888/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9025, '2002-01-06 23:00:00+00', '2021-03-06 21:47:50.843101+00', 'Irene''s Strathspey', 'IRENES STRATHSPEY', 3, 32, 9999, 2, 3, 17, 2600, NULL, '', 67, '840/880/888/804', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20250, '2021-03-07 13:12:22.041067+00', '2021-03-07 14:52:01.460321+00', 'Denise Babin, M.D.', 'DENISE BABIN MD', 1, 32, NULL, 1, 3, 42, 2497, '2010-01-01', 'Devised by John McCormick on the occasion of member Denise''s graduation from medical school, 2010.', 69, '888/880/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20251, '2021-03-07 15:26:05.347412+00', '2021-03-07 15:26:05.347412+00', 'Waddin Birl for Dan and Lindsay', 'WADDIN BIRL FOR DAN AND LINDSAY', 3, 96, NULL, 2, 3, 3, 12022, '2011-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20084, '2020-09-24 08:49:59.267013+00', '2021-03-07 16:58:50.798715+00', 'Darlington Dancer, The', 'DARLINGTON DANCER', 4, 160, 10, 1, 100, 99, 884, '2020-03-13', 'Devised to celebrate a significant birthday for Pat Stevenson, 13 March 2020. Although Pat has lived in Western Australia for a long time she is originally from Darlington in northern England''s County Durham.', 82, '8008/8448/8888/8668/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20252, '2021-03-07 17:08:31.645347+00', '2021-03-07 17:16:02.75513+00', 'St. Andrew Salute', 'SAINT ANDREW SALUTE', 2, 32, NULL, 2, 3, 17, 12023, '2011-01-01', 'Devised as a demonstration on the occasion of the 2011 St. Andrew Society Robert Burns dinner when only six persons were available to dance. ', 85, '888/886/844/848', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5573, '2000-04-25 22:00:00+00', '2021-03-09 16:26:15.979285+00', 'Riffle Volunteers', 'RIFFLE VOLUNTEERS', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'Dance collected by Jean C Milligan. Originally entered in SCDDB as "The Rifle Volunteers", but the correct title is apparently "Riffle Volunteers" (see <<https://my.strathspey.org/dd/issue/2339/|issue 2339>>). The former title is kept as a (mis)spelling alias.', 31, '440/800/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3738, '2000-04-25 22:00:00+00', '2021-03-09 16:55:37.945656+00', 'Lassies of Moffat', 'LASSIES OF MOFFAT', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 41, '800/800/844/668', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20246, '2021-03-04 12:13:33.481775+00', '2021-06-30 13:45:04.256686+00', 'Kindred Spirit, A', 'KINDRED SPIRIT', 1, 32, NULL, 1, 3, 42, 10959, '2019-10-31', 'For Teresa Lockhart and the other followers of “Anne”, in celebration marking the Scottish Country Dancers who danced in the series Anne With An “E”.', 59, '822/888/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19076, '2018-12-06 12:24:48.030635+00', '2021-03-13 20:30:12.373027+00', 'Louise Carnegie Gates, The', 'LOUISE CARNEGIE GATES', 1, 32, NULL, 1, 3, 42, 10882, '2010-01-01', 'The Louise Carnegie Gates adorn the entrance to Pittencrieff Park at the junction of Chalmers Street and Bridge Street. They were named for the wife of Andrew Carnegie, who purchased Pittencrieff Park and donated it to the people of Dunfermline in 1903. Described at the ceremony as "a magnificent entrance to an equally magnificent pleasure-ground", the Gates were formally opened on 28th June 1929, three days after the formation meeting of the Fife Branch.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8857, '2002-11-03 23:00:00+00', '2021-03-09 23:13:06.573512+00', 'Phyllis Dixon Ivory', 'PHYLLIS DIXON IVORY', 3, 32, 9999, 1, 3, 42, 51, '1998-06-01', 'This dance is dedicated to San Francisco fiddler Kim McGarrity, who passed away in July 1998. She was sometimes known as Phyllis Dixon Ivory (her band was named Fiddlesticks and Ivory). 

Being devised June 1998, the dance description was revised December 1998.



Here are the official instructions, downloaded from http://home.roadrunner.com/~glasshall/dances.html



Bars



1-8 1st couple turn with the right hand once around, cast one place (2nd

couple stepping up). Turn with the left hand once around and cast

to the left (Man down, Woman up) to finish between the 2nd and 3rd

couples, 3-and-3 across.



9-12 All Set and Link for 3, to finish 2-1-3, corners on opposite sides.



13-16 2nd Man and 3rd Woman (on 2nd Corner diagonal) changes places

with the right hand and cast into 2nd place on their own side, 1st

Couple stepping (Man down, Woman up) into the vacated place

beside them.



17-20 2nd Woman and 3rd Man (on 1st corner diagonal) change places with

the left hand and cast into 2nd place on their own side, 2nd Man

stepping up and 3rd Woman stepping down into the vacated place

beside them.



21-24 1st Couple (on the 2nd Corner diagonal) change places with the right

hand and cast into 2nd place on their partner''s side, 2nd Woman

stepping up and 3rd Man stepping down into the vacated place

beside them.



25-28 1st Couple half-turn and twirl (as in Bars 5-8, Argyll Strathspey,

RSCDS Book 35).



29-32 All dance back-to-back.



Repeat, having passed a couple.', 39, '800/466/422/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8858, '2002-03-04 23:00:00+00', '2021-03-09 23:16:10.817229+00', 'Dancing Master of Moncton, The', 'DANCING MASTER OF MONCTON', 3, 32, 9999, 2, 3, 18, 51, '1998-07-01', 'This dance is for Bill Libby, the dancing master of Moncton, New Brunswick, whose legacy is happy and bountiful dancing in the Maritimes of Canada.', 63, '844/888/888/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20230, '2021-02-27 10:14:42.865597+00', '2021-03-09 23:22:54.368566+00', 'Emily''s Wedding', 'EMILYS WEDDING', 2, 32, NULL, 1, 3, 42, 10621, '2013-01-01', 'Emily Aird was a friend of Stuart’s sister Fiona. After Emily’s actual wedding she became Emily McKay. This dance was written for and danced at the reception by all guests after much rehearsing beforehand.', 44, '800/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2681, '1997-04-03 22:00:00+00', '2021-03-10 17:32:29.820456+00', 'Gregorach Reel, The', 'GREGORACH REEL', 1, 40, 9999, 1, 3, 42, 185, '1990-01-01', 'This dance was devised to celebrate Norman Bett’s 60th Birthday in June 1990, and is named after the Gregorach Band which he led some years before and which mainly consisted of members of his family.  



The various sections of the dance show:  

1-8     Norman organising the band.  

9-16 The accordion - movement of the right hand on the keyboard followed by the  movement of the bellows.  

17-24 The violin - the diagonal lines represent the bow - 1st couple must pass left shoulders between reels to form the straight line of the bow.  

25-32 Norman conducts the band (1st couple) while the dancers (2nd & 3rd couples) dance around the room.', 60, '880/888/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20253, '2021-03-09 23:42:50.754482+00', '2021-03-09 23:46:15.641448+00', 'Flying Scot, The', 'FLYING SCOT', 1, 32, NULL, 1, 4, 1, 207, NULL, 'Adapted from <<https://my.strathspey.org/dd/dance/2260/#cribs|The Flying Scotsman>> by Hugh Thurston.', 53, '4444/4444/8000/4888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9021, '1999-04-24 22:00:00+00', '2021-03-10 10:02:32.495506+00', '75 Years Young', '75 YEARS YOUNG', 2, 32, 9999, 1, 4, 2, 2599, NULL, 'The instructions in Friendship Dances have 8 bars for the intersecting reels of four and 8 bars for dancing up/down and casting.  The e-crib and diagram phrase this as 12 bars and 4 bars.  



Written for 75th Anniversary of RSCDS at St Andrews Summer School 1998.', 78, '8008/8448/8888/8668', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (587, '1997-04-03 22:00:00+00', '2021-03-10 10:52:40.236543+00', 'Bluebell Reel, The', 'BLUEBELL REEL', 1, 32, NULL, 1, 3, 42, 35, '1993-01-01', 'Devised: 1993.



Originally published with the title spelled as "Blue Bell", the republication by the <<ddp:Tokyo Scottish Bluebell club#10489>> in their <<ddpub:#1035|anniversary book>> uses "Bluebell". So that has been changed to be the main name of the dance with the "Blue Bell" version as official alias.', 56, '844/844/844/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6666, '1998-11-17 23:00:00+00', '2021-03-10 12:02:29.998362+00', 'Tourists in Cambridge', 'TOURISTS IN CAMBRIDGE', 2, 32, 9999, 3, 5, 16, 2434, NULL, '_Story_: the dance is intended to represent various aspects of Cambridge:  

1-8   King’s College and the Backs  

9-16  Punting the Backs  

17-24 St Catherine’s College  

25-28 The Bridges  

29-32 Mill Pond Whirlpool', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7227, '2002-03-03 23:00:00+00', '2021-03-11 14:01:08.741+00', 'Woodland Assembly', 'WOODLAND ASSEMBLY', 2, 64, 9999, 4, 4, 54, 313, NULL, 'Repeat bars 1-64 with 2C and 4C dancing bars 9 - 28. 2C face 3M to begin the reel. 4C face 1M.



This is Priddey''s simplified version of his own »<<ddd:#2135|Fete Champêtre>>«, a demonstration dance.', 91, '8888  8080  8888  8484  8888  8888  8888  8888', 1, 1, 0, 1, 90);
INSERT INTO 'dance' VALUES (20260, '2021-03-12 15:44:19.459483+00', '2021-03-12 15:44:19.459483+00', 'Decade in Perm, A', 'DECADE IN PERM', 1, 40, NULL, 3, 5, 7, 635, '2012-01-01', 'Notes: The dance was devised to mark the tenth anniversary of the Perm Scottish Dancing group, Silver Tassie, in 2012, so a five couple dance seemed appropriate. The dance works equally well as a three couple version (in a three couple set).  



Perm is at the foot of the Urals, some two time zones from Moscow, and I taught the dance at their weekend school in 2012.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20254, '2021-03-10 00:01:27.076072+00', '2021-03-10 23:51:48.964721+00', 'Forty Years Together', 'FORTY YEARS TOGETHER', 1, 40, NULL, 1, 4, 52, 2197, '2004-04-04', 'For Colin and Carol Johnston, with congratulations and best wishes on their 40th Wedding Anniversary.', 70, '8800/8800/8800/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20255, '2021-03-11 16:26:09.597244+00', '2021-03-11 17:09:03.427335+00', 'Yuri''s Welcome to Tokyo', 'YURIS WELCOME TO TOKYO', 2, 32, NULL, 1, 3, 42, 1445, NULL, 'To commemorate the safe arrival of little toy mammoth Yuri in Tokyo.', 49, '822/822/866/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20257, '2021-03-11 16:35:48.090387+00', '2021-04-02 20:41:49.185779+00', 'Mr. and Mrs. Ligtmans', 'MR AND MRS LIGTMANS', 4, 128, 13, 4, 4, 1, 1445, NULL, '', 78, '6060/8888/8888/6666', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20258, '2021-03-11 16:36:39.587812+00', '2021-03-16 04:59:27.623063+00', 'Larry Strathspey, The', 'LARRY STRATHSPEY', 3, 32, NULL, 1, 4, 2, 1445, NULL, 'To commemorate our friends Larry and Gill’s 40th wedding anniversary.', 78, '8000/8488/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12388, '2005-04-28 22:00:00+00', '2021-04-27 20:29:31.211566+00', 'Seeing Spots', 'SEEING SPOTS', 2, 32, 9999, 1, 2, 76, 3538, '1999-01-01', 'The dance was devised for Doug Kean of Peterborough on a significant birthday. "Seeing spots is common among old people" - Birthday Card.', 43, '44/44/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20256, '2021-03-11 16:32:26.083151+00', '2021-03-22 22:13:36.593262+00', 'No Trouble at All', 'NO TROUBLE AT ALL', 1, 40, NULL, 1, 3, 42, 1445, NULL, '', 63, '800/844/888/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20267, '2021-03-12 16:37:39.825775+00', '2021-03-12 16:37:39.825775+00', 'Searching for Arina', 'SEARCHING FOR ARINA', 4, 64, 5, 1, 4, 1, 635, NULL, 'I first met Arina Volgina in 2012 when I stayed with her at the end of a teaching tour which started in St Petersburg, stopped briefly in Moscow, and finished in her home city of Nizhny Novgorod. Over the years we have become good friends, with her translating for me at many courses in Russia. Perhaps the two most memorable ones were in 2013, when she supported me at a teacher training course in Voronezh, and in 2015, when we travelled to Samara to teach a course for wheelchair dancers. She has also accompanied me to several courses in St Petersburg, and acted as a tour guide around the city and nearby palaces.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20268, '2021-03-12 16:40:46.909274+00', '2021-03-12 16:40:46.909274+00', 'Dancing Together', 'DANCING TOGETHER', 1, 40, NULL, 1, 4, NULL, 635, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20269, '2021-03-12 16:42:24.080356+00', '2021-03-12 16:42:24.080356+00', 'Spring in Samara', 'SPRING IN SAMARA', 1, 32, NULL, 1, 4, NULL, 635, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8558, '2002-04-15 22:00:00+00', '2021-03-16 18:37:45.877221+00', 'Tribute to the Ladies', 'TRIBUTE TO THE LADIES', 2, 32, 9999, 1, 100, 2, 692, '1995-09-01', '', 78, '8228/8888/8448/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8855, '2005-01-13 23:00:00+00', '2021-03-13 10:35:18.701745+00', 'Everything Stops for Tea', 'EVERYTHING STOPS FOR TEA', 3, 32, 9999, 1, 3, 42, 244, '2005-01-13', 'According to the description in the strathspey threads <<http://www.strathspey.org/lists/strathspey@strathspey.org/t/40296/|40296>> and finally <<http://www.strathspey.org/lists/strathspey%40strathspey.org/t/40434/|40434>> this dance seems to refers to tearoom culture in the 1930es.



The deviser describes it as a dance in four acts.



-   "The Park" (bars 1-8):                        The lead down and back and cast represent a pre-tea stroll through the park.



-   "The Teashop Foyer" (bars 9-16):      The rectangle inscribed by the grand chain represents the foyer of the tea shop.



-   "Finding One''s Table" (bars 17-24):   The half figures of eight down and then up represent searching for a free table.



-   "The Teapots" (bars 25-32):               And the "teapots" represent...well, of course...the teapot.



He explicitly also refers to the song "Everything Stops for Tea" as the suggested tune. It was written by Maurice Sigler (tune) and Al Goodheart (lyrics). The song was performed by Jack Buchanan in 1935 and was available on records and featured in Buchanan''s 1935 comedy film, “Come Out Of The Pantry”.

', 56, '880  888  800  888', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (8838, '2000-06-04 22:00:00+00', '2021-03-13 10:53:13.656391+00', 'Deep Pool Reel', 'DEEP POOL REEL', 1, 96, 9999, 1, 4, 3, 2419, NULL, '"The dance depicts the eddies and whirlpools of many a highland burn. It is a lot of fun to dance but you have to keep your wits about you."



Although the dance starts and ends in a longwise set, most of the action is in a square with 1st couple facing 3rd couple and 2nd couple facing 4th couple.', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19078, '2018-12-06 12:26:57.241144+00', '2021-03-13 20:34:57.525057+00', 'Peacocks in the Glen', 'PEACOCKS IN THE GLEN', 1, 32, NULL, 1, 4, 2, 11753, '2015-01-01', 'Peacocks have lived in Pittencrieff Park (known locally as The Glen) in Dunfermline since 1905, and books have been published about their fictional adventures.  



The four bar left hand turns can be performed as a birl by energetic dancers.

', 62, '8008/8448/8448/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9199, '2002-10-28 23:00:00+00', '2021-03-13 12:22:59.039591+00', 'Westbourne Reel', 'WESTBOURNE REEL', 1, 32, 9999, 1, 3, 42, 1415, NULL, 'Westbourne is an area in the West End qf Glasgow, and is the area in which my in-laws, Dan and Maureen, live.', 47, '800/888/880/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19061, '2018-12-03 15:58:41.793086+00', '2021-03-13 20:09:34.711742+00', 'Red Rose, The', 'RED ROSE', 3, 32, NULL, 4, 4, 1, 11751, '2016-01-01', 'The dance represents a rose slowly opening, thus making a flowing strathspey. Burns tunes such as ''My Love is like a Red Red Rose'' and others make it an ideal Burns Night dance. It was devised for the Crook of Devon class, and would be particularly suitable for newer dancers or a children''s class.', 56, '555/555/666/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19082, '2018-12-06 12:32:50.82314+00', '2021-03-13 21:16:55.908771+00', 'Queensferry Crossing, The', 'QUEENSFERRY CROSSING', 2, 32, NULL, 1, 4, 2, 11758, '2016-01-01', 'In 2011, the deviser travelled to Kenya with other members of Queensferry Parish Church (including a number of current and former dancers), to visit its partner church in Chogoria. The pattern of the dance represents a journey, meeting new people (and their return visit), and the building of a "bridge" and circle of friendship between the two communities. The title Queensferry Crossing seemed appropriate to highlight the connection between dancers in South Queensferry and Dunfermline.', 78, '8040/8888/8088/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20279, '2021-03-13 22:23:54.663411+00', '2021-03-13 22:23:54.663411+00', 'Track and Trace', 'TRACK AND TRACE', 3, 40, NULL, 2, 3, NULL, 2887, '2020-08-01', '"When sufficient confidence is achieved, this dance could be danced as a reel, to indicate that the Track and Trace has got quicker."



Dance specifically devised with adapted figures to maintain 2m distance from other dancers. Where formations are listed for the dance they are the originals the actual figures were adapted from.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20280, '2021-03-13 22:27:30.686978+00', '2021-03-13 22:27:30.686978+00', 'Yellow Rose, A', 'YELLOW ROSE', 2, 40, NULL, 2, 3, 17, 12029, '2020-08-01', 'Dance specifically devised with adapted figures to maintain 2m distance from other dancers. Where formations are listed for the dance they are the originals the actual figures were adapted from.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20261, '2021-03-12 15:47:33.480106+00', '2021-03-14 12:07:09.735481+00', 'Trans-Siberian Express, The', 'TRANSSIBERIAN EXPRESS', 1, 32, NULL, 8, 133, 90, 635, NULL, 'The dance was written to capture the spirit of travelling by train with “Dance & Travel”, reflecting the fact that couples would spend time with each other in one compartment, and then move on to talk with other couples in the next.  



“Dance and Travel” was the brainchild of Anna Abramova, a teacher of historical dance in Novosibirsk. It consisted of taking a group of “historical dancers” to various cities by overnight train in 3rd class carriages, to join up with similar groups in each new city to hold joint workshops and a final ball. I accompanied them on three trips to teach Scottish country dancing, and it was interesting to see how they progressed from one year to the next.', 92, '888888/888888/888888/808808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8629, '2000-08-05 22:00:00+00', '2021-03-16 09:49:28.118856+00', 'Burning Hearts', 'BURNING HEARTS', 2, 32, 9999, 1, 4, 2, 2030, NULL, 'This dance was written for the wedding of Kathrin and Albin Gensler.



The original URL (http://mitglied.lycos.de/ErlangenScotDance/links/dances.html#Dance4) is now defunct.', 72, '8888  8228  8008  2882', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (20259, '2021-03-11 18:32:42.169526+00', '2021-03-15 02:07:07.522101+00', 'Glasgow 95 Strathspey', 'GLASGOW 95 STRATHSPEY', 3, 64, NULL, 6, 118, 3, 12025, '2018-11-01', 'Devised for the 95th anniversary of Glasgow Branch.', 83, '24 24 24/24 24 24/24 24 24/24 24 24 /24 8 8/8 24 8/8 8 24/ 24 24 24/24 24 24', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8628, '2000-08-05 22:00:00+00', '2021-03-16 10:03:29.796538+00', 'Romance in Ireland', 'ROMANCE IN IRELAND', 3, 32, 9999, 1, 3, 42, 2030, NULL, 'This dance was written for and performed the first time at the wedding of Rita Borsos-Balzus and Stefan Balzus in Budapest - their lucky first meeting was in Ireland during their holidays, where they decided to make their plans together... 



A simpler version of this dance called <<ddd:Irish Romance>> has been devised by <<ddp:Gilliam, David>>. He decided to make this version more suitable for a bit less experienced dancers by changing bars 9 to 24. It sure takes less time to teach it and make the dancers move. 



The original URL (http://mitglied.lycos.de/ErlangenScotDance/links/dances.html#Dance2) is now defunct.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8555, '2002-02-28 23:00:00+00', '2021-03-16 18:59:06.287438+00', 'Blackford Jig', 'BLACKFORD JIG', 2, 40, 9999, 1, 3, 42, 692, '1995-10-01', 'The deviser dedicated this to Donald Ridley, in appreciation of the tunes which he has so generously composed, and played for her dances.', 50, '800/822/888/822/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20273, '2021-03-13 21:51:49.450873+00', '2022-08-08 16:05:33.968182+00', 'August Strathspey', 'AUGUST STRATHSPEY', 3, 32, NULL, 2, 3, 18, 12029, '2020-08-01', 'Dance specifically devised with adapted figures to maintain 2m distance from other dancers.

Where formations are listed for the dance they are the originals the actual figures were adapted from.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8554, '2002-02-28 23:00:00+00', '2021-03-16 19:04:03.241932+00', 'Bill Martin''s Strathspey', 'BILL MARTINS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 692, '1993-05-01', 'Devised for Bill Martin, friend and teacher of the Derwent Scottish Country Dance Club, Cockermouth. for many years.', 69, '888/888/880/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5699, '1999-08-06 22:00:00+00', '2021-05-01 21:48:51.665189+00', 'Rothesay at the Fair', 'ROTHESAY AT THE FAIR', 1, 240, 9999, 4, 4, 3, 9998, NULL, 'This dance was collected from Mrs Peter Nimmo of Vancouver. It is said to have been danced in Glasgow about the year 1860. As children it was played as a game and described the joys of ‘Rothesay at the Fair’ - swing-boats, Merry-go-rounds, etc. The last two figures show the return to Glasgow through all the railway tunnels and the walk home at the end. ', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3225, '1999-08-06 22:00:00+00', '2021-05-01 20:50:14.881985+00', 'Jeannie o'' the Witchin'' E''e', 'JEANNIE O THE WITCHIN EE', 2, 40, 9999, 1, 2, 76, 9998, NULL, 'According to <<https://my.strathspey.org/dd/issue/2383/|issue 2382>> Mrs MacNab writes: This dance is dedicated to my friend Miss Jean Milligan. Collected originally in Ayrshire, but gifted by Mrs Fassiefern Bain of Vancouver, late of Appin, daughter of the Reverend W Stewart of Nether Lochaber.', 40, '40/82/80/88/80', 0, 1, 1, 0, 57);
INSERT INTO 'dance' VALUES (3680, '1999-08-06 22:00:00+00', '2021-05-01 21:36:48.27148+00', 'Lamont of Inveryne', 'LAMONT OF INVERYNE', 1, 208, 9999, 1, 4, 3, 9998, NULL, 'From the original: "This dance is one from the 15th century and is said to be danced on the occasion of the visit of Mary Queen of Scots to ‘Toward Castle’. Collected from Allan McDonald of Truro, Nova Scotia."



However, from <<https://my.strathspey.org/dd/issue/2387/|issue 2387>>, the above should be 16th not 15th  century. The original must be an error since Mary Queen of Scots lived 1542-1587.



Toward Castle is the seat of the Clan Lamont.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8512, '2002-04-14 22:00:00+00', '2021-03-17 19:55:43.551257+00', 'Standpretty', 'STANDPRETTY', 1, 32, 9999, 4, 4, NULL, 2052, NULL, '"Dedicated to my wife Jessie. Standpretty is a small hamlet south of Edinburgh where her mother was born. During their youth Jessie and her brothers were often told tales of things that happened ''when we lived in Standpretty''. It is also the name of our house."', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8507, '2002-04-08 22:00:00+00', '2021-03-17 20:09:18.251153+00', 'May You be Dancing on Air', 'MAY YOU BE DANCING ON AIR', 1, 32, 9999, 1, 3, 42, 35, NULL, 'For this dance the deviser writes after the instructions:



*I see in the face of my partner a transcending of personality, of posture, a graciousness of gesture. A tiIt of the head and a light in the eye are all part of THE DANCE.*



*In the Jigs and Reels the feet take on wings and the body becomes more supple as the music lift them up.

In the Strathspey the ladies in their ball finery raise hands with a delicate air to meet those of their partner, in their mind''s eye all are Ladies and Gentlemen and part of a scene of elegance and courtly mannerisms.*



*No longer the cares of the day intrude, the too many inches around the waist, the Setting step that won''t come together, all is transformed, and there is a gratefulness to fellow dancers for each and every shared transcended moment.*', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7455, '1998-12-17 23:00:00+00', '2021-03-18 20:29:27.54299+00', 'Margo Lewick''s Jig', 'MARGO LEWICKS JIG', 2, 32, 9999, 1, 3, 42, 440, NULL, 'Written for my good friend and fellow member of St. Andrew''s, Mrs Margo Lewick.', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6766, '1998-12-17 23:00:00+00', '2021-03-18 20:43:39.546931+00', 'Tullybannocher', 'TULLYBANNOCHER', 2, 32, 9999, 1, 3, 42, 440, '1993-06-30', 'Devised by Ann Campbell, June 30, 1993, and named after Tullybannocher, Scotland.', 44, '844/844/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8480, '2001-11-26 23:00:00+00', '2021-03-19 10:50:32.535768+00', 'Drumrunie Forest', 'DRUMRUNIE FOREST', 1, 32, 9999, 1, 2, 76, 872, NULL, '', 56, '80/88/84/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1534, '1997-04-03 22:00:00+00', '2021-03-21 11:32:09.387538+00', 'Dancing Bees, The', 'DANCING BEES', 3, 32, 9999, 1, 3, 42, 35, NULL, 'We see a bee coming in through the entrance hole, running up the combs and stopping motionless surrounded by other hive-mates. It then disgorges all the honey it has just collected. Then it begins to perform a kind of "round dance," whirling round, changing direction many times, some hive-mates joining in. The bee is giving them instructions where to find a plentiful source of honey.  

They take off and find the exact flowers that had been described to them. They return and repeat the dance for the other bees. Unless a honey crop is abundant enough to justify the calling up of a large army of foragers, no dances are performed inside the hive. ', 38, '440/044/844/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14750, '2013-03-26 21:35:18.925743+00', '2021-03-21 12:00:52.535548+00', 'Highland Light Infantry, The', 'HIGHLAND LIGHT INFANTRY', 2, 32, NULL, 1, 4, 1, 352, '1999-08-09', 'Description sent to SCDDB by Rod Downey, March 2013.

The preferred recording is Fete Champetre by David Hall and his Scottish Dance Band (featuring the tune Teddy Bears'' Picnic).', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8178, '2002-04-30 22:00:00+00', '2021-03-21 14:18:39.252904+00', 'Celtic Bicentenary, The', 'CELTIC BICENTENARY', 1, 32, 9999, 1, 3, 42, 520, '1996-01-01', '', 53, '888/822/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20281, '2021-03-19 13:28:45.616373+00', '2021-03-19 15:14:30.392169+00', 'Let''s Have a Swig', 'LETS HAVE A SWIG', 1, 32, NULL, 2, 3, 17, 440, '2021-02-17', 'Devised for Arlene Koteff, inspired by her comment about having a swig during her Zoom dance class.', 81, '888/808/860/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8461, '1997-12-28 23:00:00+00', '2021-03-19 23:00:38.388258+00', 'It''s Fun to Dance', 'ITS FUN TO DANCE', 1, 40, 9999, 1, 3, 42, 872, NULL, '', 45, '880/800/800/880/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8364, '2002-06-03 22:00:00+00', '2021-03-20 11:03:23.025983+00', 'Saint Margaret''s Jig', 'SAINT MARGARETS JIG', 2, 32, 9999, 1, 4, 1, 108, '1996-01-01', '', 62, '8000/8440/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8246, '1998-01-06 23:00:00+00', '2021-03-20 19:58:14.031259+00', 'Monday Madness', 'MONDAY MADNESS', 1, 40, 9999, 1, 4, 1, 34, '1984-11-01', '"This dance was written for the Atlanta Monday night class and after dancing it, they suggested the name."', 75, '8242/8484/8484/8466/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7496, '1998-12-17 23:00:00+00', '2021-03-21 07:58:22.150679+00', 'Ramsay''s Rant, The', 'RAMSAYS RANT', 3, 40, 9999, 4, 4, 13, 440, NULL, 'Written for Bill and Mary Ramsay, my friends and fellow members of St. Andrew''s of Brampton.', 85, '8888/6666/6666/6666/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12110, '2005-03-23 23:00:00+00', '2021-03-21 19:59:04.439111+00', 'Salute to Margaret Rae', 'SALUTE TO MARGARET RAE', 3, 32, 9999, 2, 3, 17, 1235, NULL, 'Devised by Margaret Waddell to commemorate the Golden Jubilee of the Duos and District Branch of The Royal Scottish Country Dance Society and to pay tribute to our Founder, known affectionately as "Daisy" Rae.', 73, '860/844/888/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7565, '2002-02-11 23:00:00+00', '2021-03-25 00:31:19.202114+00', 'Riddlers Rant, The', 'RIDDLERS RANT', 1, 32, 9999, 1, 3, 42, 127, NULL, '"For Mary Sutherland.

''The Riddlers'', a children''s TV programme, appears on ITV Channel 3 on Thursdays at 3.30 pm for 10 minutes. Mary, like myself, is the only ''old bairn'' I know who watches the programme.

I have tried to fit the characters in the programme into the figures of the dance, ie Montgomery, Mossup, Middler and Tiddlup. (Yorkshire TV have been informed), and replied with photos of the cast."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8040, '1997-12-02 23:00:00+00', '2021-03-22 17:41:30.142032+00', 'Castle Jig, The', 'CASTLE JIG', 2, 32, 9999, 1, 4, 1, 758, '1994-01-01', '"The Mountain View class used to take a field trip twice a year to the Edinburgh Castle Pub in San Francisco where we were joined by dancers from all over the Bay area. It was always a fun relaxing evening that started with fish and chips served in newspaper and a pint of amber liquid to quench the thirst. Part of the fun was to invite the pub''s patrons, who were not yet dancers, to come and join us. This is how this dance came to be."



There is also a more relaxed 40 bar version of the dance which is shown in the video and described in the MiniCrib. The e-crib and diagram follow the 32 bar version.', 81, '8888  8888  8000  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (7382, '1998-12-17 23:00:00+00', '2021-03-21 18:45:14.551388+00', 'Doctor Hall''s Reel', 'DOCTOR HALLS REEL', 1, 32, 9999, 1, 3, 42, 440, NULL, 'Written in memory of the late Dr. Henry Hall of the St. Andrew''s group, who loved Scottish Country Dancing.', 50, '880/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8056, '1997-12-03 23:00:00+00', '2021-03-22 17:24:29.454519+00', 'Highland Mary', 'HIGHLAND MARY', 2, 32, 9999, 1, 3, 42, 758, '1991-01-01', 'Music:  

  There is no specific tune chosen at this time but the dance seems to want an easy moving jig or a gentle strathspey, but not an ''air''.  



Notes:  

I would use the more forgiving strathspey tempo if turn comer and partner were a new (or almost new) figure.  

This dance was devised for a Robert Bums dance evening. Highland Mary was Mary Campbell of Argyll with whom Bums was going run away to the West Indies. Mary died shortly before they were to sail and is said to have inspired Bums'' song, "Flow Gently Sweet Afton." (Jo Hamilton)', 41, '880/800/822/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8039, '1998-01-05 23:00:00+00', '2021-03-22 17:45:09.958947+00', 'Black-Haired Lassie, The', 'BLACKHAIRED LASSIE', 1, 32, 9999, 1, 3, 42, 895, '1993-01-01', 'Can also be danced as a strathspey.



Note: As a new 1st couple begins at the top, 3rd couple dance up into the reel from 4th place and the former 1st couple step to the bottom.



The black-haired lassie is Julie Osborne, who was in the Stockton beginners'' class.', 56, '888/800/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6657, '1998-11-17 23:00:00+00', '2021-03-27 19:31:57.499711+00', 'Torry Quine, The', 'TORRY QUINE', 1, 88, 9999, 4, 4, 3, 2431, NULL, 'A Torry Quine is a young girl from the Torry area of Aberdeen.', 93, '4444  8888  4242  8888    4444  8888  2424  8888    6666  6666  16 16 16 16  8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9016, '1999-04-24 22:00:00+00', '2021-04-01 08:39:55.260088+00', 'William''s Jig', 'WILLIAMS JIG', 2, 32, 9999, 1, 3, 42, 2599, '1998-01-01', 'Dedicated to the memory of William (Bill) Wilde (1932-1998) for all his help and support over many years to the Caberfeidh Junior Dancers. His presence is missed by all.', 41, '440/800/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1093, '1997-08-31 22:00:00+00', '2021-06-23 11:23:33.439033+00', 'Cathie McLaren''s Jig', 'CATHIE MACLARENS JIG', 2, 40, 9999, 1, 3, 42, 176, NULL, 'In the instructions for this dance, the formation in bars 9-16 is referred to as "balance in line right round" but seems to be the same as the Spoke.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20282, '2021-03-22 20:34:26.37756+00', '2021-03-22 21:05:53.921091+00', 'Toronto''s Teachers', 'TORONTOS TEACHERS', 1, 32, NULL, 1, 4, 2, 440, NULL, 'Devised on May 3rd, 2011 for all the teachers in the Toronto Association (no matter where in the GTA they live) without whom we would have no Scottish country dancing.', 65, '8008/8888/8888/8668', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7412, '1998-12-17 23:00:00+00', '2021-03-23 09:52:17.901557+00', 'Hawkin''s Hornpipe, The', 'HAWKINS HORNPIPE', 1, 32, 9999, 1, 3, 42, 440, NULL, 'Written for my friends and fellow dancers at St. Andrew''s, David and Margaret Hawkins, on the occasion of their fortieth wedding anniversary.', 41, '800/444/066/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7842, '1998-10-26 23:00:00+00', '2021-03-23 20:08:56.824811+00', 'Miss Scott''s Strathspey', 'MISS SCOTTS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 1139, NULL, '', 66, '888/888/888/822', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7814, '2002-03-11 23:00:00+00', '2021-03-23 20:24:26.138163+00', 'Lyne Valley Reel', 'LYNE VALLEY REEL', 1, 40, 9999, 1, 3, 42, 692, '1995-01-01', 'Devised for the Lyne Valley Band.', 60, '880/808/888/866/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7645, '2002-03-02 23:00:00+00', '2021-03-23 23:36:48.634331+00', 'Champion Gold', 'CHAMPION GOLD', 3, 32, 9999, 2, 3, 18, 755, '1985-01-01', '', 75, '844/888/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7524, '1999-01-03 23:00:00+00', '2021-03-26 11:12:39.734016+00', 'Sweet Basil', 'SWEET BASIL', 1, 32, 9999, 1, 3, 42, 480, '1995-10-22', '"In some cultures, basil is a sacred herb; in others, a sign of love; and still others, a medicinal plant.

Basil is thought good for the digestive system, nervous headaches, and anxiety.

In ancient Greece and Rome, physicians shouted and cursed while sowing the seeds to ensure a good crop.

I hope you don''t find the same necessary for dancing or teaching this dance."', 63, '888/844/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14607, '2012-12-16 23:53:44.670841+00', '2021-03-26 23:21:36.21637+00', 'We are tying the Knot', 'WE ARE TYING THE KNOT', 1, 32, NULL, 1, 3, 42, 3775, '2011-09-01', 'Devised by for the occasion of the wedding of Sophie Rickebush and Sjoerd van Leersum in September 2011.



Offficial description:



1 –  8     1st  Set, cross right hand, cast down for two places and dance up to finish facing first corners



9 – 12    First corners pass and turn. On bar 12 dancing couple pass right shoulder to face second corners



13 – 16   Second corners pass and turn. At the end, 1st couple pass right shoulder to finish back to back facing own sides ready for: 



17 – 24   Double triangles. 1st couple finish in the center facing up.  On bar 20 the man dances an extra loop: turn on the spot by the right. And on bar 24 the man continue turning on the spot by the right ¼ while  the lady continue turning on the spot by the right ¾ to face up. 



25 – 32   1st couple dance up between 2nd couple, cast down around them, an coming in to join nearer hands, dance down between 3rd couple and cast up to 2nd place. (Fig. of 8 on sidelines).



Repeat having passed a couple.  	



Note: Corners pass and turn: 1st couple dance round their corner positions by the right. The corners dance in on the first bar, passing 1st man or 1st woman by the right, turn each other with the right hand on the second bar, dance out towards their corner positions on the third bar, and curve round into place on the fourth bar.

', 44, '800  844  888  800', 0, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (8670, '1999-08-06 22:00:00+00', '2021-04-05 21:40:01.759974+00', 'Friday the Thirteenth', 'FRIDAY THE THIRTEENTH', 4, 64, 5, 4, 119, 3, 479, '1971-08-13', 'A square dance for four men and eight women; one man and two women on each side of the square.



"This dance was devised on Friday 13th August 1971, on completing my Teaching Certificate at St Andrews.

I first taught the dance to mime at the Friday evening ceilidh."', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20283, '2021-03-24 02:29:31.918527+00', '2021-03-30 17:13:06.280092+00', 'Dance for David, A', 'DANCE FOR DAVID', 3, 32, NULL, 1, 3, 42, 440, '2010-01-01', 'Written in 2010 for David Booz, one of the Toronto teachers.', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7440, '1998-12-17 23:00:00+00', '2021-03-24 10:04:35.520149+00', 'Kingsmere Capers', 'KINGSMERE CAPERS', 1, 40, 9999, 1, 4, 1, 440, NULL, '1, Kingsmere Crescent, Brampton, is the home of the founder of the St. Andrew''s of Brampton Scottish country dance group, Mrs Marjorie Coulter, and it is here that we practise for demonstrations. On one such occasion our teacher, Dr. Paul Maloney, devised the "Kingsmere Allemande".', 56, '4444/8888/8000/8800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7566, '1998-07-09 22:00:00+00', '2021-03-24 11:59:17.606417+00', 'Celtic Crossing', 'CELTIC CROSSING', 2, 32, 9999, 3, 5, 7, 127, '1996-01-01', '"Devised for Andy and Gillean Lippok.

Andy and Gillean, keen members of St John''s Scottish Dancing Club, Wokingham, moved to Dublin in the summer of 1996, hence the Celtic Crossing. Andy was chairman of the club in 1996.

What can I say about the lovely Gillean - she hails from Inverness, and lets me know if she approves of my dances! Mary Sutherland thought up the appropriate name."', 82, '88880/84884/88888/84844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15769, '2015-01-11 13:46:38.483081+00', '2021-03-25 12:30:04.279898+00', 'Noble Feat, A', 'NOBLE FEAT', 1, 40, 9999, 1, 4, 2, 440, '2008-05-15', 'Dedicated to Jean Noble, to mark her receiving the Scroll of Honour from Edinburgh.', 92, '8888/8888/8888/8448/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15773, '2015-01-11 14:37:39.801198+00', '2021-03-25 19:22:03.141842+00', 'Lost Lamb, The', 'LOST LAMB', 2, 32, 9999, 2, 3, 17, 440, '2007-04-28', 'This dance is an apology to Theresa Malek for missing her out of the list of the Workshop Committee - a major oversight as Theresa has done so much for the Association and for me personally when I was Convener of the Tartan Ball.', 67, '800/888/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7533, '2002-04-15 22:00:00+00', '2021-03-25 23:46:18.258587+00', 'Wandering Piper, The', 'WANDERING PIPER', 2, 32, 9999, 1, 4, 1, 146, NULL, '"The last 16 bars of this dance are the same as the last 16 bars of *The Wandering Drummer* by Iain Boyd, published in *Happy to Meet*."', 38, '8800  4400  8000  8008', 1, 1, 1, 1, 37);
INSERT INTO 'dance' VALUES (7528, '1999-01-03 23:00:00+00', '2021-03-26 00:00:36.940416+00', 'Tipsy O''er The Glen', 'TIPSY OER THE GLEN', 3, 32, 9999, 1, 3, 42, 480, '1995-12-10', '"I devised this dance to provide a comfortable, but interesting, dance with which to introduce mirror reels. Note that the reels must be very wide in order to use the full eight bars to dance the figure."', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6846, '1998-01-04 23:00:00+00', '2021-04-04 19:29:38.130676+00', 'Up and Doon the Gallowgate', 'UP AND DOON THE GALLOWGATE', 1, 32, 9999, 1, 3, 42, 108, '1983-01-01', '"For Mary Murray of Vancouver."

', 69, '888/888/808/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5001, '1997-04-03 22:00:00+00', '2021-04-07 11:21:45.964114+00', 'November Wedding', 'NOVEMBER WEDDING', 3, 40, 9999, 1, 4, 1, 185, '1991-01-01', 'For Ian and Janice Morrison on the occasion of their wedding on 23th November 1991.



Note from the instructions: It is important to keep to the phrasing in the last eight bars.

', 42, '8110/8011/8004/8440/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20351, '2021-06-20 21:08:04.011778+00', '2021-06-24 18:32:49.854503+00', 'Friday Nights at Erin Mills', 'FRIDAY NIGHTS AT ERIN MILLS', 3, 32, NULL, 1, 3, 42, 440, '2021-06-20', 'Devised by Ann Campbell on June 20, 2021, in memory of Jean Hamilton, much loved teacher of the Erin Mills Friday night group.', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7409, '1999-01-07 23:00:00+00', '2021-03-26 23:56:36.994164+00', 'Hairy Mary', 'HAIRY MARY', 1, 32, 9999, 1, 3, 42, 480, '1994-03-01', '*From the original notes:*



"Hairy Mary is a salmon fly: gold, black, and bright blue with a light brown wing. It was created in the early 1960''s by John Reidpath of Inverness."



"The figure *of bars 9-16* came to me while I was watching the Olympic relay skating. The hardest part about teaching this dance is getting the first corners out of the reel half way through. In the Olympics, the skaters push the new racer into the race as they leave, scarcely social dancing, so I have the second corners entering behind the dancer leaving the reel, and discourage pushes."', 56, '800/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7366, '1997-12-03 23:00:00+00', '2021-03-27 00:22:54.469579+00', 'Christmas At The Heath', 'CHRISTMAS AT THE HEATH', 2, 32, 9999, 9, 7, 87, 434, '1995-12-25', '"My commission was to devise a jig for seven couples, the dance to be not too hectic and not too complicated. This commission was received on Christmas Eve and the dance devised on Christmas Day 1995 at the Jarvis Heath Hotel, Bewdley, Worcestershire."', 43, '4448444/4448444/8008000/8008000', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7088, '1997-08-25 22:00:00+00', '2021-03-31 09:14:26.936737+00', 'Where the Snowflake Reposes', 'WHERE THE SNOWFLAKE REPOSES', 2, 32, 9999, 1, 3, 42, 108, '1981-01-01', 'The title is from Byron''s poem <<https://www.scottishpoetrylibrary.org.uk/poem/lochnagar/|Lochnagar>>:  



*Away, ye gay landscapes, ye gardens of roses,*  

*In you let the minions of luxury rove,*  

*Restore me the rocks where the snow-flake reposes,  ...*  



*... I sigh for the valley of dark Lochnagar.*  ', 61, '686/686/888/806', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20080, '2020-08-31 20:38:56.487008+00', '2021-03-27 02:55:40.996538+00', 'Ginette d''Hénonville', 'GINETTE DHENONVILLE', 3, 32, NULL, 4, 4, 13, 11981, '2020-01-01', 'Dedicated to Ginette Dalleré, Scottish Country Dancer extraordinaire, of Hénonville and Paris.  We met Ginette at St. Andrew’s Summer School in 1983 and have kept in touch all these years. Hénonville is a small French village in Oise, about 60 km northwest of Paris, where Ginette’s family has lived for generations and where she loves to tend her beautiful garden.  



Published in Set & Link, RSCDS Toronto Association Newsletter, September 2020', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7312, '2006-03-07 23:00:00+00', '2021-03-27 16:12:13.182354+00', 'Siege of Buda, The', 'SIEGE OF BUDA', 1, 32, 9999, 1, 3, 42, 2688, '2001-01-01', 'This was originally a 24 bar English Country Dance, to a tune of the same name, and was rearranged as a 32 bar SCD by Gábor Turi. The siege of the Turkish controlled Buda Castle by the Hungarian army took place in 1686.', 59, '880/888/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14666, '2013-01-21 23:13:21.805019+00', '2021-03-27 18:49:22.691961+00', 'White and Purple Heather Jig, The', 'WHITE AND PURPLE HEATHER JIG', 2, 40, NULL, 1, 3, 42, 9998, NULL, 'This is a 3c version of the <<ddd:White Heather Jig>> by <<ddp:Cosh, James B|James Cosh>>.

', 37, '800/880/822/808/800', 0, 1, 0, 0, 37);
INSERT INTO 'dance' VALUES (14554, '2012-09-02 21:40:03.442245+00', '2021-03-27 18:52:19.09603+00', 'Derek and Jennifer', 'DEREK AND JENNIFER', 3, 32, NULL, 1, 3, 42, 10650, '2003-07-20', '(Written by a group in a Derek Haynes composition class at Summer School, St Andrews, 1st week 2003, where Jennifer played the piano, the main devisers being Tom Kerr and Margaret Lambourne).', 58, '860  888  408  888', 0, 1, 1, 0, 77);
INSERT INTO 'dance' VALUES (14551, '2012-09-02 20:19:13.720012+00', '2021-03-27 18:54:58.438943+00', 'Return from Fulda', 'RETURN FROM FULDA', 1, 40, NULL, 1, 4, 1, 3323, '2005-08-25', 'Our group of Scottish Country Dancers was enjoying a week of dancing and cultural visits, organised by Jim Cook of London at Kuckucksnest (Vollmerz, Germany).  The dance symbolizes the return from a day trip to Fulda on August 24, 2005.  The 16:09 return train was cancelled due to the discovery of a WW2 bomb near the line.  After the normal day [1-8] we waited in the train for ¾ hour [9-16], walked to the buses [17-24] which took us by many twists and turns to Schlüchtern and on to Vollmertz [25-32] where we were glad to be home [33-40].



The dance may be suitable for a children''s class.

', 77, '8888  2222  8888  8444  8888', 1, 1, 1, 0, 77);
INSERT INTO 'dance' VALUES (9336, '2000-02-13 23:00:00+00', '2021-03-27 19:09:24.272763+00', 'DeLong Reel', 'DELONG REEL', 1, 32, 9999, 1, 2, NULL, 777, '1999-01-01', 'From the Columbus June 1999 ball program, no source given. Patty Lindsay asked Laura Russell (teacher in Columbus) for a source and got a history lesson. »It was written by Dale Birdsall for Dick DeLong of Columbus. We asked Dale to write it as a Christmas surprise for Dick. Fred Moyes wrote the original tune for it as an additional surprise! Dale says he will publish it in his[?], Book of dances — when he gets it ready! Dale Birdsall is formerly of our branch and now in Vermont«.', 62, '84  88  88  86', 1, 1, 0, 0, 90);
INSERT INTO 'dance' VALUES (6834, '1998-04-24 22:00:00+00', '2021-04-04 19:34:39.632964+00', 'Under A Thatched Roof', 'UNDER A THATCHED ROOF', 3, 32, 9999, 1, 3, 42, 227, '1988-09-01', 'Beginners'' level.



Although the dance is a bit dull, we use it very often at the very beginning of a beginners'' class.  We find it useful for phrasing in two bars, figure of eight up and down, and making the entry into the circle easy by setting in lines of three first.', 41, '800  080  822  888', 0, 1, 0, 0, 54);
INSERT INTO 'dance' VALUES (20299, '2021-04-05 09:05:58.844858+00', '2021-04-05 20:47:15.636638+00', 'Moonraker Strathspey', 'MOONRAKER STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11029, NULL, 'This was written for my husband who is Wiltshire born.  

Moonraker is a nickname for Wiltshire folk. The story goes that Wiltshire yokels, with typical country guile, when raking a pond for kegs of smuggled brandy, feigned stupidity when surprised by the excise men, and said they were trying to rake out the moon, which was reflected in the water.  

The singing version of the Wiltshire Moonrakers is inside the front cover.', 63, '880/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20296, '2021-04-05 08:50:25.308353+00', '2021-04-05 12:52:56.142129+00', 'Dance for Jean, A', 'DANCE FOR JEAN', 1, 32, NULL, 1, 3, 42, 11029, NULL, 'This dance was devised for Jean Law to celebrate her 80th birthday.', 56, '888/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20639, '2022-01-23 23:23:22.501382+00', '2022-11-10 09:03:00.33695+00', 'Wait for the Cranberries', 'WAIT FOR THE CRANBERRIES', 1, 40, NULL, 1, 3, 42, 3723, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6853, '2002-04-15 22:00:00+00', '2021-04-05 17:20:26.154466+00', 'Uppies and Doonies', 'UPPIES AND DOONIES', 2, 32, 9999, 1, 4, 1, 82, '1998-01-01', 'The last dance Roy Clowes devised before his death.



According to the notes "the name of the dance refers to the annual Town Game in Jedburgh, where the young men form two teams, the UPPIES (i.e. those from the UPPER end of the town) and the DOONIES (i.e. those from the lower end of the town), whose object is to carry the ball to the opponents’ goal. The rules are mysterious and very flexible."', 81, '8000  8888  8888  8888', 1, 1, 0, 1, 81);
INSERT INTO 'dance' VALUES (4896, '1997-04-03 22:00:00+00', '2021-04-07 11:24:33.824083+00', 'Neil''s Delight', 'NEILS DELIGHT', 3, 64, 9999, 1, 4, 3, 200, NULL, 'Formation of set: two straight lines, man woman woman man, men with partner beside them, men on the ‘outside’ at the corners and women on the ‘inside’ of each line.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4765, '1998-11-07 23:00:00+00', '2021-03-27 19:49:55.859497+00', 'Mrs Hepburn Belches', 'MRS HEPBURN BELCHES', 1, 48, 9999, 1, 3, 42, 1749, NULL, 'Derived from Pilling, the only source mentioned in DanceData. (DancaData includes the words »of Invermay« in the name; Pilling omits them).  



Comment on Strathspey,  Fri, 15 Feb 2002 15:49:08 EST  

At the request of a long time dancer, I taught Mrs Hepburn Belches dance last night in San Francisco.  Much to my surprise, I admit, the dance was a great deal of fun, although not at all easy.  The initial crossings don''t specify hands and it seems that using right both times is a fairly straightforward way to enter the first reel, but the only dancer to remember doing the dance pointed out that crossing by the left can involve a lovely little loop for 1st man and second lady to use to eat up the necessary time before entering the first reel of 4.  Does anybody on the server have insights to offer about how this dance is/was done?  Does anyone know for sure the reference in the title?    Bruce Herbold	Bherbold@aol.com   San Francisco Branch', 58, '888  888  880  808  808  880', 0, 1, 0, 0, 77);
INSERT INTO 'dance' VALUES (3180, '2002-02-26 23:00:00+00', '2021-03-27 19:54:39.456447+00', 'Jack''s Delight', 'JACKS DELIGHT', 4, 128, 2, 4, 4, 3, 228, '1995-01-01', 'Dance writtten for the Dec. 1995 birthday of Jack Campbell, the Frankfurt club''s teacher. Bars 9-24 are based on ''Glayva''.', 91, '8888  8282  2828  8888    8888  8888  8888  8888', 0, 1, 0, 0, 45);
INSERT INTO 'dance' VALUES (2786, '1998-09-17 22:00:00+00', '2021-03-27 20:01:44.696982+00', 'Chasing the Wild Goose', 'CHASING THE WILD GOOSE', 2, 32, 9999, 3, 5, 4, 635, '1996-01-01', 'Music:  a 5x through Bobby Crowe recording of Wild Geese.', 85, '08080  88888  88888  48884', 0, 0, 0, 0, 85);
INSERT INTO 'dance' VALUES (20285, '2021-03-27 20:35:12.190691+00', '2021-03-27 20:35:12.190691+00', 'Teachers'' Pets', 'TEACHERS PETS', 1, 32, NULL, 1, 130, NULL, 12030, NULL, 'Devised by members of the Lapa group in Lisbon as a present for their teachers.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (674, '2002-04-18 22:00:00+00', '2021-03-27 21:44:37.933632+00', 'Bonnie Stronshiray', 'BONNIE STRONSHIRAY', 3, 32, 9999, 1, 3, 42, 62, '1963-01-01', 'A quote: »the key that has always made this dance so wonderful is the flirting that dancing couple can do on bars 9-10 and 13-14 ; <...> if you actually set to your partner, advancing and at the last moment just slipping in BtoB to face and turn the appropriate corner, it''s tremendous fun. The moment is all too rare, as apparently few teachers teach it this way, but it''s a moment I savour.«', 53, '880  822  888  844', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (7243, '2000-06-04 22:00:00+00', '2021-03-28 13:52:38.069507+00', 'Distillery Reel', 'DISTILLERY REEL', 1, 48, 9999, 1, 4, 1, 2419, NULL, '"I am often asked what Distillery? Any distillery as long as its a distillery. ''Take a deep breath'' before you start. The after effects are nearly the same as a guid nicht oot, usually 192 Bars of Chaos!"', 75, '8888/8888/8880/8880/8880/8000', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9535, '2000-06-20 22:00:00+00', '2021-03-28 19:13:35.132309+00', 'Four Hands on Deck', 'FOUR HANDS ON DECK', 1, 32, 9999, 1, 100, 2, 2677, NULL, 'This variation on <<ddd:Davy Nick Nack>> was published on »<<https://www.strathspey.org/lists/strathspey%40strathspey.org/t/21545/|Strathspey>>« on 20 Jun 2000.', 81, '8888  8008  8668  8668', 0, 1, 0, 0, 81);
INSERT INTO 'dance' VALUES (7178, '1997-04-03 22:00:00+00', '2021-03-29 11:36:01.502515+00', 'Wiltshire Walk', 'WILTSHIRE WALK', 3, 32, 9999, 1, 3, 42, 3590, '1993-08-01', 'The dedication reads "For Bob - Dinton - August 1993"



Dinton is a village in Wiltshire.', 44, '800/888/844/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7164, '1997-12-21 23:00:00+00', '2021-03-29 11:46:31.604697+00', 'William''s Strathspey', 'WILLIAMS STRATHSPEY', 3, 40, 9999, 1, 4, 1, 425, '2002-10-20', 'The dedication reads "Devised for Bill Thorpe for his help as chairman of the Caledonia Group of S.C.D. Dartmouth, N.S."



SCDDB gives the preferred tune as Sundrum Castle, but a copy of the instructions mentions the recording <<ddrec:#2463>> which does not include that tune.', 45, '8000/8440/8000/8484/8008', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (845, '1997-08-31 22:00:00+00', '2021-03-30 13:31:11.87955+00', 'Brudenell Jig, The', 'BRUDENELL JIG', 2, 32, 9999, 1, 2, NULL, 727, NULL, 'This dance is not to be confused with <<ddd:New Brudenell Jig>>, also by Brenda Burnell.



The dance is named after the Brudenell Evening Institute, Leeds, UK.  The deviser''s husband taught Scottish Country Dancing there, and eventually became head of the Brudenell Evening Centre.



(This information is taken from the note at the end of "The New Brudenell Jig", which appears in the 35th (Silver Thistle) Collection)

', 52, '88  80  80  88', 0, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (20287, '2021-03-30 11:38:55.440036+00', '2021-03-30 11:51:33.157161+00', 'Cranleigh Quadrille, The', 'CRANLEIGH QUADRILLE', 4, 128, 2, 4, 4, 3, 952, '2018-01-01', 'Cranleigh is a large village in Surrey, south east of London, where the deviser was born and raised (according to the introduction to video 2).', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20288, '2021-03-30 19:45:27.951462+00', '2021-03-30 19:45:51.375732+00', 'Caribbean Circle', 'CARIBBEAN CIRCLE', 1, 32, NULL, 7, 1, 4, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20289, '2021-03-30 19:55:34.610351+00', '2021-03-30 19:55:34.610351+00', 'Tea at Audrey''s', 'TEA AT AUDREYS', 2, 32, NULL, 5, 56, NULL, 3379, NULL, 'Devised for Audrey Stratton from Aberdeen. Three facing three around the room.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15093, '2013-08-24 13:12:17.823834+00', '2021-03-31 08:56:59.958846+00', 'Our Marjorie', 'OUR MARJORIE', 1, 32, NULL, 1, 3, 42, 440, '2007-01-01', 'The Marjorie of the title is Mrs. Marjorie Coulter, who started the St Andrew''s of Brampton dance group, at St Andrew''s Church, on November 7, 1966 (Marjorie danced into her 90''s).', 63, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7075, '2000-09-02 22:00:00+00', '2021-03-31 09:37:26.287994+00', 'Wheatly Hills', 'WHEATLY HILLS', 1, 32, 9999, 1, 3, 42, 129, '1968-01-01', '', 50, '800/822/888/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20290, '2021-03-30 21:49:06.726854+00', '2021-10-11 19:59:17.303304+00', 'Dancing Cheek to Cheek', 'DANCING CHEEK TO CHEEK', 3, 32, NULL, 1, 3, 42, 11643, '2020-01-01', 'Devised "with my heart last Winter" (2020).', 44, '800/844/844/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20729, '2022-03-25 09:39:56.186384+00', '2022-03-25 10:39:07.25717+00', 'Paulette in Boots', 'PAULETTE IN BOOTS', 1, 32, NULL, 1, 3, 42, 3694, '2022-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20302, '2021-04-05 09:10:20.630764+00', '2023-02-03 20:57:25.805739+00', 'Fruit Cake', 'FRUIT CAKE', 4, 32, 2, 4, 4, 1, 11029, NULL, 'This dance is for Lindsay Benaud. For many years she has provided fruit cakes for Sydney Branch balls and socials. Lindsay is one of those behind the scenes workers – never makes a fuss, just gets things done.



Originally this was mistakenly entered as "The Fruit Cake" which is kept as an alias.', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4805, '1998-09-29 22:00:00+00', '2021-04-01 09:57:29.169227+00', 'Mrs Stewart''s Jig', 'MRS STEWARTS JIG', 2, 32, 9999, 1, 3, 42, 227, '1986-01-01', '##>>

Mrs Stewart is usually referred to as co-founder, with Miss Milligan, of the RSCDS. It was Mrs Stewart who had the idea of forming a group to promote the dancing she had known as a girl and who brought together the initial group that was to be so important in creating the SCDS - Miss Milligan; Lord James Stewart Murray (later Duke of Atholl); his sister, Mrs Dorothea Ruggles-Brice and Michael Diack, the music arranger and publisher. Mrs Stewart served as the Society''s first Secretary holding that position for 10 years from the beginning in 1923. She continued to take an active interest in the Society even after her move to South Africa in 1955. She died there in 1968.

##<<



For a full biography of Mrs Stewart see

 *An Album for Mrs Ysobel Stewart of Fasnacloich*

by Dr Alastair MacFadyen published by RSCDS', 50, '800  888  880  844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (12737, '2006-05-11 22:00:00+00', '2021-04-02 08:05:43.045113+00', 'Trip to Singapore, A', 'TRIP TO SINGAPORE', 1, 32, 9999, 4, 4, 13, 1445, '2006-01-01', 'For Keith Dixon, who went on a trip to Singapore enjoying himself very much and made many friends among the dancers of the Singapore St. Andrews society .', 81, '8484/8888/8080/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7028, '2001-10-22 22:00:00+00', '2021-04-02 17:49:44.304134+00', 'Welcome to Queen''s Cross', 'WELCOME TO QUEENS CROSS', 3, 48, 9999, 1, 4, 1, 1354, NULL, '*Notes from the instructions:*  

This dance represents the friendly spirit of the class, which used to meet in Queen''s Cross Church Hall.  

1-8: people coming from all comers of the city;  

9-16: their arrival at Queen''s Cross;  

17-20: meeting a partner;  

21-32: dancing with others;  

33-48: the ever-increasing circle of friends.  

', 84, '8888/8888/8644/8022/8888/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17315, '2016-09-09 10:31:01.60514+00', '2021-04-02 20:36:04.773835+00', 'One Set Short of a Hundred', 'ONE SET SHORT OF A HUNDRED', 3, 32, NULL, 2, 3, 17, 11299, NULL, 'Aliénor writes on the diagram of the Paris Book 1: "Bars 15-16 of this dance are a simple cast without crossing, as opposed to what the diagram says. I should have seen that before publishing the book, sorry."



"For the birthdays of Tom McKinlay and <<ddp:#11350|Mathias Ferber>> on the 20th of November 2013.  The sum of their two ages and the number of dancers in the set was exactly a hundred."', 67, '880/800/808/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16636, '2015-08-27 16:37:28.041596+00', '2021-04-02 20:59:59.359145+00', 'Dearcmhara', 'DEARCMHARA', 3, 32, NULL, 2, 3, 18, 10568, '2015-01-01', 'Dearcmhara is pronounced Jark Vara



I wrote this in my head while Don was driving on our ʻtransport the dogs ʼ trip from

Halifax. It is named in honour of the first uniquely Scottish prehistoric creature to be

discovered. Dearcmhara is Scottish Gaelic for marine lizard.



January 2015', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9261, '2000-01-16 23:00:00+00', '2021-04-02 23:53:22.374018+00', 'Kindred Spirits', 'KINDRED SPIRITS', 1, 32, 9999, 1, 4, 1, 35, NULL, 'When the deviser, who lived in Canada, first met Masako (Marchan) Okada Naitoh from Japan after a long correspondence, they noticed they were wearing very similar caftans.

"We were surprised and delighted that we shared similar tastes and acknowledged that, even thought we live so far apart, we could indeed be kindred spirits."', 56, '7300/8363/7003/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20292, '2021-04-02 21:10:09.172516+00', '2021-04-02 21:17:13.138191+00', 'Spring Flowers', 'SPRING FLOWERS', 2, 32, NULL, 1, 3, 42, 11924, '2019-01-01', 'This dance was written for Montreal’s beginner class at the A&P, in order to help introduce reels on the diagonal. The name was rather aspirational, it being an unusually cold and grey April at the time.', 44, '800/844/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15358, '2014-03-03 23:33:01.817143+00', '2021-04-02 21:23:41.6082+00', 'Dish-oriented', 'DISHORIENTED', 1, 32, NULL, 1, 4, 30, 3110, '2001-01-01', 'Each time through the dance the set is on a new axis perpendicular to the one before; the top of the set (Left end for the Men) rotates clockwise 1/4 of the way around (so top of hall, right-file wall, bottom of hall, left-file wall).  However, the order of the active couples is 1, 4, 2, 3; as the couple at the bottom of the set is the new active couple on second and fourth time around.



Original:

1-8     	Ones lead down the middle and back and cast into 2nd place

9-12   	Partners R-hand turn once round

13-16 	Partners dance back to back

17-24 	Top and bottom foursomes dance R-hands across and L-hands across

25-30 	Ends chase orbiting counterclockwise 3/4 round the set while middle four dance R-hands across 1 1/4 (5 places) to face partners

31-32 	All set in lines of four on new axis

Repeat with new actives

', 81, '8000  8888  8888  8888', 0, 1, 1, 0, 81);
INSERT INTO 'dance' VALUES (11760, '2004-08-21 22:00:00+00', '2021-04-02 21:57:53.265001+00', 'Maryan Merger, A', 'MARYAN MERGER', 3, 32, 9999, 4, 4, 1, 2766, '2003-08-01', 'This dance is written to honor Mary Spring and Bryan Luce on their wedding day September 27, 2003.', 94, '6666/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4685, '1997-09-09 22:00:00+00', '2021-04-02 22:23:54.561753+00', 'Mount Saint Helens Reel', 'MOUNT SAINT HELENS REEL', 1, 32, 9999, 1, 4, 2, 1153, NULL, '', 72, '8888/4444/4444/8668', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8522, '2002-04-08 22:00:00+00', '2021-04-02 23:08:20.122596+00', 'Posting Round the World', 'POSTING ROUND THE WORLD', 1, 32, 9999, 4, 5, 46, 48, NULL, '', 65, '08088/80808/00088/88888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6961, '2002-04-15 22:00:00+00', '2021-04-03 18:19:26.339977+00', 'Way Out West', 'WAY OUT WEST', 3, 32, 9999, 1, 107, 11, 108, '1993-01-01', '"For George and Onie Senyk of Sharpes, Florida."



The dance starts with 1st & 3rd couples on the men''s side and 2nd & 4th couples on the women''s side. The progression is one place clockwise to 3rd & 4th couples on the men''s side and 1st & 2nd couples on the women''s side.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20293, '2021-04-02 23:00:23.748528+00', '2021-04-03 22:26:22.41941+00', 'Cluaran', 'CLUARAN', 3, 32, NULL, 1, 4, 1, 11181, '2021-04-03', 'Cluaran is the Gaelic name for Thistle. This dance is dedicated to the new Scottish Country Dance Group Cluaran in Port-Louis near Lorient (Brittany, France) and to her teacher Clémentine Job.', 63, '8000/8888/8440/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20294, '2021-04-03 01:27:43.528681+00', '2021-04-03 01:43:52.580433+00', 'Jig for Meg and Dave, A', 'JIG FOR MEG AND DAVE', 2, 40, NULL, 2, 3, 17, 11181, '2021-04-03', '', 87, '888/888/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13121, '2006-11-28 23:00:00+00', '2021-04-03 11:24:40.935681+00', 'JB2', 'JB2', 4, 64, 13, 4, 4, 54, 11324, '2004-10-01', '"This dance was written in celebration of the marriage of Jessica Bhattacharyya and James Bellarby (thus JB squared) on 16 October 2004 in Westerstede, Germany."', 75, '8888/8080/8888/8080/0808/8888/0808/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6997, '1998-01-05 23:00:00+00', '2021-04-03 17:50:17.176815+00', 'Wee Doc and Doris, A', 'WEE DOC AND DORIS', 1, 32, 9999, 1, 3, 42, 114, NULL, '"Written for Dr. Bob Rowe and his wife Doris, with thanks for many years of good friendship."', 56, '880/888/888/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2651, '1997-09-17 22:00:00+00', '2021-04-06 20:09:38.025508+00', 'Great Expectations', 'GREAT EXPECTATIONS', 2, 32, 9999, 1, 2, 76, 895, '1989-01-01', 'Suited for Jig as well as Reel time (stated explicitly in the description of the dance).', 43, '44/44/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12477, '2005-07-21 22:00:00+00', '2021-04-11 13:43:57.455996+00', 'Fiddlesticks Frolic, The', 'FIDDLESTICKS FROLIC', 1, 40, 9999, 1, 3, 42, 952, '2005-01-01', 'Jenifer Kelly writes:    

Notes for teachers on the dances in the Anniversary Suite.   

As I devised these dances I had a particular teaching point in mind for each of them.  



These teaching notes can be found at 

http://rscds-sf.org/resources/dances/Anniversay%20Suite%20Notes.pdf', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6646, '1997-09-16 22:00:00+00', '2022-11-01 18:50:16.694021+00', 'Tonbridge Castle', 'TONBRIDGE CASTLE', 2, 32, 9999, 1, 3, 42, 218, NULL, 'From the notes: "Dedicated to Maureen Dalton, who founded the Tonbridge Scottish Dancers. Tonbridge Castle is situated in the town of Tonbridge."', 63, '848/888/686/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19935, '2020-03-30 00:45:27.743051+00', '2021-04-07 11:44:08.655556+00', 'Salute to San Diego', 'SALUTE TO SAN DIEGO', 2, 32, NULL, 1, 3, 42, 1502, '2020-01-01', 'Tune “Salute to Cap’n Jim” composed by Muriel Johnstone ©2019 Scotscores.  



Devised by Muriel Johnstone and members of the San Diego Branch, 2020.  



Dance devised with humble thanks to Marjorie McLaughlin and the San Diego Branch who nominated her for the RSCDS Scroll of Honour in 2002. At the time, the Branch chairman was Jim Mosteller who presented the scroll at a special ceremony during the New York Branch Jeannie Carmichael Ball.  

', 56, '822/888/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19496, '2019-07-25 08:49:32.98844+00', '2021-04-07 12:32:52.72516+00', 'Agne Hanson''s Strathspey', 'AGNE HANSONS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11842, '2013-05-01', 'Dedicated to Stockholm branch teacher Agne Hanson on his 60th birthday.



The instructions for bars 17-24 as published in the original Scandinavian Book PDF were mangled in the editing process. They should read:  

*1st lady dances right hands across with 2nd cpl and left hands back to place while 1st man dances right hands across with 3rd cpl and left hands back to place (teapots).*', 69, '844/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6621, '1998-01-05 23:00:00+00', '2021-04-07 15:38:26.012557+00', 'Tittle Tattle', 'TITTLE TATTLE', 1, 32, 9999, 1, 3, 42, 108, '1994-01-01', 'Drewry advises that "like other forms of tittle-tattle this dance should not be taken too seriously."



He also adds in a footnote that: 

"While I was checking Book 10 for reprinting, my attention was drawn to "The Infare" with its unusual turning with crossed hands. This dance is an attempt to develop the idea of crossed-hand turning. My guinea pigs decided that it worked better as a reel than as a strathspey."', 56, '880/880/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19938, '2020-03-30 02:00:39.698897+00', '2021-04-07 15:51:06.764748+00', 'A-Ward Winning Reel', 'AWARD WINNING REEL', 1, 32, NULL, 1, 3, 42, 10574, '2019-12-01', 'Dedicated to Ward Fleri on the occasion of receiving of the Branch Award, March 7, 2020.', 66, '844/888/488/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6601, '1997-09-16 22:00:00+00', '2021-04-07 16:48:21.0401+00', 'Tickle My Fancy', 'TICKLE MY FANCY', 2, 32, 9999, 1, 3, 42, 108, '1967-01-01', 'From the original instructions: "Miss A. Tickle of Dalston, Cumberland, is one of the leading members of Carlisle and Border Branch."', 59, '880/866/888/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3805, '1998-04-13 22:00:00+00', '2021-04-07 17:04:33.523285+00', 'Lightning Ridge', 'LIGHTNING RIDGE', 1, 48, 9999, 4, 4, 46, 151, NULL, 'Lightning Ridge is an opal mining area in the north of N.S.W.', 61, '8888/0888/8080/0808/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2914, '1997-11-24 23:00:00+00', '2021-04-07 19:22:36.550163+00', 'Highland Heather Honey', 'HIGHLAND HEATHER HONEY', 4, 128, 2, 4, 4, 3, 127, NULL, 'From the notes: "Dance devised for Lesley Jane Forbes of Buckie after watching her win the Gold Medal in the Strathspey & Reel in the Commonwealth Highland Dancing Championships at Princes Street Gardens, Edinburgh, on 24th August, 1980."', 88, '8888/8484/8888/8484/4848/8888/4848/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2840, '1997-09-03 22:00:00+00', '2021-04-07 19:54:09.341973+00', 'Heather On The Mountain', 'HEATHER ON THE MOUNTAIN', 3, 32, 9999, 2, 3, 17, 519, '1977-01-01', '"For the 21st birthday of Martin Dunkerton (a past president of the Edinburgh University New Scotland Country Dance Society)"', 71, '444/615/888/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20297, '2021-04-05 08:54:46.906298+00', '2021-04-08 08:52:28.679281+00', 'Arthur or Martha', 'ARTHUR OR MARTHA', 3, 32, NULL, 1, 4, 2, 11029, NULL, '', 69, '8008/8008/8888/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1862, '2002-04-28 22:00:00+00', '2021-04-08 10:10:05.473692+00', 'Dunvegan Castle', 'DUNVEGAN CASTLE', 4, 64, 5, 4, 4, 3, 406, '1972-01-01', 'From the notes: "Composed in honor of Dame Flora MacLeod of MacLeod, Chieftain of the Clan MacLeod, on the occasion of her 94th birthday celebration at the Burns Night Dinner of the St. Andrews Society of Washington, D.C."', 100, '16 16 16 16   8888  8888    8888  8888  8888  8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1577, '1997-09-01 22:00:00+00', '2021-04-08 10:21:42.173325+00', 'Davy Glen''s Strathspey', 'DAVY GLENS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 105, NULL, 'From the notes: "Davy Glen was a famous ''character'' of the Scottish hills. A drystane-dyker who worked when he needed to, and spent the rest of his time on the hills."



The diagram after bars 17-24 in the online instructions shows 1st couple on opposite sides, but from the preceding text they should be back on their own sides at that point.', 69, '4084/8080/8888/0888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20307, '2021-04-07 23:33:29.105753+00', '2021-04-08 11:35:24.717392+00', 'Celtic Round, The', 'CELTIC ROUND', 1, 40, NULL, 1, 100, 2, 12033, NULL, '', 82, '8228/8888/8888/8888/8008', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6093, '1997-09-14 22:00:00+00', '2021-04-08 12:48:03.940415+00', 'Silver Wedding Strathspey', 'SILVER WEDDING STRATHSPEY', 3, 32, 9999, 2, 3, 17, 21, NULL, 'For Max and Benita Bateman.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5332, '1997-09-11 22:00:00+00', '2021-04-10 10:56:29.496542+00', 'Pot-Pourri, A', 'POTPOURRI', 4, 32, 9999, 1, 4, 1, 21, NULL, 'Some versions of the original instructions give the final progression as 2 4 1 3 which seems incorrect. The MiniCrib has 2 3 4 1 is consistent with the choreography.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6526, '1997-04-03 22:00:00+00', '2021-04-10 11:08:13.224716+00', 'Thick Lies the Mist', 'THICK LIES THE MIST', 3, 32, 9999, 1, 3, 42, 44, NULL, 'According to the notes this was presented to Mel and Ellie Briscoe to celebrate the second Buffalo Gap Scottish Country Dance Camp.', 61, '420/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20329, '2021-04-19 08:16:22.152196+00', '2021-04-19 11:43:50.130647+00', 'Ghillies à Crampons, Les', 'GHILLIES A CRAMPONS', 1, 40, NULL, 3, 5, 16, 11786, '2014-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20308, '2021-04-10 18:06:44.114275+00', '2021-04-10 18:13:01.992546+00', '"It''s a Doozie"', 'ITS A DOOZIE', 1, 32, NULL, 1, 3, 18, 12034, '2016-01-01', 'Devised for Garry Thomas', 47, '822/888/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4048, '2002-04-24 22:00:00+00', '2021-06-06 21:25:38.360042+00', 'Macleod''s Tables', 'MACLEODS TABLES', 1, 48, 9999, 4, 4, 46, 1912, NULL, 'From the notes to the dance: "Macleod''s Tables are the two flat topped mountains overlooking Dunvegan. Ask about the legend of the Tables next time you visit Skye." Or look at links such as <<http://www.glendaleskye.com/the_tables.php>> and <<https://thedunvegan.com/what-to-do/macleods-tables/>>.', 83, '8008/8888/8888/8888/8008/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20424, '2021-08-02 03:00:31.044298+00', '2021-08-02 03:23:03.156667+00', 'Bavarian Double', 'BAVARIAN DOUBLE', 1, 32, NULL, 8, 6, NULL, 12052, '2011-01-01', 'Devised by Arthur Kingsland, based on J MacGregor-Brown Guide To SCD (ex-Collins) / Minicrib: Marney Wilson (one of the teachers at the Colleges class, one of the classes within the Hunter Valley Branch.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19118, '2018-12-14 17:59:32.239782+00', '2021-08-10 18:56:21.093759+00', 'Smiling Lila', 'SMILING LILA', 1, 32, NULL, 1, 3, 42, 709, '2017-11-01', 'More information including sheet music is available via <<https://www.scottish-country-dancing-dictionary.com/dance-crib/smiling-lila.html>>', 46, '880/840/800/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6478, '1998-04-19 22:00:00+00', '2021-04-11 11:04:54.347647+00', 'Tartan Ribbons', 'TARTAN RIBBONS', 2, 32, 9999, 1, 3, 42, 1029, NULL, 'Lindsey Trafford writes:- "The idea for the name of this dance came when Mum was decorating the church for a flower festival. I thought the arrangements would look better linked up with matching ribbons. As the flowers were all different colours Mum said the ribbons would have to be her favourite colour ...........TARTAN."', 50, '888/800/822/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6444, '1998-01-05 23:00:00+00', '2021-04-11 11:41:25.035073+00', 'Talisman, The', 'TALISMAN', 1, 40, 9999, 1, 3, 42, 13, NULL, 'The heading in the book claims this as a 32 bar reel, but gives 40 bars of instructions.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14510, '2012-07-04 13:11:09.547963+00', '2021-04-11 13:07:36.309711+00', 'Betelgeuse', 'BETELGEUSE', 6, 32, NULL, 1, 3, 42, 3101, NULL, 'Betelgeuse is the brightest star in the constellation Orion. It is a multiple star and is an irregular variable around 1st magnitude.  

In remembrance of Prof. H. K. Powell who began each astronomy lecture with a reading in Greek from Homer.', 56, '800/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20284, '2021-03-25 12:08:47.976562+00', '2023-02-13 12:43:34.720812+00', 'Mr and Mrs Crawford''s Strathspey', 'MR AND MRS CRAWFORDS STRATHSPEY', 3, 40, NULL, 1, 4, 1, 10621, '2008-01-01', '', 68, '8222/2822/8888/4444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6399, '1998-01-05 23:00:00+00', '2021-04-11 22:57:29.34633+00', 'Survivor from St Andrew''s', 'SURVIVOR FROM ST ANDREWS', 1, 48, 9999, 1, 3, 42, 3586, '1990-08-01', 'Written on the deviser''s return from taking the teacher''s exam at St Andrews - August 1990.



Possible interpretations of the figures (from the instructions):  

1-8 Golf links/links of friendship (OR links formed under pressure of exams!).  

9-16 Journey to St Andrew''s (OR chasing our tails to get the work done!).  

17-32 St Andrew''s Cross (OR reeling with exhaustion!).  

33-40 The crown on the RSCDS emblem (OR crowning moment - Passing the exams).  

41-48 World wide ring of friendship formed by the RSCDS (OR celebrations!).  

', 54, '880/800/844/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6327, '2002-02-12 23:00:00+00', '2021-04-12 22:27:25.969565+00', 'Storybook Glen', 'STORYBOOK GLEN', 3, 32, 9999, 1, 4, 2, 127, NULL, 'For Joyce Crump of Rochester, Kent.



The footnote to the dance says that:

Joyce was born in Aberdeen and now lives in Kent, and needless to say her love for Aberdeen and Deeside has never waned. Storybook Glen is a scenic beauty spot on Royal Deeside. "The once upon a time place for happy ever after people".', 94, '8888/7777/7777/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20309, '2021-04-13 13:01:27.596608+00', '2021-04-13 13:01:27.596608+00', 'Bev Tait''s Strathspey', 'BEV TAITS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 11901, '2019-07-01', 'This dance was written for Bev Tait for her 80th birthday. Bev Tait was the Scottish Country Dance teacher for Werribee Scottish Country Dance Group for 30 years before retiring in 2018. Bev and her husband, Uilleam Tait, attained their teachers’ certificates in 1980. Uilleam would also attend the class. As a child, Rachel Goerke remembers Bev and Uilleam Tait teaching at teaching weekends in Bendigo, Victoria, during the 1980’s. Many of the Werribee Scottish Country Dance Group continue to catch up with Bev on regular basis.



Published in The Spurtle, Issue 45, December 2020 by RSCDS Melbourne Branch.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6273, '2002-02-12 23:00:00+00', '2021-04-13 22:34:35.468163+00', 'Stan and Janet''s Jig', 'STAN AND JANETS JIG', 2, 32, 9999, 1, 4, 1, 1229, NULL, 'From the notes: "Stan and Janet Donaldson, for whom the dance was written, are the longest serving members of the Broadford class and Stan currently holds the position of branch chairman. The dance was devised to mark Stan''s retirement from British Telecom."', 61, '8664/8444/8200/8844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6178, '1998-09-29 22:00:00+00', '2021-04-14 10:33:17.136658+00', 'Sodger Laddie', 'SODGER LADDIE', 2, 32, 9999, 1, 3, 42, 397, '1731-01-01', 'The notes to the revised edition of Book 12 say the RSCDS version is abbreviated to the first 32 bars of the original in the 1731 "Caledonian Country Dances Book the Third" by John Walsh.', 50, '888  888  800  800', 1, 1, 0, 1, 66);
INSERT INTO 'dance' VALUES (20313, '2021-04-14 09:39:57.64908+00', '2021-07-13 22:31:20.109413+00', 'Holden Together', 'HOLDEN TOGETHER', 1, 32, NULL, 1, 4, 1, 11262, '2017-07-01', 'For Elizabeth and Peter Holden’s first wedding anniversary.', 50, '8000/8000/8242/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5487, '2003-10-02 22:00:00+00', '2021-04-24 19:04:49.237428+00', 'Toyboys of Toowoomba, The', 'TOYBOYS OF TOOWOOMBA', 2, 48, 9999, 1, 4, 2, 108, '1995-06-01', 'Drewry writes that this dance is for Rebecca MacCrae of Brisbane, Australia. When Drewry visited for a dance weekend in nearby Toowoomba, she described a fantasy of having a toyboy wearing leather and giving her rides on a large motorbike. Drewry felt this needed a dance.', 88, '8484/8888/8888/8888/8008/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9343, '2002-04-30 22:00:00+00', '2021-08-02 04:18:19.827742+00', 'Mrs Elspeth Sinclair''s Strathspey', 'MRS ELSPETH SINCLAIRS STRATHSPEY', 3, 32, 9999, 2, 3, 18, 452, '1983-01-01', '', 67, '888/808/880/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20312, '2021-04-14 09:37:08.188745+00', '2021-06-23 00:07:27.108122+00', 'Stop Worrying and Have Fun', 'STOP WORRYING AND HAVE FUN', 2, 32, NULL, 1, 3, 42, 12036, '2019-02-01', '', 59, '888/844/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20310, '2021-04-14 09:33:12.445086+00', '2021-10-01 20:30:13.177586+00', 'Golden Sun of Early Spring, The', 'GOLDEN SUN OF EARLY SPRING', 2, 32, NULL, 1, 3, 42, 12035, '2019-01-01', '', 50, '880/888/800/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20319, '2021-04-14 10:51:43.295529+00', '2021-11-24 12:34:53.731333+00', 'Fifty and Fabulous', 'FIFTY AND FABULOUS', 4, 64, 5, 2, 3, 18, 11262, '2010-07-01', 'Devised by Colin Anderson and Tom McKinlay in July 2010, for Brigitte Cojean’s 50th birthday.', 62, '800/844/844/884', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20322, '2021-04-14 11:07:33.471558+00', '2021-11-25 07:28:31.338974+00', 'Chambéry', 'CHAMBERY', 4, 64, 5, 107, 54, NULL, 401, NULL, 'Devised by Ron Wallace in February 2020. This dance is dedicated to Danièle Landrieau, her committee and all the attendees of the Easter weekend planned in Chambéry in April 2020.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6048, '2000-02-21 23:00:00+00', '2021-04-14 21:37:07.138408+00', 'Shiftin'' Bobbins', 'SHIFTIN BOBBINS', 1, 32, 9999, 1, 3, 42, 82, NULL, '##>>

The dance is to a tune of the same name by Muriel Rimmer and obviously refers to either spinning or weaving. However, there is some uncertainty as to the specific spinning or weaving involved. The chorus of the Jute Mill Song which refers to weaving in Dundee includes the lines:



*Shifting bobbins coorse and fine  

They fairly mak’ you work for your ten and nine*



This has contributed to a view that the tune for the dance refers to Dundee jute weaving. However, it appears from other sources to be more likely that the composer of the tune was referring to the Lancashire cotton mills.

##<<



[More information welcome]





', 53, '822  888  888  800', 1, 1, 0, 1, 70);
INSERT INTO 'dance' VALUES (6025, '1999-04-19 22:00:00+00', '2021-04-14 21:44:27.492259+00', 'Shawlands Cross', 'SHAWLANDS CROSS', 2, 32, 9999, 1, 4, 1, 87, NULL, '', 62, '8844/0808/4848/4480', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5897, '1998-11-14 23:00:00+00', '2021-04-17 09:43:13.097426+00', 'Sark Bridge', 'SARK BRIDGE', 3, 32, 9999, 1, 4, 1, 212, NULL, '', 94, '8686  8888  8888  8686', 1, 1, 0, 0, 93);
INSERT INTO 'dance' VALUES (20323, '2021-04-15 08:56:06.0494+00', '2021-04-18 06:22:38.753315+00', 'Just Give Me a Kiss', 'JUST GIVE ME A KISS', 3, 32, NULL, 1, 3, 42, 12039, '2021-01-01', 'On average, a French person gives 30 kisses a day ! Kissing is a tradition that is very important to me but because of the pandemic, we only talk about wearing masks and maintaining a social distance. This dance was devised to keep the French kissing tradition alive and to give back a little love to everyone.  



In Vercors, where this dance was created, people are used to kiss one another twice to say hello, starting with the right cheek ! There is thus plenty of time in 2 bars to kiss twice. But in some other parts of France, people are used to kissing 3 or even 4 times…. And some start with the left cheek ! So make sure where your partner comes from before you start the dance to avoid any trouble for bars 27&28. We suggest you start with the right cheek!', 47, '880/800/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4878, '1997-11-25 23:00:00+00', '2021-04-18 10:52:50.774047+00', 'Nacton Hall', 'NACTON HALL', 1, 40, 9999, 1, 3, 42, 1164, NULL, 'According to *<<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-165-August-October-1983.pdf#page=7|The Reel>>* Nacton Hall is a village hall in Suffolk where local dances regularly meet for classes.', 56, '800/888/802/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20311, '2021-04-14 09:34:59.246465+00', '2022-06-07 09:48:22.834102+00', 'Pléiades', 'PLEIADES', 1, 32, NULL, 1, 3, 42, 11299, '2020-01-01', 'Dedicated to two constellations, one of stars and one of Earth‐observation satellites, and to friends made thereby.', 53, '800/822/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20320, '2021-04-14 10:53:17.287422+00', '2022-06-16 22:18:46.678004+00', 'Jig So Puzzled, A', 'JIG SO PUZZLED', 2, 32, NULL, 1, 3, 42, 11350, '2016-01-01', '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20314, '2021-04-14 09:42:58.834034+00', '2022-07-31 20:33:45.517128+00', 'Drawn in', 'DRAWN IN', 3, 32, NULL, 1, 3, 42, 12037, '2019-03-01', '', 53, '840/844/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3264, '1997-09-05 22:00:00+00', '2021-04-17 17:13:33.798918+00', 'Jig on the Bridge', 'JIG ON THE BRIDGE', 2, 40, 9999, 1, 107, 2, 82, NULL, 'Lacking an official source, here is an unofficial description.



4 x 40 bar Jig 



Dance starts in "Glasgow Highlanders" set positions, i.e. 1st and 3rd couples side by side on the men''s side, 2nd and 4th couples side by side on the ladies side facing 1st and 3rd couples, ladies on their partner''s right. 



1 -4 1L and 4L touch RH and cast to the left round their partner back to place 



5 -8 Middle four dancers dance half rights and lefts with no polite turn, finishing facing the ends 



9 - 16 All take two hands with the end dancers, and the two couples at the top and the two at the bottom dance a poussette ACROSS the dance, i.e. the top two couples change sides and the bottom two couples change sides. The poussette starts with the men dancing forwards, the ladies backwards. Finish in the following order: on the men''s side it should be 2L 3M 1L 4M, and on the ladies side 1M 4L 2M 3L. 



17 - 24 RSh reels of 4 on the sides. 



25 - 26 Middles give RH to ends and change places with a half turn 27 -28 Men give LH (1M to 3M and 2M to 4M) and turn once round to make a line up and down the middle of the set, 3M and 4M facing down, 1M and 2M facing up. 



29 - 32 Men give LSh to dance half a reel of four, finishing beside their partner. All couples are now one place anticlockwise round the set. 



33 - 40 Eight hands round and back.



Repeat from new positions.



Note: John Robertson provided this information, adding "I have no idea where this dance came from. I must have entered it into my card system in the 1970''s. It is a novel and fairly challenging, but enjoyable dance."', 80, '4224/8888/8888/5555/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11192, '2003-02-15 23:00:00+00', '2021-04-17 17:17:04.880661+00', 'CookCooksnest, The', 'COOKCOOKSNEST', 3, 40, 9999, 1, 4, 2, 3323, '2002-01-01', 'Dedicated to Jim Cook, of the London RSCDS Branch, in appreciation for organizing »The Reel goes Cuckoo«, a week of dancing and sightseeing, held at Kuckucksnest, Schlüchtern-Vollmerz, Germany, 18-25 August 2002.', 87, '8642/8888/8888/8888/8844', 0, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (11191, '2003-02-15 23:00:00+00', '2021-04-17 17:17:32.269946+00', 'Wedding in the Kuckucksnest', 'WEDDING IN THE KUCKUCKSNEST', 2, 32, NULL, 1, 3, 42, 2197, '2002-01-01', 'For bars 9-24 1c dances in Jig time while 2c+3c dance 8 bars in Strathspey time.', 62, '800/888/888/888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (6870, '2002-04-15 22:00:00+00', '2021-04-17 17:28:59.796755+00', 'Valley Full of Tree-Tops, A', 'VALLEY FULL OF TREETOPS', 1, 32, 9999, 1, 3, 42, 108, '1986-01-01', 'The notes for the dance say it was devised for the Mary Prentice weekend at Treetops Hotel, Aberdeen.



The title is a quotation from Midwinter by John Buchan: "At first it was like the twanging of fine wires in a wind, mingled with an echo of organ music heard over a valley full of tree-tops."', 53, '404/808/848/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20324, '2021-04-15 13:53:27.13789+00', '2021-07-07 08:33:07.62663+00', 'Jig for Kay, A', 'JIG FOR KAY', 2, 32, NULL, 104, 2, 4, 3325, '2021-04-01', 'Devised for Kay Senior as a warm up dance for Chiswick’s annual ball Kilts and Posh Frocks.



Kay who celebrated her 90th birthday in January 2021 founded Chiswick Scottish Country Dance Club in September 2002 and is its President and continues to be its driving force.', 100, '88/88/88/88', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5261, '2002-04-08 22:00:00+00', '2021-04-25 11:47:53.917252+00', 'Pinewood Place Rant, The', 'PINEWOOD PLACE RANT', 3, 32, 9999, 1, 4, 2, 118, '1985-05-01', 'Devised for a party given for the members of the demonstration team at John and Marjory Trew''s home in Pinewoods Place, Cataraqui Woods.', 75, '8008/8888/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1084, '2002-04-19 22:00:00+00', '2021-06-23 11:28:09.465318+00', 'Cataraqui Woods', 'CATARAQUI WOODS', 3, 32, 9999, 1, 4, 1, 118, '1983-01-01', 'The dance notes say this was "devised in collusion with Agnes Williamson as a surprise for John Trew, and first danced in December 1983 to celebrate his retirement, and move to the new family home in the Cataraqui Woods subdivision of Kingston."', 69, '8008/8888/8008/8088', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5961, '1997-09-08 22:00:00+00', '2021-04-16 11:54:05.580574+00', 'Scottish Man O'' War, The', 'SCOTTISH MAN O WAR', 2, 32, 9999, 5, 2, NULL, 151, NULL, 'The notes for the dance say that the Loch Lomond was a sailing ship which brought migrants to Australia in the years 1870 to 1908. It was known as the Scottish Man of War, because it had gun ports painted on its sides.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5905, '1997-04-03 22:00:00+00', '2021-04-16 22:41:03.191101+00', 'Saunter, The', 'SAUNTER', 1, 32, 9999, 1, 3, 42, 352, NULL, '', 38, '800/800/808/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20342, '2021-05-03 16:16:32.003656+00', '2021-05-03 16:30:58.192633+00', 'Seal of Approval, The', 'SEAL OF APPROVAL', 2, 32, NULL, 2, 3, 17, 440, '2021-05-01', 'Devised on May 1, 2021, after the Friday night Zoom class when Deirdre Bark taught her new dance, Selkie Fowk (Seal People in English, from an old Scottish legend) and Arlene Koteff gave it her seal of approval.', 67, '800/888/880/088', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3232, '1998-09-17 22:00:00+00', '2021-07-06 20:24:16.43189+00', 'Stormy Rush-Hour, A', 'STORMY RUSHHOUR', 3, 32, 9999, 1, 4, 2, 1013, '1998-03-06', 'The instructions were originally posted on the strathspey mailing list (<<sspey:11237|message 11237>>) though a <<sspey-thread:11261|subsequent message>> pointed out some problems with the start of the dance where Rights and Lefts for 3 couples is done in just 6 bars.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2649, '1997-09-03 22:00:00+00', '2021-07-28 08:16:02.627393+00', 'Grapevine, The', 'GRAPEVINE', 3, 32, 9999, 1, 3, 42, 971, '1985-01-01', 'Devised by Dorothea McKenzie for the 25th Anniversary Ball of the St. Catharines'' Branch, 1985. The Niagara reqion is noted for its many vineyards, and as a consequence, the production of many fine table vines.', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9576, '2000-09-06 22:00:00+00', '2021-04-17 09:40:19.873906+00', 'Breath of Spring', 'BREATH OF SPRING', 3, 32, 9999, 1, 4, 1, 2793, '1992-02-01', 'Devised in February 1992 while teaching reels of three -- to show that not all reels of three are the same. Dedicated to a special friend who plays golf "left-handed".', 44, '8880/4400/8000/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1300, '1997-04-03 22:00:00+00', '2021-04-18 11:39:54.906925+00', 'Come out of your Buckie', 'COME OUT OF YOUR BUCKIE', 1, 32, 9999, 1, 3, 42, 108, '1984-01-01', 'In the publication of this dance in *<<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-175-February-April-1986.pdf#page=2|The Reel>>* Drewry writes that it is for <<ddp: Zadworny, Margaret#1269>> of Nova Scotia who was born in Buckie. He also says that "Buckie" is the name for the whelk or sea-snail as well as the town on the Banff-shire coast. So the title "Come out of your Buckie" also means "Come out of your shell".', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4047, '1997-08-27 22:00:00+00', '2021-04-18 12:07:00.040527+00', 'Macleod''s Maidens', 'MACLEODS MAIDENS', 2, 40, 9999, 1, 3, 42, 108, '1986-01-01', 'Drewry writes that Macleod''s Maidens are rocky pinnacles in the sea just to the west of Idrigill Point at the south end of the (Duirinish) penisula which contains Macleod''s Tables on the extreme west of Skye.', 66, '860/888/888/888/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3106, '1997-09-04 22:00:00+00', '2021-04-18 12:25:33.123137+00', 'Invereshie', 'INVERESHIE', 3, 32, 9999, 1, 3, 42, 108, '1987-01-01', 'Drewry writes that Invershie is in Strathspey near Kincraig. It lies between the east shore of Loch Insh and the confluence of the Spey and the Feshie.', 50, '840/666/666/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4646, '2002-01-08 23:00:00+00', '2021-04-17 18:01:40.504645+00', 'Monymusk', 'MONYMUSK', 3, 32, 9999, 1, 3, 42, 459, '1786-01-01', 'In *Scotland Through Her Country Dances*, George S. Emmerson writes:



> »Sir Archibald Grant of Monymusk« is one of the great Strathspey tunes, composed by that very original composer in the traditional idioms, Daniel Dow (1732-83), music teacher in Edinburgh.



> The name is Gaelic, »moine mus(g)ach«, »nasty, filthy bog«. Not, perhaps, the most prepossessing of names. The laird of this territory in Aberdeenshire is Grant, Baronet of Monymusk. The Third Baronet, who died in 1796, is doubtless the one honoured by Daniel Dow.



One must always be wary when Emmerson uses words like »doubtless«, but in this instance his theory seems sound. There are other conjectures about the name which are more absurd.



Monymusk is 50 kilometers or so (30 miles) north-west of Aberdeen and can be found using Google Maps. <<http://www.scottish-places.info/towns/townfirst4089.html|The Gazetteer for Scotland>> contains more information about the place than anyone other than serious Scottish history buffs would find useful.



<<https://www.rscdslondon.org.uk/wp-content/uploads/2018/02/Reel-016-January-February-1954.pdf#page=3|Issue 16>> of <<ddpub:#73|The Reel>> contains <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/02/Reel-016-January-February-1954.pdf#page=3|an article>> about Monymusk.

', 59, '800  888  888  866', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (20327, '2021-04-18 00:15:51.832822+00', '2021-04-21 07:11:56.091085+00', 'C''est pour Vous', 'CEST POUR VOUS', 2, 48, NULL, 1, 4, 1, 12042, '2010-01-01', 'Célie (8 years old) and Maëlle (9 years old), two little Méaudre Reel dancers,  were bored at lunch time. They decided to create a dance to keep themselves busy. In France, the lunch break lasts usually 2 hours, from 11:30am to 1:30pm! It was enough for them to create the dance.  



Giving the dance in a huge box to Sophie Marchand, their SCD teacher, as a Christmas present in 2010, the two girls apologised : « c''est pour vous Mme Marchand ! C''est une danse mais nous n''avons pas trouvé de titre ! », this is for you Mrs Marchand ! It''s a dance but we couldn''t find it a proper title… So the title of the dance came naturally : c''est pour vous !  



The very first Méaudre Reel dance had just been created. We''ll have to wait for the pandemic and the lockdowns in 2021 to have the first SCD book published by the Méaudre Reel, a SCD group in the French Alps at 1 000 metres high.', 46, '8800/8000/8000/8080/4004/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3662, '1997-09-07 22:00:00+00', '2021-04-17 20:34:39.190563+00', 'Laird''s Medley, The', 'LAIRDS MEDLEY', 4, 64, 5, 1, 4, 1, 82, NULL, 'The progression is 213 for strathspey and reel sections with 1st couple dropping to the bottom after the reel section.', 69, '888/888/888/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (445, '2001-09-13 22:00:00+00', '2021-04-17 21:00:35.629281+00', 'Bees of Maggieknockater, The', 'BEES OF MAGGIEKNOCKATER', 2, 32, 9999, 1, 4, 1, 108, '1975-01-01', 'In the note on the original dance instructions, John Drewry wrote:  

*Maggieknockater is a hamlet two miles North-east of Craigellachie. In a field there beside the road is a large sign – Maggieknockater Apiary – hence the title of this dance.*  

Some years later, John noted that the apiary had closed and the sign had been removed.', 72, '8040  8888  8888  8044', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (5188, '1998-07-08 22:00:00+00', '2021-04-25 13:09:31.782879+00', 'Pawling Reel, A', 'PAWLING REEL', 2, 32, 9999, 1, 100, 11, 108, '1988-01-01', 'For the members of the New York Branch to mark the 25th Pawling Weekend.



In his footnote to the dance Drewry writes:

The title was chosen to teach the New York Branch Newsletter writers that they were not the only ones who could play with words. They suggested that I only deserved a "Dee" grade for many of my dances! Those who find the title truly "appalling" may use "THE BIG APPLE" as an alternative.', 69, '8008/8888/8448/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20332, '2021-04-19 10:34:21.012634+00', '2021-04-23 18:15:11.555685+00', 'Snow Wave, The', 'SNOW WAVE', 1, 40, NULL, 1, 4, 2, 12046, '2021-01-01', 'As no dancing was allowed in France because of the pandemic, the Méaudre Reel (France) decided to organise a weekly SCD creation workshop to keep its teenagers active. This workshop lasted for 3 months, from February to April 2021.  

The teenagers were impressive with their creations, so eager to be dancing again. We thus decided to gather all the Méaudre Reel dances and have a book printed: Dancing in Vercors Book1.  

The Snow Wave was created by one of the teenagers'' teams during a SCD creation workshop. One girl was dreaming of surfing in Martinique while the two others were dreaming of «surfing » down the ski slopes… but in pandemic times, only surfing on paper is possible!', 66, '8008/6446/0880/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4809, '2002-04-19 22:00:00+00', '2021-05-04 23:02:45.78208+00', 'Mrs Sybil Shaw', 'MRS SYBIL SHAW', 3, 32, 9999, 1, 3, 42, 513, NULL, 'The deviser writes: "This dance was written for my mother, in recognition of all she has done for the cause of Scottish Country Dancing. In Norwich, both my parents were founder members of the Branch, and for the last 25 years in Leicester my mother has been a keen dancer, a caring committee member and Secretary of the Branch for 7 years. She is well known as a cheerful ambassadress wherever she goes - throughout the Midlands, to St. Andrews and beyond! Thank you, Mum."', 59, '880/888/844/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19192, '2019-02-20 23:16:50.383777+00', '2021-04-20 17:54:58.885354+00', 'Ten Year Reel, A', 'TEN YEAR REEL', 1, 40, NULL, 1, 3, 42, 11786, '2017-08-01', 'This dance was devised for the 10th annivesary of the Méaudre Reel by one of Méaudre Reel''s "oldest" dancer, Célie, a 16-year old teenager.  



Dancing in Méaudre all started because in January 2006, there happened to be no snow in this little ski resort in the French Alps. To keep her pupils busy that winter, Sophie Marchand started to teach them Scottish country dancing instead of skiing during her PE lessons.  



In May 2018, for the Méaudre Reel''s 10th anniversary, 100 dancers coming mostly from France and UK took part in a  SCD weekend in Méaudre. Naturally, they all ended gathered for a photo souvenir.... around a marmot wearing a kilt ( Méaudre Reel''s mascot!) at the end of the weekend.', 63, '884/800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7980, '1998-04-24 22:00:00+00', '2021-04-18 17:58:52.33151+00', 'Tom''s Friends', 'TOMS FRIENDS', 3, 96, 9999, 4, 4, 3, 146, NULL, 'Dedicated to the memory of Tom Steele who died in December 1992.', 62, '8080/8080/0808/0808/4444/4444/4444/4444/8484/4848/8888/8888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20577, '2021-12-21 16:17:44.009074+00', '2021-12-21 16:17:44.009074+00', 'Both Ends of the Rainbow', 'BOTH ENDS OF THE RAINBOW', 1, 48, NULL, 1, 4, 2, 2682, '2021-11-24', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16959, '2016-05-27 22:04:52.133025+00', '2023-01-14 12:44:05.192077+00', 'Flight of the Sand-Martins, The', 'FLIGHT OF THE SANDMARTINS', 1, 40, NULL, 1, 110, 42, 908, NULL, 'May also be danced as a Jig.



First published in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/02/Reel-018-May-1954.pdf#page=3|The Reel #18>>, May 1954.



This appears to be a duplicate of <<ddd:#2223>> - a 48 bar version of the dance which is attributed to <<ddp:McConachie, Jack#251>>. See discussion in <<https://my.strathspey.org/dd/issue/2369/|issue 2369>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20328, '2021-04-18 23:13:21.622989+00', '2021-04-19 00:32:24.197317+00', 'Challenge accepted', 'CHALLENGE ACCEPTED', 1, 32, NULL, 1, 2, 76, 12021, '2021-01-01', 'Shelby Yahn stayed connected with Scottish Country Dancing during the pandemic by writing a new dance each week for 52 weeks. This dance was #50 and came from a request from Rebecca, a Milwaukee SCD teacher, to write a dance with a chain progression figure. Shelby writes: "I like chain progressions, and rarely see them in dances, so I was happy to oblige and grateful for the inspiration. I liked the idea of rolling a chain progression into a poussette, which is an uncommon combination. I also included a set and rotate which I think kicks off the dance with good momentum (which doesn’t die down until the chord at the end). Interestingly, this may be the only dance I’ve written without any solo for the first couple; every figure has both couples fully engaged, and neither gets the spotlight, so this dance is a group/team/set effort. This is also another four-figure-dance, isn’t too fussy, and as Rebecca pointed out, uses all three types of steps (setting, traveling, and slip). I like how this dance turned out and look forward to dancing it some day! The name is a shoutout to Barney Stinson from the show How I met Your Mother. He creates (usually ridiculous) challenges for himself, declares them ''challenge accepted!'', and doesn’t rest until he’s pulled them off, and I was happy to feel challenged to write a dance this week which highlights such a fun figure."

', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20340, '2021-05-03 10:03:30.688944+00', '2021-06-16 23:33:04.16732+00', 'Leila''s Mingle Jingle', 'LEILAS MINGLE JINGLE', 1, 32, NULL, 5, 1, NULL, 11114, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20002, '2020-06-04 21:47:54.529054+00', '2021-04-19 19:28:44.257808+00', 'Ellen Garvie of Clunie', 'ELLEN GARVIE OF CLUNIE', 1, 32, NULL, 1, 114, 1, 3325, '2020-02-01', 'Born in Clunie, north of Perth in 1920 Dr Ellen Garvie, with her father James Garvie, were leading lights in the formation and early years of RSCDS London Branch and later both were made Hon. Presidents, the first eight bars depict the centenary of her birth.', 81, '8888/8888/888/8000', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20330, '2021-04-19 08:42:21.012942+00', '2021-04-20 15:56:31.87297+00', 'Don''t Worry', 'DONT WORRY', 4, 32, 10009, 8, 105, 9, 12044, '2021-01-01', 'As no dancing was allowed in France because of the pandemic, the Méaudre Reel (France) decided to organise a weekly SCD creation workshop to keep its teenagers active. This workshop lasted for 3 months, from February to April 2021.  

The teenagers were impressive with their creations, so eager to be dancing again. We thus decided to gather all the Méaudre Reel dances and have a book printed: Dancing in Vercors Book1.  



This dance was created by one of the teenagers'' teams during their weekly SCD creation workshop.  



Lise and Manon were thinking with nostalgia, back to the time when they danced one of their favourite dances, Iona Cross, a dance for 6 couples. Then they thought it would be a good challenge for them to create a 6-couple dance : no need to worry, a 6-couple dance but not a difficult one, we promise …. so Don''t Worry !', 79, '888888/888888/800000/888888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20331, '2021-04-19 09:17:29.123529+00', '2021-04-20 15:57:57.22686+00', 'Thoughts of Romance', 'THOUGHTS OF ROMANCE', 3, 32, NULL, 1, 3, 42, 12045, '2021-01-01', 'As no dancing was allowed in France because of the pandemic, the Méaudre Reel (France) decided to organise a weekly SCD creation workshop to keep its teenagers active. This workshop lasted for 3 months, from February to April 2021.

The teenagers were impressive with their creations, so eager to be dancing again. We thus decided to gather all the Méaudre Reel dances and have a book printed: Dancing in Vercors Book1.

This dance was created by one of the teenagers'' teams during the weekly SCD creation workshop.



Three girls wanted to create a Strathspey and to start it with a 2 hand turn. « It is so romantic to dance this simple formation with a nice and handsome partner, looking at him straight in the eyes ! Do you remember in Newcastle when I danced with M…. ? As for me, my best partner ever was in St Andrews, it was a dream dancing a strathspey with A…. »  



But then, 2 other girls in the team simply said : yes, that can also be a nightmare when dancing with a poor dancer and not understanding a single word of what he says !! The 2 hand turn may last just too long !  



To have an intensive and magical dancing moment, don''t forget to choose a partner with lovely eyes.', 61, '842/808/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5766, '1998-09-30 22:00:00+00', '2021-04-20 16:37:29.161542+00', 'Ruffian''s Rant', 'RUFFIANS RANT', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 34, '444/800/800/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5710, '1997-09-13 22:00:00+00', '2021-04-20 19:35:05.937932+00', 'Round And Round The Radical Road', 'ROUND AND ROUND THE RADICAL ROAD', 2, 40, 9999, 1, 3, 42, 1246, NULL, 'The Radical Road is the winding way to the top Arthur''s Seat, a major tourist attraction in the city of Edinburgh.', 55, '800/888/844/888/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19194, '2019-02-20 23:26:06.248646+00', '2021-04-24 07:41:51.365665+00', 'Méaudre Reel, The', 'MEAUDRE REEL', 2, 40, NULL, 1, 3, 42, 3337, '2015-01-01', 'The dance and music were devised and composed for Sophie Marchand (Méaudre Reel- France) and presented to her on 2 May 2015 by Roddy Johnston, Seonaid Lynn, David Foreman and Diana Sarran as a token of gratitude for her warm welcome and in recognition of all she has done for Scottish Country Dancing in Méaudre, a tiny little village in the French Alps at 1 000 meters high.', 66, '822/888/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6616, '1998-04-19 22:00:00+00', '2021-05-01 21:57:52.156401+00', 'Tir Nan Og', 'TIR NAN OG', 4, 64, 10006, 1, 4, 1, 9998, NULL, 'The name means "Land of the Eternal Young".



It was published by the RSCDS in a leaflet along with dances collected by Mary MacNab. However, according to the notes, this is a traditional dance from Lewis in the Outer Hebrides and was collected by Iain MacFarlane (of Toronto). It is sometimes danced to mouth music.', 58, '7007  8008  8008  8448  7007  8008  8440  8448', 0, 1, 0, 1, 57);
INSERT INTO 'dance' VALUES (20640, '2022-01-24 14:56:00.081974+00', '2022-01-26 01:49:54.77973+00', 'Yes, We dance!', 'YES WE DANCE', 3, 32, NULL, 2, 3, 18, 11181, '2022-01-24', '', 77, '880/648/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14673, '2013-01-21 23:57:01.372186+00', '2022-01-29 17:08:35.118574+00', 'Rhymer''s Glen', 'RHYMERS GLEN', 1, 32, 9999, 1, 3, 42, 10716, '2006-01-01', '', 56, '888  880  888  800', 0, 0, 0, 0, 75);
INSERT INTO 'dance' VALUES (20609, '2022-01-09 19:04:53.606898+00', '2022-08-15 15:19:46.812605+00', 'Octogenarian, The', 'OCTOGENARIAN', 1, 32, NULL, 1, 3, 42, 1190, NULL, '"For Miss C.I. Mowat of Leven (Daisy)"', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20333, '2021-04-19 10:40:14.942079+00', '2021-07-13 22:33:54.902298+00', 'Joie de Rire', 'JOIE DE RIRE', 2, 40, NULL, 1, 3, 42, 12047, '2021-01-01', 'As no dancing was allowed in France because of the pandemic, the Méaudre Reel (France) decided to organise a weekly SCD creation workshop to keep its teenagers active. This workshop lasted for 3 months, from February to April 2021.  

The teenagers were impressive with their creations, so eager to be dancing again. We thus decided to gather all the Méaudre Reel dances and have a book printed: Dancing in Vercors Book1.  

Joie de Rire was created by one of the teenagers'' teams during the weekly SCD creation workshop. They loved the title Joie de Vivre and as it was great fun creating this new dance, they called it Joie de Rire.', 42, '844/880/808/884/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20334, '2021-04-21 06:46:09.048025+00', '2021-04-24 06:05:43.090103+00', 'Clémentine''s Strathspey', 'CLEMENTINES STRATHSPEY', 3, 32, NULL, 2, 3, 17, 11181, '2021-04-20', 'This dance is dedicated to Clémentine Job, teacher of the Scottish Country Dance Group *Cluaran* in Port-Louis near Lorient (Brittany, France) as a three-couple version of <<ddd:Cluaran>> (strathspey).', 67, '800/888/840/488', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5378, '2002-04-08 22:00:00+00', '2021-04-25 08:25:29.287331+00', 'Priory Street Strathspey, The', 'PRIORY STREET STRATHSPEY', 3, 32, 9999, 1, 3, 42, 635, NULL, 'The footnote for the dance says that the Branch class in York was originally held in the Presbyterian Church, Priory Street, York, and has now moved to the Priory Street Centre.', 53, '840/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5539, '1998-09-29 22:00:00+00', '2021-04-24 10:23:58.084059+00', 'Regent''s Favourite', 'REGENTS FAVOURITE', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 44, '800/888/800/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20336, '2021-04-24 09:05:49.100356+00', '2021-04-24 23:32:21.989267+00', 'Love Street Strathspey', 'LOVE STREET STRATHSPEY', 3, 32, NULL, 2, 3, 17, 2949, '2019-01-01', 'The Queensland Branch technique classes are held in a hall in Love Street, Spring Hill, Brisbane, and the dance was written in 2019 to introduce the beginners to strathspey steps.', 75, '888/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20335, '2021-04-21 23:00:11.576045+00', '2021-04-27 07:59:22.960241+00', 'Gravitas', 'GRAVITAS', 3, 32, NULL, 1, 3, 42, 11356, '2021-04-21', 'Wouter Joubert, the composer of the tune wrote on the Strathspey Mailing List:

<i>"I got around tonight to work out the chords for a tune in honour of the late Prince Philip,

Duke of Edinburgh, who lived just a few months short of a hundred. The tune was

composed on the day of his funeral."</i>



His comment on reading “Gravitas” was:

<i>"Those mirror reels, especially with the couples taking hands, has the feeling of a stately

procession. Your whole dance seems to embody the twists and turns of life which, even

when it comes full circle, does not finish precisely where it started because all those

twists and turns of life change and shape a person into who they are at the end."</i>', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6756, '1998-09-29 22:00:00+00', '2021-04-27 17:02:53.64896+00', 'Trysting Place, The', 'TRYSTING PLACE', 3, 32, 9999, 1, 2, 76, 44, '1985-01-01', 'Notes from Book 35

----------------------



The dance was devised by Iain Boyd, New Zealand, in 1985, and inscribed to Mary Murray of Vancouver B.C.



Mary''s former home in Falkirk, and still that of her parents, is in Tryst Road, opposite the traditional site of the Falkirk Tryst where cattle drovers from the Highlands, Lowlands and the north of England met to buy and sell their livestock and produce.



The Highland Schottische poussette was created by Jackie Johnstone of Dumfries and was first used in his dance "S. S. Johnstone" (Loreburn Set Volume II). In that dance, the men start back to back in the middle of the line and so progression been modified for use in "Trysting Place".





Notes extracted from elsewhere

-----------------------------------



The "Falkirk Tryst" was one of the largest livestock markets in Scotland with farmers and buyers gathering from all over Scotland and beyond. At its height times as many as 150,000 cattle, sheep and horses were droved there. The tryst was held up to three times a year in August, September and October. With the arrival of the railroad, numbers declined until the late 19th century. Nowadays, you still have the annual Falkirk tryst fun fair here.



For more also historical information on the Falkirk Tryst see <<https://falkirklocalhistory.club/around-and-about-the-area/themes/falkirk-trysts/|Falkirk Local History Society>>, <<http://ourstories.everyone-rs3.com/story/all-roads-lead-to-falkirk-gaelic-heritage-and-the-falkirk-tryst|Our Stories Falkirk>>, <<https://www.falkirkherald.co.uk/news/opinion/falkirk-tryst-cattle-market-fun-fair-998971|Falkirk Herold>> and <<https://en.wikipedia.org/wiki/Stenhousemuir#History|Wikipedia>>.





Pronuncation

---------------



The Scots pronuncation of “tryst”, according to the <<https://www.dsl.ac.uk/entry/snd/tryst|Dictionaries of the Scots Language>> is /trəist/. Don''t let yourself be confused by English dictionaries online which usually specify /trɪst/.', 69, '88  88  88  88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (9630, '2000-09-05 22:00:00+00', '2021-04-28 06:29:49.462562+00', 'Miss Milligan Lives On', 'MISS MILLIGAN LIVES ON', 2, 32, 9999, 1, 4, 1, 35, NULL, '*In my files I found this "Tribute to Our Teacher" and thought it would be a fitting way to finish this book. This little ditty was made up by some dancers in 1987 at Halifax, Nova Scotia, Canada, for their teacher, Bob Millar, of Toronto, Ontario, Canada, who was strict on detail according to them: (verses 3, 4, 5)*  



For Allemande hold watch out or he''ll scold;  

There''s no room in his mind for suggestion  

When he has just read what Miss Milligan said  

A Quibble is out of the question.  



When Bob''s teaching us Double Triangles,  

Which the class very frequently mangles,  

Miss Milligan high on her cloud in the sky,  

Is a vision he usually dangles.  



It''s Miss M that we''re trying to please,  

Though we hope Mister M won''t sneeze,  

''Cause we''re sore in each joint  

As we balance and point  

While we''re trying to dance up a breeze.', 66, '4440/4440/8888/4888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9077, '1999-07-25 22:00:00+00', '2021-04-28 14:00:42.42046+00', 'Brodick Castle Gardens', 'BRODICK CASTLE GARDENS', 4, 64, 17, 4, 4, NULL, 2626, NULL, 'Each repetition of the dance ends with everyone in their partner''s original place.



NB the instructions for this dance in some versions of original publication omit any mention of bars 23-24. The North Ayrshire branch confirms bars 17-24 should read:  

17-20    The first and third couples dance counter-clockwise half way round the set to original side, while the second and fourth couples dance left hands across in the centre.  

21-22    All four couples face their partners and set.  

23-24    All four couples turn their partner by the right hand once round, the second and fourth couples finishing in promenade hold, men with partners on their left.  

', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5549, '1999-04-19 22:00:00+00', '2021-04-29 19:11:57.170393+00', 'Renwick Reel', 'RENWICK REEL', 1, 32, 9999, 1, 3, 42, 87, NULL, 'The oiginal SCDDB entry was "The Renwick Reel" which is kept as an alias. The book just has "Renwick Reel".', 59, '888/844/855/855', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5005, '1998-04-19 22:00:00+00', '2021-04-29 20:50:03.354003+00', 'Nunspeet Frolic', 'NUNSPEET FROLIC', 2, 32, 9999, 1, 3, 42, 227, '1990-01-01', 'Intermediate level.



Devised for the Nunspeet Weekend, February 1990', 34, '880  800  800  822', 1, 1, 0, 1, 45);
INSERT INTO 'dance' VALUES (15781, '2015-01-11 17:07:59.344733+00', '2021-05-01 22:51:09.632798+00', 'McKenzie of Seaforth', 'MACKENZIE OF SEAFORTH', 7, 120, 9999, NULL, 117, NULL, 9998, NULL, 'This dance was collected by Mary Isdale MacNab from Donald Dingus in Kintail, Rosshire and was originally dedicated to Kenneth MacKenzie, Earl of Seaforth in 1771. It was published as a leaflet in 1968 by Mary MacNab''s neice Elizabeth Sutorius of San Diego, California.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20343, '2021-05-06 21:15:08.451197+00', '2021-05-06 21:15:08.451197+00', 'Belle Espagne, La', 'BELLE ESPAGNE', 3, 32, NULL, 1, 4, 1, 11582, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20593, '2022-01-07 14:35:38.784925+00', '2022-01-07 14:35:38.784925+00', 'Narrow Path into the Cavern, A', 'NARROW PATH INTO THE CAVERN', 1, 32, NULL, 1, 4, 1, 11514, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20325, '2021-04-16 15:42:45.554077+00', '2021-05-01 09:53:52.100626+00', 'Cramond Island', 'CRAMOND ISLAND', 1, 32, NULL, 1, 4, 1, 12040, '2011-01-01', 'The dance, Cramond Island, was written by Andrew Cook to celebrate the very first visit by the Méaudre Reel to Scotland in 2011.  



A group of dancers from Edinburgh (including Andrew Cook) met the "Scottish" dancers from a tiny little village in the French Alps in May 2009: the Méaudre Reel. They were so amazed to see French children enthusiastic about SCD that they invited all of them  in Scotland. After raising funds, the Méaudre Reel''s first tour to Scotland took place in 2011.  



Cramond is a district in the north west of Edinburgh but was once a separate, ancient village dating back to Roman times. Cramond Island is approximately 8 hectares and lies 1.5km off the foreshore. Being a tidal island it can be reached at low tide by a causeway – so we all walked out and had a picnic on the Island, after having fun with a treasure hunt through Cramond Village.  



Symbolism:  



Bars 1-8: *Shape of the island.*  

Bars 9-16: *Represents the water weaving round the concrete pillars of the causeway.*  

Bars 17-24: *This is the Forth Bridge that you can see clearly from Cramond Island.*  

Bars 25-32: *Waves in the Firth of Forth.*', 81, '8888/8000/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20337, '2021-05-02 18:06:51.542026+00', '2021-05-03 10:47:53.870333+00', 'Bug Hut, The', 'BUG HUT', 1, 32, NULL, 4, 4, NULL, 120, NULL, 'MiniCrib gives the source as "More Than Welcome 6". According to David Haynes this is one of six cassettes/CDs More Than Welcome I - VI recorded by Bobby Moore of Kirkcaldy. The dance description is shown on the CD insert.  The recording of "More Than Welcome 6" appears to date to 2002.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4879, '2003-01-27 23:00:00+00', '2021-05-03 08:47:24.443254+00', 'Nae Bother at A''', 'NAE BOTHER AT A', 2, 32, 9999, 1, 3, 42, 35, NULL, 'Boehmer writes that the title was *a favourite expression of one of our special teachers, Catherine Prentice. Dancers from years back will remember Catherine''s "Nae Bother at A''" after successfully putting us through the formations of a new dance. If she were teaching this rathet simple dance, I am sure you would hear her express herself in this way.*

', 44, '822/844/822/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4755, '1998-09-29 22:00:00+00', '2021-05-04 23:21:50.594131+00', 'Mrs Grant''s Fancy', 'MRS GRANTS FANCY', 3, 32, 9999, 1, 3, 42, 373, '1792-02-01', 'For a while both SCDDB and MiniCrib had a mistaken additional entry for this dance with the name shortened to "Grant''s Fancy". This has now been removed.', 50, '800/800/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4581, '1997-04-03 22:00:00+00', '2021-05-07 19:47:24.580125+00', 'Miss Siobhan''s Fancy', 'MISS SIOBHANS FANCY', 1, 32, 9999, 1, 3, 42, 418, NULL, 'In the original book the dance name is spelled "Soibhan" and dedicated to "Miss Soibhan Downing of Monbulk,Victoria". This is assumed to be a typo but is added as a spelling alias.', 44, '620/888/800/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11896, '2004-11-04 23:00:00+00', '2021-07-30 06:14:04.331163+00', 'Loch Ness Monster Reel', 'LOCH NESS MONSTER REEL', 1, 32, 9999, 1, 3, 42, 308, '2004-06-01', 'Written during a Furlongs holiday at Crieff, for Elizabeth Scott from Sevenoaks (Kent), whose husband requested that the word ‘monster’ was included in the title!!!!', 41, '800/822/888/800', 1, 1, 1, 0, 54);
INSERT INTO 'dance' VALUES (9617, '2000-09-05 22:00:00+00', '2021-05-01 14:57:32.721536+00', 'Charming Genius, A', 'CHARMING GENIUS', 3, 32, 9999, 1, 4, 1, 35, NULL, 'It was not easy for Miss Jean C. Milligan of Glasgow, as a SCD teacher, to define steps. She was met with howls of protest. Everyone was sure that his or her way was the only right and proper way and wouldn''t change. When she reintroduced the Poussette she provoked immediate criticism. A dancer of note voiced the feelings of the men, "Na, na, yer Grace, I dinna like this twa-handed Poussette. We''ve aye dune it gruppit." He had a point there but had to yield to Miss Milligan when she showed them the authority of an old MSS of 1790, which described it in detail. She was also accused of inventing new steps when she reintroduced the Skip Change of Step. She rigidly adhered to this discipline with the tenacity of a Border Terrier, they say. "Try to interfere in a meeting that she is chairing and see how far you get," was the word. These, of course, are necessary ingredients of genius.', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (441, '1997-11-25 23:00:00+00', '2021-05-01 19:36:23.497563+00', 'Because he was a Bonnie Lad', 'BECAUSE HE WAS A BONNIE LAD', 4, 112, 19, 1, 4, 3, 9998, NULL, 'This dance was taken from an old Jacobite dance of 1745 which was danced by followers of Prince Charles Stuart. 



The dance was arranged from a dance collected by Mrs MacNab’s brother in North Carolina, USA.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3428, '1997-11-18 23:00:00+00', '2021-05-01 19:51:08.207276+00', 'Kelvingrove', 'KELVINGROVE', 3, 152, 9999, 4, 4, 3, 9998, NULL, 'According to <<https://my.strathspey.org/dd/issue/2392/|issue 2392>> this dance was arranged from one collected by Mrs MacNab (where ‘arranged’ is surely a euphemism for changed/ devised/ choreographed).', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5128, '1999-08-06 22:00:00+00', '2021-05-01 19:57:58.836652+00', 'Over the Dee and over the Don', 'OVER THE DEE AND OVER THE DON', 2, 152, 9999, 107, 4, 3, 9998, NULL, 'The 152 bars consist of 32 bars for the entry, 88 bars to do the actual dance, and 32 bars for the exit.



The rivers Dee and Don are famous for encircling the city of Aberdeen in North-East Scotland. The weaving in and out of the dancers as they enter is supposed to represent the winding of the two rivers.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1881, '1999-08-06 22:00:00+00', '2021-05-01 20:48:42.755136+00', 'Earl of Errol''s Reel, The', 'EARL OF ERROLS REEL', 2, 200, 9999, 2, 3, 3, 9998, NULL, 'Originally known as The Hay Polka.



From <<https://my.strathspey.org/dd/issue/2382/|issue 2382>>: The original 200 bar dance was in 6/8 Polka tempo where polkaing around the set in ballroom hold was a main feature. The dance was changed to what we have today by Miss Milligan not entirely we are told with Mrs MacNab’s approval.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4043, '2002-03-02 23:00:00+00', '2021-05-01 21:20:15.998056+00', 'MacLeod of Dunvegan', 'MACLEOD OF DUNVEGAN', 1, 136, 9999, 107, 6, 3, 9998, '1956-01-01', 'Dedicated to Dame Flora McLeod of McLeod on the island of Skye



A dance for two sets of three couples. They stand looking down the room with a good space

between each set.



This demonstration dance has 



Part A   "Round the castle" {32}  

Part B   {32}  

Part C   "Wheels of Two" {16}  

Part D   "Women''s String" {24}  

Part E   "Men''s Solo" {24}  

Final figure {8}



As reported in <<https://my.strathspey.org/dd/issue/2291/|issue 2291>> this dance is also known as Dunvegan Castle which is the ancestral home of the McLeods. The third figure is also known as the Castle Walls.



According to some, the dance dates back to the 16th century. It is said to represent the formation of the Castle. The dance was collected from Allan McDonald of Truro, Nova Scotia, Canada. ', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4044, '2002-03-02 23:00:00+00', '2021-05-01 21:41:27.937117+00', 'MacLeod of Harris', 'MACLEOD OF HARRIS', 1, 144, 9999, 4, 4, 3, 9998, NULL, 'MacLeod of Harris is a Wedding Dance from the Isle of Harris. This dance was given to Mrs MacNab by Torquil MacLeod late of Truro, Nova Scotia.



"In the dance we see the visiting wedding guests, The reel danced. The chain is the friendship ring. The last figure is the going home. Each couple stands at the door of their Croft and waves goodbye to their friends."



*According to <<https://my.strathspey.org/dd/issue/2394/|issue 2394>> the above footnote is typical of the romantic approach Mrs MacNab saw the dancing. I feel it adds a charm of its own and typical of its time.*', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20594, '2022-01-07 14:38:31.63649+00', '2022-01-07 14:38:31.63649+00', 'Take Your Time', 'TAKE YOUR TIME', 1, 32, NULL, 1, 4, 1, 11514, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4045, '2002-03-02 23:00:00+00', '2021-08-02 21:19:03.357014+00', 'MacLeod of Lewis', 'MACLEOD OF LEWIS', 4, 96, 11, 107, 3, NULL, 9998, NULL, 'For three couples on three sides of a square (or semicircle).



This dance was collected from J McAskell of Stornaway by Mary Isdale MacNab. The dance purportedly dates back to 1649 “and was very popular in that period”. (The fact that we don''t seem to have other contemporary dances of similar complexity from independent sources makes that somewhat doubtful.)', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20407, '2021-07-30 09:08:15.637031+00', '2021-07-30 09:08:15.637031+00', 'Frances of Ecclefechan', 'FRANCES OF ECCLEFECHAN', 2, 0, NULL, NULL, NULL, NULL, 370, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20338, '2021-05-03 09:55:28.023134+00', '2021-06-16 23:36:07.214975+00', 'Bram''s Hungarian Dance No. 8', 'BRAMS HUNGARIAN DANCE NO 8', 1, 32, NULL, 1, 2, 76, 11114, NULL, 'Devised especially for Bram, who started to dance Scottish Dancing in 2020 with our Online Bo’ness Dance group. He picked up the dances so quick and his absolute favourite figure is the Figure of 8. The dance was devised originally for solo/1 couple dancing, but it can be danced in a 2 couples set.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4455, '1998-09-29 22:00:00+00', '2021-05-08 09:32:20.21033+00', 'Miss Devon''s Reel', 'MISS DEVONS REEL', 3, 32, 9999, 1, 2, 76, 263, '1795-01-01', 'Note: with normal size 4c sets there is no space for both 1c+2c and 3c+4c to dance their reels.  TacTalk 25 #3/4 (March 2001) says »this dance should never be placed on a programme«.  However, if a 3c set is used there is no lack of space.', 60, '88  88  80  88', 1, 1, 0, 1, 87);
INSERT INTO 'dance' VALUES (4439, '2002-10-15 22:00:00+00', '2021-05-08 10:55:32.524028+00', 'Miss Bunty Beaumont', 'MISS BUNTY BEAUMONT', 3, 32, 9999, 1, 3, 42, 93, '1989-05-01', 'Dedicated to Miss Bunty Beaumont, a loyal and long-standing teacher of Sydney Branch of the Royal Scottish Country Dance Society, who inspired many a dancer to love and cherish Scottish Country Dancing.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4438, '1998-09-29 22:00:00+00', '2021-05-08 11:00:27.011097+00', 'Miss Brown''s Reel', 'MISS BROWNS REEL', 1, 32, 9999, 1, 2, 76, 862, NULL, 'Adapted from B Cooke "A Selection of the Present Favourite Country Dances for the Year 1796.

Thus, B Cooke may be just the collector and not the devisor of the dance.', 56, '66  80  88  88', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (19976, '2020-05-16 17:45:06.614518+00', '2021-05-08 22:27:43.856572+00', 'Covid Lockdown Strathspey', 'COVID LOCKDOWN STRATHSPEY', 3, 32, NULL, 1, 2, 76, 11948, '2020-05-16', 'After (videos of) more than 50 dances published, we decided it was time to devise our own.

It is named Covid Lockdown Strathspey and represents this period.   



bar 1-8: the virus is born and spreads   

bar 9-16: lockdown: no contact with others, you can''t go around, you have to stay at home   

bar 17-24: the lockdown decreases, there are the first openings, something can be done but still no contact   

bar 25-32: returning to normal life, Covid was defeated   



The set of excellent videos made by the Graziani family during the lockdown can be seen on their you-tube channel:   https://www.youtube.com/channel/UCyojdYqjbxETi1C5mFptXtg/videos', 64, '84/88/88/88', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4517, '1998-11-07 23:00:00+00', '2021-05-08 23:16:13.007011+00', 'Miss Jeannie Carmichael', 'MISS JEANNIE CARMICHAEL', 4, 64, 5, 1, 4, 5, 921, NULL, 'Devised in honour of Miss Jeannie R. B. Carmichael for her leadership of Scottish Country Dancing in the United States of America.', 77, '8008  8448  8888  8888    8888  12 0 0 0  4444  8888', 0, 1, 0, 0, 76);
INSERT INTO 'dance' VALUES (4291, '2000-05-04 22:00:00+00', '2021-05-09 09:24:58.005643+00', 'Meeting of the Waters, The', 'MEETING OF THE WATERS', 1, 48, 9999, 1, 3, 42, 44, NULL, '"The Meeting of the Waters" was devised to commemorate the 1964-65 Summer School held in Wanganui, the ''River City''.



In a message to the strathspey mailing list (on 23/10/2019) Iain Boyd wrote:



*Note re bars 1-8:*



*In the first edition of “The Strathtay Album” the diagram clearly shows first woman and second man passing by left shoulders before dancing out to the sidelines at the end of the reel of four.*



*However, after the dance became popular with the release of Frank Reid’s recording on “Dance With The London Highland Club”, I changed the ending so that first woman and second man pass by right shoulders and dance directly across the set.*



*I did this because I noticed that the less experienced dancers were having difficulty getting out to the sidelines. The diagram was changed in a reprint of the collection, but, at the time, there was no way I could easily disseminate the change.*



*I prefer the second way of finishing the reel of four.*



*However, as the original way is probably ingrained in many dancer’s minds I am prepared to accept that there are now two ways of finishing the reel of four in this dance - an original and a subsequent way.*



*Consequently, dancers and teachers should check which ending is being danced in their local area.*

', 50, '880  800  800  844  888  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (4155, '1998-09-29 22:00:00+00', '2021-05-09 18:55:01.640602+00', 'Margaret Parker''s Strathspey', 'MARGARET PARKERS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1982-01-01', '"Inscribed to Mrs Margaret G Parker, MBE, MA, JP on her election as Chairman of the Royal Scottish Country Dance Society."', 62, '844  844  888  888', 1, 1, 0, 1, 83);
INSERT INTO 'dance' VALUES (4087, '1998-07-09 22:00:00+00', '2021-05-11 10:57:55.22967+00', 'Maid of the Mist, The', 'MAID OF THE MIST', 3, 32, 9999, 3, 5, 7, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for the weekend at Niagara in October, 1977.', 88, '8884/84884/88888/80888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11987, '2005-01-20 23:00:00+00', '2021-05-12 09:32:00.465257+00', 'Pittencrieff Panic', 'PITTENCRIEFF PANIC', 1, 32, 9999, 1, 3, 42, 3382, '2004-05-08', 'Seonaid Gent provided the instructions for this dance and commented :



"Pittencrieff Panic was a group of my friends (calling themselves the Town  House Posse) to celebrate my wedding to David on 8 May 2004.  The reception was held in the Glen Pavillion in Pittencrief Park in Dunfermline.  The Panic bit comes from the fact that it was only when they were having tea in between attending the wedding ceremony and coming to the evening reception that they realised no-one had written a dance for us."



Strathspey mailing group, Jan. 22, 2005, Message 40364, 

<<https://www.strathspey.org/lists/strathspey%40strathspey.org/t/40359/#m40364>>

', 62, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4024, '1998-04-12 22:00:00+00', '2021-05-12 17:46:33.189003+00', 'Macfarlanes'' Strathspey, The', 'MACFARLANES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 62, '1968-06-01', 'For Cathie and Iain Macfarlane.', 50, '844/808/880/880', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4022, '1998-01-05 23:00:00+00', '2021-05-12 17:51:21.632275+00', 'Macfarlane''s Fiddle', 'MACFARLANES FIDDLE', 1, 32, 9999, 1, 3, 42, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Jim Macfarlane, who plays the fiddle in Jim MacLeod''s Band.', 69, '808/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3900, '1997-04-03 22:00:00+00', '2021-05-13 21:22:51.997956+00', 'Lomond Strathspey, The', 'LOMOND STRATHSPEY', 3, 32, 9999, 1, 4, 1, 259, NULL, 'SCDDB has the recommended tune as <<ddt:Cornet''s Lass, The#321>> but the instructions specify a recording <<ddrec:Cornet''s Lass, The#4143>> which actually does not include that tune.', 75, '8080/8484/8888/8088', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8045, '1999-10-29 22:00:00+00', '2021-05-13 22:14:24.061158+00', 'Crummy Reel, The', 'CRUMMY REEL', 1, 32, 9999, 1, 2, 76, 1382, NULL, '', 52, '80/88/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6290, '1997-04-03 22:00:00+00', '2022-08-12 18:15:56.678345+00', 'Staten Island', 'STATEN ISLAND', 1, 64, 9999, 4, 4, 13, 270, NULL, '', 94, '8888/8888/8888/8888/6666/6666/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3859, '1999-08-09 22:00:00+00', '2021-05-14 19:24:06.934676+00', 'Loch Erichtside', 'LOCH ERICHTSIDE', 3, 32, 9999, 1, 3, 42, 9998, NULL, 'Collected in Oxton, Berwickshire.



The instructions for bars 9-16 mention 1st corners (9-12) and then 2nd corners (13-16) but the diagram for the start of bar 9 shows 1st couple facing 2nd corners. MiniCrib and Keith Rose diagram both follow the original diagram (dancing with 2nd corner first).', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3847, '2002-03-11 23:00:00+00', '2021-05-14 19:37:22.932057+00', 'Little Strathspey, The', 'LITTLE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1991-07-01', 'For Bill and Hope Little of Castle Douglas.', 56, '880/888/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4280, '2001-02-25 23:00:00+00', '2021-06-12 10:59:55.870534+00', 'McMarley''s Cross', 'MACMARLEYS CROSS', 3, 32, 9999, 2, 3, 17, 415, NULL, '', 83, '888  880  808  888', 0, 1, 0, 1, 83);
INSERT INTO 'dance' VALUES (3784, '1997-09-07 22:00:00+00', '2021-05-15 18:01:46.106794+00', 'Let us Dance at Medowie', 'LET US DANCE AT MEDOWIE', 3, 32, 9999, 1, 3, 42, 1072, NULL, 'Eric Ferguson''s crib for this dance had two variants he had been taught. In one bars 25-32 were:  1c+2c ½Poussette ; 1c+2c+3c turn RH. The online instructions have 2M+1W set advancing | turn BH to face partner on 1diag ; 1c+2c ½Poussette. This is now the version given in the e-crib.

', 62, '848  844  808  884', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (3781, '1997-04-03 22:00:00+00', '2021-05-15 18:20:47.198965+00', 'Leslie''s Strathspey', 'LESLIES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 62, '1965-03-01', '"For our daughter Leslie Joan. The women have precedence in the double half figures of eight, bars 5-8 and 13-16."', 50, '880/808/844/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15676, '2014-10-19 19:57:27.02741+00', '2021-05-16 09:41:51.384583+00', 'C''est Si Bon', 'CEST SI BON', 1, 32, NULL, 1, 3, 42, 74, '2010-02-01', 'The dance was devised to honour Catherine Bonner for her long term service to Scottish Country Dancing in the Sydney area, particularly to the St John''s Wahroonga and Gosford Classes. The dance was programmed as a ''Mystery Dance'' for the Gosford Class Social in February 2010, with music selected by Chris Duncan. The Social was a celebration of her 80th birthday, her service to Gosford Class and her receiving a Branch Award through Sydney Branch.  



The title refers to Catherine having been born in France, her name and her reputation in the Sydney area.



According to <<https://my.strathspey.org/dd/issue/2453/|issue 2453>> the dance was devised for the recording <<ddrec:Alasdair''s Reels#9783>>.', 56, '880/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3702, '1999-04-19 22:00:00+00', '2021-05-16 11:15:01.667432+00', 'Langside Ladies Jig', 'LANGSIDE LADIES JIG', 2, 32, 9999, 1, 4, 1, 87, NULL, '', 84, '8880/8888/8888/2666', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3678, '2002-04-19 22:00:00+00', '2021-05-16 17:38:49.709694+00', 'Lammermuir Hills, The', 'LAMMERMUIR HILLS', 3, 32, 9999, 1, 2, 76, 146, NULL, 'The Lammermuir Hills can be found south-east of Edinburgh, where they

form the boundary between East Lothian and the Borders. They are not

particularly high (up to 535 m or so) but steep and impassable in many

places. The main road from Edinburgh to England takes a detour around

them rather than going across.



The hills provide the setting for Sir Walter Scott''s novel *The Bride

of Lammermoor* as well as Gaetano Donizetti''s opera *Lucia di

Lammermoor* (which is based on the novel).

', 60, '88  66  66  88', 1, 0, 0, 1, 87);
INSERT INTO 'dance' VALUES (3666, '1998-01-05 23:00:00+00', '2021-05-16 17:52:29.314074+00', 'Lake Macquarie Reel', 'LAKE MACQUARIE REEL', 1, 40, 9999, 1, 3, 42, 1058, NULL, 'The dance was written for Lake Macquarie S.C.D. Class. Lake Macquarie is the name of a picturesque lake in the Newcastle area (NSW, Australia).



The instructions say both that is was devised by Lake Macquarie Juniors. And by Charles Park.', 52, '800/888/822/888/844', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3579, '2002-04-19 22:00:00+00', '2021-05-18 11:05:51.897191+00', 'Ladies of the Glen, The', 'LADIES OF THE GLEN', 2, 32, 9999, 1, 100, 2, 313, NULL, 'The title is from Walter Scott''s poem Glenfinlas:



*E''en the tired pilgrim''s burning feet*  

*At noon shall shun that sheltering den,*  

*Lest, journeying in their rage he meet*  

*The wayward Ladies of the Glen.*  ', 75, '8008/8448/8448/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3528, '1998-09-29 22:00:00+00', '2021-05-18 20:43:17.459318+00', 'Kiss me quick, my Mither''s coming', 'KISS ME QUICK MY MITHERS COMING', 1, 32, 9999, 1, 3, 42, 198, '1748-01-01', 'In the 1938 original edition of Book 12 the title of this dance was "Kiss Quick, My Mither''s Coming"', 44, '408  408  888  800', 1, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (8218, '2003-01-30 23:00:00+00', '2021-05-19 02:36:41.153826+00', 'Tucked into Edinburgh''s Canongate', 'TUCKED INTO EDINBURGHS CANONGATE', 1, 32, 9999, 1, 3, 42, 35, NULL, 'A few steps away from Holyrood Palace and well within frowning distance of John Knox''s house, is a unique shop. Tucked into Edinburgh''s Canongate, it is the only one in Britain to specialize in selling playing cards. I wondered that the shop would be so close to John Knox''s house. Wouldn''t he have disapproved? At his time the Kirk had banned playing cards as an invention of the devil. I wonder what John Knox would have said on learning he was depicted as the Joker in one pack! The earliest record of playing cards was aroWld 1370, although it is thought the Chinese played cards in the 10th century. I wondered why hearts, diamonds, spades and clubs were the symbols on cards. I learned that these were generally believed to have come from the French - hearts for the church and scholarships, diamonds for merchants, spades for the military and clubs for the peasants.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3492, '1998-01-05 23:00:00+00', '2021-05-19 10:54:31.983742+00', 'King''s Causeway, The', 'KINGS CAUSEWAY', 1, 40, 9999, 1, 3, 42, 313, NULL, 'For Win and John Baldwin.



According to the notes, the road leading southwards from Tain is known as the King''s Causeway, a name which commemorates the regular pilgrimages of King James IV to the shrine of St Duthac in that town.', 65, '800/888/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3475, '2002-08-29 22:00:00+00', '2021-05-19 16:38:10.094116+00', 'Kilt Maker, The', 'KILT MAKER', 1, 32, 9999, 1, 4, 1, 480, NULL, 'To Dot Stein, whose enthusiasm, creativity, and tailoring knowledge were instrumental in outfitting our group, and others, in Scottish regalia.', 53, '8000/8888/8440/8004', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3454, '1998-01-12 23:00:00+00', '2021-05-19 16:47:10.615596+00', 'Kicking Horse, The', 'KICKING HORSE', 1, 32, 9999, 5, 2, 76, 108, '1983-01-01', 'Drewry writes that this dance was "for the dancers of Alberta, Canada who invited me to teach at Banff Springs. Unfortunately, when I chose the name, I did not realise that The Kicking Horse Pass was over the provincial boundary in British Columbia!"', 94, '66/88/88/88 ', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3446, '1997-04-03 22:00:00+00', '2021-05-19 17:44:35.74227+00', 'Kettle Drum, The', 'KETTLE DRUM', 1, 32, 9999, 1, 3, 42, 173, '1969-03-19', 'The dance was named for the 3rd tune (Kettledrum) on the recording Galloway House by Jim Johnstone.', 63, '888/888/880/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (991, '2001-10-25 22:00:00+00', '2021-05-21 21:09:08.621689+00', 'By Candlelight', 'BY CANDLELIGHT', 3, 32, 9999, 1, 3, 42, 108, NULL, 'As per the leaflet posted on the Scottish Country Dance Teachers'' Association (Canada) website:



Devised - "Between 1972 and 1982"



Note - "The title was originally "A(nother) Candle for Mary" but was changed, at Mary''s request, to "By Candlelight".  The original probably sounded religious rather than like a Birthday Greeting!"



Other notes:



The dance was devised by John Drewry with the name "A Candle for Mary" for Mary Prentice''s Birthday.  The sheet bears a handwritten note "Name Changed at Mary''s request to:- "By Candlelight". Mary was a local SCD Teacher. The name "A Candle for Mary" has been kept as an alias because the dance is known by some under that name, and copies of the original sheet are still in circulation.



The dance was devised in the 1970ies, but the actual year is unknown.





', 56, '822/888/888/822', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8430, '1997-12-28 23:00:00+00', '2021-05-23 12:05:49.470934+00', 'Johnny Lad', 'JOHNNY LAD', 1, 32, 9999, 1, 4, 1, 173, NULL, 'The dance is named for the first tune on the track <<ddrec:Bothy Ballads>> reccorded by <<ddp:MacLeod, Jim and his Band#3009>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20595, '2022-01-07 14:41:29.867651+00', '2022-01-07 14:41:29.867651+00', 'Stout Man''s Strathspey, The', 'STOUT MANS STRATHSPEY', 3, 32, NULL, 1, 4, 2, 11514, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3340, '1997-09-05 22:00:00+00', '2021-05-23 12:22:26.056212+00', 'Johnny Lad', 'JOHNNY LAD', 1, 32, 9999, 1, 3, 42, 21, NULL, 'The instructions mention the tune as "Johnny Lad".  SCDDB currently links one called "Johnnie Lad". The ABC tune finder lists both names possibly for different tunes. It is not clear if SCDDB is currently suggesting the wrong one.', 56, '884/888/880/822', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3329, '1998-05-05 22:00:00+00', '2021-05-23 20:07:16.521396+00', 'John Paul Jones', 'JOHN PAUL JONES', 1, 32, 9999, 1, 3, 42, 108, '1964-01-01', 'Drewry writes in the notes to the dance that "John Paul was born in 1747 at Kirkbean in Kirkcudbrightshire. For a time he was apprenticed to a Whitehaven merchant. He assumed the name Jones when he settled in Virginia. He joined the American Navy in 1775, and in 1778 he led the famous surprise attack against Whitehaven. The motions in the dance represent the confusion in the town when it was attacked."', 53, '800/888/888/822', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3309, '1998-07-09 22:00:00+00', '2021-05-23 20:46:32.84719+00', 'Joe Foster''s Jig', 'JOE FOSTERS JIG', 2, 32, 9999, 2, 3, 18, 88, '1972-01-01', 'The notes to the dance say that "Joe and Iris Foster, who retired to live in Perthshire, celebrated their Silver Wedding on March 4th 1972 with a ceilidh at Keyham Village Hall in Leicestershire. Lindsay Ross, who travelled down specially to celebrate with Joe and Iris, composed the tune "Joe Foster''s Jig" for the occasion. Here is a Jig to go with the music."', 48, '484  686  802  808', 1, 1, 0, 1, 64);
INSERT INTO 'dance' VALUES (12532, '2005-08-29 22:00:00+00', '2021-05-28 00:11:41.987397+00', 'Snow on the Mountain', 'SNOW ON THE MOUNTAIN', 2, 32, 9999, 1, 3, 42, 2408, '2003-01-01', 'Devised 2003 by Lara Friedman-Shedlov for Audrey McClellan''s novel "The White Rose of Scotland," the

second in her trio of romance novels about life on the fictional island of Eilean Dubh.  

I believe the original deviser of the formation "petronella double triangles" was John Bowie Dickson, in

the dance "Pinewoods Reel."', 63, '800/888/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3268, '1997-08-30 22:00:00+00', '2021-05-24 10:27:12.015293+00', 'Jiggery Pokery', 'JIGGERY POKERY', 2, 32, 9999, 1, 3, 42, 21, '1988-01-01', 'For Ron and Evelyn Wake on the occasion of their Silver Wedding. Nov 88.', 61, '860/888/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3267, '1997-09-04 22:00:00+00', '2021-05-24 10:30:53.624114+00', 'Jig for Mrs Dunn, A', 'JIG FOR MRS DUNN', 2, 32, 9999, 1, 2, 76, 1023, NULL, 'The notes say the dance was "composed by the children from Mrs Norah Dunn''s chiLdren''s class when she left the Helensburgh district."', 52, '80/80/88/88', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3388, '1998-01-05 23:00:00+00', '2021-05-24 11:27:33.055722+00', 'Just for You', 'JUST FOR YOU', 1, 32, 9999, 3, 5, 7, 104, NULL, 'In the original text the dance name is spelt "JUST FOR YOU".', 74, '84844/88888/80800/86866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13834, '2011-08-05 22:00:00+00', '2021-05-25 08:38:55.48349+00', 'Three Gentlemen', 'THREE GENTLEMEN', 3, 32, NULL, 2, 3, 17, 10293, '2010-01-01', 'Devised: 2010



Three Gentlemen is a three-couple set dances inspired by The Gentleman by Roz Scott Huxley (1986).', 50, '844/844/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3250, '1998-04-12 22:00:00+00', '2021-05-25 12:21:05.246666+00', 'Jewel in the Navel, The', 'JEWEL IN THE NAVEL', 2, 32, 9999, 1, 3, 42, 108, '1995-06-01', 'The notes say this is "for Dr. Heinz Duewell of Newcastle N.S.W." and a footnote explains that Heinz divides Scottish Country dancers into two categories:



  1. Below the navel dancers: who are most concerned with perfection of footwork and technique;



  2. Above the navel dancers: who dance for the joy of moving to stirring music and meeting like minded people.  ', 56, '880/808/888/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3129, '2001-09-13 22:00:00+00', '2021-05-26 09:16:51.982266+00', 'Irish Rover, The', 'IRISH ROVER', 1, 32, 9999, 1, 3, 42, 87, NULL, '##>>

A dance written to the well-known Irish song about a mythical sailing ship:  

*… an elegant craft, she was rigged fore and aft  

And how the Trade Winds drove her  

She had twenty-three masts and withstood several blasts  

And they called her The Irish Rover*

##<<



Note on “Lead or Dance on [1-4]”.  The original wording used by Cosh in “22 SCDs” was “lead”.  The RSCDS republished the dance in "Thirty  Popular Dances Vol.2" in November 2019. Page 36, and used “Dance”.  So that is now the correct handing.

', 56, '844/844/888/844', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (3047, '1998-01-05 23:00:00+00', '2021-05-26 10:19:10.573004+00', 'I''ll Ne''er Leave Thee', 'ILL NEER LEAVE THEE', 1, 32, 9999, 1, 3, 42, 976, '1740-01-01', 'The notes say this may be done in a 4 or 5 couple set.', 55, '844/844/860/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20345, '2021-05-26 23:21:32.783585+00', '2021-05-30 09:21:56.336836+00', 'Heinz Rieger''s Strathspey', 'HEINZ RIEGERS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 440, '2018-04-13', 'Devised on April 13, 2018, in memory of Heinz Rieger, who loved Scottish country dancing.



Suggested Music: Bobby Brown, *Celtic Fire in the Music*, “Strathspeys” (Disc 2, Track 3)', 63, '880/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20346, '2021-05-26 23:23:11.029625+00', '2021-05-30 09:22:23.030909+00', 'John Clark''s Jig', 'JOHN CLARKS JIG', 2, 32, NULL, 1, 3, 42, 440, '2011-10-01', 'Devised by Ann Campbell in October 2011 for John Clark, to thank him for always rearranging the furniture at the Board meetings so that I have a desk for my papers and a place to stand where I feel I am part of the group.', 56, '800/866/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20344, '2021-05-26 23:17:21.62205+00', '2021-05-27 17:54:50.102829+00', 'Chocolate Bunnies', 'CHOCOLATE BUNNIES', 1, 32, NULL, 2, 3, 17, 440, '2021-03-31', 'Devised on March 31, 2021, after Arlene Koteff’s Zoom dance class the night before.', 94, '888/888/288/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3679, '1998-01-05 23:00:00+00', '2021-05-30 11:38:51.834333+00', 'Lamont Of Cowal', 'LAMONT OF COWAL', 1, 32, 9999, 1, 3, 42, 352, '1991-05-12', 'The notes say that "according to Highland tradition the Lamonts were the most ancient proprietors of Cowal."



The <<ddpub:Blue Book#604>> gives the music as "The Isle". Recordings with that name are actually Jigs whereas this dance is described as a Reel.', 44, '844/844/844/800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17285, '2016-09-07 22:44:18.607829+00', '2021-05-27 19:32:36.033623+00', 'Bobby Brown''s Fifty Musical Years', 'BOBBY BROWNS FIFTY MUSICAL YEARS', 2, 48, NULL, 3, 5, 7, 440, '2010-08-24', 'Devised for Bobby Brown to celebrate his 50 years as a musician in 2011.', 63, '88888/80800/88888/84844/84844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2955, '1997-09-17 22:00:00+00', '2021-05-27 22:07:32.79418+00', 'Holland Park', 'HOLLAND PARK', 2, 32, 9999, 1, 3, 42, 997, '1981-01-01', 'The instructions suggest using either of the recordings La Flora or Tayport Beauty from the album for book 27.



In the notes, George Swirles reports that the dance was introduced "at a session of Scottish Country Dancing held in Holland Park, London, in 1981 for the entertainment of tourists in London who were invited to take part in many of the dances.... At Holland Park all nationalities danced and all ages. I have had partners varing from a delightful, little girl of about six or seven to a lady who must have been about 60 or more."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20347, '2021-05-26 23:25:24.919158+00', '2021-05-30 09:22:47.388173+00', 'Stefan''s Strathspey', 'STEFANS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 440, '2016-11-26', 'Devised by Ann Campbell on November 26, 2016, in fond memory of Stefan Korus.', 69, '888/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2882, '1998-01-05 23:00:00+00', '2021-05-30 12:04:28.032816+00', 'Herring Bone', 'HERRING BONE', 1, 32, 9999, 1, 4, 1, 352, '1990-06-01', 'The <<ddpub:Blue Book#604>> gives the music as "Campbell''s Hornpipe" as recorded by <<ddp:Frank Reid and his Band#2414>> on the album <<dda:Dance Time#149>> though that recording does not explicitly mention the tune "<<ddt:Campbell''s Hornpipe#237>>" (possibly just missing from SCDDB listing?).



However the <<ddpub:Kiwi Book#695>> suggests <<ddrec:Buchan Gate#1998>> by the <<ddp:Olympians Scottish Dance Band#3024>>.', 56, '4444/4444/8440/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3085, '1997-09-15 22:00:00+00', '2021-05-30 10:33:56.738363+00', 'Thane of Argyle', 'THANE OF ARGYLE', 1, 32, 9999, 1, 3, 42, 352, '1991-04-26', 'The instructions in the <<ddpub:Blue Book#604>> give the music as "Baldy Bain''s Fiddle" on the record <<dda:Ready...And!#206>> by <<ddp:Brown, Bobby #2085>>. It is assumed the track normally spelled as "Bauldy Bain''s Fiddle" is intended.', 53, '888/800/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10, '1998-04-04 22:00:00+00', '2021-06-01 19:41:14.61288+00', 'Abegweit', 'ABEGWEIT', 3, 96, 9999, 4, 4, NULL, 108, '1990-01-01', 'Pronounced "A-beg-wait"



Abegweit is the Micmac (now referred to as Mi''kmaq) name for Prince Edward Island and means "cradled upon the waters".



This dance is one part of a set of three Scottish country dances devised to mark the Canada Winter Games hosted by Prince Edward Island in February 1991 and in support of the Island Tourist Theme for 1991 - The Road to the Isle.  The other dances in this set are Midwinter and Marylou''s Reel.



At the request of the PEI Scottish Country Dancers, J. Duncan Keppie composed the tune Rustico for this dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2717, '2001-04-22 22:00:00+00', '2021-06-01 20:55:42.168839+00', 'Haddo House', 'HADDO HOUSE', 2, 32, 9999, 1, 3, 42, 91, NULL, 'The notes say that  Haddo House near Tarves was gifted to the National Trust in 1978 on the death of David Gordon, Lord Aberdeen. The movements of the dance represent the two wings of the house.', 50, '822  800  866  888', 1, 1, 0, 1, 66);
INSERT INTO 'dance' VALUES (2707, '1997-09-03 22:00:00+00', '2021-06-01 21:50:17.981902+00', 'Gushet Neuk', 'GUSHET NEUK', 2, 32, 9999, 1, 3, 42, 62, '1968-11-01', 'Devised in November 1968 for all members of an Australian Club. The original name was "Let''s all go walkabout" by which it is probably known in Australia. The present name is that of the tune composed by Jimmy Reith of Aberdeen.', 55, '660/730/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7705, '1997-09-02 22:00:00+00', '2021-06-02 10:45:34.098335+00', 'Ettrick Shepherd, The', 'ETTRICK SHEPHERD', 3, 32, 9999, 2, 3, 30, 313, NULL, 'For Hazel and Alan Ashment.



According to the notes, the poet, James Hogg (1770 - 1835) was known as The Ettrick Shepherd.



The starting positions are 3,2,1 on the men''s side and 1,2,3 on the women''s side and their progression is 1,3,2 and 2,3,1 respectively.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3646, '1997-09-07 22:00:00+00', '2021-06-02 10:49:07.825676+00', 'Laggan Falls, The', 'LAGGAN FALLS', 3, 32, 9999, 2, 3, 18, 313, NULL, 'For Phil Bowlen of Bundoora.



The Laggan Falls are on the Isle of Mull, two miles to the north of Ulva Ferry, near the shores of Loch Tuath.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2688, '1997-09-03 22:00:00+00', '2021-06-02 10:56:37.348898+00', 'Greyfriar''s Bobby', 'GREYFRIARS BOBBY', 3, 32, 9999, 2, 3, 18, 313, NULL, 'Near Greyfriars Church in Edinburgh stands a fountain in memory of Greyfriars Bobby, a faithful terrier, who watched over his master''s grave for fourteen years.', 83, '800/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2642, '2003-01-25 23:00:00+00', '2021-06-02 11:37:04.616621+00', 'Granny Knot, The', 'GRANNY KNOT', 1, 32, 9999, 1, 3, 42, 35, NULL, 'The notes say this dance was "written for Dr. Peter McBryde, a teacher, and his wife, Marion, who have contributed much to Scottish Country Dancing in Canada through the Teachers'' Association and Tactalk."



A footnote explains that a Reef Knot tied incorrectly is known as a ''Granny Knot''. In the S.C.D. formation called ''The Knot'', dancers turn with the left hands back to places, whereas in the last 4 bars of this dance they turn to places with the right hands, suggesting the above title.', 56, '888/880/848/840', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2580, '2002-05-01 22:00:00+00', '2021-06-02 23:57:11.529341+00', 'Heathcote Hall', 'HEATHCOTE HALL', 1, 32, 9999, 1, 3, 42, 74, '1993-01-01', 'According to the notes for the dance "Heathcote Hall is a house that was built in the 1860''s not long after the Illawarra railway line was constructed. When the dance was written, the front of the dance devisor''s home faced the Hall across the street. (The devisor has now moved). The part of Heathcote containing the Hall is within an enclave in the Royal National Park and its gazebo tower used to be used for a fire lookout."', 63, '884/888/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2538, '1997-09-03 22:00:00+00', '2021-06-03 14:22:04.350032+00', 'Glenfinnan Reel, The', 'GLENFINNAN REEL', 1, 32, 9999, 1, 3, 42, 960, NULL, 'One of a set of three dances (reel, jig and strathspey) comprising the Glenfinnan signature dances which were premiered as a medley at the Gala Day in Hamilton, Ontario in May 1976.', 50, '880/844/844/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2497, '1997-09-03 22:00:00+00', '2021-06-03 19:38:11.716045+00', 'Glasgow Gardens', 'GLASGOW GARDENS', 3, 32, 9999, 1, 3, 42, 108, '1988-01-01', 'For the Glasgow Garden Festival in Summer 1988.', 50, '800/844/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1782, '2001-11-21 23:00:00+00', '2021-06-03 21:33:58.35301+00', 'Duke and Duchess of Edinburgh, The', 'DUKE AND DUCHESS OF EDINBURGH', 1, 40, 9999, 1, 3, 42, 846, NULL, 'This dance originally came out in 1948, when the current Queen used to

be »the Duchess of Edinburgh«. Her husband, Prince Philip, of course

still uses the title. The RSCDS officially »blessed« it by including

it in Book 39 when it came out in 1996, to celebrate the Queen''s 70th

birthday.



The following corrections were included on a loose sheet "Notes on Dances by Bob Grant June 1996", when Book 39 was first sold in the Summer School bookshop:



1-8  1st woman ''hovers'' while 1st man faces top before casting



9-16  Nearer hands



25-32  Second time through, 1st couple crosses to the bottom giving left hands



This dance had been published originally in 1948 by Rae, Macintosh with original music by John Robertson (The Duke and Duchess of Edinburgh and Birkhall).  The 1996 RSCDS Book 39 incorrectly named the first tune as Dunnottar Castle from the Middleton Collection (this is the music used for Miss Florence Adams from RSCDS Book 38). An erratum slip was produced.', 57, '888  800  888  822  888', 1, 1, 1, 1, 76);
INSERT INTO 'dance' VALUES (2458, '2001-08-19 22:00:00+00', '2021-06-05 10:25:42.561836+00', 'Get Weaving', 'GET WEAVING', 2, 32, 9999, 1, 3, 42, 108, '1994-07-01', '"For Ron Wallace and Gary Thomas of Santa Rosa, California, who have acquired a loom to get weaving at home."', 56, '800/844/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2431, '1998-11-14 23:00:00+00', '2021-06-05 10:50:18.300204+00', 'Geneva Park', 'GENEVA PARK', 2, 40, 9999, 1, 4, 1, 62, '1965-07-01', 'The notes say this was devised in July 1965 for our annual Branch Weekend held at Geneva Park, Lake Couchiching, in September. The entry into the lead-up after reel of four requires care.



The instructions also say this is for "3 couples in four couple set". However 1st couple end in 4th place with 4th couple stepping up, so for SCDDB this is a 4 couple dance with progression 2341.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2423, '2001-11-20 23:00:00+00', '2021-06-05 11:24:34.197632+00', 'Geese in the Bog, The', 'GEESE IN THE BOG', 2, 32, 9999, 1, 3, 42, 550, '1995-01-01', 'The notes for the dance say that "the name of the tune seemed to fit the dance. conjuring up images of strings of geese meandering aimlessly yet purposefully, all the time lost."', 63, '880/844/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15884, '2015-01-22 12:32:00.899898+00', '2021-06-05 11:42:00.358775+00', 'Gardener''s Delight, The', 'GARDENERS DELIGHT', 2, 40, 9999, 1, 3, 42, 3694, '2007-01-01', 'Suggested Music: Spring Chicken recorded by David Cunningham on The Silver Thistle Collection CD.



The notes say this dance is for "Carol Anderson who contributes so much to keep the Sutton Coldfield RSCDS running smoothly and the memory of Barry Priddey’s dances alive by organising an annual workshop of his dances. She enjoys her garden as much as her dancing hence the title."', 55, '888/880/888/800/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2357, '1997-11-18 23:00:00+00', '2021-06-06 10:10:24.79766+00', 'Frost and Snow', 'FROST AND SNOW', 3, 32, 9999, 1, 2, 76, 9998, NULL, 'Frost and Snow (together with A Trip to Glasgow) were the two new dances taught by Jean Milligan at the Palace of Art in Glasgow on 3 December 1977. Jean Milligan died in 1978 and this was the last time she taught in Glasgow.', 52, '80  88  44  88', 1, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (1561, '1997-04-03 22:00:00+00', '2021-06-19 21:21:46.192795+00', 'Darling Diversion, The', 'DARLING DIVERSION', 3, 32, 9999, 1, 4, 1, 352, '1991-05-06', 'According to the dance notes, during the latter half of the 18th century, Scottish Dancing was known as the Darling Diversion.', 67, '8440/8880/8464/8088', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10003, '2001-07-19 22:00:00+00', '2021-07-10 04:25:03.99196+00', 'Aad''s Farewell to Delft', 'AADS FAREWELL TO DELFT', 1, 64, 9999, 4, 4, 3, 1049, '1997-01-01', 'Dance devised for Aad Boode on the occasion of his departure to Dublin, July 1997. To thank Aad for all he did for the Delft Branch during 28 years.', 69, '6666/6666/8080/0808/8080/0808/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18376, '2018-06-11 09:15:11.252059+00', '2021-06-06 11:25:26.308082+00', 'White Tornado, The', 'WHITE TORNADO', 1, 32, NULL, 1, 3, 42, 2766, '2011-05-01', 'This dance is for my second cat, Ajax. Ajax was purported to be a pure-bred Persian without papers. He was a long-haired white cat with a slightly pushed-in face, but without the extreme features of a Persian. I found him in a newspaper ad, and the day I picked him up he earned his name.  

I was driving home with him in a cardboard carrying case when I stopped to pick something up at the store (only away 10 minutes really). When I returned he was nowhere in sight. After searching the car multiple times, I started driving sadly home, when I heard him crying. He had crawled up behind the dashboard. I finally extracted him by opening the glove compartment and pulling him out. At that time the ad for Ajax Cleanser called it the ‘white tornado’ and I felt it applied to my little white kitten.  

He was loving and fun and had a great time teasing Misty.', 50, '888/800/880/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14739, '2013-03-15 23:47:17.355862+00', '2021-06-06 11:55:33.215555+00', 'Portsonachan', 'PORTSONACHAN', 2, 32, NULL, 1, 3, 42, 2682, '2013-03-16', '1-8 First couple dance a figure of eight on the sides, first woman in front of the second, and behind the third; first man similarly. Hands should be given where possible.



9-16 First couple dances a figure of eight across the dance around the second couple.



17-24 First and second couples dance four hands across and back, finishing in the centre ready for a poussette.



25-32 First and second couples dance a poussette.



Repeat, having passed a couple.



Devised 16th March 2013. This is a teaching dance for our influx of beginners who were having dificulty with figures of eight across/on the sides. Plus I had just taught poussette. Portsonachan means \port of peace", and is a Hotel on Loch Awe where Kristin and I stayed during Easter 2012. The setting is quite lovely, and we had a great time, while experiencing a rather surreal (but friendly) hotel experience involving lost bookings, cold water, delightfully eccentric Spanish waiter, remarkable furniture and many other adventures. 

', 37, '800  800 880  880', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (20349, '2021-06-07 16:05:42.152965+00', '2021-06-07 16:05:42.152965+00', 'Ngaio Gold', 'NGAIO GOLD', 3, 32, NULL, 3, 5, 16, 12050, NULL, 'To celebrate the 50th anniversary of the Ngaio SCD Club. The original tune (name unknown) was composed by Aileen Logie.



Source: <<https://youtu.be/mKwK0FGn2oU|youtube video>>.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5768, '2002-05-04 22:00:00+00', '2021-06-12 18:16:23.117919+00', 'Rumbledethumps', 'RUMBLEDETHUMPS', 2, 48, 9999, 1, 114, 14, 3126, '1994-01-01', 'According to the dance notes, Rumbledetbumps is the Border version of Bubble and Squeak. Rumbled means "mixed" and thumped, means "bashed together". There is plenty of the former, but hopefully none of the latter! With thanks to Liverpool RSCDS Demonstration Team who gave their time to practice this dance.', 88, '4444/8888/8448/8888/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2173, '1999-10-16 22:00:00+00', '2021-06-08 09:26:31.554661+00', 'Finlay Stewart Skinner', 'FINLAY STEWART SKINNER', 3, 32, 9999, 1, 3, 42, 2672, NULL, 'The notes say that "the original tune for this dance was commissioned by Heidi Skinner for her husband, Finlay. Finlay, originally from Edinburgh, was recently enveigled into Scottish Country Dancing by Heidi, son Colin and daughter Sheena, all enthusiastic dancers with the Basel group in Switzerland."', 56, '844  844  888  880', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (2157, '1997-04-03 22:00:00+00', '2021-06-08 12:51:36.935474+00', 'Fife Meeting, The', 'FIFE MEETING', 1, 32, 9999, 1, 3, 42, 146, '1991-07-01', 'The notes say this is "for Susan and Alan Carr on the occasion of their wedding in July 1991."', 58, '864/844/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2016, '2002-12-16 23:00:00+00', '2021-06-11 20:24:30.800152+00', 'Ewan Telford''s Strathspey', 'EWAN TELFORDS STRATHSPEY', 3, 32, 9999, 1, 4, 2, 881, '1991-01-01', 'The notes for the dance say that "Alison commissioned the tune for her husband Ewan''s Christmas in 1990. She devised the dance for his birthday in January 1991."', 81, '8008/8888/8888/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1974, '1997-04-03 22:00:00+00', '2021-06-12 08:29:07.204448+00', 'Emerald Isle, The', 'EMERALD ISLE', 1, 32, 9999, 1, 2, 76, 418, NULL, 'Inscribed to Jennifer Williamson of Monbulk, Victoria.', 69, '88/88/88/88', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1961, '1998-03-11 23:00:00+00', '2021-06-12 09:48:10.664696+00', 'Ellie''s Jig', 'ELLIES JIG', 2, 32, 9999, 1, 3, 42, 51, '1990-04-06', 'The dance, named for the devisor''s wife Ellie, was first taught at the Lethbridge, Alberta, Workshop, April 6-8, 1990. 



The idea for the non-progressive Knot occurred simultaneously to Ellie and me while we were watching a Knot being performed one evening. An alternative name for the figure is the "Slip Knot."', 39, '432  432  880  880', 1, 1, 1, 1, 52);
INSERT INTO 'dance' VALUES (1959, '2002-04-19 22:00:00+00', '2021-06-12 09:57:58.657255+00', 'Ellen''s Request', 'ELLENS REQUEST', 3, 32, 9999, 4, 55, NULL, 870, NULL, 'Arrangement: two couple longwise set with an extra person in the centre:  

....Top....  

1M....1W  

......C......  

2M....2W  ', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1931, '2002-02-26 23:00:00+00', '2021-06-12 10:00:57.613467+00', 'Eightsome Reel, The', 'EIGHTSOME REEL', 1, 464, 9999, 4, 4, 3, 9998, '1870-01-01', 'A description of the dance and its origins is given in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-052-May-1972.pdf#page=3|issue 52 of The Thistle magazine>>.', 48, '[allC40]  8x[leadingW48 otherW16 allM12]  [allC40]', 1, 1, 1, 1, 4);
INSERT INTO 'dance' VALUES (472, '2002-05-04 22:00:00+00', '2021-06-12 10:37:09.340974+00', 'Ben Wyvis', 'BEN WYVIS', 2, 40, 9999, 1, 3, 42, 3123, '1994-01-01', 'Devised in 1994 to celebrate the 18th Anniversary of The Thistle Society, Wigan, and dedicated to the Chairman and Members of the Daten Scottish Country Dance Society.', 55, '800/888/844/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1857, '1998-11-14 23:00:00+00', '2021-06-13 08:13:05.516961+00', 'Dunsinane', 'DUNSINANE', 3, 32, 9999, 1, 3, 42, 108, '1977-01-01', 'John Drewry wrote in the original description the following teaching note:



*At the end of their second turn, 1st couple dance down to fourth place on

Bars 31- 32, while 4th couple *_cast_* up to third place ready to stand

while the new 2nd and 1st couples dance the figure of eight round them.*', 58, '880  866  866  866', 1, 1, 0, 1, 77);
INSERT INTO 'dance' VALUES (1830, '1997-09-11 22:00:00+00', '2021-06-13 08:31:18.800738+00', 'Dundee Civic Jig', 'DUNDEE CIVIC JIG', 2, 32, 9999, 1, 3, 42, 176, NULL, 'Dedicated, with kind permission of Lord Provost Martin McManus, to the city of Dundee on the occasion of Dundee''s first "Civic Week".', 63, '888/888/888/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7172, '2001-12-04 23:00:00+00', '2021-06-13 10:04:08.850438+00', 'Willie with his Tartan Trews', 'WILLIE WITH HIS TARTAN TREWS', 2, 40, 9999, 1, 3, 42, 453, '1760-01-01', '', 55, '888  888  800  844  844', 1, 1, 0, 0, 73);
INSERT INTO 'dance' VALUES (8394, '1997-12-28 23:00:00+00', '2021-06-13 09:57:47.725227+00', 'Sir James Hamilton', 'SIR JAMES HAMILTON', 1, 40, 9999, 1, 3, 42, 35, NULL, 'Wikipedia has a long <<https://en.wikipedia.org/wiki/James_Hamilton_of_Finnart|article>> about James Hamilton of Finnart. The notes to the dance mention his building Craignethan Castle.', 53, '800/888/822/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10823, '2002-09-22 22:00:00+00', '2021-07-30 06:19:30.633186+00', 'Amber''s Reel', 'AMBERS REEL', 1, 32, 9999, 1, 3, 42, 308, '2002-01-01', '"Written for my Granddaughter Amber."', 58, '800/686/868/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6803, '2002-11-14 23:00:00+00', '2021-06-20 00:01:16.197896+00', 'Twenty-Eighth (28th) July', 'TWENTYEIGHTH 28TH JULY', 1, 32, 9999, 1, 4, 11, 352, '1990-07-01', 'In the Tiki Book, the recommended music is given as the recording "Round About Hullachan" (with lead tune The Reel of Tulloch) whereas in the Red Book the recording "The Clints of Dromore" is suggested.



Also the last four bars were revised between the versions in the two books.', 66, '8448/8008/4664/6666', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20341, '2021-05-03 10:09:33.578929+00', '2021-06-17 08:55:09.818169+00', 'Teddy went for Honey', 'TEDDY WENT FOR HONEY', 2, 32, NULL, 1, 3, 42, 11114, NULL, 'Dedicated to Angie who joined to our online dance group with her teddy bear. Angie is the most genuine person, always gives a smile to everyone. I am looking forward to dancing with her in real life as well.



In the "figure of H" setting in bars 17-20 and 25-28 the joined hands should be across and on the sides, making an H shape in 4 bars.  

2 ..... 1 --- 3  

 .. L .. R .. L  

2 --- 1 ..... 3  

to  

2 --- 1 ..... 3  

 .. L .. R .. L  

2 ..... 1 --- 3  

', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7057, '1997-04-03 22:00:00+00', '2021-06-13 11:20:02.201606+00', 'Westerly Wind', 'WESTERLY WIND', 1, 24, 9999, 1, 4, 2, 352, '1991-04-16', 'When published in the <<ddpub:Green Book#755>> the music was given as Crieff Fair. In the <<ddpub:Lion Rampant Book#700>> this was changed to a recording of Nottingham Lace.



The two versions also differ choreographically with the Green Book version having 2nd & 3rd couples also active in bars 1-8 whereas the Lion Rampant version has them standing for 8 bars.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (135, '1997-04-03 22:00:00+00', '2021-06-13 12:58:26.516255+00', 'And Foolish Notion', 'AND FOOLISH NOTION', 3, 48, 9999, 1, 4, 2, 352, '1990-08-19', 'The title is from Burns poem *<<https://en.wikipedia.org/wiki/To_a_Louse|To a Louse>>*.', 70, '8008/8448/8888/8888/7007/8008', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4792, '1997-04-03 22:00:00+00', '2021-06-13 20:00:56.778508+00', 'Mrs Maude Meikle', 'MRS MAUDE MEIKLE', 3, 32, 9999, 1, 3, 42, 352, '1990-09-08', '', 56, '808/808/888/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6261, '1997-08-24 22:00:00+00', '2021-06-14 23:14:40.201244+00', 'Springer Fling, The', 'SPRINGER FLING', 2, 40, 9999, 1, 3, 42, 35, '1991-01-01', 'The notes for the dance say that "anyone who''s seen Chris Springer dance, knows that he loves to fling the kilt in a rousing reel or jig..."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5513, '1997-09-12 22:00:00+00', '2021-06-15 07:51:32.484261+00', 'Reel for Catherine and Thomas, A', 'REEL FOR CATHERINE AND THOMAS', 1, 40, 9999, 3, 5, 7, 280, NULL, 'Devised for Catherine Neill and Thomas Graham, and danced by members of the Boston Branch on the occasion of their marriage on April 27th 1974.



The instructions give the music as "None So Pretty". This has been interpreted here as a recording for that 40 bar dance (whose recommended tune is Johnnie in Nether Mains) rather than the tune None So Pretty.', 60, '80800/82842/88880/80800/80888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1966, '1998-11-14 23:00:00+00', '2021-06-15 08:42:01.442916+00', 'Ellwyn''s Fairy Glen', 'ELLWYNS FAIRY GLEN', 1, 32, 9999, 1, 3, 42, 116, NULL, 'Although not in the original instructions, clapping three times in bars 26 and 28 as 1st couple cross has become a popular variation.', 50, '888/800/844/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4352, '1998-10-26 23:00:00+00', '2021-06-15 20:44:46.292217+00', 'Muckle Mair Than A'' That', 'MUCKLE MAIR THAN A THAT', 1, 32, 9999, 1, 3, 42, 9998, NULL, '', 63, '866/822/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4253, '1997-09-08 22:00:00+00', '2021-06-15 20:57:02.247119+00', 'McCormick''s Reaper', 'MACCORMICKS REAPER', 1, 32, 9999, 1, 3, 42, 1088, NULL, 'The notes to the dance explain that: "Cyrus Hall McCormick, 1809-1884, perfected and got the credit for inventing the reaper which was originated by his father, Robert.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4123, '2003-01-25 23:00:00+00', '2021-06-15 21:04:30.278393+00', 'Man Of Kent''s Jig', 'MAN OF KENTS JIG', 2, 32, 9999, 1, 3, 42, 35, NULL, 'The notes say this was "written for one of my favourite people, Dr. Frank H. Morgan, whose ancestry dates back to the Men of Kent, and his two grandchildren, Sarah and Kate, (fair maids of Kent)."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1596, '1999-12-16 23:00:00+00', '2021-06-15 22:43:36.524301+00', 'Dear Green Place', 'DEAR GREEN PLACE', 3, 32, 9999, 1, 3, 42, 454, NULL, 'The dances notes say that one explanation for the name ''Glasgow'' is that at the time of the city''s foundation in the sixth century by Saint Mungo it was known by its Celtic name Glaschu meaning ''dar green place''.', 63, '844/888/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1553, '1998-01-05 23:00:00+00', '2021-06-17 21:28:51.191535+00', 'Dandy Ninth, The', 'DANDY NINTH', 1, 32, 9999, 1, 3, 42, 816, '1953-03-01', 'Dedicated to the 7/9th (Highlanders) Battalion, The Royal Scots. Collected by Miss Milligan.', 50, '800/888/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1587, '1999-04-19 22:00:00+00', '2021-06-16 09:06:10.986673+00', 'Deaconsbank', 'DEACONSBANK', 1, 32, 9999, 1, 4, 1, 87, NULL, 'Progression involves change-of-side.





Note by EF:  on each repeat two couples in varied positions start on opposite side; the dance ends (1,2,3,4).  If 2c were to start on opposite side, only the couple in 2pos would start on opposite side each time. That would improve the dance.', 69, '8800  8480  8048  8888', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (3288, '1999-08-06 22:00:00+00', '2021-06-16 14:02:09.358114+00', 'Jingling Geordie', 'JINGLING GEORDIE', 2, 32, 9999, 1, 3, 42, 2527, NULL, 'The notes say that the 62430 in the full name of the dance refers to the number of a 4-4-0 "SC0TT" class locomotive (called Jingling Geordie).', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20339, '2021-05-03 10:00:06.907961+00', '2021-06-16 23:11:43.448979+00', 'Fantastic Grannies', 'FANTASTIC GRANNIES', 1, 32, NULL, 104, 54, 54, 11114, '2020-05-01', 'Dedicated to our lovely dancer Lorna, who turned to a Granny in May 2020. The dance was designed to be able to dance during the lockdown, 2 meters apart (no progression, if it is danced by one couple, they are suggested to be in diagonal position).



The title of the dance refers to all those lovely people who keep our dancing society together and make everyone so welcomed in the dance, as you are part of the family.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1457, '1997-04-03 22:00:00+00', '2021-06-18 21:59:30.072093+00', 'Cruives of Cree, The', 'CRUIVES OF CREE', 2, 32, 9999, 1, 3, 42, 313, NULL, 'The notes explain that "the wooded stretch of the River Cree, known as the Cruives of Cree, is situated four miles north-west of Newton Stewart."', 53, '800/822/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2936, '2000-06-12 22:00:00+00', '2021-06-17 21:38:14.910136+00', 'Highwayman, The', 'HIGHWAYMAN', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'Described as for a 4 (or 5) couple set.', 47, '800/808/844/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1543, '1997-04-03 22:00:00+00', '2021-06-18 08:13:36.351369+00', 'Dancing Man, The', 'DANCING MAN', 1, 32, 9999, 1, 3, 42, 146, NULL, '"For Bob Campbell of Oakville, Ontario"', 62, '880  888  880  888', 1, 1, 0, 1, 83);
INSERT INTO 'dance' VALUES (1526, '2003-01-28 23:00:00+00', '2021-06-18 08:22:45.332557+00', 'Dance with Your Soul', 'DANCE WITH YOUR SOUL', 3, 32, 9999, 1, 4, 1, 35, '1984-01-01', 'The dedication, explaining the title, reads "This was a favourite expression of Miss Jean Milligan of Scotland, who, along with Mrs. Ysobel Stewart, was responsible for the revival of SCD in 1923. She made you want to lift your feet off the floor and truly dance with your soul. She often said, ''Dancing is a joyous thing and this must never be sacrificed to a preoccupation with drilling and detail.'' We owe her much here in Canada and Ontario where the revival caught on and spread, and for her attention to detail reviving old dances, and setting up standards for teachers and dancers alike."', 88, '8228/8888/8888/8488', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1427, '1997-04-03 22:00:00+00', '2021-06-19 10:07:26.778828+00', 'Cromartie''s New Rant', 'CROMARTIES NEW RANT', 1, 32, 9999, 1, 3, 42, 108, '1983-01-01', 'Inscribed "for William Williamson who steps up so well."', 39, '440/440/886/822', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1402, '1997-08-31 22:00:00+00', '2021-06-19 10:33:06.872456+00', 'Craigower', 'CRAIGOWER', 1, 32, 9999, 3, 5, 7, 190, '1980-09-01', 'From the notes: "Craigower, at Pitlochry, is approximately 1300 ft high and is climbed by way of quiet road, woodland footpath and the final steep ascent over heather to reach the summit where there are excellent views of the surrounding countryside."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20362, '2021-07-02 15:58:48.559638+00', '2021-07-02 16:00:50.775216+00', 'Ne''er Day Jig', 'NEER DAY JIG', 2, 32, NULL, 1, 4, 1, 9998, NULL, 'Source: <<https://youtu.be/qiYExQiTpbA|youtube video>>.', 69, '8000/8044/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20596, '2022-01-07 18:01:55.299416+00', '2022-01-07 18:01:55.299416+00', 'Dancing Through Logis'' Lane', 'DANCING THROUGH LOGIS LANE', 2, 32, NULL, 1, 4, 1, 11514, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1331, '2000-06-20 22:00:00+00', '2021-06-20 09:54:16.208224+00', 'Copenhagen Strathspey', 'COPENHAGEN STRATHSPEY', 3, 40, 9999, 1, 4, 1, 18, NULL, 'Crib posted by Brian Charlton, of Sydney, Australia, 000621, saying. ''I have never seen the original instructions. The dance has connections with Sydney Branch because the Danish Consul and his wife started SCD with the Sydney Scottish Country Dance Circle and started(?) SCD in Copenhagen when they returned home. The Scottish Country Dance Circle was the foundation for the Sydney Branch, so that must have been before 1952. Capt. Bain was, I believe, a member of the Edinburgh Demonstration Team.''', 72, '8888  8888  8040  8000  8888', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (1246, '1999-08-09 22:00:00+00', '2021-06-20 12:27:07.144583+00', 'Clydeside Lassies', 'CLYDESIDE LASSIES', 1, 32, 9999, 1, 3, 42, 9998, NULL, '<<scddb:not-identical:8086>>

Collected in the Tima Valley', 41, '880/800/804/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2186, '1997-04-03 22:00:00+00', '2021-07-04 15:51:09.603129+00', 'Fire In The Eastern Hills', 'FIRE IN THE EASTERN HILLS', 3, 32, 9999, 1, 4, NULL, 156, NULL, 'The dance "Fire in the Eastern Hills" recalls the 1983 Ash Wednesday fires in the Dandenong Ranges, east of Melbourne. (Source: Southern Stars Book, where the dance is published)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6971, '1997-04-03 22:00:00+00', '2021-06-20 21:26:28.769934+00', 'Weasel, The', 'WEASEL', 1, 24, 9999, 1, 3, 42, 352, '1990-07-01', 'The version in <<ddpub:The Kiwi Book#695>> specifies the music as Calver Lodge. The earlier publication in <<ddpub:The Red Book#757>>  proposes <<ddrec:Kenmure''s On and Awa''#930>>.



The introduction to <<ddpub:The Red Book#757>> says *the title comes from the T.V. series ''The Black Adder'' and the immortal lines ''I have a plan so cunning you could pin a tail on it and call it a weasel''.*', 58, '848/848/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1311, '1997-04-03 22:00:00+00', '2021-06-20 23:21:31.761493+00', 'Commodore, The', 'COMMODORE', 1, 32, 9999, 1, 4, 1, 352, '1990-10-23', 'Skelton writes in the introduction to <<ddpub:Yellow Book#756>> that "as usual I was stuck for a name, and as all the dances have been written with the word processor on my Commodore Amiga Computer, I called it The Commodore."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1954, '1997-04-03 22:00:00+00', '2021-06-21 11:13:30.426951+00', 'Elizabethan Rant', 'ELIZABETHAN RANT', 2, 48, 9999, 3, 5, 7, 94, NULL, '"To celebrate the 21st Anniversary of the Elizabeth Scottish country Dance Group."



The instructions do not specify which shoulder to pass to start the reel of four in bars 25-32 but as it is preceded and followed by LH turns, LSh reel would flow better.', 67, '88880/83863/83863/80800/80800/88888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20354, '2021-06-21 20:55:10.0423+00', '2021-06-21 20:55:10.0423+00', 'Viento, El', 'VIENTO', 2, 32, NULL, 1, 4, 1, 2680, '2000-06-02', 'Inscribed to "the dancers in New Mexico on the occasion of their weekend Workshop and Ball, 2-4 June 2000".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20355, '2021-06-21 21:03:00.09628+00', '2021-06-21 21:03:00.09628+00', 'Trestle Bridge, The', 'TRESTLE BRIDGE', 3, 32, NULL, 1, 3, 42, 2680, '2002-04-01', 'The notes mention the High Level Bridge at the entrance to the city of Lethbridge which was built in 1909 and is the longest and highest trestle bridge in the world.', 52, '800/880/888/882', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20356, '2021-06-21 21:08:07.432891+00', '2021-06-21 21:10:58.264613+00', 'Shalimar', 'SHALIMAR', 3, 32, NULL, 1, 3, 42, 2680, '2001-09-01', 'According to the dance notes "Shalimar is the name of my parents'' home in Glasgow. The dance was devised to honour their 50th wedding anniversary on September 1, 2001."', 56, '880/888/844/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12079, '2005-03-09 23:00:00+00', '2021-06-22 11:41:02.381959+00', 'Jig of the Merse, The', 'JIG OF THE MERSE', 2, 40, 9999, 1, 3, 42, 3525, NULL, 'This dance was the winner of a Branch competition for a new dance to mark our 50th Birthday celebration.', 65, '800  888  888  888  888', 1, 1, 1, 1, 86);
INSERT INTO 'dance' VALUES (1113, '2002-12-16 23:00:00+00', '2021-06-22 18:23:49.840302+00', 'Celebration Jig', 'CELEBRATION JIG', 2, 32, 9999, 1, 4, 2, 42, '1992-01-01', 'For the deviser''s parents, Phil and Lawrie Bowlen on the occasion of their Ruby Wedding Anniversary, January 28th 1992. The Bowlens live in Bundoora, Victoria, Australia.', 69, '4884/8008/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1103, '1998-01-05 23:00:00+00', '2021-06-22 18:29:03.783879+00', 'Caveman of Culsh, The', 'CAVEMAN OF CULSH', 1, 32, 9999, 1, 3, 42, 108, '1981-01-01', 'In the dance notes Drewry writes that "at Culsh, just to the east of Tarland. there ls a well-preserved earth house dating from prehistoric times. I once distinguished myself by falling all my length on the slippery floor, while on a visit with my sister''s children, and emerging covered wlth slimy mud."', 69, '888/888/880/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (82, '1997-04-03 22:00:00+00', '2021-06-22 20:14:06.707385+00', 'Alexandra Hall', 'ALEXANDRA HALL', 1, 32, 9999, 1, 3, 42, 209, NULL, 'The dance notes explain that "Alexandra Hall is the residence of the University of King''s College. For one week in the month of July this residence is the home of Scottish Country Dancers, who take part in the International Scottish Country Dance School. We often wonder, during this week, if the ghosts of past residents are ever disturbed by the goings on!"', 47, '888/808/822/800', 1, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (20353, '2021-06-21 20:41:49.084473+00', '2021-06-24 20:04:15.893788+00', 'Mrs. Pamela Cairns', 'MRS PAMELA CAIRNS', 2, 32, NULL, 1, 3, 42, 2680, '2000-03-04', 'This dance is devised in honour of the wedding of my sister, Pamela Brown, to Gordon Cairns on March 04, 2000 at CrieffHydro, Perthshire, Scotland.  



1 - 8 Pamela and Gordon led separate lives.  

9 - 16 Their paths crossed a couple of times.  

17 - 24 They started dating.  

25 - 32 They became inseparable.', 44, '800/888/800/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1814, '2002-09-22 22:00:00+00', '2021-08-02 09:52:28.768673+00', 'Dunblane Holiday', 'DUNBLANE HOLIDAY', 1, 88, 9999, 4, 4, 3, 308, '1994-08-01', '"This dance was written as a result of the very enjoyable holiday a group of us spent dancing at The Dunblane Hydro, courtesy of Furlong''s Travel."', 77, '8888/6666/8686/8686/6666/6868/6868/8080/4444/0808/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9775, '2002-08-29 22:00:00+00', '2021-08-02 14:09:12.205284+00', 'Dancing Shadows', 'DANCING SHADOWS', 1, 40, 9999, 1, 3, 42, 2823, '1998-01-01', 'Devised in honor of Kathy Kuluga and Tony Smith.



From the Cincinnati Branch RSCDS website, Feb 01. The lead-change Reels are similar to those in Flight of the Falcon and Pelorus Jack.', 53, '888/820/844/844/844', 0, 1, 1, 0, 56);
INSERT INTO 'dance' VALUES (828, '1997-04-03 22:00:00+00', '2021-11-17 12:41:59.730278+00', 'Broken Dreams', 'BROKEN DREAMS', 2, 32, 9999, 1, 4, 2, 352, '1991-08-02', '"A dance I wrote when I was woken by a cat at 4.30 in the morning."', 75, '8448/8448/8008/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20357, '2021-06-21 21:17:48.937304+00', '2021-10-12 10:48:31.352482+00', 'Journey to Bowen Island', 'JOURNEY TO BOWEN ISLAND', 3, 32, NULL, 1, 4, 1, 2680, '1989-06-22', 'Devised in honour of Spencer Gallagher who retired from Lethbridge to Bowen Island, off the coast of Vancouver.', 89, '8888/8888/8888/8424', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (722, '2002-03-02 23:00:00+00', '2021-06-28 15:16:52.369021+00', 'Bothwell Brig', 'BOTHWELL BRIG', 1, 40, 9999, 1, 3, 42, 108, NULL, 'According to the TAC "Index of Joihn Drewry''s Dance"s:



Rinty''s Rant was reworked and renamed to Bothwell Brig. Thus, Bothwell Brig replaced Rinty''s Rant.



The dance was devised in the 1970ies, but the actual year is unknown.



The instructions say it is "for Nancy Rintoul of Bellshill". Also that Bothwell Bridge, on the Clyde, is famous as the scene of an encounter between Monmouth and the Covenanters in 1679.', 69, '862  844  844  844  888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (20368, '2021-07-08 15:17:05.666585+00', '2021-07-08 21:58:39.716591+00', '30th of April', '30TH OF APRIL', 1, 32, NULL, 1, 3, 42, 1049, '2016-11-01', 'Dance devised for Robert Al and Marta Rudolph on the occasion of their wedding April 30,  2016.  Nov. 2016,', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20352, '2021-06-21 20:08:24.468805+00', '2021-06-24 19:52:00.106176+00', 'Rolling Stones', 'ROLLING STONES', 1, 32, NULL, 1, 3, 42, 2680, '1995-03-01', 'Every one knows the saying that "a rolling stone gathers no moss". This dance is dedicated to a wonderful couple who decided to retire to the quiet life of Victoria, B.C. and who now spend their days hiking, skiing, sailing and camping. Their evenings are  spent Scottish Country Dancing. Old age will never catch up to Mike and Mary Hanna as they don''t stand still long enough to give it a chance. True rolling stones. March 1995.', 63, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (941, '1998-11-02 23:00:00+00', '2021-06-26 08:56:08.072071+00', 'Calgary Stampede, The', 'CALGARY STAMPEDE', 1, 40, 9999, 1, 3, 42, 118, '1977-01-01', 'The notes explain the figures in the dance as representing:  

(1 - 8) Visitors come from all around to Calgary  

(9 - 16) They receive a warm welcome in the Stampede City  

(17 - 24) There is dancing in the streets  

(25 - 32) The midway on the Stampede grounds  

(33 - 40) The Rodeo infield.  ', 48, '800/822/822/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20361, '2021-06-27 22:25:28.873784+00', '2021-06-27 22:42:00.804982+00', 'Selkie Fowk, The', 'SELKIE FOWK', 1, 32, NULL, 1, 3, 42, 10959, '2021-04-26', 'Along the north and west coasts and islands of Scotland there  are many stories and songs telling of the Selkies, (the seal people) who are  reputed to be able to shape change from seals into humans. They mix and marry into the local communities but almost always the lure of the sea is too much and they return to their sea homes in the shape of seals.  



Fowk is the Scottish variant of Folk, especially in Orkney: the word is also to be found in the Yorkshire dictionary of 1887. The last 8 bars shows the sea waves swirling in & pulling the Selkies back into the sea.  



Bars 9-16 are based on the movement ‘Swing Corners,’ from Thomas Wilson’s 1811 Manual, “Analysis of Country Dancing”.', 59, '880/844/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (904, '1997-08-28 22:00:00+00', '2021-06-26 20:11:13.8728+00', 'Cabrach, The', 'CABRACH', 3, 32, 9999, 1, 3, 42, 146, NULL, '"This dance can be used to introduce the 3-couple allemande in reel time and as an introduction to dancing a medley - 32 bar strathspey -  32 bar reel, each couple dancing once through in strathspey time and  then in reel time for their second turn."  Also danced as medley; as S for 1c and 2c, as Reel for 3c and 4c.', 62, '440  888  888  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (852, '1998-01-04 23:00:00+00', '2021-06-28 09:00:28.049035+00', 'Buck''s Reel', 'BUCKS REEL', 1, 40, 9999, 1, 3, 42, 730, '1977-07-01', 'In memory of Buck Little.



The dance was first taught and danced at Pinewoods in July 1977, and first published in the Tartan Times for September 1977.', 60, '880/880/888/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9776, '2001-09-03 22:00:00+00', '2021-08-02 14:15:12.862146+00', 'Love''s Knot Forgotten', 'LOVES KNOT FORGOTTEN', 3, 40, 9999, 1, 3, 42, 2823, '1997-01-01', 'This dance can easily be done once and to the bottom, just by having the dancing couple Knot themselves to the bottom of the set.', 63, '888/888/808/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (841, '1997-09-17 22:00:00+00', '2021-06-28 10:17:15.302532+00', 'Brownie Of Blednoch, The', 'BROWNIE OF BLEDNOCH', 1, 32, 9999, 1, 3, 42, 954, '1988-01-01', 'In the dance notes the deviser writes that it "was devised for introducing reels of three in a beginners class. The dance works well in a three couple set, since only the 1st couple starts and the reel is not the first or last figure.



The name of the dance came from an old Scottish Borders myth about a brownie. The brownie''s name was Aikendrum, the Brownie of Blednoch, from a poem of that name by William Nicholson."', 50, '844/888/800/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20321, '2021-04-14 11:04:18.427325+00', '2021-06-27 11:36:39.83618+00', 'Trip to Saint-Palais, A', 'TRIP TO SAINTPALAIS', 3, 32, NULL, 1, 100, 2, 11344, '2018-01-01', 'Devised by Mathias Ferber, Emma Orgeret, Antoine Rousseau and Claude Schnitter, in Paris, 2018.  



Dedicated to Danièle Landrieau for her birthday. Saint‐Palais is a lovely town in the Gironde estuary, on the south west coast of France.', 75, '8888/8008/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20359, '2021-06-26 22:11:50.549478+00', '2021-06-29 16:47:29.266078+00', 'Manchester Lass, The', 'MANCHESTER LASS', 3, 32, NULL, 2, 3, 18, 10959, '2021-06-07', 'For Jean Hamilton : our first SCD teacher after we came to Canada.', 88, '888/888/282/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (407, '1997-04-03 22:00:00+00', '2021-07-03 12:13:51.980859+00', 'Barbara McOwen''s Ceilidh', 'BARBARA MACOWENS CEILIDH', 3, 32, 9999, 1, 3, 42, 3461, NULL, 'The notes for the dance explain that:

The original tune for this dance was commissioned by Evelyn for Barbara McOwen to thank her for all her help in the production of the recording ''''The Pipes Awa'' Wi'' the Fiddle".

Barbara is a renowned fiddler/arranger in the Scottish music scene throughout North America.', 66, '880  888  888  866', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (20245, '2021-03-04 12:12:09.144495+00', '2021-07-01 05:58:51.303556+00', 'Leverburgh Ferry, The', 'LEVERBURGH FERRY', 3, 32, NULL, 2, 3, 17, 10959, '2012-01-01', 'The Leverburgh ferry runs from Leverburgh (Obbe), South Harris to Bernara , which is joined by a causeway to North Uist. The ferry zig zags across the Sound of Harris to avoid submerged rocks and other dangers. An area of 12 foot tides & strong currents.', 75, '880/888/880/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (387, '2002-03-14 23:00:00+00', '2021-07-03 12:34:16.738247+00', 'Corrievreckan', 'CORRIEVRECKAN', 4, 128, 2, 4, 4, 3, 534, '1996-01-01', 'Dedicated to the late Frank Riley, past Chairman of the Lakes SCD Club, forester, sailor, mountaineer and much more besides.  Corrievreckan was one of Frank''s favourite places.', 75, '55  55  55  55  88  44  88  88  bis', 1, 1, 1, 1, 37);
INSERT INTO 'dance' VALUES (549, '2000-02-21 23:00:00+00', '2021-07-01 22:58:39.635765+00', 'Black Mountain Reel, The', 'BLACK MOUNTAIN REEL', 1, 32, 9999, 3, 5, 7, 175, '1968-01-01', 'First published on a Glendarroch SCD Sheet in 1968.



It is not entirely clear which mountain provided the title for this dance – possibly Twyn Lech on the English-Welsh border. <<ddp:Haynes, Derek>>, the author of this dance, was a passionate hill-walker.

', 62, '80800  82842  84884  84844', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (20360, '2021-06-27 07:03:41.901254+00', '2022-04-25 20:30:38.106099+00', 'Lochmaddy', 'LOCHMADDY', 3, 32, NULL, 2, 3, 17, 10959, '2012-05-01', 'Lochmaddy is the ferry Terminal on the Island of North Uist.  



Note: the ''circulating allemande'' in bars 17 -24 was devised by Terry Glasspool.', 83, '880/848/888/668', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (761, '1998-04-05 22:00:00+00', '2022-08-11 14:47:50.445172+00', 'Bramble Circle, The', 'BRAMBLE CIRCLE', 1, 32, 9999, 7, 1, 4, 723, NULL, 'Suited for Reel as well as Jig time (stated explicitly in the description of the dance).



"Written in honour of Seattle''s Bramble Band members who give generously of their time to play for many ''audience paticipation'' events."', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (860, '2002-02-28 23:00:00+00', '2022-08-20 08:31:42.015765+00', 'Bullers of Buchan, The', 'BULLERS OF BUCHAN', 2, 32, 9999, 1, 3, 42, 108, '1991-02-01', 'Drewry explains in his notes for that dance that:  

The Bullers of Buchan are a rock formation in the cliffs north of Cruden Bay, Aberdeenshire. The most impressive feature is "The Pot" - a circular basin surrounded by tremendous rocks and with a narrow cave-like opening through which the sea flows into the cauldron. It is possible to enter the pot by rowing boat.  

Dr Johnson and Boswell visited the Bullers in 1773.  ', 59, '880/888/666/666', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (683, '2001-12-16 23:00:00+00', '2022-12-01 16:29:33.16531+00', 'Bonny Bells of Heather, The', 'BONNY BELLS OF HEATHER', 1, 32, 9999, 8, 105, 12, 13, NULL, 'The title is from the Robert Louis Stevenson poem about the legend of Heather Ale:  

*From the bonny bells of heather*  

*They brewed a drink long-syne,*  

*Was sweeter far than honey,*  

*Was stronger far than wine.*  ', 67, '808808/888888/800008/808808', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20247, '2021-03-04 12:17:01.523167+00', '2021-07-02 16:38:20.155429+00', 'Staying Home with an Imp', 'STAYING HOME WITH AN IMP', 2, 32, NULL, 1, 3, 42, 10959, '2020-06-01', 'The Imp in question is The Lincoln Imp otherwise my husband Keith.



The _Half Rondel_ is a formation by John Drewry and is first described in his Rondel book (1967) . It appears in his dances Marischal College and Twa Rogueish Een, and is not to be confused with half of a Rondel, The Half Rondel is another of John Drewry''s formations which has not been used by the RSCDS, so does not appear in the manual. Drewry devised it for use in Reels and Jigs as the Strathspey Rondel does not translate well into the faster tempos.', 50, '800/880/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10117, '2001-10-30 23:00:00+00', '2021-07-02 20:18:21.555488+00', 'Fun in the Sun', 'FUN IN THE SUN', 1, 32, 9999, 5, 2, NULL, 2949, '1999-01-01', 'Queenslanders have a reputation for having an easy-going lifestyle, in a state that is “beautiful one day--perfect the next”. This is a friendly, fun dance to reflect our way of life. May also be danced in Strathspey time. Suitable music would be “Ross Meor” from Book 29. Music for Ten Traditional Dances by Bobby Crowe and his Scottish Dance Band.



[Details supplied in <<https://my.strathspey.org/dd/issue/2530/|issue 2530>>].', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10120, '2001-10-30 23:00:00+00', '2021-07-03 08:40:41.372226+00', 'St Lucia Strathspey', 'SAINT LUCIA STRATHSPEY', 3, 40, 9999, 1, 4, NULL, 2605, '2001-01-01', 'Devised for the 26th Australian Winter School held in Grace and Cromwell Colleges at the University of Queensland, St. Lucia, Brisbane. The St. Lucia Exchange (formation) represents the flow of people between between the two colleges.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20248, '2021-03-04 12:18:19.61131+00', '2021-07-03 11:36:33.960059+00', 'Blind Summit', 'BLIND SUMMIT', 1, 32, NULL, 1, 100, 2, 10959, '2015-10-01', 'There are Blind Summit signs on many roads in the Highlands and Islands of Scotland, warning drivers that the road dips, so oncoming traffic cannot be seen. Particularly dangerous on the Island of Harris where the roads are also one track with passing places. 



For Norma and Mike Briggs who had such a road near their home in Wisconsin, USA', 88, '8888/8888/8668/8228', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (420, '1997-08-28 22:00:00+00', '2021-07-03 12:07:25.336613+00', 'Barton Chase', 'BARTON CHASE', 2, 40, 9999, 1, 3, 42, 676, NULL, '"Devised for the Morley Scottish Dancing Club week­ end at Barton Chase, Barton-on-sea."', 40, '880/800/822/822/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (382, '1998-04-29 22:00:00+00', '2021-07-03 12:44:26.318933+00', 'Banff Hornpipe', 'BANFF HORNPIPE', 1, 32, 9999, 1, 3, 42, 108, '1994-01-01', 'Inscribed "for Alasdair Fraser of N. San Juan, California, formerly of Clackmannan, who plays ''Banks Hornpipe'' exquisitely."', 63, '808/484/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (378, '1998-07-08 22:00:00+00', '2021-07-03 14:01:26.232255+00', 'Balvenie Castle', 'BALVENIE CASTLE', 3, 32, 9999, 1, 4, 2, 108, '1994-01-01', 'From the dance notes: "Balvenie Castle is just to the north of Dufftown, near the River Fiddich, and quite close to the Glenfiddich Distillery."', 88, '8888/8888/8888/0088', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (377, '2000-09-05 22:00:00+00', '2021-07-03 14:05:06.271888+00', 'Balquidder Strathspey', 'BALQUIDDER STRATHSPEY', 3, 32, 9999, 1, 3, 42, 453, NULL, 'Balquhidder (the modern spelling) is a village in the Highlands, near

Stirling. Traditionally it belonged to Clan MacLaren, until during the

16th century the neighbouring MacGregors began to encroach on the area

and forced the MacLarens to share it with them. The famed Rob Roy

MacGregor is buried in Balquhidder.



The »quh« in »Balquhidder« is pronounced like »w«, so the place is

Bal-WID-der rather than Bal-KWID-der. (The same applies to other

Scottish names like »Urquhart« or »Colquhoun«.)

', 53, '888  888  800  822', 1, 1, 0, 1, 70);
INSERT INTO 'dance' VALUES (6361, '1997-09-14 22:00:00+00', '2021-07-03 21:45:35.36897+00', 'Struan Reel, The', 'STRUAN REEL', 3, 32, 9999, 1, 3, 42, 1129, '1962-04-11', 'Dedicated to Robert R. Gourlay.



Published as a leaflet (see <<https://my.strathspey.org/dd/issue/2515/|issue 2515>>).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6282, '1998-01-04 23:00:00+00', '2021-07-03 21:50:12.458975+00', 'Stanley Reel, The', 'STANLEY REEL', 1, 48, 9999, 1, 4, 1, 921, '1964-01-01', 'According to <<https://my.strathspey.org/dd/issue/2517/|issue 2517>> this was devised in honour of Stanley Greenberg for his devoted service to the New York Branch of the RSCDS. It was first danced by the members of the New York Branch, on the occasion of the Fifth Anniversary as a Branch of the Society, at the Holiday Hills Week-end in Pawling, New York.



Published as a leaflet.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (300, '2002-02-26 23:00:00+00', '2021-07-04 09:58:51.188372+00', 'Auld Kirk, The', 'AULD KIRK', 3, 32, 9999, 1, 4, 2, 108, '1989-01-01', 'Inscribed "for Ian Kirk of Auchendean Lodge, Dulnain Bridge".', 88, '8888/8888/8888/8008', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (271, '1997-08-28 22:00:00+00', '2021-07-04 10:10:52.424599+00', 'Atholl Reel, The', 'ATHOLL REEL', 1, 32, 9999, 1, 2, 76, 394, NULL, 'Suited for Reel as well as Strathspey time (stated explicitly in the description of the dance).', 55, '44  88  88  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (268, '1998-07-08 22:00:00+00', '2021-07-04 10:31:44.355769+00', 'Atholl Brose', 'ATHOLL BROSE', 2, 64, 9999, 1, 100, 2, 108, '1977-01-01', 'The dance is dedicated to Bill Clement of Thornhill.', 78, '8888/8888/0880/0880/8888/8448/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (203, '2002-05-01 22:00:00+00', '2021-07-04 11:03:20.82235+00', 'Bottle Forest, The', 'BOTTLE FOREST', 3, 40, 9999, 1, 3, 42, 74, '1993-01-01', 'The dance notes explain that "Bottle Forest was the original name for the parish of Heathcote, where the dance composer lived when the dance was devised. It was named by the first surveyor in the area when he found a bottle lodged in the fork of a tree."', 45, '800/800/880/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7117, '1997-04-03 22:00:00+00', '2021-07-04 15:51:27.744412+00', 'White Lady, The', 'WHITE LADY', 2, 32, 9999, 1, 3, 42, 156, NULL, 'The White Lady haunts the Court Cave, at MacDuff Castle, Wemyss, Fife. (Source: Southern Stars Book, where the dance is published)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1269, '1997-08-31 22:00:00+00', '2021-07-04 15:52:23.127856+00', 'Cockle Mill', 'COCKLE MILL', 3, 32, 9999, 2, 3, NULL, 156, NULL, 'Cockle Mill milled grain, and later iron, near the mouth of the River Almond, Cramond. Now only a ruin. (Source: Southern Stars Book, where the dance is published)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13259, '2007-02-21 23:00:00+00', '2021-07-06 20:26:01.578599+00', 'Crabbit Shona', 'CRABBIT SHONA', 2, 32, 9999, 2, 2, 76, 1013, NULL, 'In <<sspey:12277|Strathspey Message 12277>> on 14 Jun 1998 Rebecca Sager writes:  (This is just a teaching exercise, a blend of Galloway House and Leap Year. The name and music are still available for a real dance) 



32 Bar Jig for 2 couples, in a 3 couple set. (Music is 6x32)



1-8: 1C cast behind own lines turn outward and dance back up to place



9-16: 1C and 2C dance right hands across, left hands back



17-24: 1C lead down for 3 steps, up for 3 steps, cast into 2nd place as 2C step up



25-32: 2C and 1C dance rights and lefts

', 52, '80  88  80  88', 0, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (2527, '1998-10-21 22:00:00+00', '2021-07-06 20:53:02.083098+00', 'Glendarroch', 'GLENDARROCH', 3, 32, 9999, 1, 4, NULL, 44, NULL, 'This dance was devised by <<ddp:Iain Boyd#44>> in memory of <<ddp:Hugh Foss#129>>. Profits from the sale of the original leaflet were to be used for the publication of Hugh Foss''s unpublished dances (info from <<https://my.strathspey.org/dd/issue/2521/|issue 2521>>).', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20363, '2021-07-08 15:02:48.881873+00', '2021-07-18 04:34:14.477474+00', 'Delft 50 years', 'DELFT 50 YEARS', 2, 32, NULL, 3, 5, 7, 1049, '2019-11-01', 'Dance devised for the Delft Branch on her 50th anniversary november 2019', 65, '80800/86846/86886/44444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1789, '2002-03-11 23:00:00+00', '2021-07-08 18:15:24.574713+00', 'Duke of Gordon''s Welcome to Aberdeen, The', 'DUKE OF GORDONS WELCOME TO ABERDEEN', 1, 176, 9999, 4, 4, 3, 9998, NULL, 'This dance is too involved to be placed on a Ball programme; it is essentially a demonstration dance.  However MiniCrib has now provided a crib for it.



The dance has five figures:  

Fig. 1: 64 bars  

Fig. 2: 32 bars  

Fig. 3: 32 bars  

Fig. 4: 16 bars  

Fig. 5: 32 bars  



This dance was collected by Mrs MacNab but from a Mr Graham Forbes of Hamilton, Ontario who was taught it by his Grandfather in Scotland.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20378, '2021-07-13 15:02:13.932756+00', '2021-07-13 15:02:13.932756+00', 'Angela''s Reel', 'ANGELAS REEL', 1, 48, NULL, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20367, '2021-07-08 15:15:11.126273+00', '2021-07-09 01:06:47.22572+00', 'Afke''s Farwol', 'AFKES FARWOL', 2, 32, NULL, 1, 3, 42, 1049, '2016-06-01', 'Dance devised for Afke Bergstra  on her farewell to the Delft Branch of the RSCDS, after dancing for nearly 30 years. June 2016.  

Farwol'' is Frisian for Farewell.', 44, '800/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20380, '2021-07-13 15:07:08.105812+00', '2021-07-13 15:07:08.105812+00', 'Texas Starr', 'TEXAS STARR', 2, 64, NULL, 2, 3, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20370, '2021-07-10 13:17:15.074586+00', '2021-07-10 14:59:15.712191+00', 'Markinch Mars Bar King, The', 'MARKINCH MARS BAR KING', 2, 32, NULL, 1, 3, 42, 11756, '2021-06-29', 'Written to celebrate Bill Ewan''s 80th Birthday on 29th June 2021  

As everyone knows Bill''s greatest indulgence is a Mars Bar!', 59, '800/866/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2636, '1998-11-02 23:00:00+00', '2021-07-11 15:46:04.055884+00', 'Grand Macnish, The', 'GRAND MACNISH', 3, 32, 9999, 2, 3, 17, 118, '1976-01-01', 'This was first danced on 11 October 1976, the final day of the 3rd Annual Canadian Rockies Workshop. Dedicated to Robert Macnish & Co. Ltd., Glasgow, for their support and donations to the Workshop Banquet. ', 75, '800/888/888/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20381, '2021-07-13 15:08:54.629255+00', '2021-07-13 15:08:54.629255+00', 'Joan''s Reel', 'JOANS REEL', 1, 40, NULL, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20366, '2021-07-08 15:13:31.996788+00', '2021-07-09 06:12:27.023323+00', '80 Bells for Santa', '80 BELLS FOR SANTA', 1, 32, NULL, 2, 3, 18, 1049, '2013-12-26', 'Dance devised for Dick Mackay, on the occasion of his 80th birthday, December 26, 2013', 58, '480/084/484/484', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20364, '2021-07-08 15:09:01.255108+00', '2021-07-11 21:20:44.937298+00', 'Delft Branch Bike Riders', 'DELFT BRANCH BIKE RIDERS', 1, 32, NULL, 1, 3, 42, 1049, '2019-09-01', '', 58, '864/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20371, '2021-07-13 06:56:23.943481+00', '2021-07-13 06:56:23.943481+00', 'Cindy''s Jig', 'CINDYS JIG', 2, 40, NULL, 1, 4, NULL, 9998, NULL, 'Devised for Cindy Lee', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20372, '2021-07-13 14:41:56.608405+00', '2021-07-13 14:42:56.918176+00', 'Shannon''s Delight', 'SHANNONS DELIGHT', 1, 96, NULL, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20373, '2021-07-13 14:44:18.927292+00', '2021-07-13 14:44:18.927292+00', 'First Footers Jig', 'FIRST FOOTERS JIG', 2, 128, NULL, 4, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20374, '2021-07-13 14:46:52.41245+00', '2021-07-13 14:46:52.41245+00', 'Lee''s Lilt', 'LEES LILT', 4, 64, 5, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20375, '2021-07-13 14:50:17.157977+00', '2021-07-13 14:50:17.157977+00', 'Take Me Back', 'TAKE ME BACK', 2, 96, NULL, 104, 2, NULL, 9998, NULL, 'Devised for Iska Scholl who wanted a dance to singing.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20376, '2021-07-13 14:54:01.419354+00', '2021-07-13 14:54:05.438835+00', 'Caterine''s Ceilidh', 'CATERINES CEILIDH', 4, 64, 5, 99, 53, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20377, '2021-07-13 14:56:56.228463+00', '2021-07-13 14:56:56.228463+00', 'Iska''s Idyll', 'ISKAS IDYLL', 2, 64, NULL, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20382, '2021-07-13 15:12:21.973551+00', '2021-07-13 15:14:33.660518+00', 'Dina''s Dance', 'DINAS DANCE', 4, 104, NULL, NULL, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20383, '2021-07-13 15:18:00.60467+00', '2021-07-13 15:18:00.60467+00', 'Scottish Bluebells Jig', 'SCOTTISH BLUEBELLS JIG', 2, 120, NULL, 4, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20384, '2021-07-13 15:20:41.875418+00', '2021-07-13 15:20:41.875418+00', 'Sharon''s Rant', 'SHARONS RANT', 2, 96, NULL, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20385, '2021-07-13 15:22:16.724633+00', '2021-07-13 15:22:16.724633+00', 'Barbara''s Reel', 'BARBARAS REEL', 1, 48, NULL, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20386, '2021-07-13 15:25:08.235137+00', '2021-07-13 15:25:08.235137+00', 'Ashley''s Medley', 'ASHLEYS MEDLEY', 4, 64, 5, NULL, 2, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20387, '2021-07-13 15:27:31.314497+00', '2021-07-13 15:27:31.314497+00', 'Lorna''s Lilt', 'LORNAS LILT', 4, 128, NULL, 4, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20388, '2021-07-13 15:29:31.357083+00', '2021-07-13 15:29:31.357083+00', 'Gina''s Jig', 'GINAS JIG', 2, 48, NULL, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20389, '2021-07-13 15:31:35.287264+00', '2021-07-13 15:31:35.287264+00', 'Meadow Loch Special', 'MEADOW LOCH SPECIAL', 2, 64, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20365, '2021-07-08 15:11:42.115153+00', '2021-07-18 05:04:56.019479+00', 'MacLouis is Ready for Hibernation', 'MACLOUIS IS READY FOR HIBERNATION', 4, 64, 22, 1, 3, 42, 1049, '2017-08-30', 'Dance devised for Louis Brijer on the occasion of his last workingday  August 30, 2017, by Anne-Miek Klokgieters, The Hague.  

“Now the job is done, it’s time to sleep”  



Reel time: working life  

Strathspey time: time to rest', 41, '840/844/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20391, '2021-07-15 21:55:57.381328+00', '2021-07-15 21:55:57.381328+00', 'Reel of the Neutrino', 'REEL OF THE NEUTRINO', 1, 48, NULL, 4, 4, 5, 11387, '2015-11-28', 'From the <<https://www.scottishcountrydanceoftheday.com/daysoftheyear/reel-of-the-neutrino|Scottish Country Dance of the Day>> site for 13 July.



Dedicated to Kevin Lesko after the awarding of the 2015 Nobel Prize for Physics to the Sudbury Neutrino Observatory (SNO). 



Neutrinos are one of the fundamental subatomic particles. The are neutral (have no charge) and very small mass which mean they can travel great distances unimpeded and are extremely difficult to detect.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17318, '2016-09-09 18:15:58.635844+00', '2021-07-15 22:10:38.115902+00', 'Sophie''s Farewell', 'SOPHIES FAREWELL', 3, 32, NULL, 2, 3, 17, 1383, '1988-03-01', 'Devised for the San Gabriel Valley Branch workshop at Lake Arrowhead, as an exercise in continuity. My grandmother used to live near Lake Arrowhead, and this is dedicated to her. There is no recommended tune yet.', 79, '880/484/888/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8088, '2001-07-18 22:00:00+00', '2021-07-21 11:47:51.709183+00', 'Reel of the Gordon Highlanders, The', 'REEL OF THE GORDON HIGHLANDERS', 1, 32, 9999, 1, 3, 42, 1500, '1994-01-01', 'The dance was devised for the Regiment of the Gordon Highlanders on the occasion of its 200th Anniversary in 1994. 



The inside of the cover of this one dance leaflet also mentions: "The present Regiment stems directly from the amalgamation, in 1881, of the 75th Stirlingshire Regiment and the 92th (Highland) Regiment of Foot. The 92nd, was raised in 1794 as the 100th (Highland) Regiment of Foot - known as the Gordon Highlanders - by Jean, Duchess of Gordon, at a time when Britain faced a war with Revolutionary France. It was renumbered 92nd in 1798. The 75th was raised in 1787 as the 75th Highland Regiment - known as Abercromby''s - in the county of Stirling to assist the East Indian Company. On amalgamation in 1881 the new Regiment was named ''The Gordon Highlanders''. In September 1994 the Gordon Highlanders were amalgamated with the Queen''s Own Highlanders to form a new regiment ''The Highlanders''."', 62, '800/888/888/888', 0, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (20392, '2021-07-15 22:16:19.898558+00', '2021-07-17 08:17:06.979933+00', 'Lionel''s Jig', 'LIONELS JIG', 2, 32, NULL, 1, 2, 76, 11181, '2021-07-16', 'On the occasion of the election of Lionel Laffeach as Chairman of Alba Bihan, SCD Group in Séné, on 14th June 2021.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5978, '1997-04-03 22:00:00+00', '2021-07-17 21:00:25.005402+00', 'Sea-Horse Frolic', 'SEAHORSE FROLIC', 2, 32, 9999, 1, 4, 2, 109, '1974-12-01', 'The dance was written to celebrate the inauguration of the Hunter Valley Branch (Newcastle, NSW, Australia). According to the dance notes the title was derived from the devise in Lieutenant John Shortland''s Coat of Arms. He was the leader of the first colonial expedition in 1794 to where Newcastle now stands.', 75, '8080/8448/8844/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20369, '2021-07-08 15:18:23.593072+00', '2021-08-04 17:48:31.674579+00', 'Three Guirlandes, The', 'THREE GUIRLANDES', 1, 32, NULL, 2, 3, 17, 1049, '2015-01-01', '"Dance devised for Jan and Wil Werner who will be 75 and for Edwin who will be 40 this year (2015). The three of them were living on the address Guirlande 3."', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (157, '2002-08-29 22:00:00+00', '2021-07-18 08:45:37.91402+00', 'Ann Skipper''s Reel', 'ANN SKIPPERS REEL', 1, 32, 9999, 4, 4, 1, 324, '1988-01-01', 'This was my first dance. I wrote it to honor Ann Skipper, founder of the Clan MacLeod Dancers and dance mistress of Clan MacLeod USA. It has become a staple of the Clan MacLeod Dancers demonstration team in southern California, and was published in 1994 in Ann''s new collection, If the Ghillie Fits. 32 bar reel in a square set. 1988. (Wayback Machine source).', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9423, '2002-09-22 22:00:00+00', '2021-08-02 09:47:37.943093+00', 'Golden Heather', 'GOLDEN HEATHER', 4, 64, 5, 4, 4, 13, 308, '1995-01-01', 'This dance was written to celebrate the birthday of my very good friend Heather Redshaw.



However the devisor does not consider this dance works well *(comment received from Sue Petyt by email)*.', 86, '8282/8888/4848/8888/4444/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9529, '2002-09-22 22:00:00+00', '2021-08-02 10:02:15.512608+00', 'Half and Half', 'HALF AND HALF', 3, 32, 9999, 1, 2, NULL, 308, '1998-02-01', 'The first couple dance the first four bars of several figures with second couple, and then dance, the second half of each figure, in reverse order from second place with the third couple.



However the devisor does not consider this dance works well *(comment received from Sue Petyt by email)*.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20393, '2021-07-18 19:37:37.160262+00', '2021-07-18 19:42:56.975575+00', 'Emmanuel''s Jig', 'EMMANUELS JIG', 2, 32, NULL, 1, 3, 42, 11181, '2021-07-18', '', 44, '800/844/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20394, '2021-07-19 21:27:06.567934+00', '2021-07-19 21:36:35.478119+00', 'Ducklings on the Lake of Menteith', 'DUCKLINGS ON THE LAKE OF MENTEITH', 3, 24, NULL, 1, 3, 42, 11570, '2021-07-13', 'The deviser writes "I think everyone knows how calming it is to watch a group of ducklings doing their SCD routines."', 42, '800/888/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16715, '2015-09-03 14:05:35.214019+00', '2021-07-20 09:56:02.141824+00', 'On Bidborough Ridge', 'ON BIDBOROUGH RIDGE', 1, 32, 9999, 4, 55, 35, 10995, '2007-01-01', 'Bidborough Ridge has great views and a bracing breeze which give one a good feeling. Hopefully so will this lively dance matched to a foot –tapping set of tunes   



Explanation of the figure "R&L for 5 dancers".   The corners dance a standard R&L figure, but  the centre dancer dances out on a diagonal, links up with a crossing  pair of dancers to dance a half Tpot with them and finish outside the set. He or she then dances back across the set  in parallel with this pair to repeat the half Tpot with them on the opposite side of the set., again finishing outside the set. Note that if asked to join in on the first 2 bars of the figure, the centre dancer can dance back into the centre on bars 7&8.  Source: <<http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Jig/5Index%20notes.pdf>>.', 80, '44448/88888/44448/88888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11402, '2003-07-17 22:00:00+00', '2021-07-21 12:18:10.702837+00', 'Reel of the Transvaal Scottish, The', 'REEL OF THE TRANSVAAL SCOTTISH', 1, 32, 9999, 1, 3, 42, 1500, '2002-01-01', 'This dance was devised for the Tranvaal Scottish Regiment on the occasion of its Centenary 2002.



The inside of the cover of this one dance leaflet also mentions about the The Tranvaal Scottish:



On 9 June 1902, shortly after the Anglo-Boer War had ended, the Marquis of Tullibardine raised the Tranvaal Scottish Volunteers, as an infantry unit to be part of the embryonic Defence Fore of the Transvaal Colony. In 1910 the name was changed into The Transvaal Scottish. In October 1927, the Transvaal Scottish was affiliated to The Black Watch (Royal Highland Regiment).



Sidenote: According to Aad Boode (the deviser of the dance), the tune was also composed by Bill Clement also in 2002 (same year as the dance itself). 



Bill Clement (the composer of the dance''s tune) served in The Black Watch (Royal Highland Regiment) from May 1942 to April 1947; he joined the 10th Battalion Pipe Band in January 1943 and was acting Pipe-Major from January 1946. He joined the Atholl Highlanders in October 1947.



', 47, '800  800  866  880', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (20395, '2021-07-26 20:04:21.48293+00', '2021-07-26 20:04:21.48293+00', 'Joana''s Jig', 'JOANAS JIG', 2, 32, NULL, 5, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6536, '2002-02-28 23:00:00+00', '2021-07-22 09:47:04.032855+00', 'This Cordial Jig', 'THIS CORDIAL JIG', 2, 32, 9999, 5, 2, 76, 406, '1993-01-01', 'A 32 bar jig to open the Tenth Annual Ball of the Scottish Country Dance Society of Washington D.C.



The last 8 bars are danced with the ''new'' couple.



The title in the <<https://my.strathspey.org/dd/publication/554/|2nd edition (1993) Bicentennial book>> of Harry Ways has the title "This Cordial Jig". There are also references to just "Cordial Jig" (see  <<https://my.strathspey.org/dd/issue/2562/|issue 2562>>). The shorter name is kept as an alias as that is the name currently used by MiniCrib.', 94, '66/88/88/88', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7948, '1997-09-14 22:00:00+00', '2021-07-25 16:51:09.906711+00', 'Sisters of Kintail, The', 'SISTERS OF KINTAIL', 4, 128, 2, 3, 5, 3, 1276, '1969-01-01', 'Originally dedicated (1969) to Ron and Susan Nedderman, Cambridge, England.

Susan was a superb, much-loved teacher to generations of Scottish dancers, who died in April 2000.

Her  husband Ron continued to teach advanced Hugh Foss and John Drewry dances for many years but died in May 2021. 



Adrian writes: This is a demonstration dance, Medley 64S + 64*R (*- extra, optionally, for dancing off), for 5 couples initially in a longwise set, but evolving to an open circle for the start of the reel and ending in a pentagram formation. Large space needed.  Highly geometrical, the reel section has five-fold rotational symmetry, and there are pentagons in some of the strathspey figures as well. 36 diagrams provided.  Danced just once through.  Dance intensity: Strathspey virtually 100%, Reel 100%.

No crib is made by ETF for demonstration dances.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5776, '1997-09-13 22:00:00+00', '2021-07-25 20:01:35.465542+00', 'Russian Fling Reel, The', 'RUSSIAN FLING REEL', 1, 32, 9999, 1, 4, 2, 264, '1998-04-01', 'For 4 Couples in a Longwise Rotating Set. Devised in April 1988 to commemorate the visit of ”A Russian Fling” tour, led by Mr Bob Blackie, Canada, to Stockholm in May 1988.

', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12375, '2005-04-27 22:00:00+00', '2021-07-25 20:11:49.129561+00', 'QuintReel', 'QUINTREEL', 1, 64, 9999, 4, 5, 35, 264, '2003-08-01', 'This dance was devised at the 20th Anniversary camp of the Valley of the Moon Scottish Fiddling School (VOM), California in August 2003.



It started out as quick Scandinavian Waltz but it works well as a Reel too. If danced as a Waltz read 3/4 turn instead of 1 3/4 turn on bars 9-12 and 41-44.



Dedicated to VOM and also to my very good friends Archie and Anna Crawford, of Old Urray, Ross-shire, Scotland.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20597, '2022-01-07 18:04:55.477604+00', '2022-01-07 18:04:55.477604+00', 'Looking forward to St. Andrews', 'LOOKING FORWARD TO ST ANDREWS', 1, 32, NULL, 1, 4, 2, 11514, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20828, '2022-05-14 18:57:19.669387+00', '2022-05-14 18:57:19.669387+00', 'Forsake not the Lomonds', 'FORSAKE NOT THE LOMONDS', 3, 32, NULL, 1, 4, 1, 99, '1999-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20838, '2022-05-14 22:43:39.163981+00', '2022-05-14 22:43:39.163981+00', 'Gardners'' Rant, The', 'GARDNERS RANT', 1, 32, NULL, 1, 3, 42, 99, '2010-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20848, '2022-05-15 21:00:06.107429+00', '2022-05-15 21:00:06.107429+00', 'Sawney Bean''s Reel', 'SAWNEY BEANS REEL', 1, 32, NULL, 3, 5, 7, 99, '1990-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20903, '2022-06-23 18:59:28.212615+00', '2022-06-23 22:04:00.183872+00', 'Catherine Livsey''s Reel', 'CATHERINE LIVSEYS REEL', 1, 32, NULL, 1, 4, 2, 2682, '2022-06-08', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20923, '2022-06-27 16:51:03.625163+00', '2022-06-27 23:46:08.683463+00', 'Hog-Roast Rant, The', 'HOGROAST RANT', 1, 32, NULL, 7, 113, 4, 3325, '2022-06-01', 'This dance has been devised to add to other suitable and easy ceilidh style dances that exist - it gives an

opportunity to meet other dancers. It flows from one figure to the next with the opportunity to walk steps or catch up as necessary.  



Its name derives from a special platinum summer event organised by the Berkhamsted Strathspey & Reel Club.', 75, '4/8/4/8', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7288, '2002-01-08 23:00:00+00', '2022-07-03 18:39:30.601187+00', 'Marianne''s Thistle', 'MARIANNES THISTLE', 2, 32, 9999, 1, 4, 1, 17, '1992-01-01', '', 75, '8282/4844/6666/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19497, '2019-07-25 09:02:09.141203+00', '2021-07-25 20:17:01.839461+00', 'Drummer and the Dancer, The', 'DRUMMER AND THE DANCER', 1, 32, NULL, 2, 3, 17, 264, '2017-04-01', 'For Anders and Susanne Gjörling.



Anders and Susanne met in the Stockholm Scottish Country Dance Club in 1969. Susanne had been dancing then for a while and Anders was a drummer in the newly formed Thistle Pipe Band. He had been ordered by the Pipe Major to learn to dance, to be able to perform the sword dance at the bands performances. This initiative to bring a lot of young bandsmen together with a lot of young female dancers was very successful and Anders and Susanne’s marriage in 1973 was one of a total of four marriages not counting several other flings.



The instructions for bars 31-32 as published in the original Scandinavian Book PDF were slightly mangled in the editing process. They should read:  

*1st couple cross down to third place giving right hands, while 3rd couple cast up to second place to finish the reel and 2nd couple use the two bars to dance a polite turn in place.*', 83, '800/888/888/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16857, '2016-01-27 16:31:06.133923+00', '2021-07-26 14:49:24.173065+00', 'Dance to Say Thank You, A', 'DANCE TO SAY THANK YOU', 4, 64, 5, 1, 4, 1, 11236, NULL, 'Note : the strathspey part is danced with 2nd and 3rd couples and the reel part with 3rd and 4th couples, 1st couple having finished in 2nd place at the end of the Diamond Poussette.



This dance is dedicated to Avril and David Quarrie, two amazing dancers, teachers, and people. It has been written to thank them for their unwavering support to so many young dancers (including myself) whom they’ve encouraged to keep dancing and improving, as well as making them discover a real passion.

This dance may also be used by anyone to say thank you to anyone else because, sometimes, we just don’t say it enough.  

*(from the webpage/book)*', 50, '8220/8880/8220/8080/8022/8088/8022/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13604, '2010-09-20 22:00:00+00', '2021-07-28 16:34:17.419303+00', 'Ribblesdale Strathspey, The', 'RIBBLESDALE STRATHSPEY', 3, 32, 9999, 2, 3, 17, 10245, '2008-10-16', '', 67, '888/844/880/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4741, '2002-09-22 22:00:00+00', '2021-07-30 03:31:57.907363+00', 'Mrs Bunty Somes', 'MRS BUNTY SOMES', 3, 40, 9999, 1, 4, 1, 308, '1995-08-01', 'Mrs  Bunty  Somes  was  a  well  loved,  much  treasured,  long  standing  member  of Scunthorpe Scottish Country Dance Club. ', 53, '8800/8044/8880/8822/8000', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20403, '2021-07-26 20:10:48.65051+00', '2021-08-22 20:08:13.749786+00', 'Banffshire Centenarian, The', 'BANFFSHIRE CENTENARIAN', 3, 32, NULL, 3, 5, 16, 384, NULL, '2nd couple''s path represents the "1" of the number "100" and the other couples'' circles represent the two zeros.  



', 70, '48884/48884/80000/88888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9846, '2001-05-20 22:00:00+00', '2021-12-01 22:54:11.756832+00', 'Cordial Jig  TRANSFER LINKS TO This Cordial Jig 6536', 'CORDIAL JIG  TRANSFER LINKS TO THIS CORDIAL JIG 6536', 2, 32, 9999, 5, 2, 76, 9998, NULL, 'This dance is an accidental duplicate of <<ddd:This Cordial Jig#6536>>. It should be deleted. However it appears on several dance lists so cannot be removed so easily.', 94, '66/88/88/88', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14723, '2013-03-14 09:59:14.71772+00', '2021-08-02 19:54:51.135203+00', 'Lamp Black Lizzie', 'LAMP BLACK LIZZIE', 2, 40, NULL, 1, 100, 11, 3087, NULL, 'Devised by Pat Davoll, in 2007, in memory of Lizzie Vasey, who danced regularly with the East Grinstead Scottish Dance Club and Oxford University Scottish Dance Society. Lamp black is a fine black powder used in pest control, where Lizzie used to work. When she used it, Lizzie would invariably end up covered in it; hence her nickname of "Lamp Black Lizzie".', 80, '8008/8008/8888/8888/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11591, '2003-11-29 23:00:00+00', '2021-08-02 20:04:58.154743+00', 'Hope for Harriet', 'HOPE FOR HARRIET', 1, 32, 9999, 2, 2, 76, 411, '2003-01-01', 'For Roderick Nobes.  



Roderick passed his Teacher’s Certificate examination in 2001, teaching "Lady Harriet Hope’s Reel" as his test dance.  

This dance avoids the teaching points of that dance and introduces some new ones.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18696, '2018-10-02 20:45:10.567088+00', '2021-08-10 18:44:20.131422+00', 'Scholar''s Bus, The', 'SCHOLARS BUS', 2, 32, NULL, 1, 3, 42, 10959, '2013-12-01', 'In the mid 1950s my sister & I attended Finsbay School on the Island of Harris for a short while. The same school my father & his siblings attended in the years after the Great War. The Quidinish scholars who lived far from the school had to walk to the nearest roadhead, as there was no road down to their crofts, & from there they would catch a ride in a van to school. The van passed my aunt''s house & as she was the school teacher, both she & my sister & I had a ride to school.', 68, '808/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1203, '1998-10-31 23:00:00+00', '2021-08-03 11:29:06.053686+00', 'Jeep''s Jig', 'JEEPS JIG', 2, 48, 9999, 1, 4, 1, 1847, '1961-01-01', 'Jeep was the pug dog belonging to Captain Elder, for many years Bedellus of the university and honorary president of New Scotland. Jeep was adopted as New Scotland mascot, and when he died, his successor, Jeep II, was adopted likewise.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19010, '2018-10-17 19:27:00.057199+00', '2021-08-10 18:46:34.821811+00', 'Erindale Jig, The', 'ERINDALE JIG', 2, 32, NULL, 1, 3, 42, 2787, '2014-03-01', 'Devised for the Sunday Teachers'' Workshop, Mississauga, Canada, March 2014, with thanks to the Demonstration Class at Edinburgh University for acting as guinea pigs!  

 Transitions from pas de basque into slip step into skip change  

 Lengthening skip change in bars 17 - 24  

 Handing in bars 3 - 6, 9 - 16, 17 - 24, 25 - 32  

 Not too tiring for supporting couples as a first dance in a class  

 Only 1s begin so can be used as a once-and-to-the-bottom dance if numbers are low  

 A World shortage of simple jigs to begin a class with!  ', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20416, '2021-07-30 12:54:52.832507+00', '2021-08-04 02:17:24.366395+00', 'Jig to St. Benedict, A', 'JIG TO ST BENEDICT', 2, 32, NULL, 1, 100, 2, 12051, NULL, 'Dance devised by Patricia and John Cass with help from the Thursday Afternoon Class and sold in aid of St Benedict''s Hospice, Sunderland.', 75, '8008/8888/8888/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11709, '2004-03-18 23:00:00+00', '2021-08-10 19:04:01.966517+00', 'Tam o'' Shanter', 'TAM O SHANTER', 2, 40, 9999, 1, 4, 1, 666, NULL, 'Story to go with the dance  

1  -  8  Tam looks for his horse  

9  - 16 Tam and horse (Meg) ride for home  

17 - 24 Witches dancing (one is a really good dancer)  

25 - 32 Witches chase Tam and Meg  

33 - 40 The only way to escape witches in 18th century Scotland was to cross running water, so Tam and horse escape over a bridge.   Leading witch was a fast runner as well as a good dancer and she grabs the horses tail and pulls it off.

', 50, '8000/8000/0888/8888/4004', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9999, '2001-07-19 22:00:00+00', '2021-08-04 17:40:28.263077+00', 'Life Begins at Fifty', 'LIFE BEGINS AT FIFTY', 1, 32, 9999, 1, 4, 1, 1049, '1995-01-01', '"Dance devised for Tom and Anja Wetemans on the occasion of their 50th anniversary April 2 and September 8, 1995."', 72, '8448  0880  8888  8444', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (11081, '2002-12-01 23:00:00+00', '2021-08-10 12:05:47.20264+00', 'Salute to Noel Lillie', 'SALUTE TO NOEL LILLIE', 3, 32, 9999, 1, 4, 2, 782, '1985-01-01', 'Dance devised for Noel Lillie, of Seattle, for his unselfish help in starting the Portland Scottish Country Dance Club.', 81, '8888/8448/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20405, '2021-07-26 20:11:51.625543+00', '2022-09-23 19:57:04.206464+00', 'Bouquet of Flowers, A', 'BOUQUET OF FLOWERS', 1, 48, NULL, 1, 3, 42, 12062, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20404, '2021-07-26 20:11:12.63479+00', '2022-12-04 13:58:48.821214+00', 'Haudagain Roundabout, The', 'HAUDAGAIN ROUNDABOUT', 2, 32, NULL, 4, 4, 1, 10492, NULL, 'The Haudagain Roundabout is a notoriously busy junction on the A96 on the outskirts of Aberdeen.', 75, '8080/0808/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19963, '2020-04-27 22:10:48.881718+00', '2021-08-14 08:44:36.881806+00', 'Happy Birthday, Kennocha!', 'HAPPY BIRTHDAY KENNOCHA', 2, 32, NULL, 105, 53, 17, 11509, '2019-04-01', 'This may be danced as a reel.  



This dance was devised for my daughter’s birthday. She was disappointed that I was not going to be with her in the morning of the very day of her ninth birthday since I was going to be teaching in Méaudre scd May week-end while she was busy somewhere else. So I decided to write a dance that we could dance with my husband and her to celebrate together in the evening.', 92, '888/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (684, '1998-10-18 22:00:00+00', '2021-08-14 21:43:10.491603+00', 'Bonnie Hoose o'' Airlie, The', 'BONNIE HOOSE O AIRLIE', 1, 112, 9999, 4, 4, 3, 708, NULL, 'Versions of the instructions variously use "of Airlie" and "o'' Airlie", Jig and Reel and in bars 29-32 the turns are sometimes with two hands and sometimes with the right hand.', 88, '4444/8888/8080/8888/8888/8888/0808/8888/8888/8888/7777/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14991, '2013-07-24 14:57:30.352562+00', '2021-08-15 06:07:58.114802+00', 'Start Your Engines', 'START YOUR ENGINES', 2, 32, NULL, 1, 3, 42, 2932, '2012-06-26', 'Devised by Ellen Ternes (ellenter [at] comcast.net) after learning, with great glee, that the very Italian-looking Dario Franchitti, winner of the 2012 Indy 500 race, is very Scottish!



Suggested music: "Flights of Fancy," from Celebrate 50 Years of Dancing with the

Boston Branch.



The deviser is non-committal about the music, even noting that it could be danced as a reel.

', 56, '844/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20428, '2021-08-16 00:07:27.5936+00', '2021-08-16 14:20:13.456047+00', 'Burnett Strathspey, The', 'BURNETT STRATHSPEY', 3, 32, NULL, 1, 3, 42, 440, '2010-10-01', 'Devised in October 2010 for Valerie Westgate, friend and fellow member of St. Andrew’s of Brampton, whose grandmother’s maiden name was Burnett – Valerie’s only claim to a Scottish connection.', 72, '888/888/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10459, '2002-08-25 22:00:00+00', '2021-10-11 22:40:57.182113+00', 'Falkirk Lass, The', 'FALKIRK LASS', 3, 32, 9999, 1, 3, 42, 1760, '2000-01-01', 'Elaine, who was born in Falkirk, went to Dunfermline College of Physical Education in Edinburgh where she danced to Muriel, neither of them having any idea of the connection that would be made later in the USA. Elaine now teaches in Virginia and is an enthusiastic ambassador for music and dance all over North America.', 56, '800  888  844  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (10978, '2002-11-19 23:00:00+00', '2021-08-06 08:51:00.067639+00', 'Dance for Forty, A', 'DANCE FOR FORTY', 1, 32, 9999, 1, 3, 42, 3233, NULL, 'A wee story about the figures: First couple runs down to the wine cellar (bars 1-8).Having found and brought back a bottle, all set in celebration.  

The bottle is uncorked (bars 9-24). All circle as the wine flows freely. Celebrations ensue…  



Notes: The second figure is similar to Argyll Strathspey and Culla Bay. Dancers can flow from the reel into the circle but there is also time for the supporting couples to finish the reel in place before joining the circle.  



The dance was devised by Seth Major and Sarah McCullough on the occasion of Terry Harvey’s 40th birthday.', 53, '800/822/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16699, '2015-09-02 00:01:31.681963+00', '2021-08-05 10:29:54.253633+00', 'Wes Clindinning''s Hornpipe', 'WES CLINDINNINGS HORNPIPE', 1, 32, 9999, 2, 3, 17, 51, '2001-01-01', 'This dance is a modified version of Wes Clindinning’s "<<https://my.strathspey.org/dd/dance/454/|The Belfast Hornpipe>>" devised in 1989. The only difference is bars 25-28 (Wes used set and cast for 1C), and thus also the direction of the butterfly turns in bars 29-32. 



This dance is dedicated to Wes, a superb teacher and fun dancer.



This dance was ''devised'' by Mel Briscoe during a Workshop by inadvertently changing the last 8 bars. However, that variant was so successful that it made it into a number of dance programs and crib collections... unfortunately under the wrong name “Belfast Hornpipe”. 



For example, the dance had been incorporated as "Belfast Hornpipe” in the Ball program at <<https://dances.e-cribs.org/var/RSCDS_Twin_Cities_Branch_27th_Annual_Grand_Ball.pdf>>. This has been corrected to "Wes Clindinning''s Hornpipe" in the meantime.



The dance named "Belfast Hornpipe (New Way)” at <<https://dances.e-cribs.org/var/Cincinnati_Demo_Dances_2007-2008.pdf>> (there attributed to Mel Briscoe) seemingly also describes a variant of this dance, but with reversed directions of the two turns in the last 8 bars.', 50, '440/448/800/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8074, '1998-07-09 22:00:00+00', '2021-08-10 06:45:43.941301+00', 'Raccoon Ramble', 'RACCOON RAMBLE', 1, 32, 9999, 2, 3, 17, 954, '1996-01-01', 'An easy dance for 3 couples in which only the 1st couple start, and the dance ends with a circle. For teaching purposes, the rights and lefts in bars 17-24 may be replaced with right hands across and left hands back, set and cross right and set and cross back for 3 couples, or promenade for 3 couples or any other appropriate, non-progressive, formation. If there is a 4th couple the last circle is 8 hands round and back.



The name of the dance came to mind one night when some raccoons came into my back yard while I was preparing the lesson for my class. (SLK)', 44, '800/800/808/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20425, '2021-08-07 11:17:01.923257+00', '2021-08-07 11:35:34.900093+00', 'Golden Fantail, The', 'GOLDEN FANTAIL', 3, 32, NULL, 3, 5, 21, 11035, '2021-07-01', 'Detailed instructions can be found in the youtube video <<https://youtu.be/xI_wcSY42d0>>.', 69, '77077/80208/80880/88888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20427, '2021-08-07 18:42:44.23439+00', '2021-08-07 19:05:05.719432+00', 'MUGA Reel, The', 'MUGA REEL', 1, 32, NULL, 1, 3, 42, 11863, '2021-07-01', 'Devised to celebrate Kilmorack SCDC returning to dancing post Covid restrictions with a series of outdoor dances held in the Kirkhill Community Centres Multi Use Games Area during July and August 2021.', 69, '844/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6347, '1997-12-03 23:00:00+00', '2021-08-09 15:55:59.592835+00', 'Tabby Cat, The', 'TABBY CAT', 2, 32, 9999, 1, 3, 42, 954, '1996-01-01', 'I was looking for a simple three couple dance with figures we had already done. This works well since the first eight bars are a solo for the 1st couple so it is easy for the old 1st couple to step down into 4th place after the second time through. Also its not so tiring for supporting couples as a two couple dance. Besides, I love dances that end with a circle!  

This dance is named for my beloved cat, who is a tabby. (SLK)', 50, '800/888/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20426, '2021-08-07 12:14:02.935463+00', '2021-08-08 17:56:39.034548+00', 'We''re no awa''', 'WERE NO AWA', 1, 0, NULL, 1, 4, NULL, 555, NULL, 'Demonstration dance set to music by Tommy Scott. Starts with 4 couples.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8062, '1997-09-18 22:00:00+00', '2021-08-09 15:46:06.597065+00', 'Katie''s Dance', 'KATIES DANCE', 1, 32, 9999, 1, 3, 42, 758, '1988-01-01', 'Katie was a member of my Children''s Class who came along to Dancing in the Park soon after she began dancing. She didn''t know many figures but she learned quickly and the Big Kids enjoyed seeing her progress. (JH)', 34, '800/800/804/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16537, '2015-07-31 14:36:26.317703+00', '2021-08-10 18:43:07.072622+00', 'Countess of Dunmore''s Reel, The', 'COUNTESS OF DUNMORES REEL', 1, 32, 9999, 1, 3, 42, 10959, '2012-10-01', 'In the mid 19th century, the Earl of Dunmore owned the whole of the Island of Harris. After the passing of the 1872 Education (Scotland) Act, Catherine, Countess Dowager of Dunmore, gave lands in favour of the School Board of the Parish of Harris for the building of schools. These included Finsbay School, which was attended by members of the deviser''s family.', 56, '800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20449, '2021-08-20 15:12:30.09207+00', '2021-08-20 15:58:39.123432+00', 'Shall we dance?', 'SHALL WE DANCE', 3, 32, NULL, 2, 3, 17, 11225, '2020-02-01', '', 53, '800/888/822/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3063, '1997-09-04 22:00:00+00', '2021-08-10 18:17:43.849984+00', 'Ice Crystals', 'ICE CRYSTALS', 3, 32, 9999, 1, 3, 42, 428, NULL, 'The notes say that "the movement of the dance represents patterns traced by ice crystals forming frost on a window pane."', 50, '822/866/448/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19119, '2018-12-15 15:13:41.28833+00', '2021-08-10 18:45:45.074584+00', 'Farewell to Benbecula', 'FAREWELL TO BENBECULA', 3, 32, NULL, 2, 3, 17, 10959, '2014-01-01', 'For Theresa Malek to celebrate a special birthday:  

Theresa''s ancestors were cleared from Benbecula in the 1840s & compelled to emigrate to North America.  



_Music_: Farewell to Benbecula by Marian Anderson. Copyright Maramax Music or alternative CD Ribble Valley CD: David Queen''s Strathspey', 72, '880/886/800/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20474, '2021-09-12 10:25:03.439714+00', '2021-09-12 10:25:03.439714+00', 'Parting Glass, The', 'PARTING GLASS', 3, 32, NULL, 1, 3, 42, 2682, '2021-02-25', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20478, '2021-09-12 12:30:25.935199+00', '2021-09-12 12:30:25.935199+00', 'Daydream', 'DAYDREAM', 2, 32, NULL, 1, 4, 1, 2682, '2021-07-19', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12140, '2005-04-10 22:00:00+00', '2021-08-16 14:00:23.967132+00', 'Award of Scroll, The', 'AWARD OF SCROLL', 1, 32, 9999, 1, 3, 42, 440, '1997-11-08', 'Devised in honour of Jim Stephens, a former teacher of the St. Andrew’s of Brampton

Scottish Country Dance group, who received the Award of Scroll for services to the

R.S.C.D.S. on November 8, 1997.', 50, '800/844/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17148, '2016-07-12 22:44:56.979439+00', '2021-08-16 16:31:06.262117+00', 'That''s All You''re Getting!', 'THATS ALL YOURE GETTING', 1, 32, NULL, 1, 3, 42, 10338, '2011-01-01', 'For Bill Forbes on the occasion of his 90th birthday.



"That''s all you''re getting!" is one of Bill''s stock expressions.  When teaching at St. John''s SCDC, Bill might occasionally say this immediately after a quick walkthrough or recap, at which point he would expect everyone to just dance the dance.  It certainly encourages us to learn quickly, and proves to us (on most occasions) that we are able to just dance it.  



Recommended tune: <<ddt:Braes of Enzie, The#11344>> by Alister Forbes. Recorded music: Selection of Strathspeys found on CD Scottish Dance Country by Bobby Brown. Note the order of words ‘Scottish Dance Country’ is as written in dance instructions.', 63, '800/888/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20429, '2021-08-16 22:37:12.302183+00', '2021-08-16 22:42:17.052876+00', 'Robin Hood''s Bay', 'ROBIN HOODS BAY', 2, 32, NULL, 1, 4, 1, 625, '1998-06-06', 'Robin Hood''s Bay is a quaint fishing village on the east coast of England.



The dance was devised for audience participation dancing or a first night of class. It can be done in a 3-couple set.

', 62, '8888/8888/8000/8000', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20430, '2021-08-17 23:10:32.832262+00', '2021-08-19 14:01:11.444834+00', 'Heather''s Strathspey', 'HEATHERS STRATHSPEY', 3, 32, NULL, 1, 2, 76, 440, '2014-10-23', 'Devised on October 23, 2014, for Heather Collins, friend and fellow member of St Andrew’s of Brampton. The first 8 bars are inspired by “Glastonbury Tor”.', 60, '88/88/80/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20433, '2021-08-19 15:21:14.571773+00', '2021-08-19 15:35:55.750036+00', 'St. Andrew''s Salute to Saskatoon', 'SAINT ANDREWS SALUTE TO SASKATOON', 3, 40, NULL, 2, 3, 17, 440, '2011-11-14', 'Devised on November 14, 2011, for Sandra Beardsall and Bill Richards who spent several weeks dancing with us while living in Brampton and whom we will miss when they head home to Saskatoon.', 65, '880/888/888/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20437, '2021-08-19 20:42:52.538899+00', '2021-08-19 20:42:52.538899+00', '''Inn'' Strathspey, The', 'INN STRATHSPEY', 3, 32, NULL, 2, 3, 17, 10387, '2021-01-01', '', 83, '844/888/448/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20434, '2021-08-19 16:38:04.199114+00', '2021-08-20 07:58:42.505173+00', 'Susan''s Syringa Strathspey', 'SUSANS SYRINGA STRATHSPEY', 3, 32, NULL, 1, 3, 42, 440, '2006-09-28', 'Devised on September 28, 2006 for Susan Elliotson, friend and fellow member of St. Andrew’s of Brampton, who suggested the title, because “Syringa” (lilac), one of her favourite flowers, extended the alliteration.', 52, '800/855/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11582, '2003-11-11 23:00:00+00', '2021-08-20 10:08:48.933202+00', 'Uisge Beatha', 'UISGE BEATHA', 3, 32, 9999, 2, 3, 17, 553, '1999-10-01', 'The dedication reads: For my good friend Lawson Thomas on his 65th birthday. Slainte!', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20431, '2021-08-18 16:35:31.718017+00', '2021-08-20 11:02:01.980659+00', 'Kathleen Stokoe of Dundee', 'KATHLEEN STOKOE OF DUNDEE', 3, 32, NULL, 1, 2, 76, 440, '2011-02-11', 'Devised on February 11, 2011, for Kathleen Stokoe, friend and fellow member of St. Andrew’s of Brampton (and to add to the repertoire of two couple dances).', 52, '44/44/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20444, '2021-08-20 13:42:18.694933+00', '2021-08-20 13:56:34.774079+00', 'Roberta, MBE', 'ROBERTA MBE', 1, 32, NULL, 1, 3, 42, 440, '2016-01-18', 'Devised on January 18, 2016, for my old school friend, Roberta Lees, MBE, former head of Speech Therapy at Strathclyde University in Glasgow.', 59, '884/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20438, '2021-08-19 22:51:11.249662+00', '2021-08-20 13:57:12.723287+00', 'Tiger Two Step', 'TIGER TWO STEP', 2, 32, NULL, 7, 2, 76, 12057, '2021-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20440, '2021-08-20 12:41:28.078515+00', '2021-08-20 14:02:15.483302+00', 'Demo Dandy Dancers', 'DEMO DANDY DANCERS', 1, 32, NULL, 1, 100, 103, 11827, '2021-01-01', '', 75, '8008/8888/8008/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20447, '2021-08-20 14:14:09.333495+00', '2021-08-20 14:24:10.471713+00', 'In Memory of Marjorie', 'IN MEMORY OF MARJORIE', 3, 32, NULL, 1, 3, 42, 440, '2016-02-18', 'Devised on February 18, 2016, in memory of Marjorie Coulter, founder of St Andrew’s of Brampton, who died on February 11, 2016.', 63, '888/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20432, '2021-08-19 12:47:45.534604+00', '2021-08-20 14:24:23.229099+00', 'Welcome to the Stagger Inn', 'WELCOME TO THE STAGGER INN', 1, 32, NULL, 5, 2, 76, 10240, '2021-01-01', '', 100, '88/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20448, '2021-08-20 15:06:02.062957+00', '2021-08-20 15:34:14.683881+00', 'Dance for Donna, A', 'DANCE FOR DONNA', 4, 64, 5, 1, 3, 42, 440, '2016-02-26', 'Devised on February 26, 2016, for Donna Campbell, long time friend and fellow member of St Andrew’s of Brampton.', 63, '888/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20446, '2021-08-20 13:54:34.641061+00', '2022-02-14 00:58:04.645819+00', 'Staggering Hame', 'STAGGERING HAME', 2, 32, NULL, 2, 3, 17, 11412, '2021-01-01', '', 50, '440/404/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20445, '2021-08-20 13:47:16.143153+00', '2022-06-27 11:57:02.087575+00', 'Last Orders', 'LAST ORDERS', 3, 32, NULL, 1, 3, 42, 2101, '2021-01-01', '', 56, '880/888/844/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19835, '2020-01-23 23:55:42.834496+00', '2022-10-01 14:58:20.467394+00', 'African Monarch', 'AFRICAN MONARCH', 3, 32, NULL, 1, 4, 2, 11220, '2019-01-01', 'Monarch butterflies in general are well known for making long migratory flights. This dance has been written to commemorate both Emma Trousdale and Carmen Davidson, both of whom find themselves, very much not by choice, needing to migrate to opposite ends of the planet. We wish them both well as they head to new adventures in the UK and New Zealand respectively, and we shall remember them when we see the African Monarch Butterflies, until they both return home.



Travel well, our African Monarch butterflies.



Andrew and Heather Hodgson,

December 2019', 50, '8008/8008/8008/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20439, '2021-08-20 12:28:17.6741+00', '2022-12-04 17:27:14.527214+00', 'Ewan''s Midnight Medley', 'EWANS MIDNIGHT MEDLEY', 4, 128, 10034, 4, 4, 28, 10648, '2021-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20443, '2021-08-20 13:39:07.006407+00', '2022-12-04 17:33:16.362558+00', '2am Jig, The', '2AM JIG', 2, 32, NULL, 1, 3, 42, 11827, '2021-01-01', '', 56, '800/844/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20441, '2021-08-20 13:06:36.590564+00', '2023-01-17 10:56:33.073791+00', 'Da Trowie Reel', 'TROWIE REEL', 4, 32, 8, 2, 3, 17, 2793, '2021-01-01', 'The last 8 bars of this dance have been revised since the original publication and should be:



25-32    All three couples dance 6 Hands round to the right for 6 slip steps, pull back RIGHT shoulder and skip change back to place.



The video uploaded by Sarah Horne on 16 December 2021 is correct.', 64, '804/844/800/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20396, '2021-07-26 20:05:15.107238+00', '2021-08-21 13:45:47.955987+00', 'John McLean''s Reel', 'JOHN MACLEANS REEL', 1, 32, NULL, 1, 4, 2, 3688, NULL, 'The tune was written for John McLean by James Alexander. Sheena Gray, a friend of John and his wife asked if Margaret would devise a dance for John.  

He was invited to the Bellie Hall and the dance was performed for him.', 69, '8008/8448/8448/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20435, '2021-08-19 20:26:45.283019+00', '2021-09-07 19:12:20.119221+00', 'Young Accordion Man, The', 'YOUNG ACCORDION MAN', 1, 32, NULL, 1, 3, 42, 2793, '2021-01-01', '', 39, '844/844/622/422', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20436, '2021-08-19 20:35:57.95072+00', '2021-09-07 19:13:37.614269+00', 'Barmaids'' Jig, The', 'BARMAIDS JIG', 2, 32, NULL, 3, 5, 7, 10240, '2021-01-01', '', 79, '84844/88880/84884/86866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20475, '2021-09-12 10:29:52.174872+00', '2021-09-12 10:29:52.174872+00', 'Bowls Club Reel, The', 'BOWLS CLUB REEL', 1, 32, NULL, 1, 3, 42, 2682, '2021-04-30', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20455, '2021-09-04 09:56:21.884034+00', '2021-09-04 10:00:32.22038+00', 'Bouquet for May, A', 'BOUQUET FOR MAY', 3, 32, NULL, 2, 3, NULL, 11981, '2021-07-01', 'Dedicated to May Macfarlane, founder of the Tayside Scottish Country Dancing Groups in Toronto and presented to her on the occasion of her 94th birthday in July 2021 in London, Ontario.



Source: September 2021 issue of <<ddpub:Set and Link#1290>>.', 69, '880/808/288/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20316, '2021-04-14 10:45:23.615846+00', '2021-11-25 01:04:38.728038+00', '#ILoveNice', 'ILOVENICE', 2, 32, NULL, 1, 3, 42, 11643, '2017-01-01', 'The dance is dedicated to all the victims of the terrorist attack which happened in Nice on July 14, 2016. After that the city decided to create the hashtag #I LoveNice to celebrate the city, the people, unity and to share a positive energy.', 44, '800/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20400, '2021-07-26 20:09:09.990527+00', '2021-08-22 11:48:59.913943+00', 'Portsoy Links', 'PORTSOY LINKS', 3, 32, NULL, 2, 3, 17, 3286, NULL, 'Alison and her husband Brian signed up as volunteers at Portsoy''s Salmon Bothy Museum when it opened in 2009. The name of the dance was inspired by the situation of the Salmon Bothy on Links Road in Portsoy.', 48, '880/880/800/868', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8077, '1997-09-18 22:00:00+00', '2021-08-23 18:33:10.365835+00', 'Reeling at St. Paul''s', 'REELING AT ST PAULS', 1, 32, 9999, 1, 2, NULL, 1391, NULL, 'In bars 1-16, 2nd couple change who cuts the reel. In the first reel, 2nd man cuts the reel and in the second reel it is 2nd woman who cuts the reel.  

I wrote this because in a small class, when too few students show up, I wanted to be able to teach reels of three. The name of the dance honors st. Paul''s Episcopal Church where I teach one of my classes in Tustin, California. (DK)', 52, '48/48/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11095, '2002-12-05 23:00:00+00', '2021-08-24 07:22:55.484086+00', 'Hodgson Strathspey', 'HODGSON STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3287, '2001-03-01', 'Dance devised to mark Vernon and Barbara Hodgson''s retirement from the Church in Llanbister and their subsequent removal to Cardi/ f. We shall miss them but we look forward to their promised visits.', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20456, '2021-09-04 19:42:04.185969+00', '2021-09-16 23:05:33.406326+00', 'Unexpected, The', 'UNEXPECTED', 1, 48, NULL, 1, 100, 2, 1228, '2019-02-01', '', 77, '8008/8668/8668/8668/8668/8228', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20457, '2021-09-06 08:53:35.338872+00', '2021-11-15 23:48:20.40095+00', 'Annie''s Dance', 'ANNIES DANCE', 2, 32, NULL, 1, 4, 2, 10568, '2021-01-01', 'Written to celebrate Annie''s 40th birthday.', 100, '8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20451, '2021-08-30 20:59:48.99028+00', '2021-08-31 22:17:36.572279+00', 'Cachette House, La', 'CACHETTE HOUSE', 1, 40, NULL, 1, 3, 42, 11181, '2021-08-31', 'La Cachette was the home of Brenda Gale, teacher in Jersey, and her husband Richard for many years before they moved to the coast. It holds happy memories for them and for Roland Telle who has enjoyed many happy hours on the dance floor with Brenda and drinking Breton beer with Richard.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20453, '2021-09-03 01:59:45.089409+00', '2021-09-03 02:01:08.388461+00', 'Visiting Brittany', 'VISITING BRITTANY', 3, 32, NULL, 1, 4, 1, 11181, '2021-09-03', '', 94, '8888/8888/8888/8088', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2045, '1997-08-27 22:00:00+00', '2021-09-03 10:05:57.612169+00', 'Fairy Flag, The', 'FAIRY FLAG', 1, 32, 9999, 1, 3, 42, 108, '1967-01-01', 'Inscribed to Miss F. Adams of Wishaw.

', 56, '844/808/888/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13448, '2009-11-16 23:00:00+00', '2021-09-06 08:42:52.540192+00', 'River Ness, The', 'RIVER NESS', 1, 32, 9999, 3, 5, 7, 1911, NULL, 'Published in the Diamond Jubilee Collection of the RSCDS Inverness and District Branch: <<http://my.strathspey.org/dd/publ/1027/>>', 79, '88886/84884/88888/80800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17478, '2016-11-06 17:47:24.461772+00', '2021-09-11 00:47:59.955928+00', 'City of Birmingham, The', 'CITY OF BIRMINGHAM', 3, 32, NULL, 1, 100, 2, 3694, NULL, 'At a dance, one of the MC''s had problems with dance titles slightly mixing up ''City of Belfast'' and ''The Library of Birmingham'' to become ''The City of Birmingham'' so we had to devise a dance to add to the confusion! ', 84, '8888/8448/8888/8228', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20458, '2021-09-07 00:53:31.671324+00', '2021-09-07 01:04:51.952877+00', 'Cribmaster Extraordinaire', 'CRIBMASTER EXTRAORDINAIRE', 1, 32, NULL, 1, 3, 42, 440, '2021-09-03', 'Devised by Ann Campbell on September 3, 2021, for Roland Telle, to thank him for all his help and encouragement.', 59, '848/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20460, '2021-09-11 23:02:04.908862+00', '2021-09-11 23:02:04.908862+00', 'Bluetooth Beastie, The', 'BLUETOOTH BEASTIE', 1, 40, NULL, 1, 3, NULL, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20466, '2021-09-11 23:07:30.018554+00', '2021-09-11 23:07:30.018554+00', 'Irish Eyes are Smiling', 'IRISH EYES ARE SMILING', 4, 128, 2, NULL, NULL, NULL, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20459, '2021-09-07 20:28:52.386649+00', '2021-09-07 20:43:16.691523+00', 'Twenty-five Glorious Years', 'TWENTYFIVE GLORIOUS YEARS', 2, 32, NULL, 1, 3, 42, 440, '2010-05-01', 'Devised in May 2010 for Paul Maloney to celebrate his 25th anniversary as the revered teacher of St Andrew’s of Brampton. This dance was premiered on September 22, 25 years and 4 days after Paul began teaching the group.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20461, '2021-09-11 23:03:31.707765+00', '2021-09-11 23:03:31.707765+00', 'Cameron Bandshell, The', 'CAMERON BANDSHELL', 2, 32, NULL, 1, 4, NULL, 3618, NULL, 'Can be danced with 3, 4 or 5 couples.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20462, '2021-09-11 23:04:13.43001+00', '2021-09-11 23:04:13.43001+00', 'Roses of Saint Martins, The', 'ROSES OF SAINT MARTINS', 3, 40, NULL, 1, 4, NULL, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20463, '2021-09-11 23:05:11.708172+00', '2021-09-11 23:05:11.708172+00', 'Golden Anniversary Reel, The', 'GOLDEN ANNIVERSARY REEL', 1, 40, NULL, 1, 3, NULL, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20464, '2021-09-11 23:05:47.272516+00', '2021-09-11 23:05:47.272516+00', 'Dancing Memories', 'DANCING MEMORIES', 3, 32, NULL, 1, 4, NULL, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20465, '2021-09-11 23:06:35.74775+00', '2021-09-11 23:06:35.74775+00', 'Musical Ride, The', 'MUSICAL RIDE', 1, 40, NULL, 4, 4, NULL, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20469, '2021-09-11 23:09:30.439648+00', '2021-09-11 23:09:30.439648+00', 'Victorians, The', 'VICTORIANS', 3, 80, NULL, 4, 4, NULL, 3618, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20398, '2021-07-26 20:08:09.418597+00', '2022-08-15 15:13:48.620637+00', 'Fond Farewell, A', 'FOND FAREWELL', 2, 32, NULL, 1, 4, 2, 12060, '1998-01-01', 'Devised by Alice Archibald to mark the retirement of Rev. David Butters as Minister of St Ninian''s and Forglen Parish Church, Turriff in January, 1998.', 88, '8888/8888/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20454, '2021-09-04 09:35:26.192699+00', '2022-05-29 21:04:14.949624+00', 'Jogger, the Astronomer, and the Ballerina, The', 'JOGGER THE ASTRONOMER AND THE BALLERINA', 1, 32, NULL, 1, 3, 42, 12064, '2013-01-01', 'Source: September 2021 issue of <<ddpub:Set and Link#1290>>.', 63, '840/888/866/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20399, '2021-07-26 20:08:38.860616+00', '2022-12-04 13:55:39.766394+00', 'Millbank Reel, The', 'MILLBANK REEL', 1, 32, NULL, 1, 3, 42, 12061, NULL, 'This dance was inspired by happy memories of the children who attended the Scottish Country Dance Classes at Millbank Primary School, Buckie.', 50, '888/800/800/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11585, '2003-11-23 23:00:00+00', '2021-11-09 09:25:39.730231+00', 'Maxwells Rant Again, The', 'MAXWELLS RANT AGAIN', 3, 32, 9999, 1, 4, 2, 108, '2002-11-01', 'For Colin and Betsy Maxwell of Eaglesfield.



Drewry writes: *When this dance was danced in Morland in May 2003, we did it in strathspey tempo to allow dancers to get used to its slightly unusual format, before dancing it as a reel. I got the impression that most of the class were more comfortable with it at the slower tempo. Of course confident dancers are at liberty to do the dance in reel tempo.

When it was tried out in Dumfries with Colin and Betsy in the class, it went well as a reel after an initial walk-through.

It could be danced as a medley - four times as a strathspey and then four times as a reel. If the dance is to be repeated, 4th couple, in second place, may stay facing out, ready to dance out and up.*



So although currently classified as a strathspey in SCDDB, both strathspey travel and skip change steps are listed.



Although the original inspiration is "Maxwell''s Rant" (with apostrophe), the instructions for this dance have it without apostrophe. The alternative is added as a spelling alias.', 75, '8888/8888/8080/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20483, '2021-09-13 07:12:12.844525+00', '2021-09-13 07:44:16.340123+00', 'Mechthild & Andrew', 'MECHTHILD AND ANDREW', 3, 32, NULL, 1, 3, 42, 12065, '1995-01-01', '', 38, '800/800/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9355, '2000-03-15 23:00:00+00', '2021-09-13 14:23:23.971423+00', 'Andrew''s (My) Delight', 'ANDREWS MY DELIGHT', 2, 32, 9999, 1, 4, 1, 448, '1983-01-01', 'Ronda and Peter Ovenden, friends and teachers of the Cleveland group in Brisbane, Australia, named this dance as I had always used it as an exercise dance on the Friday nights.', 59, '8080/0808/6060/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20572, '2021-12-03 22:36:04.100786+00', '2021-12-04 12:10:51.611221+00', 'Kenilworth', 'KENILWORTH', 2, 32, NULL, 1, 3, 42, 9998, NULL, 'Originally published in 1822 by Nathaniel Gow as a 24 bar dance and named after Sir Walter Scott''s historical novel Kenilworth.  Reconstructed by the RSCDS in 2021 to mark the 250th anniversary of Sir Walter''s birth.  Bars 25-32 have been added for those dancers who prefer 32 bar dances.



', 47, '800/840/880/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20560, '2021-11-21 21:06:21.883228+00', '2021-11-22 18:04:20.269402+00', 'Cailin Rua', 'CAILIN RUA', 3, 32, NULL, 1, 2, 76, 2976, '2002-01-01', 'May be danced in 3 or 4 couple sets.



Cailín Rua (COLL-een ROO-ah) is Irish Gaelic for “red-haired girl” and the name of a song by Cucanandy, which Katherine listened to often around the time she had a flame-point Siamese cat named Fiona, her red-haired girl.



The Giacolettis commissioned the tune (<<ddt:Katydid#14531>>) as a donation to Pinewoods Camp, and the title is a childhood nickname Katherine’s mother often used for her.', 60, '80/88/88/88', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20569, '2021-12-03 21:20:50.306599+00', '2021-12-04 11:12:20.84907+00', 'Laird of Dumbiedike''s Favorite, The', 'LAIRD OF DUMBIEDIKES FAVORITE', 1, 32, NULL, 1, 3, 42, 9998, NULL, 'Originally published in 1820 by John Sutherland, Edinburgh in a booklet linked to Sir Walter Scott''s novel The Heart of Midlothian. The Laird of Dumbiedykes is one of the characters in the novel. This version of the dance was reconstructed by the RSCDS in 2021 to mark the 250th anniversary of Sir Walter Scott''s birth. 



An alternative version was published in RSCDS Book 12 in 1938. <<https://my.strathspey.org/dd/dance/3656/>>', 56, '880/888/880/808', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20491, '2021-09-15 20:12:16.153591+00', '2021-09-16 12:24:33.128309+00', 'On Bennetts'' Brae', 'ON BENNETTS BRAE', 3, 32, NULL, 1, 3, 42, 11356, '2016-01-01', 'Musicians'' note: For variety this tune can easily be transposed into G Major. Just ignore the 2 flats in the key signature and play in C Major but still play all the indicated F sharps.', 44, '880/800/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20486, '2021-09-15 20:01:37.779689+00', '2021-09-16 09:29:02.71195+00', 'View of the Moon, A', 'VIEW OF THE MOON', 2, 32, NULL, 4, 4, 13, 12066, '2016-01-01', 'Musicians'' note: For variety, and to create the effect of orbiting the moon, play as written but change each ‘B’ to ‘B flat’ in bars 1-8 and 17-24 only. ...However, this cheeky title has nothing to do with a lunar eclipse!', 75, '8888/8888/8080/0808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20450, '2021-08-23 23:00:37.049188+00', '2021-09-16 16:28:58.039526+00', 'Minnowburn, The', 'MINNOWBURN', 3, 32, NULL, 1, 4, 1, 12063, '2012-01-01', 'The Minnowburn flows through “an area of scenic beauty” in the leafy fringes of the city of Belfast. The dance represents its journey. Water rises at the source (bars 1-4), flow begins and pebbles are cast aside (5-8), the stream forms (9-16), with swirling eddies (17-20) until it meets a pebbly shoal (21-24), then flow increases (25-28) until stream becomes river (29-32)', 66, '8400/8880/8484/8844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20488, '2021-09-15 20:07:43.314503+00', '2021-09-16 09:30:44.993702+00', 'Gold in My Pocket', 'GOLD IN MY POCKET', 2, 48, NULL, 1, 4, 1, 12067, '2012-05-01', 'Devised by The Gay Gordons at their 4th Annual Dance Week 12th -19th May 2012 at Laurieston Hall, Dumfriesshire, Scotland for tune ‘Gold in My Pocket’ by M. G. Hughes 2012.', 47, '8080/8888/4444/4444/8484/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20543, '2021-11-03 13:52:57.913095+00', '2022-04-22 20:27:02.43654+00', 'Seagulls @ Sawtell, The', 'SEAGULLS  SAWTELL', 1, 32, NULL, 1, 4, 1, 11035, '2021-01-01', 'The dance was originally entered in the database with the name "The Seagulls of Sawtell". However the preferred name is"The Seagulls @ Sawtell" as on the video. The original name is kept as an alias.', 52, '7070/8080/8440/8444', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15222, '2013-10-29 00:10:42.379489+00', '2022-08-14 10:58:33.840433+00', 'Dalston Jig, The', 'DALSTON JIG', 2, 40, 9999, 1, 4, 1, 10889, '2011-01-01', 'The Dalston Jig was devised by Pat Harland for her daughter Jennifer''s 40th birthday and tells the story of a day in Dalston, London.  

1-16: eaving the house, delivering the children to school  

17-24: Negotiating Ridley Road market  

25-32: Going in and out of the shops  

33-36: Everyone at school again, catching up on the news  

37-40: Going home  



*Health warning*: The dance is meant to be relentless, as a reflection of the life of a Mum with young children.', 65, '8080/0808/8888/0008/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14331, '2011-12-08 23:00:00+00', '2022-09-19 06:38:36.176916+00', 'Bill McIver''s Fancy', 'BILL MACIVERS FANCY', 3, 32, 9999, 1, 3, 42, 2701, '2010-05-03', 'This dance was devised for Bill and Carolyn McIver of Reno, Nevada. For several years they have hosted a number of dancers in their home for the annual Truckee, California workshop. They are the consummate hosts and really see to the well-being of each guest. Bill is a gourmet chef; so the vittles are always top-notch. I won''t even touch on his Scotch collection but you can imagine. What is a special pleasure is to see the loving care that Bill and Carolyn show each other in many small ways. It is clear that they still fancy one another quite a bit.', 63, '844/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20402, '2021-07-26 20:10:02.353408+00', '2022-12-04 13:57:32.922612+00', 'Moray Rambler, The', 'MORAY RAMBLER', 1, 32, NULL, 1, 3, 42, 11921, NULL, 'The Moray Rambler was named after one of Bill''s favourite books "The Complete Moray Rambler" by Richard Gordon. "The Moray Rambler" was the title for a series of walks published every week in the P&J and the book is the entire collection.', 63, '844/888/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20489, '2021-09-15 20:09:35.505351+00', '2021-09-18 08:10:59.754706+00', 'Gillie''s Garters', 'GILLIES GARTERS', 3, 32, NULL, 1, 3, 42, 11356, '2019-01-01', 'M G Hughes''s parents named him ‘Gilbert’ after his mother’s father. Over the years many have shortened it to Gil or Gillie. So, this title has nothing to do with the lad who follows the Laird.', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20493, '2021-09-18 07:48:58.095866+00', '2021-09-18 08:11:16.917446+00', 'Cobbler Goes Left, The', 'COBBLER GOES LEFT', 3, 32, NULL, 1, 3, 42, 10612, '2021-01-01', 'By Martin McWilliam for his friend Herbert (Schuster) for his 60th + 1 (Covid year)', 63, '880/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20484, '2021-09-15 19:57:46.565475+00', '2021-09-16 12:20:02.24437+00', 'Further Ado', 'FURTHER ADO', 1, 32, NULL, 1, 3, 42, 11356, '2019-01-01', '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20487, '2021-09-15 20:05:39.869047+00', '2021-09-16 09:22:46.619379+00', 'Branches of the Yew are Evergreen, The', 'BRANCHES OF THE YEW ARE EVERGREEN', 3, 32, NULL, 1, 3, 42, 11356, '2016-01-01', 'Dedicated to all unnamed composers who have become ‘traditional’. Memory fades, but “The Branches of the Yew are Evergreen”.', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14481, '2012-06-15 05:08:32.102967+00', '2021-09-20 22:13:56.108159+00', 'Cherry Blossom Strathspey', 'CHERRY BLOSSOM STRATHSPEY', 3, 40, NULL, 4, 4, 13, 2688, '2008-01-01', 'A gift to Atsuko Clement for organising a superb Cherry Blossom Dancing Tour to Japan in 2008', 94, '6666/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20485, '2021-09-15 19:59:26.241529+00', '2021-09-16 09:23:41.616452+00', 'Arthur Govan''s Here', 'ARTHUR GOVANS HERE', 3, 32, NULL, 1, 3, 42, 12063, '2019-01-01', 'Arthur, piper of London, precedes the haggis and brings the whisky! The first two bars fanfare his arrival. As 1st Man then 1st Woman turn diagonal partners, the music asks “have you seen him, have you seen him?” When 1st couple progress down the centre of the set, we know Arthur Govan’s here. The swirl of the poussette represents the skirl of the pipes.', 38, '660/660/800/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20490, '2021-09-15 20:10:59.422438+00', '2021-09-16 12:23:02.859749+00', 'Bird in the Hand', 'BIRD IN THE HAND', 1, 32, NULL, 2, 3, 17, 11356, '2016-01-01', '', 69, '800/888/808/828', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19034, '2018-10-24 19:05:56.417006+00', '2021-09-23 20:37:28.047063+00', 'Pilot''s Delight', 'PILOTS DELIGHT', 1, 32, NULL, 1, 3, 42, 2701, '2017-05-27', 'The dance and tune are the result of Pat Gregory’s successful bid at the 2016 Asilomar Weekend Auction. In addition to Scottish Country dancing, Pat’s an active member of the Ninety-Nines, an international organization of women pilots.', 40, '800/822/844/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20494, '2021-09-23 10:37:17.838851+00', '2021-09-23 22:36:05.018414+00', 'One Year On', 'ONE YEAR ON', 1, 32, NULL, 1, 3, 42, 316, '2019-01-01', 'Dedicated to Ramona and Matthias on their first wedding anniversary.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20495, '2021-09-23 17:05:27.425459+00', '2021-09-24 09:25:13.347596+00', 'Leather Band, The', 'LEATHER BAND', 2, 32, NULL, 1, 100, 11, 10648, '2020-01-01', 'Dedicated to Marian Anderson and Max Ketchin after the deviser heard of their touring in motorbike leathers.', 75, '8888/8008/8008/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6718, '1997-09-16 22:00:00+00', '2021-11-11 15:29:09.863033+00', 'Trip to Expo, A', 'TRIP TO EXPO', 1, 32, 9999, 1, 3, 42, 562, NULL, '', 63, '888/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20515, '2021-10-11 22:24:36.121371+00', '2021-11-22 01:05:15.53958+00', 'Pacemaker Dance, The', 'PACEMAKER DANCE', 3, 32, NULL, 1, 100, 102, 10387, '2020-01-01', 'The dance is dedicated to the N.H.S for their devoted work during Covid-19 and to Moira Fletcher a founder

member of the Belfast Branch as she celebrated her 90th birthday. Moira, Ruth, Jenny, Tom and myself

have all benefited from the wonderful invention of the pacemaker, and the professional skills of the NHS.', 75, '0880/8888/8888/2662', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20559, '2021-11-17 08:38:13.343137+00', '2021-11-22 13:14:36.392623+00', 'Dancing in 3D', 'DANCING IN 3D', 2, 32, NULL, 2, 3, 18, 10568, '2021-01-01', 'This dance was written for Peter Price and Deborah Leary as one of the winners of the TAC silent auction to have a dance written in their honour. Deborah says that It was so nice when they started seeing their dancing friends again in 3D instead of 2D on a zoom screen. ', 90, '888/824/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20317, '2021-04-14 10:47:14.754857+00', '2021-11-24 12:39:25.766508+00', 'Christaline', 'CHRISTALINE', 3, 32, NULL, 1, 3, 42, 11350, '2018-07-01', 'This dance is dedicated to Pascaline Latour and Christophe Schuwey, and was devised for the opening of their wedding ceremony. They executed the dance for their friends and family, right after their appearance on the great stairs. We are very grateful to both of them for their many contributions to the Paris Branch, and wish them every happiness in their future together!', 59, '866/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20561, '2021-11-21 21:53:13.562904+00', '2021-11-27 16:56:55.425936+00', 'St Mark''s Strathspey', 'SAINT MARKS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 616, '2020-10-01', 'Devised during  Covid-19. The dance name was chosen from a list of ten entries of which this name was suggested by Jamie Wilson and Evelyn Norman.', 50, '822/888/844/822', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5824, '2001-11-20 23:00:00+00', '2021-09-25 09:16:01.595055+00', 'Saint Ebba''s Strand', 'SAINT EBBAS STRAND', 1, 40, 9999, 1, 4, 2, 1235, '1981-01-01', 'Devised to honour Miss M.A. Rae on becoming Hon President of the Duns & District Branch.



From the notes: The advance and retire represents the ebb and flow of the tide and the circular movements represent the seagulls wheeling round the rocks. The crosses (the wheels) represent St. Ebba and the Christian communities of the district. Each figure should flow into the next representing continuity of life from generation to generation and from century to century.', 80, '8888  8888  8888  8008  8008', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (20841, '2022-05-15 20:27:00.35839+00', '2022-05-15 20:27:00.35839+00', 'Dervaig House', 'DERVAIG HOUSE', 3, 32, NULL, 2, 2, 76, 99, '1988-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20927, '2022-06-29 16:52:31.56302+00', '2022-06-29 17:50:43.164031+00', 'Trotter at Play', 'TROTTER AT PLAY', 2, 32, NULL, 1, 3, 42, 2766, '2022-03-01', 'We have 4 cats. Three are elderly (age 14+) and one is just turning 6. He is very active and loves to play. This dance tries to capture some of the joy of him at play.', 44, '844/844/800/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20562, '2021-11-21 22:35:07.328483+00', '2022-11-29 22:05:41.583138+00', 'Chase, Pursued by a Bear', 'CHASE PURSUED BY A BEAR', 2, 32, NULL, 4, 4, 13, 11237, '2018-04-01', 'Originally devised in 2018 but only finalised in autumn 2021.', 88, '8080/8888/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16845, '2016-01-18 14:33:33.306542+00', '2021-09-26 11:08:34.636879+00', 'Dancing in Kirkcudbright', 'DANCING IN KIRKCUDBRIGHT', 3, 32, 9999, 1, 4, 1, 11035, NULL, 'On bars 27 & 28 second and third couples need to make sure they are covering as they curve into place, to give this phrase a tidy finish as the first couple simply cast off into third place.  



This dance could also be done in a three couple set. With only one change the ending would now be:  

Bars 28-32 the first couple turn both hands 1½ times to finish in third place on own sides.  



My thanks to Lesley Campbell for her suggestion that third couple cast to enter the reel across (bars 9-16). The formation really does work much better this way.  



In 2013 Damon and I danced in Scotland for the first time. Our English base was in The Lake District where we stayed for a week in Chapel Stile.  

From there we drove to Kirkcudbright to dance on the last night of their season.  



We arrived late afternoon in this pretty, seaside spot and were welcomed by the gathering dancers and spent a very enjoyable evening in warm and pleasant dancing conditions.  



Later in the evening I exchanged our email address with Evelyn Thomas who was coming to NZ in 2014. We met up again then and danced together and shared a meal with both Evelyn & her husband, Ian.

This dance was devised in memory of a very pleasant night in Kirkcudbright dancing with Evelyn and other dancers from that area.', 59, '8800/8880/8080/8444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20496, '2021-09-27 17:14:09.551464+00', '2021-09-27 17:25:04.225839+00', 'Thistle in the Park', 'THISTLE IN THE PARK', 3, 32, NULL, 1, 100, 2, 12068, NULL, 'Source: <<https://youtu.be/hv_YZtDSEc4|youtube video>> from 2018.', 62, '0880/8448/8008/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10261, '2001-11-25 23:00:00+00', '2021-09-27 23:10:20.555473+00', 'Betsy Ross', 'BETSY ROSS', 2, 32, 9999, 1, 3, 42, 2766, '2001-07-01', 'This dance honors Miss Betsy Ross, who sewed the original *Stars and Stripes*, with thirteen stars in a circle on a blue field and thirteen red and white stripes.', 47, '800/822/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4837, '2002-02-28 23:00:00+00', '2021-09-29 08:50:56.910243+00', 'Murray, The Outlaw Of Falahill', 'MURRAY THE OUTLAW OF FALAHILL', 1, 32, 9999, 1, 3, 42, 406, '1993-01-01', 'According to the dance notes "Murray, The Outlaw Of Falahill" was the official name of US President Franklin Delano Roosevelt''s dog Fala. Fala was named after one of the president''s ancestors, John Murray who was the outlaw celebrated in the ballad "The Song of Outlaw Murray".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10056, '2001-09-03 22:00:00+00', '2021-10-02 22:18:55.142476+00', 'Celia''s Jig', 'CELIAS JIG', 2, 32, 9999, 1, 3, 42, 2932, '2000-01-01', 'Devised by Ellen Ternes in honor of Celia Kirby, a dear friend and an indispensable member of the Frederick Scottish Country Dancers, October, 2000', 44, '822/800/844/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2093, '1998-04-11 22:00:00+00', '2021-10-02 14:42:25.338154+00', 'Farewell To Paternoster Square', 'FAREWELL TO PATERNOSTER SQUARE', 4, 72, 39, 4, 4, NULL, 68, '1991-08-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20498, '2021-10-02 19:33:52.482313+00', '2021-10-02 20:23:22.382596+00', 'Cobey''s Barn', 'COBEYS BARN', 1, 32, NULL, 1, 3, 42, 2932, '2021-01-01', 'Devised in memory of Cobey England, 1993-2020 of Maryland USA, a wonderful young man who brought joy and laughter to Scottish Country dancing and exquisite excellence to competitive ballroom. Cobey had plans to build a dance barn on family farm. He never got to do that, but there’s no doubt he’s working on it in heaven.', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12779, '2006-06-14 22:00:00+00', '2021-10-03 23:16:38.154521+00', 'Greenbelt Gallop, The', 'GREENBELT GALLOP', 1, 32, 9999, 1, 3, 42, 3686, '2005-01-01', '', 53, '800/844/866/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13759, '2011-07-12 22:00:00+00', '2021-10-04 07:31:23.912118+00', 'Pillar Dance, The', 'PILLAR DANCE', 2, 40, NULL, 4, 4, 4, 2973, '2010-05-01', 'Devised in May 2010. 



The New York Branch meets in the main hall of Holy Cross School on 43rd Street in Manhattan. This hall has several pillars which are incorporated in this dance. In the event that a group has the "misfortune" to dance in a hall without pillars, it may substitute hands across for the movements around the pillars



Music  Any good jig. A suitable recording is "Let‘s Celebrate, We Twa", Kenny Thomson

and the Wardlaw Scottish Dance Band, track 16.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20499, '2021-10-04 22:54:31.343367+00', '2021-10-05 15:58:14.449154+00', 'Bemis Up, Scotty', 'BEMIS UP SCOTTY', 1, 32, NULL, 1, 3, 42, 2932, '2020-01-01', 'Devised in honor of Barb and Sam Bemis, to thank them for their great tech work, patience and fun in keeping us connected to the dancing we love. They have been Stars in our Trek through corona dancing.', 41, '800/888/800/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20500, '2021-10-05 22:10:42.511204+00', '2021-10-05 22:18:30.877979+00', 'Joy', 'JOY', 1, 32, NULL, 1, 2, 76, 12072, '1984-01-01', 'Adapted to Scottish from a contra dance by Lannie McQuaide (duple minor contra) found in 500 Zesty Contras, published 1984.', 60, '84/88/88/84', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20501, '2021-10-06 13:19:08.893824+00', '2021-10-06 21:08:09.519065+00', 'No Hands Please!', 'NO HANDS PLEASE', 1, 32, NULL, 1, 3, 42, 11166, '2021-01-01', '', 44, '800/880/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20502, '2021-10-06 15:44:55.652653+00', '2021-10-06 15:50:21.427916+00', 'Leap Year Fair', 'LEAP YEAR FAIR', 2, 32, NULL, 1, 2, 76, 2408, NULL, 'Combination of Leap Year and The Highland Fair devised for teaching purposes', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20503, '2021-10-09 08:36:39.370706+00', '2021-10-09 08:36:39.370706+00', 'Down Under', 'DOWN UNDER', 2, 32, NULL, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20504, '2021-10-09 08:38:01.151903+00', '2021-10-09 08:38:01.151903+00', 'McLeod''s Landing', 'MACLEODS LANDING', 1, 32, NULL, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20505, '2021-10-09 08:41:09.288314+00', '2021-10-09 08:41:09.288314+00', 'Old Woman, The', 'OLD WOMAN', 1, 40, NULL, 1, 3, 42, 352, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20497, '2021-10-02 04:06:23.025453+00', '2021-10-14 09:20:58.564903+00', 'Bypass, The', 'BYPASS', 1, 32, NULL, 1, 3, 42, 12071, '2005-05-01', 'Written for Alan Nicolle, who came through his quadruple heart bypass with flying colours in May 2005.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20520, '2021-10-12 15:32:54.91573+00', '2021-10-19 13:43:39.708072+00', 'Now Wash Your Hands', 'NOW WASH YOUR HANDS', 1, 80, NULL, 4, 4, 3, 575, '2020-01-01', '', 85, '6666/8888/8888/4444/8888/6666/8888/8888/4444/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20598, '2022-01-07 18:07:14.960419+00', '2022-01-07 18:07:14.960419+00', 'Choice of the Day, The', 'CHOICE OF THE DAY', 3, 32, NULL, 1, 4, 11, 11514, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5574, '1999-08-09 22:00:00+00', '2022-01-30 18:04:32.76048+00', 'Rifleman, The', 'RIFLEMAN', 1, 32, 9999, 1, 2, 76, 9998, NULL, '<<scddb-not-identical:5575>>

', 52, '80/88/88/80', 1, 1, 0, 0, 50);
INSERT INTO 'dance' VALUES (20829, '2022-05-14 19:02:30.31773+00', '2022-05-14 19:02:30.31773+00', 'Merrick Rant, The', 'MERRICK RANT', 1, 40, NULL, 1, 3, 42, 99, '2004-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20821, '2022-05-14 18:07:54.74226+00', '2022-05-15 10:13:45.057518+00', 'Sheila Gardiner''s Strathspey', 'SHEILA GARDINERS STRATHSPEY', 3, 32, NULL, 1, 4, 2, 99, '2091-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20842, '2022-05-15 20:35:34.005186+00', '2022-05-15 20:35:34.005186+00', 'Wig-Maker''s Son, The', 'WIGMAKERS SON', 2, 32, NULL, 1, 3, 42, 99, '1988-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14675, '2013-01-22 00:04:32.375927+00', '2022-06-23 22:51:18.799972+00', 'Missouri White Rabbit', 'MISSOURI WHITE RABBIT', 1, 32, NULL, 1, 2, 76, 9998, NULL, 'Dance adapted from Iain Boyd.', 52, '44  88  44  88', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (20786, '2022-04-27 21:45:25.206409+00', '2022-06-28 19:56:34.974393+00', 'Iguazú Falls, The', 'IGUAZU FALLS', 1, 32, NULL, 1, 3, 42, 2101, '2020-03-01', 'The whole entry still needs to be checked.  

The diagram is in error; it probably comes from another dance.', 61, '882/888/888/444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20926, '2022-06-29 15:19:46.705904+00', '2022-06-29 15:23:36.908092+00', 'Circle of Life', 'CIRCLE OF LIFE', 3, 32, NULL, 1, 3, 42, 2766, '2022-05-01', 'I''ve known of several friends and family members losing loved ones during the last couple of years, but also friends having babies and it reminded me that life is a circle.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11839, '2004-10-31 23:00:00+00', '2022-07-01 13:11:06.006758+00', 'Dragon''s Wing', 'DRAGONS WING', 2, 32, 9999, 1, 3, 42, 2961, NULL, 'Devised: 2004', 50, '800/866/822/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6679, '1998-04-19 22:00:00+00', '2022-07-03 13:04:07.625444+00', 'Travellers'' Jig, The', 'TRAVELLERS JIG', 2, 32, 9999, 1, 3, 42, 62, '1978-01-01', '', 75, '800/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12863, '2006-09-12 22:00:00+00', '2022-09-19 09:41:30.288429+00', 'To Catch a Weasel', 'TO CATCH A WEASEL', 2, 32, 9999, 1, 3, 42, 2961, '2005-01-01', '', 44, '800/844/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20526, '2021-10-21 18:07:27.322403+00', '2021-10-22 09:54:03.684574+00', 'Ô Mon Beau Cularo', 'O MON BEAU CULARO', 1, 32, NULL, 1, 3, 42, 11354, '2018-06-01', 'Cularo was the first name given to the city of Grenoble on June 6th 43 B.C. It then changed to Gratianopolis in year 379 and slowly transitioned to the current name.', 67, '833/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20524, '2021-10-21 18:03:36.027315+00', '2021-10-22 09:45:39.276243+00', 'Chardon du Dauphiné, Le', 'CHARDON DU DAUPHINE', 3, 32, NULL, 1, 4, 1, 11354, '2018-06-01', '', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20527, '2021-10-21 18:08:52.818019+00', '2021-10-22 09:56:57.767815+00', 'Dancing Together Again', 'DANCING TOGETHER AGAIN', 1, 32, NULL, 1, 3, 42, 11509, '2018-10-01', 'The name of the dance refers to how much I enjoy meeting and dancing again with the members of our group in Grenoble after a break like a holiday. It was written before the pandemic period, but will probably be quite appropriate when we resume dancing after the endless months of lockdown.', 56, '822/8848/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20523, '2021-10-21 18:01:42.682073+00', '2021-10-22 09:40:56.529902+00', 'BellCorEuse', 'BELLCOREUSE', 2, 32, NULL, 1, 3, 42, 11354, '2018-06-01', 'Belledonne, Vercors and Chartreuse are the three mountains ranges (or Massifs) surrounding Grenoble, making the valley look like a Y (Le Y Grenoblois).', 63, '888/844/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20528, '2021-10-21 18:12:52.823928+00', '2021-10-22 09:59:51.334343+00', 'Year with Harry Potter, A', 'YEAR WITH HARRY POTTER', 4, 64, 5, 2, 2, 76, 11509, '2018-10-01', 'My husband, our two children and I spent a great amount of delicious hours reading or listening to the whole story of Harry Potter together. It lasted about a year.  

If someone is inspired to devise a set of music for this dance including Slytherin House and Tam Lin, it would just be wonderful!', 63, '84/88/88/88/84/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20529, '2021-10-21 18:14:25.834595+00', '2021-10-22 10:07:29.152536+00', 'My Joyful Dancer', 'MY JOYFUL DANCER', 2, 32, NULL, 1, 3, 42, 11509, '2018-10-01', 'For my daughter, who loves dancing, different types of dances, among which Scottish country dances.', 54, '844/555/888/606', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20530, '2021-10-21 18:17:34.113457+00', '2021-10-22 10:13:45.531083+00', 'My Great Builder', 'MY GREAT BUILDER', 3, 32, NULL, 1, 3, 42, 11509, '2019-03-01', 'For my son, who loves building, and keeps building all over the place, at anytime with whatever is available (legos, kaplas, paper and adhesive tape, snow, sand, sticks, stones etc.). For example, we once had a cable car all made with paper and adhesive tape dividing half of our living room in two parts, when he was six.  

Sometimes, he puts things together in a different way, you would say it’s not going to work, but in the end, it does work. This inspired me for the formation “modified crown triangles”.', 59, '800/866/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20534, '2021-10-21 18:30:41.945681+00', '2021-10-23 01:08:32.472038+00', 'Reel of Three for Free', 'REEL OF THREE FOR FREE', 1, 48, NULL, 2, 3, 17, 12079, '2021-08-01', 'This dance was devised to work on the spatial geometry of the reel of three. It was written as a reel R6x48, but it can also be danced as a strathspey S3x48.', 67, '800/888/800/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20536, '2021-10-21 18:33:53.238268+00', '2021-10-22 10:38:04.901005+00', 'Capharnaüm à Grenoble', 'CAPHARNAUM A GRENOBLE', 1, 40, NULL, 1, 3, NULL, 12079, '2021-08-01', 'If you have six very energetic dancers, it is possible to dance it as a reel R6x40, 3C/3.', 75, '888/888/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20525, '2021-10-21 18:05:37.068661+00', '2021-10-29 14:00:52.814267+00', 'Pont sur l''Isère, Le', 'PONT SUR LISERE', 1, 32, NULL, 2, 3, 46, 11354, '2018-06-01', '', 50, '844/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20556, '2021-11-14 20:48:33.638919+00', '2021-11-14 21:33:18.337825+00', 'Frank Bennett''s Jig', 'FRANK BENNETTS JIG', 2, 32, NULL, 1, 3, 42, 3414, '2021-10-10', '', 50, '800/880/808/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20557, '2021-11-15 14:17:13.100186+00', '2021-11-15 14:18:18.07429+00', 'Miss Avery Rose', 'MISS AVERY ROSE', 2, 32, NULL, 2, 3, 17, 10648, '2018-01-01', 'Miss Avery Rose is devisers young granddaughter, who is very bouncy & full of energy, hence a jig with lots of pas de basque.', 66, '866/888/888/808', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20558, '2021-11-15 14:52:19.390559+00', '2021-11-15 14:52:19.390559+00', 'Scarecrow Jig, The', 'SCARECROW JIG', 2, 32, NULL, 1, 3, 42, 10568, '2021-01-01', '', 56, '804/840/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16729, '2015-09-03 21:02:07.845135+00', '2021-11-18 06:15:32.123454+00', 'Toast to Aberdeen, A', 'TOAST TO ABERDEEN', 3, 32, NULL, 2, 3, 17, 11195, '2014-01-01', '', 83, '880/888/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20545, '2021-11-05 19:18:43.550512+00', '2021-11-05 19:25:46.616165+00', 'Best Set Squared', 'BEST SET SQUARED', 2, 64, NULL, 4, 4, NULL, 11932, '2020-05-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20537, '2021-10-28 15:29:36.197127+00', '2021-10-29 17:18:22.888334+00', 'Amateur Epidemiologist, The', 'AMATEUR EPIDEMIOLOGIST', 1, 32, NULL, 1, 3, 42, 12080, NULL, 'During the 2020 COVID-19 lock-down period, the whole nation became amateur epidemiologists  and knowledgeably discussed weighty matters such as community transmission, flattening the curve  and social distancing. The daily one o’clock briefings from the Prime Minister and Director General  of Health became a daily fixture in many households as we eagerly awaited news about the number  of new cases and whether we were flattening the curve. 



The dance depicts some of the changes to our daily routines such acknowledging friends from afar  on our daily walks, swerving off the footpath to keep two meters from other walkers and queuing  for groceries. Finally lockdown ends and we are all able to mix again. 



Devised by Andrew Oliver during the 2020 COVID-19 lock-down.  

Recommended music: The Magic of Merrill (The Reel of Seven)  



Above dance information supplied by the deviser, Andrew Oliver.  



''The Amateur Epidemiologist'' was chosen for a book of dances published to commemorate the Wellington Region’s 60th Anniversary. The Region forms part of the New Zealand Branch of the RSCDS.  



The video was taken at the Linden SCD''s annual dance earlier this year. Andrew is dancing as first man.  



Live music was by the Saltire Band: Jason Morris, Mary McDonald, Ann Goodbehere and Duncan McDonald.', 44, '800/844/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20539, '2021-11-03 13:02:00.846248+00', '2021-11-03 13:02:00.846248+00', 'Baby Boomer''s Nest', 'BABY BOOMERS NEST', 3, 32, NULL, 1, 4, 1, 11035, '2021-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20540, '2021-11-03 13:06:24.254532+00', '2021-11-03 13:06:24.254532+00', 'Drop Your Pants Here', 'DROP YOUR PANTS HERE', 1, 32, NULL, 1, 3, 42, 11035, '2021-01-01', '', 56, '800/844/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3036, '1997-09-04 22:00:00+00', '2021-11-03 13:43:30.967458+00', 'Hurrier You Go the Behinder You Get, The', 'HURRIER YOU GO THE BEHINDER YOU GET', 2, 32, 9999, 1, 4, 1, 108, '1977-01-01', '"For Frances Gray of Toronto and her helpers, who published a book of my dances in Canada."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20542, '2021-11-03 13:48:18.310302+00', '2022-05-16 22:34:09.802199+00', 'Momentum', 'MOMENTUM', 1, 32, NULL, 1, 3, 42, 11035, '2021-01-01', '', 53, '840/844/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20533, '2021-10-21 18:28:26.336532+00', '2022-12-04 17:35:00.176469+00', 'Half Right & Half Left', 'HALF RIGHT AND HALF LEFT', 1, 32, NULL, 2, 3, 17, 12079, '2021-08-01', 'This dance for three couples was inspired by “It’s All Right”.', 67, '888/800/888/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20532, '2021-10-21 18:22:08.048532+00', '2022-07-13 20:22:09.955625+00', 'Beginning of the Year', 'BEGINNING OF THE YEAR', 2, 32, NULL, 1, 3, 42, 11509, '2019-09-01', 'This dance was devised for the first class of the year.', 50, '800/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8864, '2002-11-12 23:00:00+00', '2022-12-19 14:34:44.783956+00', 'Ian Gaylor''s Entrance to Matrimony', 'IAN GAYLORS ENTRANCE TO MATRIMONY', 1, 32, 9999, 4, 4, 14, 2488, '1998-01-01', 'Written in 1998 by Todd McCall to commemorate the marriage of Madison, Wisconsin, dancers Ian Gaylor and Nancy McClements.



According to <<https://my.strathspey.org/dd/issue/2641/|issue 2641>> the tune was written by Mike Briggs for the dance''s premier in Madison.', 81, '8000/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20535, '2021-10-21 18:32:00.780492+00', '2023-01-10 19:03:22.565167+00', 'Day with Dance, A', 'DAY WITH DANCE', 3, 48, NULL, 2, 3, 17, 12079, '2021-08-01', '', 56, '800/844/844/844/844/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6514, '1997-09-14 22:00:00+00', '2021-11-03 18:43:03.794679+00', 'Thanksgiving Reel', 'THANKSGIVING REEL', 2, 48, 9999, 1, 3, 42, 1298, NULL, 'In the online publication (<<http://www.dancescottish.ca/books_files/Centennial%20Collection.pdf>>) this danced is unnamed and just referred to as "Jig (Lively)". It is not clear how the name "Thanksgiving Reel" was assigned to the dance in SCDDB. As MiniCrib use "Jig (Lively)" that is now added as an alias.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20538, '2021-11-03 10:50:40.695996+00', '2021-11-04 10:42:39.879378+00', 'London Bridge', 'LONDON BRIDGE', 3, 32, NULL, 2, 2, 76, 2973, '2012-10-01', 'This dance was devised for teaching the Rondel. The old London Bridge had many arches, so London Bridge seemed a good title for the dance.

Devised in October 2012, revised in January 2021.

May be danced in 3 or 4 couple sets.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19665, '2019-09-24 18:16:32.190878+00', '2021-11-04 22:13:35.769119+00', 'Gravitational Waves', 'GRAVITATIONAL WAVES', 1, 32, NULL, 1, 3, 42, 11237, '2019-08-01', 'The dance celebrates the first detection by the <<https://en.wikipedia.org/wiki/LIGO|LIGO detector>> of gravitational waves produced by two black holes circling and merging together over a billion light years from Earth. This event was observed on 14 September 2015 almost exactly a century after the existence of gravitational waves was predicted by Einstein in his General Theory of Relativity.



Bars 5-12 represent the LIGO detector which has two 4 km long arms arranged in an L shape. Bars 13-16 show the circling and merging black holes. The wiggly reels are the resulting gravitational waves and the final circle is for the <<https://www.nobelprize.org/uploads/2018/06/press-40.pdf|Nobel Prize>> medallions awarded by the Swedish Academy in recognition of this amazing scientific achievement.



A recording by Ian Robertson of the music for this dance is available via <<https://my.strathspey.org/u/murrough/recording/>>.

', 53, '842/824/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20544, '2021-11-05 19:14:36.208399+00', '2021-11-05 19:14:36.208399+00', 'Jewellery Shop, The', 'JEWELLERY SHOP', 3, 32, NULL, 1, 2, 76, 1313, '2021-01-01', 'The set should have dancers 2m apart both across and on the sides. Suggested as a strathspey but may be danced in reel time. The choreography has "lots of diamonds!"', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20546, '2021-11-05 20:01:06.318578+00', '2021-11-05 20:01:06.318578+00', 'Bursting the Bubble', 'BURSTING THE BUBBLE', 2, 96, NULL, 4, 4, 3, 12082, '2020-04-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20548, '2021-11-05 20:19:54.250315+00', '2021-11-05 20:20:40.250275+00', 'Covid - NZ Story', 'COVID  NZ STORY', 3, 32, NULL, 1, 4, 1, 12050, '2020-05-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20549, '2021-11-05 20:24:21.659088+00', '2021-11-05 20:28:27.385267+00', 'Masks and Faces', 'MASKS AND FACES', 3, 32, NULL, 2, 3, 17, 11155, '2020-08-01', 'Devised during the Covid 19 epidemic based on ideas from the dances “<<ddd:Parting Kiss, The>>” in Iain Boyd’s book “May I have the Pleasure” and John Gregory’s dance “<<ddd:After Supper Sweeper, The>>”.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20550, '2021-11-05 20:32:12.009468+00', '2021-11-05 20:32:12.009468+00', 'Play It Safe', 'PLAY IT SAFE', 2, 32, NULL, 2, 3, 17, 11226, '2020-01-01', 'To comply with social distancing, all dancers should be 1 metre away from other dancers at all times and no hands given at any time.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20551, '2021-11-05 20:39:21.444537+00', '2021-11-05 20:39:21.444537+00', 'Slow Down and Distance', 'SLOW DOWN AND DISTANCE', 4, 64, 22, 1, 4, NULL, 12084, '2020-07-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18671, '2018-10-01 10:18:33.120543+00', '2021-11-09 10:52:55.674534+00', '20 Years at Fermi', '20 YEARS AT FERMI', 2, 32, NULL, 1, 3, 42, 2766, '2014-10-01', 'This dance celebrates 20 years of dancing at Fermilab.', 54, '800/880/808/822', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13892, '2011-08-22 22:00:00+00', '2021-11-09 13:17:42.060972+00', 'St Chad''s Strathspey', 'SAINT CHADS STRATHSPEY', 3, 32, NULL, 2, 3, 18, 2788, '1999-04-01', '"This dance was written for Alison Murdoch and Chris Hiller, stalwart members of the demonstration team of the Newcastle and District Branch of the RSCDS, on the occasion of their wedding at Easter 1999."', 94, '882/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20555, '2021-11-14 11:07:28.241629+00', '2021-11-14 11:07:28.241629+00', 'Kissed by Nessie', 'KISSED BY NESSIE', 1, 32, NULL, 1, 3, 42, 3645, '2021-11-04', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14430, '2012-05-08 21:23:53.640766+00', '2021-11-25 17:54:25.780636+00', 'Lena''s Kitchen', 'LENAS KITCHEN', 1, 32, NULL, 1, 3, 42, 3580, '2007-11-01', 'For Lena Robinson, who is renowned for her tireless  work and activities in the kitchen at St. Columba''s Church, Pont Street, London



Description:



1-8	  1st couple petronella turn and set. Then turn right hands once and a half to finish with 1st lady facing down with 1st man behind her, also facing down.  Meanwhile the 2nd and 3rd couples dance four hands round to the left and back again.  (1234)



9-16	  With 1st lady leading, the 1st couple dance a tandem reel of three with second couple, giving right shoulders to 2nd man to start, and changing order as they change direction (ie Dolphin Reels across the dance).  1st couple finish in 2nd place opposite sides in the middle.  2nd couple finish in 1st place on own sides.  (2134)



17-24	  1st couple, with nearer hands joined, dance down between 3rd couple and cast up to second place opposite sides.  2nd, 1st and 3rd couples advance and retire. (2134)



25-32	  1st man with second couple and 1st lady with third couple dance right hands across. 1st couple turn left hands once and a half to own sides. (2134)



Suggested CD:	Scottish Dances Vol. 8 - D. Anderson  No. 7 - Chevy Chase



', 56, '888/880/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20564, '2021-11-28 09:30:19.277553+00', '2021-11-29 00:32:38.48545+00', 'Stuart''s Strathspey', 'STUARTS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10623, '2021-03-01', 'Devised in memory of Berkhamsted Strathspey and Reel Club member Stuart Anderson.', 50, '880/800/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20599, '2022-01-07 18:09:51.58633+00', '2022-01-07 18:09:51.58633+00', 'Some Scotch Flair', 'SOME SCOTCH FLAIR', 2, 32, NULL, 1, 4, 2, 11514, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15634, '2014-09-29 13:19:39.819363+00', '2022-01-08 17:53:43.143152+00', 'Sour Lemon, The', 'SOUR LEMON', 2, 40, NULL, 1, 3, 42, 11007, '2001-03-01', 'Devised by John & Hilary Ashby, also original members of Bridport Scottish Country Dancers, in March 2001. This jig was written for all those who forget to smile when dancing!', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20552, '2021-11-05 20:42:34.774052+00', '2022-01-08 08:59:57.239273+00', 'Covid-19 Jig, The', 'COVID19 JIG', 2, 32, NULL, 2, 3, 17, 11356, '2020-03-01', '', 67, '800/888/800/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20605, '2022-01-08 11:53:01.617659+00', '2022-01-08 17:01:08.222809+00', 'Queensland Breeze, The', 'QUEENSLAND BREEZE', 3, 32, NULL, 1, 3, 42, 11527, '2021-01-01', 'The Quick Scotch video is titled "The Queensland Breese" but the deviser says it should be "Breeze".', 47, '770/832/856/833', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20606, '2022-01-09 18:21:46.152944+00', '2022-01-09 18:21:46.152944+00', 'Two Rebeccas, The', 'TWO REBECCAS', 2, 32, NULL, 2, 3, 17, 10568, '2015-08-01', '"This is dedicated to Rebecca Blackhall-Peters, a wonderful teacher, and Rebecca Allison, a brand new dancer and terrific massage therapist. They both gave me what I needed at TAC in Virginia."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20607, '2022-01-09 18:27:31.660963+00', '2022-01-09 18:27:31.660963+00', 'Wedding at Fingask Castle', 'WEDDING AT FINGASK CASTLE', 1, 32, NULL, 7, 113, 4, 10568, '2015-08-01', '"This dance is written for James Moxley and Katherine Robinson to celebrate their marriage September 6, 2015 at Fingask Castle in Scotland"', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20554, '2021-11-11 09:53:39.36839+00', '2022-10-01 18:05:30.877769+00', 'Purple Rain', 'PURPLE RAIN', 2, 32, NULL, 2, 3, 17, 10568, '2021-10-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20547, '2021-11-05 20:15:22.328304+00', '2022-06-23 22:02:37.905253+00', 'Counting Teddy Bears', 'COUNTING TEDDY BEARS', 2, 32, NULL, 2, 3, 17, 12083, '2020-04-01', 'During the Lockdown, many people put Teddy Bears in their windows, for the amusement of youngsters and oldies, alike, who were encouraged to see how many they could find during their daily walks.', 56, '800/800/844/868', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (627, '1998-01-05 23:00:00+00', '2021-12-02 23:44:09.712018+00', 'Bon Accord', 'BON ACCORD', 1, 40, 9999, 1, 3, 42, 108, '1964-01-01', 'Drewry''s own notes:



During bars 1-28, 1st Lady dances similar figures to those danced by her partner but four bars later.



Miss Allie Anderson, of Edinburgh, prefers 1st couple to omit the setting, and turn by the right hands for four steps during bars 29-32.  I have left the dance in the original version because the setting marks the end of the part where 1st lady is imitating her partner, after a four-bar interval, and because the setting gives the 1st couple a chance to orientate themselves before plunging into the last eight bars.  Miss Anderson''s version is however a pleasant optional variation.



This dance was written for Miss Margaret Brander and the  members of the Carlisle and Border Branch Advanced Class.  Miss Brander chose the title - the motto of Aberdeen - her native city.  That was before I knew that I was coming to live in Abderdeen myself.



Tune: Bon Accord by Winifred M. Carrie (1st ans 2nd tunes; see the music sheets for this book).  It is essential to use the correct tunes for this dance because the first 24 bars consist of two 12-bar phrases rather than three 8-bar ones.



SCDDB Editor''s Note on [39-40]   

In the first original text by Drewry (typed and then stenciled) 1c crosses RH on [39-40].  In the later printed versions (Bon Accord Book, and the later TAC reprint) 1c cross LH on [39-40].  It is not clear if Drewry changed his mind, or if this was an overlooked editing error.  Crossing LH is now the official version, even if some consider Drewry''s original RH choice to flow better. ', 49, '680/844/808/800/888', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (20567, '2021-12-03 20:10:25.369993+00', '2021-12-03 23:28:44.287533+00', 'Jeanie Dean''s Strathspey', 'JEANIE DEANS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 9998, NULL, 'Originally published in 1820 by John Sutherland, Edinburgh in a booklet linked to Sir Walter Scott''s novel The Heart of Midlothian. Jeanie Deans was the heroine of the novel.  This dance was reconstructed by the RSCDS in 2021 to mark the 250th anniversary of Sir Walter Scott''s birth.', 41, '800/888/822/800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20568, '2021-12-03 20:59:23.214297+00', '2021-12-03 23:45:49.631482+00', 'Reuben Butler', 'REUBEN BUTLER', 2, 32, NULL, 1, 3, 42, 9998, NULL, 'Originally published in 1820 by John Sutherland, Edinburgh in a booklet linked to Sir Walter Scott''s novel The Heart of Midlothian in which Reuben Butler is one of the lead characters. This dance was reconstructed by the RSCDS in 2021 to mark the 250th anniversary of Sir Walter Scott''s birth.', 41, '800/840/880/808', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20573, '2021-12-03 22:54:31.38918+00', '2021-12-04 12:16:21.096611+00', 'Pirate, The', 'PIRATE', 1, 32, NULL, 1, 3, 42, 9998, NULL, 'Originally published in 1822 by Nathaniel Gow as a 24 bar dance and named after Sir Walter Scott''s romantic novel The Pirate.  Reconstructed by the RSCDS in 2021 to mark the 250th anniversary of Sir Walter''s birth.  Bars 25-32 have been added for those dancers who prefer 32 bar dances.', 44, '440/440/880/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5853, '2003-04-15 22:00:00+00', '2021-12-04 18:09:55.483595+00', 'Pat Clark''s Strathspey', 'PAT CLARKS STRATHSPEY', 3, 32, 9999, 1, 100, 2, 479, '2003-02-01', '"Dedicated to Pat Clark whose wonderful music has inspired many a dancer and teacher. It was devised on the occasion of the Nunspeet Weekend, February 2003."', 87, '8888  8888  8888  8008', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (3672, '2000-06-12 22:00:00+00', '2021-12-05 22:14:34.424111+00', 'Lamb Skinnet', 'LAMB SKINNET', 2, 32, 9999, 1, 3, 42, 466, '1751-01-01', 'The Society’s version of this dance can be traced to "Thompson''s Compleat Collection of 200 Favourite Country Dances" (c. 1755) where it was published without setting in bars 1-4 and 9-12.



Several meanings of the name have been discussed. A very likely on is that name traces back to a card game, since the tune is also known under similar names like "Lamb Skinnett", "Lambskinnet", "Lanquenet", "Lansquenet". Lansquenet is the French writing and pronunciation of the German term "Landsknecht" which refers to a foot soldier in foreign service. And there is also a card game with the same name likely introduced by these mercenary soldiers.



Webster’s Revised Unabridged Dictionary (1913) states for "Lansquenet":  

   1. A German foot soldier in foreign service in the 15th and 16th centuries; a soldier of fortune; — a term used in France and Western Europe.  

   2. A game at cards, vulgarly called lambskinnet.



Try the 5-couple version of this - <<ddd:Skamb Linnet>>



Some versions of the instructions for bars 17-24 of this dance have 1st couple dancing above 1st place in 4 bars, setting, then casting with 3rd couple stepping down on 23-24 (and 2nd couple not moving). This was reflected in  the original version of the e-crib. However the revised version of Book 14 has 1st couple dancing up to 1st place as 2nd & 3rd couples step down, then 2nd couple step up again as 1st couple cast. The e-crib was updated to show this version.', 31, '800  800  800  880', 1, 1, 1, 1, 41);
INSERT INTO 'dance' VALUES (18017, '2017-10-19 21:57:29.743056+00', '2021-12-05 23:05:12.89115+00', 'Absacker, Der', 'ABSACKER', 1, 32, NULL, 1, 3, 42, 11534, '2016-06-21', '"Der Absacker" is German  for a nightcap... a last-drink-to-end-the-evening-with-a-blast nightcap. Much heartfelt thanks to Joana Stausberg for the apt name. Twirls and birls and extra toasts are naturally encouraged.', 53, '880/844/822/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20442, '2021-08-20 13:23:26.381594+00', '2021-12-06 11:35:59.895197+00', 'Stagger Dream', 'STAGGER DREAM', 3, 40, NULL, 2, 3, 17, 12059, '2021-01-01', '', 53, '800/822/822/844/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20492, '2021-09-16 16:32:51.416363+00', '2021-12-06 12:31:15.05424+00', 'London Nine-O', 'LONDON NINEO', 1, 32, NULL, 1, 3, 42, 11454, '2020-03-14', 'This dance is the winning entry, out of 35 dance entries, for RSCDS London Branch 90th Anniversary New Scottish Dance Devising Competition.  

The trialing of the three short-listed dances took place at St Columba’s Church, London on 11 September 2021.  

This dance originally and temporarily named Happy Times is now renamed and is to be known by its anniversary name: London Nine-O.  

The name London Nine-O was given by Betty Arrol of Ruislip, England and under the competition rules has been chosen by London Branch as being best suited for this dance and occasion.', 63, '888/800/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20830, '2022-05-14 19:58:26.174505+00', '2022-05-14 19:58:26.174505+00', 'A. B. Paterson''s Jig', 'A B PATERSONS JIG', 2, 32, NULL, 1, 4, 2, 99, '2016-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20600, '2022-01-07 18:12:15.150787+00', '2022-01-07 18:12:15.150787+00', 'Cascade, The', 'CASCADE', 1, 32, NULL, 1, 4, 1, 11514, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20608, '2022-01-09 19:00:25.424569+00', '2022-01-09 19:00:25.424569+00', 'West Wynd, The', 'WEST WYND', 3, 32, NULL, 5, 2, 76, 1190, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20843, '2022-05-15 20:39:32.651661+00', '2022-05-15 20:39:32.651661+00', 'Spread Eagle, The', 'SPREAD EAGLE', 1, 32, NULL, 1, 3, 42, 99, '1988-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20566, '2021-12-03 18:20:47.491578+00', '2022-10-11 14:08:58.170275+00', 'Heart of Midlothian, The', 'HEART OF MIDLOTHIAN', 1, 32, NULL, 1, 3, 42, 9998, NULL, 'Originally published in 1820 by John Sutherland, Edinburgh in a booklet linked to Sir Walter Scott''s novel The Heart of Midlothian.  Reconstructed by the RSCDS in 2021 to mark the 250th anniversary of Sir Walter Scott''s birth.', 38, '880/800/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19785, '2019-12-01 23:17:02.700954+00', '2022-08-15 13:31:48.915697+00', 'Joy to the World', 'JOY TO THE WORLD', 2, 32, NULL, 1, 4, 11, 2973, '2019-11-01', 'Devised by Chris Ronald in November 2019 for Sue Biddle of Vancouver, Canada. This dance came about through an auction at the 2019 summer school of the Scottish Country Dance Teachers Association (Canada). Sue was the winning bidder. Hence the alternate title for the dance of ''Biddle''s Best Bid''.   



Bars 17-24.  Tandem reels of 3: When dancing in tandem, experienced dancers may alternate the lead at top and bottom of set (dolphin style).  ', 88, '8888/8888/8888/0880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (453, '1997-09-06 22:00:00+00', '2021-12-07 00:19:29.540864+00', 'Belfast Almanac, The', 'BELFAST ALMANAC', 2, 32, 9999, 1, 2, 76, 129, '1968-01-01', 'There are two versions of the Glendarroch Sheet for this dance. In one (earlier?) version 2nd couple are shown turning RH in bars 27-28 in between dancing up LH and then later turning LH for 29-32. The other (corrected?) version shows 2nd couple turning LH throughout. This matches the text.', 87, '80/88/88/88', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11693, '2004-02-18 23:00:00+00', '2021-12-07 15:58:34.993293+00', 'Flight of the Dove', 'FLIGHT OF THE DOVE', 1, 32, 9999, 1, 3, 42, 3429, NULL, '', 53, '800/888/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20315, '2021-04-14 09:45:51.648213+00', '2021-12-09 01:13:25.946265+00', 'Ville Lumière, La', 'VILLE LUMIERE', 1, 32, NULL, 1, 4, 2, 11781, '2019-04-01', '', 75, '8008/8888/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17239, '2016-09-03 22:21:51.065681+00', '2021-12-09 08:03:53.953794+00', 'Taste @ Sawtell', 'TASTE  SAWTELL', 1, 32, NULL, 1, 3, 42, 11035, NULL, '', 63, '888/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (338, '1998-07-08 22:00:00+00', '2021-12-10 09:53:09.279956+00', 'Back to Bach', 'BACK TO BACH', 1, 32, 9999, 3, 5, 7, 108, '1993-01-01', 'In  the original publication, John Drewry states:   



For David Goldberg of Brooklyn NY. February 1993. Bratach Bana is David Goldberg’s favourite dance - this is a 5–couple variation of the dance. The “Goldberg Variations” are a set of variations for the harpsichord by J S Bach written for J T G Goldberg to play to Count Keyserling as a solace for insomnia. (The dancers cannot afford to go to sleep during this dance!). David loves a play on words, hence the title. Sadly the final version of this dance did not include a back-to-back movement. ', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (729, '1997-08-25 22:00:00+00', '2021-12-13 02:18:47.008759+00', 'Boyndie Knot, The', 'BOYNDIE KNOT', 3, 32, 9999, 1, 3, 42, 108, '1992-11-01', 'The notes say this is a "dance for the Ruby Wedding of Jonathan and Mary Ross who were married at Boyndie Kirk near Whitehills, Banffshire in March 1953."



The instructions give the tune as "The Boyndie Knot" by <<ddp:Meikle, George>> whereas SCDDB currently links a tune called "The Knotted Piece of String" also by <<ddp:Meikle, George>>. Its not clear if these are the same tune.', 63, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9579, '2000-09-06 22:00:00+00', '2021-12-12 14:57:32.914878+00', 'Walker Strathspey', 'WALKER STRATHSPEY', 3, 32, 9999, 2, 2, 76, 118, '1998-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (153, '1998-10-11 22:00:00+00', '2021-12-18 14:24:45.468013+00', 'Angus MacLeod', 'ANGUS MACLEOD', 1, 64, 9999, 1, 4, 22, 315, '1969-01-01', 'Twice through only!



The pattern represents the Black Watch cap badge design.  In some areas the custom is that inner dancers who pass to corners do not first swivel to face inwards, but, like those in the centre, swivel during the setting.





A comment made by David Queen on the Scottish Country Dance teachers (07/2017):

"Dad wrote the dance in 1969 and the first version started with a reel of 4 on the sides, then he changed it to the dance in movement which defines the dance."', 73, '4884  8888  0440   12 12 12 12    6886  0880  0880  0880', 0, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (5308, '1998-11-12 23:00:00+00', '2021-12-12 23:55:58.562109+00', 'Polharrow Burn', 'POLHARROW BURN', 1, 32, 9999, 3, 5, 7, 129, '1967-01-01', '', 65, '80800  88808  86846  82842', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (3172, '2000-02-21 23:00:00+00', '2021-12-13 01:21:52.3725+00', 'J. B. Milne', 'J B MILNE', 1, 32, 9999, 1, 3, 42, 129, '1954-01-01', '##>>

From the Dundee Courier and Advertiser of 25 September 1968



Mr J B Milne dies at age 66



Mr J B Milne, who was a millboy with ambition, died yesterday at his home, Ruthven House, Meigle, aged 66, as head of Scotland’s largest private cinema chain.



He had been ill for some time.



His first cinema was the Palladium, Dundee, where he once played the violin and washed floors. When he died he controlled 34 cinemas and bingo halls.



John Bannerman Milne was one of three sons of the late Mr Charles Milne, a Dundee coal merchant.



When he was nine he bought his first violin and by the age of 16 he was working in Dura Works from 5.30 am to 6 pm, teaching the violin from 6 pm to 8 pm, then playing in a dance hall until midnight.



Mr Milne became an apprentice engineer, but his future lay in the entertainment world.



His first entertainment job was at the Variety Theatre, later the Palladium, and later the Rex, until it was demolished.



He was a 19s a week “musical director and cleaner”. His savings were invested in a motor hire business, which he sold for £360 to found his cinema empire.



In 1928 Mr Milne bought the hall where he once worked. He had the vision to install talkies and never looked back.



Within 10 years, he had the largest cinema chain under private ownership in Scotland. Mr Milne recognised the potential of bingo and introduced it. Some of his halls remained cinemas, some became bingo halls, some combined the two.



Mr Milne bought Ruthven House, a 32-room Adam-designed manor, complete with its furnishings in 1946. A 1500-acre estate went with it.



Citizen award

 

But he did not forget his home town, where he had his offices at Bannerman House, South Tay Street. In 1961, he presented his ‘Citizen of the Year’ award to Dundee Corporation for annual presentation.



Mr Milne’s interests ranged from Stornoway to Galashiels. He, at one time, owned the Kinnaird and the Capitol, Dundee.



The cinemas and bingo halls he owned include –

Royalty, Ritz, State, Broadway, Victoria in Dundee; Regal, Broughty Ferry; Palace and Picture House, Arbroath; King’s and Playhouse, Montrose; Picture House, Cowdenbeath; Opera House, Lochgelly; Palace and Imperial, Methil; Troxy and Regent, Leven; Regal, Blairgowrie; Scala, Cupar and County, Kinross.



He also owned the Picture House, Tayport; Regal, Auchterarder; Regal, East Wemyss and the Globe, Buckhaven, which are now closed.



##<<





Added on 13-10-11 from:  http://thesession.org/tunes/3479



JB Milne, the man



He was my grandmother’s cousin.

Brief biography of him is as follows (found it on the web)…

"John Bannerman Milne was born one of three sons of Charles Milne, a Dundee coalmerchant, in 1902. When he was nine, he bought his first violin. By the age of sixteen, he was working at Dura Works (a jute mill) from 5.30am to 6.00pm, teaching the violin from 6.00pm to 8.00pm and then playing in a dance hall until midnight.

His first entertainment job was at the Variety Theatre, Dundee, as a 19 shillins a week "musical director and cleaner". He eventually bought the theatre in 1925 for £360 (actually with his sister, Lizzie, though this is not mentioned on the web - my mum told me this!), installed "talkies", and never looked back. Within ten years he … presided over a theatre, cinema and bingo empire that stretched from Stornaway to Galashiels …

The dance was devised by Angus Fitchet who dedicated it to J.B. Milne as "the man who gave him his start in his show business career".



Some other stuff - he bought Lizzie out at some point early on and then expanded his "empire" - he died in 1968 - never married and lived in Ruthven Hall, near Meigle. He taught my mum to drive in a Rolls Royce in a field on his estate and also once told her in conversation that he had more money than he knew what to do with - he couldn’t even manage to spend the interest on his money, no matter how hard he tried! Don’t know what happened to the money !!! Unless mum has kept it very well hidden all these years!!!



Described in another report as a "fiery redhead" - whatever that means!



Thought this might flesh out the answer for anyone who is interested in knowing more about the man the tune is named after …



# Posted by jbmilnesobscurerelly 6 years ago. ', 50, '440  800  888  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (13181, '2006-12-11 23:00:00+00', '2021-12-20 15:32:42.457397+00', 'Follow Me', 'FOLLOW ME', 2, 32, 9999, 4, 5, 6, 2766, '2006-09-01', '', 50, '80808/08088/80044/04840', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17993, '2017-10-10 11:50:41.055949+00', '2022-01-03 02:05:52.778732+00', 'Road To Torridon, The', 'ROAD TO TORRIDON', 1, 40, 9999, 3, 5, 16, 384, '2013-01-01', 'For forty years, Scottish Country Dance Classes have been held in Torridon under a variety of Teachers. Over that duration, music has always been provided by a mixture of records, tapes and CDs. The current Teacher, Marie Macdonald, has taken the bold move of celebrating the 40th Anniversary of the Torridon SCD Group by organising a SC Dance with ''live'' music.



''The Road to Torridon'' has been devised to mark the event, to a tune composed by Frank Thomson of Aberdeen who provided the said ''live'' music.



[Source: the original description]

', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11465, '2003-09-22 22:00:00+00', '2021-12-25 19:51:49.760371+00', 'Dancing Along the Rock River', 'DANCING ALONG THE ROCK RIVER', 3, 32, 9999, 2, 3, 17, 2766, '2002-05-01', 'I wrote this dance right after driving out to Oregon, IL to check out the venue for our annual weekend workshop. Stronghold is on a bluff overlooking the Rock River. I also wanted to write a dance using this music and it is only three times through.', 58, '800/844/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14743, '2013-03-23 08:40:35.023063+00', '2022-01-01 04:56:42.882337+00', 'Skara Brae', 'SKARA BRAE', 3, 32, NULL, 3, 5, 7, 3165, '1993-01-01', 'Skara Brae is a stone age village at the bay of Skaill on the West coast of Mainland, Orkney', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10129, '2001-10-30 23:00:00+00', '2022-01-03 02:36:26.714901+00', 'Melbourne Cup, The', 'MELBOURNE CUP', 2, 32, 9999, 1, 4, 1, 2949, NULL, 'Source: Youtube video', 68, '8888/5555/4444/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14330, '2011-12-08 23:00:00+00', '2022-01-03 02:54:33.415372+00', 'Miracle in Merrill', 'MIRACLE IN MERRILL', 1, 32, 9999, 1, 3, 42, 2701, '2010-01-01', 'Devised: 2010', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16040, '2015-02-11 15:35:19.650518+00', '2022-01-01 06:24:06.419281+00', 'St Andrew''s Lightning', 'SAINT ANDREWS LIGHTNING', 2, 32, 9999, 3, 5, 10, 3694, '2008-11-01', '', 82, '48484/88888/48444/88888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20452, '2021-09-02 10:30:31.702024+00', '2022-01-05 01:52:44.560358+00', 'My Dear Oncologist', 'MY DEAR ONCOLOGIST', 2, 32, NULL, 2, 3, 17, 11509, '2021-06-01', 'Devised by Anne Dejean for her oncologist Sophie.



Information derived from the <<https://youtu.be/8EaDI1R7ns8|youtube video>>.', 75, '880/808/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20578, '2021-12-21 19:53:40.936451+00', '2022-04-07 05:14:42.243699+00', 'Bloody Catheter', 'BLOODY CATHETER', 2, 32, NULL, 1, 4, 1, 11509, '2021-06-01', 'This dance depicts the deviser''s experiences in hospital.  Anne writes:



  One day, two nurses had difficulties in inserting a catheter in my arm, they needed a few tries to achieve it, which was not a very nice experience. After a little while, I decided I would make something funny out of this bad and painful moment.



  Bars 1-4 and 9-12, the advancing dancers represent the approaching catheter, whereas the retiring dancers symbolise the fleeing vein.



 This is a very easy dance, more like a ceilidh dance, or suitable for warming up.', 81, '8888/8888/8440/8448', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19635, '2019-09-08 09:12:57.179712+00', '2022-01-05 19:00:39.031152+00', 'Benign Presence, The', 'BENIGN PRESENCE', 3, 32, NULL, 2, 3, 18, 11237, '2019-01-01', 'For Rachel Wilton who has benignly presided over London Branch for many years.



An early version of the instructions had a mistake in bars 25-32 mixing up 2nd and 3rd couples in places. This is now fixed (thanks to David Haynes of the MiniCrib team for pointing it out).', 75, '884/822/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20585, '2022-01-05 17:54:21.442587+00', '2022-01-06 12:23:42.250594+00', 'Sakura Invites You to Tokyo', 'SAKURA INVITES YOU TO TOKYO', 2, 64, NULL, 4, 4, NULL, 12089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20580, '2022-01-05 17:46:32.816371+00', '2022-01-06 12:24:03.803266+00', 'Cornie, the Unicorn, Joins the Dance', 'CORNIE THE UNICORN JOINS THE DANCE', 2, 32, NULL, 1, 4, NULL, 12089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20581, '2022-01-05 17:49:38.860458+00', '2022-01-06 12:24:27.619372+00', 'Aimee Likes the Figure of Eight', 'AIMEE LIKES THE FIGURE OF EIGHT', 1, 32, NULL, 5, 2, NULL, 12089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20582, '2022-01-05 17:50:53.536587+00', '2022-01-06 12:24:44.6315+00', 'Tango Dances in the Pampas', 'TANGO DANCES IN THE PAMPAS', 1, 32, NULL, 1, 4, NULL, 12089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20583, '2022-01-05 17:52:13.886035+00', '2022-01-06 12:25:02.010877+00', 'Meet Mrs Kiwi', 'MEET MRS KIWI', 3, 32, NULL, 2, 4, NULL, 12089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20584, '2022-01-05 17:53:05.659896+00', '2022-01-06 12:25:19.306055+00', 'Rudolf Dances in Moscow', 'RUDOLF DANCES IN MOSCOW', 2, 32, NULL, 1, 4, NULL, 12089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20586, '2022-01-05 17:55:49.148497+00', '2022-01-06 12:25:37.84261+00', 'Hans, the German Hedgehog', 'HANS THE GERMAN HEDGEHOG', 1, 32, NULL, 1, 4, NULL, 12089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20587, '2022-01-05 17:58:09.673939+00', '2022-01-06 12:25:52.763222+00', 'Dart, the Dragon', 'DART THE DRAGON', 1, 32, NULL, 2, 4, NULL, 12089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20589, '2022-01-05 18:00:49.121353+00', '2022-01-06 12:26:41.332335+00', 'Sussie, Please, Wake Me Up!', 'SUSSIE PLEASE WAKE ME UP', 2, 32, NULL, 1, 4, NULL, 12089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20590, '2022-01-05 18:01:58.433792+00', '2022-01-06 12:26:51.464114+00', 'Holly, the Red Squirrel from Pinewoods', 'HOLLY THE RED SQUIRREL FROM PINEWOODS', 3, 32, NULL, 2, 4, NULL, 12089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20591, '2022-01-05 18:02:59.013007+00', '2022-01-06 12:27:11.436523+00', 'Nandi, the Giraffe from Zululand', 'NANDI THE GIRAFFE FROM ZULULAND', 3, 32, NULL, 104, 4, NULL, 12089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20592, '2022-01-05 18:03:55.805222+00', '2022-01-06 12:27:20.84856+00', 'Ethan from Australia', 'ETHAN FROM AUSTRALIA', 1, 32, NULL, 2, 4, NULL, 12089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2170, '1998-07-09 22:00:00+00', '2022-01-07 11:28:14.039054+00', 'Findhorn Medley', 'FINDHORN MEDLEY', 4, 96, 21, 2, 3, 3, 82, NULL, 'The last 8 bars of the reel are quite demanding. On video 1 the team substituted the following:  

25-28: dancing couple (original couple 2) set diagonally to each other and cast (pulling back right shoulder) one place (to second place opposite side) while couples 1 and 3 turn once (instead of 1 1/2 times) finishing on their opposite side [(1)(2)(3)]  

29-32: all circle half way 6 hands round to the left to finish [321]. This means the the dance finishes 321, whereas the original instructions have the dancers finishing 123.  ', 78, '282/848/686/888/888/666/888/666/242/646/646/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20588, '2022-01-05 17:59:44.188712+00', '2022-01-07 13:14:16.067682+00', 'Corgis Are at Balmoral''s Castle, The', 'CORGIS ARE AT BALMORALS CASTLE', 1, 32, NULL, 5, 2, NULL, 12089, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17188, '2016-08-22 14:03:32.648735+00', '2022-01-07 13:29:37.886435+00', 'Scapa Flow', 'SCAPA FLOW', 1, 40, NULL, 2, 3, 18, 11319, '2016-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13539, '2009-12-02 23:00:00+00', '2022-01-07 14:19:45.489154+00', 'Hotel Elsbury', 'HOTEL ELSBURY', 2, 32, NULL, 1, 3, 42, 12091, '2005-01-01', 'From the dance notes: "Devised for Betty Elsbury, the ''hostess with the mostest'', and her devoted husband Clive. Many thanks for your kind hospitality!"', 56, '800/888/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13159, '2006-12-11 23:00:00+00', '2022-08-07 11:10:26.367617+00', 'Sherlock''s Mom', 'SHERLOCKS MOM', 3, 32, 9999, 1, 4, 2, 2766, '2006-02-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13173, '2006-12-11 23:00:00+00', '2022-08-07 11:14:48.23716+00', 'Miss Jenny Lee', 'MISS JENNY LEE', 3, 32, 9999, 1, 4, 11, 2766, '2006-06-01', 'This dance was written for Jenny Lee, a summer intern at Fermilab, who really caught on quickly to the dancing.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7523, '1998-12-17 23:00:00+00', '2022-10-23 19:51:38.548444+00', 'Susan''s Baby', 'SUSANS BABY', 2, 32, 9999, 1, 3, 42, 440, NULL, 'Written for my friend and fellow member of St. Andrew''s of Brampton , Susan Baulcomb Stephens, and her son, Christopher.', 53, '800/888/844/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20610, '2022-01-09 19:17:14.567358+00', '2022-01-09 19:17:14.567358+00', 'Miss Lawson''s Reel', 'MISS LAWSONS REEL', 1, 32, NULL, 1, 3, 42, 1190, '1988-01-01', '"For Jennifer"



In the book the recommended tune is given as "Jennifer Lawson''s Reel" (no composer mentioned). The Irvine Valley SCD band recorded a track <<ddrec:Miss Lawson''s Reel>> which includes a tune entered there just as "Jennifer''s Reel" by BA Ramsay. It is assumed that is the intended one.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20611, '2022-01-09 19:20:53.820174+00', '2022-01-09 19:20:53.820174+00', 'Scotstoun Medley', 'SCOTSTOUN MEDLEY', 4, 64, 5, 2, 3, 18, 1190, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20612, '2022-01-09 19:24:26.456597+00', '2022-01-09 19:24:26.456597+00', 'Laigh Strathspey, The', 'LAIGH STRATHSPEY', 3, 32, NULL, 1, 3, 42, 1190, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20613, '2022-01-09 19:27:46.974163+00', '2022-01-09 19:27:46.974163+00', 'Life Let Us Cherish', 'LIFE LET US CHERISH', 2, 32, NULL, 1, 3, 42, 1190, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20614, '2022-01-09 19:30:15.76258+00', '2022-01-09 19:30:15.76258+00', 'Jig for Jennifer, A', 'JIG FOR JENNIFER', 2, 32, NULL, 1, 3, 42, 1190, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20615, '2022-01-09 19:36:03.45999+00', '2022-01-09 19:36:53.15764+00', 'Saturday Morning Jig', 'SATURDAY MORNING JIG', 2, 32, NULL, 5, 2, 76, 1190, '1983-01-01', '"For Sherwood Junior Country Dance Class"

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20616, '2022-01-09 19:41:39.323133+00', '2022-01-09 19:42:43.945575+00', 'Sherwood Strathspey', 'SHERWOOD STRATHSPEY', 3, 32, NULL, 1, 3, 42, 1190, '1989-01-01', '"For Sherwood Scottish Country Dance Club Silver Jubilee in 1989"', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20617, '2022-01-09 19:46:51.376311+00', '2022-01-09 19:46:51.376311+00', 'Gleniffer Circle', 'GLENIFFER CIRCLE', 1, 32, NULL, 5, 56, 76, 1190, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10892, '2002-10-20 22:00:00+00', '2022-01-09 20:03:40.199204+00', 'Epping Hundred', 'EPPING HUNDRED', 1, 32, 9999, 1, 3, 42, 108, '2002-01-01', 'To celebrate Epping Forest (Scottish Association) Centenary in 2003. Requested by Sheila Tanner of Buckhurst Hill, Essex.', 59, '660/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11284, '2003-05-04 22:00:00+00', '2022-01-29 00:34:31.265474+00', 'Linnea''s Strathspey', 'LINNEAS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 2701, '2001-01-01', 'Devised for Linnea Johnson on the occasion of her birthday. A dear friend, beautiful dancer and delightful partner, she has also been the manager of the San Fransisco class for many years.  This dance pays homage to two of her favourite dances: Sugar Candie and General Stuart’s Reel. A huge thank you to Tom Winter for his suggestion to have 1st couple active during the chain progression. What a nice change. (Source: The notes in the original publication ''Dunsmuir Dances'')



The chain progression for 3 couples was named ''Promenade Chain Progression'' (and ''Chaperoned Chain Progression'') in the description.', 53, '800  822  888  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (20621, '2022-01-10 17:11:55.216517+00', '2022-01-10 17:12:37.611488+00', 'Richmond Wedding, The', 'RICHMOND WEDDING', 1, 32, NULL, 1, 3, 42, 854, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20622, '2022-01-10 17:14:17.13573+00', '2022-01-10 17:14:17.13573+00', 'Nelson''s Flower', 'NELSONS FLOWER', 3, 32, NULL, 1, 3, NULL, 854, NULL, 'Devised for Janet Tavener.  

 

With grateful thanks of her generosity and hospitality when we had an unexpected stopover in Nelson, New 

Zealand.  

  

The flower in the dance title refers to the Bird of Paradise flower that Janet has growing in her front garden, 

which  I  admired  greatly  when  we  stayed  with  her.  The  opening  out  in  bars  5-8  is  meant  to  represent  the flowering of the Bird of Paradise flower.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20618, '2022-01-09 23:35:09.908118+00', '2022-08-22 23:30:34.354772+00', 'Jig For the New Year, A', 'JIG FOR THE NEW YEAR', 2, 32, NULL, 1, 3, 42, 2766, '2020-01-01', 'This dance started from an idea for the figure in bars 9-16 and grew from there.', 48, '864/444/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20619, '2022-01-10 17:07:16.63121+00', '2022-01-10 19:17:55.840716+00', 'Catriona''s Reel', 'CATRIONAS REEL', 1, 32, NULL, 1, 3, 42, 854, NULL, 'Devised for my elder daughter, Catriona.', 56, '888/888/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20635, '2022-01-18 15:17:13.870241+00', '2022-01-22 14:07:01.239581+00', 'Dancing Surgeon, A', 'DANCING SURGEON', 1, 40, NULL, 4, 4, 1, 11509, '2021-10-01', 'This dance refers to the surgeon who operated my vertebra in June 2021. When I asked him if there was a risk I might lose the use of my legs, difficult to imagine as an scd teacher, he started to dance a few Irish steps like in Irish set dancing, that a friend of his had taught him! Then he explained to me that the risk was much higher with no operation than with an operation. I liked that exchange with him and I felt quite confident. And the operation went all right.  

During the first phrase of the dance, formations are different each time through to convey an Irish flavor, and this is also why there is a swing at the end.', 80, '8080/0808/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3333, '1997-04-03 22:00:00+00', '2022-01-23 20:08:18.806754+00', 'John Stephen of Chance Inn', 'JOHN STEPHEN OF CHANCE INN', 3, 32, 9999, 1, 3, 42, 108, '1982-01-01', 'Versions of the instructions for this dance have either turn one and half or turn one and a quarter in bars 3-4. The latter seems to make more sense.', 56, '808/484/888/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5552, '2000-06-12 22:00:00+00', '2022-01-29 16:15:23.399395+00', 'Rest And Be Thankful', 'REST AND BE THANKFUL', 1, 32, 9999, 1, 3, 42, 251, NULL, 'In western Scotland, the A83 road connects Tarbet on the western shore of Loch Lomond to Campbeltown on the Kintyre peninsula. »Rest and be thankful« is the name of a viewpoint and picnic area on the A83, at the summit of its pass through the Arrochar Alps between Loch Long and Loch Fyne. The name derives from an inscribed stone that marked the summit on the old »drover''s road« constructed by soldiers in 1753. Its suggestion is very sensible given that the old road up Glen Croe from Loch Long ended in a very steep climb up to the pass. The modern A83 does not keep to the bottom of the glen, for a more gradual incline.', 44, '800  844  844  844', 0, 1, 1, 0, 58);
INSERT INTO 'dance' VALUES (15621, '2014-09-12 20:10:56.880587+00', '2022-01-29 22:08:52.419254+00', 'Yes', 'YES', 1, 32, NULL, 1, 3, 42, 11002, '2014-09-08', 'This dance came about due to a conversation between Frank Thomson and the deviser George T

Watt. Frank suggesting a dance simply called ‘YES’ in honour of the Scottish Referendum on

Independence (18 september 2014) and challenging George to write one. Over to Frank for a tune!

', 61, '886/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20099, '2020-09-30 16:12:10.308421+00', '2022-01-29 22:21:33.835173+00', 'What''s in a Name?', 'WHATS IN A NAME', 3, 32, NULL, 1, 3, 42, 11971, '2020-07-01', 'The title, a line from “Romeo and Juliet”, cropped up while I was simply running out of ideas how to call yet another dance – and I didn’t feel like choosing a name alluding to the corona crisis again. I hope Shakespeare will forgive me.', 44, '800/844/888/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18517, '2018-08-21 09:34:44.98361+00', '2022-01-30 00:04:27.683772+00', 'Walnut Schiehallion Reel, The', 'WALNUT SCHIEHALLION REEL', 2, 96, NULL, 4, 4, 3, 11509, '2018-04-01', 'I just love schiehallion reels.  

This dance is definitely not for those who easily feel dizzy!', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14445, '2012-06-12 13:24:40.158068+00', '2022-02-15 15:37:24.675988+00', 'Potten End Reel, The', 'POTTEN END REEL', 1, 32, NULL, 1, 3, 42, 10621, '2010-07-01', 'From the dance description:  

Berkhamsted Strathspey & Reel Club meets each Tuesday evening, for social dancing and newcomer instruction, in Potten End Village Hall and has done since 1959. (Image: Signpost on village green)', 49, '800/888/844/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20620, '2022-01-10 17:09:00.670467+00', '2022-08-15 15:21:34.127118+00', 'Susie''s Jig', 'SUSIES JIG', 2, 32, NULL, 1, 3, 42, 854, NULL, 'Devised for my younger daughter, Susie. ', 50, '880/800/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20579, '2022-01-01 18:56:01.784163+00', '2022-01-11 08:21:48.940514+00', 'Bob Grant of Edinburgh', 'BOB GRANT OF EDINBURGH', 3, 32, NULL, 1, 4, 2, 550, '2021-01-01', 'In  memory  of  Bob  Grant,  1935-2021.  Bob  was  a  renowned  teacher  in  Edinburgh,  travelling around  the  world  to  teach,  and  was  also  my mentor for the final  part  of  my  Teacher’s  Certificate. Muriel’s  tune  “Bob  Grant  of  Edinburgh”  was  played  during  his  funeral,  and  I  felt  he  needed  to be  honoured  with  a  dance  to  match.  



The  set,  hands  across  and  twiddle  on  bars  3-6  evokes  the  set,  turn  and  twiddle  at  the  start  of Bob’s  dance  “Dancing  Forth”.  



When  I  first  learned  the  strathspey  poussette,  I  was  taught  it  in  the  symmetric  way  described here,  and  I  still  prefer  it  this  way.    Bob  Grant  wrote  an  article  for  RSCDS  magazine  Scottish Country  Dancer  (issue  13,  October  2011)  about  the  strathspey  poussette,  describing  how  in books  19  and  20  it  was  originally  described  symmetrically  and  only  later  was  the  standard changed  to  the  current  recommendation  with  1st  couple  nearer  the  men’s  side  and  2nd  couple nearer  the  women’s  side  at  the  end  of  bar  one.  



Bob  received  a  lot  of  comment  from  other  dancers  wishing  for  the  return  of  the  symmetric poussette.    In  this  dance,  the  strathspey  poussette  should  be  danced  the  way  I  first  learned  it  and the  way  Bob  advocated.', 72, '8228/8888/8448/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15594, '2014-08-31 14:23:39.156027+00', '2022-01-11 11:24:27.312468+00', 'Awa the Noo', 'AWA THE NOO', 3, 32, NULL, 3, 5, 7, 10998, '2002-01-01', 'This dance was translated into the Scottish Dancing métier by John Wilcock from the English Country Dance The Adieu, from C. & S. Thompson''s 1776 Collection, republished by the Thompson firm in Volume 4 of their Compleat Collection, also published by Tom Cook in Hunter''s Moon, Cotswold Music Society (July 1997); full acknowledgment is made to both these sources.



', 100, '88888/88888/88888/88888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15597, '2014-08-31 14:58:59.940014+00', '2022-01-11 11:25:46.995821+00', 'Betty''s Fancy', 'BETTYS FANCY', 3, 32, NULL, 3, 5, 16, 10998, NULL, 'The dance was written to celebrate dance teacher Betty Thomson''s fifty years'' membership of the Stafford & District Caledonian Society. The Stafford Knot is the badge of the Stafford family, and has been used on their coats of arms, liveries and buildings for centuries, e.g. on tiles at Stafford Castle. The family has been pleased to grant use of their badge to certain institutions, e.g. Staffordshire County Council, the North Staffordshire Railway ("The Knotty"), Staffordshire University, etc. and from this use it has sometimes incorrectly been termed the Staffordshire Knot. The correct term remains the Stafford Knot, however.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13752, '2011-07-11 22:00:00+00', '2022-01-11 11:26:59.822501+00', 'Cannock Chase', 'CANNOCK CHASE', 2, 32, NULL, 1, 4, 1, 10998, '2001-01-01', '', 81, '6666/6666/8888/0888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16865, '2016-02-02 22:52:46.948626+00', '2022-01-11 11:27:30.9902+00', 'McColl Strathspey, The', 'MACCOLL STRATHSPEY', 3, 64, NULL, 6, 3, 3, 2091, '2000-01-01', 'Devised by John Dalkin and John Wilcock of Stafford & District Caledonian Society ', 91, '888/555/555/888/888/888/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20623, '2022-01-11 11:33:26.845057+00', '2022-01-11 11:33:26.845057+00', 'Stafford Diamond Jubilee Jig', 'STAFFORD DIAMOND JUBILEE JIG', 2, 32, NULL, 1, 3, 42, 10998, '2016-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20624, '2022-01-11 11:46:09.548393+00', '2022-01-11 11:46:09.548393+00', 'Yorkshire Rose', 'YORKSHIRE ROSE', 3, 32, NULL, 6, 3, NULL, 12092, '1994-01-01', 'The instructions on the web appear to be missing bars 29-30?', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4904, '1997-09-10 22:00:00+00', '2022-01-11 18:37:06.970763+00', 'An Niseag (Nessie)', 'NISEAG NESSIE', 4, 64, 5, 1, 4, 14, 13, NULL, 'This was originally entered in SCDDB as "An Niseach". The title in the book is "An Niseag". The former is kept as a spelling alias.', 86, '8668/8888/0880/8888/ 8888/8888/4884/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2935, '2002-02-26 23:00:00+00', '2022-01-13 10:21:51.403277+00', 'Highlandman''s Umbrella, The', 'HIGHLANDMANS UMBRELLA', 1, 32, 9999, 4, 4, 13, 181, NULL, 'The Highlandman''s Umbrella was a nickname for the railway bridge of Glasgow Central Station which could be used to shelter from the rain.



According to George Watt (on the strathspey mailing list) "there is a song by the Alexander Brothers, The Heilanman''s Umbrella. This was also recorded by Andy Stewart (<<https://www.youtube.com/watch?v=BX8ZKtndqtM>>). And there is, or was, a great wee music shop under the bridge that has an amazing selection of Scottish Dance CDs."', 78, '6666  6666  5555  8888', 1, 1, 1, 0, 78);
INSERT INTO 'dance' VALUES (5155, '1997-04-03 22:00:00+00', '2022-01-14 18:10:24.944436+00', 'Paisley Weaver, The', 'PAISLEY WEAVER', 2, 32, 9999, 1, 3, 42, 422, NULL, '', 47, '880/880/833/833', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3624, '1997-04-03 22:00:00+00', '2022-01-15 00:37:01.389474+00', 'Lady Mary Ramsay', 'LADY MARY RAMSAY', 3, 32, 9999, 1, 2, 76, 270, NULL, '', 60, '66/66/88/88', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17898, '2017-07-16 12:16:15.537042+00', '2022-01-13 21:17:53.554283+00', 'New Year Jig', 'NEW YEAR JIG', 2, 32, NULL, 1, 3, 42, 11155, '1995-04-01', 'This dance was devised to teach reels of three at a children''s class at Upper Hutt.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4232, '1997-04-03 22:00:00+00', '2022-01-14 18:08:58.623413+00', 'Mauchline Lady, The', 'MAUCHLINE LADY', 1, 32, 9999, 1, 3, 42, 422, NULL, '', 47, '800/888/880/804', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6836, '1997-04-03 22:00:00+00', '2022-01-14 18:09:51.856108+00', 'Under The Rowan Tree', 'UNDER THE ROWAN TREE', 3, 32, 9999, 1, 2, NULL, 422, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4101, '1997-09-08 22:00:00+00', '2022-01-15 00:45:18.883615+00', 'Mairi''s Reel', 'MAIRIS REEL', 1, 32, 9999, 1, 2, 76, 1100, NULL, 'Devised by Mairi Lees (aged 7) - Ponteland Class.', 60, '88/80/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17356, '2016-09-16 13:14:19.835055+00', '2022-01-22 20:44:01.531677+00', 'Happy Trail', 'HAPPY TRAIL', 3, 32, NULL, 1, 4, 1, 2792, NULL, 'A scan available to the e-cribs team has the dance title as "Happy Trail" but <<https://my.strathspey.org/dd/issue/2715/|issue 2715>> reports another copy with title "Happy Trails". The latter is added as an alias.



The e-cribs team scan suggests using "any suitable strathspey" whereas the Happy Trails scan gives a number of possible tunes.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (213, '1997-08-22 22:00:00+00', '2022-01-29 00:33:49.341557+00', 'Argee Bargee Rant, The', 'ARGEE BARGEE RANT', 3, 32, 9999, 1, 3, 42, 518, '1989-01-01', 'Devised for the wedding of Janet Lyddon and Kevin Marchand in February 1989. They confirmed their mutual attraction on a narrow boat, or barge.', 69, '888/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19647, '2019-09-16 00:18:34.750714+00', '2022-01-29 16:28:29.346617+00', 'Charlotte''s Joy', 'CHARLOTTES JOY', 2, 32, NULL, 1, 3, 42, 10790, '2010-01-01', 'Devised by Bob Branstrom, January 2010, for Charlotte Khuner, in response to her joyous and contagious smile while dancing.  



Note: First couple should maintain bright smiles, shameless eye contact, even a gentle shoulder nudge in bars 17 & 18, but they should only touch hands during the turn in the last four bars.', 50, '800/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18228, '2018-01-22 23:39:13.238691+00', '2022-01-29 17:15:22.174658+00', 'RNIB Anniversary Reel', 'RNIB ANNIVERSARY REEL', 1, 32, NULL, 1, 3, 42, 246, '1992-12-01', 'Inscribed to the Royal National Institute for the Blind to celebrate their 125th Anniversary.



', 37, '800/866/800/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6972, '2003-01-27 23:00:00+00', '2022-01-29 22:32:57.98543+00', 'Weathercock, The', 'WEATHERCOCK', 2, 32, 9999, 1, 4, 1, 234, NULL, '', 81, '8888  8484  8080  8888', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (11303, '2003-05-10 22:00:00+00', '2022-09-23 17:31:20.115244+00', 'Borussia Strathspey, The', 'BORUSSIA STRATHSPEY', 3, 32, 9999, 1, 3, 42, 854, NULL, 'Devised for Petra Dolata of Calgary, Canada (formerly of Dortmund, Gerrmany).  Petra is one of Borussia 

Dortmund Football Club’s biggest fans, hence the Borussia in the title', 47, '800/844/822/888', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (10016, '2001-09-12 22:00:00+00', '2022-01-15 23:22:12.910671+00', 'Daffodil, The', 'DAFFODIL', 3, 32, 9999, 1, 3, 42, 108, '2000-01-01', 'The dedication reads "In memory of John Baldwin of Hanley Swan, near Worcester. John''s favourite flower was the daffodil."

', 56, '880/866/822/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20626, '2022-01-16 21:30:05.786027+00', '2022-01-16 21:30:05.786027+00', 'Fare Thee Weel a While', 'FARE THEE WEEL A WHILE', 3, 32, NULL, 1, 4, NULL, 421, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20627, '2022-01-16 21:35:19.802508+00', '2022-01-16 21:35:19.802508+00', 'Murdoch Went A''Wooing', 'MURDOCH WENT AWOOING', 2, 40, NULL, 1, 4, NULL, 12093, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20629, '2022-01-16 21:42:35.356884+00', '2022-01-16 21:42:35.356884+00', 'Glow in Winter', 'GLOW IN WINTER', 1, 32, NULL, 1, 4, NULL, 637, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20630, '2022-01-16 21:44:27.922084+00', '2022-01-16 21:44:27.922084+00', 'Allardyce Strathspey, The', 'ALLARDYCE STRATHSPEY', 3, 32, NULL, 2, 3, NULL, 12094, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20628, '2022-01-16 21:40:38.920154+00', '2022-01-16 21:56:41.268831+00', 'Silver Threads', 'SILVER THREADS', 4, 64, 5, 2, 3, NULL, 758, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20631, '2022-01-17 13:20:53.29067+00', '2022-01-17 13:20:53.29067+00', 'Begone Social Distancing!', 'BEGONE SOCIAL DISTANCING', 5, 48, NULL, 2, 2, NULL, 3583, '2022-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20632, '2022-01-17 16:34:10.285887+00', '2022-01-17 16:39:15.685937+00', 'Remembering Marian', 'REMEMBERING MARIAN', 3, 32, NULL, 2, 3, 17, 11262, '2021-01-01', 'In memory of Marian Roth (1937-2021) who was a long term member of the Geneva Scottish Country Dancing Club.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18537, '2018-08-27 23:02:49.558803+00', '2022-01-18 09:23:10.972776+00', '100 years behind us!, A', '100 YEARS BEHIND US', 4, 192, 3, 2, 3, 17, 11691, '2018-01-01', 'Dance devised by Jennie Hartley with input from members to commemorate the Centenary of Watford and West Herts Scottish Society.  



Bars 25-28 represent the 1, bars 5-8 represent 00 - making the 100.', -1, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (896, '1998-11-05 23:00:00+00', '2022-01-18 21:55:35.899618+00', 'C.J.''s Reel', 'CJS REEL', 1, 32, 9999, 1, 3, 42, 21, NULL, 'Inscribed to deviser''s wife.', 66, '888/866/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20636, '2022-01-19 00:45:53.800596+00', '2022-01-19 01:10:30.496586+00', 'Porter Street Strathspey', 'PORTER STREET STRATHSPEY', 3, 32, NULL, 4, 4, 13, 12097, NULL, 'Porter Street is the address of the Plateau group''s weekly class in Enumclaw (Washington, USA).', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20637, '2022-01-19 00:52:05.50365+00', '2022-01-19 09:44:40.493831+00', 'Fruit Basket Upset', 'FRUIT BASKET UPSET', 2, 32, NULL, 1, 4, 4, 12096, NULL, 'Notes from the deviser:



The name is a local Portland Oregon name for the children’s game Musical Chairs.



The dance was inspired by a performance at the Enumclaw Highland Games when Pat and I accidentally traded partners with another couple. It is a four couple jig. It starts with 1st couple position, then 2nd couple position, then back to 1st couple position and one more time from 2nd couple position. I use the word position because couples trade partner throughout the dance. The last figure of each time through has the man in 1st  position and the lady in 4th position dancing to the middle of the set, turning two-handed 1 ½ times with the man ending at the 4th position men’s side and the lady ending in the 1st position ladies side. Each time through you form a new couple until at the end of the 4th time through you return to your original partner.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6705, '1997-12-21 23:00:00+00', '2022-01-19 09:48:50.402758+00', 'Trimble Tumble', 'TRIMBLE TUMBLE', 1, 32, 9999, 1, 3, 42, 9, '1980-01-01', '" Devised for the West Point Grey Presbyterian Church S.C.D. Group, 12th & Trimble, Vancouver, B.C., Canada, 1980.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3681, '1997-09-07 22:00:00+00', '2022-01-19 11:55:32.471409+00', 'Lamp Of Lothian, The', 'LAMP OF LOTHIAN', 1, 32, 9999, 1, 3, 42, 177, NULL, '"Devised by Mrs Jean Henderson, North Berwick, in honour of her Haddington class."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2744, '1999-04-21 22:00:00+00', '2022-01-19 17:41:35.803359+00', 'Hamilton Hornpipe', 'HAMILTON HORNPIPE', 1, 40, 9999, 1, 3, 42, 101, '1985-01-01', 'This dance was revised by the deviser in 1985.', 53, '800/888/800/888/866', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (10303, '2002-01-08 23:00:00+00', '2022-01-19 17:58:54.988338+00', 'Summer Sun Days', 'SUMMER SUN DAYS', 1, 32, 9999, 1, 3, 42, 9998, NULL, 'This dance was added to MiniCrib by Charles Upton. However his successors in the MiniCrib team do not have any original instructions other than the MiniCrib itself.', 44, '800/880/800/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16802, '2015-10-25 03:30:49.686395+00', '2022-01-19 18:36:03.146244+00', 'Laurentian Reel, The', 'LAURENTIAN REEL', 1, 32, NULL, 1, 3, 42, 101, NULL, 'Handwritten transcription, but signed by Andrew Gillies.

The first line states that "? to members of the RSCDS Montreal Branch.', 56, '888/808/808/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2880, '1997-09-04 22:00:00+00', '2022-01-19 20:35:07.848831+00', 'Hermitage Frolic, The', 'HERMITAGE FROLIC', 1, 40, 9999, 1, 3, 42, 318, NULL, '', 60, '808/800/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20633, '2022-01-17 16:46:22.215253+00', '2022-01-20 13:18:05.215441+00', 'Liz''s News Reel', 'LIZS NEWS REEL', 1, 32, NULL, 1, 3, 42, 11262, '2021-01-01', '"For Liz Matthews after covid-19".



During the first lockdown Liz produced a series of colourful newsletters for the Geneva Scottish Country Dancing Club while the group could not meet in person.', 58, '774/844/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6406, '1998-09-29 22:00:00+00', '2022-01-20 17:27:59.16292+00', 'Sutherland Reel, The', 'SUTHERLAND REEL', 1, 40, 9999, 1, 3, 42, 432, NULL, '', 57, '840  800  888  888  888', 1, 1, 1, 1, 76);
INSERT INTO 'dance' VALUES (5832, '1998-01-04 23:00:00+00', '2022-01-20 22:20:39.174118+00', 'St Johnstoun Reel, The', 'SAINT JOHNSTOUN REEL', 1, 32, 9999, 1, 3, 42, 11748, '1944-01-01', 'According to *<<https://www.rscdslondon.org.uk/wp-content/uploads/2019/05/Reel-307-electronic.pdf#page=13|The Reel issue 307>>* this dance was devised in a German prisoner of war camp in Hohenfels, Bavaria in 1944.', 31, '800/800/800/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7648, '2001-06-16 22:00:00+00', '2022-01-21 14:30:32.055601+00', 'Clachan Glinnes', 'CLACHAN GLINNES', 3, 32, 9999, 4, 5, NULL, 197, NULL, '', 60, '04048/40408/44448/88888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20634, '2022-01-18 10:15:12.912991+00', '2022-01-21 21:51:18.280018+00', '16th of June, The', '16TH OF JUNE', 2, 32, NULL, 3, 5, 16, 11021, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1404, '2002-03-04 23:00:00+00', '2022-01-21 23:14:00.548734+00', 'Crail Harbour', 'CRAIL HARBOUR', 3, 32, 9999, 2, 3, 18, 159, NULL, 'At the end of the dance, all retain hold of partners'' hand for bow and curtsey.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14679, '2013-01-23 01:30:19.363888+00', '2022-01-22 22:08:58.95307+00', 'Circassian (Big) Circle', 'CIRCASSIAN BIG CIRCLE', 1, 32, NULL, 7, 1, 4, 9998, NULL, 'This dance has no relationship to the dance "Circassian Circle" in Book 1 #3.  



Dance entered using the video of the Edinburgh team in Newcastle 2012 as source; original source unknown - though there are several variations to be found on the web.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13935, '2011-08-22 22:00:00+00', '2022-01-23 12:09:23.837433+00', 'Scotsman''s Journey, A', 'SCOTSMANS JOURNEY', 4, 96, 54, 1, 4, 1, 2203, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14301, '2011-11-04 23:00:00+00', '2022-01-23 18:30:48.616639+00', 'Bonnie Broom, The', 'BONNIE BROOM', 7, 0, NULL, NULL, 51, 3, 2805, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5812, '1997-09-13 22:00:00+00', '2023-02-13 12:25:09.951671+00', 'St Andrew''s Square', 'SAINT ANDREWS SQUARE', 4, 96, 10026, 4, 4, 3, 108, '1988-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1479, '1998-01-12 23:00:00+00', '2022-01-24 17:41:08.676097+00', 'Cumberland Square Eight, The', 'CUMBERLAND SQUARE EIGHT', 1, 64, 9999, 4, 4, 54, 9999, NULL, 'This is a Ceilidh style dance, of "traditional" origin. It is known under a number of names.



A description of this dance was published end of 1939 in the magazine "English Dance and Song" as "The Square Eight" with a subtitle "as danced in Cumberland, near the Scottish Border". You may want to read the scans at <<http://www.contrafusion.co.uk/Dances/EFDS3911-CumberlandSquareEight.html|contrafusion>> for more information.



John Keppie wrote it up in 1992 as "Cumberland Square" in the book "Burns Night in the Annapolis Valley" and states "This is a North Country dance arranged for Scottish Country dancing. Square set of 4 couples with sets lined up across and up-and-down the room so that the sets can intermingle during bars 1-16".  Danced 2 x 64.



More recently in 2017 a dance description entitled "The Cumberland Square Eight" was published in the "Collins Little Book: Scottish Dance".



The dance has also been described as "The Cumberland Square Eight" in the <<http://www.scottishdance.net/ceilidh/dances.html#CumberlandSquareEight|Ceilidh Dance instructions>> on the Grand Chain server.



Furthermore, "The Cumberland Square Eight" is mentioned in a number of books and novels such as "Disaster with the Fiend" by Sheila Lavelle (1988, p.76-83), "Popular Leisure in the Lake Counties" by Lyn Murfin (1990, p.194) or "Annie''s Girl" by Audrey Howard (2002).



From the published names one tends to speculate that while "The Square Eight" might have been an original name, the term "Cumberland" might have been added to distinguish this version danced in Cumberland (near the Scottish border) from other dances like the "Goathland Square Eight" or the "Yorkshire Square Eight". The abbreviation to "Cumberland Square" may be misleading as judging from the above sources it seems unlikely that this dance refers to a location called Cumberland Square.



In <<https://my.strathspey.org/dd/issue/2633/|issue 2633>> Meryl Thomson provides information about the source of the dance:



The dance "Cumberland Quadrille" appears in the handwritten notes of Thomas Murphy c.1830s, now held in the Mitchell LIbrary, Glasgow. The instructions appear to be a precursor of the current dance - Top and Bottom Highland Scottische poussette to opposite places. Sides the same. Top and Bottom repeat Back, Sides repeat back. Top and Bottom rights and lefts turn partners sides Ladies Chain all set to corners, Balance & turn partners, grand Chain half round, promenade to places all waltz.



This was a single quadrille - quadrille being a historic term for a dance for 4 couples in a square set. 

', 62, '80/08/80/08/80/08/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17133, '2016-07-10 09:40:03.563266+00', '2022-01-24 22:36:02.818727+00', 'Remparts de Séville, Les', 'REMPARTS DE SEVILLE', 2, 32, NULL, 1, 3, 42, 11299, '2014-03-01', 'In Act 1 of Bizet’s opera “Carmen” the heroine asks to meet her lover at a tavern by Seville’s city walls (Les Remparts). The dance was written in Seville, Spain.

', 53, '800/822/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17826, '2017-06-22 17:10:52.607962+00', '2022-01-26 01:37:54.078744+00', 'Carol''s Delight', 'CAROLS DELIGHT', 3, 32, NULL, 2, 3, 18, 10907, '2004-05-01', 'For Carol Aitken to mark a significant birthday.', 92, '888/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20641, '2022-01-26 08:50:13.023086+00', '2022-01-26 08:57:44.87331+00', 'Once on the Right, Once on the Left', 'ONCE ON THE RIGHT ONCE ON THE LEFT', 2, 32, NULL, 1, 2, 76, 11509, '2021-11-01', 'On 31st August 2021, I had surgery to strengthen my right leg and prevent the threat of a hip fracture due to a cancer bone lesion. On 3rd September, after a few hours back home, I fell on my left side and broke my left hip. So I went back to hospital and had my left leg operated on to insert an artificial hip.  

It was quite a hard moment to experience, but when I heard I was going to have an artificial hip, I didn’t get too deeply depressed because I remembered Fred DeMarse telling us, when he was teaching a class in Lyon a few years before, that he had two artificial hips. He was dancing in such a light and lively way, giving the feeling of complete ease, that you would never had known he had artificial hips. Therefore I felt quite confident that I could have a normal life and resume Scottish country dancing in the future, and it helped me to put up with what was happening.  

In this dance, you give alternately right hand and left hand, referring to my two operated legs, first on the right side, then on the left side. However I must say each leg was operated only once!', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20513, '2021-10-09 11:10:46.728247+00', '2022-01-26 17:31:25.413146+00', 'Marie-Do and Lucie', 'MARIEDO AND LUCIE', 4, 32, 1, 1, 3, 42, 11509, '2021-08-01', 'Marie-Do and Lucie, mother and daughter, are the two devoted nurses who came daily to my home to take care of me. They were very kind and very friendly, I really appreciated their visits.  

The strathspey time represents their gentleness and kindness. And the movements danced on quick time are like nurses giving injections: needles approach, enter the skin, and then are pulled out. Dancers are invited to sing part of the tune, as my two nurses quite often used to start humming during the treatments.', 55, '888/880/555/555', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20649, '2022-01-27 18:59:52.84483+00', '2022-03-10 18:33:17.398004+00', 'Silvery Tay, The', 'SILVERY TAY', 1, 32, NULL, 1, 4, 2, 12103, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12056, '2005-02-23 23:00:00+00', '2022-01-29 00:29:24.336834+00', 'Air of Beloit, The', 'AIR OF BELOIT', 3, 32, 9999, 1, 2, 76, 3510, '2004-01-01', '', 60, '88/80/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14583, '2012-10-02 09:46:15.695826+00', '2022-01-29 00:32:09.302557+00', 'Animal Magic', 'ANIMAL MAGIC', 1, 64, NULL, 1, 100, 22, 1415, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11685, '2004-02-18 23:00:00+00', '2022-01-29 00:36:46.757668+00', 'Auld Springs Gees nae Price', 'AULD SPRINGS GEES NAE PRICE', 3, 32, 9999, 1, 3, 42, 1350, NULL, 'Note: "Auld Springsll are "Old Tunes".  For Sheila VWlson who knows so many old tunes.', 62, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20642, '2022-01-27 10:03:00.635335+00', '2022-01-29 08:20:32.111734+00', 'Dr Ligon of Marietta', 'DR LIGON OF MARIETTA', 1, 40, NULL, 1, 3, 42, 10568, '2021-01-01', '', 70, '820/888/888/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5222, '1998-11-07 23:00:00+00', '2022-01-29 10:14:48.210247+00', 'Perth Medley, The', 'PERTH MEDLEY', 4, 64, 22, 1, 3, 42, 9998, NULL, '', 54, '880  800  844  800  800  888  844  800', 1, 1, 1, 1, 54);
INSERT INTO 'dance' VALUES (20653, '2022-01-27 19:04:57.149294+00', '2022-09-06 14:16:53.681938+00', 'No Hands Allowed', 'NO HANDS ALLOWED', 1, 32, NULL, 1, 3, 42, 12101, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20643, '2022-01-27 18:50:31.349415+00', '2022-09-06 12:52:24.072555+00', 'Highland Gateway', 'HIGHLAND GATEWAY', 2, 32, NULL, 1, 3, 42, 2748, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20645, '2022-01-27 18:55:08.041139+00', '2022-09-06 12:59:45.602083+00', 'Dancing in Perthshire', 'DANCING IN PERTHSHIRE', 3, 32, NULL, 4, 4, 4, 12101, NULL, '', 84, '6666/6666/7777/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20647, '2022-01-27 18:57:43.533613+00', '2022-09-06 14:03:17.682535+00', 'Perth''s New Normal Jig', 'PERTHS NEW NORMAL JIG', 2, 32, NULL, 1, 4, 1, 12102, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20648, '2022-01-27 18:58:24.265906+00', '2022-09-06 14:05:09.983648+00', 'Branklyn Gardens', 'BRANKLYN GARDENS', 1, 32, NULL, 1, 3, 42, 463, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20650, '2022-01-27 19:00:36.858269+00', '2022-09-06 14:07:58.530101+00', 'Alive at 95 – A Perthshire Jig', 'ALIVE AT 95  A PERTHSHIRE JIG', 2, 32, NULL, 1, 3, 42, 12105, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20651, '2022-01-27 19:01:17.406356+00', '2022-09-06 14:11:03.59004+00', 'Crossing that Bridge for Perth 95', 'CROSSING THAT BRIDGE FOR PERTH 95', 2, 32, NULL, 1, 3, 42, 11872, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20654, '2022-01-27 19:05:49.501602+00', '2022-09-06 14:20:00.939484+00', 'Festival Fun', 'FESTIVAL FUN', 1, 32, NULL, 1, 4, 2, 2664, NULL, 'May be danced as reel or jig.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20644, '2022-01-27 18:52:40.747982+00', '2022-09-06 14:21:28.188989+00', 'Tour Round Highland Perthshire, A', 'TOUR ROUND HIGHLAND PERTHSHIRE', 3, 32, NULL, 1, 3, 42, 12100, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20655, '2022-01-27 19:06:36.028174+00', '2022-09-06 14:33:57.133525+00', 'Ruby Menzies Strathspey, The', 'RUBY MENZIES STRATHSPEY', 3, 32, NULL, 2, 3, 18, 2664, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20656, '2022-01-27 19:08:27.392205+00', '2022-09-06 14:35:41.232349+00', 'Reel for Kitty, A', 'REEL FOR KITTY', 1, 32, NULL, 1, 4, 2, 12106, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20657, '2022-01-27 19:09:05.029999+00', '2022-09-06 14:38:13.411537+00', 'Rubies and Diamonds for Perth', 'RUBIES AND DIAMONDS FOR PERTH', 3, 32, NULL, 1, 3, 42, 12104, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20658, '2022-01-27 19:10:00.381375+00', '2022-09-06 14:42:50.17132+00', 'Perth Celebrates', 'PERTH CELEBRATES', 2, 32, NULL, 4, 4, 4, 12104, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20646, '2022-01-27 18:57:04.075384+00', '2022-09-10 06:25:53.250018+00', 'Perth Reels for Real', 'PERTH REELS FOR REAL', 1, 32, NULL, 1, 100, 2, 12102, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5688, '1998-09-30 22:00:00+00', '2022-01-29 17:20:04.486631+00', 'Rosnor Abbey', 'ROSNOR ABBEY', 2, 40, 9999, 1, 2, 76, 9998, NULL, 'Rosnor Abbey



There is much confusion about the precise execution of bars 1-2 and 9-10.



The older variant is for both pairs (1W+2M and 1M+2W) to turn RH and face each other on the midline, W above M. This pattern is asymmetric; 1W+2M make a 7/8 turn and back, 1M+2W a 5/8 turn and back.  None of the instructions mention 5/8, 7/8 or even mentions the asymmetry



Later instructions specify ½ turn, that would bring each pair to the same diagonal as where they started.



The most recent instructions add an (optional?) ¾ turn. If taken precisely this brings the pairs to the other diagonal.



For the record, here are some official descriptions; there''s plenty of confusion.



My (purple, undated) copy of MMM1 (page 38) has the following original text:  

1-4	1st lady and 2nd man turn each other by the right hand for 2 skip change of step; facing up and down in the middle of the dance they set to each other.  

5-8	They turn each  other with left hands back to places, and set.  

9-16	1st man and 2nd lady do the same.  



The 1992 Manual has a note:  

Bars   1-4  1st woman and 2nd man turn to finish with 1st woman facing down and 2nd man facing up.  

Bars 9-12  1st man and 2nd woman turn to finish with 1st man facing up and 2nd woman facing down.  



The 2005 Manual does not have a note for the dance.



The 2013 Manual has a note:  

Bars 1-2  1st woman and 2nd man turn three-quarters to finish with 1st woman facing down and 2nd man facing up.  In earlier versions of these bars, 1st woman and 2nd man turn half way.  

Bars 9-10  1st man and 2nd woman turn three-quarters to finish with 1st man facing up and 2nd woman facing down. Alternatively they may turn half way.  



TACnotes 4th ed 1995 says:  

1-2  1st woman & 2nd man three-quarters turn to finish with woman facing down and man up.  

9-10  1st man and 2nd woman turn as bars 1-2.  



TACnotes 5th ed 2008 says:  

1-2  NB: In 2007 edition this is a HALF turn to face each other in middle of the set.  

9-10  2nd woman and1st man turn as bars 1-2.  



Read more: on the RSCDS website the Technique Panel has published a statement at <<https://www.rscds.org/learn/resources-dancers/technique-advisory-panel-dances>>.

', 48, '44  44  80  88  88', 0, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (5708, '1999-10-27 22:00:00+00', '2022-01-29 17:29:08.368895+00', 'Round about Hullachan', 'ROUND ABOUT HULLACHAN', 1, 32, 9999, 5, 1, NULL, 9998, NULL, '', 100, '8  8  8  8', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3561, '1998-09-30 22:00:00+00', '2022-01-29 17:32:42.620923+00', 'Russe, La', 'RUSSE', 1, 64, 9999, 4, 4, 46, 9998, NULL, '"As danced in Forfar"', 69, '8888  8888  8000  8000  8080  8080  8888  8888', 0, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (5802, '2002-08-26 22:00:00+00', '2022-01-29 17:36:33.600308+00', 'St Andrew''s Fair', 'SAINT ANDREWS FAIR', 2, 32, 9999, 1, 3, 42, 146, '1980-01-01', 'The spelling "Andrew''s" in the dance name shows that it refers to a Fair on St. Andrew''s Day (November 30th), and not to a fair in the town of St. Andrews.

', 62, '800/888/888/888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (5804, '1999-10-04 22:00:00+00', '2022-01-29 17:37:40.704504+00', 'St Andrews Gardens', 'SAINT ANDREWS GARDENS', 2, 32, 9999, 1, 3, 42, 152, '1986-01-01', '', 47, '880  833  833  844', 0, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (11398, '2003-07-06 22:00:00+00', '2022-01-29 17:40:47.997297+00', 'Sands of Forvie, The', 'SANDS OF FORVIE', 3, 32, 9999, 2, 3, 17, 146, NULL, 'In memory of Margaret Kendall, dancer, teacher and artist.  Margeret loved Forvie in Aberdeenshire.  This nature reserve has a vast expanse of sand dunes, beneath which lies a village buried in a sandstorm over 400 years ado.', 71, '880  855  855  808', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (5808, '1998-09-29 22:00:00+00', '2022-11-12 12:15:20.580572+00', 'St Andrew''s of Brampton', 'SAINT ANDREWS OF BRAMPTON', 1, 32, 9999, 1, 4, 2, 440, NULL, '', 75, '8008  8888  8888  8008', 1, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (7511, '1998-10-18 22:00:00+00', '2022-01-29 17:47:23.702736+00', 'Scottish Accent Reel, The', 'SCOTTISH ACCENT REEL', 1, 32, 9999, 1, 3, 42, 394, '1996-01-01', '', 56, '880  800  888  888', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (8289, '1998-01-13 23:00:00+00', '2022-01-29 17:49:08.167867+00', 'Scottish Butterfly', 'SCOTTISH BUTTERFLY', 1, 64, 9999, 4, 4, 4, 2018, NULL, '', 62, '8888/8080/0808/8080/0808/8080/0808/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5992, '1998-07-08 22:00:00+00', '2022-01-29 17:52:03.366502+00', 'Selkie Wife, The', 'SELKIE WIFE', 3, 32, 9999, 1, 114, 2, 313, NULL, '', 88, '8888  8888  0880  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (5995, '1997-09-13 22:00:00+00', '2022-01-29 17:52:44.987346+00', 'Selkirk Reel', 'SELKIRK REEL', 1, 32, 9999, 1, 3, 42, 705, NULL, 'The notes say this is a ''take-off'' of "<<ddd:Jessie''s Hornpipe#3246>>" with the same suggested music.', 37, '800  800  880  880', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (6012, '1998-07-08 22:00:00+00', '2022-01-29 20:47:18.520983+00', 'Seven Thistles', 'SEVEN THISTLES', 1, 32, 9999, 1, 100, 2, 13, NULL, '', 81, '8008/8448/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19555, '2019-08-26 12:29:19.772557+00', '2022-01-29 20:53:17.76285+00', 'Shy Lassie, The', 'SHY LASSIE', 2, 32, 9999, 1, 3, 42, 10786, '2012-01-01', 'This dance was devised by Greg Reznick so that Melanie Howard, a delightful young dancer, would have a dance to go with her tune.', 50, '844/808/844/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12805, '2006-07-02 22:00:00+00', '2022-01-29 21:16:01.540495+00', 'South Street Harborne', 'SOUTH STREET HARBORNE', 2, 32, 9999, 1, 3, 42, 1275, NULL, 'The Harborne class met at South Street Methodist Church Hall for seventeen years.', 63, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8709, '2001-05-03 22:00:00+00', '2022-01-29 21:18:54.769734+00', 'Spiffin''', 'SPIFFIN', 2, 32, 9999, 4, 5, 16, 2121, '1992-12-25', 'The dance was devised on December 25, 1992, by ten dancers, namely David and Avril Quarrie, Suzie Kinsman, Ingrid Kendall, Sue Eisley, John Collins, Elaine Brunken, Mary Brown, and Mel and Ellie Briscoe at Christmas at the Spiff Inn, Mt. Sidney, VA, USA.



"Spiffin''" is a British expression meaning everything done just right. 



Description revised April 8, 1993.', 53, '80808/04048/04048/40008', 1, 1, 1, 1, 42);
INSERT INTO 'dance' VALUES (19904, '2020-03-23 23:13:17.004326+00', '2022-01-29 21:29:52.888885+00', 'Swirling Stream, The', 'SWIRLING STREAM', 1, 32, NULL, 1, 100, 2, 10890, NULL, '', 72, '8228/8228/8228/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9110, '2001-11-21 23:00:00+00', '2022-10-02 12:40:39.798831+00', 'Royal Deeside Railway, The', 'ROYAL DEESIDE RAILWAY', 1, 32, 9999, 1, 3, 42, 9, '1987-01-01', 'The Pilling diagram in the 8th edition is in error, see the supplement to the 8th edition for the correct one.', 38, '820  820  804  844', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (19290, '2019-05-06 22:29:39.839238+00', '2022-01-29 22:15:07.927925+00', 'Wining and Dining', 'WINING AND DINING', 2, 32, NULL, 3, 5, 7, 11807, NULL, 'To celebrate the occasion of Sara Andrews’ 50th birthday. Bars 13-20 are very slightly borrowed from the Aurora classic, the Elephant Stampede.

', 60, '80800/84884/88888/80800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16792, '2015-10-14 15:53:16.101961+00', '2022-01-30 18:40:36.392292+00', 'Viking''s Sheepskin, The', 'VIKINGS SHEEPSKIN', 1, 48, 9999, 2, 3, 17, 2682, '2014-05-27', 'Notes from The Johnsonville Collection:



Devised 27th May 2014. 

The Sheepskin Hey is discussed in the last dance. There were two competing versions of the dance and I have recorded one as MOGGIE AND THE FISH, and one as here. The name comes from the Viking Ball, as discussed above, and began with a group of men marching as Vikings. All were wearing sheepkin jackets over their costumes. Again, the recommended tune is “Miss Gayton’s Hornpipe”. A suitable recording is “The Sound of Harris” by Andrew Rankine and his Band.



Given to Charlotte Williams and the group at Eastbourne, the former convincing me to keep this version.', 61, '444/444/444/444/448/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10578, '2002-09-25 22:00:00+00', '2022-01-30 18:49:49.579151+00', 'Two Up, Two Down', 'TWO UP TWO DOWN', 3, 32, 9999, 1, 4, 81, 175, NULL, '"For Pat Batt and all the other two-sex Scottish Dancers who have to dance on either side of the set.  The dance was inspired by Pat''s poem "The Ladies Man".  



See https://www.rscdslondon.org.uk/pat-batt-poem-the-ladies-man/



Note: there is a misprint in the description published in the 5th Carnforth Collection in bars 25-32 - it should say 3rd & 2nd couples, and at the same time 1st and 4th couples pass right shoulders to start.', 87, '8880/8880/8888/8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (6798, '2001-11-22 23:00:00+00', '2022-01-30 19:03:15.010107+00', 'Twelvesome Reel', 'TWELVESOME REEL', 1, 32, 9999, 4, 6, 79, 313, NULL, 'For Jean and Ian Campbell', 83, '888888  808088  080888  888888', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (16939, '2016-05-01 22:42:09.405396+00', '2022-01-30 20:17:58.824435+00', 'Tuolumne Tournee', 'TUOLUMNE TOURNEE', 3, 32, NULL, 1, 4, 2, 11250, '1994-06-01', 'The dance was written in summer of 1994 after a weeklong stay at Tuolumne (TWALL'' uh mee) Lodge in Yosemite National Park with a group of Scottish Country Dancers. On one of our daily hikes on the twisting and turning trails, Linda Boucher playfully suggested we should write a dance with the tournee figure in it. Hence this dance.', 75, '8008/8888/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17848, '2017-06-22 17:49:22.465023+00', '2022-01-30 20:26:10.575085+00', 'Three Rough Diamonds', 'THREE ROUGH DIAMONDS', 2, 32, NULL, 1, 3, 42, 10907, NULL, 'Dance for Three Rough Diamonds - Ossie Draper, Bob Morrison and Bernie Platzer, each celebrating their 75th year of enjoyment.  





Note by SCDDB co-editor Eric Ferguson, 1 october 2019.  The instructions in the book [The Dancing Brolga Collection of SC Dances, Volume 3] are difficult to understand, as the "set and rotate for three couples" is quite different from the currently standard version. The e-crib explains the formation more precisely; it is non-progressive, but all change sides,', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18951, '2018-10-12 20:07:30.279414+00', '2022-01-30 20:53:34.900523+00', 'Tamburin Jingles', 'TAMBURIN JINGLES', 1, 40, NULL, 4, 4, 1, 11728, '2006-01-01', '', 85, '8888/6666/4444/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13582, '2010-08-07 22:00:00+00', '2022-02-01 16:37:54.550712+00', 'Valentine, The', 'VALENTINE', 3, 32, NULL, 1, 3, 42, 463, '2008-02-14', 'Written for Fiona Mackie on St Valentine''s Day, 14 February 2008.



Linda Gaul, responding to queries about [25-28], wrote (p6 of the October 2009 edition of Scottish Country Dancer): 



"The original instructions  for bars 25-26 state “3rd, 1st and 2nd couples, giving right hands, turn half way round and remain in the middle”.  That is correct.   The only error was that the “all facing up” instruction got put at the end of bars 25-26 instead of 27-28.  



I often say to my class that at the end of bar 28, you can get a kiss in, if you wish. You couldn’t do that if you were setting near the sidelines!  If the dancers in the videos are shown near the sidelines they are wrong!



', 56, '800  880  888  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (17964, '2017-09-25 20:43:07.179619+00', '2022-02-01 16:49:03.010419+00', 'Golden Gala Tangle', 'GOLDEN GALA TANGLE', 3, 32, NULL, 2, 3, 17, 10568, '2016-11-01', '', 71, '880/888/822/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9862, '2002-05-06 22:00:00+00', '2022-02-01 20:43:39.364241+00', 'Gypsy Dreams', 'GYPSY DREAMS', 3, 32, 9999, 1, 2, 76, 2677, NULL, 'Music: A smooth strathspey for example: »Birks of Invermay« by Tersipchore', 67, '86  88  88  88', 1, 1, 1, 1, 96);
INSERT INTO 'dance' VALUES (10793, '2002-08-25 22:00:00+00', '2022-02-01 22:46:47.279518+00', 'David Russell Hall', 'DAVID RUSSELL HALL', 1, 40, 9999, 1, 3, 42, 3188, NULL, '', 80, '800  888  422  888  422  888', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (15341, '2014-02-15 21:23:09.591581+00', '2022-02-02 03:04:07.23228+00', 'Amazing Grace Strathspey', 'AMAZING GRACE STRATHSPEY', 3, 32, NULL, 1, 4, 1, 3717, '2007-02-24', 'Devised for Rene Johnstone, teacher at the Malaga Class on her 85th birthday.  Well known in the Dundee area she spent 30 years in Spain and then returned to Broughty Ferry', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14443, '2012-06-12 13:21:26.617478+00', '2022-02-15 15:35:47.923547+00', 'Foundling, The', 'FOUNDLING', 3, 32, NULL, 2, 3, 17, 10620, '2011-03-01', 'From the dance description:  

Ashlyns School, Berkhamsted, in whose splendid hall Berkhamsted Strathspey and Reel Club''s Annual Highland Ball has been held for many years, was originally The Foundling Hospital and as such it remained for 20 years. Founded by retired sea captain Thomas Coram in 1739 The London Foundling Hospital was originally in Bloomsbury, until in 1926 it temporarily moved to Redhill and then in 1935 after its completion to Ashlyns. The club member to whom this dance is dedicated, the late Lorna Brown, was a foundling at Ashlyns.', 91, '888/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5455, '1998-07-08 22:00:00+00', '2022-02-02 18:44:18.069523+00', 'Railway Man, The', 'RAILWAY MAN', 3, 32, 9999, 1, 4, 2, 1102, NULL, 'The original book says that in bars 13-16 1st & 4th couples should turn one and a quarter then cast ending on opposite sides. It is assumed this is a mistake as to get to opposite sides they just need to turn three quarters.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14446, '2012-06-12 13:29:06.897559+00', '2022-02-15 15:38:25.468706+00', 'Chiltern Chase', 'CHILTERN CHASE', 2, 40, NULL, 4, 4, 13, 3328, '2011-02-01', 'From the dance description:  

The dance name comes from walks in the Chiltern Hills and the dance reflects a time when a group was walking in an area of many interlocking paths.  After negotiating a stile one might walk with a new companion.', 80, '4444/8888/6666/8484/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2386, '1998-01-05 23:00:00+00', '2022-02-02 23:24:24.294619+00', 'Gallivanter''s Reel', 'GALLIVANTERS REEL', 1, 32, 9999, 1, 3, 42, 48, NULL, '', 50, '822/888/810/810', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14441, '2012-06-12 13:15:27.138979+00', '2022-02-15 15:31:04.2653+00', 'Sixtieth Celebrations', 'SIXTIETH CELEBRATIONS', 2, 32, NULL, 1, 3, 42, 10619, '2011-02-01', 'From the dance description: 

The Berkhamsted Strathspey and Reel Club celebrate the sixtieth anniversary of its formation in 2012 and coincidentally Jeremy and Anne Newton also celebrate their sixtieth birthdays in 2012.', 50, '880/822/822/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14447, '2012-06-12 13:30:47.962099+00', '2022-02-15 15:39:04.557954+00', 'Ladies of Berkeau, The', 'LADIES OF BERKEAU', 3, 32, NULL, 1, 3, 42, 10623, '2009-01-01', 'From the dance description:  

The dance was devised in June 2009 by Jon Allen-Friend of Glenview Scottish Country Dancers, Toronto, who is a regular visitor to the Berkhamsted Strathspey & Reel Club''s dances. The two clubs are twinned. Berkhamsted is sometimes called ''Berko'' for short, and the spelling Berkeau in the dance name is a play on the French-Canadian connection.', 56, '888/888/800/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14651, '2013-01-05 09:11:33.17609+00', '2022-04-26 01:19:37.112927+00', 'Lost Thread, The', 'LOST THREAD', 3, 40, NULL, 2, 3, 17, 515, '2009-03-01', 'Written for the retirement of a prison officer, colloquially called “a screw” (which has a thread, of course). ', 80, '800  888  888  888  808', 1, 1, 1, 0, 80);
INSERT INTO 'dance' VALUES (20831, '2022-05-14 20:08:28.81441+00', '2022-05-14 20:08:28.81441+00', 'Fiona Stapleton''s Strathspey', 'FIONA STAPLETONS STRATHSPEY', 3, 32, NULL, 1, 4, 2, 99, '2010-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20541, '2021-11-03 13:42:02.265602+00', '2023-01-13 23:20:54.125092+00', 'Genteel Weasel, The', 'GENTEEL WEASEL', 3, 32, NULL, 1, 3, 42, 11035, '2021-01-01', '', 67, '844/888/688/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9758, '2001-05-03 22:00:00+00', '2022-02-03 18:30:34.232472+00', 'Pretty River Strathspey, The', 'PRETTY RIVER STRATHSPEY', 3, 32, 9999, 2, 3, 4, 2816, '1994-01-01', 'Pretty River Strathspey - Background



Dancers in the Toronto area will be saddened to learn that my father, Gordon McHaffie, passed away on Christmas Day 2000 at the age of 96. He had been in failing health for some time.



Gordon arrived in Canada from England in 1950, and shortly thereafter became one of the small group of early enthusiasts in Toronto to enjoy Scottish Country dancing, both at Rosedale Presbyterian Church and at the Fort York Armouries. He played a role in persuading a number of Toronto dancers of the day that they did not need bagpipes to do Scottish Country Dancing -- in some military circles that had been considered the normal or even the proper dancing music.



His dancing career spanned over 85 years. His earliest memory of dancing was learning the Eightsome Reel, as a child of six, with his playmates, while his mother played the piano. He continued dancing

into his nineties.  He danced with The Glenview Group from its inception and was made a Life Member of that group. After his retirement in 1969, he danced with the small group in N Ottawa, near his home in the Pretty River Valley, near Collingwood.



For his 90th birthday, I wrote the dance, “The Pretty River Strathspey.”  Those who would like to remember and celebrate his life might like to try the dance, which has not been published before.  The instructions follow. It can be danced to any pastoral style 3 x 32 bar Strathspey, but the tune for the dance is really Stan Hamilton''s, “Compliments to Gordon McHaffie”, which is so far unpublished, but was Stan''s own message of congratulation to Gordon.  

', 83, '800/888/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20659, '2022-02-03 23:45:11.329195+00', '2022-02-03 23:59:13.373577+00', 'Petra''s Frolic', 'PETRAS FROLIC', 2, 32, NULL, 1, 4, 1, 12110, NULL, 'Source: <<https://youtu.be/6cYox6TvmRA|youtube video>>.', 66, '8008/8888/8008/8444', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19224, '2019-03-05 22:06:54.126814+00', '2022-04-26 01:42:50.880785+00', 'Westbury Days', 'WESTBURY DAYS', 3, 40, NULL, 2, 3, 17, 11795, NULL, '', 73, '880/800/888/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7654, '2001-11-21 23:00:00+00', '2022-02-05 11:25:47.86151+00', 'Connie''s Jig', 'CONNIES JIG', 2, 48, 9999, 1, 3, 42, 793, NULL, '"Written in fond memory of Connie Grainger, past president of the Hereford Branch."



<<https://my.strathspey.org/dd/issue/2718/|Additional information>> from the deviser:



Connie was a traditionalist and disliked the many new dance sequences which complicated her final years'' dancing pleasure as she could *[not?]* get her head around many of them. This dance uses no ''new'' sequences. Moreover, when she had to stop dancing through ill-health, she still got pleasure from watching, and laughing when mistakes were made; one unusual move in the dance provides many opportunities for such laughter.

', 58, '800  880  808  888  888  888', 1, 1, 1, 1, 77);
INSERT INTO 'dance' VALUES (4026, '1997-09-08 22:00:00+00', '2022-02-05 23:57:12.561422+00', 'MacGregors Gathering', 'MACGREGORS GATHERING', 3, 32, 9999, 5, 2, 76, 181, '1986-01-01', 'In the original book, this dance is named without an apostrophe  on the page for the dance, but with an apostrophe in the table of contents. The latter is added as a spelling alias.', 100, '88  88  88  88', 0, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (11525, '2003-10-02 22:00:00+00', '2022-02-08 13:30:09.932931+00', 'Love Spoon, The', 'LOVE SPOON', 3, 32, 9999, 2, 3, 17, 3384, NULL, '', 83, '888/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13470, '2009-11-17 23:00:00+00', '2022-02-08 14:15:29.813123+00', 'Figure It Out', 'FIGURE IT OUT', 1, 32, NULL, 2, 3, 17, 146, NULL, '', 50, '840/880/888/804', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17608, '2017-02-16 09:00:34.76138+00', '2022-02-08 15:00:22.900387+00', 'Striking Gold', 'STRIKING GOLD', 2, 32, NULL, 2, 3, 17, 1582, '2015-04-01', '', 67, '880/880/808/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6918, '1997-04-03 22:00:00+00', '2022-02-09 00:27:40.833663+00', 'Wandering Willie', 'WANDERING WILLIE', 2, 32, 9999, 1, 2, NULL, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20661, '2022-02-07 10:41:01.912017+00', '2022-02-08 21:31:16.312882+00', 'Barbara''s Favourites', 'BARBARAS FAVOURITES', 3, 32, NULL, 1, 3, 42, 793, '2022-01-01', 'Devised in memory of the deviser''s wife and dancing partner for 64 years, Barbara, the dance is constructed from some of her favourite sequences.



Muriel Johnstone has made a recording of her music for the dance. Apart from the original tune for this dance (<<ddt:Barbara''s Favourites>>) it also includes <<ddt:Dean Brig of Edinburgh, The>>, <<ddt:Ceilidh Umbrella, The>> and Atholl Palace.



The original instructions can be found in <<https://my.strathspey.org/dd/issue/2720/>>.



Less able/less energetic dancers, who find the return to own sides via passing right shoulders in bars 23 - 24 too demanding, may turn right hands.', 47, '800/888/822/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9250, '2000-01-16 23:00:00+00', '2022-02-08 23:23:11.748047+00', 'Pam''s People', 'PAMS PEOPLE', 1, 40, 9999, 1, 3, 42, 3590, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20664, '2022-02-11 11:04:11.008894+00', '2022-02-11 11:04:11.008894+00', 'My Best Friend, Meo', 'MY BEST FRIEND MEO', 3, 32, NULL, 1, 4, 1, 12112, '2012-05-18', 'Written for Korbkarn “Meo” Hanutsaha, 10/16/1952-10/21/2011, a long-time Scottish Country Dancer, RSCDS member, and teacher for her benefit dance held May 18, 2012', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15602, '2014-09-03 14:26:20.786744+00', '2022-02-13 16:59:16.47684+00', 'Almo Rant, The', 'ALMO RANT', 1, 48, NULL, 4, 4, 14, 12108, '1957-01-01', 'Written by Gill Russell and Rita Marlow on the occasion of the golden wedding of Alister and Molly Reid.  This was in 1957 in Surrey, UK. The dance name is thus derived from their combined names.



The reel is 2 x 48.', 83, '8888/8080/0808/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20663, '2022-02-10 09:23:29.897694+00', '2022-02-11 10:16:50.320558+00', 'Ambulance Drivers'' Choreography, The', 'AMBULANCE DRIVERS CHOREOGRAPHY', 1, 32, NULL, 1, 3, 42, 11509, '2021-07-01', 'During the months I was ill, I was driven by ambulance quite a few times. Once I was struck by the well-coordinated, accurate and mirroring movements of the ambulance drivers as they pushed the stretcher I was lying on into the ambulance and secured it. I found it interesting and beautiful and this title occurred to me. Then I wanted to devise a dance containing only mirror movements to refer to this particular moment.', 53, '800/888/844/848', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15014, '2013-07-31 19:55:12.904803+00', '2022-02-14 00:01:39.966116+00', 'You can Count on the Music', 'YOU CAN COUNT ON THE MUSIC', 2, 32, NULL, 2, 3, 17, 10568, '2012-08-01', '', 83, '888/844/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14449, '2012-06-12 13:34:14.07318+00', '2022-02-15 15:40:46.630152+00', 'Trip to Perth', 'TRIP TO PERTH', 2, 32, NULL, 2, 3, 17, 10625, '2010-11-01', 'From the dance description:  

Devised by Jane Rose, current President of the Berkhamsted Strathspey and Reel Club, with friends Maureen Ainsworth, Jon Allen-Friend and Stephen Webb while on a trip to Perth for the AGM of the RSCDS in November 2010.', 79, '800/888/848/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8635, '1998-11-01 23:00:00+00', '2022-02-14 18:08:20.605615+00', 'Valentine for Vanessa, A', 'VALENTINE FOR VANESSA', 3, 32, 9999, 1, 3, 42, 2071, '1988-01-01', 'Devised by Oberdan Otto for his "dear wife Vanessa".



Danced on 14 February 2015 in Schlüchtern-Vollmerz.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5307, '2000-12-05 23:00:00+00', '2022-02-15 13:54:46.190916+00', 'Polesden Lacey', 'POLESDEN LACEY', 3, 32, 9999, 2, 3, 18, 785, '1990-01-01', '', 83, '888  888  844  808', 1, 1, 0, 1, 83);
INSERT INTO 'dance' VALUES (17971, '2017-09-25 20:53:40.094425+00', '2022-02-21 09:05:33.108417+00', 'Meet Your Corners', 'MEET YOUR CORNERS', 1, 32, NULL, 2, 3, 17, 10568, '2017-02-01', '', 83, '844/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20832, '2022-05-14 20:15:36.649457+00', '2022-05-14 20:15:36.649457+00', 'Luke Brady''s Reel', 'LUKE BRADYS REEL', 1, 32, NULL, 1, 4, 2, 99, '2014-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20844, '2022-05-15 20:43:45.111752+00', '2022-05-15 20:43:45.111752+00', 'Annette Musker''s Hornpipe', 'ANNETTE MUSKERS HORNPIPE', 1, 32, NULL, 1, 4, 2, 99, '2020-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20662, '2022-02-07 18:06:52.762306+00', '2022-12-15 23:36:12.665422+00', 'New Cumberland Reel, The', 'NEW CUMBERLAND REEL', 2, 32, NULL, 1, 4, 1, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14450, '2012-06-12 13:35:32.021949+00', '2022-02-15 15:41:33.844163+00', 'Diamond Reflections', 'DIAMOND REFLECTIONS', 3, 32, NULL, 1, 2, 76, 2197, '2011-04-01', 'From the dance description:  

Like the reflections from light on the diagonals of a cut diamond, Scottish country dancing brings many special memories over the years upon which to reflect.', 60, '88/80/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14451, '2012-06-12 13:36:57.559627+00', '2022-02-15 15:43:12.760383+00', 'Dulce in Dacorum est', 'DULCE IN DACORUM EST', 1, 40, NULL, 1, 100, 2, 10620, '2011-04-01', 'From the dance description:  

''Dacorum'' was the Roman name for the Berkhamsted area. The latin title translates: ''It is Sweet in Dacorum'', ''Dulce'' is pronounced ''Dul-chay'',', 95, '8448/8888/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14452, '2012-06-12 13:40:35.031806+00', '2022-02-15 15:44:04.391305+00', 'Lightning at Dawn', 'LIGHTNING AT DAWN', 2, 32, NULL, 1, 4, 1, 10627, '2011-03-01', 'From the dance description:  

Lightning at dawn is always exciting. ''Lightning'' also happens to be the name of Ann and lan''s whippet, who greets the day with energy and enthusiasm.', 62, '8880/8088/8260/8422', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14453, '2012-06-12 13:42:11.362434+00', '2022-02-15 15:45:37.353444+00', 'Silver Roses', 'SILVER ROSES', 4, 40, 10, 4, 4, 1, 2197, '2008-09-01', 'According to the dance description, Ken Martlew devised the dance for Brian and Jane Rose on celebrating their Silver Wedding on 3rd September 2008.', 70, '6666/6666/0808/8080/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12368, '2005-04-27 22:00:00+00', '2022-02-15 15:47:42.284036+00', 'Our Friend Robert', 'OUR FRIEND ROBERT', 1, 32, 9999, 1, 3, 42, 3325, '2004-01-01', 'From the dance description:  

This dance was devised for Stephen’s good friend Robert Bateson to celebrate his 70th birthday on 9 January 2004 as a thank you to him for many years of friendship. The dance includes figures particularly liked by Robert.', 56, '822/888/844/866', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14458, '2012-06-12 13:50:45.01216+00', '2022-02-15 15:53:44.481691+00', 'Other Left, The', 'OTHER LEFT', 2, 32, NULL, 1, 100, 2, 10629, '2005-08-01', 'From the dance description:  

Teachers are sometimes heard saying ''the other left'' to dancers!', 75, '6666  8448  8888  8008', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14459, '2012-06-12 13:52:42.405007+00', '2022-02-15 15:55:32.723567+00', 'Monday Welcome', 'MONDAY WELCOME', 1, 32, NULL, 1, 3, 42, 10630, '2010-12-01', 'From the dance description:  

Berkhamsted Strathspey and Reel Club hold an advanced class on Mondays, which Tom and Betty Arrol [the deviser of the dance] attend.', 56, '880/808/880/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16517, '2015-07-26 10:23:35.538347+00', '2022-02-15 20:24:03.480858+00', 'Gentle Crossing, The', 'GENTLE CROSSING', 3, 32, NULL, 1, 3, 42, 3355, '2013-01-01', 'Devised on the ferry crossing from Germany to Switzerland', 63, '880/888/888/088', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3609, '1998-09-30 22:00:00+00', '2022-02-17 16:27:24.528895+00', 'Lady Home''s Jig', 'LADY HOMES JIG', 2, 32, 9999, 1, 3, 42, 9998, NULL, 'The instructions in MMM1 2nd edition, revised 1966 specify:



17-20 1st couple cross giving right hand and cast off to second place.  2nd couple step up on bars 19-20.



21-24 1st couple giving left hand cross back to own sides and cast off around 3rd couple to meet partner, and lead up to face first corners.



TAC notes suggests phrasing of bars 17-24 should be: cross and cast (3), cross and cast (3), lead to corners (2).



According to strathspey list thread <<https://www.strathspey.org/lists/strathspey@strathspey.org/t/63976/>> the name is pronounced ''Hume'' (Hyoom). See also <<https://www.clan-home.org/history-of-the-homes/>>.', 53, '888  888  800  822', 0, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (20318, '2021-04-14 10:48:57.118568+00', '2022-02-16 08:25:26.12725+00', 'Chambéry Blues', 'CHAMBERY BLUES', 1, 40, NULL, 1, 3, 42, 11912, '2020-06-01', 'This dance was created to combat the sadness and the frustration we all felt when we had to cancel our international Easter weekend planned in Chambéry in April 2020. Dedicated to the invited team: Ron Wallace, Keith Smith and James Gray, to the Paris Band’s musicians and to the Chambéry Committee.', 58, '862/844/866/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20666, '2022-02-16 14:52:54.930937+00', '2022-02-17 00:11:28.546864+00', 'Whole of the Moon, The', 'WHOLE OF THE MOON', 4, 64, 17, 1, 4, 2, 335, '2021-09-18', 'Devised in memory of Pam Hood. For further details see <<https://mailchi.mp/728d9b8bae62/the-quaich-committee-first-draft-10543548?e=[UNIQID]>> (issue 19, December 2021, of the RSCDS Leicester magazine <<https://www.rscdsleicester.org.uk/the-quaich-archive/|The Quaich>>).', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1883, '1999-08-06 22:00:00+00', '2022-02-17 16:27:41.20829+00', 'Earl of Home, The', 'EARL OF HOME', 3, 32, 9999, 1, 4, 52, 1517, NULL, 'This dance has the progression of a 3-couple dance in a 4-couple set, and is danced eight times through.  However, as all four couples dance bars 1-8 it is technically a 4-couple dance.



According to strathspey list thread <<https://www.strathspey.org/lists/strathspey@strathspey.org/t/63976/>> the name is pronounced ''Hume'' (Hyoom). See also <<https://www.clan-home.org/history-of-the-homes/>>.

', 59, '8888  8000  8220  8880', 1, 1, 1, 1, 59);
INSERT INTO 'dance' VALUES (20667, '2022-02-17 09:04:59.452266+00', '2022-02-17 17:51:52.194358+00', 'Herons of Pen Mané', 'HERONS OF PEN MANE', 3, 32, NULL, 2, 3, 17, 12113, '2020-06-01', 'Pen Mané marsh is an ornithological natural park on the East side of Lorient. Devised by Clementine Job & Anne Dejean', 75, '808/880/808/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20350, '2021-06-16 09:01:21.121208+00', '2022-02-18 12:55:15.589819+00', 'Wild Ducks of Pen Mané', 'WILD DUCKS OF PEN MANE', 3, 32, NULL, 1, 3, 42, 12114, '2021-06-09', 'Pen Mané marsh is an ornithological natural park on the East side of Lorient.', 56, '800/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20668, '2022-02-18 21:21:42.061758+00', '2022-02-18 21:49:56.332643+00', 'Sweethearting Nightshade', 'SWEETHEARTING NIGHTSHADE', 1, 32, NULL, 1, 3, 42, 12115, '2022-02-01', 'The title of this dance is an anagram of the title of the dance which inspired it, loaned it most of its formations, and music.', 59, '844/844/866/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11562, '2003-10-30 23:00:00+00', '2022-02-19 22:56:23.210319+00', 'Houseboat, The', 'HOUSEBOAT', 3, 32, 9999, 1, 3, 42, 1445, NULL, 'Written in remembrance to our friend Paul Etty who used to live in a houseboat.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19980, '2020-05-23 09:53:16.377985+00', '2022-02-20 16:33:27.574327+00', 'Magic Roundabout, The', 'MAGIC ROUNDABOUT', 3, 32, NULL, 1, 2, 76, 10912, NULL, '', 62, '86/88/88/84', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1960, '1998-04-08 22:00:00+00', '2022-02-20 17:43:52.119537+00', 'Ellenbrook', 'ELLENBROOK', 1, 32, 9999, 1, 3, 42, 108, '1977-01-01', 'The original books says this dance is

"for Western Australia for the 150th Anniversary of the founding of the State

... in response to a request from Mary Mackenzie."



Ellenbrook, the tune by Ian Powrie, was the name of Ian''s house in Western Australia.

', 53, '880/822/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3128, '1997-04-03 22:00:00+00', '2022-03-04 11:41:44.376846+00', 'Irish Girls', 'IRISH GIRLS', 2, 32, 9999, 1, 3, 42, 270, NULL, '', 53, '844/888/844/822', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20833, '2022-05-14 22:19:28.082682+00', '2022-05-14 22:19:28.082682+00', 'Creetown Lassie', 'CREETOWN LASSIE', 3, 32, NULL, 2, 3, 17, 99, '1989-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20845, '2022-05-15 20:47:54.536719+00', '2022-05-23 16:34:27.769171+00', 'Elizabeth Lye''s Strathspey', 'ELIZABETH LYES STRATHSPEY', 3, 32, NULL, 1, 4, 2, 99, '2020-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14796, '2013-04-07 20:09:19.797477+00', '2022-07-01 13:34:11.541299+00', 'From Shore to Shore', 'FROM SHORE TO SHORE', 2, 32, NULL, 1, 3, 42, 3183, '2010-04-01', '', 55, '888/800/844/688', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10563, '2002-05-12 22:00:00+00', '2022-07-03 19:51:17.036901+00', 'Lady of the Dance', 'LADY OF THE DANCE', 1, 40, 9999, 1, 3, 42, 228, NULL, '', 55, '800/844/844/888/888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (20934, '2022-07-05 22:56:48.531477+00', '2022-07-05 22:56:48.531477+00', 'Last Electrichka, The', 'LAST ELECTRICHKA', 2, 40, NULL, 1, 3, 42, 12164, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20939, '2022-07-06 23:16:15.149839+00', '2022-07-06 23:16:15.149839+00', 'Moscow Rings, The', 'MOSCOW RINGS', 4, 64, 17, 4, 119, 13, 12119, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17410, '2016-10-16 16:22:46.293381+00', '2022-09-19 04:44:56.174962+00', 'Alec''s Legacy', 'ALECS LEGACY', 3, 32, 9999, 1, 3, 42, 11221, '2015-11-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20574, '2021-12-04 23:21:59.43892+00', '2022-02-21 09:31:20.042076+00', 'Slowly But Surely', 'SLOWLY BUT SURELY', 3, 32, NULL, 2, 3, 17, 11509, '2021-06-01', 'When I got diagnosed with cancer, the news spread quickly among the scd groups of the surrounding area, and I received a lot of lovely supporting messages from scd dancers. Also, a friend of mine told me to imagine myself dancing once I had recovered, and before that, dancing a not too energetic dance once I had only partly recovered, so that my brain would help me recover. All this gave me the idea to devise new dances and this was the first one, aimed for the period on the way to recovery. I sent the instructions to all those who had written to me, and I received videos from three groups dancing this dance (Méaudre, Grenoble and Lyon), and it was just wonderful to watch these in my hospital bed.  

The dancer in remission starts in first place, this is why the 1st couple dance less than the others (no turn at the end), they have to save energy and enter the dance progressively.', 56, '181/383/383/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3659, '2002-01-08 23:00:00+00', '2022-02-21 13:19:52.857673+00', 'Laird of Milton''s Daughter, The', 'LAIRD OF MILTONS DAUGHTER', 2, 32, 9999, 1, 3, 42, 473, '1950-01-01', 'This is one of the earliest “modern” dances published by the Society

(1963 in <<ddpub:Book 22>>).



There are a few curious anecdotes about the origin of the title of

this dance. George Emmerson''s *Scotland Through Her Country Dances*

used to claim that Flora MacDonald, well known from the mythology

surrounding Bonnie Prince Charlie, was the daughter of a laird of

Milton (on the west coast of South Uist) and that the dance was named

after her. In the second edition of the book there is a reference to

the dance in the index, but the page in question has been replaced by

a facsimile of the old description of a completely different dance!

Apparently the second edition thus corrected one of the bigger bloopers

made in the first, in a somewhat ham-fisted manner, without also

fixing the index.



The correct story goes as follows: According to *Book 22*, the dance was

“Devised by Lord Craigmyle while in India”. The Laird of Milton in

question is known to be the late Chief of Clan Arthur, James

E. MacArthur-Moir (1914-2004), who apparently worked in India for a

while. The dance was invented on the occasion of the birth of his

daughter – according to *Burke''s Peerage and Baronetage, 107th

edition*, she is called Mary MacArthur (now Wood) and was born on 10

October 1950.

', 44, '800/633/633/888', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (3876, '1998-05-11 22:00:00+00', '2022-02-21 13:34:46.841654+00', 'Loch Torridon', 'LOCH TORRIDON', 1, 32, 9999, 1, 3, 42, 313, NULL, 'For Joan and David Whyte, formerly of Torridon.', 50, '800/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5292, '1997-12-03 23:00:00+00', '2022-02-21 21:52:50.242807+00', 'Puddin ''n'' Pam', 'PUDDIN N PAM', 2, 40, 9999, 1, 3, 42, 514, NULL, 'This dance was composed by Mrs. Joyce Elliott, one of the Leicester Branch Teachers. It is ascribed to Mrs. Pamela Hood who had an uncanny knack or tracking down puddings in foreign countries when they were in short supply.



Instructions may be found towards the end of issue 12 of the Leicester Branch bulletin The Quaich at <<https://us4.campaign-archive.com/?u=78fe0ddc70d920bcc3f82add4&id=700d2e1e62>>.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13847, '2011-08-21 22:00:00+00', '2022-02-21 22:04:02.467055+00', 'City of Belfast', 'CITY OF BELFAST', 3, 32, NULL, 2, 3, 17, 10387, NULL, '', 62, '840  880  844  808', 0, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (20669, '2022-02-20 23:41:35.892103+00', '2022-02-22 16:33:14.912527+00', 'Berkhamsted Medley, The', 'BERKHAMSTED MEDLEY', 4, 128, 2, 1, 4, 1, 11412, '2022-01-01', 'See <<https://berkhamstedreelclub.org/the-berkhamsted-medley/>> for the background to the dance.', 75, '8000/8880/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5678, '1997-04-03 22:00:00+00', '2022-02-26 11:54:05.617607+00', 'Rosebud by My Early Walk, A', 'ROSEBUD BY MY EARLY WALK', 2, 48, 9999, 1, 100, 2, 108, '1971-01-01', '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12166, '2005-04-13 22:00:00+00', '2022-02-22 18:37:48.565132+00', 'Canongait', 'CANONGAIT', 2, 128, 9999, 4, 4, 3, 1759, '1968-01-01', 'Canongait in the old city of Edinburgh is reputed to be the "gait" or walk of the Augustinian Canons of

Holyrood Abbey, leading from the confines of the sanctuary to The Royal Mile and the precincts of the

city proper.', 100, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1508, '1997-08-20 22:00:00+00', '2022-02-22 18:51:33.541788+00', 'Dalston''s Delight', 'DALSTONS DELIGHT', 3, 40, 9999, 1, 4, 1, 108, '1965-01-01', 'The dedication reads "To Miss F. Adams of Wishaw". The original notes explain that *Miss Adams chose the title of this dance to remind her of the weekend when she taught at the Carlisle and Border Branch Weekend School at Dalston Hall, near Carlisle.*', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16724, '2015-09-03 20:34:17.001433+00', '2022-02-24 18:53:15.035633+00', 'Anne McArthur', 'ANNE MACARTHUR', 3, 32, NULL, 2, 3, 17, 2101, '2006-01-01', 'Written for Anne''s retirement from Aberdeen Council in 2006.', 50, '888/800/844/826', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2723, '1997-05-17 22:00:00+00', '2022-02-24 20:41:09.212456+00', 'Haggis Tree, The', 'HAGGIS TREE', 3, 32, 9999, 1, 2, 76, 108, '1982-01-01', 'This is a "Pastoral", which is danced to slow airs with slow strathspey-like steps. The dedication reads "for Freddy Sverdlove of New York".', 64, '84/88/88/88', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (2331, '1997-09-02 22:00:00+00', '2022-02-25 18:48:08.948757+00', 'Fraser River Jig, The', 'FRASER RIVER JIG', 2, 32, 9999, 1, 3, 42, 929, NULL, '', 100, '888/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20702, '2022-03-04 12:23:47.31137+00', '2022-03-04 12:23:47.31137+00', 'Faery Cradle', 'FAERY CRADLE', 1, 32, NULL, 1, 3, 42, 2528, NULL, 'Published in the March 2022 edition of the Toronto <<ddpub:Set and Link#1290>> magazine.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17244, '2016-09-04 10:16:36.231903+00', '2022-03-25 18:39:59.51037+00', 'Diamonds are Forever', 'DIAMONDS ARE FOREVER', 2, 32, NULL, 1, 4, 2, 11329, NULL, 'Devised by Roberta Gotfried in celebration of her parents’ 60th wedding anniversary



Music: “Roz and Gil Gotfried” as composed by Andy Imbrie (see page 26)', 66, '4444/6666/6666/7337', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20673, '2022-02-24 19:12:10.471213+00', '2022-04-08 14:13:55.687636+00', 'Merci Sophie!', 'MERCI SOPHIE', 4, 64, 17, 2, 2, 76, 11509, '2021-11-01', '', 60, '66/66/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20834, '2022-05-14 22:24:19.945663+00', '2022-05-14 22:24:19.945663+00', 'Ainster Laddie, The', 'AINSTER LADDIE', 2, 40, NULL, 1, 3, 42, 99, '1991-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20846, '2022-05-15 20:50:46.370615+00', '2022-05-15 20:50:46.370615+00', 'Three Wild Lads', 'THREE WILD LADS', 2, 32, NULL, 1, 3, 42, 99, '1988-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20930, '2022-07-04 16:07:06.301887+00', '2022-07-05 10:13:37.955646+00', 'Cinderella', 'CINDERELLA', 2, 32, NULL, 5, 2, 76, 3325, '2022-01-01', 'The original deviser of this dance (found c.2010) is unknown. This modified version of the instructions was provided by Stephen Webb.



Suitable recorded music:  

*The 19th Hole* by Ian Munro recorded on CD *Double Take* - Track 5 ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20931, '2022-07-04 22:42:40.806644+00', '2022-07-05 07:55:18.25303+00', 'Hurtling Hedgehog, The', 'HURTLING HEDGEHOG', 1, 32, NULL, 1, 3, 42, 12160, '2019-01-01', 'Boris was named during the Tory Party leadership election. He is quite portly, bumbles around a lot, changing direction without warning and trampling over everything in his path.', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18586, '2018-09-13 12:07:48.232363+00', '2022-07-05 22:44:03.689825+00', 'Moscow Hooligans'' Jig', 'MOSCOW HOOLIGANS JIG', 2, 32, NULL, 1, 3, 42, 11703, NULL, 'Also known as Ekaterina.', 47, '844/800/822/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20935, '2022-07-05 23:00:59.37955+00', '2022-07-05 23:00:59.37955+00', 'Scottish Fold and Scottish Straight Cats', 'SCOTTISH FOLD AND SCOTTISH STRAIGHT CATS', 3, 32, NULL, 1, 2, 76, 12165, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20671, '2022-02-24 19:06:43.216288+00', '2022-02-26 10:52:52.459059+00', 'H.A.D.', 'HAD', 3, 32, NULL, 1, 2, 76, 11509, '2021-08-01', 'HAD stands for “hospitalisation à domicile”, which means Hospital At Home. I spent many days and weeks in hospital, but I also had the chance to be on a hospital at home programme for quite long periods, which was very nice! I really enjoyed being back home with my husband and two children, but still being as well taken care of as if I were in hospital. This department is very professional, the whole team is really great and includes a lovely and marvellous coordinating doctor and a fantastic psychologist. It is a dance for advanced dancers to symbolise these experienced professionals. The slow strathspey time represents how they took the time to listen to me and to look after me in a very reassuring way, and is also meant to describe their

sweetness. It’s a two-couple dance (small number), because they treat patients in a very personalised way.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7774, '1997-09-05 22:00:00+00', '2022-02-26 11:07:29.449858+00', 'June''s Jubilee Jig', 'JUNES JUBILEE JIG', 2, 38, 9999, 1, 4, 1, 1036, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17559, '2017-01-22 15:45:48.264461+00', '2022-02-27 23:56:15.666712+00', 'Lady Catherine Brodie''s Reel', 'LADY CATHERINE BRODIES REEL', 2, 32, NULL, 1, 3, 42, 11446, '1997-01-01', 'Dedicated to the deviser''s wife, Catherine Boddie Linz.', 50, '880/808/800/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11797, '2004-09-10 22:00:00+00', '2022-02-28 00:05:27.933259+00', 'Merchiston Castle Jig', 'MERCHISTON CASTLE JIG', 2, 32, 9999, 1, 100, 2, 550, '2004-09-21', 'Devised for Katy Thompson and Andrew Gray in honour of their wedding in Barclay Church in Edinburgh on the 21st of August, 2004', 81, '8888  8448  8888  8008', 1, 1, 1, 1, 81);
INSERT INTO 'dance' VALUES (20684, '2022-03-03 18:04:47.537619+00', '2022-03-03 18:04:47.537619+00', 'Hands up!', 'HANDS UP', 3, 32, NULL, 1, 3, NULL, 11527, NULL, 'At the beginning of the dance weekend in Kazan I mentioned about keeping right hands positions with

joining at shoulder height and with elbows down, especially in two hands turns. Never seen sucn a brilliant

hand usage than for the next two days!', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7475, '2002-02-27 23:00:00+00', '2022-03-02 00:51:08.408084+00', 'New Caledonia Jig', 'NEW CALEDONIA JIG', 2, 32, 9999, 1, 4, 1, 146, NULL, '', 69, '8880/8880/8000/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20685, '2022-03-03 18:06:49.354798+00', '2022-03-03 18:06:49.354798+00', 'It''s Twenty Four Below', 'ITS TWENTY FOUR BELOW', 1, 24, NULL, 1, 4, NULL, 11527, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20693, '2022-03-03 23:04:28.377559+00', '2022-09-02 10:11:16.898624+00', 'Early Morning', 'EARLY MORNING', 1, 32, NULL, 2, 3, 17, 11529, NULL, '', 75, '888/880/808/808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20675, '2022-03-03 00:17:22.178335+00', '2022-03-03 00:37:05.010346+00', 'Yellow Submarine Strathspey', 'YELLOW SUBMARINE STRATHSPEY', 3, 32, NULL, 4, 4, 13, 11527, '2022-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16191, '2015-04-11 17:41:05.875328+00', '2022-03-03 16:20:58.444371+00', 'Pepita Dreamteam', 'PEPITA DREAMTEAM', 1, 32, 9999, 1, 3, 42, 10612, '2009-01-01', 'Written for Meike and Jörn Dronner to celebrate their 50/55 Birthdays in 2010.', 57, '711/866/866/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20677, '2022-03-03 17:48:24.170814+00', '2022-03-03 17:48:24.170814+00', 'Vis-à-Vis', 'VISAVIS', 3, 32, NULL, 1, 3, NULL, 11529, NULL, 'As a gift for A. Bomstein for his birthday.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20678, '2022-03-03 17:51:27.123538+00', '2022-03-03 17:51:27.123538+00', 'Secret Recipe, A', 'SECRET RECIPE', 2, 32, NULL, 1, 4, NULL, 11527, NULL, 'We have some dishes at our dance events. Once someone said: “We know all your recipes“. We answered “No, we always have a couple of secret recipes”. And cooked two new dishes. One of them was this dance with “Flat Set and Link” formation.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20682, '2022-03-03 17:59:54.460918+00', '2022-06-16 22:27:24.624739+00', 'Haggis Muse, The', 'HAGGIS MUSE', 3, 32, NULL, 1, 4, 2, 11527, NULL, 'The dance [is] dedicated to Arina Volgina, who once helped me to cook haggis on the night before St. Andrew’s Day.  It was a giant leap in my ability of cooking haggises.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20680, '2022-03-03 17:55:53.871167+00', '2022-03-03 17:55:53.871167+00', 'Against the Wind', 'AGAINST THE WIND', 1, 32, NULL, 1, 3, NULL, 11527, NULL, 'When your way leads against the usual directions. Written about the strong life situation it becames the

kind of dance where you can test who leads – your mind or your body. That’s the challeng', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20681, '2022-03-03 17:57:57.398514+00', '2022-03-03 17:57:57.398514+00', 'I''ll Be Back', 'ILL BE BACK', 4, 64, 17, 1, 4, NULL, 11527, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20683, '2022-03-03 18:02:45.490268+00', '2022-03-03 18:03:36.149299+00', 'Basket of Kittens, The', 'BASKET OF KITTENS', 1, 32, NULL, 1, 3, NULL, 11529, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20686, '2022-03-03 18:07:55.760762+00', '2022-03-03 18:07:55.760762+00', 'Extra Cross', 'EXTRA CROSS', 1, 32, NULL, 1, 3, NULL, 11527, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20687, '2022-03-03 18:09:49.625528+00', '2022-03-03 18:09:49.625528+00', 'Kelpie In the Snow', 'KELPIE IN THE SNOW', 3, 32, NULL, 1, 3, NULL, 11527, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20688, '2022-03-03 18:10:55.616629+00', '2022-03-03 18:10:55.616629+00', 'Reel of Viy, The', 'REEL OF VIY', 1, 32, NULL, 1, 3, NULL, 11529, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20689, '2022-03-03 18:59:53.989907+00', '2022-03-03 19:03:28.765835+00', 'Lady Alcina Dimitrescu', 'LADY ALCINA DIMITRESCU', 3, 32, NULL, 1, 4, NULL, 11529, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20690, '2022-03-03 22:55:36.702306+00', '2022-03-03 22:55:36.702306+00', 'Queens Prefer Violet', 'QUEENS PREFER VIOLET', 3, 32, NULL, 1, 3, NULL, 11529, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20691, '2022-03-03 22:57:35.664735+00', '2022-03-03 22:57:35.664735+00', 'Swing Madness, The', 'SWING MADNESS', 1, 24, NULL, 7, 113, NULL, 11527, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20694, '2022-03-03 23:06:10.306569+00', '2022-03-03 23:06:10.306569+00', 'City Street', 'CITY STREET', 1, 32, NULL, 1, 4, NULL, 11527, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20695, '2022-03-03 23:07:47.201126+00', '2022-03-03 23:07:47.201126+00', 'Niobium', 'NIOBIUM', 2, 32, NULL, 2, 3, NULL, 11529, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20696, '2022-03-03 23:08:58.915857+00', '2022-03-03 23:09:37.211439+00', 'Cheese, The', 'CHEESE', 1, 32, NULL, 1, 3, NULL, 11527, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20697, '2022-03-03 23:13:40.268135+00', '2022-03-03 23:13:40.268135+00', 'Ludmila''s Fancy', 'LUDMILAS FANCY', 2, 32, NULL, 1, 3, NULL, 11529, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20698, '2022-03-03 23:15:49.2478+00', '2022-03-03 23:15:49.2478+00', 'Metro Reel', 'METRO REEL', 1, 32, NULL, 1, 3, NULL, 12019, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20699, '2022-03-03 23:16:59.88558+00', '2022-03-03 23:16:59.88558+00', 'Beach Ballroom, The', 'BEACH BALLROOM', 3, 32, NULL, 2, 3, NULL, 11527, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20700, '2022-03-03 23:21:45.804436+00', '2022-03-03 23:21:45.804436+00', 'Coin Tossing Hornpipe', 'COIN TOSSING HORNPIPE', 6, 32, NULL, 1, 3, NULL, 11527, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20701, '2022-03-03 23:23:18.003885+00', '2022-03-03 23:23:18.003885+00', 'Russian Mushrooms', 'RUSSIAN MUSHROOMS', 1, 32, NULL, 7, 5, NULL, 11527, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20565, '2021-11-30 11:36:22.241888+00', '2022-03-13 18:10:04.18078+00', 'Hello "C" Goodbye', 'HELLO C GOODBYE', 1, 40, NULL, 1, 3, 42, 10612, '2021-01-01', 'In this dance 1st woman represents corona virus and the hand claps are the widening spread of infections.', 55, '600/844/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20676, '2022-03-03 00:22:39.604967+00', '2022-07-05 22:34:54.523179+00', 'Give Way to Kangaroos', 'GIVE WAY TO KANGAROOS', 1, 32, NULL, 4, 4, 1, 11527, '2022-01-01', 'The original video (<<https://youtu.be/PJxJTSD4imU>>) gave the title as "Give a Way to Kangaroo" which is also in the original version of the QS Twin Peaks Blue book. A later video has "Give Way to Kangaroos" which was added as a spelling alias. Later publication in the book Couple One Ready changed the name to "Give Way to Kangaroos" which is now the official title.



The instructions for bars 17-20 in the book have the ladies slipping left into the centre first whereas the videos show the men slipping into the centre first. The e-crib follows the videos.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20679, '2022-03-03 17:53:10.574027+00', '2022-06-16 22:31:50.108077+00', 'Wunschpunsch', 'WUNSCHPUNSCH', 2, 32, NULL, 1, 100, 2, 11529, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20692, '2022-03-03 23:01:38.22025+00', '2022-09-02 10:41:25.039244+00', 'Fall of the Leaves Jig, The', 'FALL OF THE LEAVES JIG', 2, 32, NULL, 1, 4, 2, 11527, NULL, '', 73, '7007/8888/8888/4444', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5525, '2002-01-08 23:00:00+00', '2022-03-06 00:21:51.408191+00', 'Reel of the 51st Division, The', 'REEL OF THE 51ST DIVISION', 1, 32, 9999, 1, 3, 42, 1861, '1940-01-01', '##>>

Reams have been written about this dance and several pages could be added here but that is not the intention of these notes.



The dance was written by Lieutenants Jimmy Atkinson and Peter Oliver with some input from Lt Col. Tom Harris Hunter while a prisoner of war in a camp in Germany.



The defining feature of the dance, the diagonal lines representing the Saltire badge of the Division, was worked out by Jimmy Atkinson while marching from the north-west coast of France to the POW camp on the German/Austrian border and was said by him to be a variation on the beginning of *Scottish Reform*.



To read more about the history of the dance you may refer to <<https://my.strathspey.org/u/anselm/stories/reelofthe51st/|here>>, <<https://web.archive.org/web/20170617141349/http://www.historyinanhour.com/2014/06/04/history-reel-51st-division/|here>> or <<https://www.laird.org.uk/Scots/51st_Division_at_St_Valery.aspx|here>>. Or <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-165-August-October-1983.pdf#page=4|here>>. A recording of Jimmy Atkinson talking about the dance is part of a BBC article <<https://canvas-story.bbcrewind.co.uk/sites/dancing-for-victory/|here>>.

##<<', 47, '800  833  833  888', 1, 1, 1, 0, 62);
INSERT INTO 'dance' VALUES (19717, '2019-10-24 16:53:21.68702+00', '2022-03-07 18:13:10.899687+00', 'Little Girl in Red Shoes, A', 'LITTLE GIRL IN RED SHOES', 1, 32, NULL, 1, 100, 2, 10356, '2015-07-01', 'Devised to celebrate the 15th anniversary of the SCDC Clara in Yokohama and dedicated to Mrs Yoko Takahashi the organiser and teacher of the club.



The name and first tune of the dance come from a sad story and song based in Yokohama (not far from Tokyo). A summary of the story, about a little Japanese girl separated from her mother and raised by western missionaries, can be found at <<https://en.m.wikipedia.org/wiki/Akai_Kutsu>>. Akai Kutsu is a Japanese translation of [a little girl in] red shoes.



SCD club "Clara" asked Marchan to devise a dance with this famous song, because Clara is a club in Yokohama. The Clara club made several recordings of the music for this dance featuring other Japanese hit songs with a link to Yokohama. These were played by Bluebell SCD band (piano: Akiko Kasama, fiddle: Kana Otake, recorder: Fumitaka Saito, drum: Akiyo Shito).', 59, '6006/8888/8008/8008', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13286, '2007-06-20 22:00:00+00', '2022-03-06 19:08:43.054337+00', 'Fireside Lounge, The', 'FIRESIDE LOUNGE', 3, 32, 9999, 3, 5, 44, 2924, '2000-01-01', '»Devised by Tim Harrison, San Pedro, California.



Note::

  This dance was devised in the Fireside Lounge of the St. Jerome''s University at the University of

  Waterloo in Waterloo, Canada. The Fireside Lounge is where after-parties were held during the

  Teachers'' Association (Canada) Summer School 2000. People arrive at the after-party and join

  a group for chatting. As the party continues people leave that group to join another group while

  others wander from group to group searching for conversation in which they can participate. The

  dance idea was suggested by Karen Baisden of Seattle, Washington, USA.«

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20705, '2022-03-07 18:48:07.110095+00', '2022-03-07 18:48:07.110095+00', 'Kawagoe Matsuri Strathspey', 'KAWAGOE MATSURI STRATHSPEY', 3, 32, NULL, 1, 4, 11, 2887, '2018-11-01', '"In honour of the Alba Scottish Country Dance Groups in Japan, taught by Masako Nomura and who made me so welcome."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20706, '2022-03-07 18:54:11.926397+00', '2022-03-07 18:54:11.926397+00', 'Anniversary Celebration Jig', 'ANNIVERSARY CELEBRATION JIG', 2, 32, NULL, 1, 4, 2, 2887, '2021-12-01', '"For Alderley & District Caledonian Society’s 50th Anniversary. It is one of a suite of three dances to mark the occasion and danced publicly at their 50th Anniversary Dance on 11th March 2022."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20707, '2022-03-07 18:59:31.011968+00', '2022-03-07 18:59:31.011968+00', 'Anniversary Celebration Reel', 'ANNIVERSARY CELEBRATION REEL', 1, 40, NULL, 3, 5, 6, 2887, '2021-12-01', '"For Alderley & District Caledonian Society’s 50th Anniversary. It is one of a suite of three dances to mark the occasion and danced publicly at their 50th Anniversary Dance on 11th March 2022."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20704, '2022-03-07 00:40:49.003583+00', '2022-03-07 00:47:06.524304+00', 'Two Hearts Entwined', 'TWO HEARTS ENTWINED', 1, 32, NULL, 1, 3, 42, 2766, '2022-02-01', 'I had an idea for the figure in bars 1-8 and realized it looks like a heart when danced. It seemed appropriate the idea occurred in early in February before Valentine’s Day.', 31, '800/800/633/633', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13183, '2006-12-11 23:00:00+00', '2022-03-07 00:48:23.808764+00', 'Two Hearts Joined', 'TWO HEARTS JOINED', 3, 32, 9999, 4, 5, 6, 2766, '2006-10-01', 'This dance was written for Marsha Hanson and Clay Spurlock on the occasion of their marriage October 14, 2006.', 45, '80808/08088/60024/02640', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20708, '2022-03-07 19:02:17.229412+00', '2022-03-07 19:02:17.229412+00', 'Anniversary Celebration Strathspey', 'ANNIVERSARY CELEBRATION STRATHSPEY', 3, 32, NULL, 1, 4, 2, 2887, '2021-12-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19617, '2019-09-03 21:06:55.153791+00', '2022-03-09 01:06:07.656366+00', 'Double Postie''s Jig', 'DOUBLE POSTIES JIG', 2, 32, NULL, 1, 4, 2, 82, NULL, 'Crib derived from the video.', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20709, '2022-03-09 09:29:22.981568+00', '2022-03-09 09:29:22.981568+00', 'Whirlpool, The', 'WHIRLPOOL', 1, 88, 9999, 4, 4, 3, 11162, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20717, '2022-03-09 09:52:23.180354+00', '2022-03-09 09:52:23.180354+00', 'Old Railway Bridge, The', 'OLD RAILWAY BRIDGE', 1, 32, 9999, 1, 2, 76, 11162, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20712, '2022-03-09 09:39:12.378895+00', '2022-03-09 10:19:01.49785+00', 'Punch Line', 'PUNCH LINE', 2, 40, 9999, 10, 2, 76, 11162, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20711, '2022-03-09 09:37:44.66436+00', '2022-03-09 10:17:13.172644+00', 'Carneval Fancy', 'CARNEVAL FANCY', 3, 48, 9999, 4, 4, 3, 11162, NULL, 'This was devised as a demonstration dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20710, '2022-03-09 09:35:22.492345+00', '2022-03-09 10:18:19.160246+00', 'Dance with Sashes', 'DANCE WITH SASHES', 1, 72, 9998, 8, 6, 3, 11162, NULL, 'From the dance description: When writing this dance, I was inspired by a display done by the Glasgow University Scottish Country Dance Club also using sashes.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20713, '2022-03-09 09:45:38.808235+00', '2022-03-09 10:22:16.599462+00', 'Maxglan Medley', 'MAXGLAN MEDLEY', 4, 32, 2, 104, 2, 76, 11162, NULL, 'Maxglan is the part of Salzburg where The Flying Scotsman Scottish Dancers Salzburg founded by Regina Freinbichler used to dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20714, '2022-03-09 09:47:36.500057+00', '2022-03-09 10:22:58.507629+00', 'Inner Circle, The', 'INNER CIRCLE', 2, 40, 9999, 6, 3, 4, 11162, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20715, '2022-03-09 09:48:48.507407+00', '2022-03-09 10:23:04.84232+00', 'Mount of the Fairies', 'MOUNT OF THE FAIRIES', 1, 88, 9999, 4, 4, 3, 11162, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20716, '2022-03-09 09:50:22.843268+00', '2022-03-09 10:23:09.879371+00', 'Fasching Hornpipe', 'FASCHING HORNPIPE', 6, 32, 9999, 1, 3, 42, 11162, NULL, 'Fasching is the German word for carneval. This dance, as you can see in the video, was danced at a carneval party.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14568, '2012-09-08 21:55:28.962131+00', '2022-03-10 18:57:16.105331+00', '3 Feisty Women', '3 FEISTY WOMEN', 1, 32, 9999, 2, 3, 17, 10657, '2007-04-01', 'Devised in the Cleveland Heights Group, spring 2007



The 6-couple version of this dance is called "Double the Trouble"', 67, '880  888  800  826', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (20703, '2022-03-06 19:56:59.677882+00', '2022-09-23 19:32:19.825598+00', 'Lang Tyme Mairrit', 'LANG TYME MAIRRIT', 3, 32, NULL, 1, 3, 42, 12108, '2001-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18305, '2018-04-25 22:17:16.45083+00', '2022-03-10 21:23:06.025065+00', 'Millmead Strathspey, The', 'MILLMEAD STRATHSPEY', 3, 32, NULL, 2, 3, 17, 11632, '2008-01-01', 'To celebrate the 50th anniversary of South East Herts Scottish Country Dance Society.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20835, '2022-05-14 22:32:49.141229+00', '2022-05-14 22:32:49.141229+00', 'Miss Mary Ann Baxter of Balgavies', 'MISS MARY ANN BAXTER OF BALGAVIES', 3, 32, NULL, 1, 4, 2, 99, '1990-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (17014, '2016-06-09 10:30:33.276689+00', '2022-03-16 23:13:23.217747+00', 'Brighouse Bay', 'BRIGHOUSE BAY', 2, 48, 9999, 4, 4, 13, 1415, NULL, 'The deviser writes that

"As a child my parents took us to Brighouse Bay campsite for summer holidays. I have since taken all my children there for holidays and Lewis had his first experience of camping there age 2."', 69, '8080 8484 0808 8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (18037, '2017-10-28 20:13:13.603681+00', '2022-03-10 23:52:47.128972+00', '100th English Weekend reloaded, The', '100TH ENGLISH WEEKEND RELOADED', 1, 40, 9999, 3, 5, 16, 11539, '2013-07-07', 'Devised for Lothar Rummel''s 100th English Weekend on 5th to 7th of Juli, 2013 in Hedersleben, Germany.

The dance was updated in June 2014 for better flow.



The dance description was online available at http://www.scd-chemnitz.de/tanze/ - however, the Scottish Dance Group in Chemnitz seemingly has dissolved and thus also the server does not exist anymore.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20718, '2022-03-11 00:03:49.448301+00', '2022-03-11 00:07:18.575994+00', 'Emerging from Loch Down', 'EMERGING FROM LOCH DOWN', 3, 32, NULL, 1, 3, 42, 11237, '2021-09-01', 'Loch Down, which features naturally rising bubbles due to geothermal activity, was little known until recently due to its very self-isolated, but airy and well ventilated location. A dip in the water can present challenges as there are strong cross and side currents, known to swimmers as lateral flow tests. It is best visited alone or in small numbers, avoiding too much face to face contact, as mixing of large numbers of men and women in Loch Down can provoke polygamous chain reactions (PCRs)!



This dance is dedicated to Martina Mueller-Franz who inspired the title (and consequently the dance) with a serendipitous typo ("lockdown" to "lochdown") in an email she sent me as the pandemic restrictions were being eased. We owe her many thanks. Firstly for regularly providing information to complete and correct the strathspey database. And secondly for the large number of Scottish Country Dance videos she has made over the years and uploaded to her youtube channel (<<https://www.youtube.com/c/strathspey64/videos>>).', 69, '880/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20719, '2022-03-12 21:23:37.182722+00', '2022-03-12 21:23:37.182722+00', 'Why Knot', 'WHY KNOT', 3, 32, NULL, 2, 3, 18, 9998, NULL, 'Source: <<https://youtu.be/wf3JBcvyIiI|youtube video>> by the Kalamazoo Royal Scottish Country Dancers, Michigan.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20722, '2022-03-20 12:16:37.672224+00', '2022-03-20 17:10:38.240471+00', 'My Little Buttercup', 'MY LITTLE BUTTERCUP', 3, 32, NULL, 2, 3, 18, 11077, '2016-11-01', 'There is also a 5 couple version of this dance (<<http://www.rscds-swws.org/news/stories/MyLittleButtercupTenPesoVersion.pdf>>).', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6545, '1998-07-08 22:00:00+00', '2022-03-13 20:08:52.880802+00', 'Thistle Down Reel', 'THISTLE DOWN REEL', 1, 32, 9999, 1, 4, 2, 697, NULL, '', 59, '6886/8008/8008/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1888, '1999-08-06 22:00:00+00', '2022-03-14 10:43:49.620632+00', 'Earl of Ulster Medley, The', 'EARL OF ULSTER MEDLEY', 4, 96, 10053, 6, 3, 3, 28, '1976-01-01', '', 100, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19254, '2019-04-02 20:32:27.373788+00', '2022-03-14 23:52:46.990632+00', 'Titanic, The', 'TITANIC', 1, 32, NULL, 1, 3, 42, 9998, NULL, 'Crib found on a dance programme.  Dance originally added using that information.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9104, '2001-11-21 23:00:00+00', '2022-03-15 08:56:00.621738+00', 'Nice to See You', 'NICE TO SEE YOU', 1, 32, 9999, 5, 56, 76, 2664, '1995-01-01', '', 79, '888  888  080  848', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (16734, '2015-09-09 15:57:44.709217+00', '2022-03-16 04:24:46.751117+00', 'Converys of Clonskeagh, The', 'CONVERYS OF CLONSKEAGH', 1, 32, NULL, 1, 2, NULL, 11201, '2015-09-03', 'For Hazel and Liam Convery in celebration of their Golden Wedding Anniversary 3rd September 2015.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1339, '1997-04-03 22:00:00+00', '2022-03-17 08:54:56.029164+00', 'Corbie-Stones', 'CORBIESTONES', 3, 32, 9999, 1, 3, 42, 13, NULL, 'Corbie-stones are the step-like projections on the sloping adge of a gable, found particularly on houses in the finishing villages of Fife.', 63, '880/666/877/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13894, '2011-08-22 22:00:00+00', '2022-03-17 20:55:51.133725+00', 'Devil''s Water, The', 'DEVILS WATER', 3, 40, NULL, 1, 4, 2, 2788, '1999-03-01', 'From the dance notes:

"The Devil''s Water is a small river between Corbridge and Hexham. The dance represents how the water swirls and flows and reminds me of pleasant walks alongside the river."', 70, '8008/8888/8888/8008/8008', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20720, '2022-03-20 00:38:22.609347+00', '2022-03-20 00:38:22.609347+00', 'Smell of Roses, The', 'SMELL OF ROSES', 3, 32, NULL, 2, 3, NULL, 3645, '2022-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20721, '2022-03-20 11:56:25.045192+00', '2022-03-20 12:08:30.157462+00', 'Let''s Ride', 'LETS RIDE', 1, 32, NULL, 1, 3, 42, 10593, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15790, '2015-01-15 16:09:16.884938+00', '2022-03-21 18:01:02.894399+00', 'Broome Rigg, The', 'BROOME RIGG', 2, 32, 9999, 1, 2, 76, 210, NULL, '2 couple dance in 3 or 4 couple set.



The original version of this dance was subsequently revised. In an email from Duncan Keppie he writes that "I substituted the Ancient Poussette for the Highland Pousette". The PDF of <<ddpub:#1207>> on the MiniCrib website still has the original version (as of March 2022). The instructions available at <<https://www.scottish-country-dancing-dictionary.com/dance-crib/broome-rigg.html>> have the later version with the Ancient Poussette.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20723, '2022-03-20 12:22:15.195247+00', '2022-03-20 12:22:15.195247+00', 'We Can Sew!', 'WE CAN SEW', 1, 32, NULL, 1, 3, 42, 11077, '2018-02-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20724, '2022-03-20 12:36:30.411618+00', '2022-03-20 12:37:32.151589+00', 'Pacific Northwest Picnic Surprise', 'PACIFIC NORTHWEST PICNIC SURPRISE', 1, 32, NULL, 3, 5, 7, 12118, '2018-01-01', 'There is also a 3 couple version of this dance (<<http://www.rscds-swws.org/news/stories/PacificNorthwestCeilidh.pdf>>).', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20725, '2022-03-20 12:48:55.922591+00', '2022-03-20 12:48:55.922591+00', 'Take the Amigos'' Clothes', 'TAKE THE AMIGOS CLOTHES', 1, 32, NULL, 1, 3, 42, 11077, '2018-03-01', 'There is also a 5 couple version of this dance (<<http://www.rscds-swws.org/news/stories/TakeAmigosClothesTenPesoVersion.pdf>>).', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16025, '2015-02-09 23:05:28.538447+00', '2022-03-20 12:50:55.535271+00', 'Plethora of Piñatas, A', 'PLETHORA OF PINATAS', 1, 32, NULL, 1, 3, 42, 11077, '2014-10-01', 'There is also a 5 couple version of this dance (<<http://www.rscds-swws.org/news/stories/PlethoraPinatasTenPesoVersion.pdf>>).', 62, '800/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20726, '2022-03-20 22:38:56.662714+00', '2022-03-21 10:51:29.534772+00', 'Heart and Soul', 'HEART AND SOUL', 3, 32, NULL, 2, 3, 17, 10568, '2022-01-01', '"Dedicated to Ramona Galmona for her February 22 birthday."', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20727, '2022-03-21 17:08:01.679134+00', '2022-03-21 17:08:01.679134+00', 'Tight Little Island', 'TIGHT LITTLE ISLAND', 3, 32, NULL, 5, 2, 76, 210, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20728, '2022-03-21 21:56:49.838641+00', '2022-03-21 21:58:59.649928+00', 'Caleco', 'CALECO', 4, 96, 11, 6, 3, 3, 9998, NULL, 'Demonstration dance devised by a local dancer in Leicester in the 1980s.



The instructions called the dance "Caleco" but the <<https://youtu.be/8yEy2VAHfjc|video>> has "Calico".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13778, '2011-07-23 22:00:00+00', '2022-03-22 21:32:18.885731+00', 'Dun Arisaig', 'DUN ARISAIG', 2, 32, NULL, 1, 4, 2, 1276, NULL, 'Adrian writes:  Dun Arisaig: 4x32 J for 4 couples in a longwise set. Dance intensity 75%. Standard - I''d say intermediate, although it does involve 8 dancers in  a St. Andrews Cross (i.e. an oblique diagonal cross, not right-angled, as in the flag of Scotland).  This cross is formed in 4 bars, rotated halfway in 4 bars, and then dissolved in 4 more bars - so this dance is not for a crowded ballroom with close lines. The figures involving the cross are not so much difficult as unusual.  In such cases less experienced dancers, with less certainty about how Scottish dances "should" go, may actually take to them more easily.



Dedicated to Ruth and Peter Thornton, of Liskeard, Cornwall



Recommended tunes: jigs suitable for marches, e.g. Pipe-Major Donald Maclean, played AABB.', 75, '8888/8888/4444/0808', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20576, '2021-12-21 16:13:02.032554+00', '2022-03-27 17:16:38.97032+00', 'Peter Elmes'' Strathspey', 'PETER ELMES STRATHSPEY', 3, 32, NULL, 2, 3, 17, 2682, '2021-01-01', '', 83, '880/888/808/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20730, '2022-03-26 19:30:40.556395+00', '2022-03-27 15:39:03.416505+00', 'Silver Star, The', 'SILVER STAR', 1, 128, NULL, 1, 4, NULL, 275, NULL, 'The dance is based on an idea made by a member of the advanced class of the 1971 Auckland Labour Weekend School. The Silver Star was a luxury passenger train that ran overnight between Wellington and Auckland.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20731, '2022-03-26 19:44:50.583112+00', '2022-03-27 15:39:29.640115+00', 'Camp Akatarawa', 'CAMP AKATARAWA', 2, 32, NULL, 1, 3, 42, 349, NULL, 'This dance commemorates the last time the Linden Scottish Country Dance Club and friends gathered at the Salvation Army Campsite at Akatarawa for a weekend of socializing and dancing - March 2004', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20732, '2022-03-26 19:51:39.303368+00', '2022-03-27 15:39:55.232477+00', 'Wellington Orchid, The', 'WELLINGTON ORCHID', 3, 32, NULL, 6, 3, 17, 11932, NULL, 'This dance was devised to celebrate the 60th Anniversary of the Wellington Region. Devised  in 2021', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20734, '2022-03-26 20:21:40.606067+00', '2022-10-27 07:37:09.3739+00', 'Camping at Victoria Mines', 'CAMPING AT VICTORIA MINES', 3, 32, NULL, 1, 4, 1, 11211, NULL, 'Victoria Mines is an old silver mine on the trail between the Inca city of Choquequirao and modern day Yanama in the Peruvian Andes. To get from Choquequirao to Victoria Mines you have to zigzag down a vertical descent of around 1000m to cross the Rio Blanco and then zigzag 2000m vertical ascent up the other side of the valley to get to the mines. The mines are at an altitude of 4130m above sea level and the tailings make a great camping spot after a very long day''s walk. The views are stunning!



In the original book the tune was given as <<ddt:Hills of Lorne, The>> (as for Autumn in Appin). However in <<https://my.strathspey.org/dd/issue/2891/|issue 2891>> the deviser explains this was a mistake and it should be <<ddt:Doon the Burn, Davie Lad#403>>.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20736, '2022-03-26 20:39:34.358359+00', '2022-12-01 14:53:22.778046+00', '''Halfway House'', Petone, The', 'HALFWAY HOUSE PETONE', 3, 32, NULL, 1, 4, 1, 11073, NULL, 'Devised 2019-05

The Community House in Britannia Street, Petone, has been the venue for Region Committee Meetings for a number of years. It would be difficult to find a suitable venue at the junction of State Highways 1 and 2. This would be almost equidistant between the two northernmost clubs, Waikanae and Carterton.', 56, '8080/0808/8440/8448', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20737, '2022-03-26 20:54:29.576773+00', '2022-03-27 17:14:49.660939+00', 'Autumn Rays', 'AUTUMN RAYS', 1, 32, NULL, 1, 3, 42, 11890, NULL, 'Devised: 2021', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20738, '2022-03-26 21:01:32.715192+00', '2022-03-27 17:15:22.535836+00', 'Strait Ferry, The', 'STRAIT FERRY', 2, 32, NULL, 1, 3, 42, 11155, NULL, 'Devised: March 27th', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20739, '2022-03-26 21:19:57.709554+00', '2022-03-27 17:15:44.237038+00', 'Isla and Johnny', 'ISLA AND JOHNNY', 3, 32, NULL, 1, 102, 1, 11955, NULL, 'Devised: 2018-08

Inspired by the Island Bay and Johnsonville clubs'' first combined annual dance of 2018. The Island Bay Club is now known as the Capital City but the collegiality and cooperation between the two clubs continues.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20740, '2022-03-26 21:24:14.057489+00', '2022-03-27 17:16:07.854109+00', 'Wingless Flight', 'WINGLESS FLIGHT', 1, 32, NULL, 1, 3, 42, 11226, NULL, 'Devised: 2015-08

In May 2015, I slipped on an icy deck and fractured my right wrist. I am right handed. I had been invited to teach at the Queen''s Birthday Weekend School that year, which I did - complete with plaster cast and sling. 

I devised this dance to require no hands, so eye contact with your partner and other dancers is especially important.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13315, '2007-08-05 22:00:00+00', '2022-03-28 01:59:31.622994+00', 'Silver Poppy, The', 'SILVER POPPY', 2, 48, 9999, 1, 3, 42, 12010, NULL, '', 50, '800/888/844/844/844/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15172, '2013-09-28 19:45:52.752623+00', '2022-03-28 17:36:20.700322+00', 'Blue Valley', 'BLUE VALLEY', 3, 32, NULL, 2, 3, 17, 3101, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19476, '2019-07-23 09:22:30.91741+00', '2022-03-29 09:33:14.094135+00', 'Reel for Cosmo John, A', 'REEL FOR COSMO JOHN', 1, 32, NULL, 6, 3, 17, 10889, '2016-01-01', 'A Scottish Reel devised to raise Autism Awareness. My grandson is fascinated by all things that turn, spin or whirl. This dance contains movements to suggest coin spinning, washing machines, lorry wheels, turbine blades.... *(from the youtube video comment)*', 83, '800/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20747, '2022-04-02 18:32:57.777255+00', '2022-04-02 19:08:40.224303+00', 'Strawberries', 'STRAWBERRIES', 3, 32, NULL, 1, 3, 42, 463, NULL, 'Strawberries is one of Morgan''s best known and most loved poems.

The dance celebrates the connection between the two people. The tune ends unfinished, left behind, not unlike the discarded plates.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20744, '2022-03-30 02:14:53.244225+00', '2022-03-30 02:42:25.222543+00', 'Captain O''Neill''s Strathspey', 'CAPTAIN ONEILLS STRATHSPEY', 3, 32, NULL, 4, 4, 1, 11181, '2022-03-30', 'Captain Felix O''Neill was one of the companions of Bonnie Prince Charlie during his escape after the Battle of Culloden (1746). See <<https://www.dib.ie/biography/oneill-felix-a6922|Captain O''Neill''s Biography>>  

This dance has been devised to teach Schiehallion Reels.', 100, '8888/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20146, '2020-11-14 11:53:40.911408+00', '2022-03-31 17:29:30.889978+00', 'Rose Bouquet, A', 'ROSE BOUQUET', 3, 32, NULL, 2, 3, 17, 2874, '2020-02-01', '', 67, '880/888/800/808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20937, '2022-07-06 22:53:05.136418+00', '2022-12-04 21:51:12.260269+00', 'Butcher''s Jig', 'BUTCHERS JIG', 2, 32, NULL, 1, 2, 76, 12167, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20743, '2022-03-27 22:56:25.880455+00', '2022-04-02 19:00:55.38623+00', 'George Square Starlings', 'GEORGE SQUARE STARLINGS', 1, 48, NULL, 4, 4, NULL, 217, NULL, 'The Starlings in George Square is a three part poem that describes the plight of the starlings and their eviction from central Glasgow.

The dance and the tune are both focussed on the first of the three parts. The starlings are in their multitudes and dance, dash and dart like a shower of arrows.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20746, '2022-04-02 18:27:03.788376+00', '2022-08-16 12:22:05.998203+00', 'Trinity, The', 'TRINITY', 2, 32, NULL, 1, 3, 42, 11301, NULL, 'Trio is a tremendously joyous poem. This dance maintains the clever continued use of three and emulates the joy and happiness of the poem''s protagonists.

The tune refers to the memorable line, "Orphean Sprig! Melting Baby! Warm Chihuahua!" The melody references the threesome''s journey, bouncing repeatedly onward, without looking back.', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20742, '2022-03-27 22:45:32.492014+00', '2022-08-17 08:20:11.959171+00', 'Off Course', 'OFF COURSE', 3, 32, NULL, 2, 3, 18, 11884, NULL, 'In Spacepoem 3: Off Course, Morgan uses a series of ever slightly changing images to create a sense of isolation and unease, but also hopefulness and optimism.

The dance emphasises some of the elegant images of "turning continents" and "imaginary somersaults." The tune warps from sombre minor to hopeful major and takes inspiration from the uplifting final image: "the floating song."', 64, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20745, '2022-04-02 09:32:32.797338+00', '2022-04-03 10:47:03.976417+00', 'Decapitation Jig, The', 'DECAPITATION JIG', 2, 32, NULL, 1, 107, 14, 9998, NULL, '', 50, '8800/8800/8800/8800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20748, '2022-04-02 18:38:30.577088+00', '2022-04-02 19:15:01.300197+00', 'Mercury Men', 'MERCURY MEN', 1, 32, NULL, 3, 5, 7, 3379, NULL, 'A dance and tune for those native to Mercury on meeting their visitors from Earth in Morgan''s poem, The First Men on Mercury.

The dance is complex and involves dancers in the unconventional feature in Country dancing of couples changing sides as the dance progresses. This reflects the way that the men arriving on Mercury and the inhabitants adopt each other''s language and become increasingly difficult to disentangle.

The tune is named after the Alien''s initial greeting and has a simple theme, which becomes gradually altered and more complicated. As Morgan concludes, "but nothing is ever the same, now is it?"', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18204, '2018-01-13 10:34:12.52575+00', '2022-04-03 09:00:40.771252+00', 'Arctophiles'' Jig, The', 'ARCTOPHILES JIG', 2, 32, NULL, 1, 3, 42, 59, '2014-05-29', 'An ''arctophile'' is a person who collects or is very fond of teddy bears.



For all those who take their teddy bears with them to summer school.



Any suitable jig played AABB.



Suitable recorded music: "Major Ian Stewart'' recorded by Muriel Johnstone and Keith Smith on ''Cairngorms'' track 12 (CD).', 63, '800/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1064, '1997-04-03 22:00:00+00', '2022-04-03 10:55:37.98269+00', 'Castle Brae', 'CASTLE BRAE', 3, 32, 9999, 1, 3, 42, 332, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10449, '2002-04-01 22:00:00+00', '2022-04-03 17:06:53.046373+00', 'Flowers of Kinburn, The', 'FLOWERS OF KINBURN', 3, 40, 9999, 1, 2, 76, 59, NULL, 'The dance was originally entered with the wrong title: The Flowers of Kilburn. It should be "Kinburn" (see <<https://my.strathspey.org/dd/issue/2753/|issue 2753>>). The mistaken version is kept as a (mis)spelling alias.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1445, '1998-04-08 22:00:00+00', '2022-04-03 18:15:42.544926+00', 'Crossing the Line', 'CROSSING THE LINE', 3, 24, 9999, 1, 4, 1, 352, '1993-11-24', '', 58, '8800/8440/8448', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16051, '2015-02-13 13:53:43.130963+00', '2022-04-05 21:26:15.220435+00', 'Barry Priddey Strathspey, The', 'BARRY PRIDDEY STRATHSPEY', 3, 32, 9999, 1, 100, 2, 3694, '2011-04-01', 'Suggested music: The Dancing Dominie recorded by George Meikle and the Lothian Band', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20672, '2022-02-24 19:08:42.153773+00', '2022-04-08 08:35:20.483799+00', 'My Private Physiotherapist', 'MY PRIVATE PHYSIOTHERAPIST', 2, 32, NULL, 1, 3, 42, 11509, '2021-09-01', 'When I had my two legs operated on (see Once on the Right, Once on the Left), I didn’t feel very autonomous and I was advised by the surgeon to go to a rehabilitation centre to improve quickly and to avoid home accidents which might lead to another operation!!! So I stayed several days in hospital waiting for a place in such a centre, but since there weren’t any, I finally went home on an H.A.D. (hospital at home) programme. A childhood friend of mine, Nathalie Comaille-Lenhoff, who is a physiotherapist but lives a long way from our home, managed to come and stay a few days with me right at that time. So I had my own private physiotherapist,even better than having a place in a rehabilitation centre!  

This dance was devised for her, I really enjoyed the few days with her, and I was very grateful for her help. 1st man represents the private physiotherapist who guides the patient (1st woman) throughout the dance, except for the last 2 bars, when the patient has become autonomous and can set alone.', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16049, '2015-02-13 13:33:26.770123+00', '2022-04-06 02:17:43.553242+00', 'Heart of the Run', 'HEART OF THE RUN', 3, 32, 9999, 2, 3, 17, 3694, '2008-11-01', 'Prior to the distillation process of malt whisky the liquid passes through the spirit safe but the first part is recycled as it is not pure enough. Only the middle bit (the Heart of the Run) goes on to be distilled and the final part is also recycled. I learned this on a visit to the Glenturret Distillery near Crieff following the Society AGM in Perth.', 83, '888/484/484/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5316, '2003-01-27 23:00:00+00', '2022-04-06 10:24:32.372028+00', 'Pool Of Connla, The', 'POOL OF CONNLA', 3, 32, 9999, 1, 102, 2, 313, NULL, 'The <<https://www.oxfordreference.com/view/10.1093/oi/authority.20110803095632663|Oxford Reference>> says:



> A source of inspiration and knowledge in early Irish mythology, some what comparable to the well of Mimir in Norse tradition. The location of the well changes from text to text, and the identity of the Connla for whom it is named is not clear. It may be under the sea, in Tír na nÓg [The Land of Youth], or in Tír Tairngire [The Land of Promise]. One Dindshenchas [lore of place-names] cites a Connla''s Well near Tipperary.



The dance is dedicated to <<ddp:Holden, Anna Campbell>> on account of the authority of her teaching.', 87, '8008  8888  8888  8888', 1, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (16536, '2015-07-31 14:34:44.978061+00', '2022-04-10 10:59:59.899326+00', 'MacDonald of Keppoch', 'MACDONALD OF KEPPOCH', 4, 128, 2, 4, 4, 1, 2973, NULL, 'The title of the dance refers to the clan of which the Ronald family is a sept.', 78, '8282/8888/8080/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14553, '2012-09-02 20:49:42.190619+00', '2022-04-26 01:52:03.309405+00', 'Dancing Lights, The', 'DANCING LIGHTS', 2, 32, NULL, 1, 3, 42, 2680, '1992-11-01', 'Devised for and dedicated to the Yellowknife Scottish Country Dance Club on the occasion of their annual workshop, November 1992. The name was chosen after the author saw the northern lights "dancing" in the arctic sky.', 50, '800  880  888  844', 1, 1, 1, 0, 66);
INSERT INTO 'dance' VALUES (5079, '1998-10-15 22:00:00+00', '2022-04-10 15:59:19.361779+00', 'On the Morning Tide', 'ON THE MORNING TIDE', 1, 32, NULL, 1, 3, 42, 44, '1984-01-01', '', 50, '880  800  844  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (18090, '2017-11-23 18:14:48.051109+00', '2022-04-10 16:33:11.329689+00', 'Necklace of Coral, A', 'NECKLACE OF CORAL', 4, 240, 10032, 7, 113, NULL, 1848, '2016-04-01', 'To celebrate the 35th (coral) anniversary of the RSCDS Peterborough and District Branch.  ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20753, '2022-04-09 23:30:23.871543+00', '2022-04-11 00:08:26.508972+00', 'Experimental Reel, The', 'EXPERIMENTAL REEL', 2, 32, NULL, 1, 3, 42, 1445, NULL, 'This is a weird dance, there was no special reason to devise it, but I think there should be a place for weird dances.', 48, '404/404/7777/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13365, '2009-08-02 22:00:00+00', '2022-04-26 01:44:05.31846+00', 'Yet Another Birthday', 'YET ANOTHER BIRTHDAY', 3, 32, NULL, 2, 3, 17, 10568, NULL, 'Written for the author''s husband, Don Nemiroff, on his birthday.



Author''s Note: »The first 8 bars I call ›The Maurice Progression‹, inspired by the dance <<ddd:Maurice>> written by Gary Thomas and published in *Dunsmuir Dances* in memory of Maurice Whitby. Maurice was very active in the earlier days of the Montréal Branch (dancing, teaching, and working on the Committee of Management) until he moved to Ontario.«



DEVISED:2007-05', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16010, '2015-02-09 13:34:55.11717+00', '2022-05-07 21:41:01.082618+00', 'Mohonk Rant, The', 'MOHONK RANT', 1, 32, 9999, 2, 3, 17, 11070, '2000-01-01', 'According to <<https://my.strathspey.org/dd/issue/2785/|issue 2785>> this is a once and to the bottom 3 couple set dance meant to be done 6 times through. Finishing the slip step facing down with nearer hands joined is the key to starting the turns correctly.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20749, '2022-04-03 18:55:16.83821+00', '2022-11-19 11:25:13.328152+00', 'Atholl Celebrations', 'ATHOLL CELEBRATIONS', 4, 64, 5, 1, 3, 42, 11013, '2022-01-01', '', 69, '880/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2828, '1997-09-03 22:00:00+00', '2023-01-20 12:11:49.583936+00', 'Heads And Tails', 'HEADS AND TAILS', 1, 32, NULL, 1, 3, 42, 938, NULL, '', 56, '808/888/888/800', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17420, '2016-10-19 21:42:59.445281+00', '2022-04-10 17:44:28.114119+00', 'St George''s Cross', 'SAINT GEORGES CROSS', 1, 48, 9999, 2, 3, 17, 10912, NULL, 'Contains Sash Pin Reels.



This dance is a derivative of <<ddd:Mary MacNiven''s Sash Pin#17411>> with the sash pin reels in a St George''s Cross rather than a St Andrew''s Cross formation.

Also see the dance <<ddd:St Piran''s Cross#17421>> by <<ddp:Reuben Freemantle>#10912>>.



St George''s Cross (or the Cross of St George) is a red cross on a white background used as a symbolic reference to Saint George. This flag was associated with St George from medieval times and has been adopted on the coat of arms and flags of several countries and cities which have St George as a patron saint, notably England. 



(Source: <<http://www.scottish-country-dancing-dictionary.com/dance-crib/st-georges-cross.html|Scottish Country Dancing Dictionary>>)', 90, '484/888/888/888/888/648', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9474, '2002-11-28 23:00:00+00', '2022-04-12 11:49:11.088028+00', 'Nethy Bridge', 'NETHY BRIDGE', 3, 32, 9999, 2, 2, 76, 108, '1999-01-01', '', 50, '80/88/88/80', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15733, '2015-01-09 14:35:50.873259+00', '2022-05-07 22:14:41.107973+00', 'Villain''s Turnstile Jig, The', 'VILLAINS TURNSTILE JIG', 2, 32, 9999, 1, 3, 42, 3694, '2009-05-31', 'Dedicated to Richard Francis, a Villa fan, who are known as Villans.



The dance was published with the title "Villain''s" but the dedicatee says it should be "Villan''s" which is added as an alias.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12631, '2005-11-08 23:00:00+00', '2022-04-18 08:17:45.822294+00', 'Braes of Strathlene, The', 'BRAES OF STRATHLENE', 3, 32, 9999, 1, 3, 42, 127, '2004-01-01', 'Devised by Bill Forbes, originally from Buckie, for Anne Taylor of Fochabers (Moray). Strathlene, on the eastern outskirts of Buckie, (Banffshire) has wonderful winding paths - a hiker’s paradise - leading away from the sea up to the golf course. The Braes cradle a fairly large holiday park overlooking the Moray Firth, famous for its sunsets - an unbelievable view. The Village of Findochty nestles to the East of the Braes and is where Anne grew up. “PS. I am not employed by the Scottish Tourist Board,” writes Bill Forbes.', 63, '880/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16645, '2015-08-27 16:46:57.67349+00', '2022-04-15 17:00:55.238434+00', 'He Shoots! He Scores!', 'HE SHOOTS HE SCORES', 2, 32, NULL, 1, 2, 76, 10568, '2015-03-01', 'Written for my hockey crazy son.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12633, '2005-11-08 23:00:00+00', '2022-04-17 08:17:22.39518+00', 'Gourdieburn', 'GOURDIEBURN', 3, 32, 9999, 2, 3, 17, 3688, '2003-01-01', '', 67, '800/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11908, '2004-11-22 23:00:00+00', '2022-04-17 08:25:50.928692+00', 'Moranbank', 'MORANBANK', 3, 32, 9999, 1, 3, 42, 3379, NULL, '', 56, '844/888/844/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12630, '2005-11-08 23:00:00+00', '2022-04-17 10:47:17.108377+00', 'Compliments to Jessie Bain', 'COMPLIMENTS TO JESSIE BAIN', 3, 32, 9999, 1, 4, 1, 3687, '1989-01-01', 'Devised by Jean Mair, for her sister, Jessie Bain.  This dance was the winner of a competition

organised by the Banffshire Branch for their 60th Anniversary in 1989.



Jessie Bain was Pianist at the Buckie Class, and various other classes, for many years and was a

recipient of the Society’s Scroll in 1986.', 69, '6666/8888/8040/8444', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20401, '2021-07-26 20:09:36.585362+00', '2022-04-17 16:37:03.276642+00', 'Lady from Cuguen, The', 'LADY FROM CUGUEN', 1, 40, NULL, 1, 3, 42, 11181, '2021-08-22', '', 60, '800/888/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4928, '2000-02-21 23:00:00+00', '2022-04-22 02:04:16.78651+00', 'New Rigged Ship, The', 'NEW RIGGED SHIP', 2, 48, 9999, 1, 3, 42, 9998, '1805-01-01', 'The book 9 description tells 1c to start leading up on [33].  It is then impossible to face 1cnrs in time for setting to the corners.  The Manual (in notes for dances) recommends to 1c dance up on [31-32]. They can then reach 1cnr on [34].  ', 46, '880  888  800  800  822  866', 1, 1, 1, 1, 61);
INSERT INTO 'dance' VALUES (20770, '2022-04-17 18:19:49.728446+00', '2022-04-17 18:36:46.61076+00', 'Great Rider, A', 'GREAT RIDER', 3, 40, NULL, 2, 3, 17, 11181, '2022-04-17', 'Dedicated to LTC (r) André Donzeau, a great rider and a very good friend.', 70, '800/822/888/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (427, '1997-09-11 22:00:00+00', '2022-04-18 20:15:16.57354+00', 'Bauld Buccleuch', 'BAULD BUCCLEUCH', 2, 32, 9999, 3, 5, 30, 13, NULL, '', 94, '80808/88888/88888/52225', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20772, '2022-04-18 21:24:44.128444+00', '2022-04-18 21:24:44.128444+00', 'DU3A UR30', 'DU3A UR30', 2, 32, NULL, 5, 2, NULL, 12121, '2022-01-01', 'Written in 2022 to celebrate the 30th anniversary of the University of the Third Age (U3A) in Dundee.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9986, '2001-08-19 22:00:00+00', '2022-04-18 21:49:19.292166+00', 'Civil Engineer, The', 'CIVIL ENGINEER', 1, 32, 9999, 1, 4, 2, 2694, '2001-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20771, '2022-04-18 11:46:16.987452+00', '2022-04-19 07:21:51.219751+00', 'Let''s Have Music and Dance', 'LETS HAVE MUSIC AND DANCE', 1, 32, NULL, 1, 3, 42, 10325, NULL, '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18230, '2018-01-25 14:50:44.912154+00', '2022-04-20 08:36:35.148572+00', 'Spring Fling in Brittany, A', 'SPRING FLING IN BRITTANY', 1, 48, NULL, 2, 3, 17, 872, '2009-03-28', 'Devised by Marilyn Watson on 28/03/2009 for the "<<https://scots-bonnet.fr|Saint Quay Perros Group>>" in Brittany.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (986, '1998-04-05 22:00:00+00', '2022-04-26 01:48:52.694999+00', 'Campsie Glen', 'CAMPSIE GLEN', 3, 32, 9999, 1, 3, 42, 62, '1976-01-01', '', 50, '800/880/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13766, '2011-07-12 22:00:00+00', '2022-04-26 01:36:53.070657+00', 'Summer Meeting, A', 'SUMMER MEETING', 3, 32, NULL, 2, 3, 17, 10371, NULL, '»This dance is dedicated to TAC on their 50th Anniversary. ›A Summer Meeting‹ is named for those who meet at Summer School every year.«', 71, '848/646/088/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20826, '2022-05-14 18:41:23.665144+00', '2022-05-14 18:41:23.665144+00', 'Ann Gibb''s Strathspey', 'ANN GIBBS STRATHSPEY', 3, 32, NULL, 1, 4, 2, 99, '1990-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20836, '2022-05-14 22:36:14.357718+00', '2022-05-14 22:36:14.357718+00', 'Carole Menzies'' Reel', 'CAROLE MENZIES REEL', 1, 32, NULL, 1, 4, 2, 99, '1994-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20847, '2022-05-15 20:55:58.970851+00', '2022-05-15 20:55:58.970851+00', 'Belfast Hooley, The', 'BELFAST HOOLEY', 1, 32, NULL, 1, 4, 2, 99, '1994-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13132, '2006-12-05 23:00:00+00', '2022-08-13 20:12:03.174825+00', 'Nether Kellet', 'NETHER KELLET', 1, 32, 9999, 1, 4, 2, 104, '2005-03-01', 'Devised for Derek and Maureen Haynes (who lived in Nether Kellet, Lancashire, UK).', 87, '8888  8008  8888  8888', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (20773, '2022-04-22 12:12:56.335353+00', '2022-10-01 18:13:20.769226+00', 'Robb Quint of Thousand Oaks', 'ROBB QUINT OF THOUSAND OAKS', 2, 40, NULL, 2, 3, 17, 3179, '2022-04-11', '"I composed a tune one Sunday afternoon under the Ginkgo tree on our front lawn. When Robb posted about Ginkgo trees in Southern California, I knew that tune was meant for him. The dance to accompany the tune is a tribute to Robb and our friendship of many years via email. We even communicate in Afrikaans, my first and his ??? language.", Wouter said.', 57, '800/822/844/844/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20776, '2022-04-22 20:20:24.859318+00', '2023-01-24 11:16:30.557326+00', 'Normandale Ceilidh', 'NORMANDALE CEILIDH', 2, 32, NULL, 1, 4, 1, 11035, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20766, '2022-04-15 11:12:48.11635+00', '2022-12-01 14:51:27.253471+00', 'Trip to Ottawa', 'TRIP TO OTTAWA', 2, 32, NULL, 1, 3, 42, 316, '2010-01-01', '', 53, '800/888/822/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20775, '2022-04-22 20:18:45.448702+00', '2023-01-10 18:58:41.739403+00', 'Set the Table for Tea', 'SET THE TABLE FOR TEA', 2, 32, NULL, 1, 3, 42, 11035, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20774, '2022-04-22 20:18:00.782857+00', '2023-01-10 19:01:56.301394+00', 'Stranded in Sawtell', 'STRANDED IN SAWTELL', 3, 32, NULL, 1, 4, 1, 11035, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20777, '2022-04-22 20:21:06.476455+00', '2023-01-20 12:33:00.992885+00', 'Easy on the Brain', 'EASY ON THE BRAIN', 1, 32, NULL, 2, 3, 17, 11035, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16292, '2015-05-06 23:04:17.714986+00', '2022-04-25 20:12:17.682577+00', 'Bag o'' Shells', 'BAG O SHELLS', 3, 32, NULL, 1, 2, 76, 2766, '2009-02-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20778, '2022-04-22 23:20:40.949135+00', '2022-04-22 23:30:40.224679+00', 'Ardbiel Strathspey, The', 'ARDBIEL STRATHSPEY', 3, 40, NULL, 2, 3, 17, 11863, '2021-10-01', 'Dance devised by Peter Jamieson and Ruth MacInnes to celebrate the October 2021 house warming of “Ardbiel” a beautiful home built by Fiona MacDonald at Farley, near Beauly in Ross-Shire.  

  

The movements in the dance represent some of the elements of the build.  

  

_Bars 1-8_ represent the complex negotiations with Highland Council Planning and Building Control departments to gain planning permission and building warrant for the innovative design.  

  

_Bars 9-16_ represent the extensive mixing of the natural lime based building materials.  

  

_Bars 17-24_ represent the raising of the beautiful arches which define the shape of the house and support the roof.  

  

_Bars 25-32_ represent the travails of finally getting the completion certificate. (We couldn’t think of any way to elegantly represent the breaking of the laptop…)  

  

_Bars 33-40_ represent the gathering of friends for the house warming.', 65, '880/840/808/828', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18926, '2018-10-09 14:03:22.560623+00', '2022-04-25 20:14:43.518319+00', 'Ultimate Brief, The', 'ULTIMATE BRIEF', 3, 32, NULL, 1, 2, 76, 2766, '2010-08-01', 'The name of this dance comes from the fact that it may be briefed in 4 words: poussette, knot, bourrel, allemande.', -1, '88/88/88/88', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18683, '2018-10-02 00:50:38.268481+00', '2022-04-25 20:18:26.015759+00', 'Blood Moon, The', 'BLOOD MOON', 3, 32, NULL, 2, 3, 17, 2766, '2015-09-01', 'I wanted to try a 6-person reel and we had an eclipse on the moon on Sunday, September 27th – a super blood moon.', 92, '880/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20779, '2022-04-24 08:56:42.770214+00', '2022-04-24 22:34:14.511323+00', 'Broadford Strathspey, The', 'BROADFORD STRATHSPEY', 3, 32, NULL, 2, 2, 76, 11863, NULL, 'Devised by Ruth MacInnes and Peter Jamieson as a simple dance to use for teaching the Broadford Bay centrepiece.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13594, '2010-09-15 22:00:00+00', '2022-04-25 08:36:18.809598+00', 'Reel Archie, The', 'REEL ARCHIE', 1, 32, 9999, 1, 4, 2, 10613, '2007-03-01', 'Dance composed for Archie McKechnie''s 75th Birthday.  

In some sources the dance is attributed to an Alec Taylor.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17884, '2017-07-06 19:54:37.512247+00', '2022-04-25 17:02:02.657982+00', '42 Years and Out', '42 YEARS AND OUT', 3, 32, NULL, 1, 3, 42, 2766, '2013-11-01', 'I wrote this dance to celebrate my retirement and looking forward to no more commutes or schedules after 42 years working full time. The dance contains some of my favorite figures.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10269, '2001-11-25 23:00:00+00', '2022-04-25 17:07:49.730591+00', 'Ampersand', 'AMPERSAND', 3, 32, 9999, 1, 3, 42, 2766, '2001-11-01', 'This dance was named because the figure danced by 1M in bars 9-16 reminds me of the ampersand (''&'') character.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19956, '2020-04-15 19:29:51.28865+00', '2022-04-25 20:09:45.759201+00', 'Famiglia Graziani, La', 'FAMIGLIA GRAZIANI', 3, 32, NULL, 2, 2, 76, 11237, '2020-04-10', 'It may be danced just twice in a two couple set or as usual in a three or four couple set as preferred. It is a busy dance so a three couple set is probably ideal.



During the Corona virus lockdown the Graziani family in Bologna have been making one video per day of a two couple RSCDS dance published on their <<https://www.youtube.com/channel/UCyojdYqjbxETi1C5mFptXtg/videos|youtube channel>>. It has been lovely to watch this series so this dance is offered as a thank-you. And also in case they run out of RSCDS dances to try!



There is a 6x32 recording by <<ddp:#11858>> of the music for this dance available via <<https://my.strathspey.org/u/murrough/recording/>>.', 67, '88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5464, '1998-10-15 22:00:00+00', '2022-04-25 20:11:17.399856+00', 'Ram''s Horn, The', 'RAMS HORN', 3, 24, 9999, 1, 2, 76, 1192, '1984-01-01', '<<ddp:Iain Boyd#44>> notes in <<http://my.strathspey.org/dd/issue/1918/|issue 1918>>:



*The dancers should not hesitate at the end of the right hands across but flow smoothly into the cast to the left.*



*The instructions to remain in the middle with hands joined were included to ensure that the cast started from the middle and not from the sidelines.*



*The half poussette should start from the middle rather than from a diagonal line. The diagram in the original publication clearly shows where dancers should finish the promenade movement.*



*The dance was published before the Society decided that the half poussette should start from a diagonal line.*



*It would be appreciated if dancers respected the devisor''s original instructions.*', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12542, '2005-10-09 22:00:00+00', '2022-04-25 20:23:55.356352+00', 'Jean Martin of Aberdeen', 'JEAN MARTIN OF ABERDEEN', 3, 32, 9999, 2, 3, 17, 1502, '2004-01-01', '', 63, '844  888  888  808', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (15248, '2013-11-13 21:33:05.898571+00', '2022-04-25 20:27:48.893345+00', 'Laurelwood', 'LAURELWOOD', 3, 32, NULL, 2, 3, 17, 3431, '2006-05-31', 'Leaflet', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20, '1997-04-03 22:00:00+00', '2022-04-26 00:00:46.547599+00', 'Achamore House', 'ACHAMORE HOUSE', 3, 32, 9999, 1, 4, 1, 370, NULL, '', 81, '8444/8822/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14456, '2012-06-12 13:45:43.200702+00', '2022-04-26 01:18:43.658079+00', 'Lord Brownlow''s Strathspey', 'LORD BROWNLOWS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 10628, '2010-01-01', 'A bit of background on Lord Brownlow and Berkhamsted. He owned the Ashridge estate not far from Berkhamsted. He had a waiting room at Berkhamsted railway station where the Berkhamsted club used to meet in the 1950s before they moved to Potten End Village Hall.



From the dance description:  

Adelbert Wellington Cust, 3rd Earl Brownlow (1844-1921), inherited Ashridge House and the large estate and lived there with his wife Countess Adelaide Brownlow. By all accounts he also had his own Railway Waiting Room in which Berkhamsted Strathspey & Reel Club in the early days ofthe club met on Saturday nights to dance!', 66, '880/808/888/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19872, '2020-03-09 17:30:09.36998+00', '2022-04-26 01:20:32.772818+00', 'Lydia''s Magic Garden', 'LYDIAS MAGIC GARDEN', 3, 32, NULL, 2, 3, 17, 10568, '2019-08-01', '', 71, '880/880/848/808', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16103, '2015-02-21 17:50:14.812461+00', '2022-04-26 01:26:44.825731+00', 'Mr Donald Davidson', 'MR DONALD DAVIDSON', 3, 32, 9999, 2, 3, 17, 11091, NULL, 'Devised by Jody Williams and inscribed to Mr. Donald Davidson, a most dedicated Dancer, on his birthday.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15710, '2014-12-03 05:58:19.82978+00', '2022-04-26 01:27:41.167841+00', 'Orange to Aotearoa', 'ORANGE TO AOTEAROA', 3, 32, NULL, 2, 3, 17, 11035, '2013-01-01', 'Devised 2013 for Christine Grobler of the Orange County Branch, Orange County, California', 54, '800/880/822/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19247, '2019-03-23 10:38:06.735724+00', '2022-04-26 01:29:25.240072+00', 'Peter Knight''s Strathspey', 'PETER KNIGHTS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 11454, '2019-01-01', 'Devised to celebrate the 80th birthday of <<ddp:Knight, Peter#218>>, the editor of A Guide to Scottish Country Dancing, formerly known as Collins.   It was danced for the first time at St Columba''s Church London in January 2019, as a demonstration at Peter''s 80th birthday party.', 75, '880/880/888/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19236, '2019-03-08 23:33:18.252094+00', '2022-04-26 01:31:29.945497+00', 'Reels Aplenty', 'REELS APLENTY', 3, 32, NULL, 2, 3, 17, 165, NULL, '', 67, '822/844/866/808', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15277, '2013-12-07 20:51:20.321532+00', '2022-09-26 22:53:32.677003+00', 'Dr. Quarrie''s Birthday', 'DR QUARRIES BIRTHDAY', 3, 32, NULL, 2, 3, 17, 1760, '2008-02-01', 'DATE:2008-02', 50, '880/844/844/808', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19905, '2020-03-24 22:07:16.238049+00', '2022-08-22 23:33:57.446256+00', '18th of November, The', '18TH OF NOVEMBER', 3, 32, NULL, 1, 3, 42, 2766, '2018-11-18', 'To celebrate my 70th birthday and incorporating some of my favorite figures. I love how the knot flows into the bourrel.  



Suggested music is *Don on Yon Bank* from Heather Hills by Mara Shea and Dave Wiesler.', 50, '880/880/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14599, '2012-11-07 14:30:47.784627+00', '2022-04-26 01:55:39.793465+00', 'Fleur de Lyon, La', 'FLEUR DE LYON', 3, 32, NULL, 1, 3, 42, 12020, '2007-04-01', 'This dance was a present to Maguy from her friends Stephen, Nicole and Ken. Maguy was given it on 7 April 2007 along with a recording of her tune. Maguy was very touched by this. The dance’s name describes Maguy well as she always wore bright colours, turquoise being her favourite.

The dance was devised to celebrate her love of life and SCD. Maguy loved slow airs and her favourite figures were the poussette all round, the bourell and tandem reels and these figures form the basis of this dance.

Stephen danced this dance with Maguy in Lyon on 25 May 2007. Maguy took SCD to heaven in July 2007. ', 56, '880/844/888/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2021, '1998-04-11 22:00:00+00', '2022-04-26 08:38:53.195826+00', 'Expert Dancer, The', 'EXPERT DANCER', 3, 32, 9999, 1, 3, 42, 62, '1982-01-01', 'Inscribed to "fellow teacher and long-time friend, June Shore."', 47, '880/800/844/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2687, '1998-04-12 22:00:00+00', '2022-04-26 14:55:34.588396+00', 'Grey Wanderer, The', 'GREY WANDERER', 3, 48, 9999, 1, 102, 2, 44, '1982-01-01', '', 92, '8888/4444/8888/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18387, '2018-06-19 16:16:48.439336+00', '2022-04-26 15:02:28.688914+00', 'Lisou''s Strathspey', 'LISOUS STRATHSPEY', 3, 32, NULL, 1, 4, 1, 11644, '2018-01-01', '', 56, '8000/8800/8044/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2323, '2000-08-30 22:00:00+00', '2022-04-26 09:08:19.285947+00', 'Frae A'' the Airts', 'FRAE A THE AIRTS', 4, 32, 1, 1, 3, 42, 62, '1978-01-01', 'The RSCDS description (presumably by the deviser) notes: "Written for the ''South Pacific Fling'' dancers from Canada to dance while in New Zealand and Australia" - thereby setting the stage for the idea that the society pursued in books 36 & 37.', 59, '880  880  888  866', 0, 1, 0, 0, 79);
INSERT INTO 'dance' VALUES (17921, '2017-08-23 11:18:54.920874+00', '2022-04-26 09:12:48.970689+00', 'Kirsten''s Jig', 'KIRSTENS JIG', 2, 32, NULL, 1, 3, 42, 401, '2015-01-01', 'This dance was commissioned for Kirsten Steinbach, the committed long-time secretary of the Freiburg Scottish Country Dancers on the occasion of a special birthday. It was presented to her during a course she had organized in 2015 featuring Ron Wallace and Muriel Johnstone.', 56, '880/844/888/880', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3665, '1997-09-07 22:00:00+00', '2022-04-26 09:13:54.779519+00', 'Lake Geneva', 'LAKE GENEVA', 3, 32, 9999, 1, 3, 42, 361, NULL, 'Kent Smith writes:  My use of the figure [9-20] was inspired by "The Three Rivers Reel" by Martin Mulligan.



Both on bars 12 and 16 1W and 3M pass Lsh and face R into the next half reel.  There is a variant where they pass a tight Lsh 3/4 round each other and face L; they thus change roles in the half reel across for [12-16].  From then on the variants are identical again. Eric Ferguson, march 2015. ', 53, '848/646/808/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18977, '2018-10-17 11:05:48.055219+00', '2022-04-26 09:16:12.610521+00', 'Marian Cook''s Strathspey', 'MARIAN COOKS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11362, NULL, '', 56, '888/800/880/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16626, '2015-08-27 13:41:55.879682+00', '2022-04-26 09:17:29.115162+00', 'Mayne Event, The', 'MAYNE EVENT', 1, 32, NULL, 1, 3, 42, 3703, NULL, '', 63, '880/888/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17321, '2016-09-09 19:47:27.138552+00', '2022-04-26 09:21:16.251814+00', 'Peat Road, The', 'PEAT ROAD', 1, 32, NULL, 1, 3, 42, 10959, '2011-01-01', 'The Peat Road was chosen as the 50th Tartan Ball Reel to celebrate 50 years of the Tartan Ball in the Royal York Hotel, Toronto. February 16th 2013



The Peat Road: is a narrow, single track road that twists & turns with few passing places & is the "short cut" between Finsbay & Leverburgh in South Harris, one of the islands of the Outer Hebrides in Scotland. The Peat Road winds along the shores of Loch Langabhat & over the moor, past the peat beds, where the crofters cut & stack the peat. Once dried, it is transported to their croft houses & used as fuel.', 63, '880/848/884/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5225, '1998-01-05 23:00:00+00', '2022-04-26 09:24:17.814047+00', 'Pet O'' the Pipers', 'PET O THE PIPERS', 1, 48, 9999, 1, 3, 42, 270, NULL, '', 54, '880/633/888/633/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9334, '2000-02-01 23:00:00+00', '2022-04-26 09:26:41.509652+00', 'Silver Anniversary, The', 'SILVER ANNIVERSARY', 3, 32, 9999, 1, 3, 42, 361, NULL, '', 50, '440/880/888/844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12396, '2005-04-28 22:00:00+00', '2022-04-26 09:29:19.411863+00', 'Sugar on Snow', 'SUGAR ON SNOW', 3, 32, 9999, 1, 3, 42, 2766, '2005-03-01', 'I grew up in northern Vermont and still remember a trip to the sugarhouse when I was small. A treat served there was sugar on snow – freshly boiled down maple syrup poured on clean snow.', 53, '808/880/844/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19258, '2019-04-06 00:33:49.287579+00', '2022-04-26 09:36:01.454057+00', 'Another Trip Around the Sun', 'ANOTHER TRIP AROUND THE SUN', 3, 40, NULL, 1, 4, 22, 11801, '2019-02-01', 'Devised by Ray McEward with valued assistance of Marjorie McLaughlin and Ward Fleri, Feb 2019   



Tunes chosen by Andy Imbrie.  



This dance is dedicated to Ms. Jeanne V. Moody on the occasion of her 40th birthday. The best is yet come! May there be many more trips around the sun for you.



The San Diego 45th Anniversary book (2020) gives the title as "Another Trip Around the Sun" but the earlier online source URL (2019) has "''round" instead of "Around". This is added as a spelling alias.', 82, '8888/8888/8228/8008/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11450, '2003-09-22 22:00:00+00', '2022-04-26 09:38:46.230939+00', 'Bit o'' Birl, A', 'BIT O BIRL', 3, 32, 9999, 4, 4, 13, 2766, '2002-02-01', '', 63, '8008/8008/0880/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3383, '2002-04-19 22:00:00+00', '2022-04-26 09:40:20.537421+00', 'Dance Called Irene, A', 'DANCE CALLED IRENE', 3, 32, 9999, 1, 4, 2, 401, '1996-01-01', '', 81, '8888/8448/8008/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10768, '2002-11-24 23:00:00+00', '2022-04-26 09:44:51.365731+00', 'Dancing Thistles', 'DANCING THISTLES', 3, 32, 9999, 1, 4, 2, 3179, '2002-01-01', 'Devised in honour of the 30th Anniversary of the Pretoria Branch, 2002.  The club emblem is the Dancing Thistle.  Suggested level: Advanced.', 89, '8686/8888/8888/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12429, '2005-05-05 22:00:00+00', '2022-04-26 10:16:30.820021+00', 'Double Dutch', 'DOUBLE DUTCH', 3, 32, 9999, 1, 4, 2, 2793, '2002-01-01', '', 69, '8008  8888  8448  8008', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (19084, '2018-12-06 13:03:49.276864+00', '2022-04-26 14:53:41.464+00', 'Glen Pavilion, The', 'GLEN PAVILION', 3, 32, NULL, 1, 100, 2, 11760, '2017-01-01', 'The Glen Pavilion in Pittencrieff Park is where the Branch holds its annual Ball.  



The dance was devised as an elegant and sociable dance, with dancers meeting

and giving hands to many other dancers.  

', 79, '8888/8448/8888/8008', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18521, '2018-08-23 10:33:13.305019+00', '2022-04-26 15:03:48.523664+00', 'Martin''s Farewell', 'MARTINS FAREWELL', 3, 32, NULL, 1, 4, 1, 11678, '2018-01-01', 'A memorial dance for Martin Norgate who not only danced and taught in Cumbria but danced with Schiehallion for many years.', 83, '8020/8888/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18036, '2017-10-27 23:25:14.106037+00', '2022-04-26 15:09:22.241629+00', 'Mentors, The', 'MENTORS', 3, 80, 9999, 4, 4, 3, 11236, '2015-05-01', 'This dance was devised for David and Avril Quarrie, two wonderful teachers and mentors who always know how to help dancers learn and improve, and how to make them feel they belong.

', 70, '4444/4444/8080/8080/0808/0808/8888/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19442, '2019-06-29 13:36:50.47353+00', '2022-04-26 19:22:52.169535+00', 'Orillia''s Own', 'ORILLIAS OWN', 3, 32, NULL, 1, 4, 2, 2766, '2017-07-01', 'Gordon Lightfoot sang Farewell to Nova Scotia on a pirate album and I loved the tune; it is the 4th tune on this track.

  	', 88, '8888/8008/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18078, '2017-11-21 18:05:43.494166+00', '2022-09-27 23:05:30.190377+00', 'From Finland to Bavaria', 'FROM FINLAND TO BAVARIA', 2, 32, NULL, 1, 3, 42, 3775, NULL, 'This dance was devised on the occasion of the wedding of Ramona and Matthias. The chase and the circle symbolize the wedding rings', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20780, '2022-04-25 23:56:35.220233+00', '2023-01-05 19:06:31.840285+00', 'Take 10', 'TAKE 10', 1, 32, NULL, 3, 5, 7, 11225, '2022-04-01', 'For the 10th anniversary of the Lisbon Lapa group.', 70, '80800/88888/80800/88888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17349, '2016-09-14 23:08:39.114493+00', '2022-04-26 19:27:34.023406+00', 'Pitlochry Lassies', 'PITLOCHRY LASSIES', 3, 32, 9999, 1, 100, 2, 2793, '2009-10-01', 'The dance was devised by Ruth Taylor from Kingston, Ontario to accompany the tune "Ruth Frae Pitlochry" written for her by Muriel Johnstone. 



"The dance is dedicated to all the Scottish Country Dancing Lassies of Pitlochry - past, present, future - especially my mother, Lillie Donald, and my dear friend, Ruth Cunnison, the other ''Ruth frae Pitlochry''".



The dance had been nominated for RSCDS Book 48.', 87, '8888/8888/8008/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5679, '2000-08-01 22:00:00+00', '2022-04-26 19:29:21.092855+00', 'Rosebud In My Garden, A', 'ROSEBUD IN MY GARDEN', 3, 32, 9999, 1, 4, 11, 651, '1993-09-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13755, '2011-07-11 22:00:00+00', '2022-04-26 19:32:40.499494+00', 'Sunshine Sally', 'SUNSHINE SALLY', 3, 32, NULL, 1, 4, 1, 2973, '2007-03-01', 'Devised March 2007, to honour long-time dancer and Branch stalwart, Sally Freedman. The title was chosen as Sally has a collection of ''Suns'' in her house. Moreover Sally always has warm welcome for new people and new ideas.', 94, '8888  8888  8888  8088', 0, 1, 0, 0, 93);
INSERT INTO 'dance' VALUES (14436, '2012-05-09 13:36:21.260166+00', '2022-04-26 20:02:58.376172+00', 'Dilemma, The', 'DILEMMA', 4, 96, 54, 2, 3, 17, 15, NULL, '', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19704, '2019-10-23 21:30:54.126314+00', '2022-04-26 20:18:29.802025+00', 'Dancing in Avalon', 'DANCING IN AVALON', 3, 32, NULL, 1, 2, 76, 11890, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8590, '1998-03-30 22:00:00+00', '2022-04-26 20:25:47.995795+00', 'In the Buff', 'IN THE BUFF', 3, 32, 9999, 1, 2, NULL, 2018, '1997-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8315, '1998-03-30 22:00:00+00', '2022-04-26 20:28:17.311485+00', 'Lover''s Quarrel', 'LOVERS QUARREL', 2, 32, 9999, 1, 2, NULL, 2018, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12485, '2005-07-24 22:00:00+00', '2022-04-26 20:37:05.513334+00', 'Oregon Spring', 'OREGON SPRING', 3, 32, 9999, 1, 3, 42, 2766, '2005-07-01', 'This dance is named for one of the types of tomatoes we planted in our yard this season.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16367, '2015-05-21 10:13:43.882504+00', '2022-04-26 20:43:05.151834+00', 'Weel Bobb''d', 'WEEL BOBBD', 3, 32, 9999, 1, 4, 1, 2018, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16231, '2015-05-01 10:39:05.265489+00', '2022-04-26 21:02:50.138304+00', 'Farewell to St Kilda', 'FAREWELL TO ST KILDA', 3, 40, 9999, 1, 4, 1, 84, '2014-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (7171, '1997-09-17 22:00:00+00', '2022-04-26 23:17:13.048978+00', 'Willie Whyte O'' Fife', 'WILLIE WHYTE O FIFE', 3, 32, 9999, 1, 2, 76, 1075, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9470, '2001-11-25 23:00:00+00', '2022-04-26 23:18:39.962982+00', 'Down Side Up', 'DOWN SIDE UP', 1, 32, 9999, 1, 3, 42, 108, '1999-05-01', 'Inscribed "for the dancers in the Antipodes". 3rd couple are the active couple.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13911, '2011-08-22 22:00:00+00', '2022-04-27 00:01:06.45496+00', 'Greetings Malcolm', 'GREETINGS MALCOLM', 3, 32, NULL, 1, 3, 42, 3179, '2003-01-01', 'In honour of Malcolm Brown, both friend and invaluable source for my many dancing queries.', 69, '880/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20789, '2022-04-27 22:21:22.715008+00', '2022-04-27 22:21:22.715008+00', 'Purmamarca Market', 'PURMAMARCA MARKET', 3, 32, NULL, 1, 4, 1, 2101, '2020-05-01', '', 91, '8282/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20019, '2020-06-16 20:31:05.920526+00', '2022-07-11 12:05:11.233075+00', 'Alison Hogg Strathspey', 'ALISON HOGG STRATHSPEY', 3, 32, NULL, 1, 4, 1, 11415, NULL, 'This dance has been devised for Alison Hogg, who lives in Salisbury. She requested a strathspey containing a bourrel.', 75, '8888/8080/8044/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12947, '2006-10-22 22:00:00+00', '2022-04-27 11:31:17.612882+00', 'Wee Birl, A', 'WEE BIRL', 3, 32, 9999, 2, 3, 17, 2793, '2000-01-01', 'Devised in response to a request by the Brockville Scottish Country Dancers for a new dance to include in the Brockville Christmas 2000 Social program.', 75, '880/880/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17166, '2016-08-17 17:56:40.063843+00', '2022-04-27 12:40:40.519095+00', 'Lass Frae Laurel, A', 'LASS FRAE LAUREL', 3, 32, NULL, 1, 3, 42, 2823, '2009-10-01', 'For Elaine Brunken, who is a lass from Laurel, Maryland.', 52, '880/800/855/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20781, '2022-04-27 21:16:09.421917+00', '2022-05-03 23:18:17.112114+00', 'Welcome to Argentina', 'WELCOME TO ARGENTINA', 2, 32, NULL, 1, 3, 42, 2101, '2019-10-01', 'This dance was written for the workshop I taught in Buenos Aires in October 2019.', 58, '811/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20784, '2022-04-27 21:31:35.13957+00', '2022-04-27 21:31:35.13957+00', 'Salinas Grandes', 'SALINAS GRANDES', 1, 32, NULL, 1, 3, 42, 2101, '2020-05-01', '', 72, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20787, '2022-04-27 21:52:44.261856+00', '2022-04-27 21:52:44.261856+00', 'Florida Street "Cambio Cambio"', 'FLORIDA STREET CAMBIO CAMBIO', 3, 32, NULL, 1, 4, 1, 2101, '2020-05-01', '', 67, '770/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20791, '2022-04-27 22:40:36.481501+00', '2022-05-04 14:37:47.070453+00', 'Charly''s Strathspey', 'CHARLYS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 2101, '2020-04-01', 'Written for Charly Candia to include his favourite formations.', 83, '880/888/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20790, '2022-04-27 22:30:12.731068+00', '2022-04-27 22:30:12.731068+00', 'Jacarandas of Buenos Aires, The', 'JACARANDAS OF BUENOS AIRES', 3, 32, NULL, 2, 3, 17, 2101, '2020-05-01', '', 71, '800/866/888/808 ', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20793, '2022-04-27 22:48:49.028571+00', '2022-04-27 22:48:49.028571+00', 'Four Spoons, The', 'FOUR SPOONS', 3, 32, NULL, 4, 4, 13, 2101, '2020-04-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16591, '2015-08-26 15:18:54.701205+00', '2022-04-28 03:47:08.488547+00', 'Queen of Victoria', 'QUEEN OF VICTORIA', 3, 32, 9999, 1, 3, 42, 2115, NULL, 'The birl, a progression introduced in 1976 by Bob Campbell of Oakville in his dance, <<ddd:Campsie Glen#986>>, is also referred to as the ''bourrel'',  

For many years, June Shore lived with her husband, Sam, on Victoria Avenue in Hamilton. There, she

undoubtably reigned as Queen. with Sam as her consort. The figures of the dance exemplify her courtly

and regal manner.', 53, '880/844/844/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10118, '2001-10-30 23:00:00+00', '2022-04-28 09:08:41.693386+00', 'Dance Odyssey, A', 'DANCE ODYSSEY', 1, 32, 9999, 3, 5, NULL, 2950, NULL, 'Devised for the 26th Australian Winter School held in St. Lucia, Brisbane, 2001.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6268, '1997-04-03 22:00:00+00', '2022-04-28 18:29:55.929252+00', 'Squirrels in the Spinney, The', 'SQUIRRELS IN THE SPINNEY', 3, 32, 9999, 1, 3, 42, 48, '1991-01-01', 'Inscribed "For Doreen and Roy White of The Spinney, Carr Bridge".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20827, '2022-05-14 18:44:46.987135+00', '2022-05-14 18:44:46.987135+00', 'Broomellon', 'BROOMELLON', 2, 32, NULL, 1, 3, 42, 99, '2007-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20794, '2022-04-27 22:52:18.980301+00', '2022-05-04 12:20:18.89412+00', 'Barolo Palace Tower', 'BAROLO PALACE TOWER', 4, 64, 5, 4, 4, 1, 2101, '2020-03-01', 'Barolo Palace is a beautiful building in Buenos Aires. It was a challenge for me as I do not like heights. However, I was coaxed unwillingly to the top up winding, narrow stairs and had to sit precariously on a narrow ledge at the top of a lighthouse structure.  

The view of the city was amazing.  

An unforgettable afternoon. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20788, '2022-04-27 21:55:57.988434+00', '2022-05-05 09:10:56.092221+00', 'Siete Colores', 'SIETE COLORES', 3, 32, NULL, 1, 4, 1, 2101, '2020-05-01', 'The Siete Colores is a hill of 7 colours at Purmamarca. Each rock colour is said to have formed during different time periods. The patterns in this dance depict the layers of rocks.', 80, '4884/8888/8008/8688 ', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20783, '2022-04-27 21:27:14.265117+00', '2022-05-08 01:54:51.310008+00', 'On the Tropic of Capricorn', 'ON THE TROPIC OF CAPRICORN', 2, 32, NULL, 1, 3, 42, 2101, '2020-03-01', 'To commemorate standig on the Tropic of Capricorn in the Province of Jujuy October 2019.', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20837, '2022-05-14 22:40:38.304283+00', '2022-05-14 22:40:38.304283+00', 'Mistress Dean''s Rant', 'MISTRESS DEANS RANT', 3, 32, NULL, 1, 4, 2, 99, '1994-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4348, '1997-04-03 22:00:00+00', '2022-08-17 18:01:07.815749+00', 'Michener Strathspey, The', 'MICHENER STRATHSPEY', 3, 32, 9999, 1, 3, 42, 361, '1988-09-01', '"Dedicated 10 Gail Michener."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8407, '1998-01-04 23:00:00+00', '2022-08-17 18:10:34.72809+00', 'Blessing of the Arms, The', 'BLESSING OF THE ARMS', 3, 32, 9999, 1, 4, 2, 35, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9427, '2000-05-17 22:00:00+00', '2022-08-17 18:17:44.935418+00', 'Bombadil, Maggot and Mushrooms', 'BOMBADIL MAGGOT AND MUSHROOMS', 2, 40, 9999, 3, 5, 7, 2203, '1999-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11620, '2003-12-04 23:00:00+00', '2022-08-17 18:31:57.330636+00', 'Loralee Hyde', 'LORALEE HYDE', 3, 32, 9999, 1, 4, 15, 2682, '1996-01-01', 'Inscribed "Loralee is a good friend living in Wellington, New Zealand."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19362, '2019-05-25 21:55:10.613181+00', '2022-04-28 21:27:10.07865+00', 'John of Dumbarton', 'JOHN OF DUMBARTON', 3, 40, NULL, 2, 3, 18, 11150, '2019-01-01', 'In bars 33-36, for the touch nearer hands, the deviser Isabel Neves wants people to touch palms with fingers pointing upwards and maintaining contact for as long as possible, roughly two bars.



The dance was devised in memory of John Corcoran who died in 2018. He was one of the directors of St Andrews College Summer School, in Bearsden.



The deviser writes that he was "a great man, very active in his community. And very nice and kind. He would take me on trips and almost make me feel I was Scottish, not a tourist. The closest I had to a Scottish father.  I felt like a real Scot on a weekend trip the few times he took me somewhere. My first fish and chips, in Callander, ice cream in beautiful Luss come to mind. And he took a day to take me to Loch Katrine, to do the tour on the steamship I''ve been dreaming of since I was eighteen."', 67, '800/844/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6264, '1997-04-03 22:00:00+00', '2022-05-06 20:39:23.571368+00', 'Square Root', 'SQUARE ROOT', 3, 64, 9999, 4, 4, 3, 159, NULL, 'This is a palindromic dance in phrases of 2+2+4, 4+4, 8, 8, 8, 8, 4+4, 4+2+2.', 94, '8484/8888/8888/8888/8888/8888/8888/4848', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20795, '2022-04-30 18:55:21.880308+00', '2022-04-30 19:14:04.654805+00', 'Do What I Mean, Not What I Say!', 'DO WHAT I MEAN NOT WHAT I SAY', 1, 32, NULL, 1, 3, 42, 12123, '2022-03-01', 'A dance in memory of Ron Nedderman of Cambridge, reflecting on one of his favourite sayings when teaching the Foss and Drewry class.



The dance consists of two 32 bar parts. In the the first "as I say" version all three couples end on opposite sides after the first 8 bars and dance bars 9-24 on opposite sides whereas in the second "as I mean" version they end on own sides on bar 8.



This could be considered as a 4x64 bar dance but the deviser prefers it as 8x32 as it would be possible for sets to dance just the "right" second part.

', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1639, '1998-01-11 23:00:00+00', '2022-04-30 19:23:14.750325+00', 'Devorgilla''s Delight', 'DEVORGILLAS DELIGHT', 2, 32, 9999, 1, 3, 42, 108, '1977-01-01', 'Incribed "for Lena Barclay of Aberdeen, formerly of Dumfries".



From Drewry''s notes: Devorgilla was the wife of John de Balliol, the founder of Balliol College, Oxford. She built the old footbridge across the Nith in Dumfries and, after her husband''s death, she founded Sweetheart Abbey.', 53, '848/484/844/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20804, '2022-05-04 00:48:04.339197+00', '2022-09-06 10:43:53.313694+00', 'Mei schazzal is no füü zu glaa', 'MEI SCHAZZAL IS NO FUU ZU GLAA', 1, 32, 9999, 1, 2, 76, 523, '2022-01-25', 'The dance title means "My love, she’s but a Lassie yet" in Viennese dialect.  



From the dance description: Inspired by Marian Anderson’s version of the music on her CD "Robert Burns Dances" during preparations for an online Burns Night; inscribed to Joanna Janiska who shared her book of Burns poems in Viennese and researched the title.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20049, '2020-07-14 11:07:03.680429+00', '2022-05-02 23:29:35.693397+00', 'Kathy''s Fascinator', 'KATHYS FASCINATOR', 2, 32, NULL, 2, 3, 17, 11356, '2020-01-01', 'To celebrate Kathy Warren’s love of dance and friendship

An alternate version for the last 8 bars is perhaps better.

1st couple set, cast off as the 3rd couple step up. 

All three couples dance back to back. 

- LRH', 75, '880/844/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20797, '2022-05-03 19:48:35.676669+00', '2022-05-03 19:48:35.676669+00', 'Claverhouse Rant', 'CLAVERHOUSE RANT', 1, 32, NULL, 1, 4, 1, 11858, NULL, '', 81, '8448/8888/8800/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20799, '2022-05-03 20:14:05.99414+00', '2022-05-03 20:14:05.99414+00', 'Trinity Launch', 'TRINITY LAUNCH', 3, 32, NULL, 1, 4, 1, 11858, NULL, '', 52, '8000/8262/8000/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20800, '2022-05-03 20:29:29.273109+00', '2022-05-03 20:29:29.273109+00', 'Across the Waves', 'ACROSS THE WAVES', 1, 32, NULL, 1, 4, 1, 11858, NULL, '', 63, '8484/8080/8000/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20801, '2022-05-03 20:48:53.425136+00', '2022-05-03 20:48:53.425136+00', 'Ready Aye Ready', 'READY AYE READY', 1, 32, NULL, 4, 5, 95, 12125, NULL, '', 65, '88888/80008/88888/42442', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20802, '2022-05-03 21:50:06.20903+00', '2022-05-03 21:50:06.20903+00', 'Coire Bhreacain', 'COIRE BHREACAIN', 3, 32, 9999, 4, 4, NULL, 12126, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20803, '2022-05-03 21:53:06.046109+00', '2022-05-03 21:53:06.046109+00', 'Way to St Andrews, The', 'WAY TO ST ANDREWS', 3, 40, 9999, 1, 4, NULL, 12126, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17114, '2016-06-30 21:26:26.574027+00', '2022-05-06 22:47:35.266227+00', 'Square Cooper, The', 'SQUARE COOPER', 2, 40, NULL, 4, 4, 1, 3590, '2005-01-01', '10 bar phrases', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11602, '2003-12-04 23:00:00+00', '2022-05-06 01:40:23.429265+00', 'Daisy Chain, The', 'DAISY CHAIN', 3, 32, 9999, 1, 3, 42, 2682, '1998-01-01', 'Information from the original description:

The dance was devised in June 1998 as a teaching dance to introduce ''ladies'' chain''. Recommended music is a strong strathspey such as "Bonnie Flowers o''er the Muir" with a suitable recording being by the Berkeley Players "None So Pretty".

Daisy Macdonald Fanning is the niece of Rod Downey. The dance celebrates her birth.  



Originally "Bonnie Flowers O''er the Muir" was assigned as tune for the dance, which is the name of the suitable recording. The lead tune of this recording, however, has a different name. Rod Downey has realized this and had the tune corrected to "Barbara Rae", the correct lead tune of the recording "Bonnie Flowers O''er the Muir".', 56, '888/880/880/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2026, '1997-09-02 22:00:00+00', '2022-05-07 20:43:49.900864+00', 'Faa Patteran, The', 'FAA PATTERAN', 3, 32, 9999, 1, 3, 42, 856, NULL, 'The "Faa" of the title is thought to refer to John Faa, king of the Gypsies at the time of James V of Scotland, while "Patteran" means signs used by Roma people. See <<https://en.wikipedia.org/wiki/John_Faa>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16007, '2015-02-09 13:20:09.929845+00', '2022-05-07 21:26:29.655254+00', 'Mohonk Welcome, The', 'MOHONK WELCOME', 1, 32, 9999, 5, 2, 30, 11070, '2000-01-01', 'According to <<https://my.strathspey.org/dd/issue/2783/|Issue 2783>> Bob Houghton prefers recordings from "Don Bartlett and the Scotians Play Favourites".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20805, '2022-05-06 22:35:42.301005+00', '2022-05-07 22:38:11.550856+00', 'Sam''s Butter Churn', 'SAMS BUTTER CHURN', 3, 32, NULL, 1, 2, 76, 3745, '2013-01-01', 'Source: MiniCrib.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20782, '2022-04-27 21:21:29.295864+00', '2022-06-26 16:52:09.497406+00', 'Road to Cafayate, The', 'ROAD TO CAFAYATE', 2, 32, NULL, 1, 3, 42, 2101, '2020-04-01', 'I went on a day trip to Cafayate from Salta. The journey followed many winding roads and this dance reflects the bends and turns in the road. It wound its way through many multi-colored rocks with names like: the frog, castle, monk, Titanic sinking and the amphitheatre.  

This amazing journey travelled through mountains and then desert. It ended in the beautiful town of Cafayate. It is a centre of wine production and is 1,683 metres above sea level. ', 50, '888/800/844/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20796, '2022-04-30 20:53:02.058022+00', '2022-08-05 17:29:49.303696+00', 'Bickering Brattle', 'BICKERING BRATTLE', 1, 32, NULL, 2, 2, 76, 3599, '2011-12-01', 'Published in the May 2022 issue of <<ddpub:Set and Link#1290>>.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20798, '2022-05-03 19:59:30.752176+00', '2022-09-09 20:32:01.678823+00', 'Get Knotted', 'GET KNOTTED', 2, 32, NULL, 2, 3, 17, 11858, NULL, '', 50, '888/880/800/808', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4781, '1997-11-27 23:00:00+00', '2022-09-13 11:50:12.117521+00', 'Mrs MacArthur of Netherlee', 'MRS MACARTHUR OF NETHERLEE', 4, 64, 9999, 4, 4, NULL, 454, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18611, '2018-09-15 23:10:58.735559+00', '2022-05-08 07:33:30.691206+00', 'Slante, Austro-Alba', 'SLANTE AUSTROALBA', 1, 32, NULL, 2, 3, 18, 2018, '1998-01-01', 'Crib by the devisers is available at <<https://www.scottish-country-dancing-dictionary.com/dance-crib/slante-austro-alba.html>>.



This dance was first published in <<ddpub:#411>> under the name "Tune the Fiddles" but was later renamed "Slante, Austro-Alba" (and slightly revised).', 58, '080/484/484/448', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1915, '1997-09-01 22:00:00+00', '2022-05-08 09:14:44.040859+00', 'Edinburgh Strathspey, The', 'EDINBURGH STRATHSPEY', 3, 32, 9999, 1, 4, 1, 710, NULL, '', 91, '8888/8888/8888/8444', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20806, '2022-05-08 23:11:21.950869+00', '2022-06-25 08:43:47.650084+00', 'Lads of Lawers', 'LADS OF LAWERS', 2, 32, NULL, 1, 3, 42, 12155, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20807, '2022-05-08 23:19:18.463978+00', '2022-05-09 07:06:57.632566+00', 'Fifty Years Young... et alors ?', 'FIFTY YEARS YOUNG ET ALORS ', 4, 64, 5, 1, 3, 30, 12129, NULL, 'This dance was created for Sophie Marchand, the Scottish Country Dance teacher and president of the Méaudre Reel, on the occasion of her 50th birthday. Her adult SCD students surprised her with a first demo of this dance on April 4, 2022. This was an opportunity to thank her for her commitment to teaching SCD in the Vercors for more than 15 years. Through her dynamism and with a lot of patience, she has indeed brought the taste and the pleasure of dancing to dozens and dozens of students, young and old!', 38, '800/822/822/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13701, '2011-07-04 22:00:00+00', '2022-05-09 11:40:51.884563+00', 'Honeymoon in Scotland', 'HONEYMOON IN SCOTLAND', 4, 32, 1, 4, 4, 13, 479, '1986-01-01', 'The dedication reads: "This dance is dedicated to Mr. Minoru Okumura and Mrs. Shoko Okumura on their honeymoon trip to St. Andrews and other places of Scotland."



STRATHSPEY Bar 1-8 (Heart shape): They grew up without knowing each other. One day they met and

fell in love. Bar 9-16: Wedding ceremony. REEL Bar 1-4: Honeymoon trip to Scotland. Bar 5-16: Touring around and dancing in Scotland.', 95, '8888/8666/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20808, '2022-05-09 11:54:14.596364+00', '2022-05-09 11:54:14.596364+00', 'Abigail Grater''s Strathspey', 'ABIGAIL GRATERS STRATHSPEY', 3, 32, NULL, 1, 4, 2, 99, '2021-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16008, '2015-02-09 13:26:17.954388+00', '2022-05-09 11:56:12.154954+00', 'Warm Up Dance, A', 'WARM UP DANCE', 2, 32, 9999, 5, 2, 54, 11070, '2000-01-01', 'This is a 1x32 bar Jig used solely to teach slip step. Each couple slips down and back to place before both couples circle round and back.', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20817, '2022-05-09 17:30:18.747431+00', '2022-05-09 17:39:07.928353+00', 'Cober Hill Caper', 'COBER HILL CAPER', 1, 32, NULL, 1, 4, 1, 523, '2019-05-01', 'Inspired by the London Gay Gordons’ residential week at Cober Hill Hall, May 2019.



Although intended as a reel this dance may also be done (or practised) in strathspey time if preferred.', 62, '8800/8844/8088/8008', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20348, '2021-05-28 08:17:09.229436+00', '2022-05-09 12:10:26.841492+00', 'Reuben Freemantle''s Jig', 'REUBEN FREEMANTLES JIG', 2, 32, NULL, 1, 3, 42, 99, '2021-05-01', '', 56, '800/866/866/888', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20818, '2022-05-09 17:35:23.257629+00', '2022-05-09 17:41:12.450478+00', 'Re-jig for Covid', 'REJIG FOR COVID', 2, 40, NULL, 1, 4, 1, 523, '2021-07-01', 'Inspired by the way that Covid turned the world upside-down, preventing us from making contact with other people. The "moorland progression" is a modified version of the defining sequence in Muirland Willie and reminds us of the fact that we could only take our exercise "in nature". The 40 bars are a reference to quarantine.', 85, '8888/0880/8888/0888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20809, '2022-05-09 12:03:47.688704+00', '2022-05-09 14:05:41.268772+00', 'Janet Scott Swanston''s Jig', 'JANET SCOTT SWANSTONS JIG', 2, 32, NULL, 1, 3, 42, 99, '2021-07-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20811, '2022-05-09 14:39:12.766298+00', '2022-05-09 14:39:12.766298+00', 'Jonathan Wilson''s Reel', 'JONATHAN WILSONS REEL', 1, 32, NULL, 1, 3, 42, 99, '2022-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20812, '2022-05-09 14:48:15.913534+00', '2022-05-09 14:48:15.913534+00', 'Betsy Miller''s Hornpipe', 'BETSY MILLERS HORNPIPE', 1, 48, NULL, 1, 3, 42, 99, '1991-01-01', 'The notes say this dance commemorates "Elizabeth (Betsy) Miller (1792–1864) from Saltcoats, Ayrshire, a Scottish merchant who was the first woman to be given a sea captain’s licence by the Board of Trade, making her the first female sea captain in Great Britain"', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20813, '2022-05-09 14:51:50.262879+00', '2022-05-09 14:51:50.262879+00', 'Frazers of Strathkinness, The', 'FRAZERS OF STRATHKINNESS', 3, 32, NULL, 2, 3, 17, 99, '2011-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20814, '2022-05-09 14:57:12.89275+00', '2022-05-09 14:57:12.89275+00', 'James Wilson''s Reel', 'JAMES WILSONS REEL', 1, 32, NULL, 1, 100, 2, 99, '1990-01-01', 'The notes say this dance commemorates "James Wilson (1742–1798) the Fife-born lawyer and political theorist who signed the Declaration of Independence in 1776 then helped draft the US Constitution, which he also signed in 1787, making him one of the founding fathers of the United States"

', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20815, '2022-05-09 15:02:18.52183+00', '2022-05-09 15:02:18.52183+00', 'Bubbly-jock, The', 'BUBBLYJOCK', 2, 32, NULL, 1, 3, 42, 99, '1993-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20816, '2022-05-09 15:06:52.309403+00', '2022-05-09 15:06:52.309403+00', 'Nae Coins in the Kist', 'NAE COINS IN THE KIST', 1, 32, NULL, 1, 3, 42, 99, '1988-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20820, '2022-05-14 18:02:38.2249+00', '2022-05-14 18:02:38.2249+00', 'St Margaret''s Knot', 'SAINT MARGARETS KNOT', 3, 32, NULL, 2, 3, 17, 99, '2004-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20769, '2022-04-15 15:56:58.844411+00', '2022-12-04 18:00:05.53891+00', 'Seven Up', 'SEVEN UP', 2, 40, NULL, 107, 112, NULL, 12120, '2022-01-01', 'A set of 7 dancers, 2 lines of 3 on the sides & with number 7 in the middle facing up  



……1…2…3  

Top ....7....  

……6…5…4  



The progression is 2,3,6,7,4,5,1.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20810, '2022-05-09 12:07:02.639932+00', '2022-05-09 23:32:02.969642+00', 'Shoko Okumura''s Strathspey', 'SHOKO OKUMURAS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 99, '2021-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20134, '2020-10-22 22:19:42.443413+00', '2022-05-12 09:58:45.034083+00', 'Teviot Bridge Reconstructed, The', 'TEVIOT BRIDGE RECONSTRUCTED', 2, 24, 9999, 1, 2, 76, 10912, '2020-01-01', '', 43, '80/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (282, '1998-01-05 23:00:00+00', '2022-05-12 15:10:35.055487+00', 'Auckland Airs', 'AUCKLAND AIRS', 1, 32, 9999, 2, 3, 17, 80, NULL, '"Inscribed  to Rhoda Tanner and the members of the Auckland Region, New Zealand Branch, on the occasion of their 1986 Summer School."', 83, '888/808/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10380, '2002-09-25 22:00:00+00', '2022-05-14 16:54:41.565058+00', 'Rosewood JEM, The', 'ROSEWOOD JEM', 3, 32, 9999, 2, 3, 18, 555, NULL, 'Note that the instructions for this dance were changed slightly after its first publication in <<ddpub:Gatineau Gathering, A#794>> (handing for some turns and the final few bars for 1st couple). The deviser''s preferred version is demonstrated in <<https://my.strathspey.org/dd/dancevideo/8704/|Video 1>>.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20822, '2022-05-14 18:13:46.5051+00', '2022-05-14 18:13:46.5051+00', 'Bulling Boots', 'BULLING BOOTS', 1, 48, NULL, 1, 4, 1, 99, '2091-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20840, '2022-05-15 20:17:49.037178+00', '2022-05-15 20:17:49.037178+00', 'Ricki Robb''s Reel', 'RICKI ROBBS REEL', 1, 32, NULL, 1, 100, 2, 99, '2005-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20768, '2022-04-15 15:56:22.213907+00', '2022-06-13 23:22:33.111862+00', 'Five Times Twirl', 'FIVE TIMES TWIRL', 2, 32, NULL, 107, 55, 31, 12120, '2022-01-01', 'Start in W shape with dancers 2 & 4 facing gaps in line of dancers 1, 3 & 5



&nbsp;&nbsp;&nbsp;&nbsp;1…3…5  

Top  

&nbsp;&nbsp;&nbsp;&nbsp;...2…4…  

', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20823, '2022-05-14 18:22:20.914197+00', '2022-05-16 00:09:24.683785+00', 'Bill Forbes'' Rant', 'BILL FORBES RANT', 3, 32, NULL, 2, 3, 17, 99, '2016-01-01', '', 71, '880/822/808/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20824, '2022-05-14 18:25:46.346359+00', '2022-10-17 23:18:20.382144+00', 'St John''s Jig, The', 'SAINT JOHNS JIG', 2, 32, NULL, 1, 3, 42, 99, '2019-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20849, '2022-05-15 21:04:33.155239+00', '2022-05-15 21:04:33.155239+00', 'Elizabeth Garrett Anderson''s Strathspey', 'ELIZABETH GARRETT ANDERSONS STRATHSPEY', 3, 32, NULL, 1, 3, 42, 99, '1989-01-01', 'The notes say this commemorates "Elizabeth Garrett Anderson (1836–1917), physician and suffragist, the first woman to qualify as a physician and surgeon and become the first female mayor in Britain"', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20825, '2022-05-14 18:33:39.206426+00', '2022-05-15 23:59:45.515326+00', 'Bonnie Benbecula', 'BONNIE BENBECULA', 3, 32, NULL, 2, 3, 17, 99, '2091-01-01', 'The inscription is "In memory of Sheila Jupp, who spent her childhood on this Hebridean island".



The publication gives the tune as "Crawhillock". It is assumed to be intended as "Crowhillock".

', 83, '888/808/088/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20850, '2022-05-16 15:11:21.631152+00', '2022-05-16 15:11:21.631152+00', 'Proof o'' the Pudding, The', 'PROOF O THE PUDDING', 1, 32, NULL, 1, 3, 42, 99, '1989-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20851, '2022-05-16 15:19:46.820427+00', '2022-05-16 15:19:46.820427+00', 'Sir Hugh Lyon Playfair''s Jig', 'SIR HUGH LYON PLAYFAIRS JIG', 2, 32, NULL, 1, 4, 2, 99, '2012-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20852, '2022-05-16 15:24:36.402469+00', '2022-05-16 15:24:36.402469+00', 'Tread We a Measure', 'TREAD WE A MEASURE', 3, 40, NULL, 1, 3, 42, 99, '1990-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20853, '2022-05-16 15:29:43.883318+00', '2022-05-16 15:29:43.883318+00', 'Duke and Duchess of Cornwall, The', 'DUKE AND DUCHESS OF CORNWALL', 1, 40, NULL, 1, 3, 42, 99, '2004-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20854, '2022-05-16 15:36:10.872833+00', '2022-05-16 15:36:10.872833+00', 'Duke and Duchess of Cambridge, The', 'DUKE AND DUCHESS OF CAMBRIDGE', 1, 40, NULL, 1, 3, 42, 99, '2011-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20855, '2022-05-16 15:38:56.349179+00', '2022-05-16 15:38:56.349179+00', 'Duke and Duchess of Sussex, The', 'DUKE AND DUCHESS OF SUSSEX', 1, 40, NULL, 1, 3, 42, 99, '2018-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20856, '2022-05-16 15:41:50.640822+00', '2022-05-16 15:41:50.640822+00', 'Silver Arrow, The', 'SILVER ARROW', 2, 32, NULL, 2, 3, 17, 99, '2012-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20857, '2022-05-16 15:50:43.957407+00', '2022-05-16 15:50:43.957407+00', 'Mollie Shippey''s Strathspey', 'MOLLIE SHIPPEYS STRATHSPEY', 3, 32, NULL, 1, 100, 2, 99, '1992-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20858, '2022-05-16 15:54:28.795634+00', '2022-05-16 15:54:28.795634+00', 'Mrs Erskine''s Fancy', 'MRS ERSKINES FANCY', 1, 32, NULL, 1, 3, 42, 99, '1898-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20859, '2022-05-16 15:58:52.59952+00', '2022-05-16 15:58:52.59952+00', 'Ashintully Castle', 'ASHINTULLY CASTLE', 3, 32, NULL, 1, 3, 42, 99, '1988-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14713, '2013-02-04 16:31:51.507802+00', '2022-05-17 22:46:58.001523+00', 'Foursome and Half Reel of Tulloch (trad. version), The', 'FOURSOME AND HALF REEL OF TULLOCH TRAD VERSION', 4, 136, 10011, 104, 106, 3, 1556, NULL, 'There are various versions of this dance in circulation, which tend to differ in the length of the strathspey and the reel parts. 



See:



<<ddd:Foursome and Half Reel of Tulloch, The  #7542>>. (32 S + 32 R + 64 R)



<<ddd:Foursome Reel  and Half Reel of Tulloch, The#20860>> (32 S + 64 R)



and  <<https://my.strathspey.org/dd/issue/2759/|issue 2759>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20733, '2022-03-26 20:02:45.881426+00', '2022-05-17 07:18:59.673925+00', 'Bucket Tree, The', 'BUCKET TREE', 2, 32, NULL, 1, 3, 42, 44, NULL, 'Devised: 1998-05

Presented to the members of the Tawa Club to celebrate the Club''s 50th Anniversary in 2008. The "bucket tree" is a large macrocarpa trimmed to the shape of an upturned bucket and is a Tawa landmark near the Willowbank Reserve. The Tawa Club includes a representation of the tree in its club badge.



NB the suggested recording does not include the recommended tune (see <<https://my.strathspey.org/dd/issue/2797/|issue 2797>> for background details).', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20863, '2022-05-21 09:42:07.549703+00', '2022-12-10 19:10:57.196447+00', 'Cranberry Tartelette, The', 'CRANBERRY TARTELETTE', 2, 32, NULL, 2, 3, 30, 12220, NULL, 'Luitgard Merkens (SCD Group Münster/Germany) came up with this adaptation of <<ddd:Cranberry Tart, The#9157>> by <<ddp:Glasspool, Terry#2677>> for a 3 couple set, inverting the set each time. After the first turn the progression is 2,1,3. The next turn has the original 3rd couple as dancing couple with 3rd woman starting, followed 2 bars later by her partner. This variation seems sufficiently popular to have its own dance entry.



See <<https://www.scdmuenster.de/2018/08/22/m%C3%BCnsteraner-variationen-cranberry-pie-und-tartelette/>> (German) for more details.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20861, '2022-05-20 21:19:51.281833+00', '2022-05-20 21:19:51.281833+00', '40 Year Friendship Strathspey', '40 YEAR FRIENDSHIP STRATHSPEY', 3, 32, NULL, 4, 4, 13, 3377, NULL, 'Source: <<https://youtu.be/3HHXF02_QaA|youtube video>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13852, '2011-08-21 22:00:00+00', '2022-12-13 13:53:51.176356+00', 'Diamond for Belfast, A', 'DIAMOND FOR BELFAST', 2, 40, NULL, 2, 3, 17, 872, NULL, '', 93, '888  888  888  448  888', 0, 1, 0, 0, 93);
INSERT INTO 'dance' VALUES (7542, '2000-02-21 23:00:00+00', '2022-05-17 22:44:44.620758+00', 'Foursome and Half Reel of Tulloch', 'FOURSOME AND HALF REEL OF TULLOCH', 4, 128, 10017, 105, 2, 3, 9998, NULL, 'Note that there are various versions of this dance in circulation, which tend to differ in the length of the strathspey and the reel parts. 



See also:



<<ddd:Foursome Reel  and Half Reel of Tulloch(trad. version), The#14713>> (48 R + 88 R)



<<ddd:Foursome Reel  and Half Reel of Tulloch, The#20860>> (32 S + 64 R)



and  <<https://my.strathspey.org/dd/issue/2759/|issue 2759>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20390, '2021-07-14 08:16:11.431621+00', '2022-05-21 23:24:43.851896+00', 'Nightingale Floor, The', 'NIGHTINGALE FLOOR', 1, 32, NULL, 4, 55, 37, 10433, '2012-03-01', 'Inscribed "For Patsy & Ian Marks on their return from a Rotary trip to Japan, March 2012."



The dance notes explain that "Centuries ago, floors in the hallways & corridors of Japanese temples & palaces were designed to make a ''chirping'' sound when walked on.  This was a security device – an early, ''early warning system''.  Dry boards creak naturally under pressure, but these floors were created so that the flooring nails would rub against a jacket or clamp (usually leather), causing birdlike noises - hence ''nightingale'' floors (''uguisubari''). This ensured that no one could sneak through the corridors undetected. The most famous example is in Nijo Castle, Kyoto, Japan."', 65, '80808/88888/08088/42442', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20862, '2022-05-20 21:26:36.573949+00', '2022-05-20 21:26:36.573949+00', 'eXcel', 'EXCEL', 1, 32, NULL, 1, 100, 2, 12130, NULL, 'Source: <<https://youtu.be/3HHXF02_QaA|youtube video>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4217, '1998-10-20 22:00:00+00', '2022-05-21 08:17:15.191098+00', 'Mary Stewart Strathspey', 'MARY STEWART STRATHSPEY', 3, 32, 9999, 5, 2, 76, 496, '1970-01-01', 'This dance is published with the name "Mary Stewart Strathspey" in <<ddpub:Dances with a Difference#394>> but as "Mary Stewart''s Strathspey" in the <<ddpub:#678|Los Angeles 25th Anniversary Book>>.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10844, '2002-09-26 22:00:00+00', '2022-05-31 11:32:12.461073+00', 'Adelaide Strathspey, The', 'ADELAIDE STRATHSPEY', 3, 32, 9999, 1, 4, 1, 605, NULL, 'This simple dance was devised for a St Valentine''s Day demonstration. (from the publication)



Music used is as for The Belle of Bon Accord on the "See You Jimmy'''' tape. (from the publication)', 38, '8000/8800/8044/8000', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20932, '2022-07-05 22:47:41.077976+00', '2022-09-02 18:55:02.275924+00', 'Return of the Geologist, The', 'RETURN OF THE GEOLOGIST', 2, 32, NULL, 1, 3, 42, 12162, NULL, '', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20868, '2022-05-26 21:51:03.08142+00', '2022-05-26 21:51:03.08142+00', 'Drumrossie', 'DRUMROSSIE', 3, 32, NULL, 1, 3, 42, 12133, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11443, '2003-09-22 22:00:00+00', '2022-05-22 09:08:06.58526+00', 'Jacobite, The', 'JACOBITE', 1, 32, 9999, 1, 3, 42, 2766, '2003-04-01', 'During our trip to Scotland in August of 2001, we took the steam train from Fort William to Mallaig – the Jacobite. The figure in bars 19-24 reminds me of a train.



Crib author''s note: The online instructions say that [25-32] has mirror reels, but they are opposing reels (in 2pl 1M starts down, 1W starts up); in addition each of the end couples makes one crossing.', 56, '800/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (60, '1997-08-28 22:00:00+00', '2022-05-22 15:27:45.94488+00', 'Airy Holme Jig', 'AIRY HOLME JIG', 2, 32, 9999, 2, 3, 4, 372, '1978-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12620, '2005-11-08 23:00:00+00', '2022-05-22 22:06:15.359302+00', 'Alison''s Strathspey', 'ALISONS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 3647, NULL, 'The original text says:  Progressive 3 Cpl. dance in a 4 Cpl. Longwise Set.  <...> Can also be danced as a 3 couple dance with 3rd & 1st Cpl. circling to the Lt in bars 21 to 24, 3rd Cpl. opening out for the 6 hands round in bars 25 to 32.



The E-crib gives the 3C/4C version as the default, whereas MiniCrib has the 3C set version. The diagram shows both.', 56, '844/088/448/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (3133, '1997-04-03 22:00:00+00', '2022-05-23 08:18:23.914178+00', 'Iron Man, The', 'IRON MAN', 3, 32, 9999, 1, 2, 76, 270, NULL, '', 56, '48/88/88/80', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20785, '2022-04-27 21:34:25.280896+00', '2022-05-23 17:48:37.743696+00', 'Insurance Man from BA, The', 'INSURANCE MAN FROM BA', 1, 32, NULL, 1, 3, 42, 2101, '2020-03-01', 'The dedication reads "This dance is written for a wonderful Argentine friend, tourist guide, host, dancer and gentleman. He made my visit to Argentina in 2019 the most memorable time in my life."', 59, '844/888/844/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8203, '1997-12-27 23:00:00+00', '2022-05-24 21:34:10.691876+00', 'Waratah Weaver, The', 'WARATAH WEAVER', 2, 32, 9999, 1, 4, 1, 2015, NULL, 'Can be danced in a 3C, 4C or 5C set.



Another existing variation is 8x32 for 3C in a 4C set with the three couples all dancing reels instead of solo figures of 8.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20866, '2022-05-24 22:00:13.912541+00', '2022-05-24 22:01:23.797517+00', 'Onyx', 'ONYX', 1, 32, NULL, 1, 3, 42, 2706, NULL, 'Source: PDF linked from <<https://rscds-twincities.org/performance-repertoire/>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20865, '2022-05-24 21:17:58.34246+00', '2022-05-24 22:01:51.919875+00', 'Harry Gordon', 'HARRY GORDON', 4, 64, 5, 104, 2, NULL, 2408, NULL, 'A performance dance with no progression. Written in memory of the deviser''s father, Harry Gordon Friedman.



Source: PDF linked from <<https://rscds-twincities.org/performance-repertoire/>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20870, '2022-05-29 12:40:43.262691+00', '2022-05-29 12:40:43.262691+00', 'Bats in the Belfry', 'BATS IN THE BELFRY', 2, 32, NULL, 1, 3, 42, 11924, '2012-01-01', 'Written in 2012 as a Halloween dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20867, '2022-05-26 17:08:41.455379+00', '2022-05-26 21:44:59.555211+00', 'Welcome to Your Feet Again', 'WELCOME TO YOUR FEET AGAIN', 3, 32, NULL, 1, 3, 42, 12132, NULL, 'Repeat from new places, but in the second round, for Bars 9–14, Partner 2 leads the chase down behind their own sides to dance below 3s, and casts up behind their opposite side to 2nd place, while Partner 1 dances up the middle to 2nd place opposite side.



Couples decide independently who will be Partner 1 and Partner 2.



On the final two bars of the second round, 1s can cross down to the bottom of the set while 3s can dance up a place to begin the next round.



This dance was devised for a first class back after a hiatus due to Covid and avoids taking hands. If dancers are now comfortable taking hands in setting or changing places, they may! If dancers prefer not to take hands and instead hold champagne glasses, they may clink between the advance and the retire!', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20563, '2021-11-23 19:11:26.187055+00', '2022-05-30 21:35:17.470036+00', 'Between Yews and Willows', 'BETWEEN YEWS AND WILLOWS', 3, 32, 9999, 2, 3, 17, 11162, '2021-11-01', 'Statement by Regina Freinbichler, the deviser of the dance, from her web page of the dance (with her permission):



_Ovarian Cancer Appeal for Scottish Country Dancers_



I have been suffering from ovarian cancer for the past 4 years. I’m at a point where I know I’m not winning the fight. As a keen Scottish Country Dancer I would like to make an impact, and so I have decided to start this appeal.

It would be great if you could join in, do the dance that I have written in your group, and print out the leaflet I have prepared for your dancers (or read the info to them). Men do not need to feel left out. It could be someone close to them who is diagnosed with ovarian cancer. When I was first diagnosed, I did not have that information. It would have been helpful to me.

In <<https://www.turnverein-maxglan.at/wp-content/uploads/2021/11/ovarian-cancer2.pdf|the leaflet>> you will also find information about the dance name. A special thanks to Stephan Vollmar and the Munich Scottish Association for trying the dance and creating the minicrib.



*A 3x32 recording for this dance by Wouter Joubert is available at the same link as the score for the tune:  

<<https://drive.google.com/drive/folders/1hWXHwuPxXlBa8F94hKA7i3255_coPtD9>>*



From <<https://www.turnverein-maxglan.at/wp-content/uploads/2021/11/ovarian-cancer2.pdf|Regina''s leaflet>>:  

Why is the dance called “Between yews and willows”? 

The yew tree, which we all know is poisonous, specifically its bark, provides us with a chemotherapeutic agent for 

the treatment of ovarian cancer called Paclitaxel.  

The willow tree is a symbol of hope, healing, the ability to let go of pain and suffering and the idea of standing tall. 

', 50, '800/888/800/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19711, '2019-10-24 16:37:15.048055+00', '2022-05-27 11:32:03.661219+00', 'Darvel Weaver, The', 'DARVEL WEAVER', 1, 32, NULL, 1, 3, 42, 11894, '2000-01-01', 'In honour of James Gilchrist, weaver and tenter, of Darvel, Ayrshire and dedicated to his daughter and son-in-law, Cath and Alec Campbell', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20869, '2022-05-29 07:27:46.068379+00', '2022-05-29 08:48:47.425624+00', 'Birthday Month, The', 'BIRTHDAY MONTH', 2, 32, NULL, 1, 3, 42, 11924, NULL, 'Crib given in dance list <<https://my.strathspey.org/dd/list/34321/>>.', 63, '844/888/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14116, '2011-08-25 22:00:00+00', '2022-05-29 10:33:39.341558+00', 'Strathpsey Advancement Party of Scotland Strathspey, The', 'STRATHPSEY ADVANCEMENT PARTY OF SCOTLAND STRATHSPEY', 3, 24, NULL, 1, 2, 76, 10433, NULL, 'The notes say "This dance is dedicated to the members of the StrAthPSey Advancement Party of Scotland (SAPS). The dance is short because the title is long. PS There are only deliberate spelling mistakes on this page!"



So the "Strathpsey" in the title is correct (see <<https://my.strathspey.org/dd/issue/2800/|issue 2800>>).', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20625, '2022-01-13 09:56:10.101839+00', '2022-05-29 11:46:16.221175+00', 'Platinum Jubilee, The', 'PLATINUM JUBILEE', 3, 32, NULL, 2, 3, 17, 3325, '2022-01-01', 'In the year 2022, HM The Queen, Patron of the RSCDS, celebrates her Platinum Jubilee. And for the

Berkhamsted Strathspey and Reel Club it is its platinum year too. Coming in threes, Jeremy and Anne

Newton past-president (1983-1985) and current president respectively, also share in the celebrations with

their 70th birthdays in May; this dance commemorates this remarkable year.  



_Teaching notes_:  

Bars 1-2 1st couple dancing down to meet use long steps to reach the bottom of the set.  

Bars 7-8 1st couple curve into second place to flow into six hands round halfway.  

Bars 13-16 2nd and 3rd couples change direction on bar 13 to dance left hands across.  

Similarly,  

Bars 21-24 2nd and 3rd couples change direction on bar 21 to dance right hands across.  

Bar 32 1st couple quarter turn about to face in ie the short way.  

For information, progression order: 1/2/3, 2/3/1, 3/2/1, 1/2/3.  



Information about the tunes is given in <<https://my.strathspey.org/dd/issue/2799/|issue 2799>>.', 67, '800/888/888/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10845, '2002-09-26 22:00:00+00', '2022-05-31 11:33:44.200867+00', 'All In', 'ALL IN', 1, 32, 9999, 4, 4, 1, 3180, NULL, 'This dance is titled "All In" because it is a favourite saying for dancers, and because everyone is dancing, and also when you stop, you are "all in". [from the publication]

', 100, '8888  8888  8888  8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10851, '2002-09-26 22:00:00+00', '2022-05-31 13:46:59.861671+00', 'Let''s All Celebrate', 'LETS ALL CELEBRATE', 3, 40, 9999, 6, 3, NULL, 3196, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20881, '2022-06-07 22:00:04.447989+00', '2022-09-27 16:11:48.557693+00', 'Bouquets', 'BOUQUETS', 3, 32, NULL, 2, 3, 17, 12146, '2021-01-01', '', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20882, '2022-06-07 22:17:47.22704+00', '2023-02-25 17:59:34.545975+00', 'Frisky Ten Years', 'FRISKY TEN YEARS', 1, 32, NULL, 1, 100, 2, 12147, '2016-09-01', 'Devised for the 10th anniversary of ''The Frisky", a dancing group based in Tokyo.



According to the deviser, right hand turns by 2C and 3C on bars 21-24 may be omitted.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20873, '2022-05-31 20:01:55.512101+00', '2022-05-31 20:57:06.119148+00', 'Sightlines from Chernex', 'SIGHTLINES FROM CHERNEX', 3, 32, NULL, 1, 4, 2, 11237, '2020-02-01', 'This dance is for Jim and Aline Cook who kindly invited me for supper in their former holiday home in the village of Chernex. This was in the hills above Montreux from where they had a lovely view over the eastern end of Lake Geneva and the surrounding mountains. Chernex, which is pronounced like “Shairnay”, is on the Montreux Oberland Bernois or “GoldenPass” railway line. This climbs and winds its narrow gauge way up from Montreux, through the gorgeous scenery of the Bernese Oberland, to the rail and river junction at Zweisimmen. The reels, snake pass and tournée may be taken to illustrate the loopy nature of the line.', 94, '8484/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20876, '2022-06-07 20:37:59.022278+00', '2022-06-07 21:36:19.298336+00', 'Tatiana''s Dream', 'TATIANAS DREAM', 2, 32, NULL, 1, 3, 42, 12137, NULL, 'Tatiana is a character in Alexander Pushkin''s novel Eugene Onegin who dreams that a bear helps her cross a raging torrent.', 59, '844/888/488/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20880, '2022-06-07 21:53:47.928079+00', '2022-06-07 21:53:47.928079+00', 'Sweetfish of Neo River', 'SWEETFISH OF NEO RIVER', 2, 32, NULL, 1, 3, 42, 12145, '2016-05-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20883, '2022-06-07 22:28:14.285881+00', '2022-06-07 22:28:14.285881+00', 'Gate of Daffodil Garden, The', 'GATE OF DAFFODIL GARDEN', 3, 32, NULL, 1, 3, 42, 12148, '2021-02-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20215, '2021-02-04 21:16:52.965477+00', '2022-06-11 02:39:50.410997+00', 'Anticipation', 'ANTICIPATION', 2, 32, NULL, 2, 3, 18, 10568, '2021-01-01', '', 100, '888/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20885, '2022-06-08 09:27:50.255679+00', '2022-06-08 09:27:50.255679+00', 'Peatys Jig', 'PEATYS JIG', 2, 32, NULL, 1, 3, 42, 12150, '2015-07-01', 'Devised for ''Peatys", a Scottish Country Dance group in Gotanda, Tokyo.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20884, '2022-06-07 22:36:17.139609+00', '2022-06-08 11:12:15.653376+00', 'Happy Anniversary!', 'HAPPY ANNIVERSARY', 2, 40, NULL, 1, 3, 42, 12149, '2021-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20875, '2022-06-07 20:31:09.14674+00', '2022-06-23 08:40:05.343259+00', 'Celebrate Ten and Twenty Years', 'CELEBRATE TEN AND TWENTY YEARS', 3, 32, NULL, 2, 3, 18, 12141, '2020-01-01', 'This dance was written to celebrate two dancing groups which the deviser established. One group is ''Clara'' for the 20th anniversary, the other is ''Saltire'' for the 10 anniversary.', 50, '888/880/800/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20888, '2022-06-08 17:31:56.412851+00', '2022-06-08 22:25:27.244848+00', 'Eliza Tells a Tale', 'ELIZA TELLS A TALE', 2, 32, NULL, 2, 3, 17, 3583, '2022-03-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20889, '2022-06-08 22:33:58.808174+00', '2022-06-08 22:34:54.548681+00', 'Levi Jackson Rag', 'LEVI JACKSON RAG', 1, 32, NULL, 107, 5, NULL, 2487, '1975-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15686, '2014-10-30 07:18:19.837985+00', '2022-06-09 16:10:02.725788+00', 'Malcolm''s Shoes', 'MALCOLMS SHOES', 2, 32, NULL, 1, 3, 42, 10810, '2014-05-04', 'Devised 4 May 2014, by Sergey Kargapoltsev (robroyway [at] gmail.com). The little story that happened in Vladimir city (Russia) on Spring School with Malcolm Brown when he lost his shoes.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20890, '2022-06-09 22:55:17.151978+00', '2022-06-09 22:55:17.151978+00', 'Sharon Heights Reel', 'SHARON HEIGHTS REEL', 1, 32, NULL, 1, 3, 42, 361, '2018-03-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1906, '1997-04-03 22:00:00+00', '2022-06-09 23:48:47.987467+00', 'Edie''s Jubilee', 'EDIES JUBILEE', 2, 32, 9999, 1, 3, 42, 361, '1989-03-01', 'Dedicated to Edit Spear in honor of her 60th birthday.', 59, '800/888/888/866', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20891, '2022-06-10 04:19:20.561452+00', '2022-06-10 05:03:45.966905+00', 'Thank You Linda Henderson', 'THANK YOU LINDA HENDERSON', 2, 32, NULL, 2, 3, 18, 10568, '2022-04-01', '"I had forgotten all about the pinwheel progression until Linda Henderson asked me about it.  So, of course, I had to write a new dance with it, in quick time this time." Holly said.', 92, ' 880/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14995, '2013-07-30 17:03:39.461067+00', '2022-06-11 21:17:21.847291+00', 'There and Back Again', 'THERE AND BACK AGAIN', 3, 32, NULL, 1, 3, 42, 10568, NULL, '"I wanted to write a dance with the pinwheel progression in it." Holly said.', 61, '880/866/866/877', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20878, '2022-06-07 21:06:09.092309+00', '2022-06-23 23:10:26.425546+00', 'Dancing on West Sands', 'DANCING ON WEST SANDS', 1, 32, NULL, 1, 3, 42, 12143, '2020-08-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13965, '2011-08-24 22:00:00+00', '2022-06-12 11:05:18.625447+00', 'Docent''s Tour, The', 'DOCENTS TOUR', 3, 32, NULL, 1, 3, 42, 2701, '2006-12-28', 'This dance was devised for Sid Kass to celebrate his 75th birthday, December 31, 2006. The dance was presented at the San Francisco Class on Thursday December 28, 2006 as a surprise to Sid. The title of the dance refers to Sid''s volunteer work as a docent at two local museums.- TW', 47, '800/844/844/866', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (20887, '2022-06-08 09:39:33.851499+00', '2022-06-18 12:50:08.852139+00', 'Always on my Mind', 'ALWAYS ON MY MIND', 1, 32, NULL, 1, 3, 42, 11140, '2021-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20877, '2022-06-07 20:59:32.647862+00', '2022-06-19 12:11:29.918379+00', 'Happy Dancing', 'HAPPY DANCING', 2, 32, NULL, 1, 3, 42, 11974, '2020-06-01', 'This dance was devised with delight to meet and dance together again after long adjournment by COVID-19 and for enjoying without hands as much as possible.', 63, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20886, '2022-06-08 09:35:02.647098+00', '2022-06-19 13:12:16.107462+00', 'Yamashita Park', 'YAMASHITA PARK', 3, 32, NULL, 1, 3, 42, 12151, '2020-03-01', 'Yamashita Park in Yokohama city is one of the most beautiful and famous parks facing Tokyo Bay.



1st couple dance a floor pattern of two interlocking hearts during bars 9-16.', 56, '800/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20874, '2022-06-07 20:24:56.797783+00', '2022-06-23 08:07:22.559019+00', 'Cheerful Celebrations', 'CHEERFUL CELEBRATIONS', 2, 32, NULL, 1, 3, 42, 11140, '2020-01-01', 'Music composed by Hiroko Kokai.', 47, '800/844/822/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20879, '2022-06-07 21:14:30.443739+00', '2022-06-25 10:13:08.655427+00', 'Leisurely Stroll, A', 'LEISURELY STROLL', 3, 32, NULL, 1, 3, 42, 12144, '2020-06-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20872, '2022-05-31 19:19:53.080336+00', '2023-01-20 22:54:32.067213+00', 'Cliffs of Moher, The', 'CLIFFS OF MOHER', 1, 32, NULL, 1, 3, 42, 11237, '2022-02-01', 'This dance is for Steve Oakes, an enthusiastic member of the Gay Gordons group in London. Early in 2022 he had to spend a few months away helping to make a film set near the Cliffs of Moher in county Clare, Ireland. This was written to entice him back. Steve''s pas de basque style is quite energetic and he likes twirls and wide loops. All those are exhibited here.



There is a short video with a good view of the cliffs at <<https://youtu.be/XtYH2as-r5Y>>.', 53, '844/822/866/866', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10849, '2002-09-26 22:00:00+00', '2022-10-14 11:31:04.507851+00', 'Tea Break', 'TEA BREAK', 2, 32, 9999, 2, 3, 17, 3194, NULL, 'This dance was devised during a tea break, which is considered essential at our Friday night dancing class. This class enjoys a challenge. [from the publication]



In the dance description Julie Pastok suggests "The Wapenshaw" on Highlander Music Volume 6 CD by Drummond Cook''s Scottish Country Dance Band as suitable recording.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (811, '1997-04-03 22:00:00+00', '2022-06-12 11:36:17.425714+00', 'Brimmond', 'BRIMMOND', 3, 32, 9999, 1, 3, 42, 108, '1986-01-01', 'The inscription reads "for Simon Wood of Ellon who played for the first performance of this dance Simon is a helicopter pilot - hence the name of the progression".



So this is the first dance with the Set and Rotate figure.



Brimmond is a hill overlooking Aberdeen.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7630, '1997-08-31 22:00:00+00', '2022-06-18 09:08:24.045439+00', 'Cape Cod Reel, The', 'CAPE COD REEL', 1, 32, 9999, 2, 3, 17, 741, NULL, 'Description

-----------



1- 8::

  1s and 3s advance 2 steps diagonally to centre. Then turn left 90 degrees and take 2 steps out to the corner and stay facing out. Meanwhile 2’s pull their right shoulder back and cast, man up, lady down to end in the middle of the set at top and bottom. 2s set facing each other whilst 1s and 3s set turning right to face each other. All 3 couples set once more whilst facing each other. 

9-16::

   Repeat bars 1 to 8. i.e. 1s and 3s in diagonally whilst 2nd man casts down the ladies side and 2nd lady casts up the men’s side. 2s set facing each other whilst 1s and 3s set turning to face each other. All 3 couples set once more. (Everyone is now on the opposite side and the set is upside down.) 

17-20::

   3s at the top, cast to the bottom on the wrong side, followed by 2s who end up in 2nd place. Whilst 1s cross to the top, lady crossing in front of her partner. 

21-22::

  1s and 2s right hands across for 2 steps. 1st lady finish facing out the men’s side with her partner behind. 

23-24::

   1s and 3s left hands across for 2 steps. (1s are now at the bottom and everybody is back on the correct side) 

25-32::

   All 3 couples circle left and back   

Repeat twice in new positions.



The dance was devised by Mark Dungey, Sue Prout, Margaret Miles (all of the FalmouthWhite Heather Club) and Margaret Hoare, on a trip to Falmouth Massachusetts (On the Cape Cod Peninsula)', 96, '888/888/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20901, '2022-06-23 18:41:12.471951+00', '2022-06-23 20:41:26.877475+00', 'Tairawhiti Wedding', 'TAIRAWHITI WEDDING', 3, 32, NULL, 1, 4, 1, 2682, '2022-06-01', 'This dance commemorates the wedding of the deviser''s son in Tairawhiti (the Maori name for Gisborne, NZ).', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20904, '2022-06-23 19:05:31.108458+00', '2022-06-23 21:25:24.448124+00', 'Piwakawaka, The', 'PIWAKAWAKA', 1, 48, NULL, 1, 4, 1, 2682, '2022-05-13', 'Fomr the notes: The piwakawaka is a New Zealand fantail. It is known for its friendly "cheet cheet" call and energetic flying; dancers will need some energetic dancing and to be on their game for this dance.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20920, '2022-06-25 15:26:29.010226+00', '2022-10-25 19:43:16.300792+00', 'Shadows', 'SHADOWS', 3, 32, NULL, 2, 3, 17, 2806, NULL, 'The Shadow Progression needs careful timing and is quite slow. 

1st man and 2nd woman simply shadow 1st woman and 2nd man in the progression. The idea came to me one very hot, sunny day while watching dancers outside dancing on grass and casting shadows.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20907, '2022-06-25 13:36:14.001344+00', '2022-06-26 22:53:09.564054+00', 'Newcastle''s 70th Celebration', 'NEWCASTLES 70TH CELEBRATION', 3, 32, NULL, 1, 4, 2, 2806, NULL, 'Dance devised in 2019 to celebrate Newcastle and District Branch''s 70th Anniversary in 2020

(The first 8 bars show the 7 and 0 shapes)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20910, '2022-06-25 14:18:28.501803+00', '2022-10-25 20:05:57.994665+00', 'Sheila of Morpeth', 'SHEILA OF MORPETH', 3, 40, NULL, 1, 102, 1, 2788, NULL, 'Dance written by Dr. Peter Avery (Branch Chairman) as a tribute to the tremendous contribution made by Sheila Trafford to Scottish dancing in the North East of England, both as a teacher and an organiser.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20917, '2022-06-25 15:10:28.731905+00', '2022-10-25 20:01:45.741274+00', 'Bird Man, The', 'BIRD MAN', 2, 32, NULL, 1, 3, 42, 2806, NULL, 'Dance written in memory of Peter Hawkey who died in 2006. Peter was Warden on the Farne Islands for many years and it was extremely interesting to listen to him talking about the bird life, especially the Puffins. Peter and his wife Joyce rarely missed local dances and travelled great distances to go to dances in other areas and abroad.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20918, '2022-06-25 15:17:31.020661+00', '2022-08-12 09:40:07.561827+00', 'Golden Wishes', 'GOLDEN WISHES', 1, 32, NULL, 3, 5, 93, 2806, NULL, 'Dance written for Stocksfield Scottish Country Dance Club''s 50th Anniversary in July 2016. When asked to write this dance, I was requested to make it a challenge! I hope it fits the bill! Enjoy.', 80, '84048/88088/84884/88888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20899, '2022-06-23 13:32:10.491454+00', '2022-06-27 12:07:30.684148+00', 'Something in the Air', 'SOMETHING IN THE AIR', 3, 32, NULL, 2, 2, NULL, 3703, '2019-01-01', 'Devised August 2019, Revised October 2019



This dance was inspired by the wonderful set of Song Airs on A Dancer’s Best Friend by the trio, Terpsichore.  Since this set of airs is 6x32 bars, the dance was envisioned for a three-couple set.  However the dance could be done as a standard two couple dance in a four-couple set.



Note:  The Rose Progression was devised by Rod Downey of New Zealand.  

', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20916, '2022-06-25 15:07:23.479575+00', '2022-10-25 20:02:44.428149+00', 'Cathie Smith''s Reel', 'CATHIE SMITHS REEL', 1, 32, NULL, 1, 3, 42, 2806, NULL, 'Dance devised in memory of Cathie Smith who died in December 2016. Cathie was a member of the Newcastle & District Branch of the RSCDS for many years and she was a founder member of Mike Barlow''s Ponteland evening class.

She was a very friendly lady and supported all local events. She is greatly missed by all her friends and those who knew her.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20909, '2022-06-25 14:09:51.741154+00', '2022-10-25 20:07:08.867302+00', 'Freda''s Frolic', 'FREDAS FROLIC', 2, 32, NULL, 4, 4, 13, 2806, NULL, 'This dance was written for Freda Phillipson. Freda has been a loyal member of our Branch and Life member of the RSCDS for 47 years. During this time she has seved as a committee member, teacher, pianist and musical composer as well as a keen dancer. Over these years, Freda has enjoyed lots of trips to places all over Scotland including the Scottish Islands (These trips are known as Freda''s Frolics!)', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20915, '2022-06-25 14:56:06.60418+00', '2022-08-05 17:35:45.765022+00', 'Jesmond Saunter', 'JESMOND SAUNTER', 3, 32, NULL, 1, 3, 42, 2806, NULL, 'Jesmond Dene is a pleasant, green, leafy area with footpaths along and near the River Ouse in a part of Jesmond on the outskirts of Newcastle.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20928, '2022-06-29 18:24:41.153402+00', '2022-06-29 18:24:41.153402+00', 'Bees Are Back!', 'BEES ARE BACK', 1, 32, NULL, 1, 3, NULL, 2766, '2022-03-01', 'This dance should rightly be named ''Bees Are Still Here!'''' since this is the first year we have had bees survive the winter.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20924, '2022-06-29 03:55:12.221961+00', '2022-06-29 04:21:54.7968+00', 'High Maintenance', 'HIGH MAINTENANCE', 1, 32, NULL, 2, 3, 17, 2766, '2022-05-01', 'We have a 16-year-old cat who has many medical issues. He’s been diagnosed with Cushing''s Disease and has all the issues that come with that, so we have to regulate his food and he takes many medications. He is ''high maintenance'' and I wanted to write a dance in which everyone is busy all the time.', 72, '888/888/888/488', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20228, '2021-02-22 19:09:19.449343+00', '2022-06-30 17:36:56.337325+00', 'Pat a Cake Polka', 'PAT A CAKE POLKA', 13, 16, NULL, 5, 113, NULL, 9998, NULL, 'Simple ceilidh dance. Couples facing round the room anticlockwise.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20902, '2022-06-23 18:46:58.087284+00', '2022-06-23 18:46:58.087284+00', 'Slater''s Crimson China', 'SLATERS CRIMSON CHINA', 3, 32, NULL, 1, 4, 11, 2682, '2022-06-04', 'Slater’s Crimson China (Rosa eglanteria) was the first rose brought to New Zealand.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20905, '2022-06-23 19:08:57.97507+00', '2022-06-23 19:08:57.97507+00', 'Summer Waltz Mixer', 'SUMMER WALTZ MIXER', 5, 16, NULL, 7, 1, NULL, 2682, '2022-01-15', '', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18978, '2018-10-17 11:19:16.952179+00', '2022-08-15 14:39:13.876603+00', 'Golden Branch, The', 'GOLDEN BRANCH', 3, 32, NULL, 1, 4, 1, 2680, '2000-07-01', 'This dance is devised in honour of the 50th Anniversary of the Boston Branch of the RSCDS. They are indeed a Golden Branch.



NB there is a version of the instructions for this dance which has it as a Reel rather than Strathspey.', 72, '8004/8888/8080/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20914, '2022-06-25 14:52:02.01652+00', '2022-06-28 17:56:14.944002+00', 'Gill''s Jig', 'GILLS JIG', 2, 32, NULL, 1, 4, 11, 2806, NULL, 'This dance was devised for Gillian Stewart, Branch member and one of our very accomplished Branch pianists. She has played for classes, courses and dances etc. for many years. She plays in both our local bands "The Braes of Wansbeck" and "The Music Will Tell You".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14994, '2013-07-25 10:25:30.843969+00', '2022-06-28 18:02:40.166861+00', 'Time to Spare', 'TIME TO SPARE', 3, 32, NULL, 2, 3, 17, 2806, NULL, 'This dance was devised in 2011 in memory of Howard Graham who, with hs wife Heather, were members of our Branch and attended most of our functions.  Howard was retired and used to say he had "Time to Spare".', 56, '884  884  844  808', 1, 1, 1, 0, 75);
INSERT INTO 'dance' VALUES (9561, '2001-11-21 23:00:00+00', '2022-07-05 10:36:26.119306+00', 'S-Locomotion', 'SLOCOMOTION', 3, 32, 9999, 1, 4, 1, 2789, '1998-01-01', 'In the  "Scottish Country Dancer" No 21 October 2015 under ''Letters to the editors'' , p.28 you find the following interesting letter about the pronunciation of ''S-Locomotion''.



Dear Editor,



At the recent AGM we were invited to dance the strathspey from book 41, which was incorrectly announced as "Ess-Locomotion".  The deviser, the late Ken Jones of Sheffield Branch wrote this dance in honour of our Branch President, Paul Bond.  Ken knew that Paul had a passionate interest in steam engines  and assumed, wrongly as it happens, that these were the type which hauled trains, hence "Locomotion".  However, he realized that by preceding this word with the letter "S", he could point out that Paul, always a stirrer, but now getting elderly, caused, wherever he went, a "slow commotion"!



Joyce and Hugh Porteous, Sheffield Branch

', 84, '6666/6666/8488/8888', 1, 1, 1, 1, 84);
INSERT INTO 'dance' VALUES (20936, '2022-07-06 11:21:13.644173+00', '2022-09-02 10:25:09.919467+00', 'Friday Evening, The', 'FRIDAY EVENING', 3, 32, NULL, 2, 3, 17, 12166, NULL, 'From the dance notes: *What to do when your Internet connection is lost while you’re in the middle of the class? To write a new dance, of course!*', 48, '800/811/844/804', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20925, '2022-06-29 04:20:02.06846+00', '2022-06-29 15:12:48.43264+00', 'Golden Splendor', 'GOLDEN SPLENDOR', 2, 32, NULL, 1, 3, 42, 2766, '2022-05-01', 'One day I was looking out the window and flashes of gold flew by and I watched a pair of goldfinches flying around the yard, then I thought of the figure in bars 1-8 and the rest followed. When my group tried the dance, people set in bars 17-24 as is often done in Australian Ladies (half set across then finish facing up and down) and one person opted to half set backing up then finishing forward. But first couple can make the track just fine – note that the track is a figure of 8 around 1st corner positions.', 63, '880/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2518, '1997-09-03 22:00:00+00', '2022-07-01 13:43:52.753742+00', 'Glen, The', 'GLEN', 2, 32, 9999, 1, 2, 76, 954, '1985-01-01', 'Suggested music is "Any good jig (or reel), 6 (or 8) times through".', 60, '88  88  80  88', 1, 1, 1, 1, 87);
INSERT INTO 'dance' VALUES (20912, '2022-06-25 14:28:47.181819+00', '2022-10-25 20:04:19.476269+00', 'Robert''s Rant', 'ROBERTS RANT', 1, 32, NULL, 1, 3, 42, 2806, NULL, 'Devised in March 2018 in memory of Robert Hughes who died the previous month. [More detail in the book]', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20895, '2022-06-17 15:04:31.484378+00', '2022-06-26 11:39:47.319337+00', 'Ronalds'' Reel, The', 'RONALDS REEL', 1, 48, NULL, 2, 3, 18, 12153, '2022-04-30', 'The dance is dedicated to Chris and Sue Ronald in gratitude for mentoring and supporting a new generation of teachers and dancers in the New York area in the years before they left stateside and returned to their native England in 2021. 

', 86, '884/888/844/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20922, '2022-06-26 12:07:47.525955+00', '2022-06-26 12:10:25.885182+00', 'Slinky, The', 'SLINKY', 2, 32, NULL, 2, 3, 17, 2973, '2012-10-30', 'Named after the children''s toy. 



The formation ''set and link'' was devised by New Zealander Alec Hay in 1966. He indicated that hands are released on completion of the setting steps. A tendency has emerged for dancers to retain hands some way into the linking movement. I discourage this practice as it risks shoulder injuries. 



As with many of my ''formation dances'', this dance may be done as a jig, reel or strathspey.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5604, '2002-11-14 23:00:00+00', '2022-07-01 22:31:54.689742+00', 'Road to Applecross, The', 'ROAD TO APPLECROSS', 2, 32, 9999, 1, 3, 42, 313, NULL, 'Not to be confused with <<ddd:Trip to Applecross>>.



“Applecross, a remote Highland village on Scotland''s west coast, facing the island of Raasay, can be approached via Bealach nam Bo, ‘The Pass of the Cattle’, a mountain road with steep zig-zag turns and spectacular views of Skye and the Outer Isles.”', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20906, '2022-06-23 22:41:56.971234+00', '2022-10-25 20:10:03.462831+00', 'North Country Weaver', 'NORTH COUNTRY WEAVER', 3, 32, NULL, 1, 3, 42, 11924, '2022-02-01', 'Devised by Beth Birdsall in February 2022 in honor of her mother, Polly Birdsall, for the occasion of a

birthday. Polly is an avid weaver and knitter in addition to being a Scottish Country Dance teacher, and

the figures of the dance are intended to evoke warping and weaving on a loom.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20933, '2022-07-05 22:52:42.272108+00', '2022-07-05 22:52:42.272108+00', 'Hedgehog''s Birthday', 'HEDGEHOGS BIRTHDAY', 1, 48, NULL, 1, 4, 1, 12163, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20929, '2022-07-03 01:55:33.072332+00', '2022-10-09 10:29:11.725775+00', 'Shared Tradition, A', 'SHARED TRADITION', 1, 32, NULL, 1, 3, 42, 2766, '2022-03-01', 'We dance all over the world and we dance the same figures, thus Scottish Country Dancing is a worldwide shared tradition.', 38, '800/822/822/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11107, '2003-01-13 23:00:00+00', '2022-07-03 18:00:06.284466+00', 'St Andrews Links', 'SAINT ANDREWS LINKS', 3, 40, 9999, 2, 3, 17, 3091, '2002-01-01', 'Devised in 2001 to celebrate the ''links'' between the Home of Golf and the RSCDS.', 77, '800  888  888  866  484', 1, 1, 0, 0, 76);
INSERT INTO 'dance' VALUES (12422, '2005-05-01 22:00:00+00', '2022-07-03 18:15:01.939978+00', 'Salute to the Keans', 'SALUTE TO THE KEANS', 3, 32, 9999, 1, 4, 1, 3538, '1994-01-01', 'Devised and performed for Margaret and Doug Kean on their 25th Wedding Anniversary.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16595, '2015-08-26 18:44:55.511096+00', '2022-07-03 20:09:02.586288+00', 'Diamond for Helensburgh, A', 'DIAMOND FOR HELENSBURGH', 4, 64, 5, 1, 4, 28, 3183, '2011-01-01', 'Devised to celebrate the 60th Anniversary of Helensburgh & District RSDCS.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20919, '2022-06-25 15:21:45.411793+00', '2022-10-25 19:45:46.287225+00', 'Tyne Bridge, The', 'TYNE BRIDGE', 2, 32, NULL, 1, 4, 1, 2806, NULL, 'The movements involved are an attempt to show the structure of the Tyne Bridge.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20893, '2022-06-11 20:17:24.182127+00', '2022-06-13 00:03:43.536363+00', 'Une Mazurka sous les Étoiles', 'UNE MAZURKA SOUS LES ETOILES', 3, 32, NULL, 2, 3, 17, 11643, '2022-06-09', 'Description



 “Une mazurka sous les étoiles”  

32 bars strathspey for 3c in a 3c set.



1-8::

       1c+2c dance the Poussette  

   

9-16::

     Mirror reels of 3 on own side (1c start in and down ; all three couples join hands when possible).  

            On 7&8: 1c+2c continue a little bit faster to put 1c in second place and 2c at top (1c make a loop to finish in second place)  

            (finishing in order: 2, 1, 3).   

  

17-24::

   1c dance the Figure of love (starting going to the left: woman down, man up).  

            [1W cross down and cast up one place (behind her 2nd corner) while 1M cross up and cast off one place (behind his 2nd corner),

            1c meet in the middle, touch BH and twirl (Rsh back), and 1W cast up one place (behind her 1st corner) and cross down to go back to 2nd place while 1M cast down one place (behind his 1st corner) and cross up to go back to 2nd place]  

  

  

25-32::

   1c+3c dance The Tourbillon    (finishing in order: 2, 3, 1). ', 67, '880/888/800/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5956, '1998-12-20 23:00:00+00', '2022-06-15 07:45:51.021248+00', 'Scottish Fiddler o'' Crieff, The', 'SCOTTISH FIDDLER O CRIEFF', 2, 32, 9999, 1, 3, 42, 3461, '1984-01-01', 'Dedicated to the fiddle players at Pinewoods, 1982, and devised for Ron''s tunes "Bert Gonnella''s Jig" and

"Lizzie Duncan''s Fancy" by Evelyn M. E. Murray.  



The Fiddler is, of course, Ron Gonnella. The musicians at Pinewoods Camp in Massachusetts, that year included Christine Anderson, Ron Gonnella, Colin Gordon, Barbara McOwen, Ed Pearlman, Ralph Thompson and John Turner. Pinewoods is the place where the Boston Branch of the Royal Scottish Country Dance Society holds its summer week and weekend sessions. To the deviser, Pinewoods is a beautiful place to enjoy the timeless musical and dancing heritage of Scotland without interference from the modern world; it means "time out"!', 63, '880/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20100, '2020-10-03 19:56:11.118922+00', '2022-06-16 23:02:37.794313+00', 'Four Weeks of Summer School', 'FOUR WEEKS OF SUMMER SCHOOL', 1, 32, NULL, 1, 4, 2, 11527, '2020-01-01', 'The notes suggest you "Imagine the first day of Summer School in St. Andrews where people from around the world meet. First meetings, first dancing, more and more new friends till the last night which means the end of the week and leaving new friends. But at the same time it is the beginning of a new week..."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20894, '2022-06-17 10:05:11.557658+00', '2022-06-17 10:05:11.557658+00', 'Crocked But Willing!', 'CROCKED BUT WILLING', 3, 32, NULL, 2, 3, 42, 802, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9876, '2002-03-03 23:00:00+00', '2022-06-17 10:46:57.285529+00', 'Nelson''s Column', 'NELSONS COLUMN', 3, 56, 9999, 1, 4, 3, 697, NULL, '', 86, '8888/8008/0880/8888/8888/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20358, '2021-06-21 21:25:49.969513+00', '2022-06-17 11:07:59.687536+00', 'Paddlewheeler, The', 'PADDLEWHEELER', 4, 64, 5, 4, 4, 1, 2680, '2001-04-01', 'Devised to celebrate the one day workshop held by the Vernon SCD club in the Paddlewheel Hall, Vernon B.C. in April 2001.', 75, '8080/8080/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20898, '2022-06-19 15:34:24.666318+00', '2022-06-19 15:34:57.726931+00', 'Black Hole Spin', 'BLACK HOLE SPIN', 3, 32, NULL, 1, 4, 11, 11936, '2018-03-01', 'From the deviser: “ The gradually increasing number and size of circles, from two people to four people

to eight, is intended to represent the increasing size of black holes over time as they merge together.

The casting out of the circle is intended to represent Hawking radiation; pair production near to a black

hole event horizon (pairs turn), can lead to one particle falling into the black hole (one of each pair forms

a circle), the other particle free to radiate out (dance out and cast). In this way, energy is lost from a

black hole and they can evaporate over time (circle disperses).



The general motion of the dance is (almost) continually in the same direction, reminiscent of the

conserved angular momentum / spin properties of a black hole. This dance was devised in honour of

Stephen Hawking, who passed away aged 76 on 14th March 2018.”



DEVISED: 2018-03', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16761, '2015-09-21 22:02:06.120748+00', '2022-06-19 16:36:37.026541+00', 'Yorkshire Rose, The', 'YORKSHIRE ROSE', 2, 32, NULL, 1, 3, 42, 11209, '2013-01-01', 'Source: Minicrib



Devised in 2013 for over 90 year old Winifred Barker. See <<https://www.chesterstandard.co.uk/news/15973701.chester-woman-90-has-traditional-jig-named-after-her/>>.

(NB her name is misspelled Baker in that article: see <<https://my.strathspey.org/dd/issue/2810/|issue 2810>>).', 56, '888/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8201, '1997-12-27 23:00:00+00', '2022-06-17 19:32:47.896554+00', 'Ruby Wedding Strathspey, The', 'RUBY WEDDING STRATHSPEY', 3, 32, 9999, 1, 3, 42, 74, '1995-07-01', 'Deviser = Napier 921', 63, '888/844/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20896, '2022-06-17 22:37:58.382306+00', '2022-06-17 23:02:56.96061+00', 'Miss Amy Andrews', 'MISS AMY ANDREWS', 3, 32, NULL, 2, 3, 17, 12154, NULL, '', 92, '866/888/888/848', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (782, '1997-12-21 23:00:00+00', '2022-06-21 14:28:01.072459+00', 'Brendan Brae, The', 'BRENDAN BRAE', 3, 32, 9999, 1, 3, 42, 425, '1992-03-01', '', 69, '888/888/888/808', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20897, '2022-06-19 08:46:48.650933+00', '2022-06-20 06:10:14.254032+00', 'Kelburn''s Farewell', 'KELBURNS FAREWELL', 2, 32, NULL, 1, 3, 42, 11890, '2022-04-01', 'Kelburn’s Farewell was on the programme for the Kelburn Scottish Country Dancing Club’s tea dance on June 19, 2022.  



The dance was devised by the club’s tutor, Chris Totton, and its name reflects the fact that the club is closing down after 63 years of existence.  



The dance was held in St Michael’s church hall in Kelburn, Wellington, New Zealand. Live music was by Aileen Logie, Hilary Ferral and Jason Morris.  



The deviser asked Aileen Logie to write the lead tune for the dance. Aileen writes: “I wrote a tune that night  - a tune which has happy bits and sad bits, reflecting all the good years of the Kelburn club and their decision to close. A few days later, Chris sent me the dance and mentioned that he liked Vale of Atholl on the Heather Hills CD. My jig happened to go pretty well with these tunes, and so the set was made quite easily. I just needed to change the tunes to an ABBA configuration to fit with Chris''s dance. (Vale of Atholl is a well known pipe band based in Pitlochry, Scotland - it wins lots of trophies globally. The tunes are in the style of pipe jigs).”  



Aileen’s lead tune is also called Kelburn’s Farewell.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2608, '1997-09-03 22:00:00+00', '2022-06-20 07:44:12.048467+00', 'Goodnight and Joy Be With You', 'GOODNIGHT AND JOY BE WITH YOU', 1, 32, 9999, 1, 3, 42, 21, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2125, '1998-10-04 22:00:00+00', '2022-06-21 21:34:37.040903+00', 'Ferla Mor', 'FERLA MOR', 1, 32, 9999, 1, 3, 42, 108, '1971-01-01', '', 44, '800  844  844  844', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (11294, '2003-05-04 22:00:00+00', '2022-06-18 07:23:24.850151+00', 'Sylvan Strathspey, The', 'SYLVAN STRATHSPEY', 3, 32, 9999, 1, 2, 76, 2783, '1999-11-01', '', 64, '84  88  88  88', 1, 1, 1, 1, 93);
INSERT INTO 'dance' VALUES (2640, '1998-04-12 22:00:00+00', '2022-06-18 08:40:11.323484+00', 'Grandmother''s Delight', 'GRANDMOTHERS DELIGHT', 3, 32, 9999, 1, 3, 42, 227, '1987-01-01', '', 62, '880  888  880  888', 0, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (10589, '2002-06-04 22:00:00+00', '2022-06-27 12:17:00.634879+00', 'Miss Catherine Ann', 'MISS CATHERINE ANN', 3, 32, 9999, 2, 3, 17, 316, NULL, '', 56, '840/804/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12186, '2005-04-14 22:00:00+00', '2022-06-22 22:11:54.945856+00', 'Desperation', 'DESPERATION', 1, 32, 9999, 1, 3, 42, 135, '1994-04-01', 'The dance was devised in desperation as the deadline for the 1994 Jack McConachie Sword Competition entries loomed', 62, '880/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20553, '2021-11-06 18:06:29.546164+00', '2022-06-23 20:57:09.77081+00', 'Maggie Boag''s Jig', 'MAGGIE BOAGS JIG', 2, 32, NULL, 1, 4, 1, 2682, '2021-10-08', 'Source <<https://youtu.be/pmMfNLfAOKU|youtube video>> which suggest that any reasonable recording of ”The Dhoon” will suffice.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13933, '2011-08-22 22:00:00+00', '2022-06-27 13:01:32.369863+00', 'Under African Skies', 'UNDER AFRICAN SKIES', 1, 32, NULL, 1, 3, 42, 146, NULL, '', 64, '626/888/848/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20942, '2022-07-07 09:25:19.702071+00', '2022-07-07 09:25:19.702071+00', 'Bicycle Rental Jig', 'BICYCLE RENTAL JIG', 2, 32, NULL, 1, 3, 42, 12169, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20943, '2022-07-07 09:31:09.292553+00', '2022-07-07 09:31:09.292553+00', 'Moscow Bikefest', 'MOSCOW BIKEFEST', 1, 32, NULL, 1, 4, 2, 12170, NULL, 'From the dance notes:  

*It’s about the Moscow Bicycle Festival. On which people who love cycling gather together to drive the entire Sadovoe Koltso (the name of the boulevard in Moscow). This is a dance about a meeting of like-minded people, Sadovoe, and of course, bicycles.*', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20944, '2022-07-07 09:34:05.360495+00', '2022-07-07 09:34:05.360495+00', 'Flying of Soap Bubbles, The', 'FLYING OF SOAP BUBBLES', 1, 32, NULL, 7, 1, 4, 12119, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20945, '2022-07-07 09:38:25.837162+00', '2022-07-07 09:38:25.837162+00', 'Eat the Road!', 'EAT THE ROAD', 1, 32, NULL, 1, 3, 42, 11527, NULL, 'From the dance notes:  

*The dance is dedicated to Uriy Saifulin, the fastest taxi driver in Volga river region. He can transfer you from one town to another with the the speed of the light. Just fasten your seat belt.*', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20946, '2022-07-07 10:29:43.517604+00', '2022-07-07 10:29:43.517604+00', 'Missing Friends', 'MISSING FRIENDS', 3, 32, NULL, 2, 3, 18, 2887, '2021-08-01', 'Source: dance list <<https://my.strathspey.org/dd/list/34802/>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20938, '2022-07-06 22:57:14.735641+00', '2022-07-08 14:00:37.120677+00', 'Snail, The', 'SNAIL', 3, 32, NULL, 1, 4, 1, 12119, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20941, '2022-07-06 23:39:46.952898+00', '2022-07-08 14:21:11.094253+00', 'Tea and Strawberry Jam', 'TEA AND STRAWBERRY JAM', 2, 32, NULL, 1, 3, 42, 12168, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (521, '1998-09-27 22:00:00+00', '2022-07-09 10:28:05.189897+00', 'Birks of Abergeldie, The', 'BIRKS OF ABERGELDIE', 1, 48, 9999, 1, 3, 42, 9998, '1720-01-01', '', 33, '800  800  880 844  800  800', 1, 1, 0, 1, 44);
INSERT INTO 'dance' VALUES (6405, '1998-04-19 22:00:00+00', '2022-07-10 08:31:05.476299+00', 'Susie Petrov''s Strathspey', 'SUSIE PETROVS STRATHSPEY', 3, 32, 9999, 3, 5, 21, 361, '1990-01-01', 'Devised in 1990 under the working title "Hamish Henderson''s Refusal", the dance was revised in 1991 and published in 1992 as "Susie Petrov''s Strathspey".



The dance is dedicated to Susie Petrov, one of the inspiring musicians who have played at TAC Summer School [presumably 1990].



This dance appears in a <<https://www.youtube.com/watch?v=4cQ-vaS3Nsc|YouTube video>> that states: *Recorded on September 13, 2008, at the Arkansas Dance Festival in Mountain View. The dances included are "A Flock of Geese," "A Trip to St. Andrews." and "Preston Mill."*    The second dance is in fact "Susie Petrov''s Strathspey".  It is unclear how the wrong name arose.', 77, '84448/88088/08880/88888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10069, '2001-09-12 22:00:00+00', '2022-07-21 15:02:13.265699+00', 'Bespoke Taylors', 'BESPOKE TAYLORS', 3, 32, 9999, 1, 3, 42, 108, '1999-01-01', 'John Drewry wrote this dance for the Taylors of Dargaville, New Zealand. 



Note: During Bars 25-32, 1st man dances up both times, while 1st woman dances down both times, to enter the half reels of four.', 63, '844/888/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20017, '2020-06-16 20:11:12.294631+00', '2022-07-10 08:45:22.717334+00', 'Thunderbird 5', 'THUNDERBIRD 5', 1, 32, NULL, 4, 55, 16, 11415, NULL, 'devised this dance to help in classes when numbers may be limited and gave it this title as Thunderbirds was a favourite TV programme as a child.', 65, '88888/80808/08088/24442', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5924, '1997-04-03 22:00:00+00', '2022-07-14 02:10:15.423311+00', 'Scotch Gate', 'SCOTCH GATE', 1, 32, 9999, 1, 3, 42, 212, '1979-01-01', 'Entry to the old walled City of Carlisle from the Borders was through the Scotch Gate. It has historical associations with Bonnie Prince Charlie, Sir Walter Scott and the song The Yellow Haired Laddie.', 66, '888/888/888/822', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20531, '2021-10-21 18:20:13.362697+00', '2022-07-10 10:18:12.409344+00', 'Trèfle à Quatre Feuilles, Le', 'TREFLE A QUATRE FEUILLES', 2, 32, NULL, 1, 3, 42, 11509, '2019-04-01', 'This dance was devised to introduce the corners pass and turn formation. It was very popular in a group where only a very few people understand English, so it was given the French name for a four-leaf clover.', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7520, '2003-01-09 23:00:00+00', '2022-07-11 20:11:27.687956+00', 'Saint Columba''s Strathspey', 'SAINT COLUMBAS STRATHSPEY', 3, 32, 9999, 3, 5, 10, 435, '1985-02-15', 'Devised for St. Columba''s Hospice, Boswall Road, Edinburgh



Warning. In "SCD in Diagrams" (the "Pilling" book), up to the 8th Edition, the line at bar 12 is solid instead of dashed, giving the erroneous impression that this is a 40-bar dance.', 55, '08080  48884  08080  48444', 1, 1, 1, 0, 55);
INSERT INTO 'dance' VALUES (9220, '2002-02-16 23:00:00+00', '2022-07-11 20:52:19.520131+00', 'Thomas Glover''s Reel', 'THOMAS GLOVERS REEL', 1, 32, 9999, 1, 3, 42, 108, '1998-01-01', 'The dance notes say this was "for the dancers in Mr. Miyakawa''s Group in Japan, who have invited me to visit them in 1998".



Thomas Glover, originally from Aberdeen, settled in Nagasaki Japan where he founded a trading company.

', 47, '800  844  822  888', 1, 1, 0, 0, 62);
INSERT INTO 'dance' VALUES (12695, '2006-02-16 23:00:00+00', '2022-07-13 01:19:12.924426+00', 'Yorkshire Lasses', 'YORKSHIRE LASSES', 2, 32, 9999, 1, 3, 42, 146, '2004-01-01', 'For Rae Baston, Avis Harrison and Pat Hynes to celebrate their 210 years in 2004.', 45, '440/860/888/822', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (936, '1998-09-29 22:00:00+00', '2022-07-13 06:27:46.516522+00', 'Caledonian Rant, The', 'CALEDONIAN RANT', 3, 32, 9999, 1, 3, 42, 432, '1816-01-01', '', 31, '800/800/800/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10071, '2001-09-12 22:00:00+00', '2022-07-21 15:05:36.634919+00', 'Cat and the Fiddle, The', 'CAT AND THE FIDDLE', 2, 32, 9999, 1, 3, 42, 108, '1998-01-01', 'Note from the original description: Both of the diagonal half reels of four (Bars13-16 and Bars 21-24) are from first place on the women''s side to third place on the men''s side.', 56, '800  888  888  844', 0, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (9985, '2001-09-12 22:00:00+00', '2022-07-21 15:07:23.067785+00', 'Christies'' Strathspey', 'CHRISTIES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1999-08-01', 'John Drewry wrote this dance for the Christies of Vancouver Island.



We have two PDFs as source for this dance:

1.  A typical Drewry typed sheet, where the dance is called "Christie''s Strathspey"

2.  A copy of the pages of Greenburn Book 3, where the dance is called "Christies'' Strathspey"', 41, '800  844  844  822', 1, 1, 1, 0, 54);
INSERT INTO 'dance' VALUES (20908, '2022-06-25 13:46:02.165951+00', '2022-07-28 08:47:23.115377+00', 'Busy Fingers', 'BUSY FINGERS', 1, 32, NULL, 1, 3, 42, 2806, NULL, 'Devised for Patricia Cass in appreciation for all she has done for our Branch over many years. Patricia is an accomplished pianist and has played for classes, courses and events for much longer than many members can remember. She has been on the Branch committee including some years as secretary. Along with her husband John (The Festival Man), she co-founded The Newcastle Festival and ran it for 30 years. This is a straightforward little dance as Patricia likes things to be uncluttered!

', 50, '800/866/866/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20962, '2022-07-30 12:27:52.637809+00', '2022-07-30 12:30:13.214708+00', 'Julia''s First Cousin', 'JULIAS FIRST COUSIN', 2, 32, NULL, 1, 3, 42, 12185, NULL, 'Found at <<http://rscdsboston.org/events-fliers/Albany50thAnniversaryParty2022.pdf>> and dance list <<https://my.strathspey.org/dd/list/32988/>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (185, '1997-08-28 22:00:00+00', '2022-07-30 16:42:33.004182+00', 'Anniversary Strathspey', 'ANNIVERSARY STRATHSPEY', 3, 32, 9999, 1, 3, 42, 640, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (698, '1997-08-31 22:00:00+00', '2022-07-30 18:44:48.605846+00', 'Border Hills, The', 'BORDER HILLS', 3, 32, 9999, 1, 3, 42, 713, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1556, '1997-09-01 22:00:00+00', '2022-07-31 10:11:07.111379+00', 'Dargie Glebe', 'DARGIE GLEBE', 3, 32, 9999, 2, 3, 17, 108, '1975-02-02', 'Inscribed "for George Mechan of Invergowrie, Dundee".', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20947, '2022-07-15 13:28:18.307423+00', '2022-07-15 13:41:53.843779+00', 'Mainzer Narhalla Reel', 'MAINZER NARHALLA REEL', 1, 40, 9999, 1, 3, 42, 12178, '2009-01-01', 'The title of this dance is inspired by the <<https://en.wikipedia.org/wiki/Narrhallamarsch|Mainzer Narrhalla-Marsch>>, the signature tune of the “Meenzer Fassenacht” (Mainz carnival), composed in 1840 by bandmaster and founding member of the *Mainzer Carneval-Verein* (Carnival Club of Mainz), Carl Zulehner (1805-1847).



In the city of Mainz, carnival is culturally very important (to a point where it is referred to locally as “the fifth season”). The SCD group there is called the “Narhalla Dancers” [only one “r”].



The formations of the dance symbolise various aspects of the history and culture of the city of Mainz:



- The hands across on bars 1–8 stand for the wheels in the city''s traditional coat of arms.

- The 1st couple''s solo figure on bars 9–16 symbolises the Mainz carnival parade.

- Bars 17–24 evoke the *Äbsch Seit* (“wrong side”), i.e., the other bank of the river Rhine.

  Of course the inhabitants of Mainz consider themselves greatly superior to the people living there

  (a sentiment that is vigorously reciprocated).

- Bars 25–32 allude to Mainz-based Johannes Gutenberg''s invention of printing using movable type.

- The cross formation in bars 33–36 signifies the archbishopric of Mainz.

- The final movement on bars 37–40, the “wine press”, points to the local tradition of viticulture.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20948, '2022-07-15 17:37:12.538423+00', '2022-07-15 17:37:12.538423+00', 'Reverse Reel, The', 'REVERSE REEL', 1, 40, NULL, 3, 5, 16, 3400, NULL, 'Deviser''s notes: “While the instructions are for a 5×40 Dance, it can be danced in 3, 4, or 5 couple sets. If a 3 or 4 couple set, careful phrasing is required. It can also easily be ‘converted’ to a 32 bar reel by eliminating bars 17–24 (or 33–40).”', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20949, '2022-07-15 17:44:20.68823+00', '2022-07-15 17:44:40.156572+00', 'Lady Gwen''s Crossroad Reels', 'LADY GWENS CROSSROAD REELS', 3, 32, NULL, 2, 3, 17, 12179, NULL, 'Dedicated to Gwen Paterson-Traxler.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20950, '2022-07-15 17:53:58.845711+00', '2022-07-15 17:53:58.845711+00', 'Courting, The', 'COURTING', 1, 96, NULL, 107, 5, NULL, 12180, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20952, '2022-07-15 22:13:48.437083+00', '2022-07-15 22:14:47.956361+00', 'Darwin', 'DARWIN', 1, 48, NULL, 2, 3, NULL, 10568, '2021-12-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2575, '2002-03-11 23:00:00+00', '2023-01-27 11:16:45.780382+00', 'Glowerin'' Coo, The', 'GLOWERIN COO', 2, 32, 9999, 1, 3, 42, 108, '1988-01-01', 'Dedication for the dance: "For Stanley Wilkie of Edinburgh who, when teaching double triangles, said that first couple should not be like ''coos glowering ower a dyke''."', 62, '888  866  866  844', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (20960, '2022-07-30 12:09:00.876289+00', '2022-07-30 12:09:00.876289+00', 'V Times X', 'V TIMES X', 1, 32, NULL, 1, 4, 1, 160, NULL, 'Found at <<http://rscdsboston.org/events-fliers/Albany50thAnniversaryParty2022.pdf>> and dance list <<https://my.strathspey.org/dd/list/32988/>> where it is just attributed to "Grubb".', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20957, '2022-07-15 22:29:57.476833+00', '2022-07-16 22:59:59.235228+00', 'Troubles End', 'TROUBLES END', 3, 40, NULL, 2, 3, 18, 10568, '2022-05-01', 'After a wonderful SCD weekend at Pawling and a visit with Lois New in Albany for a hybrid zoom dance (on the more exciting side of the camera for a change), we were driving up through Vermont to see Don and Martha Kent. We passed a lane called Troubles End and, since that described exactly how we felt after going away for the first time in 2 years, I decided to use it as a name for a dance – dedicated to Pawling,  

Lois New and Don and Martha Kent. Thank you for making us feel human again.', 65, '880/888/888/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9235, '2000-01-16 23:00:00+00', '2022-07-21 14:53:48.619494+00', 'Milton''s Strathspey', 'MILTONS STRATHSPEY', 3, 32, 9999, 1, 4, NULL, 108, '1997-01-01', 'John Drewry wrote the dance in memory of Milton Levy, who died in December 1996 and who devised the formations ''set and link for three'' and ''balance in line with Highland Schottische''.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20953, '2022-07-15 22:16:58.413357+00', '2022-07-16 02:27:44.227787+00', 'As Time Goes By', 'AS TIME GOES BY', 1, 32, NULL, 1, 3, 42, 10568, '2021-12-01', 'I decided to write a birthday dance for myself!! I love a three couple poussette.', 53, '888/884/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12625, '2005-11-08 23:00:00+00', '2022-07-16 19:45:10.735443+00', 'Lady Stoneycroft', 'LADY STONEYCROFT', 3, 32, 9999, 1, 4, 1, 3647, NULL, 'Lady Stoneycroft was the name given to the mother of one of the dancers who put on a posh voice when answering the phone.', 84, '8888/8888/6666/2666', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1398, '1998-07-08 22:00:00+00', '2022-07-17 14:54:11.50206+00', 'Craigievar', 'CRAIGIEVAR', 3, 32, 9999, 1, 100, 11, 127, NULL, 'Craigievar Castle at Alford, Aberdeenshire, is the ancestral home of the FORBES Clan.', 97, '8888/8888/6886/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19169, '2019-01-18 15:46:57.056553+00', '2022-07-17 18:38:18.548903+00', 'Across Kildonan Hall', 'ACROSS KILDONAN HALL', 3, 32, NULL, 2, 3, 17, 10568, '2019-08-01', 'Written for a TMR class celebrating Katie and Alistair’s engagement.', 64, '880/888/888/846', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20951, '2022-07-15 22:11:47.937422+00', '2022-07-18 07:39:21.448951+00', 'Tour En L''Air', 'TOUR EN LAIR', 3, 32, NULL, 1, 2, 76, 10568, '2021-10-01', 'One of those ‘to help me get to sleep’ dances. Plus I do love the Tournée.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10070, '2001-09-12 22:00:00+00', '2022-07-21 15:03:31.129258+00', 'Bow Fiddle Rock', 'BOW FIDDLE ROCK', 2, 32, 9999, 1, 3, 42, 108, '2000-05-01', 'Note from the original description: "Bow Fiddle Rock" is at Portknockie at the west end of Cullen Bay (about forty miles north of Aberdeen). It is a large pointed rock surrounded by the sea, but not very far from the shore. On it''s south side there is a large arc of rock almost like a flying buttress. An impressive sight! There, are several other interesting rocks nearby.', 56, '800/844/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20958, '2022-07-21 09:25:03.458571+00', '2022-07-21 09:31:29.464326+00', 'Calvin Welcome, A', 'CALVIN WELCOME', 2, 32, NULL, 1, 4, 1, 12181, '2017-01-01', '', 36, '8000/8000/8800/8222', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7099, '1998-07-08 22:00:00+00', '2022-07-21 10:13:51.51853+00', 'Whisky in Bond', 'WHISKY IN BOND', 3, 32, 9999, 1, 4, 2, 108, '1982-01-01', '*Notes from the book:*



The dance was written to mark the Silver Wedding Anniversary of Paul and Dulcie Bond.



''Whisky in Bond'' is whisky stored in a ''bonded'' warehouse awaiting payment of excise duty.

Naturally it is kept with the strictest security.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10170, '2002-02-16 23:00:00+00', '2022-07-21 10:20:47.252652+00', 'Whirling Dervishes, The', 'WHIRLING DERVISHES', 1, 32, 9999, 1, 4, 2, 108, '2000-09-01', 'The dance notes for the set turning about in bars 3-4 say

''Dancers who find this too vertiginous may set without turning''.', 69, '8080/8888/8484/8008', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10010, '2002-03-03 23:00:00+00', '2022-07-21 16:19:01.804961+00', 'Oooh Chihuahua!', 'OOOH CHIHUAHUA', 1, 48, 9999, 1, 4, 11, 108, '2000-01-01', 'John Drewry adds some notes in *Greenburn Book 3:*



* A jolly dance to celebrate May Day 2000

* The title, which comes from an exclamation made by a young man in a current Television Commercial, is pronounced with the "Oooh" very long and the second syllable of "Chihuahua" strongly accented. I thought it would be an amusing dance title.

* Chihuahua is a province and a city in the north of Mexico. My books tell me that the province is mainly a high plateau and I hope that the dancers are on a high after doing the dance.

* Chihuahuas are also a breed of miniature dogs.', 79, '4884/8888/8008/6666/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20963, '2022-07-30 12:40:22.721208+00', '2022-07-30 12:40:22.721208+00', 'Black Cat''s Jig, The', 'BLACK CATS JIG', 2, 32, NULL, 1, 3, 42, 1349, NULL, 'Source <<http://www.rscds-greaterdc.org/flyers/nova_carolporter2022_cs.pdf>> and dance list <<https://my.strathspey.org/dd/list/34989/>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20954, '2022-07-15 22:21:00.194856+00', '2022-09-23 18:58:12.895201+00', 'Dancing with the Daffodils', 'DANCING WITH THE DAFFODILS', 4, 128, 2, 4, 4, 13, 10568, '2022-03-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9984, '2001-09-12 22:00:00+00', '2022-07-21 15:15:18.065559+00', 'Dowry Bride, The', 'DOWRY BRIDE', 3, 32, 9999, 1, 4, 1, 108, '1999-10-01', '*Notes from Greenburn Book 3:*



For Margaret Pirie of St Cyrus at the request of her husband Charlie.



1. John Orr was born at Bridgeton, near St Cyprus, in 1794. He went to India and worked in Madras. He retired in 1843 and died in November 1845. He left money in a trust, proceeds from which were to be divided by five and given each year to the oldest, youngest, tallest and shortest brides married in St Cyrus Kirk; the fifth portion was to be used for the relief of the poor of the parish. This distribution of money continues to the present day and the recipients are known as ''The Dowry Brides of St Cyrus''.

1. The progression is similar to that in *The Earl of Mansfield*.

1. In this dance 4th couple do not dance until Bars 29-32.

1. Bars 1-8 could be regarded as 1st woman comparing her statistics with those of the other women in the set.<BR> 

Bars 17-24 are the bridal progression!', 62, '8000/8880/8880/8484', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10072, '2001-09-12 22:00:00+00', '2022-07-21 16:02:33.718962+00', 'Granny Knot, The', 'GRANNY KNOT', 3, 48, 9999, 2, 3, 17, 108, '2000-01-01', 'John Drewry wrote in 2000: "The Granny Knot" and "The Ocean Plait" are virtually the same dance, but in different tempi.  I may withdraw one when I find out which is more popular with the dancers."



*Greenburn Book 3* shows the following dedication: Another KNOT for Morland! For all the grannies who attend the week of dancing in Morland.', 74, '520  888  444  555  888  888', 0, 1, 1, 0, 71);
INSERT INTO 'dance' VALUES (10073, '2001-09-12 22:00:00+00', '2022-07-21 15:18:28.533013+00', 'Dunbuy', 'DUNBUY', 3, 40, 9999, 2, 3, 17, 108, '2000-01-01', 'Notes from *Greenburn Book 3:*



Dunbuy (pronounced dun-boo-eee) is a small rocky island with a hole through the middle like a window. It lies between Siains Castle and the Bullers of Buchan, just to the south of Peterhead. It was visited by Dr. Johnson and Boswell on their tour of Scotland.



Dunbuy comes from the Gaelic "Dun Buidhe" meaning "Yellow Castle". The rock is reddish-brown. Maybe the "yellow" comes from the droppings of the sea birds which swarm on the rocks in their thousands!

', -1, '', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10074, '2001-09-12 22:00:00+00', '2022-07-21 15:25:57.51633+00', 'Dumfries Doglet, The', 'DUMFRIES DOGLET', 2, 32, 9999, 1, 4, 2, 108, '2000-01-01', 'John Drewry wrote this dance for Briar Johnstone of Dumfries.



Further notes from *Greenburn Book 3:*



1. In May 2000 Jackie Johnstone brought his dog Briar to the Morland Dance Week. (The pronunciation of "Briar" rhymes with "deer".) Briar used to be an Afghan but he shrank in the wash. Unfortunately Jackie did not use "Brand-X" for the laundering process.<BR> Briar attended the dance classes in Morland and attracted a lot of attention from the dancers and, when they heard his sad history, they all said "Oooh Chihuahua!".

1. _The women use four pas de basque. The men may use pas de basque but on Bars 1-2 they should really use "PAS DE CHIEN"_: i.e. they hop four times on the left foot while holding the right foot in second aerial position.<BR> Alternatively the men may place the left foot in second position for the first hop and then bring it in to third rear aerial position for the second hop and repeat this for the remaining hops.<BR> They then use pas de basque for Bars 3-4.

1. Bars 17-24 (and 25-32) are a new form of progression which, in Briar''s honour, may be called a _"Doglette"_.<BR> (Certainly NOT a "Pussette"! Briar would be horrified at the very idea!!!)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9350, '2001-09-12 22:00:00+00', '2022-07-21 15:36:19.991294+00', 'Fruit-Cake, The', 'FRUITCAKE', 2, 32, 9999, 1, 3, 42, 108, '1999-01-01', 'John Drewry wrote this dance for Rosalind Zuridis. 



Other notes from *Greenburn Book 3:*



1. When 1st couple are repeating the dance, during bars 21 -24, 1st and original 4th couples can turn with the right hand one and a half times, before dancing the circle. This is a convenient way of taking the original first couple down to the bottom to be ready for a clean start with the new top couple.

1. Mrs. Zuridis has written an article about me for the London Reel. In it she says that if she ever creates a dance it will be called "Drewry''s Cake". Maybe this dance will help her on her way, but I hope that she does not think that I am an absolute fruit-cake or even a half-baked one!



Please also note, the spelling of this dance is not consistent. In "New dances by John Drewry (devised in the period 1999 - 2000)" this dance is spelled "Fruit Cake, The". In the "Greenburn Book 3" (2000) and in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-230-December-1999-February-2000.pdf#page=2|"The Reel" (No. 230, Dec 1999, page 2)>> it is spelled "The Fruit-Cake".



', 62, '848/848/844/888', 1, 1, 1, 0, 87);
INSERT INTO 'dance' VALUES (10075, '2001-09-12 22:00:00+00', '2022-07-21 15:58:05.348067+00', 'Jiggin'' Janet', 'JIGGIN JANET', 2, 40, 9999, 2, 3, 17, 108, '2001-01-01', 'Dedication from *Greenburn Book 3:* A dance in memory of Etta Gibson who left us at Christmas 2000.



More notes from the book: 



1. This is a very energetic dance in which 1st and 2nd couples dance without a break for 32 bars. The last eight bars have been added to take 1st couple to third place where they can rest after dancing once. The unfortunate 2nd couple have to dance twice with only an 8 bar rest between turns. 

1. There is a Jig tune composed by Jimmy Blair called "Etta Gibson".', 60, '880  880  880  880  800', 0, 1, 0, 0, 60);
INSERT INTO 'dance' VALUES (10078, '2001-09-12 22:00:00+00', '2022-07-21 16:00:09.4596+00', 'Lord''s Lodging, The', 'LORDS LODGING', 1, 40, 9999, 1, 3, 42, 108, '2000-01-01', 'Dedication from *Greenburn Book 3:* A dance to celebrate the visit of Ron Wallace and his dancers to Huntly.



Further notes from the book:



1. At the end of the second turn of the dance,1 st woman dances down crossing over to fourth place, while 1 st man casts off to fourth place.

1. While staying at Huntly Castle Hotel, Ron and his party visited the ruins of Huntly Castle and, in the part known as "The Lord''s Lodging", Ron played the pipes while some of the group danced. Ron felt that this was one of the highlights of the tour.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9541, '2001-09-12 22:00:00+00', '2022-07-21 16:04:12.636714+00', 'Monster on the Rocks, The', 'MONSTER ON THE ROCKS', 3, 40, 9999, 1, 4, 2, 108, '2000-05-01', 'Drewry adds two notes in *Greenburn Book 3:*



1. The title does not refer to Bigfoot in Western Canada, but to a rock formation which I have discovered between Slains Castle and Dunbuy (just to the north of Cruden Bay). The rocks have two holes right through the base and, from the cliff top, they look like a monster trying to climb out of the sea.

1. It is quite safe to be near the monster because it is very friendly. In fact it is "pally"olithic.', 85, '4444/8888/8888/8888/8844', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10077, '2001-09-12 22:00:00+00', '2022-07-21 16:16:54.763235+00', 'One Fine Day', 'ONE FINE DAY', 1, 32, 9999, 3, 5, 7, 108, '1999-01-01', 'In *Greenburn Book 3* John Drewry adds some notes:



* The dance is a conversion of "Thomas Glover''s Reel" into a 5 couple dance.

* Thomas Glover went to Japan and settled in Nagasaki, where he married a Japanese wife. The opera "Madame Butterfly" was thought to be inspired by the story of Thomas although he did not abandon his wife as Pinkerton did.

* "One Fine Day" is a celebrated aria from the opera.', 65, '80800/84884/84884/82842', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10076, '2001-09-12 22:00:00+00', '2022-07-21 16:12:38.86453+00', 'Ocean Plait, The', 'OCEAN PLAIT', 1, 48, 9999, 1, 3, 42, 108, '2000-01-01', 'John Drewry wrote in 2000: "The Granny Knot" and "The Ocean Plait" are virtually the same dance, but in different tempi.  I may withdraw one when I find out which is more popular with the dancers."



*Greenburn Book 3* shows the following dedication: Another KNOT for Morland! This is similar to the Granny Knot but in quick tempo.



In addition, John Drewry notes: An Ocean Plait is a very complicated knot made from a single length of rope. (See "Knots and Ropework" by Eric C. Fry. (David and Charles))', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (390, '1997-04-03 22:00:00+00', '2022-07-30 16:47:49.778574+00', 'Banks of Aray, The', 'BANKS OF ARAY', 3, 32, 9999, 1, 3, 42, 411, '1992-01-01', 'For Betty Sharpe, Teacher of Knox SCD club since 1965.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10079, '2001-09-12 22:00:00+00', '2022-07-21 16:24:09.732823+00', 'Paddy Baa', 'PADDY BAA', 1, 32, 9999, 1, 3, 42, 108, '2000-05-01', 'Note in *Greenburn Book 3:* 



I have just visited my friends at Dulnain Bridge and they were helping the local farmer by bottle-feeding two lambs. The farmer''s wife had christened one of the lambs PADDY BAA and I felt this would be a good title for a dance because that was the way some people used to pronounce "pas de basque".



The dedication at the top of the dance description reads: for the Cade Lambs of Strathspey', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10011, '2001-09-12 22:00:00+00', '2022-07-21 16:25:48.672188+00', 'Out of Africa', 'OUT OF AFRICA', 1, 32, 9999, 1, 100, 2, 108, '2000-01-01', 'The dedication in *Greenburn Book 3* says: A dance For the Golden Wedding of Jim and Rina Grant of Aberdeen.



Furthermore, John Drewry added some notes:



1. At the end of each tum, except the last, 4th man in second place on the men''s side, and 1 st man in third place on the women''s side, can stay facing out ready to repeat the dance with new end couples.

1. This dance was requested by Jim and Rina''s daughter Fiona, who now lives in Bristol.

1. Jim and Rina were married in 1952 in Nigeria, where they were both working. That gave me the idea of the title of this dance.

1. Haverholme Priory, near Sleaford in lincolnshire, was the home of the Finch-Hattons. It is now a shell because of a disastrous fire.<BR> Denys Finch-Hatton features in Karen Blixen''s book Out of Africa. My sister thinks that our father''s mother worked at the Priory when she was a young girl. She certainly came from that part of lincolnshire and was the same grandmother who claimed a family connection with Sir Isaac Newton.', 81, '6886/8228/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10080, '2001-09-12 22:00:00+00', '2022-07-21 16:28:12.349536+00', 'Premium Bonds', 'PREMIUM BONDS', 3, 32, 9999, 1, 100, 2, 108, '2000-01-01', 'Drewry specifies in the notes to the dance: 



- The dance may be danced just as a strathspey or just as a reel, or four times as a strathspey followed by four times as a reel, or twice as a strathspey followed by twice as a reel. 

- When turning with two hands in reel tempo, skip change of step should be used.



John Drewry wrote the dance for Paul and Dulcie Bond with the comment: "A dance to enrich life and avoid overtaxing yourself."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10008, '2003-01-30 23:00:00+00', '2022-07-21 16:29:49.918876+00', 'Recumbent Stone, The', 'RECUMBENT STONE', 1, 48, 9999, 3, 5, 6, 108, '2000-01-01', 'Some notes by John Drewry in *Greenburn Book 3:*



Recumbent stone circles are found in the North-East of Scotland and

they are thought to be at least five thousand years old. The recumbent

stone is a very large stone lying on its side and it is flanked by two

upright stones which are of a similar size to the other stones in the circle.

The recumbent stone is always on the south-west side of the circle and it

is thought that it was used in observations of the moon. There is a fine

recumbent stone circle at Easter Aquhorthies to the north-west of

Inverurie.



Once, when I was visiting it, I met a wee man who assured me that

someone standing in the circle was much more likely to see U.F.O''s than

someone standing nearby! Maybe his powers of imagination were more

developed than mine.



An article in the Scotsman revealed that this circle has unusual

acoustic properties which have been verified with scientific instruments.

Similar acoustic properties are found at the Cairns of Camster, near

Wick, in Caithness. The suggestion was that the old priests used the

acoustic properties to impress the people with their "magic" powers.', 60, '48884/80800/84840/84884/82842/80800', 1, 1, 1, 1, 63);
INSERT INTO 'dance' VALUES (20864, '2022-05-21 09:47:56.837123+00', '2022-07-27 21:59:07.469708+00', 'Splendour in the Grass', 'SPLENDOUR IN THE GRASS', 3, 32, NULL, 2, 3, 17, 11237, '2020-09-01', 'The title comes from seeing a sign attached to a lamp post on Hampstead Heath (during the pandemic) which read:  

*“There is splendour in the grass” (Wordsworth).*  

*There is also my lost hearing aid!*  

*Unusually pleasant reward offered...*



The dance contains the Snake Pass figure but any snakes in the grass should be assumed to be slow worms (which are actually lizards).

', 83, '880/888/888/808', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20913, '2022-06-25 14:36:58.399533+00', '2022-07-29 09:19:34.002105+00', 'Quince Jelly', 'QUINCE JELLY', 4, 32, 10020, 1, 130, 11, 2806, NULL, '1st and 4th couples cross on 2nd chord.



The deviser wished the dance to be danced 2x32S + 2x32R. The Recording on the CD is 2x(32S+32R).



Dance written for our good friends, Peter and Madeleine Quince who have been members of our Branch and attended dances here for many years. Peter was on our committee and served as Chairman for two years. They danced and made friends all over this country as well as many others, especially in France, Madeleine''s home country, where they lived for part of each year. Peter liked homemade jam and I often gave them some of my home made quince jelly.

Sadly, Peter died in early 2019 before the dance was published.', 81, '4884/8888/8008/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20961, '2022-07-30 12:13:42.722064+00', '2022-07-30 12:13:42.722064+00', 'Five Star Reel, The', 'FIVE STAR REEL', 1, 32, NULL, 1, 100, 2, 2677, NULL, 'Found at <<http://rscdsboston.org/events-fliers/Albany50thAnniversaryParty2022.pdf>> and dance list <<https://my.strathspey.org/dd/list/32988/>>.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5637, '2002-02-27 23:00:00+00', '2022-07-30 16:17:27.713216+00', 'Robertson Rant, The', 'ROBERTSON RANT', 3, 80, 9999, 4, 4, 3, 420, '1949-01-01', 'The following corrections were included on a loose sheet "Notes on Dances by Bob Grant June 1996", when Book 39 was first sold in the Summer School bookshop:



17-24  Men finish reel by curving left about, acknowledging partner, before facing corner (Men speed up, women slow down)', 85, '8888  8888  8080  8888  0808  8888  6666  6666  8888  8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (649, '1997-08-28 22:00:00+00', '2022-07-30 18:41:48.344742+00', 'Bonnie Flowers o''er the Muir', 'BONNIE FLOWERS OER THE MUIR', 3, 32, 9999, 1, 3, 42, 604, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (838, '1998-04-12 22:00:00+00', '2022-07-30 18:49:30.94081+00', 'Broughton Heights', 'BROUGHTON HEIGHTS', 3, 32, 9999, 1, 100, 11, 154, NULL, 'From the dance notes: "Named atter the hill behJnd the village of Broughton, Peeblesshire"', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20964, '2022-07-30 22:48:33.342385+00', '2022-07-30 22:59:36.707956+00', 'Hope', 'HOPE', 3, 32, NULL, 1, 4, 2, 11225, '2020-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1089, '1997-09-17 22:00:00+00', '2022-07-31 09:54:37.980699+00', 'Catch Ye Her Eye', 'CATCH YE HER EYE', 3, 40, 9999, 1, 4, NULL, 767, NULL, 'The notes say this was written "To emphasise the importance - and the pleasure from the use of eye contact with your partner".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1618, '1998-07-09 22:00:00+00', '2022-07-31 10:25:35.694518+00', 'Dennis''s Fancy', 'DENNISS FANCY', 3, 32, 9999, 3, 5, 7, 108, '1991-02-01', 'Inscribed "for Dennis and Irene Steed of Aberdeen".', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1711, '1997-09-01 22:00:00+00', '2022-07-31 10:35:07.067057+00', 'Dougal Dubh', 'DOUGAL DUBH', 3, 32, 9999, 1, 3, 42, 73, NULL, '"Devised for my husband, Doug."', 50, '800/844/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2328, '1997-04-03 22:00:00+00', '2022-07-31 10:46:20.875481+00', 'Francis Sitwell''s Strathspey', 'FRANCIS SITWELLS STRATHSPEY', 3, 32, 9999, 3, 5, 16, 270, NULL, '', 55, '80800/48884/82842/80800', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3453, '1997-04-03 22:00:00+00', '2022-07-31 11:35:30.631754+00', 'Kickapoo Gatherings', 'KICKAPOO GATHERINGS', 3, 32, 9999, 1, 3, 42, 361, '1989-09-01', 'From the notes: Dedicated to Avril and David Quarrie as thanks for the many delightful social gatherings they hosted at their home on Kickapoo Road in Batavia, Illinois.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3775, '1998-11-11 23:00:00+00', '2022-07-31 19:28:16.554992+00', 'Lennox Love to Blantyre', 'LENNOX LOVE TO BLANTYRE', 3, 32, 9999, 1, 3, 42, 9998, NULL, '', 47, '804  804  844  866', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (19198, '2019-02-21 00:29:56.149539+00', '2022-07-31 20:36:47.896882+00', 'One Blue Cloud in the Grey Sky', 'ONE BLUE CLOUD IN THE GREY SKY', 1, 40, NULL, 2, 3, 17, 11787, NULL, 'The 5 Couple version of this dance is called "Two Blue Clouds in the Grey Sky".', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10081, '2001-09-12 22:00:00+00', '2022-07-21 16:43:32.811012+00', 'Round Hay of Six, The', 'ROUND HAY OF SIX', 3, 64, 9999, 6, 3, 54, 108, '1964-01-01', 'The dedication reads: For the Leeds Day School



Drewry specifies: »The dance may be danced as a Strathspey only, or it may be repeated in Reel tempo to make a Medley.« or in the wording of *Greenburn Book 3:* »Strathspey - 3 couples - 64 bars OR Medley [Strathspey + Reel] - 64+64 bars«



Further notes by John Drewry from the *Greenburn Book 3:*



- _about the setup:_  

  The dance is triangular in shape and the couples stand at the apices of an equilateral triangle.  

  For the women, comers are the men standing on their right and contra comers are the other men. For the men, comers are the women standing on their left and contra corners are the other women.  

The dance may be danced as a Strathspey only, or it may be repeated in Reel Tempo to make a Medley.

- _about the name:_

   There is already a dance called The Round Reel of Eight (Book 27 No.7). This gave me the idea for the title of this dance.  

   In English Country Dances a "Hey" or "Hay" is the equivalent of a "Reel" in Scottish Country Dances.  

ROUNDHAY is a district of Leeds with a famous park.

- The _Triangular Reel of Six_ is slightly like a triangular Schiehallion Reel, but the phrasing is different.  

The phrasing in this dance is:- dance in, pass left shoulders, dance out and curve round into place using four equal steps (similar to the phrasing in a foursome reel).  

In a Schiehallion Reel the phrasing for the men is:- two long steps to travel to the next woman''s place and two short steps to cast to the man''s place, whereas for the women it is:- two short steps to cast to the man''s place and then two tong steps to travel to the next woman''s place. I hope I am not being too pedantic in thinking in this way about the reels.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10082, '2001-09-12 22:00:00+00', '2022-07-21 16:45:39.941327+00', 'Rings Round the Moon', 'RINGS ROUND THE MOON', 3, 32, 9999, 1, 3, 42, 108, '2000-01-01', 'Devised in April 2000 for the Hereford Scottish Country Dance Club in memory of Harold James, who had been dancing for 49 years.



In the 2001 printing by TACbooks, the title in the table of contents is "Rings Around the Moon", but the title above the dance description is "RINGS ROUND THE MOON".  After the description follows: "NOTE: I called a previous dance for Hereford Over the Moon.  "Rings Round the Moon" are not rings like the rings of Saturn, but Lunar Haloes. A double halo is a rare event."   It seems clear that Drewry wanted the name to be "Rings Round the Moon". "Rings Around the Moon" has been added as an alias.   

', 50, '800/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10084, '2001-09-12 22:00:00+00', '2022-07-21 16:49:27.994798+00', 'Slip Knot, The', 'SLIP KNOT', 1, 32, 9999, 1, 3, 42, 108, '2000-01-01', 'The dedication says: Another KNOT for Morland!  

(see also "The Granny Knot" and "The Ocean Plait")', 59, '844/888/844/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10087, '2001-09-12 22:00:00+00', '2022-07-21 16:56:51.586475+00', 'New Leeds Strathspey, The', 'NEW LEEDS STRATHSPEY', 3, 32, 9999, 1, 4, 11, 108, '2001-01-01', 'John Drewry wrote the dance for the Day School in Leeds, Yorkshire.



...and he added the note: *New Leeds* is a village about eight miles south of Fraserburgh in Aberdeenshire.

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9897, '2001-09-12 22:00:00+00', '2022-07-21 17:00:17.035399+00', 'Toll House, The', 'TOLL HOUSE', 3, 32, 9999, 2, 3, 17, 108, '1999-09-01', 'John Drewry wrote this dance in September 1999 for Margaret Hutcheon of Mosstowie and Margaret Kendall of Pontefract.



Furthermore he added the following notes in *Greenburn Book 3:*



- At the junction on the. A96 Aberdeen-Inverness road, where the road to Mosstowie branches off, there is an old toll house which is painted in such a way that the windows appear to have eyebrows!

- The house in Monymusk, where Margaret Kendali spends some time each summer is also an old toll house.



_Please also note:_ The Pilling diagram in the 8th edition is in error, see the supplement to the 8th edition for the correct one.', 83, '880/888/888/088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10885, '2002-10-20 22:00:00+00', '2022-07-21 17:10:27.510252+00', 'Clean Sweep (with new Brougham), A', 'CLEAN SWEEP WITH NEW BROUGHAM', 3, 32, 9999, 1, 3, 42, 108, '2002-01-01', 'Brougham (pronounced Broom) with its ruined castle lies to the south-east of Penrith.

', 53, '660/800/888/888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6678, '2002-05-14 22:00:00+00', '2022-07-22 15:25:20.304954+00', 'Nae Fantoosherie', 'NAE FANTOOSHERIE', 3, 32, 9999, 1, 3, 42, 181, '1994-05-01', 'The dance was devised to celebrate the appointment of Miss Biddy Fawdry as a Vice-President of the Birmingham Branch of the RSCDS in May 1994. 



''Nae Fantoosherie'' means ''no pretentiousness''. ', 63, '822/888/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13546, '2009-12-16 23:00:00+00', '2022-07-23 14:25:26.472656+00', 'Fifty Sixty-Five Strathspey', 'FIFTY SIXTYFIVE STRATHSPEY', 3, 40, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8112, '1998-10-15 22:00:00+00', '2022-07-24 08:45:18.35231+00', 'Wind Dragon, The', 'WIND DRAGON', 1, 32, 9999, 1, 3, 42, 44, '1990-12-30', 'Inspired by a small kite with long red tails seen soaring above a local park earlier in the day. The deviser has since learnt that a ''dragon'' is also ''a paper kite''.



The instructions published in <<ddpub:Island Bay Collection (2nd edition)#344>> have an error in bars 17-24 which those who have a copy should correct. Instead of:  

*17-24   First couple, first woman followed closely by her partner, dance a reel of three across the set with _second_ couple passing second woman by right shoulders to begin.*  

it should read:  

*17-24   First couple, first woman followed closely by her partner, dance a reel of three across the set with _first_ couple passing second woman by right shoulders to begin.*  

', 50, '888/800/880/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13103, '2006-11-14 23:00:00+00', '2022-07-24 19:52:44.132954+00', 'Starsigns', 'STARSIGNS', 2, 32, 9999, 102, 55, 33, 1394, NULL, 'For all the Maths enthusiasts who enjoy SCD. The last 8 bars portray constructing a hypocycloid. Some dancers would love knowing this; perhaps better not tell the others ...', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4064, '1998-09-29 22:00:00+00', '2022-07-23 20:07:32.853568+00', 'Madge Wildfire''s Strathspey', 'MADGE WILDFIRES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 460, '1820-01-01', 'The instructions for bars 9-16 have changed more than once over the years *(details courtesy of the MiniCrib team)*.

The original publication and some revised editions of Book 9 say the three couples cross "passing right shoulder".

The publication "101 Scottish Country Dances" and a number of subsequent editions of Book 9 changed that to cross "giving right hands".

In the latest RSCDS edition of Book 9 (published in 2009) they just cross "passing by the right".

The 2013 edition of the RSCDS manual is more explicit, saying that while the original specified no hands, these days usually hands are given.', 69, '888/888/866/866', 1, 1, 1, 1, 91);
INSERT INTO 'dance' VALUES (20959, '2022-07-24 22:13:05.935427+00', '2022-07-24 23:35:55.894987+00', 'X Marks the Scot', 'X MARKS THE SCOT', 2, 40, NULL, 1, 3, 42, 11237, '2020-11-01', '', 50, '800/844/466/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20911, '2022-06-25 14:24:33.854212+00', '2022-07-27 20:34:54.554443+00', 'Jig for Jean, A', 'JIG FOR JEAN', 2, 32, NULL, 1, 3, 42, 2806, NULL, 'In memory of Jean Wright who liked challenging programmes. <more detail in the book>', 56, '800/888/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20871, '2022-05-31 19:03:43.712016+00', '2022-07-27 22:14:25.585505+00', 'Atheist, The', 'ATHEIST', 1, 32, NULL, 1, 3, 42, 11237, '2022-03-01', 'Written in memory of Deborah Ainger who died in December 2021.

Deborah, a keen dancer and a passionate activist,

was never seen without a badge proudly proclaiming herself as an atheist. As a fellow non-

believer I always liked to see her wearing this. She was one of those people who found it

hard to distinguish right from left, so this dance tries to make all the directions and turning as

obvious as possible.', 66, '880/888/848/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3998, '1997-09-08 22:00:00+00', '2022-07-30 16:23:24.138256+00', 'Lutetia Hall', 'LUTETIA HALL', 3, 32, 9999, 1, 3, 42, 70, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19197, '2019-02-21 00:28:24.166731+00', '2022-07-31 20:41:30.522697+00', 'Two Blue Clouds in the Grey Sky', 'TWO BLUE CLOUDS IN THE GREY SKY', 1, 40, NULL, 3, 5, 7, 11787, NULL, 'The 3 couple version of this dance is called "One Blue Cloud in the Grey Sky".', 56, '80800/80800/84884/84884/80800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4131, '1997-04-03 22:00:00+00', '2022-08-01 20:10:09.718626+00', 'Manor Farm', 'MANOR FARM', 3, 32, 9999, 1, 3, 42, 377, NULL, 'The notes say this was "devised from an idea put forward by Margaret Roberts at a dance class at Manor Farm and arranged in conjunction with her."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4486, '1997-09-11 22:00:00+00', '2022-08-01 20:20:27.794303+00', 'Miss Giving''s Strathspey', 'MISS GIVINGS STRATHSPEY', 3, 40, 9999, 1, 3, 42, 1780, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4675, '1998-11-03 23:00:00+00', '2022-08-01 20:41:41.669006+00', 'Mossfennan', 'MOSSFENNAN', 3, 32, 9999, 1, 3, 42, 394, '1979-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5165, '1997-04-03 22:00:00+00', '2022-08-02 07:52:41.617521+00', 'Parrotts'' Strathspey', 'PARROTTS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 361, '1988-09-01', 'The notes say: "Dedicated to Jeanette and Ken Parrott, active members and supporters of the Loch Michigan Scottish Country Dance Group since its beginning. Jeanette was one of the first teachers of the group."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5582, '1997-04-03 22:00:00+00', '2022-08-02 08:05:46.226713+00', 'Ringing The Changes', 'RINGING THE CHANGES', 3, 32, 9999, 3, 5, 7, 232, NULL, 'From the notes: "Dedicated to Charles and Elaine Dunn on their retirement as Masters of Quincy House".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19628, '2019-09-04 09:10:47.118159+00', '2022-08-02 09:11:39.573295+00', 'Piper''s Wedding, The', 'PIPERS WEDDING', 1, 32, NULL, 3, 5, 16, 200, '1989-02-01', 'Sole source:  Minicrib who just attributed it to "Johnstone" (of which there are several).



According to <<https://my.strathspey.org/dd/issue/2846/|issue 2846>> it was devised by Jackie Johnstone, Dumfries, February 1999 with music arranged by <<ddp:Holmes, Ian#1668>>.', 55, '80808/08080/88888/80000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6596, '1997-04-03 22:00:00+00', '2022-08-03 07:25:12.09102+00', 'Tibbermore Piper, The', 'TIBBERMORE PIPER', 3, 32, 9999, 1, 3, 42, 417, '1979-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10057, '2001-09-10 22:00:00+00', '2022-08-03 10:48:39.218956+00', 'Craigievar Magic', 'CRAIGIEVAR MAGIC', 1, 40, 9999, 5, 4, 4, 127, NULL, 'Two couples facing two couples round the room.



*From <<https://my.strathspey.org/dd/issue/2853/|issue 2853>>:* The original notes to this dance contain the following notations at the bottom:



Repeat 3 more times (Hoping the magic works) P.S. If one person goes wrong, the magic doesn’t work!!



The “magic” Bill Forbes is talking about is that the progression of the dance over four repetitions is somewhat miraculous. The first repetition takes everyone away from their original partner and set, and further repetitions seem to irretrievably scramble things. But, astoundingly, after four repetitions, everyone is back with their original partner in their original set (!). And it works regardless of how many sets are on the floor. Truly amazing when it works. But as pointed out in the notes, if any one person goes wrong, especially early on, it messes up the progression for almost everyone.

', 95, '8888/8888/6666/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12670, '2006-02-02 23:00:00+00', '2022-08-03 23:39:33.452875+00', 'Turning a Not so Blind Eye', 'TURNING A NOT SO BLIND EYE', 3, 32, 9999, 1, 4, 1, 411, '2004-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20965, '2022-07-30 23:26:39.765125+00', '2022-08-03 13:17:35.03867+00', 'Natsumi''s Jig', 'NATSUMIS JIG', 2, 32, NULL, 1, 2, 52, 12186, '2018-01-01', 'Source <<https://youtu.be/mpIOTXbUmz0|youtube video>> where it is described as a 4C set but appears to have 2134 progression. In SCDDB it is, for the moment, shown as a 2 couple dance although all couples take part in the circle.



Deviser''s note:  

* Note 1: This was originally devised as a dance performed only twice through for four couples in a four-couple longwise set to honour and entertain 1st couple.  

* Note 2: This dance has the progression of a three-couple dance in a four-couple set, and is danced eight times through. However, all four couples dance bars 1-8 as in a four-couple dance.', 50, '8888/8000/8000/8800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7376, '1998-01-04 23:00:00+00', '2022-08-03 18:25:25.725472+00', 'Crook Inn, The', 'CROOK INN', 3, 32, 9999, 1, 100, 2, 154, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8217, '1997-12-28 23:00:00+00', '2022-08-03 18:39:26.389821+00', 'Hills of Home, The', 'HILLS OF HOME', 3, 32, 9999, 1, 3, 42, 35, '1997-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8361, '2002-06-03 22:00:00+00', '2022-08-03 18:47:11.455014+00', 'Patron Saint, The', 'PATRON SAINT', 3, 32, 9999, 1, 100, 2, 108, '1996-05-01', 'Inscribed "for Andrew Scott of Vancouver B.C. and for Simon Scott, his father."', 75, '8008/8888/8008/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8925, '2002-04-30 22:00:00+00', '2022-08-03 20:04:57.499143+00', 'Castle Campbell', 'CASTLE CAMPBELL', 3, 40, 9999, 1, 4, 15, 520, NULL, 'The notes say "This strathspey was written for Ellen and Lynnette Campbell who visited me in 1995 for a delightful tour of Scotland. "', 72, '8000/8220/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17754, '2017-05-21 08:49:37.212648+00', '2022-08-03 20:09:00.129873+00', 'Ashley and Her Husbands', 'ASHLEY AND HER HUSBANDS', 2, 32, NULL, 1, 3, 42, 11237, '2016-12-01', 'For Ashley Weller, with many thanks for organising the Gay Gordons expert evenings.



Ashley’s husband Steve does not dance, so Ashley travels to dance events with past and present members of the Gay Gordons who are sometimes assumed to be her partner and whom she collectively refers to as her extra husbands. In this dance 1st woman goes on promenades with other men while her partner is solo for the central 16 bars.



A recording by Ian Robertson of the music for this dance is available via <<https://my.strathspey.org/u/murrough/recording/>>.

', 50, '800 853 835 888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4779, '2002-02-28 23:00:00+00', '2022-08-04 21:57:07.706447+00', 'Mrs MacDougall''s Strathspey', 'MRS MACDOUGALLS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 406, '1988-01-01', 'Inscribed "For Jeannie Mac Dougall of the St. Columba''s Scottish Country Dance Group".



SCDDB originally had a devised date of 1993, but a copy of the instructions has January 1988. And the name is spelled with a space as "Mac Dougall" which is added as an alias.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20571, '2021-12-03 22:17:05.898319+00', '2022-08-04 07:58:48.932481+00', 'Madge Wildfire''s Reel', 'MADGE WILDFIRES REEL', 1, 32, NULL, 1, 3, 42, 9998, NULL, 'Originally published in 1820 by John Sutherland, Edinburgh in a booklet linked to Sir Walter Scott''s novel The Heart of Midlothian. Reconstructed by the RSCDS in 2021 to mark the 250th anniversary of Sir Walter Scott''s birth.', 47, '880/800/822/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9177, '1999-12-06 23:00:00+00', '2022-08-05 16:46:27.084986+00', 'On Tour', 'ON TOUR', 3, 32, 9999, 2, 2, 76, 304, NULL, '', 69, '88  88  88 88', 1, 1, 0, 0, 100);
INSERT INTO 'dance' VALUES (9573, '2000-09-06 22:00:00+00', '2022-08-05 16:48:01.299851+00', 'Changearound', 'CHANGEAROUND', 3, 32, 9999, 2, 2, 76, 118, '1998-12-01', '', 67, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10272, '2001-11-25 23:00:00+00', '2022-08-05 16:56:31.29552+00', 'Glencoe Weeps', 'GLENCOE WEEPS', 3, 32, 9999, 1, 3, 42, 2766, '2001-11-01', 'During my August 2001 trip to Scotland, our last stop was Glencoe. It was an on-and-off rainy day, but that made it all the better because water poured off the mountains of Glencoe, making lovely waterfalls and rapids. The name of this dance also reflects the legend of the massacre of Glencoe.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14728, '2013-03-14 10:15:09.622151+00', '2022-08-05 17:01:42.426862+00', '"You Cannot go Wrong!"', 'YOU CANNOT GO WRONG', 3, 32, NULL, 2, 3, 17, 10762, NULL, 'Devised by Trisha Rawlings for the Oxfordshire Branch of the RSCDS as a mark of their affection and esteem for John Armstrong, a favourite teacher, whose catchphrase after instruction was "You cannot go wrong!"', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20966, '2022-08-05 22:40:38.170062+00', '2022-08-07 08:29:47.66576+00', 'Emmy''s Wedding', 'EMMYS WEDDING', 1, 40, NULL, 1, 4, 2, 12189, '2022-01-01', 'Devised for the wedding of Emmy Wilkinson to Matt Dunn at Fingask Castle on 9th August 2022', 48, '8008/8008/4044/8000/8088', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5831, '1997-04-03 22:00:00+00', '2023-02-13 10:02:28.440976+00', 'St. John''s Strathspey, The', 'SAINT JOHNS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 127, NULL, 'Saint John''s Strathspey, The', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20972, '2022-08-07 19:53:33.922101+00', '2022-08-11 14:44:26.988691+00', 'Will, Will you Dance', 'WILL WILL YOU DANCE', 3, 40, NULL, 1, 4, 1, 11449, NULL, 'May also be danced in a 3 or 5 couple set

', 45, '8220/8440/8330/8440/8044', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20992, '2022-08-11 05:53:30.963558+00', '2022-08-13 03:31:48.870862+00', 'Praha Matka Měst', 'PRAHA MATKA MEST', 4, 32, 1, 2, 134, 17, 11781, '2019-04-01', 'Devised by Nicolas “Niols” Jeannerod in Prague in April 2019. The title translates to “Prague, Mother of Cities” and refers to Prague''s motto during the twentieth century. It was a symbol of the mission of Prague to protect the independence and prosperity of the Czecho-Slovakian state.', 67, '800/888/844/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20968, '2022-08-05 23:06:06.809221+00', '2022-08-07 08:31:02.457544+00', 'Emmy and Matt''s Wedding', 'EMMY AND MATTS WEDDING', 4, 64, 5, 1, 4, 2, 12189, '2022-01-01', '', 47, '8008/8008/4044/8080/8000/8088/8044/8044', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20967, '2022-08-05 22:47:46.819114+00', '2022-08-07 08:32:31.7731+00', 'Matt''s Wedding', 'MATTS WEDDING', 3, 40, NULL, 1, 4, 2, 12189, '2022-01-01', 'Devised for the wedding of Emmy Wilkinson to Matt Dunn at Fingask Castle on 9th August 2022.

This is a strathspey version of Emmy''s Wedding

', 48, '8008/8008/4044/8000/8088', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8914, '1999-01-05 23:00:00+00', '2022-08-07 10:56:51.566122+00', 'Glendaruel', 'GLENDARUEL', 3, 32, 9999, 1, 3, 42, 440, '1994-10-30', 'Devised on October 30th I 994. Glendaruel is a village in the Cowal peninsula.', 56, '800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19174, '2019-01-29 23:06:34.402298+00', '2022-08-08 16:03:43.997066+00', 'Noethersche Ring, Der', 'NOETHERSCHE RING', 3, 32, NULL, 1, 3, 42, 11777, '1999-11-19', 'Dedicated to the 1999-2000 Erlangen Scottish Country Dancers.



Written in honor of the mathematician Emmy Noether (born March 23, 1882 in Erlangen - died April 14, 1935 in Bryn Mawr), who loved to dance.', 66, '888/888/840/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20970, '2022-08-07 19:47:08.845967+00', '2022-08-10 23:28:32.242708+00', 'By Achnandarach', 'BY ACHNANDARACH', 1, 32, NULL, 2, 2, 76, 11449, NULL, 'May be danced in a 4 couple set  



for Barabra Inglis of Achnandarch', 60, '88/88/88/80', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20991, '2022-08-10 23:10:35.003024+00', '2022-08-11 07:14:47.439136+00', 'Mall in St. James''s Park, The', 'MALL IN ST JAMESS PARK', 3, 32, NULL, 2, 3, 17, 11781, '2018-01-01', 'Devised by Nicolas “Niols” Jeannerod in 2018. The name was suggested by Christophe Schuwey in reference to the painting of the same name by Thomas Gainsborough.', 63, '800/822/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20973, '2022-08-09 09:48:25.140577+00', '2022-08-11 14:35:11.74926+00', 'Mine''s a Pint', 'MINES A PINT', 2, 32, NULL, 1, 3, 42, 11449, NULL, '', 67, '888/484/886/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18373, '2018-06-07 08:42:04.464724+00', '2022-08-10 11:13:49.280499+00', 'Beinn Edra', 'BEINN EDRA', 4, 128, 10034, 1, 100, 2, 11449, '2018-01-01', '', 94, '8888/8888/8888/4884', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11687, '2004-02-18 23:00:00+00', '2022-08-13 20:07:51.024285+00', 'Keepin'' it Reel', 'KEEPIN IT REEL', 1, 32, 9999, 1, 3, 42, 3425, NULL, '', 56, '844/888/888/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20975, '2022-08-09 09:52:24.23532+00', '2022-08-10 12:34:09.117314+00', 'Border Ballad', 'BORDER BALLAD', 3, 32, NULL, 1, 3, 42, 11449, NULL, 'Dingly Dell is the same dance but in reel time', 42, '820/800/866/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20976, '2022-08-09 09:53:56.090541+00', '2022-08-10 13:51:41.721453+00', 'Dingly Dell', 'DINGLY DELL', 1, 32, NULL, 1, 3, 42, 11449, NULL, 'Border Ballard is the same dance but in strathspey time', 42, '820/800/866/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20670, '2022-02-22 15:57:42.254462+00', '2022-08-10 13:58:27.110687+00', 'Now We Are Six', 'NOW WE ARE SIX', 2, 40, NULL, 1, 3, 42, 11449, NULL, '', 55, '800/880/808/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20989, '2022-08-09 11:34:36.494351+00', '2022-08-17 09:20:16.391065+00', 'Paisley-side', 'PAISLEYSIDE', 4, 96, 11, 5, 56, 76, 11449, NULL, '', 100, '88/88/88/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20993, '2022-08-11 08:36:35.336809+00', '2022-08-11 08:44:35.767975+00', 'Reel of the 51st Confusion, The', 'REEL OF THE 51ST CONFUSION', 1, 32, NULL, 2, 3, NULL, 12036, '2021-08-01', 'Devised by Anne Lanvin, Corentin Lefèvre, Isabelle Herlant, Louise Baltera, Nicolas “Niols” Jeannerod and Victor Lanvin on August 8th, 2021. This dance is a variation of one of the most popular Scottish country dances, “The Reel of the 51st Division”.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20971, '2022-08-07 19:49:40.120522+00', '2022-08-11 10:20:11.16118+00', 'Cloud Nine', 'CLOUD NINE', 4, 64, 5, 2, 3, 18, 11449, NULL, 'For Shirley Grant', 67, '800/804/888/808/080/480/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20985, '2022-08-09 11:28:58.746822+00', '2022-10-25 19:40:30.511628+00', 'Jackie ''Danie'' of Inverinate Square', 'JACKIE DANIE OF INVERINATE SQUARE', 4, 32, 10034, 4, 4, 3, 11449, NULL, '', 75, '8080/8888/8080/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20978, '2022-08-09 09:57:18.989545+00', '2022-08-11 18:52:07.30489+00', 'Gentle Gems of Carn', 'GENTLE GEMS OF CARN', 3, 32, NULL, 1, 4, 1, 11449, NULL, 'For Murdie & Mary ''Carn''', 44, '8800/8000/8080/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20969, '2022-08-07 19:44:52.345767+00', '2022-08-11 18:58:34.787022+00', 'Creagan Ruadh', 'CREAGAN RUADH', 2, 32, NULL, 1, 3, 42, 11449, '2004-01-01', 'This may also be danced as a reel.  



For Margaret Gowan with thanks for all her patience & perseverance with the Kintail Ceilidh & Country Dance Group', 41, '880/800/822/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20974, '2022-08-09 09:49:25.324399+00', '2022-08-12 09:30:43.136968+00', 'Grandpa''s Porridge', 'GRANDPAS PORRIDGE', 3, 32, NULL, 1, 4, 1, 11449, NULL, '', -1, '8000/8880/8440/8448', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20987, '2022-08-09 11:31:47.09527+00', '2022-08-17 09:28:22.609179+00', 'Barefoot Bairns', 'BAREFOOT BAIRNS', 1, 32, NULL, 1, 3, 42, 11449, NULL, '', 38, '440/800/844/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20977, '2022-08-09 09:56:05.702195+00', '2022-08-13 08:32:04.239248+00', 'Bournemouth Babe', 'BOURNEMOUTH BABE', 2, 32, NULL, 1, 3, 17, 11449, '2007-01-01', 'This may also be danced in a 3 couple or a 5 couple set', 67, '888/888/484/886', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20981, '2022-08-09 11:24:26.772123+00', '2022-08-13 15:27:24.80788+00', 'Herring Wall, The', 'HERRING WALL', 3, 32, NULL, 1, 4, 1, 11449, NULL, '', 97, '8888/8488/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20980, '2022-08-09 11:22:46.799439+00', '2022-08-13 15:33:11.971782+00', 'Alltachruinn', 'ALLTACHRUINN', 1, 32, NULL, 1, 4, 1, 11449, NULL, '', 34, '8400/8000/8044/8000', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14216, '2011-08-26 22:00:00+00', '2022-08-13 20:18:08.903219+00', 'Lady of Wishaw', 'LADY OF WISHAW', 3, 32, 9999, 1, 100, 2, 1089, NULL, 'Dedicated to May Loudon, much loved dancer and teacher of the Gleneagles SCD Club in West Vancouver on the occasion of her seventieth birthday. May grew up in Wishaw in Scotland.', 87, '8448/8448/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20984, '2022-08-09 11:26:56.378907+00', '2022-08-17 08:49:03.005445+00', 'Ratagan', 'RATAGAN', 1, 32, NULL, 1, 3, 42, 11449, NULL, '', 38, '800/800/800/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20988, '2022-08-09 11:32:32.72298+00', '2022-08-17 08:50:36.793265+00', 'Totaig Broch', 'TOTAIG BROCH', 3, 32, NULL, 4, 4, 1, 11449, NULL, '', 100, '8888/8888/8888/8888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20990, '2022-08-10 18:10:19.696731+00', '2022-09-18 21:42:20.732696+00', 'Wee Journey, A', 'WEE JOURNEY', 2, 32, NULL, 8, 6, 12, 11781, '2022-07-01', 'This dance is written as a gift for Rachel Shankland and George Meikle that took such good care of us during our Units 2 and 3. The changes of direction give many opportunities for the men to flash their underwear as the RSCDS demands for Unit 2.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11461, '2003-09-22 22:00:00+00', '2022-12-17 13:22:47.426148+00', 'Magic Dishpan, The', 'MAGIC DISHPAN', 3, 32, 9999, 4, 4, 1, 2766, '2002-04-01', 'A different version of this dance had been published by Sue McKinnell on her web site.  This was a 4x32 Jig in square formation and contained some of the same figures.  



In *The Lost Princess of Oz*, Cayke the Cookie Cook has her magic dishpan stolen. Ugu the shoemaker uses it to steal the all the magic he can from the inhabitants of Oz (including Ozma of Oz) (*Sue McKinnell*).', 81, '8888/8080/8888/4848', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (43, '1998-09-29 22:00:00+00', '2022-08-11 13:23:27.973914+00', 'Admiral Nelson', 'ADMIRAL NELSON', 1, 64, 9999, 1, 4, 1, 9998, '1805-01-01', 'From *Scotland Dances*, by Jeannie Callander Sharp:



On 21st October, 1805, the Right Honorable the Viscount Nelson, K. B., was mortally wounded aboard *Victory* during the triumphant battle of Trafalgar. It is ironic that this dance was published in the

same year as Nelson''s death.



Admiral Horatio Nelson, born in Norfolk, England, in 1758, created viscount in 1801, was the hero of all Britain. He was courageous: he gave the sight of his right eye, his right arm, and, later, his life in the defense of his country. He was a romantic figure: one only need consider his long attachment to Emma Hamilton, a fact that must have titillated the ladies of his time. He was a great humanitarian: unlike Marlborough and Wellington, his common touch would appeal strongly to the Scots.



The Nelson Monument, atop Calton Hill in Edinburgh, was finished in 1815. Whether by accident or design, it rather resembles an inverted telescope. The English monument to their native son in Trafalgar Square, while in somewhat better taste than the Edinburgh memorial, was not finished until 1849, over forty years after Nelson''s death. But, in Glasgow Green stands another monument honouring Lord Nelson. The energetic Glaswegians began erecting theirs in 1805 and it was finished in 1806. And at the same time there was erected another monument to Admiral Nelson, a seventy-foot octagonal tower atop Cluny Hill in the small Morayshire town of Forres.

', 56, '8800/8000/8000/8888/8880/8800/8888/8000', 1, 1, 1, 1, 56);
INSERT INTO 'dance' VALUES (104, '1997-04-03 22:00:00+00', '2022-08-11 13:27:14.965278+00', 'Alloway', 'ALLOWAY', 1, 32, 9999, 1, 3, 42, 28, NULL, 'To Elizabeth, who introduced me to the lasting pleasure of Scottish Counntry Dancing, - when in Bristol, 1947, she started a class with a few members of St. Oswals''s Church.', 69, '888/888/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (230, '1998-01-05 23:00:00+00', '2022-08-11 13:33:49.806578+00', 'Arms of Saint Andrews', 'ARMS OF SAINT ANDREWS', 1, 64, 9999, 1, 4, 1, 99, '1975-05-01', 'Inscribed "For Tom Rowe and Anne Carstairs who first floated the idea".', 80, '8686/8888/8000/8888/8440/8448/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (681, '1998-10-18 22:00:00+00', '2022-08-11 14:43:15.527858+00', 'Bonnie Woods o'' Craigielea, The', 'BONNIE WOODS O CRAIGIELEA', 1, 64, 9999, 1, 3, 42, 270, NULL, 'Note from the instructions: to get to the bottom from third place the original first couple should set and cast off on the first four bars of the next repeat.', 63, '800/888/888/888/888/844/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (868, '1998-11-14 23:00:00+00', '2022-08-11 14:55:49.356418+00', 'Fiddler on the Capstan, The', 'FIDDLER ON THE CAPSTAN', 1, 48, 9999, 1, 3, 42, 108, '1981-01-01', 'Inscribed "for Herb Carl of Albany, California".



The notes explain that "While he was at St. Andrews in July 1981, Herb Carl had a dream. Mary Stoker was teaching her class to dance "The New-Rigged Ship" on the deck of the Victory in Portsmouth Harbour. As usual, she was cracking her vhip and urging them to extra effort. Music for the dancing was supplied by a fiddler vho stood on the centre of the capstan while the class danced round him."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (908, '1997-08-31 22:00:00+00', '2022-08-11 15:04:02.867229+00', 'Cadger''s Bridge, The', 'CADGERS BRIDGE', 1, 32, 9999, 8, 105, 12, 313, NULL, 'The dance notes explain that "The Cadger''s Bridge crosses the Biggar Burn at the west end of the main street of Biggar. William Wallace is said to have crossed the bridge disguised as a cadger (hawker or carrier) before defeating Edward I in a battle to the south-east of the town."', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1603, '1997-09-01 22:00:00+00', '2022-08-11 23:12:50.562439+00', 'Dee''s Dandy Dance', 'DEES DANDY DANCE', 1, 32, 9999, 1, 2, 76, 96, NULL, 'If the name sounds like something out of a nineteenth-century medicine show , that''s intentional.

This dance was devised as a dance that even the rankest beginners would not be able to foul up,

and so far it has lived up to those hopes. That''s why it carries no designation as reel, jig,

strathspey or medley -- it can be (and has been) used as any one of them, as the need arises.

Often it is done with just a skipping step. That doesn''t matter; its purpose is to give beginners a 

sense of accomplishment, the satisfaction of having done a dance right, as early in the first lesson

as possible (although more experienced dancers have been known to enjoy it too).', -1, '44/44/88/88', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19852, '2020-02-24 08:28:40.059026+00', '2022-08-12 07:39:42.775337+00', 'Pudsey''s Reel', 'PUDSEYS REEL', 1, 32, NULL, 1, 4, 1, 308, '2009-09-01', 'Written for the “Dance Scottish for Pudsey” event held at DG One in Dumfries in October 2010', 81, '8888/8888/8000/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2068, '1997-09-02 22:00:00+00', '2022-08-12 07:44:24.449868+00', 'Fandango, The', 'FANDANGO', 2, 64, 9999, 1, 3, 42, 466, '1780-01-01', '', 41, '800/800/888/800/822/822/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4559, '1997-10-28 23:00:00+00', '2022-08-12 10:40:12.729983+00', 'Miss Murray of Ochtertyre', 'MISS MURRAY OF OCHTERTYRE', 1, 16, 9999, 1, 3, 42, 1749, '1798-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4075, '1998-04-12 22:00:00+00', '2022-08-12 09:12:46.232823+00', 'Magic Moments', 'MAGIC MOMENTS', 2, 32, 9999, 8, 105, 12, 80, '1990-01-01', 'This is a 3 x 32 dance; all dancers end diagonally opposite their starting point (6,5,4,3x,2x,1x).  If danced 6 times through, all finish in own places.



In the original 1990 version, published in "Brock Summer Celebration", bars [25-32] had "6c+1c turn RH, turn LH".

The current version, published in "Canada''s Irish Rover", bars [25-32] have "All Circle12 and back".', 52, '444444/444444/800008/888888', 1, 1, 1, 1, 41);
INSERT INTO 'dance' VALUES (4696, '1997-04-03 22:00:00+00', '2022-08-12 11:03:56.227019+00', 'Mr & Mrs R. J. Ross', 'MR AND MRS R J ROSS', 1, 32, 9999, 1, 4, 1, 99, '1986-03-01', 'Inscribed "For John and Sharon Ross on their Wedding Day".', 72, '4444/8888/8888/8004', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4974, '1997-04-03 22:00:00+00', '2022-08-12 11:07:17.642515+00', 'Norma''s Tune', 'NORMAS TUNE', 2, 32, 9999, 1, 2, 76, 270, NULL, 'Editor’s note to the 2021 edition.



The cross with left hand in bars 1-2 is a suggested alternative to the original instructions. These are included here for completeness, yet it is a long way for the first man in two bars.



1-2 First man casts off and crosses to second lady’s place whilst second lady crosses to first man’s place.', 58, '73/84/88/88', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5803, '1998-01-05 23:00:00+00', '2022-08-12 11:38:57.380786+00', 'Saint Andrew''s Flag', 'SAINT ANDREWS FLAG', 1, 32, 9999, 1, 3, 42, 151, NULL, 'Sheila writes:  I use this dance when introducing double triangles as most dances containing this formation have a preceeding movement which results in a confused entry into double triangles.', 50, '880/800/888/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20994, '2022-08-12 09:04:02.722405+00', '2022-08-12 09:20:17.561358+00', 'Waves, The', 'WAVES', 3, 32, NULL, 1, 3, 42, 11765, '2022-08-01', 'Devised by Saskia Frisby and inspired by the waves in the sea around St. Andrews. For Rachel Shankland and George Meikle, with heartfelt thanks for their kindness towards and patience with the Units 2/3 class of 2022.', 44, '800/880/844/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5642, '1997-04-03 22:00:00+00', '2022-08-12 11:27:04.812702+00', 'Rocket Hornpipe, The', 'ROCKET HORNPIPE', 1, 32, 9999, 5, 2, 4, 270, NULL, '', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5746, '1997-04-03 22:00:00+00', '2022-08-12 11:35:16.785352+00', 'Royal Occasion, A', 'ROYAL OCCASION', 1, 40, 9999, 1, 3, 42, 21, NULL, 'Composed in Honour of the Wedding of His Royal Highness The Prince Andrew and Miss Sarah Ferguson.', 65, '888/888/844/844/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5972, '1997-04-03 22:00:00+00', '2022-08-12 11:43:18.184281+00', 'Sea Caves, The', 'SEA CAVES', 1, 32, 9999, 3, 5, 92, 156, NULL, 'The Sea Caves refer to the many caves in the coastal cliffs at Wemyss. "Wemyss" is apparently gaelic for caves. (Source: Southern Stars Book, where the dance is published)', 65, '80800  88888  80800  48488', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (11389, '2003-07-06 22:00:00+00', '2022-08-13 17:36:11.522638+00', 'Blue and White Quilt, The', 'BLUE AND WHITE QUILT', 2, 32, 9999, 1, 3, 42, 146, '2002-01-01', 'For Barbara Peel - dancer, quilter and friend', 55, '806  680  666  888', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (9366, '2000-04-03 22:00:00+00', '2022-08-13 11:03:56.664952+00', 'Amy in the Middle', 'AMY IN THE MIDDLE', 2, 32, 9999, 1, 3, 42, 2706, '1999-01-01', 'The notes explain that "In 1998, Amy Chlebecek hurt her ankle and was unable to dance rounds. Instead, she look jumping into the middle of the set from whatever position she was dancing, and letting the other couples dance around her. Someone suggested writing a dance called ''Amy in the Middle'', so I did."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (9880, '2001-05-20 22:00:00+00', '2022-08-13 11:18:31.415957+00', 'President Stuart''s Jig', 'PRESIDENT STUARTS JIG', 2, 40, 9999, 1, 100, 2, 9998, NULL, '', 56, '8008/8008/4884/8448/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6326, '1997-04-03 22:00:00+00', '2022-08-12 22:02:04.639662+00', 'Storrers, The', 'STORRERS', 1, 32, 9999, 5, 2, 4, 270, NULL, '', 100, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6521, '1997-04-03 22:00:00+00', '2022-08-12 22:13:06.27285+00', 'There Cam'' a Young Man', 'THERE CAM A YOUNG MAN', 2, 32, 9999, 1, 3, 42, 270, NULL, '', 62, '880/888/880/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6645, '1997-04-03 22:00:00+00', '2022-08-12 22:29:29.793648+00', 'Ton, The', 'TON', 1, 48, 9999, 1, 4, 1, 270, NULL, '', 54, '4444/4444/8440/8044/8000/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6873, '1997-12-21 23:00:00+00', '2022-08-12 22:32:19.978443+00', 'Vancouver Welcome, A', 'VANCOUVER WELCOME', 1, 40, 9999, 1, 4, 2, 9, NULL, '', 90, '8668/8668/8448/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2550, '1997-04-03 22:00:00+00', '2022-08-13 08:38:52.250748+00', 'Glenkiln Jig', 'GLENKILN JIG', 2, 48, 9999, 1, 3, 42, 270, NULL, '', 54, '888/880/880/880/880/808', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4371, '1997-04-03 22:00:00+00', '2022-08-13 08:41:31.071244+00', 'Mike Hardie''s Reel', 'MIKE HARDIES REEL', 1, 40, 9999, 1, 3, 42, 21, NULL, '', 64, '860  844  888  888  888', 1, 1, 1, 1, 85);
INSERT INTO 'dance' VALUES (20982, '2022-08-09 11:25:27.414453+00', '2022-08-13 09:04:57.433252+00', 'Cro of Kintail', 'CRO OF KINTAIL', 3, 32, NULL, 1, 4, 1, 11449, NULL, 'The River Cro slowly meanders down the glaciated valley of Glen Lichd flowing into Loch Beag and under the

causeway into Loch Duich.  

The river is named after the ''cro'' of Kintail where the mountains encircle the low level ground near Morvich

as a fold would encircle & protect sheep.  

It would be lovely to dance this simple strathspey to the tune of Ian MacMhurachaidh''s song “Theid mi dhachaidh Chro Cintaille” - “I will go home to the fold of Kintail”.', 50, '8800/8000/8000/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7077, '2000-03-09 23:00:00+00', '2022-08-13 09:14:12.371431+00', 'Wheels Around The World', 'WHEELS AROUND THE WORLD', 1, 40, 9999, 4, 4, 54, 289, NULL, 'This dance was devised by a class at a Special School so that children in wheelchairs would be able to take part. (Teacher Mrs M Barlow).', 60, '4444/4444/8080/0808/8888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7866, '1997-12-03 23:00:00+00', '2022-08-13 09:30:27.161744+00', 'New Parliament House Jig, The', 'NEW PARLIAMENT HOUSE JIG', 2, 64, 9999, 107, 118, 30, 1168, '1980-01-01', 'Three trios WMW arranged in a square set.



Here is the introduction from a magazine called "Stringybark and Greenhide, Folk magazine of Australia" Vol. 2 No. 6 December 1980:



This dance represents the system of government in Australia.  The man in the middle representing the new Parliament House.  The six women representing the Australian States.  The other two men representing the Territories.  The various movements of the dance represent the interaction of the central government, the State Governments, and the Territory Authorities, finishing with a change of Government.





-------------------------Historical note by the author ------------------------------



New Parliament House Jig

------------------------------------------

This dance was not written with any particular genre in mind. Actually, I had been observing that dancing (at the time) was tending towards the frantic rather than sedate so I decided to attempt to write a dance that just couldn''t be successfully danced at a fast pace, and the original tune was played somewhat slower than the usual tempo for jigs.



Here is the background -



I lived in Canberra from 1976 - 1981 and had a gig at a wine bar/restaurant where the architect of the proposed New [Australian] Parliament House was a regular customer. He attended a couple of bush dances at the Yarralumla Woolshed when I was playing and we had some discussion about traditional dancing and how dance and movement can be representative.



From this the idea of a dance was born and very quickly composed, together with an original tune (3x64 bar jig aptly named The New Parliament House Jig) for the pending Dance Composing Competition being held by the Sydney Bush Music Club at their 1980 festival - I''m pleased to say that it won and was published in Stringybark and Greenhide in Dec 1980.



I understand that the dance has become popular near and far - which is very gratifying. Also I believe that it has been changed somewhat and some rather exotic calls have been used by inventive callers - and of course that''s the wonderful folk process at work.



The last I heard from Phil Wilson was that it was to be published (with the original tune) by Cecil Sharpe House in a collection of most popular dances. Makes me quite chuffed.



John Colville, May, 2003



', 56, '033/330/121/202/121/121/333/111', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8546, '2000-04-25 22:00:00+00', '2022-08-13 10:43:32.162452+00', 'Dodgems, The', 'DODGEMS', 1, 40, 9999, 1, 3, 42, 2759, '1997-04-01', '', 50, '440/800/844/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8991, '1999-04-19 22:00:00+00', '2022-08-13 10:50:21.116935+00', 'Barnes'' of Washington, The', 'BARNES OF WASHINGTON', 1, 32, 9999, 1, 3, 42, 2107, '1996-03-01', 'Inscribed "Devised by Christopher Bames. To commemorate the golden wedding anniversary of his parents Duard and Betty Lee Barnes in March 1996."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10647, '2002-07-21 22:00:00+00', '2022-08-13 12:14:41.888641+00', 'Fiddlin'' Round', 'FIDDLIN ROUND', 1, 32, 9999, 1, 3, 42, 2961, '1998-01-01', 'The San Francisco Branch has been blessed to have so many fine fiddlers play for balls and monthly parties. This dance is a tribute to their dedication and to many years of listening and dancing pleasure (Bob McMurtry).



May be danced as a reel or a jig.



Contributed crib supplied by Bruce Clark.

', 44, '800/844/800/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10661, '2002-07-21 22:00:00+00', '2022-08-13 12:19:54.945107+00', 'Halsway Anniversary', 'HALSWAY ANNIVERSARY', 2, 40, 9999, 1, 3, 42, 3165, '1996-01-01', 'Devised in 1996 by Peter Wright for the South Dorset Caledonian Society''s 21st Week-end at Halsway Manor. The tune was written by their "resident musician", Hugh Ferguson.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10745, '2002-07-24 22:00:00+00', '2022-08-13 14:15:41.320161+00', 'Gentle Lads and Lassies, The', 'GENTLE LADS AND LASSIES', 1, 32, 9999, 6, 53, 17, 1391, NULL, 'On those nights when only two dancers show up, I think teachers will welcome this three person dance.', 96, '888/888/888/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11805, '2004-09-16 22:00:00+00', '2022-08-13 14:18:35.868591+00', 'Colwyn''s Ruby Reel', 'COLWYNS RUBY REEL', 1, 32, 9999, 1, 3, 42, 930, '2002-12-01', 'Inscribed "For Colwyn Bay, Llandudno and District Caledonian Society on their fortieth anniversary."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12085, '2005-03-16 23:00:00+00', '2022-08-13 15:05:42.38062+00', 'Celtic Dreaming', 'CELTIC DREAMING', 1, 40, 9999, 2, 3, 17, 3520, '2000-01-01', '', 67, '888  080  808  888  800', 0, 1, 0, 0, 66);
INSERT INTO 'dance' VALUES (1039, '1997-04-03 22:00:00+00', '2022-08-13 17:08:30.509655+00', 'Carlisle Castle', 'CARLISLE CASTLE', 3, 40, 9999, 1, 3, 42, 108, '1967-01-01', 'Two of Bonnie Prince Charlie''s men were captured and left behind in Carlisle after the failed rising of 1745. One young soldier was to be executed, the other released. The Spirit of the dead soldier travelling by the ''low road'' would reach Scotland before his comrade, who would be struggling along the actual road over high, rugged country.', 49, '680  804  840  880  888', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (6322, '1997-04-03 22:00:00+00', '2022-08-13 17:20:12.500112+00', 'Stoney Path Tower', 'STONEY PATH TOWER', 1, 32, 9999, 1, 4, 1, 270, NULL, '', 72, '8888/8888/8066/8000', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10483, '2002-04-19 22:00:00+00', '2022-08-13 17:28:33.113558+00', 'Pat Morrison''s Delight', 'PAT MORRISONS DELIGHT', 3, 32, 9999, 1, 2, 76, 3100, '1995-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15212, '2013-10-14 22:30:50.365036+00', '2022-08-13 20:26:59.233706+00', 'Jig for Ayla, A', 'JIG FOR AYLA', 2, 32, NULL, 1, 4, 1, 10874, NULL, 'The notes say this was "devised by Ayla Huseyinoglu (age 9), Darlington Juniors. I like the petronella movement, and slip steps as well as skip change."', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15432, '2014-05-09 21:55:37.862568+00', '2022-08-13 20:28:55.693726+00', 'New Year Wedding', 'NEW YEAR WEDDING', 3, 32, 9999, 2, 3, 17, 10957, '2011-01-01', 'This dance is dedicated to Emily Ziccarelli and Jesse Adams in celebration of their marriage December 31, 2011.

<p>1-8 First Glances

<br>9-16 The Chase

<br>17-24 The Courtship

<br>25-32 The Wedding', 50, '808/080/080/088', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18850, '2018-10-06 13:43:29.577718+00', '2022-08-13 21:32:21.330754+00', 'Passing Fancy, A', 'PASSING FANCY', 3, 32, NULL, 1, 4, 2, 2766, '2012-09-01', 'I love playing with variations of dance figures and the bourrel is one of my favorites. I decided to see if I could make up a 4-couple version.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17631, '2017-03-07 01:04:30.323923+00', '2022-08-13 21:33:55.947323+00', 'Passing Fancy (Reel version), A', 'PASSING FANCY REEL VERSION', 1, 32, NULL, 1, 2, 76, 872, NULL, 'In "Stepping Out, part 2, Original version" of 1997 this dance was published as a Strathspey', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18243, '2018-02-15 17:32:03.581823+00', '2022-08-13 21:36:46.630244+00', 'George''s Grid Square', 'GEORGES GRID SQUARE', 4, 128, 2, 4, 4, 30, 3098, NULL, 'Grid Square - dancers progress to other squares.', 97, '8888/8686/8888/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19275, '2019-04-20 09:28:03.729502+00', '2022-08-13 22:11:51.297753+00', 'Union Jack', 'UNION JACK', 2, 32, NULL, 4, 4, 13, 11527, NULL, 'Contributed crib taken from dance list <<https://my.strathspey.org/dd/list/22206/>>', 78, '8888/7777/2222/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19982, '2020-05-28 20:44:33.365809+00', '2022-08-13 22:15:41.830302+00', 'Sintra in the Mist', 'SINTRA IN THE MIST', 4, 96, 11, 4, 4, 14, 11150, NULL, '', 80, '8282/8484/2848/4848/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13338, '2007-09-11 22:00:00+00', '2022-08-14 08:13:03.738632+00', 'High Peak', 'HIGH PEAK', 2, 32, 9999, 1, 3, 42, 3782, '2007-01-01', 'From the notes: "Devised by Evalyn and Ernst Eder in April 2007 for the first formal dance of the Madoma Group to celebrate its 25th season of dancing. This easier dance was devised to be coupled with ''<<ddd:Kinder Scout>>'' on the dance programme."

', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12440, '2005-05-09 22:00:00+00', '2022-08-14 08:15:08.175065+00', 'Kinder Scout', 'KINDER SCOUT', 2, 32, 9999, 1, 3, 42, 118, '1985-01-01', 'Kinder Scout is the High Peak of Derbyshire, at the southern end of the Pennine Chain in England.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20979, '2022-08-09 09:58:23.596827+00', '2022-08-14 08:18:21.901901+00', 'Little Rag Doll, The', 'LITTLE RAG DOLL', 1, 40, NULL, 1, 3, 42, 11449, NULL, '', 38, '800/840/804/840/880', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13898, '2011-08-22 22:00:00+00', '2022-08-14 08:24:19.281269+00', 'City in Bloom, A', 'CITY IN BLOOM', 2, 32, NULL, 2, 3, 17, 64, '2007-03-01', 'Dedicated to Muriel Johnstone, Keith Smith, Bill and Atsuko Clement and Bill Zobel, on the occasion of Pretoria Branch''s 35th Anniversary celebration in October 2007, the time of year when Jacaranda blossoms turn the city of Pretoria into a mauve wonderland.', 75, '800/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13899, '2011-08-22 22:00:00+00', '2022-08-14 08:27:45.737809+00', 'Colourful Character', 'COLOURFUL CHARACTER', 2, 32, NULL, 1, 3, 42, 3254, '2004-04-01', 'Devised by Terry Lynne Harris, Pretoria, April 2004.



Written for Martin Sheffield, with happy memories of attending his first SCD Holiday near Grenoble, France, 16-23 June 2003. Martin is a colourful character, unconventional, "slightly eccentric" (his own words on his web-site), and exudes enthusiasm and energy. Dancing with him was a joy! ', 67, '880/886/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13913, '2011-08-22 22:00:00+00', '2022-08-14 08:30:41.501922+00', 'Hamba Kahle', 'HAMBA KAHLE', 2, 32, NULL, 1, 3, 42, 64, '2006-03-01', 'Devised by Irene van Maarseveen. Pretoria. March 2006.  



This dance is dedicated to Elma Mccausland and Margo Monteith. It commemorates Elma ''s visit to South Africa in August 2006. The title, Hamb a Kahle, is a widely-used Zulu farewell which means Go Well. It is pronounced with "a" as in "ah", "h" aspirated, and "e" as in "bed", each word having two syllables, thus: "ham-ba ka-hle''''. ', 53, '660/880/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14571, '2012-09-13 16:03:11.198592+00', '2022-08-14 08:53:58.768594+00', 'Saturday Market', 'SATURDAY MARKET', 2, 32, NULL, 1, 3, 42, 10593, '2010-03-01', 'A good dance for exploring different kinds of figures of eight.



Vancouver, WA has a lovely Weekend Farmer’s Market, but you have to get there early on Saturday to get the hydroponic lettuce. 1st couple practically run over each other getting ready for the market (bars 1-4), travel to the market (bars 5-8), and wander among the stalls looking for the best prices, the best produce, and the beautiful lettuce (bars 9-24). They got there in time to get the last one, and celebrate with a circle round and back!

', 37, '800/800/800/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (14674, '2013-01-22 00:01:34.824147+00', '2022-08-14 10:12:48.993317+00', 'Reel for Miss Donaghue', 'REEL FOR MISS DONAGHUE', 1, 24, NULL, 1, 3, 42, 10717, NULL, 'Note: The deviser was 6 y old.  This becomes a more attractive dance by adding 25-32: Circle6 and back.', 46, '800  880  804', 1, 1, 1, 0, 61);
INSERT INTO 'dance' VALUES (14689, '2013-01-28 20:39:44.907745+00', '2022-08-14 10:17:32.318916+00', 'Make Haste Slowly', 'MAKE HASTE SLOWLY', 1, 96, 9999, 4, 4, 3, 10476, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14901, '2013-05-27 16:39:03.7839+00', '2022-08-14 10:29:39.842965+00', 'Mairrit at Last', 'MAIRRIT AT LAST', 2, 40, NULL, 1, 3, 42, 1331, '2001-01-01', 'My wife and I dated in the 70s, but then broke up for 17 years. This dance was part of our wedding celebration in 1999 and represents various aspects:  the first 8 bars represent the diamond ring with which I engaged her, the reels chronicle our parallel lives while apart, the chase is self-explanatory, I hope, the Double Triangles represent our sharing the news with friends and the Promenade is the wedding. ', -1, '840/888/888/', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (15193, '2013-10-14 10:08:10.949461+00', '2022-08-14 10:35:44.836912+00', 'Carol''s Reel', 'CAROLS REEL', 1, 40, NULL, 3, 5, 7, 10870, NULL, 'For their teacher, Carol Sanderson.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15195, '2013-10-14 10:21:48.121646+00', '2022-08-14 10:41:09.162503+00', 'Mortimer''s Jig', 'MORTIMERS JIG', 2, 32, NULL, 1, 3, 42, 10875, NULL, 'Deviser aged 9.



The instructions have the title "Mortimer''s Jig" but say its a 32 bar reel for three couples though only two couples are dancing. SCDDB has it as a jig. It is not clear if this was the intention. ', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (15852, '2015-01-20 11:55:03.309886+00', '2022-08-14 11:50:18.821945+00', 'Salute to St Andrew, A', 'SALUTE TO ST ANDREW', 1, 32, 9999, 5, 2, 30, 2625, '2003-11-01', 'Any good reel



such as "Dirk Kommer''s Reel" played by Marian Anderson on "Bordering On Scottish" CD - TRCD9905', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16147, '2015-02-27 18:10:37.385628+00', '2022-08-14 15:08:07.848976+00', 'Dance o da Shetland Puffins', 'DANCE O DA SHETLAND PUFFINS', 1, 32, 9999, 2, 2, 76, 1309, '2006-09-15', 'Suggested music: "Dance o da Shetland Puffins" on Da Fustra, Dance o da Shetland Puffins.



The dance notes say this was devised while listening to that CD and looking at the drawings of puffins doing a very energetic left hand tum.', 50, '80/80/88/88', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16222, '2015-04-24 07:59:41.147646+00', '2022-08-14 15:13:26.671912+00', 'Kelly''s Kaper', 'KELLYS KAPER', 2, 32, NULL, 2, 3, 17, 515, '2015-04-01', 'Written for STV Appeal Big Challenge.  This is the revised version of 27 April 2015.



Note: on the RSCDS website this dance was first erroneously stated to be a 3C/4L dance, with progression (2,1,3). Unfortunately the new RSCDS website has broken the old link (https://www.rscds.org/article/stv-appeal).', 58, '800/888/880/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16847, '2016-01-18 15:22:44.509509+00', '2022-08-14 21:32:25.888353+00', 'Fisherman Ginger''s Reel', 'FISHERMAN GINGERS REEL', 1, 32, 9999, 1, 3, 42, 11234, '2001-01-01', 'Devisers’ Notes: 



Bars 9-24 



In the rotating reel (as a corner dancer) be sure after passing right shoulder to first woman or man that you keep RIGHT to dance the rotation. First couple also need to be generous with their phrasing and allow the corner dancers to have the space to complete the rotation, there is plenty of time for first couple to complete their part of this formation. 



Bars 25-32 



If this is proving a mission with your group, the alternative is to dance 6 hands round and back. 



Again with this dance as with Dave Macfarlane''s Reel after the second time through the original 1st couple stay in third place and move down on 3-4 of the second repeat. Shown on the You Tube Clip. 





This dance was devised to celebrate the 40th birthday of Brian (Ginger) Richards. Brian''s three great passions are Jenny Richards (his wife), Scottish country Dancing and Fishing (not necessarily in that order!). Jenny asked us to devise this dance and put in movements that Brian loves. 



The movements in this dance represent the collection of the boat (1-8), the throwing out of the first line (9-12), a tiddler escaping (13-16, where the corners return safely home), and then the big catch (28) which is hauled aboard (29-32). 



The formations we have used were obvious to us. when you have seen Brian''s enthusiasm and the way he has introduced these movements into other dances, they are logical choices. 



Devised by Gaye & Damon Collin 2001 10

', 50, '800/844/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20995, '2022-08-12 12:26:13.277857+00', '2022-08-16 09:59:38.385056+00', 'Old Rag Doll, The', 'OLD RAG DOLL', 4, 64, 5, 1, 3, 42, 11449, NULL, '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17282, '2016-09-06 23:29:59.910848+00', '2022-08-15 08:35:40.07068+00', 'Piglet''s Jig', 'PIGLETS JIG', 2, 32, 9999, 1, 3, 42, 51, '2007-01-01', '“Twirl around Piglet, Step lightly Pooh, This silly ol'' dance is perfect for two.” - A.A. Milne

(Bars 3-4, 5-8, 13, 24, and 28 are opportunities for Piglet to twirl.)



For Ivy and Chris, remembering Pinewoods.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17348, '2016-09-14 23:02:40.664129+00', '2022-08-15 08:37:07.425066+00', 'Finishing Touches', 'FINISHING TOUCHES', 2, 32, NULL, 1, 3, 42, 2793, '2007-03-01', 'Devised for the Hamilton Workshop, March 2007.  



The theme was "Finish a STEP, Finish a PHRASE, Finish a DANCE".', 47, '800/800/866/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17689, '2017-04-01 19:44:00.978235+00', '2022-08-15 08:49:50.480957+00', 'Borderland Jig', 'BORDERLAND JIG', 2, 32, NULL, 1, 3, 42, 11163, '2016-07-01', 'Devised in July 2016. In the middle section (bars 9 - 16), the two lines of dancers confront a border which 

prevents them from meeting. By the end, however, all obstacles are overcome and they are able to join hands and dance together.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17941, '2017-09-17 10:26:50.977973+00', '2022-08-15 08:55:40.972749+00', 'Colours of Spring', 'COLOURS OF SPRING', 2, 32, 9999, 2, 3, 17, 3254, '2013-11-01', '', 72, '881/228/888/088', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20570, '2021-12-03 22:09:10.423092+00', '2022-08-15 09:07:06.522396+00', 'Madge Wildfire''s Strathspey', 'MADGE WILDFIRES STRATHSPEY', 3, 32, NULL, 1, 3, 42, 9998, NULL, 'Originally published in 1820 by John Sutherland, Edinburgh in a booklet linked to Sir Walter Scott''s novel The Heart of Midlothian. Madge Wildfire is a character in this novel.  Reconstructed by the RSCDS in 2021 to mark the 250th anniversary of Sir Walter Scott''s birth.



The RSCDS has previously published a different reconstruction of this dance in Book 9  <<https://my.strathspey.org/dd/dance/4064/>>', 56, '888/888/844/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18130, '2017-12-19 22:15:15.23956+00', '2022-08-15 11:14:51.989656+00', 'Tinto Hill', 'TINTO HILL', 2, 40, NULL, 1, 3, 42, 2525, NULL, 'Suitable Music The Golden Pheasant



Tinto Hill reaches at  height of 2,320 feet. The hill lies close to the village of Symington in Lanarkshire, Scotland', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18184, '2017-12-23 22:53:48.209671+00', '2022-08-15 11:16:06.665656+00', 'Bobby Brown Jig', 'BOBBY BROWN JIG', 2, 32, NULL, 1, 3, 42, 2525, '2005-10-14', 'Thank you Bobby for your wondeful gift of music to all those who enjoy Scottish Country Dancing', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (18388, '2018-06-25 11:06:16.669764+00', '2022-08-15 11:27:03.12451+00', 'Mr Finan''s Rant', 'MR FINANS RANT', 1, 48, 9999, 3, 5, 6, 10974, '2017-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19372, '2019-06-01 12:46:22.26772+00', '2022-08-15 11:42:22.841983+00', 'Jacquy''s Jig', 'JACQUYS JIG', 2, 32, NULL, 1, 4, 2, 743, NULL, 'Slow jig (can also be done as a strathspey).



To Jacquy, my wife, who has been a huge support in running my classes for many years.', 94, '8448/8888/8888/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19380, '2019-06-01 16:57:28.454842+00', '2022-08-15 11:48:29.719482+00', 'Frog on the Mantle, The', 'FROG ON THE MANTLE', 2, 32, NULL, 1, 3, 42, 10934, NULL, 'This dance revises the infamous candidate dance <<ddd:Frog in the Middle>>. I find the tune fantastic and the dance, well, lacking.  

The frogs on the mantle belong to Alfred and Eleanor Hurd, whose home has hosted many social dances, and classes and who use frogs to mark the sets. This dance is written for them, and for our candidate class tutors, Geoffrey Selling and Jill Emery.', 56, '800/888/877/855', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19650, '2019-09-16 00:59:13.514199+00', '2022-08-15 13:27:21.695989+00', 'David''s Box', 'DAVIDS BOX', 2, 32, NULL, 1, 2, 76, 11876, '2010-01-01', 'This dance was devised by Sandee Schultz to teach rights and lefts. Bars 17-32 can be varied if need be.  



The dance is named for David Newitt, who uses this method of teaching rights and lefts as an exercise.', 60, '88/88/80/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19854, '2020-02-28 11:25:05.1234+00', '2022-08-15 13:49:09.535643+00', 'Christiane''s Ceilidh', 'CHRISTIANES CEILIDH', 1, 32, NULL, 5, 56, NULL, 154, NULL, 'The dance was written for Christiane Orgeret, a talented and friendly dancer who celebrated her 60th birthday in Lyon with a dance held in the Château De Montchat, Lyon.', 92, '888/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20213, '2021-02-03 13:04:46.163432+00', '2022-08-15 14:05:46.907089+00', 'Auld Lang Syne', 'AULD LANG SYNE', 1, 40, NULL, 1, 3, 42, 3723, NULL, 'Source: MIniCrib. Can be danced as a Reel or a Jig (deviser''s statement).

', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20301, '2021-04-05 09:08:49.304509+00', '2022-08-15 14:09:06.934763+00', 'Eeeasy', 'EEEASY', 1, 32, NULL, 1, 4, 2, 11029, NULL, 'Arnold Thurling has been teaching at the Wollongong White Heather group for half a century. After teaching then recapping a dance he would inevitably declare it as “Eeeasy”. Usually we got through it too.', 69, '8008/8888/8008/8448', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20326, '2021-04-16 16:53:51.35057+00', '2022-08-15 14:11:15.294152+00', 'Jig with Alexandra, A', 'JIG WITH ALEXANDRA', 2, 32, NULL, 1, 2, 76, 12041, '2020-01-01', 'Alexandra, a Méaudre Reel (France) dancer started dancing SCD in 2016 when she was 6.  



After 5 years of dancing, she offered to her school mistress, Sophie Marchand, an easy dance for the Méaudre Reel « little ones ». The beginners'' class could dance Alexandra''s dance once and it was planned to be danced officially for the Méaudre Reel end of the year show in May 2020, but the Covid decided otherwise !', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11710, '2004-03-18 23:00:00+00', '2022-08-15 14:24:06.872615+00', 'Spindrift', 'SPINDRIFT', 3, 40, 9999, 1, 3, 42, 647, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20839, '2022-05-14 22:51:53.001361+00', '2022-08-15 15:31:17.013032+00', 'Persian Dance, The', 'PERSIAN DANCE', 1, 48, NULL, 103, 113, NULL, 99, '1988-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16412, '2015-05-30 18:22:46.363803+00', '2022-08-15 17:25:12.522994+00', 'Weaver''s Bonnie, The', 'WEAVERS BONNIE', 2, 32, 9999, 2, 3, 17, 2018, '2011-01-01', 'NB bars 17-28 of the instructions for this dance in the PDF on the MiniCrib site were truncated in the original version (now fixed). They should read:



17-28 TEAPOTS INTO DOWN MIDDLE & BACK: 1st couple dance 3-hands across, 1st man with

2nd & 3rd women, 1st woman with 2nd & 3rd men, then dance down middle followed by 2nd & 3rd

couples; and return up the middle 1st followed by 2nd and 3rd couples who separate to let 1st, then 2nd 

couple through;

', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20415, '2021-07-30 12:51:57.207827+00', '2022-08-16 10:05:56.646959+00', 'Sound Man, The', 'SOUND MAN', 3, 32, NULL, 2, 3, 17, 12051, NULL, 'In memory of our friend Mr John H. Hutton - sound engineer and a man of the highest integrity - a Sound Man in every way.  



Dance devised by Patricia and John Cass with help from the Thursday Afternoon Class and sold in aid of St Benedict''s Hospice, Sunderland.', 71, '844/888/844/804', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20792, '2022-04-27 22:44:53.269904+00', '2022-08-17 08:32:18.585862+00', 'Aberdeenshire Meets Argentina', 'ABERDEENSHIRE MEETS ARGENTINA', 3, 32, NULL, 2, 3, 17, 2101, '2019-10-01', '', 67, '800/844/888/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20986, '2022-08-09 11:30:50.086243+00', '2022-08-17 08:44:39.183859+00', 'Invershiel Gold', 'INVERSHIEL GOLD', 3, 32, NULL, 1, 2, 76, 11449, NULL, 'This may also be danced in a 3 couple set', 67, '86/88/88/88', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20983, '2022-08-09 11:26:12.57384+00', '2022-08-17 08:53:22.488182+00', 'Sisters, The', 'SISTERS', 2, 32, NULL, 3, 5, 16, 11449, NULL, 'The ridge of mountains on the north side of Glen Shiel known as the Five Sisters of Kintail are named after the legendary princesses who stand waiting, looking out over the loch for their husbands-to-be to come from Ireland after the youngest sister was only allowed to leave for Ireland with her suitor on condition that his five brothers returned to marry her five older sisters.', 78, '80608/08680/88888/88888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20306, '2021-04-06 21:36:30.499405+00', '2022-08-18 09:16:55.801062+00', 'Millennium Jig', 'MILLENNIUM JIG', 2, 32, NULL, 3, 5, 16, 12032, '2000-01-01', 'Source <<https://www.scottish-country-dancing-dictionary.com/dance-crib/millennium-jig-2.html>> and <<https://youtu.be/RyPv-5kbRYk|youtube video>>.', 40, '80008/08880/80008/80000', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20741, '2022-03-27 21:10:48.230828+00', '2022-08-17 10:18:53.195749+00', 'Open The Doors!', 'OPEN THE DOORS', 2, 32, NULL, 1, 3, 42, 3682, NULL, 'Inspired by Morgan''s poem: "For The Opening of the Scottish Parliament, 9 October 2004"



The name of the dance is taken from the opening line and of the tune from the last. The dance is suitable for the opening of a Scottish Dance programme allowing dancers of any age or ability to join in. The music highlights the joy and optimism of the poem, with some descending musical reference to mimic Morgan''s trip, "down the mile, into the heart of the city". There is occasional syncopation to interrupt the flow, suggesting the political missteps that Morgan warns against.



', 44, '800/888/800/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13150, '2006-12-11 23:00:00+00', '2022-08-17 18:38:46.716766+00', 'Eleanor''s Strathspey', 'ELEANORS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2766, '2006-01-01', 'Carl Dickson dedicates this dance to Eleanor Reed Searle, a family friend who died three and a half months before her eightieth birthday. Eleanor was a swing dancer, not a Scottish Country Dancer. However, she knew of and supported his passion for SCD. She was also a devoted wife, mother, grandmother, avid watercolorist, and gardener. As a committed volunteer she was dedicated to human rights, low-income housing, civil rights and welfare reform and served on many committees and boards in her homes states of Massachusetts and Maine. She received several honors and awards for her hard work.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13170, '2006-12-11 23:00:00+00', '2022-08-17 18:40:05.197676+00', 'Slightly Askew', 'SLIGHTLY ASKEW', 3, 32, 9999, 1, 3, 42, 2766, '2006-05-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18569, '2018-09-09 21:41:00.930615+00', '2022-08-17 21:06:44.613739+00', 'Wookiee Walk, The', 'WOOKIEE WALK', 3, 32, NULL, 1, 3, 42, 2766, '2014-04-01', 'This dance is one of two written especially for a Star Wars themed dance night.



Although the Star Wars character was a "Wookiee" with double E, the deviser originally used "Wookie" with one E in her title which is therefore the spelling used in the database.



Subsequently the deviser''s web page was updated so now the official name and alias are swapped.

', 67, '888/644/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13576, '2010-05-30 22:00:00+00', '2022-08-18 00:17:33.271185+00', 'Hana', 'HANA', 3, 32, 9999, 1, 3, 42, 154, '2009-03-22', '', 56, '800  888  880  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (454, '2000-09-21 22:00:00+00', '2022-08-18 09:02:31.957904+00', 'Belfast Hornpipe, The', 'BELFAST HORNPIPE', 1, 32, 9999, 2, 3, 17, 80, '1989-01-01', 'A variant, created inadvertently by Mel Briscoe, has now been given its own name "<<ddd:Wes Clindinning''s Hornpipe>>" as it has become popular in its own right (see there for more information).



The dance denoted as "Belfast Hornpipe (New Way)" at <<https://dances.e-cribs.org/var/Cincinnati_Demo_Dances_2007-2008.pdf>> (there also attributed to Mel Briscoe) is not identically to either of the two dances above. However, all three dances only differ in bars [25-32].  





', 46, '440  448  800  804', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (7206, '1997-09-17 22:00:00+00', '2022-08-18 09:06:08.34741+00', 'Witch''s Rant, The', 'WITCHS RANT', 1, 32, 9999, 3, 5, 16, 82, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8162, '1999-12-21 23:00:00+00', '2022-08-18 09:08:10.940916+00', 'Virginia Reel', 'VIRGINIA REEL', 1, 40, 9999, 1, 4, 1, 9998, NULL, 'Walking step (this is a ceilidh dance)



Set can be 4 couples or more. 



Collected by Mary Stoker



Music: any good hoe down.', 85, '8888  8888  8888  8000  8888', 0, 1, 0, 0, 85);
INSERT INTO 'dance' VALUES (13614, '2010-10-07 22:00:00+00', '2022-08-18 09:14:02.187614+00', 'Spinnaker Tower, The', 'SPINNAKER TOWER', 2, 40, NULL, 1, 3, 42, 11110, NULL, 'In the original description 2c stepped up on [15-16]; the author, Kathy Lawmon, now writes "After publishing it in a book of dances called Dancing in Southsea, I realised myself when teaching it that it was better to step up on bars 11-12."', 65, '888  800  888  888  888', 1, 1, 1, 0, 86);
INSERT INTO 'dance' VALUES (9733, '2000-11-17 23:00:00+00', '2022-08-18 09:30:07.944655+00', 'Rainbow Reel, The', 'RAINBOW REEL', 1, 48, 9999, 3, 5, 6, 2831, '1994-01-01', 'Devised "to mark the birth of The New (democratic) South Africa - a complex society."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2211, '1997-04-03 22:00:00+00', '2022-08-18 20:57:11.347459+00', 'Five Sisters, The', 'FIVE SISTERS', 3, 40, 9999, 3, 5, 7, 28, NULL, '"Devised for Catherine Espie, a long-time member of Downpatrick class, who now lives in Letterfearn where she enjoys the view of the near-by Five Sisters."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2595, '1999-04-21 22:00:00+00', '2022-08-18 21:01:03.381548+00', 'Golden Ring, The', 'GOLDEN RING', 3, 32, 9999, 1, 4, 1, 62, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3411, '1997-04-03 22:00:00+00', '2022-08-18 21:09:15.375123+00', 'Kay Armstrong''s Delight', 'KAY ARMSTRONGS DELIGHT', 3, 32, 9999, 1, 4, 1, 94, NULL, '"Inscribed to Kay Armstrong for her eightieth birthday, who is an example to us all with her enthusiasm and pleasure in our national dancing."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4290, '1997-09-08 22:00:00+00', '2022-08-18 21:22:28.942803+00', 'Meeting At The Hawes', 'MEETING AT THE HAWES', 3, 40, 9999, 1, 4, 1, 1118, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4803, '2000-04-05 22:00:00+00', '2022-08-18 21:24:23.932268+00', 'Mrs Stewart of Fasnacloich', 'MRS STEWART OF FASNACLOICH', 1, 32, 9999, 1, 3, 42, 319, '1973-01-01', 'This is one of a suite of three dances published in 1973 to commemorate the Golden Jubilee of the Society, 1923 -1973. Mrs. Stewart of Fasnacloich was the co-founder of the Society with Miss Milligan.



John Drewry wrote this note for his dance "<<ddd:Ysobel#7265>>": "This dance, devised in 1973, was used by the Publication''s Committee in that year as the basis for the reel "Mrs Stewart of Fasnacloich" - a dance which has always disappointed me - I do not like left shoulder reels of four and I think that setting should come at the beginning of a phrase rather than at the end. My feeling, for a long time, has been that Mrs. Stewart was never the same woman again after she was interfered with by the committee! I am publishing the dance in its original form in the hope that dancers will enjoy it this way."', 62, '880/888/844/888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (4950, '2003-01-25 23:00:00+00', '2022-08-18 21:28:25.237627+00', 'Newton of Millfield', 'NEWTON OF MILLFIELD', 3, 32, 9999, 1, 3, 42, 35, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5244, '1997-09-11 22:00:00+00', '2022-08-19 08:33:50.222191+00', 'Phyllis''s Fancy', 'PHYLLISS FANCY', 3, 32, 9999, 1, 2, 76, 313, NULL, 'Inscribed "For Phyllis Wood, for eleven years class teacher of Sutton Coldfield Scottish Country Dance Society."', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6389, '1998-10-16 22:00:00+00', '2022-08-19 08:46:04.269581+00', 'Sunart Strathspey, The', 'SUNART STRATHSPEY', 3, 32, 9999, 1, 3, 42, 226, '1980-01-01', '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7530, '2002-08-26 22:00:00+00', '2022-08-19 08:55:25.662267+00', 'Trip Around the World', 'TRIP AROUND THE WORLD', 2, 32, 9999, 1, 4, 1, 1502, '1993-02-01', 'Devised for the departure of Lin Wood from Scotland on her trip around the world. ', 69, '8000  8888  8080  8888', 1, 1, 1, 1, 68);
INSERT INTO 'dance' VALUES (10471, '2006-09-02 22:00:00+00', '2022-08-19 09:03:13.792229+00', 'Sailor Hector', 'SAILOR HECTOR', 1, 32, 9999, 1, 4, 11, 3495, '2006-01-01', 'A modified version of this dance, in which the final 8 bars were completely changed, was published in 2013 keeping the name "Sailor Hector".  To avoid confusion the new version has now (Jan 2017) been renamed "The Naughty Child".  This database entry shows the original "Sailor Hector".  "<<ddd:Naughty Child, The#17539>>" appears as separate dance on the database.', 72, '7777/8448/8448/0880', 1, 1, 1, 1, 71);
INSERT INTO 'dance' VALUES (13347, '2007-09-11 22:00:00+00', '2022-08-19 09:14:53.957146+00', 'Madoma Magic', 'MADOMA MAGIC', 3, 32, 9999, 3, 5, 16, 118, '2007-01-01', 'Devised to show a different progression in a five-couple set.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17539, '2017-01-15 23:21:03.876269+00', '2022-08-19 09:27:47.475089+00', 'Naughty Child, The', 'NAUGHTY CHILD', 1, 32, NULL, 1, 4, 11, 3495, '2013-01-01', 'This dance was derived from "Sailor Hector" (2006), differing only for bars 25-32.  This dance was first published in 2013 keeping the name "Sailor Hector", but to remove the confusion of two different dances with the same name it has now (Jan 2017) been renamed to "The Naughty Child".   This database now shows both dances separately.', 72, '7777/8448/8448/4444', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6535, '2002-05-06 22:00:00+00', '2022-08-20 08:16:36.503846+00', 'Thirtytwosome Reel, The', 'THIRTYTWOSOME REEL', 1, 464, 9999, 4, 108, 3, 9998, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8227, '1997-12-28 23:00:00+00', '2022-08-20 08:21:49.970009+00', 'Three Times on Sunday', 'THREE TIMES ON SUNDAY', 1, 32, 9999, 1, 4, 1, 35, '1997-01-01', 'From the dance notes:



"I read a story about a Kirk that employed an organ blower in the 1800s. The membership at Garturk Parish Church on Calder Street in Whiftlet, Lanarkshire, was around 750. Apparently it was very strenuous work and demanded pumping the hand bellows three times every Sunday - 12:00 noon service, 3:00 p.m. Senior Bible Class, and 6:00 p.m. evening service - also any week-night services. Once during the sermon he fell asleep. When the next hymn was announced the organist started to play but no sound came out, so the organist had to pop round behind the curtain to wake him up. After that, during the sermon, he had to sit in front of the organ and face the congregation. The bellows were still in use in 1974 when there was a power failure during a storm or an electrical fault."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (636, '1998-10-18 22:00:00+00', '2022-08-20 08:29:29.085725+00', 'Bonnie Band o'' Gold, The', 'BONNIE BAND O GOLD', 2, 32, 9999, 1, 3, 42, 702, '1983-07-01', 'Cy Chapman of the 1982-83 beginners'' class composed this dance to celebrate the wedding of fellow members, Rebecca Beddoes and Rory McAlpine, July 1983.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (2337, '1997-09-02 22:00:00+00', '2022-08-20 17:53:08.339054+00', 'Fredericton Welcome', 'FREDERICTON WELCOME', 3, 32, 9999, 1, 3, 42, 280, '1981-11-01', 'This dance was created immediately after (he Fredericton Scottish Country Dance Group''s tenrh annual weekend workshop to thank the host group and to keep the driver alert on the journey home to Cambridge, Massachusetts.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5986, '1997-09-13 22:00:00+00', '2022-08-20 18:54:08.946977+00', 'Second Salute To Miss Milligan', 'SECOND SALUTE TO MISS MILLIGAN', 1, 32, 9999, 1, 3, 42, 480, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6457, '1997-04-03 22:00:00+00', '2022-08-20 19:05:27.116099+00', 'Tankard, The', 'TANKARD', 2, 32, 9999, 1, 4, 1, 211, NULL, 'The dance notes say this was "compiled in thanks to the Apapa Scottish Country Dance Group, Lagos."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11592, '2003-11-29 23:00:00+00', '2022-08-20 19:51:28.651815+00', 'Jan Finlayson''s Jig', 'JAN FINLAYSONS JIG', 2, 32, 9999, 1, 3, 42, 411, '1997-01-01', '"Devised to mark Jan Finlayson''s three years as President of Kamo Scottish Country Dance Club. In grateful recognition of a job well done."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12434, '2005-05-09 22:00:00+00', '2022-08-20 19:54:34.956131+00', 'Second of June, The', 'SECOND OF JUNE', 3, 32, 9999, 1, 3, 42, 118, '2001-02-01', 'Devised for the marriage of Elisa Jean Hook and Anthony Paul Holland in Calgary, Alberta.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4389, '1997-04-03 22:00:00+00', '2022-08-21 08:16:08.835635+00', 'Mill on the Don, The', 'MILL ON THE DON', 1, 32, 9999, 1, 4, 1, 413, NULL, 'The instructions for this dance are a little hard to interpret usually omitting "half" from half figues and relying on bar counts. The numbering of couples often seems to refer to current places rather than original positions.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20997, '2022-08-21 18:15:03.997977+00', '2022-08-21 22:43:52.50205+00', 'Burlington Arcade', 'BURLINGTON ARCADE', 4, 32, 1, 2, 3, 18, 12195, '2022-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19690, '2019-10-05 00:00:23.325446+00', '2022-08-22 23:09:21.512885+00', 'Grandpa Squeezebox', 'GRANDPA SQUEEZEBOX', 2, 32, NULL, 1, 3, 42, 2766, '2019-09-01', '<<ddp:#1862|Mike Briggs>> played piano and accordion for the Madison SCD Branch for years. Sadly he left us this year in August. His <<https://editor.freethoughttoday.com/free/in-memoriam-mike-briggs/|obituary>> mentioned he was called Grandpa Squeezebox by his grandchildren.  



Suggested music is Two and Two from Music for RSCDS Book 19 (Ron Kerr Quintet).', 67, '886/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (334, '1997-09-29 22:00:00+00', '2022-08-22 08:47:48.507417+00', 'Bachuil Of Saint Kessog, The', 'BACHUIL OF SAINT KESSOG', 3, 32, 9999, 1, 4, NULL, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20999, '2022-08-21 18:26:06.181117+00', '2022-08-21 22:56:29.217189+00', 'Shimmering Flamingos', 'SHIMMERING FLAMINGOS', 2, 32, NULL, 4, 4, 13, 11237, '2021-01-01', 'The title comes from endless walks around odd corners of my local neighbourhood during Covid lockdowns. An architecturally uninspiring housing estate is adorned with some striking murals. One of these is a surreal adaptation of Wordsworth''s famous "I wandered lonely as a cloud" poem where the "golden daffodils" are replaced by "shimmering flamingos".

', 88, '8888/6262/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21000, '2022-08-21 18:26:39.917289+00', '2022-08-21 22:59:05.960764+00', 'Editor Emeritus, The', 'EDITOR EMERITUS', 2, 32, NULL, 1, 102, 11, 11237, '2020-06-01', 'This dance is dedicated to Eric Ferguson who has worked tirelessly for the international Scottish Country Dance community for several decades. His contributions include writing thousands of “E-cribs” and maintaining and adding to the contents of the Scottish Country Dance Database. He has always been ready to offer a helping hand to others by sharing his expertise or making quick database updates. The extra hand holds in this dance are a symbol of that.

', 75, '0880/0880/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6165, '1997-09-29 22:00:00+00', '2022-08-22 08:48:59.883959+00', 'Snow Goose, The', 'SNOW GOOSE', 3, 32, 9999, 1, 3, 42, 44, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (12250, '2005-04-19 22:00:00+00', '2022-08-22 08:49:48.697597+00', 'Gentleman in Black Velvet, The', 'GENTLEMAN IN BLACK VELVET', 3, 32, 9999, 1, 2, NULL, 44, '1999-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21001, '2022-08-21 18:38:35.162201+00', '2022-10-24 14:54:11.915574+00', 'Generous Tunesmith, The', 'GENEROUS TUNESMITH', 2, 32, NULL, 1, 3, 42, 11237, '2020-06-01', '', 56, '842/844/877/866', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21004, '2022-08-23 11:16:32.687459+00', '2022-08-23 11:18:23.112775+00', 'Super Blue Blood Moon', 'SUPER BLUE BLOOD MOON', 1, 32, NULL, 1, 100, 11, 2766, '2018-02-01', 'On January 31st of this year (2018), we had this very rare event: a super blue blood moon.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21003, '2022-08-23 11:12:18.659359+00', '2022-08-23 11:18:54.303629+00', 'It''s a New World', 'ITS A NEW WORLD', 1, 32, NULL, 1, 3, 42, 2766, '2018-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21005, '2022-08-23 11:24:11.018353+00', '2022-08-23 11:24:11.018353+00', 'First Robin of Spring, The', 'FIRST ROBIN OF SPRING', 2, 32, NULL, 1, 3, 42, 2766, '2018-03-01', 'I wanted to play with the Best Set in the Hall figure and came up with this. Note that in bars 21-28 1C is dancing Inveran reels. Written after I heard the first robin of spring in the yard.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21006, '2022-08-23 11:27:13.694089+00', '2022-08-23 11:27:13.694089+00', 'It''s Worth Believin''', 'ITS WORTH BELIEVIN', 3, 32, NULL, 1, 3, 42, 2766, '2018-03-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21007, '2022-08-23 11:43:04.288124+00', '2022-08-23 11:43:04.288124+00', 'Shadow Double Knitting', 'SHADOW DOUBLE KNITTING', 2, 32, NULL, 1, 100, 2, 2766, '2018-03-01', 'These figures remind me of the double knitting technique, which I used in a pattern I made up combining shadow knitting with double knitting.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21008, '2022-08-23 11:46:25.19848+00', '2022-08-23 11:46:25.19848+00', 'Bee Happy', 'BEE HAPPY', 1, 32, NULL, 1, 4, 2, 2766, '2018-04-01', 'Written to celebrate picking up 4 packages of bees this month.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21009, '2022-08-23 11:51:35.551353+00', '2022-08-23 11:51:35.551353+00', 'Twisted Triangle', 'TWISTED TRIANGLE', 1, 32, NULL, 1, 3, 42, 2766, '2018-04-01', 'I had an idea that one could make a triangle in a regular set and started playing with it. I also had a request for a 3-couple targe and this is what I came up with.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21011, '2022-08-23 11:57:10.465885+00', '2022-08-23 11:57:10.465885+00', 'Toni''s Big Day', 'TONIS BIG DAY', 1, 32, NULL, 1, 3, 42, 2766, '2018-04-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21012, '2022-08-23 12:13:56.032795+00', '2022-08-23 12:13:56.032795+00', 'Loop de Loop', 'LOOP DE LOOP', 2, 32, NULL, 1, 3, 42, 2766, '2018-04-01', 'The idea for the figure in bars 1-16 occurred to me along with the phrase loop-de-loop so I wrote this dance.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21013, '2022-08-23 12:16:44.35928+00', '2022-08-23 12:16:44.35928+00', 'Can''t Depend on Love', 'CANT DEPEND ON LOVE', 3, 32, NULL, 1, 3, 42, 2766, '2018-05-01', 'Named for a favorite Gordon Lightfoot song.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21014, '2022-08-23 12:19:35.678714+00', '2022-08-23 12:19:35.678714+00', 'Cotton Jenny', 'COTTON JENNY', 1, 32, NULL, 1, 3, 42, 2766, '2018-05-01', 'Written for a favorite Gordon Lightfoot song.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21015, '2022-08-23 12:24:28.444933+00', '2022-08-23 12:24:28.444933+00', 'Alberta Bound', 'ALBERTA BOUND', 1, 32, NULL, 1, 3, 42, 2766, '2018-05-01', 'Written for a favorite Gordon Lightfoot song.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21016, '2022-08-23 12:27:29.736724+00', '2022-08-23 12:27:29.736724+00', 'Just Keep Dancing', 'JUST KEEP DANCING', 1, 32, NULL, 1, 3, 42, 2766, '2018-05-01', 'With all the heat and all the pain in my hip and knee, the best medicine is to keep dancing (gently).', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21017, '2022-08-23 12:33:41.440184+00', '2022-08-23 12:33:41.440184+00', 'Chocolate Babka', 'CHOCOLATE BABKA', 1, 32, NULL, 1, 3, 42, 2766, '2018-05-01', 'Named for a favorite dessert.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21018, '2022-08-23 12:37:22.386479+00', '2022-08-23 12:37:22.386479+00', 'Tuxedo Cat', 'TUXEDO CAT', 1, 32, NULL, 1, 3, 42, 2766, '2018-05-01', 'For our black and white tuxedo cat Harrington who started out shy and is now as demanding and demonstrative as our other cats – after only 10 years.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21019, '2022-08-23 12:41:14.124069+00', '2022-08-23 12:41:14.124069+00', 'Go Go Round', 'GO GO ROUND', 2, 32, NULL, 1, 3, 42, 2766, '2018-06-01', 'Named for a favorite Gordon Lightfoot song.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21020, '2022-08-23 12:45:54.430324+00', '2022-08-23 12:45:54.430324+00', 'Ghosts of Cape Horn, The', 'GHOSTS OF CAPE HORN', 3, 32, NULL, 1, 3, 42, 2766, '2018-06-01', 'Named for a favorite Gordon Lightfoot song. Note that this could be a 3-couple set dance if the last figure is 6-bar reels across the set, then 1C dance down the center and face out to begin the double figure of 8.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21021, '2022-08-23 12:51:00.007227+00', '2022-08-23 12:51:00.007227+00', 'Farfalle', 'FARFALLE', 1, 32, NULL, 1, 3, 42, 2766, '2018-06-01', 'Farfalle is bow-tied shaped pasta and the figures in this dance are all bow ties. Also, farfalle means butterflies and we have Monarch butterflies in our yard.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10169, '2001-10-23 22:00:00+00', '2022-08-25 21:22:42.814031+00', 'Vanessa', 'VANESSA', 2, 32, 9999, 1, 3, 42, 108, '2000-01-01', 'Drewry writes that Vanessa is the old Hittite name for Avanos which is a town in the Cappadocia region of central Turkey. It is on the banks of the Red River and is famous for high grade pottery and carpets.', 69, '888/888/880/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20767, '2022-04-15 15:55:09.646651+00', '2022-08-29 07:05:49.720139+00', 'Winter Has Come, The', 'WINTER HAS COME', 2, 32, NULL, 5, 56, 76, 12119, '2021-01-01', 'From the dance notes:  

*The dance represents the image on the crest and flag of the Chuvash Republic:*  

*bars 1-4 - lower branches of the Tree of Life*  

*bars 5-8 - middle branches of the Tree*  

*bars 17-20 - upper branches of the Tree*  

*bars 29-32 - the three suns above the Tree of Life*  ', 90, '888/844/888/688', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3906, '1999-08-11 22:00:00+00', '2022-08-28 23:11:02.367447+00', 'London Highland Club''s Farewell to Fetter Lane, The', 'LONDON HIGHLAND CLUBS FAREWELL TO FETTER LANE', 1, 32, 9999, 1, 4, 1, 68, '1972-01-01', '', 56, '8666/8228/8800/8002', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21023, '2022-08-29 03:52:01.077898+00', '2022-08-29 04:36:50.681485+00', 'Waltz Hold Poussette Medley', 'WALTZ HOLD POUSSETTE MEDLEY', 4, 64, 22, 1, 3, NULL, 448, '2022-01-01', 'Devised by Andrew Timmins 2016 to 2022  

"The idea of this dance started in 2016. Ian Russell suggested, I should devise a dance with the Waltz Hold Poussette, after watching Mechthild & I dance it. We have been dancing it since 1994. Schorsch Lusky mentioned he wanted to learn it after we attending 2022 Frankfurt Ball."', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20940, '2022-07-06 23:36:48.007618+00', '2022-08-29 06:37:41.840452+00', 'Strawberry Picking', 'STRAWBERRY PICKING', 2, 32, NULL, 1, 3, 42, 12168, NULL, 'From the dance notes:  

*The dance was devised during wild strawberry gathering in summer.*  

*1-4 entry into the strawberry glade*  

*5-16 strawberry gathering into small jars*  

*17-24 pouring strawberries from the jars into a large buckets 25-32 bringing the harvest home*  

', 69, '844/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21025, '2022-08-30 18:32:49.711651+00', '2022-08-31 15:09:07.247237+00', 'Shine Never Goes Out, The', 'SHINE NEVER GOES OUT', 3, 32, NULL, 1, 3, 42, 12143, '2020-05-01', '"Cross shape" is a map symbol of the hospital and also a shape of the shining light.

', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21029, '2022-08-30 19:38:06.527526+00', '2022-08-31 09:32:19.083208+00', 'Starry Night Glow', 'STARRY NIGHT GLOW', 3, 32, NULL, 1, 3, 42, 12143, '2022-06-01', 'Corner pass and turn in this dance is "Corner pass and turn one and a quarter".', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21010, '2022-08-23 11:54:20.080019+00', '2022-09-01 10:46:30.988408+00', 'April Snow', 'APRIL SNOW', 3, 32, NULL, 1, 3, 42, 2766, '2018-04-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21022, '2022-08-23 12:54:19.737132+00', '2022-09-01 10:47:16.617773+00', 'Orange and Black Beauty', 'ORANGE AND BLACK BEAUTY', 2, 32, NULL, 1, 3, 42, 2766, '2018-07-01', 'I wrote this after seeing a Monarch butterfly in our yard on a milkweed plant opening and closing its wings – it was gorgeous.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21026, '2022-08-30 18:37:11.928033+00', '2022-08-31 09:28:24.439008+00', 'Water Beetle', 'WATER BEETLE', 2, 32, NULL, 1, 3, 42, 12203, '1994-10-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21028, '2022-08-30 19:32:56.320216+00', '2022-10-03 13:01:57.175438+00', 'Trip to Yokohama, A', 'TRIP TO YOKOHAMA', 1, 32, NULL, 1, 4, 1, 12151, '2020-03-01', 'There are many beautiful sightseeing spots in Yokohama City. It''s deviser''s pleasure, if you can feel fun by this dance.', 81, '8888/8440/8448/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (895, '1998-09-29 22:00:00+00', '2022-08-31 09:18:49.972223+00', 'C''Est L''Amour', 'CEST LAMOUR', 2, 32, 9999, 1, 3, 42, 319, '1830-01-01', 'The French convention for capitalising this title would be just "C''est l''amour" or "C''est l''Amour". Capitalising every word as "C''Est L''Amour" would be considered incorrect in French but is how the RSCDS printed it in Book 34 so that is what is used here.', 48, '411  800  888  888', 0, 1, 0, 1, 64);
INSERT INTO 'dance' VALUES (21030, '2022-08-30 19:46:50.894489+00', '2022-08-31 09:24:20.739437+00', 'New York Yankees', 'NEW YORK YANKEES', 3, 32, NULL, 1, 4, 30, 10356, NULL, 'Deviser''s note:  

This was devised with the intention of inviting all to dance it with the deepest yearning for the dear friend Yoshiaki Niwa, who has passed away.

Mr Yoshiaki Niwa and my late husband, Yukio Naitoh, were very good friends.

I remember them saying to each other that the initial of their names was the same as the New York Yankees, the baseball team, since they both had NY as the first letter of their names.

They sometimes borrowed the design of the baseball team logo, which N and Y are overlapped, when inscribing their initials. This is the origin of this dance.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21027, '2022-08-30 18:45:03.664898+00', '2022-08-31 09:31:29.765075+00', 'Wave of Memory', 'WAVE OF MEMORY', 3, 32, NULL, 1, 3, 42, 12202, '2020-11-01', 'The image of this dance is waves, approaching the center, pulling back, swirling or cutting through a vortex.

Deviser thinks the wave is similar to human memory.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21032, '2022-08-31 10:07:26.066094+00', '2022-08-31 10:07:26.066094+00', 'Roseground', 'ROSEGROUND', 3, 32, NULL, 1, 3, 42, 2766, '2018-07-01', 'Named for a favorite bobbin lace ground.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21031, '2022-08-31 09:58:51.729222+00', '2022-08-31 10:08:38.263314+00', 'Monarch Duet', 'MONARCH DUET', 1, 32, NULL, 1, 3, 42, 2766, '2018-07-01', 'This year was a good one for Monarch butterflies in my yard and one day I watched as a pair flew first separately then came together to dance a duet in the air.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21033, '2022-08-31 10:13:18.701434+00', '2022-08-31 10:13:18.701434+00', 'Spinnen, Spinnen, Spinnen', 'SPINNEN SPINNEN SPINNEN', 1, 32, NULL, 1, 3, 42, 2766, '2018-07-01', 'Named for a favorite bobbin lace book (Spinne is German for spider, Spinnen is the plural, and the book is all about making different spiders, an interesting and fun bobbin lace stitch).', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21034, '2022-08-31 10:18:12.425202+00', '2022-08-31 10:18:55.420404+00', 'Helen and Malcolm Brown', 'HELEN AND MALCOLM BROWN', 3, 32, NULL, 2, 3, 17, 2766, '2018-08-01', 'Helen and Malcolm Brown visited Chicago in August 2018 and the Chicago Branch held a dance in their honor. This dance was written shortly after that event and incorporates the starting figure from Malcolm’s dance Links with St Petersburg and the bourrel, which is a figure Helen likes.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21035, '2022-08-31 10:46:37.637123+00', '2022-08-31 10:46:37.637123+00', 'Cycles', 'CYCLES', 3, 32, NULL, 3, 5, 33, 2766, '2018-08-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21036, '2022-08-31 10:49:41.956532+00', '2022-08-31 10:50:45.818027+00', 'Catch Her If You Can', 'CATCH HER IF YOU CAN', 1, 40, NULL, 1, 3, 42, 2766, '2018-09-01', '1M chases 1W throughout the dance and only catches up with her in the last 4 bars.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21037, '2022-08-31 10:59:27.788455+00', '2022-08-31 10:59:27.788455+00', 'Ride the Wind', 'RIDE THE WIND', 2, 32, NULL, 1, 3, 42, 2766, '2018-09-01', 'The name of this dance comes from the title track in this cut of music.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21038, '2022-08-31 11:03:23.484546+00', '2022-08-31 11:03:23.484546+00', 'Nome King''s Belt, The', 'NOME KINGS BELT', 1, 32, NULL, 1, 3, 42, 2766, '2018-09-01', 'In the book Ozma of OZ, Dorothy manages to acquire the Nome King''s belt, which is an important magic item and used in later books as well.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21039, '2022-08-31 11:11:12.871888+00', '2022-08-31 11:11:12.871888+00', 'Buckingham Fountain', 'BUCKINGHAM FOUNTAIN', 1, 32, NULL, 1, 3, 42, 2766, '2018-09-01', 'Named for one of Chicago’s iconic landmarks.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21040, '2022-08-31 11:17:07.470646+00', '2022-08-31 11:17:07.470646+00', 'Diagonal Duet', 'DIAGONAL DUET', 3, 32, NULL, 1, 3, 42, 2766, '2018-09-01', 'I had an idea for an allemande on the diagonal and wrote this dance to try it out. When dancing it, one of the dancers remarked that a set of tall, long-legged, excellent dancers might prefer to dance around the outside of the set rather than within it.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21041, '2022-08-31 11:20:49.497859+00', '2022-08-31 11:21:29.316201+00', 'Just Keep Turning', 'JUST KEEP TURNING', 1, 32, NULL, 1, 3, 42, 2766, '2018-09-01', 'The title comes from the figure in bars 9-16 and 17-24 as people just keep turning the whole time.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21042, '2022-08-31 11:29:00.86574+00', '2022-08-31 11:29:00.86574+00', 'Walk Around the Block, A', 'WALK AROUND THE BLOCK', 2, 32, NULL, 1, 3, 42, 2766, '2018-10-01', 'Written while I was walking around a (long) block near my house.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21044, '2022-08-31 11:37:08.328942+00', '2022-08-31 11:37:08.328942+00', 'White City, The', 'WHITE CITY', 3, 32, NULL, 1, 3, 42, 2766, '2018-10-01', 'I was reading books about the Columbian Exposition in Chicago in 1893, a section of which was called the white city because of the color of the buildings and the extensive lighting.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21045, '2022-08-31 11:41:00.452169+00', '2022-08-31 11:41:00.452169+00', 'Farewell Faithful Oak', 'FAREWELL FAITHFUL OAK', 3, 32, NULL, 1, 3, 42, 2766, '2018-10-01', 'We lost one full-sized bur oak tree in the backyard and now another one has died.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21046, '2022-08-31 16:09:42.710986+00', '2022-08-31 16:09:42.710986+00', 'Dream Street Rose', 'DREAM STREET ROSE', 1, 32, NULL, 1, 3, 42, 2766, '2018-11-01', 'Named for a favorite Gordon Lightfoot song and written a few days before his 80th birthday.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21047, '2022-08-31 16:14:43.643796+00', '2022-08-31 16:14:43.643796+00', 'NWT Mountie', 'NWT MOUNTIE', 2, 32, NULL, 1, 3, 42, 2766, '2018-12-01', 'My grandfather was a Mountie in the Northwest Territories in the early 1910''s. At that time NWT meant a huge chunk of what is now Canada, including Alberta, which is where he lived.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21048, '2022-08-31 16:21:29.627871+00', '2022-08-31 16:22:40.281024+00', 'Highland Scrambler', 'HIGHLAND SCRAMBLER', 1, 32, NULL, 1, 3, 42, 2766, '2018-12-01', 'The original name of this dance was The Eggbeater because the figure in bars 9-24 reminds me of an eggbeater, but my class renamed it for me when they first danced it. Note that timing is critical in that figure!', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21049, '2022-08-31 16:28:12.158103+00', '2022-08-31 16:29:42.063906+00', 'Torties Are Always Sweet', 'TORTIES ARE ALWAYS SWEET', 1, 32, NULL, 1, NULL, 42, 2766, '2018-12-01', 'For Ember, who was a tortieshell I rescued. My vet says she has never met a tortieshell that wasn’t sweet-tempered and Ember definitely was a sweet cat.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21050, '2022-08-31 16:41:07.167862+00', '2022-08-31 16:41:07.167862+00', 'Longer Days', 'LONGER DAYS', 2, 32, NULL, 2, 3, 18, 2766, '2018-12-21', 'I like ladies'' chain and am always searching for ways to get first couple back on their own sides after the figure. The non-standard progression works, but is a bit ''interesting'' and my local class recommended it be listed as a 3-couple set dance after trying it out.



This dance was written on the Winter Solstice – thus the name.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21051, '2022-08-31 16:46:33.635512+00', '2022-08-31 16:46:33.635512+00', 'First Night', 'FIRST NIGHT', 1, 32, NULL, 1, 3, 42, 2766, '2019-01-01', 'Written January 1st, 2019.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21052, '2022-08-31 16:52:12.896564+00', '2022-08-31 16:52:12.896564+00', 'Time to Dance Again', 'TIME TO DANCE AGAIN', 3, 32, NULL, 1, 3, 42, 2766, '2019-01-01', 'Celebrating getting back to dancing after the holiday break.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21054, '2022-08-31 17:04:01.109122+00', '2022-08-31 17:09:17.516207+00', 'Ice-Cold-Ice', 'ICECOLDICE', 1, 32, NULL, 1, 3, 42, 2766, '2019-02-01', 'Class was cancelled for ice, then extreme cold, then ice. The temperature got to -23º F, but we survived.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21043, '2022-08-31 11:33:01.470703+00', '2022-09-01 07:48:36.179132+00', '23 / 7', '23 / 7', 3, 32, NULL, 1, 3, 42, 2766, '2018-10-01', 'This month my husband and I celebrated 23 years together, the last 7 married.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21055, '2022-08-31 17:07:05.045808+00', '2022-08-31 17:08:47.298267+00', 'Savor the Figure', 'SAVOR THE FIGURE', 2, 32, NULL, 1, 2, 76, 2766, '2019-03-01', 'I like Celtic reels and decided to write a dance to add more Celtic reels in dances.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21053, '2022-08-31 16:57:58.007183+00', '2022-08-31 17:09:47.24412+00', 'Return to Delaware Valley', 'RETURN TO DELAWARE VALLEY', 3, 32, NULL, 1, 3, 42, 2766, '2019-02-01', 'Written for Barbara Cool and Tom Senior who plan to move back to the Delaware Valley area where they started dancing.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21056, '2022-08-31 21:27:11.389483+00', '2022-08-31 21:27:11.389483+00', 'Jersey Boy', 'JERSEY BOY', 1, 32, NULL, 1, 3, 42, 2766, '2019-03-01', 'For my Dad who was born in New Jersey, served in the Navy in WWII, and died at the age of 93 on <<https://www.piday.org/|pi day>> this year. Bars 1-8 look like a heart to me.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21058, '2022-08-31 21:37:19.04031+00', '2022-08-31 21:37:19.04031+00', 'Celtic Wheel', 'CELTIC WHEEL', 2, 32, NULL, 1, 2, 76, 2766, '2019-03-01', 'While thinking about Celtic reels, this variant came to me.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21060, '2022-08-31 21:47:11.994821+00', '2022-08-31 21:47:11.994821+00', 'April Snow Again', 'APRIL SNOW AGAIN', 1, 32, NULL, 1, 3, 42, 2766, '2019-04-01', 'Just an idea that came to me for bars 9-16 and 25-32. Note that 1C is dancing full reels while corners are dancing half reels.



We had snow on April 14th this year which covered blooming daffodils. Weird.', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21063, '2022-08-31 22:05:47.524382+00', '2022-08-31 22:05:47.524382+00', 'Too Much Rain', 'TOO MUCH RAIN', 3, 32, NULL, 1, 3, 42, 2766, '2019-06-01', 'After the wettest May on record, it kept raining nearly every day in June as well. A friend posted ''The drought is over after 36 hours without rain!''', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21064, '2022-08-31 22:08:52.354657+00', '2022-08-31 22:08:52.354657+00', 'Fox in the Sun', 'FOX IN THE SUN', 1, 32, NULL, 1, 3, 42, 2766, '2019-06-01', 'We were visiting the next-door neighbors one afternoon and there was a beautiful fox in their backyard, lying on its side enjoying the sun.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21059, '2022-08-31 21:41:54.603585+00', '2022-08-31 22:33:27.875547+00', 'Four Daughters', 'FOUR DAUGHTERS', 2, 32, NULL, 1, 4, 2, 2766, '2019-03-01', 'For my Dad who had Scottish heritage (MacDonald) and also four daughters, which is why the dance adds a couple each figure to the total of four.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21061, '2022-08-31 21:55:11.819142+00', '2022-08-31 22:34:15.233632+00', 'Old Friends', 'OLD FRIENDS', 1, 32, NULL, 1, 3, 42, 2766, '2019-05-01', 'An old friend of Dan''s was in town.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21062, '2022-08-31 22:01:54.994141+00', '2022-08-31 22:34:47.808221+00', 'Something Different', 'SOMETHING DIFFERENT', 1, 32, NULL, 1, 102, 2, 2766, '2019-06-01', 'From an idea of starting with different couples crossed over at the start of the dance.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21057, '2022-08-31 21:30:26.973135+00', '2022-08-31 22:36:00.966699+00', 'Scream of the Cat', 'SCREAM OF THE CAT', 1, 32, NULL, 1, 2, 76, 2766, '2019-03-01', 'Our cat Edwin somehow managed to flip an S-shaped scratching board onto his back and screamed an awful scream. He wasn’t hurt (the board is not heavy).



I love the Celtic reel and wanted more dances containing it.

', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21065, '2022-09-01 10:41:02.289233+00', '2022-09-01 10:41:02.289233+00', 'Four Corners Romp', 'FOUR CORNERS ROMP', 1, 32, NULL, 1, 3, 42, 2766, '2019-07-01', 'Named because first couple visits all 4 corners in order in this dance.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21066, '2022-09-01 10:51:27.6519+00', '2022-09-01 10:51:27.6519+00', 'Dip ''n'' Dive', 'DIP N DIVE', 2, 32, NULL, 1, 3, 42, 2766, '2019-07-01', 'For the Monarch butterflies who dip and dive to the milkweed in our yard.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21067, '2022-09-01 10:55:33.312907+00', '2022-09-01 10:55:33.312907+00', 'Remnants of Barry, The', 'REMNANTS OF BARRY', 3, 32, NULL, 4, 4, 13, 2766, '2019-07-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21068, '2022-09-01 10:59:57.690328+00', '2022-09-01 10:59:57.690328+00', 'Spirit', 'SPIRIT', 1, 32, NULL, 1, 3, 42, 2766, '2019-08-01', 'Named for a favorite John Denver song.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21070, '2022-09-01 11:16:09.468815+00', '2022-09-01 11:16:09.468815+00', 'He Slept on My Heart', 'HE SLEPT ON MY HEART', 1, 32, NULL, 1, 3, 42, 2766, '2019-10-01', 'We lost our cat Christopher 10/8/19. He was about 14.5 years old and one of those special cats that come along now and then: sweet tempered and very loving – every night he slept on my left side all night. This dance is set to a happy tune since the 12.5 years we had together we were really good years.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21071, '2022-09-01 11:20:22.425509+00', '2022-09-01 11:20:22.425509+00', 'A.D.O.P.T.', 'ADOPT', 1, 32, NULL, 1, 3, 42, 2766, '2019-10-01', 'The loss of our cat Christopher made me think of long-time residents of pet shelters waiting for a home. A.D.O.P.T. is our local shelter.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21072, '2022-09-01 11:23:12.006072+00', '2022-09-01 11:23:12.006072+00', 'Chained Together', 'CHAINED TOGETHER', 2, 32, NULL, 1, 3, 42, 2766, '2019-10-01', 'I was playing with the snowball grand chain as a way to get first couple back to their own sides after a ladies'' chain.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21073, '2022-09-01 11:28:18.125921+00', '2022-09-01 11:28:18.125921+00', 'Tartan Weave', 'TARTAN WEAVE', 1, 32, NULL, 1, 4, 2, 2766, '2019-11-01', 'Toni makes beautiful cloth napkins and Gwen chose the pattern pictured. Toni challenged me to replicate the pattern in a dance.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21074, '2022-09-01 11:32:54.664396+00', '2022-09-01 11:32:54.664396+00', 'Merry & Bright', 'MERRY AND BRIGHT', 3, 32, NULL, 1, 3, 42, 2766, '2019-12-01', 'I wrote this after noticing a neighbor''s holiday bench with ''Merry & Bright'' on the back – from the song White Christmas.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21075, '2022-09-01 11:58:18.800939+00', '2022-09-01 11:58:18.800939+00', 'Soft Pretzels', 'SOFT PRETZELS', 2, 32, NULL, 1, 3, 42, 2766, '2019-12-01', 'This set of figures reminds me of pretzels. Plus I was born in Philadelphia, a city known for its soft pretzels.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21076, '2022-09-01 12:04:38.887608+00', '2022-09-01 12:04:38.887608+00', 'Iain''s Inspiration', 'IAINS INSPIRATION', 3, 32, NULL, 1, 3, 42, 2766, '2020-01-01', 'Iain Boyd posted a query on strathspey.org about a set and link for 3 couples on the sides which got me thinking about how it might work. I have no idea whether this is the same figure as the one Iain asked about, but when I danced it in my head, it occurred to me that it was the perfect setup for the 3-couple bourrel, so I had to try it out in a dance.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21077, '2022-09-01 12:10:36.560369+00', '2022-09-01 12:10:36.560369+00', 'Bookends', 'BOOKENDS', 2, 32, NULL, 1, 3, 42, 2766, '2020-02-01', 'The idea for bars 1-8 came to me and I started playing with it in my head. The rest of the dance sort of fell into place. Bookends seems to fit since there are figures of 8 at both ends.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21078, '2022-09-01 14:05:01.22138+00', '2022-09-01 14:05:01.22138+00', 'Last Farewell, The', 'LAST FAREWELL', 3, 32, NULL, 1, 3, 42, 2766, '2020-02-01', 'Named for a favorite song by Roger Whittaker.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21079, '2022-09-01 14:11:39.290725+00', '2022-09-01 14:11:39.290725+00', 'Knots and Crosses', 'KNOTS AND CROSSES', 3, 32, NULL, 1, 3, 42, 2766, '2020-03-01', 'In a class review of the knot, we did two in a row and I liked how it looked and felt.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21080, '2022-09-01 14:44:54.189866+00', '2022-09-01 14:44:54.189866+00', 'New Beginnings', 'NEW BEGINNINGS', 2, 32, NULL, 1, 3, 42, 2766, '2021-08-01', 'Celebrating dancing in a new venue after dancing at Fermilab for 25 years.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21082, '2022-09-01 15:02:55.573444+00', '2022-09-01 15:02:55.573444+00', 'Jack Meets George', 'JACK MEETS GEORGE', 2, 32, NULL, 1, 3, 42, 2766, '2021-10-01', 'This is a combination of Pelorus Jack reels with George Whitehorne''s LS half reels all 4 times in Skirl of the Royal Ghosts.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21083, '2022-09-01 15:07:43.993665+00', '2022-09-01 15:07:43.993665+00', 'Bourrel Madness', 'BOURREL MADNESS', 3, 32, NULL, 1, 3, 42, 2766, '2021-10-01', 'I wanted to try different ways to set up for the 3-couple bourrel.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21081, '2022-09-01 14:54:59.813191+00', '2022-09-08 08:50:44.990434+00', 'Albany', 'ALBANY', 2, 32, NULL, 1, 3, 42, 2766, '2021-09-01', 'Written for a favorite Roger Whittaker song.', 45, '804/840/864/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21105, '2022-09-19 07:58:26.143197+00', '2022-09-19 07:59:36.580685+00', 'In Strathspey Time, George, Please!', 'IN STRATHSPEY TIME GEORGE PLEASE', 3, 32, NULL, 1, 2, 76, 11927, '2022-08-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21107, '2022-09-19 08:05:58.521374+00', '2022-09-19 08:09:32.43102+00', 'Terrific Twelve, The', 'TERRIFIC TWELVE', 1, 40, NULL, 8, 6, NULL, 11840, '2022-07-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21084, '2022-09-01 15:12:44.278254+00', '2022-09-01 15:12:44.278254+00', '73 Is the Perfect Number', '73 IS THE PERFECT NUMBER', 3, 32, NULL, 1, 3, 42, 2766, '2021-10-01', 'In The Big Bang Theory Sheldon says that 73 is the perfect number because it is the 21st prime and the 12th prime is 37 and 3 * 7 = 21. Plus 73 is a palindrome in binary: 1001001. I wrote this dance for my 73rd birthday.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21085, '2022-09-01 15:15:51.760955+00', '2022-09-01 15:15:51.760955+00', 'Barry''s Birthday Bourrel', 'BARRYS BIRTHDAY BOURREL', 3, 32, NULL, 1, 3, 42, 2766, '2021-11-01', 'Written to celebrate Barry Robinson''s milestone birthday on the 16th.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21086, '2022-09-01 15:25:17.131134+00', '2022-09-01 15:25:17.131134+00', 'Twinkletoes', 'TWINKLETOES', 3, 32, NULL, 1, 3, 42, 2766, '2021-11-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20998, '2022-08-21 18:19:33.37433+00', '2022-09-01 16:41:02.340788+00', 'Back to Square One', 'BACK TO SQUARE ONE', 3, 32, NULL, 4, 4, 13, 11237, '2020-02-01', 'The Covid pandemic encouraged hands-free dances. During the first lockdown my number one favourite local walk included Tavistock Square in London. Unusually it has more statues of women than men and also several monuments for peace. So I kept going back to it - also in the series of subsequent lockdowns.



NB this dance is a hands-free revision of an earlier dance <<ddd:Helvellyn#20089>>.', 88, '8484/8888/4848/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21002, '2022-08-22 20:32:35.23406+00', '2022-09-01 16:43:20.061073+00', 'Nurse Dent', 'NURSE DENT', 2, 32, NULL, 1, 3, 42, 11237, '2022-05-01', 'This dance is for John Dent, a regular at Gay Gordons classes in London for many years and a participant at the Gay Gordons residential events at Laurieston Hall near Castle Douglas, Scotland. Those weeks usually included a cabaret night. One year we had several medics who produced a short shadow show of an operation going horribly wrong. John stole the show with a comic psycho performance as knife wielding Nurse Dent - an unforgettable memory of those gatherings.', 50, '880/804/804/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21087, '2022-09-01 19:56:30.447097+00', '2022-09-01 19:56:30.447097+00', 'Just a Little Jig', 'JUST A LITTLE JIG', 2, 32, NULL, 1, 3, 42, 2766, '2022-01-01', 'My mind was playing with starts to dances and came up with bars 1-8 and the rest just followed.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21088, '2022-09-01 20:00:17.620454+00', '2022-09-01 20:00:17.620454+00', 'Chain-Chain-Chain', 'CHAINCHAINCHAIN', 1, 32, NULL, 1, 3, 42, 2766, '2022-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21090, '2022-09-01 20:38:00.485203+00', '2022-09-01 20:38:00.485203+00', 'Tinkling Jade', 'TINKLING JADE', 3, 32, NULL, 1, 3, 42, 2766, '2022-06-01', 'Written in honor of the arrival of Xiaowen and Tom''s baby girl.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21091, '2022-09-01 20:42:00.399426+00', '2022-09-01 20:42:00.399426+00', 'Canadian Roots', 'CANADIAN ROOTS', 2, 32, NULL, 1, 3, 42, 2766, '2022-07-01', 'July 1st being Canada Day reminded me that I have Canadian roots (my paternal grandfather was born in Alberta and his parents ranched there).', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21069, '2022-09-01 11:11:37.990472+00', '2022-09-02 09:29:17.571883+00', 'Tunes of Glory', 'TUNES OF GLORY', 1, 48, NULL, 1, 3, 42, 2766, '2019-08-01', 'I used to play drums in a pipe band named Tunes of Glory and my favorite set was Wings followed by Cockney Jocks so when I realized this track plays them both and in that order, I had to write a dance. Since it is 48 bars it couldn’t be too much of a mind-twister.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21089, '2022-09-01 20:04:13.340376+00', '2022-09-02 09:29:53.733433+00', 'German Figure, The', 'GERMAN FIGURE', 1, 32, NULL, 1, 3, 42, 2766, '2022-03-01', 'This dance was written as an exercise in the 2- and 3-couple allemande. I looked up the translation of ''allemande'' and it came up ''German'' so I named it The German Figure. When we danced it, we realized first couple needs to really hustle to get into position for the last 8 bars.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21095, '2022-09-02 10:10:24.348131+00', '2022-09-02 10:10:24.348131+00', 'Frimley Hall', 'FRIMLEY HALL', 3, 48, NULL, 2, 3, 17, 11110, '2009-03-01', '', 72, '484/484/282/084/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17253, '2016-09-04 11:56:07.284531+00', '2022-09-02 14:28:47.763286+00', 'Poppy and the Thistle, The', 'POPPY AND THE THISTLE', 3, 32, NULL, 1, 100, 11, 598, '2015-04-01', 'The logo selected for the 50th anniversary of the Los Angeles Branch depicts the entwined stems of the California Golden Poppy and the Thistle of Scotland framed by the name of our Branch at the top, with the dates 1966-2016 at the bottom and a large 50 in the center. Bars 9-24 of the dance outline the shape of our anniversary logo.', 81, '8448/8888/8008/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (11985, '2005-01-20 23:00:00+00', '2022-09-02 22:56:32.470219+00', 'Greenmantle', 'GREENMANTLE', 3, 32, 9999, 2, 3, 17, 515, '2004-03-01', 'The title has no connection with John Buchan’s novel of the same name.  It could have some connection with the fine beer brewed by Broughton Brewery.



The notes for the dance also claim that "Broughton is the birthplace of John Buchan" however according to his <<https://en.wikipedia.org/wiki/John_Buchan|wikipedia entry>> Buchan was actually born in Perth.', 73, '800/866/866/868', 1, 1, 1, 1, 72);
INSERT INTO 'dance' VALUES (21096, '2022-09-04 08:09:47.432644+00', '2022-09-04 09:12:21.783207+00', 'Szilvia''s Summer School Birthday', 'SZILVIAS SUMMER SCHOOL BIRTHDAY', 2, 32, NULL, 1, 3, 42, 2688, '2022-08-01', 'Written for the deviser''s wife Szilvia whose birthday was during week 3 of the 2022 St Andrews Summer School.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21097, '2022-09-04 11:56:36.020467+00', '2022-09-04 11:56:36.020467+00', 'Jane McKenzie of Torphichen', 'JANE MACKENZIE OF TORPHICHEN', 1, 32, NULL, 1, 3, 42, 1500, '2022-01-01', 'Source: MiniCrib.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20921, '2022-06-25 15:32:21.076369+00', '2022-09-04 14:48:40.132881+00', '70 is Fun', '70 IS FUN', 1, 32, NULL, 101, 112, NULL, 2806, NULL, 'A very easy, fun dance for 7 people!', 54, '4408044/0088800/1118212/8888888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (19075, '2018-12-06 11:42:49.708353+00', '2022-09-04 19:02:31.145107+00', 'Half a Crown', 'HALF A CROWN', 1, 32, NULL, 1, 3, 42, 3699, NULL, 'A dance in 2 and 6 bar phrases!

Before decimalisation of UK money in 1971, a half crown was the largest value coin in common circulation, worth 2 shillings and sixpence or 1/8 of £1. This was converted into 12.5p in the new money.', 69, '888/888/808/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21098, '2022-09-04 20:27:20.273008+00', '2022-09-04 20:27:20.273008+00', 'Falling Leaves', 'FALLING LEAVES', 3, 32, NULL, 1, 3, 42, 2874, '2007-11-01', '', 47, '880/800/822/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20652, '2022-01-27 19:03:58.873468+00', '2022-09-06 14:14:11.027784+00', 'Oh to go Dancing for Perth''s 95th', 'OH TO GO DANCING FOR PERTHS 95TH', 2, 32, NULL, 1, 3, 42, 11872, NULL, 'The dance is named as "...Perth''s 95" in the table of contents but "...Perth''s 95th" on the page with the dance description. The former is added as a spelling alias.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1338, '1997-08-31 22:00:00+00', '2022-09-06 14:17:38.627953+00', 'Corbets Strathspey', 'CORBETS STRATHSPEY', 3, 32, 9999, 1, 4, 1, 755, NULL, '', 84, '8888 8448 8444 8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21100, '2022-09-06 16:53:04.993651+00', '2022-09-06 16:53:04.993651+00', 'What a Party!', 'WHAT A PARTY', 1, 32, NULL, 4, 4, 13, 3135, '2007-03-31', 'The dance was devised on the occasion of Peter and Marise van Riel''s party ''40 Years of Dancing Together'' (31 March 2007). Devised by Els van der Kamp-Grotenboers, 2007.

', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21093, '2022-09-01 20:51:31.569985+00', '2022-12-19 00:39:56.896626+00', 'Cheeky Chipmunk', 'CHEEKY CHIPMUNK', 2, 32, NULL, 1, 3, 42, 2766, '2022-07-01', 'I like the idea of diagonal rights and lefts across the set. I saw a chipmunk eating something on our deck and it totally ignored me and kept eating.', 56, '822/888/844/866', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21092, '2022-09-01 20:46:41.622692+00', '2022-09-08 11:52:57.210711+00', 'Penelope', 'PENELOPE', 3, 32, NULL, 1, 3, 42, 2766, '2022-07-01', 'Written because I wanted to try the slip knot in strathspey time and ended up with a circulating version. Named to honor a friend''s new baby girl.', 50, '800/888/880/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (16909, '2016-04-12 07:50:17.997056+00', '2022-09-08 07:30:29.393636+00', 'Mrs Gibbs of Josselin', 'MRS GIBBS OF JOSSELIN', 2, 32, 9999, 1, 3, 42, 11181, '2016-04-12', 'Dedicated to Mrs Gibbs who very often welcomes and hosts at home with great kindness and generosity the many dancers who came from various parts of Brittany to dance together periodically in Josselin.', 69, '880/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21094, '2022-09-01 20:55:18.530406+00', '2022-09-08 10:21:40.65048+00', 'Get Ready', 'GET READY', 2, 32, NULL, 1, 3, 42, 2766, '2022-08-01', 'This dance was written for a class on anticipation. It is a lively dance and definitely requires all 3 dancing couples to anticipate the next figure.', 56, '880/808/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4347, '1997-09-09 22:00:00+00', '2022-09-10 09:56:18.172685+00', 'Michealmas', 'MICHEALMAS', 1, 48, 9999, 4, 4, NULL, 719, NULL, 'This dance is named "Michealmas", which deviates from the standard English spelling "Michaelmas".  It may well be a typo, but that still remains the name.  The standard spelling is added as an alias. 

The editors of the 2019 combined edition of Imperial Books 4, 5 and More have opted to use the spelling "Michaelmas"', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2799, '1997-09-03 22:00:00+00', '2022-09-13 11:43:39.789568+00', 'Harris Tweed', 'HARRIS TWEED', 3, 32, 9999, 1, 4, 1, 135, NULL, 'From the instructions: "Harris Tweed originates in the Outer Hebrides off the west coast of Scotland. Most of the tweed is produced on one island with two names - Lewis and Harris. First produced over 150 years ago, the weaving is still based on a cottage industry of over 500 crofters who hand weave the tweed in their own homes."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6071, '1997-04-03 22:00:00+00', '2022-09-13 11:56:43.110516+00', 'Sillebawby', 'SILLEBAWBY', 3, 24, 9999, 1, 4, 1, 352, '1993-04-17', '', 58, '8800/8080/8880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6404, '1998-01-05 23:00:00+00', '2022-09-13 12:01:56.968668+00', 'Susie Ferguson Reel', 'SUSIE FERGUSON REEL', 1, 48, 9999, 1, 4, 1, 1297, NULL, 'Originally entered in SCDDB as "Susie Ferguson Centennial Reel" it seems to be called just "Susie Ferguson Reel" in the Centennial Collection book. The original database name is now an alias.



Bars 9-24 represent the petals of the fleur-de-lis for French Canada, bars 33-40 the St. Andrew''s Cross for Scotland and the music is for English speaking Canada.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6949, '1997-09-16 22:00:00+00', '2022-09-13 12:13:18.850606+00', 'Waters of Ben Lawers, The', 'WATERS OF BEN LAWERS', 1, 32, 9999, 1, 4, 1, 272, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8078, '1997-12-03 23:00:00+00', '2022-09-13 12:25:23.032006+00', 'Sam''s Reel', 'SAMS REEL', 2, 32, 9999, 1, 4, 1, 1349, '1995-01-01', 'This dance was devised to teach reels of four to beginners.  

Sam is a very active black cat. The dance retraces his path through my home the weekend I left him to attend the TAC AGM. When I returned I found that he had unwound and "reeled" a full roll of toilet tissue, plus most of a roll of paper towels! (CP) ', 55, '8888/8000/8800/8222', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8121, '1997-10-26 23:00:00+00', '2022-09-13 12:32:01.864651+00', 'Ins and Outs', 'INS AND OUTS', 1, 32, 9999, 4, 4, 13, 1445, '1996-01-01', 'From the instructions: "This dance is a memory of the lively ceilidhs we have enjoyed during the Scottish dance courses in the Kuckucksnest, very ably run by Carola Tress."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8708, '1999-08-06 22:00:00+00', '2022-09-13 12:53:17.311786+00', 'Sparkling Shores of Kamagari, The', 'SPARKLING SHORES OF KAMAGARI', 4, 64, 5, 1, 3, 42, 479, '1994-01-01', 'From the dance notes:

"The dance was devised on the occasion of the 5th Anniversary of the ''Kamagari Scottish Festival'' in Japan, 1994. Whilst swimming in the sea off Kamagari Island I noticed the sea glowing around me as I made contact with phosphorescent phytoplankton and the shoreline sparkling as the microscopic organisms were washed up on the sand."

', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18248, '2018-03-06 00:15:24.399534+00', '2022-09-13 15:19:28.334034+00', 'Jig for Jessie, A', 'JIG FOR JESSIE', 2, 40, NULL, 1, 3, 42, 11601, '2015-01-01', 'Devised for Jessie MacLachlan, who taught the Abingdon SCD Class and the Headington class in Oxford for many years.

Tune: Jig for Jessie (Vincent McCourt) (no further information available)', 50, '800/888/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12192, '2005-04-14 22:00:00+00', '2022-09-13 15:24:24.525152+00', 'Doug''s Farewell to Kenner', 'DOUGS FAREWELL TO KENNER', 1, 32, 9999, 1, 4, 11, 3554, '1995-06-01', 'Devised and danced on the occasion of Doug Davison''s retirement as principal of Kenner College, Peterborough. June 1995.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12367, '2005-04-27 22:00:00+00', '2022-09-13 15:30:45.419309+00', 'On the Banks of Shee Water', 'ON THE BANKS OF SHEE WATER', 2, 32, 9999, 1, 4, 1, 3538, '1992-01-04', 'From the notes "devised and danced for John Reeves on his 60th birthday. John''s roots are in Blairgowrie which lies at the foot of Glen Shee".', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7460, '1997-12-27 23:00:00+00', '2022-09-13 15:54:03.373807+00', 'Mingle-Mangle', 'MINGLEMANGLE', 4, 128, 2, 6, 3, 3, 434, '1995-07-01', 'Inscribed "To Peter Newman, who requested a medley for three couples in a triangular set, the dance to include schiehallion reels."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (15599, '2014-08-31 16:24:59.517541+00', '2022-09-13 16:56:46.583046+00', 'Braw Twa, The', 'BRAW TWA', 3, 64, NULL, 4, 4, 3, 2913, '2001-10-01', 'Bunty has taught Scottish Country Dancing at Montrose for over forty five years, and still going strong in 2008. The other half of the Braw Twa is Olwyne Taylor, who plays the piano for the classes.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2535, '1997-04-03 22:00:00+00', '2022-09-13 22:55:48.847548+00', 'Glenfiddich', 'GLENFIDDICH', 3, 32, 9999, 1, 3, 42, 108, '1975-02-02', 'To be checked: SCDDB currently links the tune Glenfiddich by William Marshall, but the instructions in The Reel #136 mention a tune of the same name by H Gray.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21101, '2022-09-14 08:28:54.99169+00', '2022-09-14 08:28:54.99169+00', 'Libellula', 'LIBELLULA', 1, 32, NULL, 1, 3, 42, 11225, '2021-09-01', 'Written for a young dancer of our group. She is so light and smooth dancing, that people call her Libelinha (dragonfly in portuguese).', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21102, '2022-09-14 08:31:41.540823+00', '2022-09-14 08:31:41.540823+00', 'Moonlight over the River', 'MOONLIGHT OVER THE RIVER', 3, 32, NULL, 2, 2, 76, 11225, '2021-09-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15418, '2014-04-11 19:59:49.954382+00', '2022-09-19 04:47:28.448548+00', 'Tea with Sylvia', 'TEA WITH SYLVIA', 2, 32, NULL, 1, 4, 1, 802, '2013-09-01', 'Written for Sylvia Dalkin from the Stafford & District Caledonian Society, to go with the tune Tea with Sylvia by Chris Dewhurst. Recorded on track 11 (Morland Ladies) of the CD Crossing Borders, by Chris, Julie & Nick Dewhurst.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15330, '2014-01-06 01:00:47.228995+00', '2022-09-19 06:34:26.10905+00', '14.13', '1413', 2, 32, NULL, 5, 1, 4, 3661, '2012-01-07', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (14337, '2011-12-08 23:00:00+00', '2022-09-19 06:35:30.044583+00', 'Alyth Promenade', 'ALYTH PROMENADE', 2, 32, NULL, 1, 3, 42, 9998, NULL, 'This is a variation of Goldring''s Ayr Promenade.  Documented by Charles Upton, 2006.  No source indicated.', 53, '666  666  888  800', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (13437, '2009-11-16 23:00:00+00', '2022-09-19 06:43:55.424932+00', 'Strathconon', 'STRATHCONON', 1, 32, 9999, 1, 4, 2, 10325, NULL, 'Published in the Diamond Jubilee Collection of the RSCDS Inverness and District Branch: http://my.strathspey.org/dd/publ/1027/', 81, '8008  4444  8888  4444  8448', 0, 1, 0, 0, 81);
INSERT INTO 'dance' VALUES (13424, '2009-11-10 23:00:00+00', '2022-09-19 06:47:57.197495+00', 'Hidemi''s Wedding', 'HIDEMIS WEDDING', 1, 40, NULL, 1, 4, 2, 10356, '2007-03-24', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12410, '2005-05-01 22:00:00+00', '2022-09-19 10:49:54.814008+00', 'Tribute to the Twentieth Century', 'TRIBUTE TO THE TWENTIETH CENTURY', 2, 40, 9999, 1, 4, 1, 3554, '1999-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12314, '2005-04-26 22:00:00+00', '2022-09-19 12:22:44.962557+00', 'Meikleour Beeches, The', 'MEIKLEOUR BEECHES', 3, 32, 9999, 2, 3, 17, 3538, '1994-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (6701, '2001-05-20 22:00:00+00', '2022-09-25 13:52:19.462578+00', 'Tribute to the Borders', 'TRIBUTE TO THE BORDERS', 2, 32, 9999, 1, 3, 42, 146, '1979-01-01', 'This dance is inscribed “To Alice and Joe Murphy” and is a tribute to the Carlisle and Borders Branch of the RSCDS also a recognition that the Borders are the first part of Scotland reached by travellers from the South.', 49, '800  844  843  888', 1, 1, 1, 1, 65);
INSERT INTO 'dance' VALUES (8065, '1997-09-18 22:00:00+00', '2022-09-19 13:41:59.588054+00', 'Miss Frown''s Reel', 'MISS FROWNS REEL', 1, 32, 9999, 1, 3, 42, 382, '1993-01-01', 'This is a modified version of "Miss Nancy Frowns" in reel time to practice pas de basque for a University of Alabama Birmingham Special Studies Class in September 1993.  

I have also taught the dance with 1st and 3rd couples dancing the hands across and back (not switching to 2nd couple for the left hands across). That works fine, too.', 38, '880/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21103, '2022-09-17 21:02:59.138898+00', '2022-09-26 22:23:15.25257+00', 'Reel for Freddie Stewart, A', 'REEL FOR FREDDIE STEWART', 1, 32, NULL, 3, 5, 7, 12204, NULL, 'Freddie was a keen dancer who died in a tragic kayaking incident in the Sound of Jura in April 2007 at the age of 23.', 73, '86860/84884/88888/80800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21109, '2022-09-19 13:59:32.813544+00', '2022-09-19 14:01:16.000482+00', 'Brigitte and Gaël Welcome', 'BRIGITTE AND GAEL WELCOME', 2, 32, NULL, 1, 3, 42, 11181, '2022-09-19', '', 44, '800/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21110, '2022-09-19 20:09:48.712013+00', '2022-09-20 06:48:38.45209+00', 'Five for Luck', 'FIVE FOR LUCK', 3, 32, NULL, 4, 55, NULL, 10574, NULL, 'Source: Red Thistle Dancers youtube videos (<<https://youtu.be/MObhB5LQt24>>, <<https://youtu.be/_fK0C1dXqdo>>).', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (170, '1997-04-03 22:00:00+00', '2022-09-26 22:39:05.972939+00', 'Anne Munro of Portree', 'ANNE MUNRO OF PORTREE', 2, 32, 9999, 1, 3, 42, 2130, NULL, 'The figures in the dance represent the letters A N N E.



The notes say that "The dance was devised by Dr Ellen Garvie. Anne has been the teacher ofthe Portree class since 1975 and the dance was written by Ellen in recognition ofAnne''s many hours of labour preparing for, and keeping control of the Portree class."', 52, '802/880/808/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21108, '2022-09-19 08:14:26.303314+00', '2022-09-22 12:47:55.605335+00', 'Units 2 and 3', 'UNITS 2 AND 3', 2, 32, NULL, 1, 3, 42, 12205, '2022-07-01', 'I devised this dance at the 2022 St Andrews Summer School while doing Units 2 and 3 of the RSCDS teaching certificate. The dance was devised such that the 2s and 3s are showcased representing Units 2 and 3. The vigour of the dance represents the high level of effort put in by students during the course. Each dancer dances from several positions, similar to how we have been taking the position of different dancers to demonstrate formations. That the ones are still during bars 9-24 represents spending time observing other dancers and teachers during the course. The plentiful curving and casting to change positions on the side lines was included to demonstrate good kilt control (or lack thereof)!', 63, '888/088/088/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12135, '2005-04-10 22:00:00+00', '2022-09-23 15:11:46.817839+00', 'Ardbrae Bank', 'ARDBRAE BANK', 1, 32, 9999, 1, 2, 76, 3538, '1999-01-01', 'The dances notes advise that:

*Bars 9-24 has a formation similar to the "Targe" but danced from the comers of a square formed by the original positions of the four dancers. At the end of each four bars the dancers meet their partners and the rotation is one place clockwise round the square.*



*There may be an "Ardbrae Bank" somewhere in the world. But in this instance the name is made from the letters of "Barbara" and "Ken" (Roberts) long-time and enthusiastic members of the Peterborough Scottish Country Dance Society to whom the dance is dedicated.*



May be danced as reel or jig.

', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11980, '2005-01-19 23:00:00+00', '2022-09-23 15:22:33.174978+00', 'Raspberry Ripple', 'RASPBERRY RIPPLE', 2, 32, 9999, 3, 5, 38, 1, '2003-01-01', 'From the notes: "Many of the farms around Blairgowrie derive part of their income from the cultivation of raspberries."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11822, '2004-10-21 22:00:00+00', '2022-09-23 15:47:49.645278+00', 'Wishing Tree, The', 'WISHING TREE', 3, 32, 9999, 2, 3, 18, 13, NULL, '"On Isle Maree, one of the islands in Loch Maree, there are the ruins of a chapel founded by St. Maelrubha, a sacred well and the remains of a wishing tree on which Queen Victoria fixed an offering in 1871."', 75, '808/888/484/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11816, '2004-10-21 22:00:00+00', '2022-09-23 15:54:56.159303+00', 'Fair Jennie''s Jig', 'FAIR JENNIES JIG', 2, 32, 9999, 1, 3, 42, 13, '1995-01-01', 'Inscribed "For Jennie Hamlin and Jeff Pitchers on the occasion of their marriage - 29th July , 1975."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (11785, '2004-09-08 22:00:00+00', '2022-09-23 16:09:35.020698+00', 'Molinos, Los', 'MOLINOS', 1, 40, 9999, 1, 3, 42, 108, '2003-01-01', 'Inscribed "for the Trip with JAG to Torremolinos."



Drewry also notes that "<<ddd:Five Stars>> is a 5-couple version of this dance. Dancers may choose which version they prefer."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11574, '2003-11-11 23:00:00+00', '2022-09-23 16:29:19.000996+00', 'Fifty-Fifty', 'FIFTYFIFTY', 1, 48, 9999, 4, 4, 46, 553, '2002-01-01', 'Inscribed "For Robert and Freddie Atkinson as they reach their half-century."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11455, '2003-09-22 22:00:00+00', '2022-09-23 17:12:38.558351+00', 'Gifts', 'GIFTS', 1, 32, 9999, 1, 3, 42, 2766, '2002-04-01', 'Note that the whole dance is palindromic. The figure in bars 9-24 is done 1st diagonal, 2nd diagonal, 2nd diagonal, 1st diagonal.  

The figure in bars 9-24 reminds me of bows tied on packages, thus the name ''Gifts.''', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20996, '2022-08-17 10:49:38.894825+00', '2022-09-23 18:47:44.966776+00', 'Sunday, Early in the Morning', 'SUNDAY EARLY IN THE MORNING', 3, 32, NULL, 2, 3, 17, 11778, '2022-07-31', '"During the Saturday ball at the end of the first week of Summer School in St. Andrews, I was asked if I wanted to write a dance for our tutor Rachel Shankland and for our musician George Meikle. Thus, on the following morning, at 6.30am, I started devising this dance."', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20955, '2022-07-15 22:24:15.082297+00', '2022-09-23 18:50:55.895643+00', 'Ça Va Bien Aller', 'CA VA BIEN ALLER', 1, 32, NULL, 1, 3, 42, 10568, '2022-02-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20860, '2022-05-17 22:26:24.915307+00', '2022-09-23 19:07:06.888782+00', 'Foursome and Half Reel of Tulloch', 'FOURSOME AND HALF REEL OF TULLOCH', 4, 96, 42, 105, 2, 3, 9998, NULL, 'Note that there are various versions of this dance in circulation, which tend to differ in the length of the strathspey and the reel parts. 



See also



<<ddd:Foursome and Half Reel of Tulloch, The  #7542>>. (32 S + 32 R + 64 R)



<<ddd:Foursome Reel  and Reel of Tulloch(trad. version), The #14713>>. (48 S + 88 R)



and <<https://my.strathspey.org/dd/issue/2759/|issue 2759>>. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (20147, '2020-11-14 14:25:56.169998+00', '2022-09-23 22:01:58.776717+00', 'We''ll Meet Again', 'WELL MEET AGAIN', 3, 32, 9999, 1, 3, 42, 12000, '2020-09-01', 'A video is available at 

https://drive.google.com/file/d/1oFq_JqTPwdUlTP-sWpwM-BJHJn5PEQku/view?fbclid=IwAR2O5-OpKSW92e8cwQfuV-IFgt9Cqyf3XiaCuezetqPY_c-WFXoR8kCM7CA

Video is only twice through.

Performed by Innes Scottish Country Dance Club, Auckland, New Zealand on 1 November 2020', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10009, '2001-07-25 22:00:00+00', '2022-09-30 20:10:47.765422+00', 'Pika, The', 'PIKA', 2, 32, 9999, 1, 3, 42, 11370, NULL, 'The dance was devised by Jeff Davis to be performed on the top of Pikes peak where the SDC

of Colorado set a high altitude record for Scottish Country Dancing. The author hoped there

might be enough other total idiots who would want to dance a jig as well as the planned

strathspey at that elevation. Small and rabbit-like, the Pika can be found scurrying through

the rocks at high altitude, gathering and storing the tundra grasses in little haystacks for the

coming winter.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10591, '2002-06-04 22:00:00+00', '2022-09-30 12:12:22.119625+00', 'Sarah Elizabeth''s Jig', 'SARAH ELIZABETHS JIG', 2, 32, 9999, 4, 4, 1, 316, NULL, 'From the notes: "This Dance was devised for my youngest daughter Sarah, who was born on May 31st 1992."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10476, '2002-04-19 22:00:00+00', '2022-09-30 12:20:12.713164+00', 'Chase, The', 'CHASE', 2, 32, 9999, 1, 3, 42, 1394, '1998-03-10', 'The notes suggest using the music for Miss Hadden''s Reel', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21111, '2022-09-27 10:28:39.796442+00', '2022-09-27 12:51:14.293318+00', 'Our Compliments to John Renton', 'OUR COMPLIMENTS TO JOHN RENTON', 3, 32, NULL, 2, 3, 18, 3325, '2022-08-01', 'John Renton, musician, band leader, composer and good egg living in Inveraray, reaches the milestone of

eighty years on 27 September 2022. This dance appreciates his friendship and acknowledges his great

contribution to RSCDS and SCD in general through his love of Scottish music.', 58, '800/844/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (10903, '2002-11-02 23:00:00+00', '2022-12-22 18:23:11.826658+00', 'Christine Miller''s Reel', 'CHRISTINE MILLERS REEL', 1, 32, 9999, 1, 4, 1, 725, '1997-01-01', 'Ruary writes:  The formations are: 



1. All four couples set twice and cross to partner''s place. 



2. First couple, followed by the other 3 couples, lead down the middle for 4 steps and cast back to place. 



3. First couple cross over RH and cast to the bottom of the set on the opposite side. The other three couples join hands and move up. First couple turn with the RH one and a half times to finish on their own side in 4th place. [seems to be incomplete]



Ruary also wrote:  Set twice and cross RH, and back,  lead down the middle and cast back Cross, cast and turn RH.



Originally, the last 4 bars were a half figure of eight, but by 2004 this had been changed to turn right once and a half

', 81, '8888/8888/8888/8000', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10290, '2001-12-18 23:00:00+00', '2022-09-30 12:32:15.490204+00', 'Nighean Ruadh', 'NIGHEAN RUADH', 3, 32, 9999, 1, 3, 42, 228, '2001-12-18', 'Initially for Miriam Betz, 18 December 2001; later for Miriam Betz and Georg Gesele.', 44, '880  808  800  880', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (10283, '2001-11-29 23:00:00+00', '2022-09-30 12:36:32.714882+00', 'Pond Place', 'POND PLACE', 3, 32, 9999, 5, 2, 76, 2973, '2000-05-01', 'Devised in May 2000 for Robin and Nick Knox of Pond Place, Babylon, for their first wedding anniversary.



*Balance-in-line in strathspey time: This is a formation devised by the late Milton Levy of New

York. The steps are the same as for normal strathspey setting. The hands move as follows: on the

first bar, those with left hands joined in the middle drop left hands and all, moving to the right,

join left hands under right hands and then drop right hands. Those moving into the middle of the

line join right hands. Repeat moving to the left on bar 2, joining right hands under left hands.

This is not as complicated as it sounds: the free hands simply join underneath the ‗holding hands‘

each time.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10085, '2001-09-12 22:00:00+00', '2022-09-30 20:07:41.249142+00', 'Spin Doctor, The', 'SPIN DOCTOR', 1, 32, 9999, 1, 3, 42, 108, '1999-11-01', 'The dedication reads: for Alice Maclean to cure her of the Millennium Bug.



Additional notes from *Greenburn Book 3:*



1. Spinning is permitted in bars marked with double underlining [that means in bars 1-8, 13-16 and 29-32]

1. Teviot Bridge (RSCDS Book 5 No.1) starts with 1st couple turning with the right hand two and a half times, but in that dance, they do not move down.

1. The reels of three are similar to those in Thomas Glovers Reel.

1. During the Winter Break in Aviemore, Alice said she was tired of people spinning so much in dances that they spoiled the phrasing. George Meikle suggested that they needed a spin doctor and so this dance was born. (Is the spin doctor also an obstetrician?) (Strangely, when they were told that spinning was permissible, the dancers did not spin.)', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4403, '1997-12-28 23:00:00+00', '2022-09-27 14:06:34.861407+00', 'Blue Loch, The', 'BLUE LOCH', 2, 32, 9999, 1, 2, 76, 872, NULL, 'This dance is almost identical to <<http://my.strathspey.org/dd/dance/3834/|The  Linton Ploughman>> from <<http://my.strathspey.org/dd/publication/5/|RSCDS Book 5>>, but ending with an Allemande instead of a Poussette.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13184, '2006-12-11 23:00:00+00', '2022-09-30 11:21:10.217124+00', 'Weird Sisters, The', 'WEIRD SISTERS', 1, 32, 9999, 6, 3, 17, 2766, '2006-10-01', 'Halloween falls on our regular dance night this year and we’ve been planning a party that night. Also, I am a great fan of Shakespeare and enjoy "The Scottish Play" a great deal. The title of this dance comes from a reference to the three witches in that play ("*Double, double, toil and trouble. Fire burn and cauldron bubble*.")', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (11072, '2002-12-01 23:00:00+00', '2022-09-30 11:27:40.834034+00', 'Mi Amigo', 'MI AMIGO', 2, 32, 9999, 2, 3, 17, 880, '1992-01-01', 'This dance was written in honor of our amigo, Javier Cortina, a student from Spain for two years. The

figures represent his travel from Madrid to Portland and getting to know us - Los Norteamericanos.

This dance was presented and first danced in the Vancouver, USA class in Vancouver, Washington, on

July 8, 1992.', 63, '808/800/888/804', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10968, '2002-11-18 23:00:00+00', '2022-09-30 11:29:18.075398+00', 'No Haste to the Wedding', 'NO HASTE TO THE WEDDING', 2, 32, 9999, 1, 3, 42, 671, '2001-01-01', 'For Eileen and Ralf, upon tying the knot after more than 10 years together.', 39, '800/844/844/820', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10940, '2002-11-14 23:00:00+00', '2022-09-30 11:36:11.721694+00', 'Striding Sharply Along the Edge', 'STRIDING SHARPLY ALONG THE EDGE', 3, 32, 9999, 1, 4, 2, 108, '2002-05-01', 'From the dance notes: The title of this dance comes from two famous edges in the Lake District, Striding Edge on Helvellyn and Sharp Edge on Saddleback. Both edges provide interesting routes to the summits of the fells. The name of the dance could be condensed to "Striding Sharply"!"



The dance is inscribed "for the dancers at Morland 2002".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9926, '2001-06-05 22:00:00+00', '2022-09-30 20:16:17.032713+00', 'Purple Heather Jig, The', 'PURPLE HEATHER JIG', 2, 40, 9999, 1, 100, 2, 101, NULL, 'A variation on <<ddd:White Heather Jig>> by James B Cosh.', 75, '8008/8888/8448/8888/8008', 1, 1, 0, 0, 75);
INSERT INTO 'dance' VALUES (9726, '2000-11-17 23:00:00+00', '2022-09-30 22:18:38.485603+00', 'Alice''s Strathspey', 'ALICES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2580, '1996-01-01', 'Devised "in honour of my teacher, Alice Schabram, whom I thank for her dedication and support for me over the years."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9708, '2000-11-13 23:00:00+00', '2022-09-30 22:26:49.801056+00', 'Arrival of Ian Stewart, The', 'ARRIVAL OF IAN STEWART', 2, 32, 9999, 1, 3, 42, 2818, NULL, '', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21120, '2022-10-01 08:05:39.895492+00', '2022-10-29 08:15:00.597115+00', 'Dancers of a Feather', 'DANCERS OF A FEATHER', 1, 32, NULL, 4, 4, 4, 10582, '2018-01-01', '', 97, '8888/8888/8888/7777', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21133, '2022-10-01 08:40:30.197495+00', '2022-10-21 00:11:08.115613+00', 'McTavish', 'MACTAVISH', 2, 32, NULL, 2, 3, 17, 3254, '2020-04-01', '', 92, '844/888/888/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (19975, '2020-05-12 11:47:37.750431+00', '2022-10-01 15:23:42.907555+00', 'Ho! Tom Bombadil', 'HO TOM BOMBADIL', 1, 32, NULL, 2, 3, 17, 3179, '2020-03-02', 'The _Tom Bombadil turn_:  



1st couple, giving right hands, cross, 1st man dancing above his partner while she dances under the arch made by their joined right hands and, with right hands still joined, 1st man curves clockwise while 1st woman curves anti-clockwise to finish next to each other in the centre in 1st place facing up. 1st woman has to start her anti-clockwise curve while dancing under their joined hands and 1st man has to dance past his partner before starting his clockwise curve.  



The tune, Ho! Tom Bombadil, inspired the dance. I then composed March Madness as the second tune to be used in the music set, and Ho! Tom Bombadil must be repeated to make up the three required tunes.', 46, '800/822/800/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21116, '2022-10-01 07:55:12.463722+00', '2022-10-01 13:47:57.395539+00', 'Arch, The', 'ARCH', 3, 32, NULL, 1, 4, 2, 11220, '2022-07-01', '*From the dance notes:*

This is a humble collaborative tribute of a dance and a tune for a truly great man, Archbishop Desmond Tutu, who passed away on 26 December 2021.



This dance does things in 2 and 2 and includes formations with arches as a nod to the humble man who was known as "the Arch".', 88, '8888/8888/8008/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21157, '2022-10-30 10:39:38.193822+00', '2022-10-30 10:39:38.193822+00', 'Gombey-san', 'GOMBEYSAN', 2, 32, NULL, 2, 3, 17, 12202, '2020-11-01', 'Gombey-san was a famous farmer and hunter. He was always busy working and became a main character of a

famous song for children.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21114, '2022-10-01 07:46:59.814442+00', '2022-10-12 19:53:48.387434+00', '2020: Vision Imperfect', '2020 VISION IMPERFECT', 1, 32, NULL, 1, 3, 42, 3254, '2020-01-01', '2020 ... perfect vision  

Year 2020 ... COVID-19 pandemic ... vision imperfect ', 53, '800/855/855/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18555, '2018-09-04 11:19:50.80088+00', '2022-10-01 15:09:22.983052+00', 'Elvish Affair, An', 'ELVISH AFFAIR', 2, 32, NULL, 1, 100, 2, 11520, '2018-08-01', 'Devised by Liebet Joubert, August 2018. This dance was inspired by elves from various fantasy stories.', 63, '8008/8888/8008/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21124, '2022-10-01 08:17:09.104589+00', '2022-10-01 15:18:36.98203+00', 'Fields of Gold', 'FIELDS OF GOLD', 2, 32, NULL, 1, 3, 42, 11520, '2022-02-21', 'In celebration of the Pretoria group''s golden (50th) anniversary in 2022 which coincides with the Pretoria Branch''s 40th anniversary.', 52, '884/646/282/882', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21134, '2022-10-01 08:42:37.642097+00', '2022-10-28 14:48:06.116964+00', 'Miss Hodgson''s Reel', 'MISS HODGSONS REEL', 1, 32, NULL, 1, 3, 42, 11220, '2021-01-24', '', 50, '800/888/808/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19049, '2018-11-10 13:17:49.38889+00', '2022-10-01 15:20:01.676534+00', 'Fraoch-badain', 'FRAOCHBADAIN', 3, 32, NULL, 2, 3, 18, 10582, '2018-06-01', 'Fraoch-badain is the five leaved Heather, Erica cinerea. This dance is in celebration of my wife Heather’s 50th Birthday.', 83, '808/888/888/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21121, '2022-10-01 08:08:32.022858+00', '2022-10-25 18:31:23.671382+00', 'Dancing Rainbows', 'DANCING RAINBOWS', 2, 32, NULL, 1, 100, 2, 11520, '2022-06-24', '', 97, '8888/8668/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21131, '2022-10-01 08:35:28.589525+00', '2022-10-01 15:34:12.20784+00', 'Ladies and Gentle-Hobbits', 'LADIES AND GENTLEHOBBITS', 3, 32, NULL, 2, 3, 18, 11520, '2018-12-16', 'Inscribed "For my father, Wouter Joubert, without whom I would never have started dancing."', 75, '484/484/888/880', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21127, '2022-10-01 08:25:03.010861+00', '2022-10-29 17:12:19.562573+00', 'Here be Dragons', 'HERE BE DRAGONS', 2, 32, NULL, 1, 3, 42, 3254, '2022-05-01', '', 53, '880/840/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21142, '2022-10-01 09:06:55.743895+00', '2022-10-09 07:02:07.276521+00', 'Winter Rose, A', 'WINTER ROSE', 1, 40, NULL, 1, 100, 2, 3179, '2018-04-01', 'In honour of Anne Naylor who has been an active branch member for many years. Anne''s southern hemisphere mid-winter birthday was the inspiration for the title. ', 79, '7007/8888/0880/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18275, '2018-04-05 11:56:36.756662+00', '2022-10-10 15:42:48.02077+00', 'Dancing Dragons', 'DANCING DRAGONS', 2, 32, NULL, 2, 3, 17, 11520, '2017-08-18', 'Devised by Liebet Joubert, 18 August 2017.



This dance was inspired by Daenerys Targaryen’s three dragons – Drogon, Rhaegal, and Viserion – from Game of Thrones. I tried to mimic the dragons in flight with the formations that I used and I decided that I had to use the snake pass, since dragons are reptilian and sometimes portrayed as serpentine.', 77, '800/888/468/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21138, '2022-10-01 08:54:36.927242+00', '2022-10-09 16:18:06.517821+00', 'Scotties Dancing', 'SCOTTIES DANCING', 1, 32, NULL, 1, 4, 11, 11220, '2019-01-01', '', 81, '8008/8888/8888/8448', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20665, '2022-02-16 01:47:36.145844+00', '2022-10-01 18:04:25.767287+00', 'Platinum Reflections', 'PLATINUM REFLECTIONS', 2, 40, NULL, 2, 3, 18, 3179, '2022-02-13', 'Devised by Wouter Joubert, 13 February 2022, in honour of the platinum Jubilee of Her Majesty, Queen Elizabeth II. The tune suggests pleasant reflection rather than processions, pomp and ceremony – hence the title.', 60, '804/808/480/844/880', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21136, '2022-10-01 08:48:29.423366+00', '2022-10-06 09:47:44.055925+00', 'Peter''s LMP', 'PETERS LMP', 1, 64, NULL, 4, 4, 3, 10582, '2017-01-01', 'This dance was devised for Peter Macfarlane in celebration of his Lemon Meringue Pie which certainly is the finest that we have ever tasted.', 75, '8888/8080/8888/8080', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21113, '2022-10-01 07:42:59.729663+00', '2022-10-01 21:12:57.768556+00', '20 in 2020', '20 IN 2020', 2, 32, NULL, 2, 3, 17, 11520, '2020-11-19', 'In honour of the 20th birthday of Stefan Naudé, a good friend, who joined us for dancing a few times this year before the Lockdown. ', 83, '844/888/844/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21132, '2022-10-01 08:38:28.966789+00', '2022-10-02 07:51:37.320711+00', 'Mary Fraser MBE', 'MARY FRASER MBE', 3, 32, NULL, 1, 4, 1, 10582, '2019-01-01', '', -1, '', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (21123, '2022-10-01 08:15:20.957879+00', '2022-10-10 16:36:04.643421+00', 'Fee Fi Foh', 'FEE FI FOH', 3, 32, NULL, 2, 3, 17, 11356, '2020-03-01', 'Inspired by the tune that Wouter posted on the Strathspey Mailing List where he linked the Coronavirus to the giant from Jack and the Beanstalk.', 67, '880/800/888/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21126, '2022-10-01 08:22:57.808626+00', '2022-10-25 18:12:47.545776+00', 'Give Me Five', 'GIVE ME FIVE', 1, 32, NULL, 4, 5, 35, 10853, '2022-01-01', '', 60, '22228/44448/88888/44422', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21117, '2022-10-01 07:57:31.006808+00', '2022-10-24 22:09:49.44236+00', 'Be Prepared', 'BE PREPARED', 1, 32, NULL, 1, 3, 42, 10582, '2019-01-01', 'This dance was devised to celebrate the 70th birthday of Jean Dunn. Aside from being a dancer, Jean is also a Regional Commissioner for the Girl Guides, hence the dances title.  



In this dance, you always need to be prepared for what comes next. The half diagonal reels represent the petals of the Guide Trefoil and in the last two bars you will see the lady "guiding" her partner home. ', 56, '880/888/844/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21125, '2022-10-01 08:18:59.771098+00', '2022-10-28 14:11:31.498378+00', 'Fond Memories', 'FOND MEMORIES', 2, 32, NULL, 2, 3, 18, 11520, '2021-06-26', '', 71, '804/800/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21119, '2022-10-01 08:03:04.053587+00', '2022-10-28 18:57:41.299799+00', 'Call of the Coucal, The', 'CALL OF THE COUCAL', 3, 32, NULL, 1, 4, 1, 11220, '2022-02-01', '', 78, '8080/8888/8888/8282', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21130, '2022-10-01 08:33:22.641879+00', '2022-10-28 19:44:00.339511+00', 'Key to the Future', 'KEY TO THE FUTURE', 2, 32, NULL, 1, 3, 42, 3254, '2018-01-01', '', 50, '840/822/844/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21182, '2022-11-27 11:46:22.954163+00', '2022-11-27 11:46:22.954163+00', 'Loch Fitty Jig', 'LOCH FITTY JIG', 2, 32, NULL, 1, 3, 42, 11753, '2021-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16774, '2015-10-01 10:31:57.760768+00', '2022-10-01 18:11:56.260441+00', 'Road to McGregor, The', 'ROAD TO MACGREGOR', 3, 32, 9999, 1, 4, 1, 10582, '2013-09-01', 'McGregor is a small town in South Africa''s Cape Winelands. The town has firm Scottish roots, and even has its own SCD club. An excellent road leads to McGregor, it carries on through the heart of the village and then... stops. The Road to McGregor could in fact be described as the Road to Nowhere. 



This dance was devised to celebrate a dancing weekend in McGregor.

', 75, '8080/8888/8484/8484', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19638, '2019-09-09 21:07:30.432888+00', '2022-10-01 18:23:55.633577+00', 'Spokane Rainbow, The', 'SPOKANE RAINBOW', 3, 32, NULL, 1, 4, 1, 10582, '2018-01-01', 'On our first day in Spokane WA, my wife Heather and I saw a beautiful rainbow while driving back into town after a visit to Coeur d’Alene. On the second day we saw a rainbow in the Spokane falls. On day three we went dancing with the Spokane SCD group, and I overheard a conversation among some of the dancers about how lovely it would be to have a 7 couple set with each couple dressed in a different one of the rainbow colours – we were 7 couples on the floor at the time.  



This dance has been devised for the Spokane Scottish Country Dance group, with thanks for a lovely evening of dancing, and to remember the rainbow which has become one of the symbols of our visit to Spokane.  



Note : This dance has been devised as a 4 couple dance to minimize the number of dancers required, but has been written in such a way that should the need arise, it can be danced in a 7 couple, rainbow coloured set by the 1st as well as 4th couples beginning. In this case it becomes a 7x32 bar dance.



*Note:  In the instructions, the title says it is a 3C/4L dance, but the description is for a 4C/4L dance.*', 62, '8880/8660/8088/8004', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9638, '2001-05-03 22:00:00+00', '2022-10-01 19:07:57.650142+00', 'Miss Johnstone of Ardrossan', 'MISS JOHNSTONE OF ARDROSSAN', 1, 32, 9999, 3, 5, 16, 146, '2000-01-01', '##>>

A dance by <<ddp:Goldring, Roy|Roy Goldring>> for <<ddp:Johnstone, Muriel A|Muriel Johnstone>> who grew up in Ardrossan on the North Ayrshire coast.

##<<', 45, '80400  80088  88800  80004', 1, 1, 1, 1, 45);
INSERT INTO 'dance' VALUES (9686, '2001-10-23 22:00:00+00', '2022-10-02 11:51:00.929664+00', 'Tri Fichead', 'TRI FICHEAD', 2, 32, 9999, 1, 3, 42, 2892, NULL, 'From the dance notes: "Tri Fichead (pronounced. tree feeket) is the gaelic for 60. The dance was written to celebrate the 6th birthday of Cathy - a dancer in the Fortrose class. Bars 17-24 describe a 6 and bars 25-32 a 0."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9682, '2001-10-23 22:00:00+00', '2022-10-02 11:54:38.757291+00', 'Leasowe Castle', 'LEASOWE CASTLE', 1, 32, 9999, 3, 5, 7, 2892, NULL, 'From the dance notes: ''This is a castle in Wallasey, Wirral, near Liverpool. It was once a sporting residence for the Earls of Derby and there is a local belief that the first "Derby" was run on Leasowe Race Course. Latterly it has been used as a convalescent home and then an hotel and conference centre.''', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9537, '2000-07-01 22:00:00+00', '2022-10-02 12:00:27.69573+00', 'Follow the Piper', 'FOLLOW THE PIPER', 1, 32, 9999, 1, 4, 1, 1253, '1995-01-01', '', 48, '8222  8000  8440  8466', 1, 1, 0, 0, 48);
INSERT INTO 'dance' VALUES (9386, '2000-04-11 22:00:00+00', '2022-10-02 12:02:53.718931+00', '25th Reel, The', '25TH REEL', 1, 32, 9999, 1, 4, 1, 2721, '1985-01-01', 'Fomr the dance notes:

"Alan and Lydia Smith founded the Concord, Massachusetts, Scottish Country Dance group in 1960. They wrote this dance for the Twenty-fifth Anniversary Ball in 1985, and Ed Pearlman composed the title tune and played for that occasion. The Concord group became a Boston Branch class in 1989 and now meets in Weston, Massachusetts."', 64, '8066/8860/8000/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9100, '1999-08-05 22:00:00+00', '2022-10-02 12:44:15.019241+00', '96 Ten, The', '96 TEN', 1, 32, 9999, 3, 5, 7, 727, '1996-01-01', 'From the dance notes:

For the 1996 first fortnight Certificate Class at Summer School. (It was the first Summer School class to be held for both Certificates together.) This was a happy group of three Full Certificate and seven Preliminary Test candidates.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9096, '1999-08-05 22:00:00+00', '2022-10-03 08:46:47.553187+00', 'New Brudenell Jig, The', 'NEW BRUDENELL JIG', 2, 32, 9999, 1, 4, 1, 727, NULL, 'This dance is not to be confused with the <<ddd:Brudenell Jig>>, also by Brenda Burnell, published by the RSCDS in <<ddpub:Second Book of Graded Scottish Country Dances, A>>.



The dance is named after the Brudenell Evening Institute, Leeds, UK.  The deviser''s husband taught Scottish Country Dancing there, and eventually became head of the Brudenell Evening Centre.



(This information is taken from the note at the end of the description of this dance in the 35th Silver Thistle Collection)', 59, '4444/4444/4884/8444', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20900, '2022-06-23 18:13:30.909225+00', '2022-10-03 18:38:10.181958+00', 'NHS Hero', 'NHS HERO', 2, 32, NULL, 1, 3, 42, 11961, '2021-01-01', 'This dance is dedicated to Linda Williamson who worked for NHS Scotland as a nurse throughout the Covid 19 Pandemic. During the first lockdown members of the public thanked the NHS by clapping on their doorsteps at 8pm on Thursday evenings. Bars 1-8 represent this with the claps.', 53, '444/880/888/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13476, '2009-11-20 23:00:00+00', '2022-10-03 22:27:06.103856+00', 'Bobby and Kobby', 'BOBBY AND KOBBY', 1, 32, 9999, 1, 3, 42, 3783, NULL, 'Inscribed "for Greyfriars Bobby of Edinburgh".



The instructions describe this as a 32 bar dance for three couples in a four couple set. However the 2nd time through is slightly modified, so the dance can also be considered as a 64 bar dance for four couples in a four couple set.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19639, '2019-09-09 21:12:11.909551+00', '2022-10-09 14:57:49.873773+00', 'Reel Numbers', 'REEL NUMBERS', 3, 32, NULL, 1, 4, 1, 10582, '2019-04-01', 'This dance is for Christopher Gilmour and Fiona McCutcheon in celebration of their 70th birthdays in 2019.  



This dance recognizes their contribution to dancing in Cape Town at club as well as RSCDS Branch level. They are both members of the Lynfrae “Reel Eight” Committee, Chris in role of Chair and Fiona as Treasurer. They additionally serve on the RSCD Branch Committee with Fiona as the current Secretary.  



They both enjoy numbers and teaching others things mathematical. Chris is Emeritus Professor at University of Cape Town having spent 42 years in the Department of Mathematics and Applied Mathematics before retiring in 2014. Fiona holds a Bsc (Hons.) Mathematics and currently coaches high-school maths.  



The dance portrays a sequence of real numbers starting with 1 couple then 2s joining in then progressively including the 3s and 4s.

The name “Reel Numbers” (and not “Real Numbers”) in intentional and not a typo as Chris is fond of word play.  

', 59, '8000/8800/8884/8448', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21158, '2022-10-30 10:48:03.404424+00', '2022-10-30 10:48:03.404424+00', 'Burns Club', 'BURNS CLUB', 3, 32, NULL, 2, 3, 18, 10356, NULL, 'Devised in memory of the late Mr. Hidenobu Katsuzaki, the founder of Burns Club in Kanazawa city. He was the excellent teacher of Scottish Country Dance in Japan.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21115, '2022-10-01 07:49:14.476135+00', '2022-10-12 20:10:11.552049+00', '5000', '5000', 1, 32, NULL, 3, 5, 33, 10951, '2020-03-27', 'Devised by Keith Rose, 27 March 2020, to mark the occasion of drawing his 5000th dance diagram since he started at the end of 1991.', 80, '84840/88888/84866/88862', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21183, '2022-11-27 11:51:51.593005+00', '2022-11-27 11:51:51.593005+00', 'Margo''s Medley', 'MARGOS MEDLEY', 4, 128, 2, 4, 4, 14, 11753, '2019-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4734, '1997-04-03 22:00:00+00', '2022-11-27 16:20:08.454465+00', 'Mrs Annette Cameron', 'MRS ANNETTE CAMERON', 2, 32, 9999, 1, 3, 42, 418, NULL, 'Inscribed "To Mrs. Annette Cameron of Boronia, Victoria."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4602, '1998-11-14 23:00:00+00', '2022-11-27 17:26:00.723155+00', 'Misses Farrell of Alloa, The', 'MISSES FARRELL OF ALLOA', 3, 32, 9999, 1, 3, 42, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Miss E. and Miss K. Farrell of Alloa.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21233, '2023-01-04 22:51:07.217996+00', '2023-01-04 22:51:07.217996+00', 'All Cackle and No Eggs', 'ALL CACKLE AND NO EGGS', 3, 40, NULL, 1, 4, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9204, '2002-03-04 23:00:00+00', '2022-10-04 01:56:47.690757+00', 'Dragon, The', 'DRAGON', 1, 32, 9999, 1, 3, 42, 108, '1998-05-01', 'I dreamed up this dance while driving down to Morland (near Penrith in Cumbria) at the end of May for the Morland Scottish Dancing Week.  

The entry into the reel of four from the left hands across is similar to that in "Dream Maker".  

The "Dragon" in the title could come from my recent trip to Japan, where there are many dragons. There is a famous temple in Kyoto which has a dragon painted on the ceiling. The dragon''s eye is in the middle of the ceiling and, no matter where you stand, the dragon''s eye is always looking at you. I was given a silk kimono bath robe with dragons printed on it. The title could also come from Morland where the landlady of the local hostelry used to be called "The Dragon". Sadly, the Dragon''s Pub has now been closed, leaving only one

hostelry in the village.', 45, '811/844/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21141, '2022-10-01 09:03:43.323164+00', '2022-10-04 10:00:11.82343+00', 'Sylvia Miskoe''s Strathspey', 'SYLVIA MISKOES STRATHSPEY', 3, 32, NULL, 1, 3, 42, 3179, '2018-04-01', 'For Sylvia Miskoe of Concord, New Hampshire.  



When I started composing music for SCD I had a million queries and Sylvia was one of those wonderful people who listened to my many questions and provided answers and explanations, who played my creations and gave feedback and advice.  



In 2004 I wrote her a tune to express my gratitude. Fourteen years later I would like to add a dance to that tune. ', 52, '880/833/822/888', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21143, '2022-10-04 10:51:53.687337+00', '2022-10-04 10:51:53.687337+00', 'Symbols used in Keith Rose diagrams', 'SYMBOLS USED IN KEITH ROSE DIAGRAMS', 99, 0, NULL, NULL, NULL, NULL, 10951, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8861, '1998-12-16 23:00:00+00', '2022-10-04 18:21:16.010017+00', 'Hand-in-hand we''ll go', 'HANDINHAND WELL GO', 2, 32, 9999, 1, 3, 42, 2018, '1998-01-01', '', 62, '844  888  844  888', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (21140, '2022-10-01 08:58:50.456455+00', '2022-10-04 11:10:51.270357+00', 'Sophie and the Dance of Life', 'SOPHIE AND THE DANCE OF LIFE', 1, 32, NULL, 1, 3, 42, 3179, '2020-04-06', 'Sophie Thompson, the granddaughter of a friend, was born on 30 March 2020, during the Covid-19 pandemic. I wrote her a tune. Often during this time of crisis I thought about the wonder of living so I decided that Sophie''s tune also needed a dance to celebrate life, Sophie''s life in particular hut also life on a broader scale. ', 63, '844/888/888/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9090, '2000-05-21 22:00:00+00', '2022-10-04 13:29:42.396168+00', 'Lady Peak''s Strathspey', 'LADY PEAKS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 108, '1998-09-01', 'Lady Peak is in the Fraser Valley just east of Vancouver.', 53, '840  844  844  888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (4102, '2002-01-08 23:00:00+00', '2022-10-04 17:54:58.439443+00', 'Mairi''s Wedding', 'MAIRIS WEDDING', 1, 40, 9999, 1, 3, 42, 87, '1959-01-01', '##>> This is considered by many to be the archetypal dance created to an already well known tune, in this case The Lewis Bridal Song.

## The words of the song *Mairi’s Wedding* were added by Sir Hugh S Robertson, founder of the 

## Glasgow Orpheus Choir. There is also a Gaelic song version with words by John Bannerman.

##<<



John Roderick (Johnny) Bannerman (1865-1938) from South Uist wrote the original Gaelic words of the song in 1935, for 1934 National Mod gold medalist singer Mary C. MacNiven of Portnahaven, Islay. Mary''s actual wedding (to sea captain John Campbell) didn''t take place until 1941. Sir Hugh S. Roberton (1874-1952), founder of the acclaimed Glasgow Orpheus Choir and a leading choir master of the time, came up with the well-known English lyrics – only very loosely related to Bannerman''s Gaelic ones – in 1936. Mary had been born in 1905 and passed away on 25 March 1997, at age 91.

(See <<http://www.heraldscotland.com/sport/spl/aberdeen/mary-c-macniven-1.405082|Mary''s obituary>>.)



On dance programmes, the »Mairi« in the title of the dance is often spelled »Mhairi«. This does look vaguely more »Gaelic« but would have to be pronounced »VAA-ri«. It would also be grammatically incorrect.



As a common variant,  some dancers pass by the right between the diagonal half-reels of four (contrary to the express wishes of the author, James Cosh). This variant has the nickname »Mairi''s Divorce«, which is a bit disrespectful as the real Mary never divorced. In 1998 Angus Henry somewhat jokingly »devised« and <<http://www.users.on.net/~anguka/mairi.pdf|published>> the

right-shoulder variant using that nickname.



Since the pass only involves the first couple, they can choose the shoulder as they wish at each pass

without disturbing the rest of the set.

', 55, '800/844/844/888/888', 1, 1, 1, 1, 73);
INSERT INTO 'dance' VALUES (8732, '1998-07-12 22:00:00+00', '2022-10-04 18:42:58.644514+00', 'Colonel, The', 'COLONEL', 2, 40, 9999, 1, 3, 42, 2204, '1740-01-01', 'Bars 25-26 now read "... pass by the right to face first corners".  Published in Scottish Country Dancer #20, April 2015.', 50, '800  888  888  822  822', 1, 1, 0, 1, 66);
INSERT INTO 'dance' VALUES (8714, '1998-04-01 22:00:00+00', '2022-10-04 18:49:53.376079+00', 'Manchester Medley', 'MANCHESTER MEDLEY', 4, 64, 17, 4, 4, 4, 479, '1993-09-01', 'Dedicated to the Manchester Branch.



The original description is named "Manchester Medley".  SCDDB also has a (S64+R64) medley called "A Manchester Medley", by an unknown deviser.  It is quite possible that to distinguish the two medleys _this_ dance was nicknamed "T'' Other Manchester Medley"; it was originally entered in SCDDB under that name.  That name has now been added as an alias.



', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8683, '1998-03-31 22:00:00+00', '2022-10-04 18:51:24.607885+00', 'Knotted', 'KNOTTED', 1, 32, 9999, 1, 2, 76, 2113, NULL, '', 45, '72  72  80  88', 0, 1, 1, 0, 65);
INSERT INTO 'dance' VALUES (21024, '2022-08-30 18:26:34.537329+00', '2022-10-04 18:58:03.025394+00', 'Fairy Feather, The', 'FAIRY FEATHER', 1, 32, NULL, 1, 3, 42, 12201, '2021-01-01', 'The deviser gave the club a nickname ''Feather Tartan'' in wishing to dance like a celestial maiden wearing a heavenly robe of feathers. "Fairy Feather" is a silk fabric created with an image of a celestial feather robe.', 66, '888/888/822/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (8206, '1997-12-27 23:00:00+00', '2022-10-04 20:42:21.829566+00', 'Sally''s Army', 'SALLYS ARMY', 2, 32, 9999, 2, 3, 17, 11253, '1996-02-01', 'From the notes:

This dance was devised by Isobel Eaton in February 1996 when a new class commenced in the Salvation Anny Citadel. Hence the name "Sally''s Army". With the Captain''s blessing it was danced publicly forthe first time at their Church Parade in March 1996.



Isobel''s suggested music (Chippy''s Rant) may no longer be available as it is from a very old recording. Another possible tune might be: Two of the Best, Craigellachie Band "Reel Friends" AD 010', 58, '880/804/804/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21139, '2022-10-01 08:56:29.252751+00', '2022-10-05 12:26:23.69982+00', 'Serenity', 'SERENITY', 3, 32, NULL, 2, 3, 17, 3254, '2020-10-01', 'This dance is dedicated to Christopher Duigan, one of South Africa''s leading concert pianists, whose twice-weekly livestream concerts from his home studio in Pietermaritzburg, KwaZulu-Natal, South Africa, were my link to sanity and serenity during the long and lonely months of aloneness in the COVJD-19 pandemic lockdown (27 March 2020 to 4 April 2022) and continue to be an immense source of joy for me.', 69, '840/886/880/808', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21153, '2022-10-25 23:05:18.568021+00', '2022-10-30 12:35:50.965097+00', 'Richmond''s Platinum Celebration', 'RICHMONDS PLATINUM CELEBRATION', 2, 32, NULL, 1, 4, 1, 11793, '2022-01-01', 'Devised for the 70th anniversary of the Richmond Branch (North Yorkshire).



Source: youtube video <<https://youtu.be/SK8gIrSRt5k>> and <<https://www.rscds-richmondnorthyorks.org.uk/videos>>.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21184, '2022-11-27 11:54:50.718182+00', '2022-11-27 11:54:50.718182+00', 'Siller in the Auld Grey Toun', 'SILLER IN THE AULD GREY TOUN', 3, 32, NULL, 1, 3, 42, 12212, '2015-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4537, '2002-03-03 23:00:00+00', '2022-11-27 17:50:30.710083+00', 'Miss MacPherson of Scone', 'MISS MACPHERSON OF SCONE', 3, 32, 9999, 1, 4, 11, 10407, NULL, 'Inscribed "For Miss Mary Macpherson, teacher of Scone Country Dance Club 1946 - 1986."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8840, '2000-06-04 22:00:00+00', '2022-12-19 16:37:46.622462+00', 'Jessie Stuart''s Reel', 'JESSIE STUARTS REEL', 1, 48, 9999, 1, 3, 42, 2419, NULL, '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21234, '2023-01-04 22:52:42.234148+00', '2023-01-04 22:52:42.234148+00', 'Bloorlea Bliss', 'BLOORLEA BLISS', 1, 32, NULL, 1, 4, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21145, '2022-10-05 17:36:24.4891+00', '2022-10-05 17:36:24.4891+00', 'Eight, Eight, Eight', 'EIGHT EIGHT EIGHT', 1, 32, NULL, 1, 4, 1, 523, '2022-09-01', 'This is a modified version of Jean Shaw’s ''<<ddd:Figures of Eight#18474>>'' which is more suitable for beginners who haven’t yet learned the setting step.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21118, '2022-10-01 08:00:10.485439+00', '2022-10-13 07:57:42.372709+00', 'Bonsoir Roland', 'BONSOIR ROLAND', 3, 32, NULL, 1, 3, 42, 3179, '2021-01-29', 'Devised by Wouter Joubert, 29 January 2021, for Roland Telle of the E-cribs team.  

As l lay awake in the early hours of the morning, stressing about my upcoming 12 hour online exam, this dance finally came together. The early morning insspiration and the fact that Roland and l usually correspond late at night via email inspired the title of the dance. ', 50, '880/888/800/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21137, '2022-10-01 08:51:28.433207+00', '2022-10-07 07:03:31.386194+00', 'Reel for Bessie, A', 'REEL FOR BESSIE', 1, 32, NULL, 1, 3, 42, 3179, '2019-10-17', 'Bessie Keun has been my accompanist and a friend since my university days. She is an excellent musician, has the patience of Job, seems to manage a 26 hour day with a smile but above all, she has a heart of gold. ', 44, '800/844/844/844', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2830, '1997-04-03 22:00:00+00', '2022-10-11 14:46:10.478485+00', 'Heart of Midlothian, The', 'HEART OF MIDLOTHIAN', 1, 32, 9999, 3, 5, 7, 313, NULL, 'The old Edinburgh Tolbooth, "The Heart of Midlothian", was for many years a prison for debtors and criminals. Demolished in 1817, its site is marked in the causeway by a heart-shaped design.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21122, '2022-10-01 08:10:59.625936+00', '2022-10-13 07:04:27.206122+00', 'Elephants Dancing on Tip-Toes', 'ELEPHANTS DANCING ON TIPTOES', 1, 64, NULL, 4, 4, 54, 10582, '2019-01-01', 'This dance is dedicated to Isabel Walker on the occasion of her 70th birthday. In her youth, Isabel was trampled by an African elephant, and was fortunate to survive the incident. I think that the elephant never meant to harm her, and when I heard the story, I had a picture in my mind of the elephant delicately doing its version of a sword dance over terrified Isobel, hence the title. In recent years Isobel has enjoyed cycling, and so you will see wheels and a chain in the dance.  



To make up the 64 bars, and to accommodate the Schiehallion reels, the composer suggests that the tune be played ABABCABC. ', 88, '8888/8888/8080/8888/8888/8484/8888/8484', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21148, '2022-10-05 19:39:33.493693+00', '2022-10-07 21:51:37.317898+00', 'Kyleside Belvedere', 'KYLESIDE BELVEDERE', 3, 40, NULL, 2, 3, 17, 10240, '2020-11-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21147, '2022-10-05 19:38:00.630504+00', '2022-10-07 21:54:04.242943+00', 'Jill''s Purple Party', 'JILLS PURPLE PARTY', 1, 32, NULL, 1, 3, 42, 10240, '2020-08-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20674, '2022-03-01 00:13:34.366025+00', '2022-10-09 11:08:57.939669+00', 'Blue Sky, Yellow Sun', 'BLUE SKY YELLOW SUN', 3, 32, NULL, 1, 114, 2, 11237, '2022-02-26', 'This dance was written the Saturday after the invasion of Ukraine. In London the weather was fine. I went out walking but kept thinking of those suffering far away. The combination of the yellow sun in a pale blue sky reminded me of the Ukrainian flag which gave me the title.



Later, Wouter Joubert kindly offered his tune *<<ddt:And when it rains...#14702>>* which he has dedicated "in support of peace and to all those who are bullied by tyrants".



Wouter has made a 4x32 recording of this (with three other tunes) which is available via <<https://my.strathspey.org/u/murrough/recording/>>.', 81, '8888/0880/8888/4884', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10847, '2002-09-26 22:00:00+00', '2022-10-14 19:44:17.334791+00', 'Platinum Jig', 'PLATINUM JIG', 2, 32, 9999, 7, 3, 17, 3193, NULL, '75th Anniversary is either Diamond or Platinum. As most people know 60 years as Diamond the decision was made to call this dance Platinum Jig. [from the publication]', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8199, '1999-12-19 23:00:00+00', '2022-10-14 19:57:32.780679+00', 'Brook, The', 'BROOK', 2, 32, 9999, 1, 3, 42, 59, '1987-01-01', '', 44, '844  822  822  880', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (6704, '1997-04-03 22:00:00+00', '2022-11-01 18:11:37.638562+00', 'Trim the Velvet', 'TRIM THE VELVET', 1, 32, 9999, 1, 3, 42, 44, '1969-06-11', 'Devised on Wednesday 11th June, 1969. The title is that of an Irish reel.

 

Both Noeline and Iain enjoy "The Montgomerie''s Rant". Those who are not familiar with the terminology ''third and fourth corners'' should read Harry Ways letter published in the March 1985 issue of TACTALK or the note published in the 1986 issue of "The New Zealand Scottish Country Dancer", page 14.



Recommended tune "The Fair Maid of Perth" played AABB.', 58, '888  888  844  822', 1, 1, 0, 1, 79);
INSERT INTO 'dance' VALUES (8176, '2002-04-08 22:00:00+00', '2022-10-14 20:02:59.434274+00', 'Peggy''s Joy', 'PEGGYS JOY', 2, 32, 9999, 1, 3, 42, 1235, '1989-01-01', 'Dance devised by Margaret Waddell in 1989 and dedicated to Mrs. Margaret Spouse of Duns - known to all as Peggy.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (8103, '2002-12-16 23:00:00+00', '2022-10-14 20:24:21.508878+00', 'Hastings Welcome, A', 'HASTINGS WELCOME', 1, 32, 9999, 1, 4, 1, 1502, '1997-01-01', 'From the dance notes: This dance was written in appreciation of the fantastic welcome Bill received on stepping onto the platform of Hastings station (New Zealand). He was met by dancers (led by Val Mitchell) and a piper and was given royal treatment during his visit.', 70, '5552  5552  8880  8888', 1, 1, 1, 1, 70);
INSERT INTO 'dance' VALUES (8046, '1997-12-03 23:00:00+00', '2022-10-14 22:17:00.555221+00', 'Dinna Fouter', 'DINNA FOUTER', 2, 32, 9999, 5, 2, 76, 146, NULL, '"Dinna Fouter" means don''t hang around, don''t shilly-shally and keep moving. (RG)', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7941, '1997-09-14 22:00:00+00', '2022-10-14 22:18:59.076875+00', 'Sgurr Alasdair', 'SGURR ALASDAIR', 1, 32, 9999, 3, 5, 16, 146, NULL, 'Inscribed "For Alastair MacFadyen."



Sgurr Alasdair is the highest peak in the Cuillin of Skye.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (20032, '2020-06-23 14:41:14.995465+00', '2022-11-22 10:01:50.711979+00', 'Mystic Knot, The', 'MYSTIC KNOT', 4, 160, 10, 4, 4, 13, 11570, '2019-12-01', 'Dedicated to Anika Lange, my chosen sister.', 100, '8888/8888/8888/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21151, '2022-10-16 21:16:48.435587+00', '2022-11-03 12:57:03.115765+00', 'Incursion of Weasels, An', 'INCURSION OF WEASELS', 2, 32, NULL, 1, 3, 42, 11237, '2020-03-01', '', 83, '800/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (20956, '2022-07-15 22:26:55.565542+00', '2022-11-30 23:23:05.10915+00', 'Stone Mountain Golden Gala Reel', 'STONE MOUNTAIN GOLDEN GALA REEL', 1, 40, NULL, 4, 4, 13, 10568, '2022-10-01', 'There is also a video at <<https://rscds-atlanta.org/wp-content/uploads/2022/08/Video_1.mov>>', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19848, '2020-02-19 22:39:02.420703+00', '2022-12-04 10:37:34.640979+00', 'Salute to Bill Hamilton', 'SALUTE TO BILL HAMILTON', 2, 32, NULL, 1, 4, 1, 743, '2019-01-01', 'Devised by Alex Milligan and friends in 2019 to recognise the work and commitment by Bill Hamilton to promote the enjoyment of Scottish Country Dancing over the last 60 years.', 78, '8888/8080/8888/4484', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21146, '2022-10-05 19:36:30.54497+00', '2022-12-04 18:06:56.791734+00', 'Anne Marshall''s Jig', 'ANNE MARSHALLS JIG', 2, 32, NULL, 1, 3, 42, 2887, '2021-01-01', '', 56, '800/844/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1056, '1997-04-03 22:00:00+00', '2022-12-18 20:22:18.016213+00', 'Carswellian Revel, The', 'CARSWELLIAN REVEL', 2, 32, 9999, 1, 4, NULL, 190, '1974-12-01', 'The author says in the sheet: "To Barbara Quicke who introduced me to SCD. Her enthusiasm became instilled in me and inspired me to devise this collection of dances."', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21235, '2023-01-04 22:53:33.22936+00', '2023-01-04 22:53:33.22936+00', 'Bluffs of Kintail, The', 'BLUFFS OF KINTAIL', 3, 32, NULL, 2, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21243, '2023-01-04 23:18:12.359875+00', '2023-01-04 23:18:12.359875+00', 'Errant Electron, The', 'ERRANT ELECTRON', 1, 32, NULL, 1, 4, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21213, '2022-12-20 20:08:34.123961+00', '2023-01-05 11:34:46.23351+00', 'Musical Chairs', 'MUSICAL CHAIRS', 3, 32, NULL, 1, 4, 2, 11237, '2022-12-01', '', 88, '8448/8888/8448/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21247, '2023-01-05 11:41:50.806996+00', '2023-01-05 11:41:50.806996+00', 'Interlocking Interactions', 'INTERLOCKING INTERACTIONS', 1, 40, NULL, 1, 4, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21156, '2022-10-29 14:41:44.997852+00', '2023-01-18 16:48:08.331784+00', 'Puffin John', 'PUFFIN JOHN', 3, 32, NULL, 1, 4, NULL, 550, '2022-06-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1400, '1997-04-03 22:00:00+00', '2022-10-20 11:44:20.197992+00', 'Craigleith', 'CRAIGLEITH', 1, 32, 9999, 1, 4, 2, 13, NULL, 'Although the instructions for 2nd & 3rd couples in bars 9-24 do not always mention which hand is used, they do describe their actions as "like J.B. Milne", so right hands can be assumed.', 91, '8228/8888/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21152, '2022-10-20 13:05:21.910042+00', '2022-10-20 13:09:16.670119+00', 'Maxwell''s Enduring Legacy', 'MAXWELLS ENDURING LEGACY', 1, 32, NULL, 1, 3, 42, 11765, '2022-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (30, '2002-02-21 23:00:00+00', '2022-10-21 23:18:22.643737+00', 'Across the Esk', 'ACROSS THE ESK', 1, 32, 9999, 1, 3, 42, 21, NULL, '', 53, '822/888/844/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7653, '1998-04-13 22:00:00+00', '2022-10-23 19:34:38.609718+00', 'Come to the Ceilidh', 'COME TO THE CEILIDH', 1, 32, 9999, 1, 4, 1, 788, '1977-01-01', '', 53, '8000/8440/8004/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7388, '1998-04-24 22:00:00+00', '2022-10-23 20:09:04.585535+00', 'Edinburgh Exiles, The', 'EDINBURGH EXILES', 1, 32, 9999, 1, 3, 42, 146, NULL, 'Inscribed "For Morag and Walter Proven."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7193, '1997-08-22 22:00:00+00', '2022-10-23 20:50:34.176933+00', 'Windmills Are Turning', 'WINDMILLS ARE TURNING', 2, 32, 9999, 1, 4, 1, 526, NULL, 'The dance notes say this was devised "following a visit to Kinderdijk, near Rotterdam, HolIand. This locality is unique for its rows of windmills, nineteen in total, dating from the eighteenth century, all of whIch are still functional. All the left and right hands across figures in this dance represent the sails of the mills turning in the wind.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (7175, '1998-01-12 23:00:00+00', '2022-10-23 20:57:59.807642+00', 'Wilma''s Hornpipe', 'WILMAS HORNPIPE', 1, 32, 9999, 1, 3, 42, 108, '1982-01-01', 'Inscribed "for Wilma Miller, Chairman of the R.S.C.D.S. 1991-1994"', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (7174, '1997-09-17 22:00:00+00', '2022-10-23 21:04:43.353963+00', 'Willie-Waught', 'WILLIEWAUGHT', 2, 32, 9999, 1, 3, 42, 1357, NULL, 'A willie-waught is a hearty draught (or a wee dram).', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (7043, '1998-07-08 22:00:00+00', '2022-10-23 21:15:49.444567+00', 'Wells of Dee, The', 'WELLS OF DEE', 3, 32, 9999, 1, 100, 1, 108, '1971-01-01', '', 81, '8888/8888/8440/8844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10907, '2002-11-02 23:00:00+00', '2022-12-22 18:31:37.90714+00', 'St. Abb''s Head Reel, The', 'SAINT ABBS HEAD REEL', 1, 32, 9999, 1, 3, 42, 725, '1998-01-01', 'This was originally entered in the datbase as "Saint Abb''s Head Reel" but the instructions give the title as "The St. Abb''s Head Reel".', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21112, '2022-09-27 13:26:00.252745+00', '2022-10-25 19:38:34.908109+00', 'At the Library', 'AT THE LIBRARY', 2, 40, NULL, 2, 3, 18, 11778, NULL, 'I wrote the danse during my shift at the library using the formation danced the previous day during our class at Saint Quay Perros.', 80, '800/888/844/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21154, '2022-10-26 04:44:26.357847+00', '2022-10-26 04:44:26.357847+00', 'Market Square', 'MARKET SQUARE', 3, 40, NULL, 4, 4, NULL, 11360, NULL, 'Dance written by Sheila Karolak and named for Market Square in downtown Pittsburgh', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16771, '2015-09-26 19:27:02.304768+00', '2022-10-24 22:32:15.545325+00', 'Breakfast with Alligators', 'BREAKFAST WITH ALLIGATORS', 3, 32, NULL, 1, 3, 42, 401, NULL, 'Ann and Ron Walker are super hosts and even provided a special breakfast display of alligators, one having its breakfast while we had ours', 53, '840/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12019, '2005-02-13 23:00:00+00', '2022-10-25 16:23:00.826673+00', 'Swirling Snow', 'SWIRLING SNOW', 3, 32, 9999, 2, 3, 18, 2793, '2004-01-01', '', 75, '800/888/888/844', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18038, '2017-10-28 22:35:56.189604+00', '2022-10-26 13:29:37.507903+00', 'Chemnitz Loopings', 'CHEMNITZ LOOPINGS', 1, 40, 9999, 1, 2, 76, 11544, '2014-08-13', 'From the dance description: The danced was devised by Undine Meister, Gabriele Schrader-Ladewig, Kristina Helle, Albrecht Meister and Thomas Gro&szlig; on 8. and 13. August 2014 during some 2 couple

exercises.



The dance description was online available at http://www.scd-chemnitz.de/tanze/ - however, the Scottish Dance Group in Chemnitz seemingly has dissolved and thus also the server does not exist anymore.



The description is now available again both via the e-cribs site and <<https://www.folkverein-chemnitz.de/scd/Chemnitz_Loopings.pdf>>.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21128, '2022-10-01 08:29:42.011395+00', '2022-10-28 13:34:33.09992+00', 'I Believe in a Better Tomorrow', 'I BELIEVE IN A BETTER TOMORROW', 4, 64, 2, 1, 100, 2, 3179, '2020-04-18', '', 81, '8448/8888/8008/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21129, '2022-10-01 08:31:28.687036+00', '2022-10-28 21:39:21.460099+00', 'Inspired by Diamonds', 'INSPIRED BY DIAMONDS', 3, 32, NULL, 1, 3, 42, 3179, '2019-11-21', 'The dance was inspired by the "half diamond reels of four" in <<ddp:Drewry, John#108>>''s dance "<<ddd:Diamond Set in Silver, A#7679>>".', 41, '822/822/833/833', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6904, '1997-08-25 22:00:00+00', '2022-11-01 17:38:32.739871+00', 'Walkers O'' Banchory, The', 'WALKERS O BANCHORY', 3, 32, 9999, 1, 3, 42, 108, '1993-05-01', 'Inscribed "for Stuart and Kathleen Walker of Banchory".', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6479, '1999-08-06 22:00:00+00', '2022-11-01 19:26:18.544508+00', 'Glen Fincastle', 'GLEN FINCASTLE', 2, 32, 9999, 1, 3, 42, 479, '1997-01-01', 'Devised "to celebrate the 25th Wedding Anniversary of Helen and Ian Russell."', 56, '844  888  844  844', 1, 1, 0, 1, 75);
INSERT INTO 'dance' VALUES (21155, '2022-10-29 11:11:19.310505+00', '2022-12-09 15:43:54.084998+00', 'Welcome to the Atholl', 'WELCOME TO THE ATHOLL', 2, 32, NULL, 1, 3, 42, 2748, NULL, 'Devised to celebrate the 60th season of the Atholl Scottish Country Dance Club 2019/20.', 56, '800/888/844/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (6455, '1997-09-14 22:00:00+00', '2022-11-01 19:30:16.204023+00', 'Tamworth Chase', 'TAMWORTH CHASE', 2, 32, 9999, 1, 3, 42, 1191, NULL, 'For several years, members of clubs in the Hunter Valley Branch attended the Highland Gathering at Tamworth. We would meet with friends from Queensland and to reduce costs, would bed down children in the rooms of those who came without. There was much chasing from one room to another with sashes and items of clothing as we made our preparations. It was a lot of fun, and with a handshake at the end, came the greeting "See you next year".', 56, '800/888/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21149, '2022-10-16 21:02:16.166787+00', '2022-11-03 12:57:47.368783+00', 'House Keys of Lisbon, The', 'HOUSE KEYS OF LISBON', 3, 32, NULL, 6, 3, 17, 11237, '2020-11-01', 'The title was inspired by a BBC news article about a Portuguese law allowing descendants of Jews expelled in the 15th and 16th centuries to return and claim citizenship.

Apparently a few families who took refuge in Istanbul still have keys to the houses in Lisbon that they were forced to leave centuries ago.

These keys have been passed down as family heirlooms.

For more details see <<https://www.bbc.co.uk/news/resources/idt-sh/Turning_Portuguese>>.



Those keen on symbolism can imagine the six dancers starting at the points of a Star of David and that the hands across and turns represent keys in locks.



The tune, <<ddt:Slockit Light, Da#7803>>, was written by fiddler Tom Anderson as a lament for the lights of houses in Shetland being extinguished as people moved away. It seemed an appropriate choice.



This dance also provides an opportunity to thank several people that I know in Lisbon: firstly Adriana Duarte for organising the Curia weekends; also <<ddp:Monteiro, Isabel#11225>> and <<ddp:Neves, Isabel#11150>> for devising lovely dances; and Barbara Gray, Joana Ferreira, Roger Picken and Sue Willdig for running the Carcavelos, Lapa and Telheiras SCD groups.

', 88, '666/666/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1320, '1997-04-03 22:00:00+00', '2022-11-05 11:15:33.24072+00', 'Connaghtman''s Rambles', 'CONNAGHTMANS RAMBLES', 2, 48, 9999, 1, 4, NULL, 270, NULL, 'Until Nov 2022, the dance was listed as "Connaughtman''s Rambles", connecting it to a tune of that spelling. It was then reverted to its original publication name "Connaghtman''s Rambles".', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3933, '2002-03-11 23:00:00+00', '2022-11-06 10:54:52.0144+00', 'Lord High Admiral, The', 'LORD HIGH ADMIRAL', 1, 32, 9999, 1, 3, 42, 270, '1983-01-01', '', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3598, '1998-11-29 23:00:00+00', '2022-11-06 11:01:49.952381+00', 'Lady Dennel Grant', 'LADY DENNEL GRANT', 3, 32, 9999, 1, 2, NULL, 270, '1983-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4874, '1997-09-10 22:00:00+00', '2022-11-06 21:47:12.72263+00', 'My Wife is a Wanton Wee Thing', 'MY WIFE IS A WANTON WEE THING', 2, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6122, '1997-08-26 22:00:00+00', '2022-11-06 21:50:15.905421+00', 'Sir William Curtis''s Speen', 'SIR WILLIAM CURTISS SPEEN', 3, 32, 9999, 1, 3, 42, 270, '1972-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (675, '1997-04-03 22:00:00+00', '2022-11-07 17:35:52.328983+00', 'Bonnie Toon of Edinburgh', 'BONNIE TOON OF EDINBURGH', 1, 40, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3119, '1998-10-20 22:00:00+00', '2022-11-07 19:45:03.490668+00', 'Iona Cross', 'IONA CROSS', 4, 192, 3, 4, 6, 60, 270, NULL, '', 79, '808088  848488  888800  888888', 1, 1, 1, 1, 13);
INSERT INTO 'dance' VALUES (2669, '1997-04-03 22:00:00+00', '2022-11-07 19:46:07.704681+00', 'Green Shades of Gask', 'GREEN SHADES OF GASK', 2, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4202, '1997-11-24 23:00:00+00', '2022-11-07 20:33:17.685566+00', 'Mary and Maurice Cooper''s Medley', 'MARY AND MAURICE COOPERS MEDLEY', 4, 64, 13, 1, 4, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4519, '1997-04-03 22:00:00+00', '2022-11-07 20:34:48.792505+00', 'Miss Johnston Of Hilton''s Fancy', 'MISS JOHNSTON OF HILTONS FANCY', 2, 24, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4812, '1997-04-03 22:00:00+00', '2022-11-07 21:11:45.826299+00', 'Mrs Trotter of Castlelaw', 'MRS TROTTER OF CASTLELAW', 2, 32, 9999, 1, 2, NULL, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4016, '1999-08-06 22:00:00+00', '2022-11-07 21:53:06.468345+00', 'Macdonald''s awa tae the Wars', 'MACDONALDS AWA TAE THE WARS', 2, 32, 9999, 1, 3, 42, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4569, '1998-07-09 22:00:00+00', '2022-11-07 21:53:44.76852+00', 'Miss Rose of Tirlogie', 'MISS ROSE OF TIRLOGIE', 1, 48, 9999, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6497, '1998-07-09 22:00:00+00', '2022-11-07 21:54:35.10877+00', 'Tell her I am', 'TELL HER I AM', 2, 32, 9999, 2, 3, 17, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6419, '1997-09-14 22:00:00+00', '2022-11-08 15:54:23.223243+00', 'Swelkie, The', 'SWELKIE', 3, 32, 9999, 6, 3, 4, 13, NULL, 'The Swelkie is a tidal whirlpool, near Stroma in the Pentland Firth. In days gone by, folk believed that

there were a pair of millstones under the Swelkie which ground the salt to make the sea salty.', 58, '800  888  444  444', 1, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (6162, '1997-09-14 22:00:00+00', '2022-11-08 16:33:53.233739+00', 'Snakes And Ladders', 'SNAKES AND LADDERS', 3, 32, 9999, 3, 5, 16, 3461, '1978-05-01', '"Snakes and Ladders" is a children''s board game "for wet weather". One climbs up the ladders and slides down the snakes, eventually making it -- in this case to the bottom of the set. Bars 1-8 represent the board, 9- 16 the dice box and counters, and 17-32 the ladders (crossing) and snakes (circles). This dance is dedicated to the Brookline class of the Boston Branch, RSCDS, and was first published in the Tartan Times for May 1978.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6136, '1997-08-19 22:00:00+00', '2022-11-08 16:37:48.869109+00', 'Ski Tow, The', 'SKI TOW', 2, 32, 9999, 1, 4, 1, 108, '1989-11-01', '"For the dancers at the Coylum Bridge Hotel November 1989"', 87, '0488  8888  8888  8488', 1, 1, 0, 0, 87);
INSERT INTO 'dance' VALUES (6047, '1997-09-14 22:00:00+00', '2022-11-08 16:53:46.484207+00', 'Shieling, The', 'SHIELING', 3, 32, 9999, 2, 3, 18, 13, NULL, 'Originally published by Jean in the leaflet “Inveran Bridge and three more Scottish Country Dances”.  



Written for Daisy and Eddie Cassie who retired to their shieling in Oxfordshire in 1984. Eddie was President of the Harwell Caledonian Society for many years.', 92, '844/888/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5980, '2002-04-08 22:00:00+00', '2022-11-08 20:43:54.689829+00', 'Seagreen', 'SEAGREEN', 3, 32, 9999, 2, 3, 17, 108, '1989-01-01', 'The notes say: ''the dance is dedicated to the members of the Paris Branch who have invited me to teach there in June 1989. Thomas Carlyle, in a well-known phrase, described Robespierre as "The seagreen incorruptible".''', 79, '828  888  828  844', 1, 1, 1, 1, 79);
INSERT INTO 'dance' VALUES (5917, '1997-09-13 22:00:00+00', '2022-11-08 23:07:11.996835+00', 'Schoon''s Bairn', 'SCHOONS BAIRN', 2, 40, 9999, 1, 3, 42, 1263, '1981-07-15', 'The dance notes say this was devised to celebrate the birth of Jacob Kenneth Schoon, July 15, 1981. The movements of the dance represent the danceIli meeting. greeting, and exclaiming over Jacob''s arrival. The original instructions were for reel time, but the dance has come 10 be done in jig lime to the tune of "Just As I Was In The Morning."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4673, '1997-04-03 22:00:00+00', '2022-11-27 16:42:28.807839+00', 'Morpeth Town', 'MORPETH TOWN', 1, 32, 9999, 1, 3, 42, 109, '1991-03-01', 'From the notes: "It is in Morpeth that the Hunter Valley Branch of the RSCDS holds a weekend school to mark the start of the dancing season. Morpeth was at one time an important river port and terminus for sea traffic from Sydney. It boasts many buildings from the early 19th century many of which have been restored."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21159, '2022-11-13 18:12:20.991986+00', '2022-11-16 00:26:20.473343+00', 'Newark''s Welcome', 'NEWARKS WELCOME', 3, 32, NULL, 2, 3, 18, 2973, '2022-09-25', 'Devised in honour of the Newark Scottish Country Dance Society which has given a very warm welcome to my wife and myself since we moved to the East Midlands in 2020.



As with many of my ''formation dances'' this dance can be done as a jig, reel or strathspey.', -1, '', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21185, '2022-11-30 23:30:24.536611+00', '2022-11-30 23:30:24.536611+00', 'Stone Mountain Strathspey', 'STONE MOUNTAIN STRATHSPEY', 3, 32, NULL, 1, 3, 42, 11445, NULL, 'There is a once through video at <<https://rscds-atlanta.org/wp-content/uploads/2022/08/Video.mov>>.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21236, '2023-01-04 22:54:27.599108+00', '2023-01-04 22:54:27.599108+00', 'Chicken Run, The', 'CHICKEN RUN', 1, 32, NULL, 1, 4, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5915, '1998-10-07 22:00:00+00', '2022-11-09 11:22:27.891587+00', 'Schiehallion', 'SCHIEHALLION', 4, 128, 2, 4, 4, 3, 392, '1971-01-01', 'Schiehallion (pronounced shee-HALL-i-en, from the Gaelic *sidh chailleann*) is a mountain in Perth and Kinross, Scotland. It overlooks Loch Tummel and is 1,083 m high, which makes it a <<https://en.wikipedia.org/wiki/Munro|Munro>>. Seen from the west its shape is an almost perfect cone, and it is reasonably easy to climb with great views.



Being an isolated mountain with a very regular shape, Schiehallion was used in 1774 for an interesting experiment which was supposed to estimate the mass of the Earth by means of the deflection of a pendulum by the mass of the mountain. This experiment was proposed by Charles Mason (1728–1786, an English astronomer who was also instrumental in the definition of the Mason-Dixon line) and carried out by a commission under the direction of the Astronomer Royal, Nevil Maskelyne (1732–1811).



The intersection of the line of latitude midway between the most northerly and southerly points on the Scottish mainland and the line of longitude midway between the most westerly and easterly points is very close to the summit of Schiehallion. This means that in a sense the mountain could be seen as the “centre of Scotland”. This, however, presupposes that the most westerly point is Corrachadh Mòr in Ardnamurchan; the completion of the Skye Bridge in 1995 makes Skye technically part of the Scottish mainland and that would throw the calculation off.



The dance was published in 1971 but a <<https://youtu.be/JgXgEtT8VLY|youtube comment>> on <<https://my.strathspey.org/dd/dancevideo/712/|video 3>> suggests it was devised in 1968.



Hugh Thurston describes the origin of the dance in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-048-May-1971.pdf#page=3|issue 48 of The Thistle magazine>>.', 93, 'no bar count made', 1, 1, 0, 0, 92);
INSERT INTO 'dance' VALUES (19165, '2019-01-17 11:37:42.645812+00', '2022-11-12 09:37:14.92255+00', 'Yellow-Haired Laddie Quadrille', 'YELLOWHAIRED LADDIE QUADRILLE', 4, 64, 10043, 4, 4, 54, 11771, NULL, 'Arranged by Gerry Gray, Prince Edward Island.  



Repeat the dance in jig time. Some changes will be necessary:  During the Grand Square, the HEAD dancers should dance out of the centre rather than retire. Also, in the Grand Square, pas de basque should be used when turning with both hands in Bars 13-16 and 29-32. Otherwise, the dance is the same.    



  

This quadrille (square dance) is based on the country-dance of the same name published in RSCDS Book 12. Each section is suggested by actions in the original dance. However, by dancing in a square and having four active couples instead of two, very little similarity is apparent.  

  

Suggested Music: “Yellow Haired Laddie” – Bobby Brown – Grandfather Mountain Gala.  



As there is no Yellow Haired Laddie in Jig Time, I recommend using “Selection of Jigs (4x32)” – Bobby Brown – Any Good Dance Any Good Tune.', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5730, '1997-04-03 22:00:00+00', '2022-11-12 12:31:17.934663+00', 'Rowena and Rebecca', 'ROWENA AND REBECCA', 3, 48, 9999, 1, 4, 1, 129, NULL, '', 61, '8000/8800/8888/0077/0088/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5654, '1997-08-22 22:00:00+00', '2022-11-12 18:43:48.952039+00', 'Ronda Blue', 'RONDA BLUE', 3, 32, 9999, 1, 2, 76, 526, '1986-06-10', 'The notes say that this was devised "following a visit to the Andalusian town of Ronda in Southern Spain on 10th June 1986. Ronda is an ancient Moorish stronghold and is rich in mediaeval Arabic architecture, characterised by its regular geometric structUres. This dance, featuring several square and circular figures, is a representation of the Ronda buildings, and takes its name from the blue sky above the town on Ihat June morning."', 64, '88  66  88  88', 1, 1, 0, 0, 93);
INSERT INTO 'dance' VALUES (5635, '1998-07-09 22:00:00+00', '2022-11-12 18:49:57.341758+00', 'Sparkling Loch, The', 'SPARKLING LOCH', 1, 32, 9999, 2, 3, 17, 1387, NULL, 'The instructions for this dance also give a variation for four couples. In 21-24 1st couple cast to 4th place. Then in 25-32 all four couples set twice and turn partners RH.



The deviser writes that:

*At my home on the Gareloch in Scotland, our living room was upstairs. It was right on the water and at night, when it was dark, we could follow the fish by the trails of phosphorus they left behind as they darted to and fro – hence "The Sparkling Loch".*', 44, '800/888/800/808', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5579, '1997-09-17 22:00:00+00', '2022-11-12 18:57:54.018546+00', 'Ring in the New', 'RING IN THE NEW', 2, 32, 9999, 1, 3, 18, 758, '1990-01-01', 'An audience participation dance. The progression is a little different but have faith, it works.



Editor''s note: the e-crib follows the original instructions exactly, but could the words "and set" have been accidentally omitted for [23-24]?', 69, '888/844/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5559, '1997-04-03 22:00:00+00', '2022-11-12 19:03:55.126803+00', 'Rhodes House Reel', 'RHODES HOUSE REEL', 1, 32, 9999, 1, 3, 42, 127, NULL, 'Inscribed "for the girls of the Oxford University Scottish Dancing Society 1983/84."



The notes add that "Rhodes House is a magnificent building where the Oxford Uniuersity Scottish Dancing Society hold their Ceilidhs. It was founded in 1929 for Rhodes Scholars, in memory of Cecil Rhodes, the founder of Rhodesia."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5542, '1998-11-29 23:00:00+00', '2022-11-12 19:18:16.113243+00', 'Reids o'' Monymusk, The', 'REIDS O MONYMUSK', 1, 32, 9999, 1, 3, 42, 127, NULL, 'Inscribed "for Angela and Jimmy Reid".



The notes add that the "dance pays tribute to Angela and Jimmy Reid who live in a house named ''Monymusk'' near Basingstoke. Angela teaches the local Scottish group, and Jimmy is an ex-piper of the Black Watch. The original tune for the dance was written by their daughter, Sheena, well known as a member of the Frank Reid Band."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5511, '2002-10-15 22:00:00+00', '2022-11-12 19:27:58.84073+00', 'Reel for ''88, A', 'REEL FOR 88', 1, 32, 9999, 1, 4, 11, 197, '1988-01-01', 'Inscribed "in honour of Australia''s Bicentennial Year, 1988."



NB the instructions describe this as for "3 couples in a 4 couple set" but the dance actually involves all 4 couples.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (5412, '2002-02-09 23:00:00+00', '2022-11-12 19:46:41.577812+00', 'Queen City Salute, The', 'QUEEN CITY SALUTE', 4, 64, 5, 1, 4, 1, 777, NULL, '', 55, '840  880  888  666', 1, 1, 1, 0, 36);
INSERT INTO 'dance' VALUES (13143, '2006-12-06 23:00:00+00', '2022-11-13 17:34:07.422467+00', 'Bridge City Strathspey, The', 'BRIDGE CITY STRATHSPEY', 3, 32, 9999, 6, 3, 4, 2998, '2004-02-01', '', 100, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13772, '2011-07-13 22:00:00+00', '2022-11-13 18:05:06.583225+00', 'Golden Chain, The', 'GOLDEN CHAIN', 3, 32, NULL, 2, 3, 17, 2973, '2009-01-01', 'Devised January 2009. 



The name Golden Chain comes from the central figure, a chain, and the dance having been devised on the 50th anniversary of the New York Branch.



This dance can also be done as a quick-time dance for 3 couples in a 4-couple set. In that case, it should be danced eight times through, with bars 29-32 modified so that 1st couple cross to second place on their own side passing left shoulder and all three couples set on the last two bars.



Music

Any good strathspey (or jig or reel). When danced as a strathspey a suitable recording is ''The Gordonian Strathspey'', Reel Friends Book 2, David Hall Scottish Dance Band, track 6.', 79, '800/888/888/866', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18357, '2018-06-03 14:01:14.089099+00', '2022-11-13 18:18:02.020896+00', 'Atsuko''s Reel', 'ATSUKOS REEL', 1, 40, NULL, 2, 3, 18, 11639, '2018-01-01', 'Dance was devised by David Carter (CSCDS Inc.) for Atsuko Clement who gave a fabulous workshop at a class mini workshop in Charlotte, NC in 2018.



Deviser''s instructions are available at <<https://www.scottish-country-dancing-dictionary.com/dance-crib/atsukos-reel.html>>.', 73, '866/800/855/855/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21181, '2022-11-27 11:44:42.783927+00', '2022-11-27 11:44:42.783927+00', 'Lews Castle Gathering', 'LEWS CASTLE GATHERING', 1, 40, NULL, 1, 3, 42, 11753, '2019-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21144, '2022-10-05 17:24:42.007474+00', '2022-11-17 00:22:00.254993+00', 'Somewhere Over the Rainbow', 'SOMEWHERE OVER THE RAINBOW', 4, 128, 51, 1, 3, 42, 11527, '2022-01-01', 'Devised to a medley on the Somewhere Over the Rainbow theme played by Bill Ewan.



*Instructions from the deviser:*  

1-8: 1st couple cross over with right hand, cast off one place and turn partner with left hand once round.  

9-16: 1st man dance half figure of eight round 2nd couple as 1st lady dance half figure of eight round 3rd couple. 1st couple finish in back to back position facing 4th corners. 1st couple set to and turn 4th corners to finish in lines.  

17-24: 2nd, 1st and 3rd couples dance circle six hands round and back. 1st couple finish in back to back position facing 3rd corners.  

25-32: 1st couple set to and turn 3rd corners to finish in lines across. 1st couple dance half figure of eight on own sides giving left shoulder to 4th corner and finish in 2nd place own sides.  

Repeat having passed a couple.   

Next and last couple dance the same in strathspey time.

', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16186, '2015-04-08 14:36:01.421148+00', '2022-11-18 11:30:33.579626+00', 'Ribbons and Rings', 'RIBBONS AND RINGS', 3, 32, 9999, 1, 3, 42, 10759, '2009-01-01', 'For Gisela and Martin McWilliam to celebrate their Silver Wedding in 2009', 56, '800/888/888/880', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4815, '1998-11-29 23:00:00+00', '2022-11-20 16:23:44.38138+00', 'Mrs Watt''s Teakettle', 'MRS WATTS TEAKETTLE', 1, 48, 9999, 1, 3, 42, 480, '1192-03-01', 'The notes say that "Mrs. Hepburn Belches [the tune for the dance] is both a tune and a dance, written by John Bowie about 1789. Mrs. Watt is John Watt''s mother, famed for her teakettle."', 41, '555/555/800/844/804/840', 1, 1, 0, 1, 50);
INSERT INTO 'dance' VALUES (21162, '2022-11-18 13:20:34.582437+00', '2022-11-18 13:46:56.479602+00', 'Swig of Jig, A', 'SWIG OF JIG', 2, 32, NULL, 1, 3, 42, 3646, NULL, '', 47, '804/880/888/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21167, '2022-11-20 22:59:25.331516+00', '2022-11-22 09:59:53.416321+00', 'Choochoo', 'CHOOCHOO', 2, 40, NULL, 4, 4, 13, 11570, '2021-01-01', 'Deviser says: "The dance is about trains and how the ride, come to a hold in a train station, shift tracks. This dance introduces the ''Choochoo Reel''."', 100, '8888|8888|8888|8888|8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21163, '2022-11-18 14:05:59.977363+00', '2022-11-18 15:58:25.552004+00', 'One Foot in Front of the Other', 'ONE FOOT IN FRONT OF THE OTHER', 2, 32, NULL, 1, 3, 42, 10788, '2020-02-01', 'Devised by Sara Gratiot in February 2020 for Anneliese Suter, who has been putting one foot in front of the other every day as she danced, hiked, and quietly made many wonderful friends on a joyous journey to her 85th birthday.', 70, '880/888/844/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21161, '2022-11-18 12:12:13.45207+00', '2022-11-18 20:12:58.589921+00', 'Black Joke, The', 'BLACK JOKE', 2, 32, NULL, 1, 3, 42, 12210, '2019-10-01', 'This dance is in phrases of 6+6+10+10.



The notes say this was devised "to fit the traditional song tune ''The Black Joke''.  This 18th century tune has an unusual structure of 6-bar and 10-bar phrases. It is used for a number of Cotswold Morris dances, which is how John first came across it."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5154, '1998-01-05 23:00:00+00', '2022-11-20 15:22:15.311173+00', 'Paisley Mondays', 'PAISLEY MONDAYS', 1, 32, 9999, 1, 3, 42, 1190, NULL, 'At the end of the second turn of the dance, 1st couple cross diagonally to the bottom to allow 4th couple to move up ready for the circle.', 69, '888  888  888  880', 1, 1, 0, 0, 91);
INSERT INTO 'dance' VALUES (5093, '2001-11-20 23:00:00+00', '2022-11-20 15:33:35.724749+00', 'One o''Clock Canon, The', 'ONE OCLOCK CANON', 1, 64, 9999, 1, 4, 8, 550, '1995-01-01', 'Requires music which plays 5×32.



Ian Brockbank <<sspey:64356|points out>> with reference to the description published in RSCDS Book 47:



> I''ve had several queries asking me if the last 2 bars of The One O''Clock

> Canon have changed.  For bars 63-64, Book 47 says 

>

> "1st couple cast off one place while the couple in fourth place dance up to

> third place."

>

> This is a misprint.  Only on bars 159-160 do they dance up to third place.

> On all other times through (63-64, 95-96 and 127-128) they dance up to

> second place, allowing the previous first couple (half way through their

> dance) to cast into third place.', 73, '8000  8440  8888  8240 = 70 // 8088  4488  8888  8826 = 104 // 8808  8800  8888  8404 = 88', 1, 1, 0, 1, 146);
INSERT INTO 'dance' VALUES (5083, '1997-04-03 22:00:00+00', '2022-11-20 15:36:39.870705+00', 'On The Wings Of The Morning', 'ON THE WINGS OF THE MORNING', 2, 32, 9999, 1, 3, 42, 62, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21168, '2022-11-21 14:56:10.2646+00', '2022-11-21 15:05:50.818562+00', 'Pascale and Marc''s Jig', 'PASCALE AND MARCS JIG', 2, 32, NULL, 2, 3, 17, 11181, '2022-11-21', '', 52, '800/880/800/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21171, '2022-11-23 10:00:37.172863+00', '2022-11-23 10:13:44.146422+00', 'Palindrome, Le', 'PALINDROME', 1, 32, NULL, 7, 1, 4, 9998, NULL, 'Palindromic mixer dance for couples in a circle. Taught by Martin Sheffield, but apparently not devised by him (information from Sophie Marchand).', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21172, '2022-11-24 20:01:52.253104+00', '2022-11-24 20:01:52.253104+00', 'Lonely Chaperone, The', 'LONELY CHAPERONE', 3, 32, NULL, 1, 3, 42, 10648, '2022-01-01', 'This may also be danced as a reel or a jig.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21170, '2022-11-21 18:24:18.161262+00', '2022-11-22 09:57:06.731637+00', 'You Haunt Me', 'YOU HAUNT ME', 3, 32, NULL, 1, 3, 18, 11570, '2022-01-01', '', 92, '884 888 888 884', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19115, '2018-12-12 17:26:57.567205+00', '2022-11-23 15:06:22.366855+00', 'Oxford Blue and Gold', 'OXFORD BLUE AND GOLD', 1, 32, NULL, 1, 4, 1, 11763, '2018-01-01', 'Devised to celebrate the 50th anniversary of the Oxfordshire Branch in 2018.', 65, '8000/8880/8444/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3946, '1997-09-08 22:00:00+00', '2022-11-25 16:18:54.8528+00', 'Lord of Islay', 'LORD OF ISLAY', 3, 32, 9999, 2, 3, 18, 13, NULL, 'From the notes "Lord of Islay was the title of one of the grandsons of Somerled, the founder of Clan Donald."', 92, '844/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21173, '2022-11-27 11:26:44.191645+00', '2022-11-27 11:26:44.191645+00', '30 Years to Life', '30 YEARS TO LIFE', 3, 32, NULL, 2, 3, 18, 11753, '2020-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21174, '2022-11-27 11:28:16.35894+00', '2022-11-27 11:28:16.35894+00', 'Strathspey for Margo, A', 'STRATHSPEY FOR MARGO', 3, 32, NULL, 2, 3, 17, 11753, '2019-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21175, '2022-11-27 11:32:55.011765+00', '2022-11-27 11:32:55.011765+00', 'Across and Back', 'ACROSS AND BACK', 2, 32, NULL, 1, 3, 42, 11753, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21176, '2022-11-27 11:34:05.351559+00', '2022-11-27 11:34:05.351559+00', 'California Dreams', 'CALIFORNIA DREAMS', 3, 32, NULL, 1, 3, 42, 11753, '2019-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21177, '2022-11-27 11:35:30.055565+00', '2022-11-27 11:35:30.055565+00', 'Dunfermline City Reel', 'DUNFERMLINE CITY REEL', 1, 32, NULL, 1, 4, 11, 11753, '2022-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21178, '2022-11-27 11:39:31.281275+00', '2022-11-27 11:39:31.281275+00', 'For a Dreich Day', 'FOR A DREICH DAY', 1, 32, NULL, 4, 4, 1, 11753, '2019-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21180, '2022-11-27 11:42:00.712487+00', '2022-11-27 11:42:00.712487+00', 'Inverkeithing Invention', 'INVERKEITHING INVENTION', 1, 32, NULL, 1, 4, 13, 11753, '2020-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21169, '2022-11-21 17:51:57.753778+00', '2022-12-07 16:44:48.904973+00', 'Rhum de Feu', 'RHUM DE FEU', 4, 240, 10054, 4, 5, 35, 11570, '2021-01-01', 'Dedicated to Dagmar Suhm, Beate Bartels and all those involved in preparing a lovely „Feuerzangenbowle“ each November Course at the Kuckucksnest in Schlüchtern/Germany.', 78, '80808/88888/08088/66668/88888/44486', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21164, '2022-11-18 20:06:06.54953+00', '2022-12-10 00:18:52.527408+00', 'Reeling Home', 'REELING HOME', 1, 40, NULL, 1, 3, 42, 12211, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21165, '2022-11-18 20:16:41.206581+00', '2022-12-27 13:41:35.722424+00', 'Atholl Anniversary Strathspey', 'ATHOLL ANNIVERSARY STRATHSPEY', 3, 32, NULL, 1, 4, 1, 11753, '2019-09-01', 'Devised "as a tribute to a welcoming Scottish Country Dance club providing Tuesday evenings of great enjoyment to members and visitors."', 91, '8888/8888/8888/4844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21179, '2022-11-27 11:40:36.259077+00', '2023-01-10 18:45:53.327594+00', 'Forget-Me-Not Reel', 'FORGETMENOT REEL', 1, 32, NULL, 1, 4, 1, 11753, '2019-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21166, '2022-11-18 20:24:38.836316+00', '2023-01-10 18:51:51.121485+00', 'Atholl Diamond Twelvesome, The', 'ATHOLL DIAMOND TWELVESOME', 3, 48, NULL, 4, 6, NULL, 3317, NULL, 'Danced three times. Progression 452631 returns all to original places after three repeats.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4393, '1997-08-25 22:00:00+00', '2022-12-03 11:43:33.873925+00', 'Miller o'' Hirn, The', 'MILLER O HIRN', 3, 32, 9999, 1, 4, 1, 108, '1977-01-01', 'John Drewry wrote in the original description that the dance was for Bob Millar of Toronto, Ontario.



The progression in Bars 25-32 is similar to that in the reel "Lochside" by Jackie Johnstone of Dumfries.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4299, '1998-04-12 22:00:00+00', '2022-12-03 12:02:01.498857+00', 'Melrose', 'MELROSE', 3, 32, 9999, 1, 3, 42, 181, '1990-01-01', 'Inscribed "for Roy and Pamela Green, to celebrate their Ruby Wedding, August, 1990".', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21186, '2022-12-01 12:52:23.090055+00', '2022-12-01 13:42:21.653144+00', 'Albany on Cloud Nine', 'ALBANY ON CLOUD NINE', 2, 32, NULL, 1, 3, 42, 12213, '2021-01-01', 'To mark Albany (N.Y.) Class’s one year anniversary of Scottish Country Dancing on Zoom (or on the cloud).  Dedicated to Lois New, Barbara and Sam Bemis, and all the teachers who have spearheaded virtual dancing for the Albany Class, and have extended the warmest of welcomes to all on Sunday nights during the COVID-19 pandemic.  The half a double triangle and half a reel sequence is borrowed from <<ddd:Rudyard''s Reel#19851>> by <<ddp:Harris, Chris#671|Chris Harris>> of Zurich (2015).', 63, '800/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (2814, '2000-07-02 22:00:00+00', '2022-12-01 14:59:18.61538+00', 'Haunted Manor, The', 'HAUNTED MANOR', 3, 32, 9999, 1, 4, 13, 313, '1989-01-01', 'For the Dance Weekend at Halsway Manor, Crowcombe, June 1989.



The dance notes say that "In view of the ghostly nature of the title, steps should be as smooth and silent as possible and all arm movements to allemande hold should be strongly marked."', 88, '8888/8888/8888/8080', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12746, '2006-05-11 22:00:00+00', '2022-12-01 20:39:16.049803+00', 'Summer Celebration, A', 'SUMMER CELEBRATION', 1, 40, 9999, 1, 3, 42, 1445, '2006-01-01', 'Inscribed "For Anja to celebrate whatever she wants."', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21188, '2022-12-02 09:15:22.220954+00', '2022-12-02 09:15:22.220954+00', 'Summer''s Day, A', 'SUMMERS DAY', 3, 32, NULL, 104, 3, NULL, 1331, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (4215, '1997-04-03 22:00:00+00', '2022-12-03 12:27:27.678616+00', 'Mary Rose Hornpipe, The', 'MARY ROSE HORNPIPE', 1, 40, 9999, 1, 3, 42, 354, NULL, 'The notes say this was "offered to the Portsmouth and District Caledonian Society on the occasion of their Day School, 31st October 1981, and in respect of the proposed raising of Henry VIII''s flagship "The Mary Rose", which foundered off Southsea Castle".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13396, '2009-11-08 23:00:00+00', '2022-12-02 10:06:06.077655+00', 'TAC''s Hospitality', 'TACS HOSPITALITY', 1, 32, NULL, 1, 3, 42, 3627, NULL, '»This dance was devised by Ian Souter, Hamilton, Ontario and Chairman of the T.A.C. 2006–2008 to acknowledge the wonderful hospitality that has been shown to its AGM Weekend and Summer School participants over the past several years by Pat Souter and her team of volunteers. There is always so much work that goes into an event that is kept in the background and magically appears each night. Well done!«', 63, '800/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16597, '2015-08-26 18:51:42.4237+00', '2022-12-03 12:40:05.760915+00', 'City of Glasgow Strathspey', 'CITY OF GLASGOW STRATHSPEY', 3, 40, NULL, 4, 4, 1, 3183, '2013-01-01', 'Devised "for the 90th Anniversary of Glasgow Branch of the RSCDS in 2013."', 70, '6666/6666/8080/0808/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13389, '2009-11-08 23:00:00+00', '2022-12-02 15:24:46.714715+00', 'TAC 50', 'TAC 50', 1, 64, NULL, 4, 4, 1, 439, NULL, '»Devised by Marie Malcolm, of Wellington, New Zealand, to celebrate the 50th Anniversary of TAC.«



The <<ddrec:TAC 50#6893|recording>> for this dance is just once through 64 bars, but the dance has a 2341 progression suggesting that it might be done four times. It is no longer possible to ask the deviser.', 91, '8888/6666/8888/8888/8888/8888/4444/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16596, '2015-08-26 18:50:49.240617+00', '2022-12-03 12:41:17.401447+00', 'Alan Ross''s Reel', 'ALAN ROSSS REEL', 1, 32, NULL, 2, 3, 17, 3183, NULL, 'Inscribed "by Anne Thorn for Alan Ross with grateful thanks for composing tunes for her dances and for providing wonderful music for Scottish country dances in the Helensburgh area."', 53, '800/888/804/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16598, '2015-08-26 18:53:18.97396+00', '2022-12-03 12:46:07.320809+00', 'Fun at Fifty or The Corrie Fisted Dancer', 'FUN AT FIFTY OR THE CORRIE FISTED DANCER', 1, 32, NULL, 3, 5, 92, 3183, '2013-05-01', 'The notes say this was "devised by Anne Thorn for her 50th birthday in May 2013".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (16612, '2015-08-26 19:12:26.742395+00', '2022-12-03 19:12:51.916369+00', 'Silver Acorn, The', 'SILVER ACORN', 3, 32, NULL, 6, 3, 4, 3183, '2014-01-01', 'Some early copies of Magic of Music 2 did not specify that the interlocking reels in bars 9 - 16 are actually reels of four as in The Wind on Loch Fyne.



The ntoes says this was devised "for the special birthday of David Reid, treasurer of Helensburgh RSCDS, a dedicated scout leader, cyclist and hill walker."', 88, '444/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4121, '2002-10-28 23:00:00+00', '2022-12-03 19:30:00.653153+00', 'Münster 1200, The', 'MUNSTER 1200', 1, 32, 9999, 3, 5, 7, 854, NULL, 'The notes say that "Münster in Westphalia, is York''s German twin city. In 1993 it celebrated the 1200th anniversary of its founding."', 50, '80800/63663/63663/80800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (4105, '1997-04-03 22:00:00+00', '2022-12-03 20:28:59.351219+00', 'Major Erskine Of Edinburgh', 'MAJOR ERSKINE OF EDINBURGH', 3, 32, 9999, 1, 3, 42, 127, NULL, 'Inscribed "for Miss Helen Erskine." And the notes say that "the dance symbolises the Major introducing herself and mixing with her fellow officers and cadets."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4063, '1997-09-08 22:00:00+00', '2022-12-03 20:38:35.728682+00', 'Madeline''s Rant', 'MADELINES RANT', 3, 32, 9999, 1, 3, 42, 480, '1992-02-14', 'The notes say that "The night Madeline Kunin was elected first woman governor of Vermont, we had enough dancers for a three couple set. The rest were glued to the radio."



For a three couple set, 1st couple end crossing down to 3rd place.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4002, '1997-09-08 22:00:00+00', '2022-12-03 20:51:10.981192+00', 'Maarten''s Melbourne', 'MAARTENS MELBOURNE', 1, 32, 9999, 1, 3, 42, 1096, NULL, 'From the notes: "Maarten van der Giessen''s life was lived in three worlds; in Nederland, where he was born; in Australia, where he spent the latter three quarters of his life and in the world of Scottish Country Dancing. He was for a time Secretary of the Melbourne & District Branch of the Society, as well as being an occasional relief teacher. He was a friend to many and always courteous on and off the dance floor."



The symbolism of the dance is given as:  

1-16: Travelling south with partner.  

17-20: A brief return to the "old" country.  

21-28: Visiting friends and relatives.  

29-32: Going back home to Melbourne.  ', 44, '840  408  822  866', 1, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (16664, '2015-08-27 18:00:58.113212+00', '2022-12-03 23:38:35.076413+00', 'Robin''s Rant', 'ROBINS RANT', 3, 32, NULL, 2, 3, 17, 10568, '2014-11-01', 'From the dance notes: "After a rather strenuous night of dancing, Don suggested that I write a dance for Robin Stewart as a joke. I was to make it as complicated as possible since Robin always despairs when I introduce one of our challenge dances (so, of course, it had to end with a Tournée though Robin swears he never has trouble with the Tournée). Use a brisk strathspey tune."', 83, '880/888/888/808', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (20397, '2021-07-26 20:05:39.934773+00', '2022-12-04 13:53:58.796151+00', 'Speyside Way, The', 'SPEYSIDE WAY', 3, 32, NULL, 2, 3, 17, 11921, NULL, 'The Speyside Way is a long distance footpath, which starts in Buckie and ends in Kingussie. It takes walkers along 100 miles of the most scenic parts of the Spey Valley and visits many famous whisky distilleries on route.', 73, '880/886/808/808', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3726, '1997-04-03 22:00:00+00', '2022-12-10 19:43:40.16448+00', 'Lassie from Stirling, The', 'LASSIE FROM STIRLING', 3, 32, 9999, 1, 3, 42, 146, '1982-01-01', 'Inscribed "For Nancy Dickson of Dalston, Carlisle."', 69, '844/888/888/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (13442, '2009-11-16 23:00:00+00', '2022-12-05 16:52:00.117133+00', 'For Old Times'' Sake', 'FOR OLD TIMES SAKE', 1, 32, 9999, 1, 3, 42, 10327, NULL, 'Published in the Diamond Jubilee Collection of the RSCDS Inverness and District Branch: <<https://my.strathspey.org/dd/publ/1027/>>', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21192, '2022-12-05 16:34:06.310307+00', '2022-12-05 23:44:44.035463+00', 'Chesterfield Caledonians, The', 'CHESTERFIELD CALEDONIANS', 3, 32, NULL, 1, 3, 42, 316, NULL, 'Source: SCDDB dance list <<https://my.strathspey.org/dd/list/37582/>>.

Tune also composed by David Queen.

An 8x32 recording played by Andrew Lyon and David Queen is available at <<https://youtu.be/M14CDJx9fek>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15145, '2013-09-20 17:34:49.574146+00', '2022-12-07 23:36:37.05082+00', 'Marion''s Medley', 'MARIONS MEDLEY', 4, 32, 1, 1, 3, 42, 10863, NULL, 'Devised for Marion Peace. The notes say that "Marion''s sparkle and long-time dedication to the Houston Branch are greatly appreciated by all who know and dance with her. A medley seems particularly suitable for a dance in Marion''s honor as it is akin to the movements of a Butterfly - another passion of Marion''s."', 50, '844/888/800/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3651, '1999-08-06 22:00:00+00', '2022-12-10 23:04:30.857502+00', 'Laird o'' Dochart''s Reel', 'LAIRD O DOCHARTS REEL', 2, 80, 9999, 1, 4, NULL, 9998, NULL, '"Collected from Archie McNab of Toronto, Ontario. Toronto was named York in the old days and it was near there where, in 1823, Chief Archebald McNab and some of his clansmen settled on their arrival from Scotland. The Chief built a house on the banks of a stream which he named the Dochart after a river in Scotland. The proud and haughty Chief was named the Laird o’ Dochart."



In <<ddpub:#1580>> this is described as a "reel for four couples", but the tune is a jig.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21193, '2022-12-08 10:24:50.221984+00', '2022-12-08 10:44:24.7359+00', 'Miss Stirling''s Hornpipe', 'MISS STIRLINGS HORNPIPE', 6, 32, NULL, 1, 4, 1, 293, NULL, '', 75, '4444/4444/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21194, '2022-12-08 10:44:55.64327+00', '2022-12-08 10:44:55.64327+00', 'Ten Ladies Dancing', 'TEN LADIES DANCING', 3, 32, NULL, 3, 5, 7, 11266, NULL, 'Source <<https://www.scottish-country-dancing-dictionary.com/dance-crib/ten-ladies-dancing.html>>', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21195, '2022-12-08 10:54:14.776042+00', '2022-12-08 11:21:27.275068+00', 'Viva La Paz', 'VIVA LA PAZ', 2, 32, NULL, 1, 3, 42, 758, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3592, '1997-04-03 22:00:00+00', '2022-12-10 21:01:01.423118+00', 'Lady Brettle''s Strathspey', 'LADY BRETTLES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 127, NULL, 'Inscribed "for Sally Brett of Harpsden, Henley."', 61, '880/888/868/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3762, '1998-09-30 22:00:00+00', '2022-12-08 16:59:38.905672+00', 'Leandor''s Jig', 'LEANDORS JIG', 2, 64, 9999, 1, 4, 1, 494, '1965-01-01', 'The publication states: "Leandor''s Jig was composed (i.m.o. devised) by the Currie family of Ardrossan. The name of the dance is compounded from the first letters of their names - Leslie, Antony and Dorothy."', 66, '4004/4004/4884/8888/8888/8888/8800/8008', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5049, '1997-04-03 22:00:00+00', '2022-12-08 21:19:37.53151+00', 'Old Eightsome Reel', 'OLD EIGHTSOME REEL', 4, 28, 9999, 1, 4, NULL, 180, NULL, 'This was originally entered in SCDDB as a medley with a total of just 28 bars. It seems likely this is a typo, probably for 128, but the editing team has no access to the original instructions to check. See <<https://my.strathspey.org/dd/issue/1568/|issue 1568>>.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21196, '2022-12-08 15:43:00.278984+00', '2022-12-08 22:29:43.729808+00', 'Peter Ellis Waltz, The', 'PETER ELLIS WALTZ', 5, 32, NULL, 5, 2, 76, 293, '2017-05-01', '', -1, '', 1, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9882, '2001-10-23 22:00:00+00', '2022-12-09 23:19:56.671434+00', 'Red Kites over the Black Isle', 'RED KITES OVER THE BLACK ISLE', 3, 32, 9999, 1, 4, 11, 2892, NULL, 'or 2x32 bar Strathspey + 2x32 bar Reel  ---  



This dance was originally written as a strathspey, but on a "party"

night it was done as a medley for fun and we found it worked. So you

have the option of dancing it either way.', 75, '8008/0880/8888/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3800, '2002-02-28 23:00:00+00', '2022-12-10 19:19:33.284872+00', 'Life Begins at Forty', 'LIFE BEGINS AT FORTY', 2, 40, 9999, 1, 4, 2, 522, '1990-01-01', 'The notes say this was devised "to celebrate the Fonieth Anniversary of Newcastle upon Tyne and District Branch. The friendly spirit of Scottish Country Dancing is shown by each couple dancing with every other couple in each repeat of the dance and the deliberate lack of new formations is so that all Scottish Country Dancers may join in with little difficulty."', 75, '8888/8008/8888/0880/8448', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (19505, '2019-07-29 10:34:07.763309+00', '2022-12-10 21:30:16.17912+00', 'Burning of Paddy''s Breeches, The', 'BURNING OF PADDYS BREECHES', 4, 128, 13, 4, 4, NULL, 2682, '2019-03-13', 'Devised 13th March 2019 for an Irish-themed night. Based around a lovely piece of music ”The Burning of Paddy’s Breeches / The Burning of the Piper’s Hut” which is 64S+64J for which I had been meaning to compose a dance for over several years. The jig is too quick to be easily danced, and hence the music needs to be slowed down about 10-15% but the Strathspey part remains quick; perhaps how historical ones were danced. To my nonmusician ear it sounds like a Irish Hornpipe. The recording is by Bobby Macleod and his band in ”Highland Accordion Medley”. I wanted to capture the evenness of the first part and the flight of the jig.



Finding a musician would solve all problems so that the first tune could be played as a reel and the second as a jig.



Alternative recorded music is ”Gay Gordons” as recorded by ”The Dancing Strings Of Scotland” (LP+) which is 64R+64J, consisting of The Barren Rocks of Aden/The Duke of Athols Highlanders.



Alternative alternative recorded music where the first part would definitely be a strathspey would be any reasonable recording of ”Johnny Walker”. For example, the version on ”Special Requests, Vol. 1” by Colin Dewar and his Band.

', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3236, '1999-10-27 22:00:00+00', '2022-12-10 23:33:44.617241+00', 'Jenny''s Bawbee', 'JENNYS BAWBEE', 3, 24, 9999, 1, 2, NULL, 432, '1816-01-01', 'A bawbee was a coin introduced by James V of Scotland and originally valued at six pence Scots (or half an English penny). The name supposedly derives from that of the Master of the Mint at the time, a laird of Sillebawby (which is a farm in the parish of Burntisland, Fife).', 57, '88  80  88', 1, 1, 1, 1, 83);
INSERT INTO 'dance' VALUES (21237, '2023-01-04 23:10:22.948973+00', '2023-01-04 23:10:22.948973+00', 'Christmas Presents, The', 'CHRISTMAS PRESENTS', 3, 48, NULL, 1, 4, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15025, '2013-08-02 10:21:40.360577+00', '2022-12-11 00:18:25.043275+00', 'Leaving York Factory', 'LEAVING YORK FACTORY', 2, 32, NULL, 2, 3, 17, 10814, NULL, 'Crib contributed by Peter McClure (jpm) – joptmc@cc.umanitoba.ca

1-8::  1st couple dance a figure of eight on their own side around 2nd and 3rd couples; start by dancing in.

9-16::  1st couple lead down the middle and up, finishing in top place.

17-20::  1st and 2nd couples set once, then dance right hands across half way.

21-24::  1st and 3rd couples set once and dance left hands across half way.

25-28::  2nd, 3rd and 1st couples advance for two and retire for two; on bar 26, 2nd and 3rd couples turn to their own side to retire.

29-32::  All 3 couples turn with the right hand once around.



Repeat with a new top couple.', 58, '800/800/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4697, '1998-01-05 23:00:00+00', '2022-12-11 16:51:15.943634+00', 'Mr & Mrs Richard McLaughlin of San Diego', 'MR AND MRS RICHARD MACLAUGHLIN OF SAN DIEGO', 1, 32, 9999, 1, 3, 42, 348, '1992-01-19', 'Inscribed to "Marjorie Easton and Richard McLaughlin, who were married in San Diego, on January 18, 1992."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8462, '1997-12-28 23:00:00+00', '2022-12-11 02:20:46.543667+00', 'Saint John''s Rant, The', 'SAINT JOHNS RANT', 1, 32, 9999, 1, 4, 1, 872, NULL, 'The E-crib and diagram follow the version available to the editing team.



According to <<https://my.strathspey.org/dd/issue/2870/|issue 2870>> in the revised publication bars 17-24 reads: "1st man followed by his partner, cast off behind 2nd couple, cross over, cast behind 3rd and 4th couples to finish in 4th place on own sides".



For the moment the E-crib and diagram reflect the original version.', 81, '8888/8888/8000/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13923, '2011-08-22 22:00:00+00', '2022-12-11 11:24:51.467586+00', 'Rainbow Nation, The', 'RAINBOW NATION', 1, 32, NULL, 1, 4, 1, 3254, '2004-04-01', 'Devised by Terry Lynne Harris, Pretona, April 2004 



Witten in celebration of 10 years of democracy in the new South Africa.



Notes:  

1. The sideways Y shape formation in bars 25-28 forms the distinctive Y of the South Africa flag design, with the (invisible) boundaries of the set forming the rectangular shape of the flag.  

2. Between repeats, it is suggested that couples retain hands after bar 32 and go straight into the circle of bars 1-8. After the final repeat (ie the 4th time through), dancers drop hands at the end of bar 32.', 69, '8888/6600/8022/8888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (13637, '2010-11-10 23:00:00+00', '2022-12-11 20:40:30.674721+00', 'Trip to Vienna', 'TRIP TO VIENNA', 3, 40, 9999, 1, 3, 42, 10294, '1998-12-02', 'A Note from "The Vienna Book":  

Dance written by Ann Murray on December 2, 1998 on the occasion of Jim Cook’s ‘Trip to Vienna’. The figures of the dance signify specific places to visit in Vienna.  

-  The Ring (circular road)  

-  Walking in the parks  

-  The spire of St. Stephen''s Church  

-  The Big Wheel  in the amusement park  

-  The Viennese Waltzes  









Note, the dance contains a "Lead up to the top and down again" which is not defined in SCDDB - thus, it was (for its similarity) annotated as "Lead down and up".', 55, '888/888/008/880/880', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (17266, '2016-09-05 23:06:56.513558+00', '2022-12-11 11:42:28.326299+00', 'Judie''s Farewell to Spring Creek', 'JUDIES FAREWELL TO SPRING CREEK', 1, 32, NULL, 1, 3, 42, 11340, '2013-05-13', 'This dance was devised for Judie Hansen, a longtime member of the Madison County Scotch Hoppers Scottish Country Dance group upon her leaving Spring Creek (Hot Springs), North Carolina for her new home in Indianapolis.



The original instructions suggest the recording <<ddrec:The Whale''s Moo#7092>> but the presumably later <<ddrec:Judie''s Farewell to Spring Creek#17266>> recording uses a different tune.', 63, '800/888/888/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4956, '1997-09-10 22:00:00+00', '2022-12-12 17:18:51.963332+00', 'Nina''s Dance', 'NINAS DANCE', 1, 24, 9999, 1, 3, 42, 1170, '1987-07-01', 'Deviser''s Notes: This dance was devised during the summer of 1987 when Nina was 10 years of age. The dance was performed by the Basic class at our 1987 Christmas Party to the tunes of Jingle Bells and Deck the Halls. The dancers wore jingle bells on their ghillies



The is dance was published by the Portland Oregon database editors have an original text which carries page number 14.  It must therefore behave been published in some book(let), but we have no information on where it originated', 50, '888/880/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9800, '2001-03-13 23:00:00+00', '2022-12-13 14:50:56.63926+00', 'Scallywag, The', 'SCALLYWAG', 2, 40, 9999, 1, 3, 42, 952, '1997-02-01', 'The notes say this is an "appropriately flirtatious dance, composed February 1997 to honor Mikkel Thompson on reaching his half century."



An early SCDDB comment suggested that *the demonstrations by the Alamo dem team show that there is an error in the original instructions for bars [33-34]: 1c meets with Rsh, not Lsh as stated, and then joins RH.* However current versions of the instructions  just mention joining RH.', 45, '800/866/844/866/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19177, '2019-01-30 17:08:01.662854+00', '2022-12-13 23:12:39.038752+00', 'Paranoid Jig, The', 'PARANOID JIG', 2, 32, NULL, 1, 3, 42, 10759, '2019-02-02', '*Note: Published in January 2019 with no setting in [17-32]. Version of 2nd February is final.*   



Devised in 2019 by Judith Kowalczik in preparation of the Skua Dubh 7th Bonn Spring Workshop on 16th March 2019 and inspired by “The Paranoid Jigs” (Touch & Go, Ben Hiant and Monika''s Jig by Keith B. Smith) by Hoogie from the album “Knackiedoo”.   

', 50, '880/844/844/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4015, '2002-08-25 22:00:00+00', '2022-12-15 13:13:07.946569+00', 'MacDonald of the Isles', 'MACDONALD OF THE ISLES', 3, 32, 9999, 2, 3, 17, 175, '1966-01-01', '##>>

John Macdonald (John of Islay) claimed the title Lord of the Isles around 1336. The title remained in the Macdonald family until 1493 when another John Macdonald was found guilty of treason for plotting with Edward IV of England and the Earl of Douglas. The title of Lord of the Isles was forfeited to the House of Stewart and is now a subsidiary title of the heir apparent to the UK throne. 

##<<



According to the RSCDS website (section on Snowball Chain), first published in Scottish Dance Archives in 1966, and in Derek Haynes'' 2nd Carnforth Collection in 1991.

', 65, '484  484  864  048', 1, 1, 1, 1, 64);
INSERT INTO 'dance' VALUES (21198, '2022-12-13 22:24:24.916926+00', '2022-12-18 17:38:23.324267+00', 'Killarney Waltz', 'KILLARNEY WALTZ', 5, 32, NULL, 5, NULL, NULL, 12222, '1950-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15525, '2014-06-27 21:22:00.934599+00', '2022-12-18 11:11:58.759379+00', 'Come to Kennisis', 'COME TO KENNISIS', 4, 32, 1, 1, 3, 42, 10971, NULL, 'This dance was devised to welcome a group of Scottish Country Dancers to our cottage on Kennisis Lake, in Haliburton County, Ontario.', 56, '844/844/880/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (4411, '2002-04-19 22:00:00+00', '2022-12-14 17:32:22.261714+00', 'Minister on the Loch, The', 'MINISTER ON THE LOCH', 3, 32, 9999, 2, 3, 17, 146, '2008-01-01', '##>>

<<imgt:skating-minister.jpg|The Rev. Robert Walker skating on Duddingston Loch|192x300:right>>

The title refers to the portrait by <<http://en.wikipedia.org/wiki/Henry_Raeburn|Sir Henry Raeburn>>

of “Reverend Robert Walker skating on Duddingston Loch”

(or “The Skating Minister”, for short)

which now hangs in the

<<https://www.nationalgalleries.org/art-and-artists/5327|National Gallery of Scotland>>.

Art and artists were among <<ddp:Goldring, Roy>>’s other great passions.



The Revd Dr Robert Walker (1755–1808), a personal friend of Henry Raeburn''s,

was born in Ayrshire but – as his father served as the minister of the

Scots Kirk in Rotterdam – he lived in the Netherlands as a child, and it is reasonable to assume

that he learned to skate there. Having been licensed as a minister in 1770 (!) he eventually became

minister of the Canongate Kirk in Edinburgh and joined the Edinburgh Skating Club (the world''s first

figure skating club), whose members frequented Duddingston Loch (seen in the painting)

or Lochend Loch when conditions were suitable for skating. According to the National Gallery of

Scotland, “Walker''s pose, as he glides across the ice, looks effortless, but would have been

recognised by fellow skaters as a difficult and sophisticated manœuvre.”



The picture, which was painted around 1795,

spent a long time in the possession of the Walker family before passing

through the hands of a number of owners during the first half of the 20th century

and finally, in 1949, being acquired, for £525,

by the National Gallery of Scotland where it languished in obscurity for another few decades.

It was featured on a commemorative postage stamp in 1973

and eventually displayed in an exhibition of Raeburn pictures at

the National Portrait Gallery in London in 1997, where it appeared on widely publicised posters

and finally achieved its well-deserved popularity.



This painting is rather unlike other portraits by Raeburn and there is an ongoing controversy

where some art historians claim it was actually executed by the French painter, Henri-Pierre Danloux.

In spite of this, it is considered an iconic work, has been exhibited domestically and abroad,

and has also found its way into popular culture,

making cameo appearances in TV shows and popular fiction.

##<<', 58, '880  800  808  844', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (21199, '2022-12-15 09:47:40.286396+00', '2022-12-15 13:10:44.885298+00', 'Spritz at Marostica Square', 'SPRITZ AT MAROSTICA SQUARE', 1, 32, NULL, 1, 3, 42, 11926, '2022-12-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11563, '2003-10-30 23:00:00+00', '2022-12-16 08:40:32.645707+00', 'Verl Girl, The', 'VERL GIRL', 1, 32, 9999, 1, 3, 42, 1445, NULL, 'This dance was written for Birgit Röhricht, teacher of the small but enthousiastic group in Bielefeld and keeper of Samson, a very nice bear.', 69, '844/888/888/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (727, '1997-04-03 22:00:00+00', '2022-12-16 10:49:32.962386+00', 'Bow River', 'BOW RIVER', 3, 32, 9999, 1, 3, 42, 108, '1986-01-01', 'According to »Catalogue of Dances by John Drewry 1963-2002«, this dance exists in an »original« version of 1986 and a »modified« version of 1996. If anybody can clear this up for us then please get in touch.



The instructions for the original version can be found at <<http://www.rscdsleeds.org.uk/files/Drewry/SCN_0044.jpg>> (courtesy of <<https://my.strathspey.org/dd/issue/2964/|issue 2964>>). It is inscribed "for the S.C.D. Weekend in Banff, Alberta". Nothing is yet known about the modified version.', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3189, '1997-04-03 22:00:00+00', '2022-12-16 21:36:02.565089+00', 'Jacobite Sword Dance, The', 'JACOBITE SWORD DANCE', 7, 104, 9999, 107, 1, NULL, 9998, NULL, 'This is a Highland-style sword dance for two dancers. It consists of 3 steps in strathspey tempo (16 bars each, with the 3rd step being repeated, for a total of 64 bars) and one reel step (40 bars).  March music is stipulated to enter and exit.  

The dance was collected and revived by Mrs MacNab in Ontario, Canada, in 1917.  It was published in 1961 in a leaflet by her niece Mrs Elizabeth Sutorius for her aunt.', -1, '', 0, 0, 0, 1, -1);
INSERT INTO 'dance' VALUES (3449, '1998-10-21 22:00:00+00', '2022-12-16 23:15:31.261277+00', 'Key to the Door, The', 'KEY TO THE DOOR', 1, 48, 9999, 3, 5, 7, 44, '1966-01-01', 'Excerpt from the original dance sheet: "Weirdlaw Scottish Country Dance Sheet No 1. / (...) "The Key to the Door" was devised by Iain Boyd to celebrate the coming of age of Mr Robert Brady in April, 1966. (...)"', 67, '80800/82842/88888/84884/84884/80800', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (5838, '1997-09-13 22:00:00+00', '2022-12-17 11:33:26.389541+00', 'Saint Margaret''s Hill', 'SAINT MARGARETS HILL', 1, 24, 9999, 1, 2, NULL, 446, '1710-01-01', 'In <<ddp:Mitchell, John W#270>>''s <<ddp:Whetherley Book 24#474|Whetherley Book 24>> the date of this dance is given as 1610 from The Dancing Master (Playford). However it does not appear in the first edition of that and <<http://playforddances.com/dances-2-3/st-margarets-hill/>> gives the date as 1710. So this entry is now changed to that later date.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21201, '2022-12-18 01:34:45.171602+00', '2022-12-18 02:06:00.01505+00', 'Families Together', 'FAMILIES TOGETHER', 3, 32, NULL, 1, 3, 42, 2766, '2022-11-01', 'I really like the reel in Eileen Watt''s reel and wanted to try something similar in strathspey time. This dance was written around Thanksgiving and a dancer in the class suggested a title similar to the one I chose.', 69, '888/888/448/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21200, '2022-12-18 01:13:07.147092+00', '2022-12-18 01:17:15.126453+00', 'Thanksgiving Kindness', 'THANKSGIVING KINDNESS', 2, 32, NULL, 1, 3, 42, 2766, '2022-11-01', 'We had planned to visit my family for the first time in years and at the last minute things got cancelled when the sister who was to host everything called to say she had a ringworm infestation (new kitten) and couldn''t have people at her house. A friend who learned about this insisted on providing us with a cornucopia of food for our Thanksgiving.', 45, '800/888/800/648', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (2918, '1998-09-29 22:00:00+00', '2022-12-18 13:06:49.994373+00', 'Highland Lass, The', 'HIGHLAND LASS', 1, 32, 9999, 1, 3, 42, 446, '1728-01-01', 'In Book 30 the RSCDS says this dance was adapted from a 1728 edition of the Playford dances. A version of the dance was also published in an earlier edition of Playford dating from 1718. The latter is available online at <<https://playforddances.com/dances-2-3/highland-lass-2/>>. Some discussion of this can be found in <<https://my.strathspey.org/dd/issue/2967/|issue 2967>>.', 50, '844  844  880  844', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (21202, '2022-12-18 02:09:30.377368+00', '2022-12-18 02:15:02.142073+00', 'Promen-all', 'PROMENALL', 2, 32, NULL, 1, 2, 76, 2766, '2022-11-01', 'I wrote this dance as a teaching dance. We''d been working on rights and lefts and figures of 8 and wanted to introduce promenade. I couldn''t find a dance in any tempo that covered all three figures, so I wrote this dance.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (12772, '2006-05-31 22:00:00+00', '2022-12-18 16:42:54.53267+00', 'Lad and his Lass, The', 'LAD AND HIS LASS', 1, 32, 9999, 1, 4, 1, 370, NULL, 'The booklet states: "For Patrick and Priscilla"', 59, '8228/2882/4444/8444', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14161, '2011-08-26 22:00:00+00', '2022-12-18 16:45:06.997602+00', 'Netherhall', 'NETHERHALL', 1, 32, NULL, 1, 3, 42, 370, NULL, 'The booklet states: "Netherhall is in Kirkcubrightshire where a group of us spent several happy holidays."', 59, '848/888/880/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (7966, '1998-07-17 22:00:00+00', '2022-12-18 19:20:00.867883+00', 'Dance No. 2 (Jig)', 'DANCE NO 2 JIG', 2, 32, 9999, 1, 4, NULL, 181, NULL, 'The original title is as shown, basically just a number and the type of dance. The editorial team came up with an unofficial alias name for this dance for better search reference.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3634, '1997-04-03 22:00:00+00', '2022-12-18 20:42:51.16412+00', 'Lady President, The', 'LADY PRESIDENT', 1, 40, 9999, 1, 3, 42, 377, NULL, 'Devised for Lady President of Wembley & District Scottish Association.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21206, '2022-12-18 21:17:24.639333+00', '2022-12-18 21:17:24.639333+00', 'St. Patrick', 'SAINT PATRICK', 1, 32, NULL, 2, 3, 17, 1862, '2002-01-01', 'Danced for the first time on March 17, 2002.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8865, '1998-12-13 23:00:00+00', '2022-12-18 21:26:49.575272+00', 'Miss Nancy Smiles', 'MISS NANCY SMILES', 2, 32, 9999, 1, 3, 42, 2489, '1998-01-01', '', 55, '880/844/868/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3578, '2002-04-19 22:00:00+00', '2022-12-18 21:31:03.532756+00', 'Ladies of Pont Street, The', 'LADIES OF PONT STREET', 1, 32, 9999, 1, 3, 42, 377, NULL, 'The author states: "This dance was devised for the partners at Pont Street who have been kind enough to dance with me. Before entering the pick-up chain 2nd and 1st couple can swing a little longer than four bars but they must be ready to enter chain when due."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21207, '2022-12-18 22:27:58.804962+00', '2022-12-18 22:27:58.804962+00', 'Carradale Bay', 'CARRADALE BAY', 3, 32, NULL, 2, 3, 17, 12226, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21208, '2022-12-18 22:37:08.979471+00', '2022-12-18 22:37:08.979471+00', 'Charles Hoy''s Strathspey', 'CHARLES HOYS STRATHSPEY', 3, 32, NULL, 1, 4, 1, 12227, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3765, '1998-07-08 22:00:00+00', '2022-12-18 23:08:36.135879+00', 'Leaving Benbecula', 'LEAVING BENBECULA', 3, 32, 9999, 1, 4, 2, 127, NULL, 'Inscribed to Mrs. Sheila Jupp, who spent several years living on the Island. It was from Benbecula that Bonnie Prince Charlie and Flora MacDonald sailed in 1746.



For a while MiniCrib had a duplicate crib for this dance under the name "Return to Benbecula". It is not known how or why this was added (around 2001). As of 2022 it is now removed from MiniCrib and SCDDB but is added as a name alias along with this note in case anyone ever tries to search for it.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21204, '2022-12-18 15:41:33.38969+00', '2022-12-19 00:41:47.840788+00', 'Long Googdbye, The', 'LONG GOOGDBYE', 3, 32, NULL, 1, 3, 42, 2766, '2022-09-01', '', 50, '800/880/844/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21203, '2022-12-18 13:17:06.122623+00', '2022-12-19 00:42:48.444784+00', 'Squirrel in a Pumpkin', 'SQUIRREL IN A PUMPKIN', 3, 32, NULL, 1, 3, 42, 2766, '2022-11-01', 'This dance was written when the idea of bars 1-8 into bars 9-16 came to me and was named for how the squirrels in our yard love the pumpkins we have left over from Halloween decorations and climb into them to eat them.', 41, '840/880/088/800', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1201, '1997-08-31 22:00:00+00', '2022-12-19 02:36:51.433736+00', 'Christmas Tree, The', 'CHRISTMAS TREE', 1, 48, 9999, 1, 4, 1, 776, NULL, 'A Dance devised at the KIRKWHELPINGTON CLASS. teacher Mrs M. Barlow. (possibly <<ddp:#528>>?).  



This dance describes a Christmas tree as follows:  

1- 8: Tinsel on the tree  

9-16: Star on top of the tree  

17-24: The baubles on the tree  

25-32: The trunk of the tree  

33-48: The strings of lights going round the tree.  



DON''T LET GO OR THE LlGHfS WILL GO OUT!', 42, '8000/8800/8800/8000/4444/4444', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9909, '2001-05-20 22:00:00+00', '2022-12-19 09:27:18.482223+00', 'Passing Place', 'PASSING PLACE', 2, 32, 9999, 1, 4, 2, 2489, '1995-01-01', 'Devised by Charles Snowdon on the Isle of Skye in celebration of the one-way roads with numerous passing places.', 88, '8888/8888/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21205, '2022-12-18 21:08:49.989608+00', '2022-12-19 11:00:59.778971+00', 'Lock and Dam No. 5', 'LOCK AND DAM NO 5', 1, 32, NULL, 1, 3, 42, 2861, '1998-01-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9832, '2001-04-29 22:00:00+00', '2022-12-19 14:29:36.203795+00', 'Squirrel on the Bough', 'SQUIRREL ON THE BOUGH', 1, 40, 9999, 1, 3, 42, 2861, '2001-01-01', '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (11020, '2002-11-24 23:00:00+00', '2022-12-19 16:40:33.603403+00', 'Cruachan', 'CRUACHAN', 4, 128, 2, 4, 4, 14, 1, '2001-01-01', 'Deep within Ben Cruachan is a pumped storage hydro-electric power station.  



This dance may be interpreted as:  



- Strathspey - Water being pumped from Loch Awe up to Cruachan reservoir.  

- Reel - Water rushing back down and producing electricity.', 63, '4444/8080/0808/8888/8888/4444/8080/0808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (9772, '2001-01-28 23:00:00+00', '2022-12-19 14:39:46.357481+00', 'Norma''s Fancy', 'NORMAS FANCY', 2, 32, 9999, 2, 3, 17, 1862, '1995-01-01', 'On 2001-01-25 Mike Briggs e-mailed this original version.  The dance exists only in leaflet form.  

Norma''s Fancy,  32 J  3C set,  Mike Briggs  

1-4		1C & 2C SET, 1C CAST OFF while 2C DANCE UP  

5-8		1C & 3C SET, 1C CAST OFF while 3C DANCE UP  

9-16		CROSSOVER MIRROR REELS OF THREE, each couple crossing down from the top in turn (2C, 3C, 1C)  

17-28	RIGHTS AND LEFTS for three couples  

29-32	All SET and CROSS RH



The dance was revised at some date before 2012; this database shows the current version. ', 83, '800/888/12 12 12/444', 0, 1, 1, 0, 83);
INSERT INTO 'dance' VALUES (21209, '2022-12-19 15:14:09.813325+00', '2022-12-19 15:14:09.813325+00', 'Cascade Reel', 'CASCADE REEL', 1, 32, NULL, 1, 3, 42, 2861, '2002-06-16', 'Devised by Michael Mudrey,June 2002 from a dream, June 16, 2002.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21210, '2022-12-19 15:15:40.257964+00', '2022-12-19 15:15:40.257964+00', 'Kenora Reel', 'KENORA REEL', 3, 40, NULL, 1, 3, 42, 2861, '2002-05-01', 'Devised by Michael Mudrey after a trip to Kenora, Ontario and recalling the Kenora Reel, May 2002', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21211, '2022-12-19 15:20:19.208191+00', '2022-12-19 15:20:19.208191+00', 'Norma''s Garden', 'NORMAS GARDEN', 1, 32, NULL, 1, 3, 42, 9998, '2002-06-30', 'Devised for the 46th wedding anniversary of Norma and Michael Briggs, June 30, 2002.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17100, '2016-06-26 17:09:22.934264+00', '2022-12-19 16:25:39.444319+00', 'Hill at the Top, The', 'HILL AT THE TOP', 2, 32, NULL, 1, 4, 2, 2887, '2010-11-01', 'This dance is dedicated to Judy Hili who became President of Alderley and District Caledonian Society in 20JO.  



It was first danced at the Alderley and District Caledonian Society St Andrews Ceiltdh on 30lh November 2010.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3571, '2001-07-18 22:00:00+00', '2022-12-19 20:29:01.338947+00', 'Ladebraes Jig', 'LADEBRAES JIG', 2, 96, 9999, 4, 4, NULL, 1049, '1973-01-01', 'The recommended recording is actually a reel, due to the few LP''s available to the devisor at the time. Devised on the occasion of the 15th anniversary of the The Hague Branch in 1973. The dance was named after the well known "Lover''s Walk" alongside the Ladebraes in St Andrews.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (9352, '2002-10-13 22:00:00+00', '2022-12-19 20:40:31.943222+00', 'Mrs May Anderson', 'MRS MAY ANDERSON', 3, 32, 9999, 2, 3, 17, 2812, NULL, 'Alasdair Graham owns a framed original, previously owned by May Anderson. It states: "The dance was written to commemorate the retiral of Mrs May Anderson as teacher of the St James'' Church Country Dance Club after 40 years. The dance was devised by Eileen Miller."', 58, '800  880  844  808', 0, 1, 0, 0, 58);
INSERT INTO 'dance' VALUES (3553, '1997-08-24 22:00:00+00', '2022-12-20 12:12:20.957172+00', 'Kynoch of Bucksburn', 'KYNOCH OF BUCKSBURN', 3, 32, 9999, 1, 3, 42, 108, '1993-01-01', 'Inscribed "for the 40th Wedding Anniversary, in September 1993, of Jim and Kathleen Kynoch, who came from Bucksburn but now live in Toronto".', 48, '811/833/833/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3537, '1998-11-25 23:00:00+00', '2022-12-20 12:15:33.140929+00', 'Kitty Campbell''s Reel', 'KITTY CAMPBELLS REEL', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 28, '800  800  822  800', 1, 1, 0, 1, 37);
INSERT INTO 'dance' VALUES (21212, '2022-12-20 11:01:05.213686+00', '2022-12-20 14:58:59.549563+00', 'Viennese Swing', 'VIENNESE SWING', 5, 32, NULL, NULL, NULL, NULL, 9998, '1973-01-01', 'CD notes it is usually attributed to Tony and Denise Dyer with a date of 1973, however the Dyers don''t recall the dance and doubt they composed it on stylistic grounds.

A video that can''t be embedded on our "video" section can be found at  <<https://www.facebook.com/watch/?v=1635738579860364>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21245, '2023-01-05 11:40:12.314047+00', '2023-01-05 11:40:12.314047+00', 'Hugs and Kisses', 'HUGS AND KISSES', 2, 32, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21214, '2022-12-20 21:24:50.764534+00', '2022-12-20 21:26:50.523499+00', 'Jacky Tar Two-Step, The', 'JACKY TAR TWOSTEP', 11, 16, NULL, NULL, NULL, NULL, 9998, NULL, 'Devised late 18th century.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8749, '1998-12-19 23:00:00+00', '2022-12-31 16:26:19.062654+00', 'Scottish Lilt, The', 'SCOTTISH LILT', 7, 8, 9999, 107, 51, NULL, 9998, NULL, 'Solo Highland man/ woman dance for 8 steps in 9/8 jig. According to D. G. MacLennan in Highland and Traditional Scottish Dances (1950), it originated in Perthshire after 1746. For competitive purposes the dance is usually danced to a completely different tune, a retreat march (also in 9/8 time, but not a jig) called <<ddt:Battle of the Somme#6343>>, by P/M Willie Lawrie.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21238, '2023-01-04 23:11:13.844565+00', '2023-01-04 23:11:13.844565+00', 'Cleo''s Asp', 'CLEOS ASP', 3, 32, NULL, 1, 4, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (13771, '2011-07-13 22:00:00+00', '2022-12-20 23:05:48.12526+00', 'Broadway', 'BROADWAY', 3, 32, NULL, 2, 3, 18, 2973, '2003-08-01', 'I decided to give the name Broadway to this dance, as this famous street cuts diagonally through much of New York City.



Music: I originally stated ''Any good tune'' but later I learned that a band in California was using ''Give My Regards to Broadway'' - for obvious reasons. I therefore asked Marian Anderson to use that tune when she made the Sunday Class Book 2 recording.



Original dance description placed here with the approval of the author

1-8::

  1st couple taking nearer hands dance down the centre for two bars, turn once round with both hands, dance up with nearer hands joined and cast to second place on own side. 2nd couple step up on bars 7 and 8.

9-12::

  2nd, 1st and 3rd couples set and link for three.  Dancers finish in two lines across the set.

13-16::

  Half diagonal rights and lefts: 1st man and 2nd woman, and 3rd man and 1st woman, change on the diagonal to begin. Finish in lines across the set, women at the top facing down, men at the bottom facing up.  2nd couple are on men’s side, 3rd couple on women’s side, 1st couple in the middle.  

17–20::

  Set and link for three.

21-24::

  Half diagonal rights and lefts: Again, 1st man and 2nd woman, and 3rd man and 1st woman, change on the diagonal to begin.  All finish on opposite side, in order 3, 1, 2.

25-32::

  3rd, 1st and 2nd couples set, half turn and twirl* with partner, and set.  Finish on own side in order 3,1,2.



Repeat from new places.



Note: The figure on bars 9 to 24 is not as difficult as it may seem at first glance.  The dancers on the left hand end of the line in set and link for three are the dancers who stand still during half diagonal rights and lefts. The remaining dancers flow into half diagonal rights and lefts. To begin, they look diagonally to their left. (Rule: If there’s no-one diagonally to your left, don’t move!)  

  

*Half turn and twirl:  

Bars 1-2:  Half turn with right hand and remain momentarily face-to-face in middle of set  

Bars 3-4:  Pulling right shoulder back, dance out to place.    

', 75, '800/866/866/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (822, '1998-09-29 22:00:00+00', '2022-12-21 21:33:01.76615+00', 'Broadford Bay', 'BROADFORD BAY', 1, 32, 9999, 1, 3, 42, 478, '1990-01-01', 'Comments by Anne Taylor (formerly Grant) from the description of <<ddd:Moonen Bay>>:



I devised Broadford Bay in 1990 and it appears in the Skye Collection Vol 1 and was adopted by the RSCDS in the Leaflet Dances in 2001. Despite the popularity of the dance, the Chase and Turn movement (Bars 17-24) still appears to pose problems with many dancers.



I have devised Moonen Bay to try to clarify the Chase and Turn movement (Bars 9-16). I have often suggested that Broadford Bay could be taught firstly in Strathspey time which may help the dancers to understand the movement. Good Luck!



Notes from Leaflet 32: "This dance was inspired by the memory of a beautiful sunset over Broadford Bay during the 1990 Isle of Skye Weekend School."', 56, '880  888  880  880', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (14665, '2013-01-21 23:11:03.264239+00', '2022-12-22 10:44:30.232797+00', 'Niles Roberts'' Farewell to Pasadena', 'NILES ROBERTS FAREWELL TO PASADENA', 2, 32, NULL, 1, 3, 42, 12243, '1991-01-01', 'When this dance was originally published the suggested tune was <<ddt:Burns'' Night#3050>>. This is now replaced by <<ddt:Doug Macdonald''s Birthday#13156>> which was subsequently written for the dance as a present to the deviser from his wife <<ddp:Anthea Macdonald#3308|Anthea>>.', 62, '800  888  888  888', 1, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (8146, '1998-10-04 22:00:00+00', '2022-12-22 11:33:42.228214+00', 'Eva Three Step', 'EVA THREE STEP', 11, 16, 9999, 5, 1, 54, 1994, '1904-01-01', 'Neither steps nor the music are anywhere near SCD style. According to the CD inlet of Glencraig''s "Are Ye Dancing''?", the dance was named after the deviser''s daughter Eva.

', 100, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3297, '1997-04-03 22:00:00+00', '2022-12-21 10:25:40.970544+00', 'Joan Warren''s Medley', 'JOAN WARRENS MEDLEY', 4, 28, 9999, 4, 4, NULL, 196, NULL, 'It is quite obvious that the bar count is incorrect as the rest of the information might be. No information on this dance with the deviser mentioned can be found, last checked 2022-12-21. The editors'' team decided to keep the dance in the database for future reference in case some information may be added later.  

<<https://my.strathspey.org/dd/issue/1570/>> ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21239, '2023-01-04 23:12:06.393958+00', '2023-01-04 23:12:06.393958+00', 'Contagion, The', 'CONTAGION', 1, 32, NULL, 1, 3, 42, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21244, '2023-01-04 23:19:01.814382+00', '2023-01-04 23:19:01.814382+00', 'From Prince to King', 'FROM PRINCE TO KING', 2, 32, NULL, 1, 4, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (245, '1998-10-31 23:00:00+00', '2022-12-21 13:40:16.900589+00', 'Arthur''s Seat', 'ARTHURS SEAT', 1, 32, 9999, 1, 3, 42, 251, NULL, 'Opinions differ on the last two bars of this dance (petronella or turn right hand). For detailed discussions of interpretations of historical sources see the following strathspey mailing list threads:

<<sspey-thread:70706>>,

<<sspey-thread:69473>>,

<<sspey-thread:69471>>,

<<sspey-thread:37481>>.

The dance is attributed to Jack McConachie on the basis that his changes from the original are effectively a new dance.', 37, '860/806/800/822', 0, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (21246, '2023-01-05 11:41:07.159408+00', '2023-01-05 11:41:07.159408+00', 'I Don''t Want to be First', 'I DONT WANT TO BE FIRST', 3, 32, NULL, 1, 4, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21215, '2022-12-20 23:20:45.348759+00', '2022-12-22 14:29:01.437689+00', '111100', '111100', 4, 64, 17, 8, 105, 69, 12120, '2022-12-01', 'A present for <<ddp:Gräff, Zoltán#3661>> on the occasion of his birthday.



The progression is (5x,4x,1x,6,3,2) after the strathspey section and (3,6,5,2x,1x,4x) including the jig section if keeping the same numbering throughout.



A recording of suitable music for the dance is available via the online source page <<http://www.bstk.hu/dances/111100/>>', 97, '8888/8888/8888/4884/8888/8888/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (4271, '1999-08-06 22:00:00+00', '2022-12-22 16:33:34.673207+00', 'McLaine of Lochbuie', 'MACLAINE OF LOCHBUIE', 1, 176, 9999, 2, 3, 3, 9998, NULL, 'In <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-033-November-1967.pdf#page=2|issue 33 of The Thistle magazine>> this dance is also given an alternative title McLaine''s Hogmanay which is added as an alias.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21228, '2023-01-04 11:33:59.179282+00', '2023-01-04 11:37:19.948416+00', 'John Rice''s Gift No 1: The Reel', 'JOHN RICES GIFT NO 1 THE REEL', 1, 40, NULL, 1, 3, 42, 12249, '2015-01-01', 'The "devised" entry is an estimation. The deviser notes she could dance again from January 2015 on after her surgery, and the tune to the dance was composed in early 2016.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21229, '2023-01-04 11:43:24.630703+00', '2023-01-04 11:53:29.642884+00', 'John Rice''s Gift No 2: The Strathspey', 'JOHN RICES GIFT NO 2 THE STRATHSPEY', 3, 32, NULL, 1, 3, 42, 12249, '2015-01-01', 'The "devised" entry is an estimation. The deviser notes she could dance again from January 2015 on after her surgery, and the tune to the dance was composed in early 2016.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21248, '2023-01-05 11:43:03.02829+00', '2023-01-05 11:43:03.02829+00', 'Jumelles de Saint Laurent, Les', 'JUMELLES DE SAINT LAURENT', 1, 40, NULL, 1, 2, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21251, '2023-01-05 11:46:49.397609+00', '2023-01-05 11:46:49.397609+00', 'Lifelong Friends', 'LIFELONG FRIENDS', 2, 40, NULL, 2, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21254, '2023-01-05 11:49:21.146513+00', '2023-01-05 11:49:21.146513+00', 'Memories of York', 'MEMORIES OF YORK', 3, 32, NULL, 1, 4, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21255, '2023-01-05 11:50:24.417271+00', '2023-01-05 11:50:24.417271+00', 'Mount Dennis Manifestations', 'MOUNT DENNIS MANIFESTATIONS', 1, 32, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21257, '2023-01-05 11:52:08.621362+00', '2023-01-05 11:52:08.621362+00', 'Our Korean Flowers', 'OUR KOREAN FLOWERS', 1, 32, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21258, '2023-01-05 11:52:48.973278+00', '2023-01-05 11:52:48.973278+00', 'Pansies and Violas', 'PANSIES AND VIOLAS', 1, 32, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21260, '2023-01-05 11:55:34.637075+00', '2023-01-05 11:55:34.637075+00', 'Pyramids of Giza, The', 'PYRAMIDS OF GIZA', 2, 40, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21261, '2023-01-05 11:56:29.801937+00', '2023-01-05 11:56:29.801937+00', 'Roses of Duthie Park', 'ROSES OF DUTHIE PARK', 1, 32, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21262, '2023-01-05 11:57:08.496569+00', '2023-01-05 11:57:08.496569+00', 'Sorrow in September', 'SORROW IN SEPTEMBER', 3, 32, NULL, 2, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (790, '2002-11-02 23:00:00+00', '2022-12-22 18:22:17.285806+00', 'Bride''s Favourite, The', 'BRIDES FAVOURITE', 2, 32, 9999, 1, 3, 42, 725, '1976-01-01', 'This dance was composed for the original music “The Bride’s Favourite” by Steeleye Span on the album “Below the Salt”, CYL 34716 - “Jigs (2009 remaster)”.



This dance has been through a number of changes. The original version was for 2 couples (see <<ddd:Bride''s Favourite (V1), The#11974>>). This was later changed to be a 3 couple dance first published in <<ddpub:Weird But Wonderful#848>>. The first 16 bars of the original 3 couple version were:  

1-8: 1c+2c circle 4H round & back  

9-16: RSh Reels of 3 on sides  

17-24: 1c lead down for 3, up for 3 & cast off  

25-32: 1c+3c RHA; 2c+1c LHA  



In 2020 that was radically changed to the current version starting with 1st couple dancing figure of 8 round 2nd couple and then into mirror reels on the sides.



In the notes for the dance the deviser describes its origin as follows:



*In 1976, during the holidays, I enjoyed having a morning bath and playing music loudly so that I could lie back and listen in a relaxed but concentrated way.  On one such day I was listening to “Below the Salt” and suddenly realised that the track I was listening to was going in eight bar phrases.  No-one else was home so I rushed through to the stereo dripping water everywhere, started that track again, puddled back to the bath,  topped it up with a bit more hot water and lay back to check on the phrasing, count how many phrases in each tune and how many tunes made up the whole piece.  After several more trips through to the stereo and top-ups I had it – 32 bar tunes and 6 of them.  Such evocative music needed a dance to increase the pleasure, so here it is!*', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12753, '2006-05-11 22:00:00+00', '2022-12-22 18:22:56.42458+00', 'Candy Floss', 'CANDY FLOSS', 3, 32, 9999, 1, 3, 42, 725, '1998-01-01', 'This dance was originally composed as a simple strathspey to teach Corners followed by Left Shoulder Reels of Three for 6 bars danced to the music of Sugar Candie .', 47, '880/800/844/866', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (10880, '2002-10-20 22:00:00+00', '2022-12-22 18:25:15.495257+00', 'Dianne Murdoch''s Promenade', 'DIANNE MURDOCHS PROMENADE', 1, 32, 9999, 7, 98, NULL, 725, NULL, 'Ruary writes: 

Turn partner RH and back LH 

Men dance round their partner and back 

Ladies dance their partner and back 

All couples promenade round the room', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (10881, '2002-10-23 22:00:00+00', '2022-12-22 18:28:13.220125+00', 'May Johnston''s Reel', 'MAY JOHNSTONS REEL', 1, 48, 9999, 1, 4, 1, 725, NULL, 'Ruary writes:  

All the men cross Rsh and cast down back to place 

All turn their partner R and L 

All the ladies cross Rsh and cast up back to place 

4th couple cast followed by the other 3 cpls. All turn RH 

1st cpl cast off to the bottom and turn RH

[this seems incomplete.  EricF]', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12756, '2006-05-11 22:00:00+00', '2022-12-22 18:29:24.898458+00', 'New Plymouth Strathspey, The', 'NEW PLYMOUTH STRATHSPEY', 3, 32, 9999, 1, 4, 1, 725, '1993-01-01', '', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (12748, '2006-05-11 22:00:00+00', '2022-12-22 18:32:17.267741+00', 'Wedding Ring, The', 'WEDDING RING', 1, 40, 9999, 7, 5, NULL, 3679, '2001-01-01', 'A group of us (Ruary Laidlaw, Simon Barbour, Glenys Barbour, Christine Miller, Patricia Digby-Smith, Howard McNally, Glenys Pearce, Mary-Ann Goldsmith, Dianne Murdoch, John Murdoch, Bob Polkinghorn, Irene Polkinghorn, Ruth Budden and Peg Stringer) were invited to the wedding of Robyn Fergusson, the NZ Branch secretary, to Brian Howes on the 10th March 2001 in Tauranga in the sunny Bay of Plenty, New Zealand.



On the spot we decided to compose a dance to mark the occasion, which we did while the bride and groom were having their photographs taken. We danced it later on at the reception, much to the DJ''s mystification, to some music that Simon Barbour had saved on his laptop that he just happened to have with him. 



(Dance Crib compiled by the devisers, 2001) ', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (13179, '2006-12-11 23:00:00+00', '2022-12-23 10:45:12.726+00', 'Whirlwind', 'WHIRLWIND', 2, 32, 9999, 1, 3, 42, 2766, '2006-07-01', '<<scddb-not-identical:12789;13729;16505;20205>>



While visiting my family in Ohio, I got to visit Wade and Gatten – a premier nursery for hostas and daylilies. One of the hostas I bought is named Whirlwind. I love the name and this dance reminds me of a whirlwind.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21217, '2022-12-23 15:51:23.478636+00', '2022-12-23 15:51:23.478636+00', 'Fine on Loch Fyne', 'FINE ON LOCH FYNE', 2, 32, NULL, 1, 3, 42, 11262, NULL, 'Devised after receiving a parking fine while visiting Loch Fyne.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21218, '2022-12-23 15:55:35.456+00', '2022-12-23 15:55:35.456+00', 'Nan''s Dance', 'NANS DANCE', 4, 64, 5, 2, 3, 17, 11262, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21219, '2022-12-23 15:58:16.399201+00', '2022-12-23 15:58:16.399201+00', 'Cinq Without Trace', 'CINQ WITHOUT TRACE', 2, 32, NULL, 3, 5, 7, 11262, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21220, '2022-12-23 16:01:08.955192+00', '2022-12-26 00:43:28.658796+00', 'Super Duper Cooper', 'SUPER DUPER COOPER', 2, 40, NULL, 1, 3, 42, 11262, NULL, '10 bar phrases', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21221, '2022-12-23 16:36:43.857624+00', '2022-12-23 23:13:41.728407+00', 'David''s Strathspey', 'DAVIDS STRATHSPEY', 3, 32, NULL, 2, 3, 17, 2874, '2020-02-01', '', 44, '800/888/800/808', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (955, '1998-10-01 22:00:00+00', '2022-12-24 22:35:59.441631+00', 'Calton Hill', 'CALTON HILL', 1, 48, 9999, 2, 3, 17, 270, NULL, '', 35, '800/844/822/800/840/084', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21222, '2022-12-25 19:24:34.446119+00', '2022-12-25 19:24:34.446119+00', 'Progressive Barn Dance', 'PROGRESSIVE BARN DANCE', 11, 8, NULL, NULL, NULL, NULL, 9998, NULL, 'Essentially the first 8 bars of the Dunoon Barn Dance with a progression on bar 4 by advancing to next lady and not to partner.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21223, '2022-12-25 19:28:53.480684+00', '2022-12-25 19:28:53.480684+00', 'White Heather Foxtrot, The', 'WHITE HEATHER FOXTROT', 13, 16, NULL, NULL, NULL, NULL, 9998, NULL, 'Devised around 1817.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21224, '2022-12-25 21:50:01.283844+00', '2022-12-25 21:50:01.283844+00', 'Baden-Powell, The', 'BADENPOWELL', 11, 8, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21225, '2022-12-25 21:59:20.254388+00', '2022-12-25 21:59:20.254388+00', 'Trew Waltz, The', 'TREW WALTZ', 5, 0, NULL, NULL, NULL, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21226, '2022-12-25 22:05:26.439755+00', '2022-12-25 22:05:26.439755+00', 'Siege of Ennis, The', 'SIEGE OF ENNIS', 2, 32, NULL, NULL, NULL, NULL, 9998, NULL, 'Anglicised version of an Irish Ceilidh dance.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21227, '2022-12-25 22:48:57.241543+00', '2022-12-25 22:48:57.241543+00', 'Lion Standard Quadrilles, The', 'LION STANDARD QUADRILLES', 10, 728, NULL, NULL, NULL, NULL, 9998, NULL, '(8 + 32×2 Jig) + (8 + 24×4 Reel) + (8 + 32×4 Jig) + (8 + 32×4 Jig) + (8 + 32×4 Reel) + (32×4 + 16 Jig)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21216, '2022-12-23 15:48:48.520675+00', '2022-12-26 00:04:32.386218+00', 'Aline''s Triangle', 'ALINES TRIANGLE', 1, 32, NULL, 6, 53, 17, 11262, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13387, '2009-11-08 23:00:00+00', '2022-12-26 12:19:26.812524+00', 'Gold and Silver', 'GOLD AND SILVER', 3, 32, NULL, 1, 3, 42, 777, NULL, '»Devised by Dale Birdsall, Shoreham, Vermont. The title, ›Gold and Silver,‹ was easy. The ›Gold‹ is the golden anniversary of the Teachers'' Association (Canada) and the ›Silver‹ refers to the 25 years since I received my preliminary certificate and first joined the TAC. I am proud that my dance was included in this tribute to the great organization of teachers which has done so much to spread the joy of Scottish Country Dancing.«', 58, '866/866/844/666', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (14322, '2011-12-01 23:00:00+00', '2023-01-04 22:35:05.240348+00', 'Wee Green Book, The', 'WEE GREEN BOOK', 1, 96, NULL, 4, 4, 3, 3694, '2009-04-01', 'Source: "Pilling", Supplement to 8th Ed.  

The cover of the "Green Book Set of SCD" names the deviser.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21231, '2023-01-04 22:46:14.420603+00', '2023-01-04 22:46:14.420603+00', 'Abby''s Lullaby', 'ABBYS LULLABY', 3, 32, NULL, 1, 4, NULL, 11981, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21232, '2023-01-04 22:50:06.268533+00', '2023-01-04 22:50:06.268533+00', 'African Queen, The', 'AFRICAN QUEEN', 2, 32, NULL, 1, 3, 42, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21264, '2023-01-05 12:32:36.370967+00', '2023-01-05 12:32:36.370967+00', 'Tears at Niagara', 'TEARS AT NIAGARA', 1, 32, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21265, '2023-01-05 12:34:10.660038+00', '2023-01-05 12:34:10.660038+00', 'Tenor Drummer, The', 'TENOR DRUMMER', 1, 32, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21266, '2023-01-05 12:35:19.523729+00', '2023-01-05 12:35:19.523729+00', 'Three Dancers, The', 'THREE DANCERS', 3, 32, NULL, 2, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21267, '2023-01-05 12:36:01.600657+00', '2023-01-05 12:36:01.600657+00', 'Tristan''s Joy', 'TRISTANS JOY', 2, 32, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21268, '2023-01-05 12:36:44.115021+00', '2023-01-05 12:36:44.115021+00', 'Two Jeans, The', 'TWO JEANS', 3, 32, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21269, '2023-01-05 12:37:31.041921+00', '2023-01-05 12:37:31.041921+00', 'Two Taysides, The', 'TWO TAYSIDES', 3, 32, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21270, '2023-01-05 12:38:30.899557+00', '2023-01-05 12:38:30.899557+00', 'Danse Ravissante, Une', 'DANSE RAVISSANTE UNE', 3, 32, NULL, 2, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21271, '2023-01-05 12:39:12.949786+00', '2023-01-05 12:39:12.949786+00', 'Viral Times', 'VIRAL TIMES', 2, 32, NULL, 1, 3, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21272, '2023-01-05 12:39:59.603696+00', '2023-01-05 12:39:59.603696+00', 'Wedding at Morningside', 'WEDDING AT MORNINGSIDE', 2, 40, NULL, 1, 4, NULL, 11981, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21273, '2023-01-05 12:40:47.321976+00', '2023-01-05 12:40:47.321976+00', 'Sunday Miscellany', 'SUNDAY MISCELLANY', 3, 32, NULL, 1, 4, NULL, 13, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21274, '2023-01-05 12:43:32.977485+00', '2023-01-05 12:43:32.977485+00', 'Delightful Deviser, The', 'DELIGHTFUL DEVISER', 3, 32, NULL, 1, 3, NULL, 12252, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21275, '2023-01-05 12:44:28.299121+00', '2023-01-05 12:44:28.299121+00', 'Sunrise at Birsay', 'SUNRISE AT BIRSAY', 1, 40, NULL, 3, 5, NULL, 12253, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21276, '2023-01-05 12:45:16.462336+00', '2023-01-05 12:45:16.462336+00', 'Towie Ball, The', 'TOWIE BALL', 3, 40, NULL, 2, 3, NULL, 12253, NULL, '

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21230, '2023-01-04 11:53:06.246602+00', '2023-01-05 19:08:03.942988+00', 'John Rice''s Gift No 3: The Medley', 'JOHN RICES GIFT NO 3 THE MEDLEY', 4, 128, 10020, 4, 4, 1, 12249, '2015-01-01', 'The "devised" entry is an estimation. The deviser notes she could dance again from January 2015 on after her surgery, and the tune to the dance was composed in early 2016.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3649, '1997-09-07 22:00:00+00', '2023-01-05 23:08:46.844487+00', 'Laigh o'' Moray, The', 'LAIGH O MORAY', 4, 160, 10048, 2, 3, 3, 93, NULL, 'The crib claims the central section is a reel but it should be a jig (<<https://my.strathspey.org/dd/issue/2899/|issue 2899>>). To be fixed by the crib author.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17418, '2016-10-19 21:24:17.282367+00', '2023-01-07 12:31:41.350431+00', 'Puggy, The', 'PUGGY', 2, 32, 9999, 1, 4, 1, 10912, NULL, 'There are some variants of this dance suggested by the devisor:

- The Puggy 1a: uses circles 8-hands round and back on bars 1-8 and 17-24.

- The Puggy 1b: if danced with 3 couples, the circles are 6-hands round and back on bars 1-8 and 17-24.

- The Puggy 2: uses circles 4-hands round and back on bars 1-8 and 17-24 for the top two and bottom two couples, respectively.



(rf. <<http://www.scottish-country-dancing-dictionary.com/dance-crib/puggy.html|The Puggy 1>> and <<http://www.scottish-country-dancing-dictionary.com/dance-crib/puggy-2.html|The Puggy 2>> at the Scottish Country Dancing Dictionary)



The Puggy was the nickname of the steam­driven, 0-4-0 locomotives used for shunting and short­haul work in many industrial locations (notably distilleries and shipyards) in Scotland.

Bars 1-8 represent the driving wheels starting and reversing;

in bars 9-16, the puggy is moving around the goods yard;

bars 17-24 represent the driving wheels starting and reversing again;

in bars 25-32, the puggy takes three trucks around the goods yard and shunts them back into the siding.



(Source: <<http://www.scottish-country-dancing-dictionary.com/dance-crib/puggy.html|Scottish Country Dancing Dictionary>>)', 81, '8888/8000/8888/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (5203, '1997-09-11 22:00:00+00', '2023-01-07 12:51:17.295062+00', 'Peggy McGhie''s Reel', 'PEGGY MACGHIES REEL', 1, 32, 9999, 1, 3, 42, 99, '1988-02-01', 'Inscribed "For my mother". Originally devised in January 1987 and updated in February 1988.



This was previously wrongly spelled in the database as "Peggie" rather than "Peggy". This is now corrected but the former is kept as a (mis)spelling alias.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21285, '2023-01-12 15:19:18.629802+00', '2023-01-12 15:19:18.629802+00', 'Glengarry Waltz, The', 'GLENGARRY WALTZ', 5, 208, NULL, 4, 4, NULL, 9998, NULL, 'W64+W32+W80+W32  

The publication states: "It dates from the time of the Great War, and comes from Norway, having been composed by Norwegians who were very fond of the Scottish waltz tunes."', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21287, '2023-01-12 15:50:15.202556+00', '2023-01-12 15:50:15.202556+00', 'Meeting of the Waters, The', 'MEETING OF THE WATERS', 1, 128, NULL, 107, 122, NULL, 9998, NULL, 'Can be danced by 16 persons as well. Structure: (Intro March 32 bars to start the dance) + R8x16', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21288, '2023-01-12 15:58:35.354858+00', '2023-01-12 15:58:35.354858+00', 'Portree Lassies, The', 'PORTREE LASSIES', 1, 152, NULL, NULL, 4, NULL, 9998, NULL, 'Intro+R32+R6x16+R24', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16856, '2016-01-19 11:17:01.673247+00', '2023-01-08 10:55:27.075426+00', 'Badgers'' Sett, The', 'BADGERS SETT', 2, 32, NULL, 1, 100, 2, 11235, '2014-07-01', 'Devised for Keith and Hazel Brockie of the Camserney group near Aberfeldy.', 69, '8008/8448/8888/4444', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21283, '2023-01-12 15:06:50.453492+00', '2023-01-12 15:06:50.453492+00', 'Dirk Dance, The', 'DIRK DANCE', 4, 0, NULL, NULL, NULL, NULL, 9998, NULL, 'The linked publication states: "Colin Robertson commented in September 2018 The Dirk Dance was bought by Tom Flett who passed on to John Wesencraft who in turn passed the dance on to Jane Harrison, daughter of Tom and Joan Flett. The reason for all the passing on was that Mrs MacNab insisted that the dance should only ever be known by two living persons at any one time (Great way to preserve a Heritage). This was the agreement that Tom took with the dance, but when Tom died Joan did not feel obliged to maintain that agreement and published the dance in Traditional Step-Dancing In Scotland in 1996."', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21290, '2023-01-12 16:10:56.673955+00', '2023-01-12 16:10:56.673955+00', 'Sword Dance of Culloden, The', 'SWORD DANCE OF CULLODEN', 7, 140, NULL, 107, 54, NULL, 9998, NULL, 'A sword dance for 4 men. Structure: S4x8+M8+R8+R4x4+R4x16+R12 (8 steps)', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21291, '2023-01-12 16:16:10.218931+00', '2023-01-12 16:16:10.218931+00', 'Waltz Cotillion', 'WALTZ COTILLION', 5, 272, NULL, 4, 4, NULL, 9998, NULL, 'W32+W3x80', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21292, '2023-01-12 16:26:06.415457+00', '2023-01-12 16:26:06.415457+00', 'Weaving Lilt, A', 'WEAVING LILT', 50, 0, NULL, 1, 4, NULL, 9998, NULL, 'Structure: Intro 4 bars; 76 bars fixed; an amount of bars needed (flexible)  

The publication states: "(...) collected (...) from Lief Hansen, of central Canada. Mr. Hansen is of Norwegian descent."', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21278, '2023-01-07 13:41:10.25273+00', '2023-01-07 13:41:10.25273+00', 'Thelma''s Jig', 'THELMAS JIG', 2, 32, NULL, 1, 4, 1, 127, NULL, 'Source: <<https://www.scottish-country-dancing-dictionary.com/dance-crib/thelmas-jig.html>>.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21277, '2023-01-07 11:31:00.770084+00', '2023-01-07 13:42:41.865376+00', 'Westcott Reel', 'WESTCOTT REEL', 1, 40, NULL, 1, 4, 1, 10333, NULL, 'Ceilidh dance, for children''s class', 85, '8888/8888/8888/8000/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21293, '2023-01-12 16:27:47.286431+00', '2023-01-12 16:30:36.67725+00', 'Whirlygig', 'WHIRLYGIG', 50, 0, NULL, 107, 117, NULL, 9998, NULL, 'Structure: 37 bars + whatever needed.  

A dance for six men. The publication states: "(...) collected (...) from Hector MacPherson of Lochboisdale."', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21295, '2023-01-12 17:24:53.422601+00', '2023-01-12 17:24:53.422601+00', 'Salute to MacNab, A', 'SALUTE TO MACNAB', 7, 0, NULL, 107, 51, NULL, 9998, NULL, 'A solo sword dance. Introduction + 6 steps.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21294, '2023-01-12 17:21:53.394848+00', '2023-01-12 17:25:36.957032+00', 'Caller Herrin, The', 'CALLER HERRIN', 7, 56, NULL, 107, 99, NULL, 9998, NULL, 'For more info visit the linked resource. Structure: Intro4+6x8+4', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5997, '1997-04-03 22:00:00+00', '2023-01-12 18:41:02.926126+00', 'Selwyn Strathspey, The', 'SELWYN STRATHSPEY', 3, 32, 9999, 1, 3, 42, 219, '1990-11-01', 'Inscribed "for Eddie Selwyn."', 50, '800/888/888/800', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21150, '2022-10-16 21:12:45.671007+00', '2023-01-07 16:18:56.870818+00', 'Hutton''s Unconformity', 'HUTTONS UNCONFORMITY', 3, 32, NULL, 1, 4, 5, 11237, '2022-06-01', 'The dance starts with two chords.

On the second chord 3rd woman and 4th man change places so that 1st and 2nd couples are facing their partner while 3rd and 4th couples are beside their partner.



This dance commemorates James Hutton (1726-1797) one of Scotland''s foremost scientists who is considered the founder of modern geology.

He was one of the first to realise that weathering of rock formations showed the Earth was far older than was assumed at the time.

Most famously he found several "unconformities" where strata of sedimentary rocks clearly overlaid older strata at a very different angle indicating that the older rocks must have been raised up from the sea bed, turned over so the strata were vertical, then sunk again and later covered with new sedimentary layers and raised up a second time.



The cross, cast off and dance down figures indicate build up of the sedimentary layers (perhaps silt carried by rivers and falling to the sea floor).

These are compressed when 1st and 2nd couples end closer together by bar 16 than at bar 9.

The rock layers are turned in bars 17-24.

The last figure has a hint of more sedimentation but is mainly oriented across at the top and up/down at the bottom like a typical unconformity.



For more information about unconformities see <<https://en.wikipedia.org/wiki/Hutton%27s_Unconformity>>. One of the notable unconformities in Scotland is on the island of Arran. See <<http://www.arrangeopark.co.uk/wp-content/uploads/Walk_Leaflets/1.%20Hutton.pdf>> and <<https://www.scottishgeology.com/best-places/isle-of-arran/>>.', 72, '8400/8800/8888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1787, '2002-02-28 23:00:00+00', '2023-01-07 22:30:23.37635+00', 'Duke of Edinburgh''s Welcome to Shetland, The', 'DUKE OF EDINBURGHS WELCOME TO SHETLAND', 1, 128, 9999, 4, 4, 54, 10990, NULL, 'The printed dance sheet states: "This is a Shetland square dance for four couples. (...) The music is of a slow reel rhythm and because of the Duke of Edinburgh''s connection with the Royal Navy, it has a hornpipe lilt. To a Scottish Country Dancer the Shetland steps are danced low on the balls of the feet, the setting step similar to the Strathspey step but slightly faster."', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (17768, '2017-05-29 07:34:59.265646+00', '2023-01-08 10:22:06.084558+00', 'Do Not Stop', 'DO NOT STOP', 1, 32, NULL, 1, 3, 42, 11487, '2017-01-01', '''This dance was written in 2017 after Spring Fling and Spring School (in Kazan) when, sadly, I had to go back to the working routine. At work I ached with the feeling of sudden “stop”: why am I not hurrying anywhere, not dancing? My wish to keep going at last turned into this dance, where the main idea is – “Go ahead, do not stop!”  

The combination of RHA and LHA in the dance came to me when I thought of Bennett Mechanical Comprehension Test – for me the process of learning or devising new dance looks rather similar to working on that test.''





No tune is recommended but the video uses the recording <<ddrec:Black Dance, The#5799>> by <<ddp:Bobby Brown and The Scottish Accent#3067>>.', 50, '800/888/888/800', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3245, '1997-04-03 22:00:00+00', '2023-01-10 19:55:03.375532+00', 'Jessie''s Fancy', 'JESSIES FANCY', 1, 40, 9999, 1, 3, 42, 372, NULL, 'Inscribed "For lessle Rhode who for many years danced at the Great Ayton class".', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2700, '1998-09-29 22:00:00+00', '2023-01-09 15:37:20.557936+00', 'Guidman of Balangigh, The', 'GUIDMAN OF BALANGIGH', 2, 32, 9999, 1, 2, 76, 446, '1728-01-01', 'The original name in Playford 1703 was "The Geud Man of Ballangigh". The spelling seems to have changed over time, eg single or double L. The name is a reference to King James V of Scotland.', 43, '62  26  44  88', 1, 1, 1, 1, 62);
INSERT INTO 'dance' VALUES (6959, '1997-04-03 22:00:00+00', '2023-01-09 23:34:16.54232+00', 'Waves of Tory, The', 'WAVES OF TORY', 1, 48, 9999, 3, 5, 16, 9998, NULL, 'Video 1 shows an "Instructional video from RSCDS archives" for this ceilidh dance, which seems to be the most common spread version in Scotland. The crib refers to this video. Can be danced as Reel or Jig, recordings for both versions exist.  

There are Irish Ceili dances and English Country Dances with the same name; their descriptions and structure do not suit Scottish Country Dancing. Yet, you can encounter other SCD descriptions for that dance that are partially influenced by bits and pieces of the Irish or English version, and it may also be danced in a 4 couple set. It is not possible to feature all those variations. ', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (15737, '2015-01-09 15:38:07.292971+00', '2023-01-10 11:25:35.123604+00', 'Five O''Clock from Welshpool, The', 'FIVE OCLOCK FROM WELSHPOOL', 1, 32, 9999, 3, 5, 7, 3694, '2009-05-31', 'Inscribed "For Sally McGurn who made the long journey from Welshpool on the five o’clock train to classes in Birmingham. One of her favourite formations is corner pass and turn."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3511, '1997-04-03 22:00:00+00', '2023-01-10 11:29:22.727792+00', 'Kinnessburn Reel', 'KINNESSBURN REEL', 1, 32, 9999, 1, 3, 42, 313, NULL, 'From the notes: "The Kinness will be familiar to those who have attended the R.S.C.D.S. Summer School as the burn which flows through St. Andrews."', 62, '800  888  888  888', 1, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (3351, '1997-04-03 22:00:00+00', '2023-01-10 13:21:24.405453+00', 'Jordanhill Strathspey, The', 'JORDANHILL STRATHSPEY', 3, 32, 9999, 1, 3, 42, 146, NULL, 'Inscribed "For Claire Goodman."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21197, '2022-12-10 21:38:58.748861+00', '2023-01-10 18:42:56.529413+00', 'Off Axis', 'OFF AXIS', 3, 32, NULL, 1, 3, 42, 2766, '2022-03-01', 'I wrote this as I was thinking about set and link for 3 couples and the dance Glayva.', 56, '844/088/888/844', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3349, '1997-09-05 22:00:00+00', '2023-01-10 19:30:01.612658+00', 'Jones Falls Jig, The', 'JONES FALLS JIG', 2, 32, 9999, 1, 3, 42, 488, NULL, 'From the notes: "Devised on the 150th Anniversary of the Rideau Canal in Ontario, and presented at Jones Falls, on the Rideau, at the 5th Annual Jones Falls Weekend of the Ottawa Branch of the R.S.C.D.S."', 50, '822/888/833/833', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (3331, '1997-09-05 22:00:00+00', '2023-01-10 19:42:02.76729+00', 'John Sinton''s Strathspey', 'JOHN SINTONS STRATHSPEY', 3, 48, 9999, 8, 105, 49, 108, '1977-01-01', 'John Drewry wrote in the original description: *A dance for John Sinton, who plays the bass

in Jim Macleod''s band at Dunblane Hydro. A large dance for a large instrument!*



Furthermore, he writes:



*There are three basic positions in the dance, because 6th couple dance

similar figures to 1st couple (but from the opposite end of the set),

5th couple dance similar figures to 2nd couple, and 4th couple to 3rd couple.*



and



*Two repeats are probably sufficient, then

each couple will have danced from 1st or 6th position, from 2nd or 5th

position and f rom 3rd or 4th position.*', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (3233, '1998-02-26 23:00:00+00', '2023-01-10 19:59:52.59405+00', 'Jennifer''s Reel', 'JENNIFERS REEL', 2, 32, 9999, 1, 3, 42, 109, NULL, '"Dedicated to a bright young lady who later became my wife (1969)."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21279, '2023-01-09 23:14:00.45316+00', '2023-01-10 23:04:04.638576+00', 'Sliding in the Snow', 'SLIDING IN THE SNOW', 2, 32, NULL, 1, 4, 2, 11225, NULL, '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21281, '2023-01-12 14:55:27.732123+00', '2023-01-12 14:55:27.732123+00', 'Bronach', 'BRONACH', 5, 48, NULL, 107, 53, NULL, 9998, NULL, '6 "steps" (aka figures), 8 bar each.  

Dance collected by Mary Isdale MacNab in North Carolina.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21280, '2023-01-12 14:50:49.157556+00', '2023-01-12 14:56:13.506892+00', 'Bonnie Prince Charlie', 'BONNIE PRINCE CHARLIE', 4, 84, NULL, 107, 4, NULL, 9998, NULL, 'S16(slow)+S20(faster)+R16+W32  

Dance collected by Mary Isdale MacNab in North Carolina.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21282, '2023-01-12 15:01:45.743619+00', '2023-01-12 15:01:45.743619+00', 'Cameronian Rant, The', 'CAMERONIAN RANT', 1, 108, NULL, 107, 122, NULL, 9998, NULL, 'R4(intro)+R6x16+R8', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21284, '2023-01-12 15:13:39.101358+00', '2023-01-12 15:13:39.101358+00', 'Double Sword Dance', 'DOUBLE SWORD DANCE', 7, 0, NULL, 107, 135, NULL, 9998, NULL, 'The publication states: "Scottish Dance Teacher''s Alliance - Notes from December 1969: Double Sword Dance may not be attributed to Mary MacNab"  

Structure of the dance: Intro + Strathspey + Reel', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21286, '2023-01-12 15:24:35.66565+00', '2023-01-12 15:24:35.66565+00', 'Lewis Bridal Dance', 'LEWIS BRIDAL DANCE', 1, 136, NULL, 1, 4, NULL, 9998, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21296, '2023-01-12 19:18:26.60219+00', '2023-01-12 19:29:28.032142+00', 'Shapinsay Polka', 'SHAPINSAY POLKA', 13, 64, NULL, 5, 1, NULL, 264, '2003-01-01', 'Dance devised for the St Magnus Festival, Orkney, 2003. First performed as part of the choreographic piece – Elements. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21297, '2023-01-12 19:33:12.022412+00', '2023-01-12 19:33:12.022412+00', 'Queen Mary Two Step', 'QUEEN MARY TWO STEP', 11, 32, NULL, 5, 1, NULL, 264, '2007-10-01', 'Dance devised on board the Queen Mary 2 crossing the Atlantic from Southampton to New York and back with the Ian Muir Sound.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21299, '2023-01-12 19:40:17.750884+00', '2023-01-12 19:40:17.750884+00', 'Loch Aineort Two Step', 'LOCH AINEORT TWO STEP', 11, 32, NULL, 5, 1, NULL, 264, '2019-07-01', 'Inspired by, and dedicated to, the dancers of the Uists: Locheynort; St Peters, Daliburgh; Carinish, and beyond.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21300, '2023-01-12 19:46:41.232852+00', '2023-01-12 19:46:41.232852+00', 'Piper''s Schottische', 'PIPERS SCHOTTISCHE', 13, 32, NULL, 5, 1, NULL, 264, '2014-01-01', 'Deviser states: "Piper’s Schottische is based on the aesthetic dance style of the Scottish Highlands and Islands. The dance was initially inspired by the Port-a-Beul: Hara Hibhi which is featured on Gillebride MacMillan’s album Air Forladh. It can however be danced to any good recording of the Highland Schottische."  

Editor''s note: not a typical Polka, but with Polka elements.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (8152, '1998-10-04 22:00:00+00', '2023-01-12 22:54:01.880134+00', 'Mississippi Dip', 'MISSISSIPPI DIP', 50, 32, 9999, 5, 1, 54, 1999, NULL, 'Ceilidh type dance, couples in ballroom hold, man with back to centre of room.  

In 2/4 the dance has 32 bar phrases, in 4/4 count it has 16 bars. Each set of known instructions is slightly different, mainly in how to do the "dip", and whether the couples waltz or polka in certain sections.  

  

Dance originally devised by Charles Wood. Collected by Nan Lawson.





', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21298, '2023-01-12 19:36:31.747863+00', '2023-01-13 11:26:20.774311+00', 'Lena of Boisdale''s Waltz', 'LENA OF BOISDALES WALTZ', 5, 32, NULL, 5, 1, NULL, 264, '2018-01-01', 'To Lena MacLellan of Boisdale in recognition for her work as a dance teacher in South Uist on the occasion of the St Peters Traditional Dance Club’s 20th Anniversary on 7 July 2018.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (3614, '1997-04-03 22:00:00+00', '2023-01-13 22:01:30.173607+00', 'Lady Louisa Macdonald Of Sleat', 'LADY LOUISA MACDONALD OF SLEAT', 7, 192, 9999, 107, 51, 54, 319, NULL, 'The instructions specify 6 steps of 32 bars; in some steps the second 16 are optional. For step 2 a triangular pattern is specified, and for step 16 a square pattern, but in the Summer School 2001 demonstration all dancers dance solo without forming these patterns. This database entry is made for the demo version.', 100, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17023, '2016-06-11 15:38:31.298988+00', '2023-01-14 15:47:29.782616+00', 'Masters Of Art, The', 'MASTERS OF ART', 3, 32, NULL, 2, 104, 17, 11237, '2016-05-01', 'Dedicated to Barrie Gabbott and Cos Ahmet, excellent teachers and practitioners of Art, with abiding thanks for being the leading lights of the London Gay Gordons for so many years.', 93, '886/888/888/848', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (16887, '2016-02-29 01:40:13.898643+00', '2023-01-14 16:02:06.559314+00', 'Quarries'' Procession', 'QUARRIES PROCESSION', 1, 40, 9999, 1, 4, 11, 11237, '2015-05-01', 'A challenging farewell for David and Avril Quarrie on the occasion of their moving from Geneva back to the Hamburg area where they first met.



*Notes from the book:*



The dance includes St Andrews and St Georges cross figures, then the 1st couple make a metaphorical procession around the four corners of the globe dancing with various people for a while and then moving on to a new corner. This is supposed to reflect the Scottish and English backgrounds of Avril and David respectively and their successive sojourns in or near Hamburg (the centre) then Virginia, Chicago, San Francisco, Geneva and finally returning to Hamburg, continually meeting new friends but sadly leaving old ones behind - after the old friends have been trained up to be better dancers!



The dance starts with a little broken symmetry, appropriate for a particle physicist, as the men and women do something slightly different and it ends with the 1st couple finally getting to dance more with each other, turning RH into retirement to their new home in 2nd place while their most recent friends, the 4s, spiral out singly to 3rd place.

', 77, '8008/8888/8884/8668/8228 ', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (19309, '2019-05-11 12:40:36.365254+00', '2023-01-14 16:22:09.253546+00', 'World Wide Web, The', 'WORLD WIDE WEB', 2, 32, NULL, 3, 129, 33, 11237, '2013-01-01', 'This demonstration dance is intended as a homage to the wonder of the modern world and contains various W-like formations and a sequence of set and link figures in reference to the network of hyperlinks that comprise the web. The final circle might be viewed as representing the world (in elliptical projection).', 95, '86684/88888/88888/88888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (17758, '2017-05-21 09:16:42.79215+00', '2023-01-14 16:42:33.072176+00', 'Simone''s Serendipitous Meeting', 'SIMONES SERENDIPITOUS MEETING', 2, 32, NULL, 1, 3, 42, 11237, '2016-03-01', 'Simone, who is originally from Belgium, met her future husband there for a month and

then corresponded for four years before joining him in London. Despite thinking she knew

everything about him she had unfortunately neglected to ask Ron if he shared her passion

for dancing and was very upset to find he did not.



One day in church she poured out her disappointment to the complete stranger who happened

to be sitting next to her. This kind lady recommended she try Scottish Country Dancing

where she could come without a partner. Simone was immediately hooked and was

subsequently taught and examined as a qualified RSCDS teacher by the redoubtable

founder of the RSCDS, Miss Milligan, who praised her for “teaching so well in a foreign

language”. Fifty years later Simone still teaches weekly at the Epping Forest Scottish

Association.', 48, '430 888 880 824', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3169, '1997-09-04 22:00:00+00', '2023-01-14 21:44:02.748997+00', 'Itchenor Strathspey', 'ITCHENOR STRATHSPEY', 3, 32, 9999, 1, 3, 42, 377, '1988-01-01', 'Inscribed "for Dorothy Murray an indefatigable worker for good causes and Honorary Treasurer of West Wittering Reel Club."', 50, '888/800/844/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21191, '2022-12-04 22:26:21.969495+00', '2023-01-16 17:11:20.892228+00', 'Summer Superstars', 'SUMMER SUPERSTARS', 1, 32, NULL, 1, 3, 42, 11237, '2022-09-01', 'Dedicated to Graham and Caroline Hamilton with many thanks for having run the London Summer Tuesdays seasons for such a long time.

', 53, '880/824/824/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (10370, '2002-03-10 23:00:00+00', '2023-01-17 11:49:24.136696+00', 'Entertainer, The', 'ENTERTAINER', 3, 32, 9999, 1, 4, 13, 2994, NULL, 'Devised in honour of Hugh Reekie on the 25th Anniversary of the entertainment Group of the RSCDS Ottawa Branch. Deviser states: "Music: The Blue Mess Jacket or other suitable strathspey" which seems to point to a recording, not a tune. ', 97, '8888/8888/8884/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21305, '2023-01-17 22:25:09.879625+00', '2023-01-17 22:25:09.879625+00', 'Curse of Scotland, The', 'CURSE OF SCOTLAND', 1, 32, NULL, 107, 111, NULL, 12254, '2015-12-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21306, '2023-01-17 22:29:09.032046+00', '2023-01-17 22:29:09.032046+00', 'Fünf (Bavarian Five)', 'FUNF BAVARIAN FIVE', 1, 32, NULL, 3, 5, NULL, 12254, '2012-06-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21307, '2023-01-17 22:35:19.59446+00', '2023-01-17 22:35:19.59446+00', 'Golden Pinwheels', 'GOLDEN PINWHEELS', 1, 32, NULL, 1, 4, NULL, 12254, '2013-11-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21308, '2023-01-17 22:38:55.477913+00', '2023-01-17 22:38:55.477913+00', 'Isle of Skye', 'ISLE OF SKYE', 1, 32, NULL, 1, 3, NULL, 12254, '2012-06-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21309, '2023-01-17 22:42:20.298793+00', '2023-01-17 22:42:20.298793+00', 'Joyous', 'JOYOUS', 1, 32, NULL, 1, 114, 2, 12254, '2018-12-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21302, '2023-01-17 22:11:58.135865+00', '2023-01-17 22:49:11.595824+00', 'Around the Rugged Rock', 'AROUND THE RUGGED ROCK', 1, 32, NULL, 1, 3, 42, 12254, '2011-09-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21303, '2023-01-17 22:15:44.861949+00', '2023-01-17 22:49:48.123648+00', 'Away to Woodford', 'AWAY TO WOODFORD', 1, 32, NULL, 1, 100, 22, 12254, '2014-12-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21304, '2023-01-17 22:19:37.352483+00', '2023-01-17 22:50:18.797902+00', 'Claddagh', 'CLADDAGH', 1, 32, NULL, 1, 3, NULL, 12254, '2016-03-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21311, '2023-01-17 22:47:51.96326+00', '2023-01-17 22:47:51.96326+00', 'St. Andrew''s Cross', 'SAINT ANDREWS CROSS', 1, 32, NULL, 1, 3, NULL, 12254, '2012-11-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21301, '2023-01-17 22:09:12.540009+00', '2023-01-17 22:48:38.905111+00', 'All the Rivers Run', 'ALL THE RIVERS RUN', 3, 32, NULL, 1, 4, 2, 12254, '2013-09-01', '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (18110, '2017-12-13 14:45:57.437392+00', '2023-01-18 16:30:40.774958+00', 'Bruntsfield Mondays', 'BRUNTSFIELD MONDAYS', 2, 32, NULL, 1, 2, 76, 550, '2008-01-01', '', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (11267, '2003-03-19 23:00:00+00', '2023-01-18 16:50:32.090845+00', 'Skagits in Stockbridge', 'SKAGITS IN STOCKBRIDGE', 3, 32, 9999, 1, 100, 2, 550, '2003-01-01', 'The dance is dedicated to Leslie (nee Henderson) and Peter Hastings. Peter and Leslie got married on the 26th of March, 2001 in the company of members of the Skagit SCD group in Annacortes, WA, and held a ball in celebration on the 27th of June, 2002, in Cluny Church Hall, Edinburgh. At the time of the celebration they were living in Stockbridge in Edinburgh.



This dance starts with two chords. On the 2nd chord 3rd and 4th couples cross to opposite side.



(Source: a copy of this dances was published in the "Dance On!" magazine together with the above information.)', 75, '8008/8448/8448/8888', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (8104, '2002-08-29 22:00:00+00', '2023-01-18 16:54:20.894769+00', 'Canonbie Ceilidh, A', 'CANONBIE CEILIDH', 1, 40, 9999, 7, 1, 4, 1853, '1996-01-01', 'This dance was devised for Hazel Easey and James Williams and presented to them on the occasion of their wedding in Canonbie, Dumfriesshire on August 24th, 1996.  © Caroline Bradshaw and Ian Brockbank, May 1996   Originally published in the New Scotland 50th Anniversary book of dances.



Bars 29-32 modified 1999 to stop the men overextending their arms in the arches.  In a private message the devisers wrote:



The original version has the men in the centre on 29-32 instead of the ladies.  This means that they are trying to move out while making arches, which means the circle has to expand, and something has to give, which makes it difficult.  With the ladies in the centre, the men are moving in, and the arches are shrinking instead.



The link to the original description has been removed to avoid perpetuating the obsolete text.', 80, '88  80  08  88 88', 1, 1, 1, 1, 80);
INSERT INTO 'dance' VALUES (2698, '1997-09-03 22:00:00+00', '2023-01-20 19:26:55.585035+00', 'Guid To Ken Ye', 'GUID TO KEN YE', 1, 32, 9999, 5, 2, NULL, 977, NULL, 'The deviser writes that "I wrote this dance so dancers could meet more folk - namely three couples instead of the usual one with each repetition of the dance."', -1, '', 0, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (6948, '1997-04-03 22:00:00+00', '2023-01-19 21:01:00.210284+00', 'Watergate Caper, The', 'WATERGATE CAPER', 4, 128, 2, 3, 5, NULL, 280, NULL, 'Devised for Pinewoods in 1973. No further information on this dance with the deviser mentioned can be found, last checked 2022-12-21. The editors'' team decided to keep the dance in the database for future reference in case some information may be added later.  

<<https://my.strathspey.org/dd/issue/1572/>>', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (5736, '1998-01-04 23:00:00+00', '2023-01-19 21:59:02.343225+00', 'Royal Auction', 'ROYAL AUCTION', 1, 28, 9999, 1, 3, 42, 24, NULL, 'Editor''s note: *This dance was in honor of the memorable May Ball, 1981, in Sacramento when a dance with Jean Patrick was auctioned off to the highest bidder to help pay Ball expenses. She brought $47.51--sold to the Scot who added the final penny and claimed his dance. The dance is also a pleasant alternative to the named tune for Princess Royal--as recorded by the Berkeley Scottish Players.*', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (16243, '2015-05-01 13:50:29.607682+00', '2023-01-19 23:13:01.253291+00', 'Wye Valley Strathspey', 'WYE VALLEY STRATHSPEY', 3, 64, 5, 6, 3, NULL, 84, '2005-01-01', 'A 64 bar strathspey in two 32 bar parts for three couples in a ''Y'' shaped triangular set.



The database editors'' copy of "Tom''s Book" looks like an original, but still this dance has an erroneous description: there is no progression.  That is why no correct e-crib could be made.', 87, '444/12,12,12/444/440/044/404/repeat', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3142, '1997-09-04 22:00:00+00', '2023-01-20 11:10:30.856695+00', 'Island Fling, The', 'ISLAND FLING', 2, 32, 9999, 1, 3, 42, 850, '1980-09-01', 'The dance is dedicated with compliments to Betty and David Grant of the George C. Armstrong group, who held "The Island Fling" annually at the Royal Canadian Yacht Club, Toronto Island.', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (16754, '2015-09-20 15:15:22.693369+00', '2023-01-19 12:40:04.673466+00', 'Cariboo Capers', 'CARIBOO CAPERS', 1, 32, 9999, 1, 3, 42, 11041, NULL, 'From the notes: This dance is dedicated to my new multi-generational family home on Cariboo Crescent. Here I''ve experienced the joy, excitement and laughter of being a parent and a grandparent all at once. This has become my third home which perhaps makes it, and myself, "three times lucky."', 61, '868/888/888/800', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (3114, '1997-11-24 23:00:00+00', '2023-01-20 11:29:04.888601+00', 'Inverugie Castle', 'INVERUGIE CASTLE', 4, 64, 17, 1, 4, 3, 514, NULL, 'The notes say this is dedicated to Bob Ritchie who for many years teased Leicester teachers about a dance bearing this name. The figures relate to his description of the area :-  

Bars 1 - 8 portray the River Ugie,  

9 - 16 depict the two castles, Inverugie and Ravenscraig,  

17 - 24 represent the communal Fish House originally used by both castles and  

25 - 32 life in the two castles.



When the dance was being devised Bob was not very well but on his recovery he was ''raring to go'' hence the reason why the women dance the first figure in strathspey time and the men dance it in jig time.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2183, '1997-09-02 22:00:00+00', '2023-01-19 13:46:10.554792+00', 'Fiona''s Wedding', 'FIONAS WEDDING', 3, 78, 9999, 4, 4, NULL, 11229, NULL, 'The publication states: "Recommended tune: Fiona''s Wedding (...) This dance was devised to fit the recording of Fiona''s Wedding which has a four bar introduction, 72 bars of vocal and a two bar coda."', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (2834, '1997-04-03 22:00:00+00', '2023-01-20 12:04:55.271505+00', 'Heather Braes Strathspey', 'HEATHER BRAES STRATHSPEY', 3, 32, 9999, 1, 3, 42, 28, NULL, '', 69, '888/888/888/448', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2667, '1997-09-03 22:00:00+00', '2023-01-20 19:39:47.254711+00', 'Green Mountain Jig, The', 'GREEN MOUNTAIN JIG', 2, 32, 9999, 1, 2, 76, 371, NULL, 'The dance, like Vermont''s Green Mountains, is interesting without being particularly rugged.  The only occasionally troublesome point is that second man and second lady must remember to step up on bars 3-4 and 7-8 respectively.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2752, '1997-09-03 22:00:00+00', '2023-01-20 12:15:29.39502+00', 'Hamish McThistle', 'HAMISH MACTHISTLE', 1, 48, 9999, 1, 3, 42, 742, NULL, 'According to the notes "Hamish McThistle is the name given to the figure of a dancing thistle, which is the emblem of the Colleges Club in Newcastle."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (13149, '2006-12-11 23:00:00+00', '2023-01-20 18:15:37.172024+00', 'Barbara''s Strathspey', 'BARBARAS STRATHSPEY', 3, 32, 9999, 1, 3, 42, 2766, '2006-04-01', 'Deviser states in the original publication: *This dance was written for Barbara Cool, the leader of our Branch demo team. Suggested music is Lady Lucy Ramsay from Gang on the Same Gate by Green Ginger.* 

When this dance was later published in Book 46, it got its own tune.', 56, '800  844  888  888', 1, 1, 1, 1, 75);
INSERT INTO 'dance' VALUES (2702, '1997-09-03 22:00:00+00', '2023-01-20 19:22:35.459105+00', 'Guisborough Lassies', 'GUISBOROUGH LASSIES', 3, 32, 9999, 1, 4, 1, 536, NULL, '', 42, '8200/8800/8080/8022', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (12432, '2005-05-09 22:00:00+00', '2023-01-20 22:15:56.132549+00', 'La Salle Causeway, The', 'SALLE CAUSEWAY', 1, 48, 9999, 4, 4, 1, 3606, '2005-04-01', 'Devised by Evalyn Eder in April 2005 and first published in The Seventh Martello Tower Book of Dances. Modified in March 2007 ("Madoma" version). The Madoma version reflected here is 4x48; the Martello version supposedly had 4x40 bars. Hence this dance is linked to different recordings for these two versions.  

The Madoma version states: "May be danced to: Solway Reel." The editors think this refers to the recording, not a tune.



The La Salle Causeway is the main crossing from Kingston across the Cataraqui River towards the previous Pittsburgh Township and Gananoque.', 94, '8888/8888/8888/8282/8888/8888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21312, '2023-01-20 23:25:09.70253+00', '2023-01-20 23:25:09.70253+00', 'King of Hearts', 'KING OF HEARTS', 1, 40, NULL, 1, 3, 42, 9998, NULL, 'Source youtube video: <<https://youtu.be/vc0134ml4Vw>>.



Although this can be a standard 3 couple dance in a 4 couple set, the video also shows alternative versions with the 4th couple also active, either in 4th place or 1st place (for the dancing couple''s repeat). These variations are referred to as "King of Hearts (with Jokers)".', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21315, '2023-01-21 00:04:57.549712+00', '2023-01-21 00:04:57.549712+00', 'Corset, The', 'CORSET', 1, 32, NULL, 1, 4, 1, 11943, NULL, 'Source: youtube video <<https://youtu.be/kHk3_BcqJ8Y>>.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (12861, '2006-09-12 22:00:00+00', '2023-01-23 15:38:24.960205+00', 'Swiss Chocolate', 'SWISS CHOCOLATE', 3, 32, 9999, 2, 3, 17, 3646, NULL, 'This dance was devised in gratitude for the men in the Mountain View Class, who come back from trips to

Switzerland bearing chocolate to share.', 67, '444/444/088/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1019, '1998-09-30 22:00:00+00', '2023-01-21 11:03:38.848735+00', 'Captain Mackintosh', 'CAPTAIN MACKINTOSH', 1, 40, 9999, 1, 3, 42, 9998, NULL, 'Note: TACnotes says: On [31-32] 1M guides 1W LH across him, and 1c flow into the reels.  The most recent edition of MMM specifies LH.  A variation with crossing RH & twirling is considered more fun by some [ETF].', 47, '444  444  880  880  866', 1, 1, 0, 1, 63);
INSERT INTO 'dance' VALUES (1652, '1997-04-03 22:00:00+00', '2023-01-21 13:09:36.881802+00', 'Diana''s Delight', 'DIANAS DELIGHT', 1, 28, 9999, 1, 4, NULL, 270, NULL, 'Although listed in the original publication of Whetherly Book 16 as a jig, the recommended music is a reel. Iain Boyd suggests in <<http://my.strathspey.org/dd/issue/1657/|issue 1657>> that John Mitchell made a mistake and the dance should be a reel.  

The editors of the re-published WB 16 version will change this to a Reel and leave a note within the publication about the change. 

', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21316, '2023-01-21 10:07:17.329493+00', '2023-01-21 14:14:18.766891+00', 'Queen''s Jubilee Strathspey', 'QUEENS JUBILEE STRATHSPEY', 3, 32, NULL, 2, 3, 17, 12255, '2022-01-01', 'Source: youtube video <<https://youtu.be/HaW73ny9M3c>>.



Devised by the RSCDS Forres branch for the queen''s platinum jubilee in June 2022.', 67, '800/888/088/808', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1791, '2002-03-11 23:00:00+00', '2023-01-21 14:25:15.498684+00', 'Duke of Kent''s Waltz, The', 'DUKE OF KENTS WALTZ', 5, 32, 9999, 103, 2, NULL, 468, '1801-01-01', 'For some interesting information on this dance from the ECD world see:



http://www.cdss.org/dances.html#dukeofkents



http://www.regencyassemblypress.com/The_Duke_of_Kents_Waltz.html



http://dancevideos.childgrove.org/ecd/playford/333-duke-of-kents-waltz



Eric''s crib, and Keith Rose''s diagram follow the ECD interpretation of this dance as shown in the videos.  Whetherly Book 24 differs:



1-8    First and second couples dance right hands across in a wheel and back with the left hands



9-16  First couple lead down the middle and back



17-24  First and second couples allemande



25-28  First couple turn first corners with the right hand



29-32  First couple turn second corners with the left hand', 87, '88/80/88/88', 0, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (18111, '2017-12-13 14:52:06.494306+00', '2023-01-21 16:40:55.126404+00', 'Salt and Sauce', 'SALT AND SAUCE', 1, 32, NULL, 1, 4, 2, 550, '2003-05-01', 'The original title for this dance was "Found on Strathspey". The deviser states: *It has been renamed to "Salt and Sauce" because I found people were confused by a reel having "Strathspey" in its name.*', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21313, '2023-01-20 23:44:16.519216+00', '2023-01-22 12:28:58.299462+00', 'Stones by the Sea', 'STONES BY THE SEA', 1, 32, NULL, 1, 3, 42, 12000, '2020-02-01', 'Source: youtube video <<https://youtu.be/g5YdFCiyu6M>>.', 56, '880/844/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21314, '2023-01-20 23:55:18.502077+00', '2023-01-22 12:32:54.752323+00', 'Cook Strait Ferries', 'COOK STRAIT FERRIES', 3, 32, NULL, 1, 2, 76, 11942, '2021-10-01', 'Source: youtube video <<https://youtu.be/IlnV1tFNVqw>>.', 69, '88/88/88/88', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (730, '1997-04-03 22:00:00+00', '2023-01-24 11:13:39.947843+00', 'Boys of Bluehill, The', 'BOYS OF BLUEHILL', 1, 64, 9999, 1, 4, 1, 270, NULL, '', 95, '8484/8888/8888/8888/8888/8888/4888/8888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21317, '2023-01-21 21:19:57.698321+00', '2023-01-22 12:43:58.769952+00', 'Rachel''s Bakery', 'RACHELS BAKERY', 2, 32, NULL, 1, 3, 42, 3646, NULL, 'Source: youtube video <<https://youtu.be/QlqLF2TvRcA>>.



The youtube comments say "This dance was written to thank <<ddp:Pusey, Rachel#10900>> for sharing many of her delicious homemade baking treats with me during the covid sheltering in place months."', 53, '800/877/877/844', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (6627, '1997-08-24 22:00:00+00', '2023-01-22 19:53:39.128964+00', 'Toast of Bon Accord, The', 'TOAST OF BON ACCORD', 2, 32, 9999, 1, 3, 42, 108, '1971-01-01', '', 64, '888/808/666/888', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (14354, '2011-12-14 23:00:00+00', '2023-01-22 19:53:59.513907+00', 'Tribute to Fred DeMarse', 'TRIBUTE TO FRED DEMARSE', 1, 32, NULL, 1, 3, 42, 854, '2008-01-01', 'Official Alias: The Nondescript Carpet Court



Devised sometime in 2008. Named in tribute to Fred DeMarse''s great teaching of the Highland Class at the 2008 RSCDS Summer School.



The alternative title - The Nondescript Carpet Court refers to an article in the Nov 2008 RSCDS San Francisco Branch Newsletter ''The Reel and Strathspeyper'' where Donna Weidenfeller had told of the demise of the chequered carpet tiles of the Chequered Court in University Hall in St Andrews, which have been replaced by nondescript carpeting. ', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21318, '2023-01-23 16:53:48.320455+00', '2023-01-23 18:22:42.949007+00', 'Finding Jo', 'FINDING JO', 2, 32, NULL, 1, 3, 42, 12257, '2022-10-01', '“When I was a little girl living in England, my parents adopted a black and white kitten from a local farm. My mother named her Josephine, after her favorite aunt, and we all called her Jo. From her earliest days, Jo had an uncanny ability to secrete herself in all manner of hidden places. Whenever my father couldn’t locate Jo, he would organize family search parties to help him find her.  



“In the dance, my father and I set off to look for Jo. He searches the upstairs (2nd couples’ position) and I search the basement (3rd couple’s position). When we still can’t find her—and since each of us privately thinks that the other simply didn’t look in the right spot—we switch places. At last Jo is discovered—but by whom, I cannot say. My entire family celebrates by dancing the final figure.”', 56, '800/888/888/880', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21319, '2023-01-24 11:23:54.87027+00', '2023-01-24 11:32:49.212676+00', 'Kingdom (Far, Far Away), The', 'KINGDOM FAR FAR AWAY', 3, 32, NULL, 4, 4, 13, 11527, '2023-01-01', 'This dance is dedicated to the UK.', 81, '8282/8888/2828/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2260, '1998-05-19 22:00:00+00', '2023-01-27 20:11:16.93206+00', 'Flying Scotsman, The', 'FLYING SCOTSMAN', 2, 32, 9999, 1, 3, 42, 392, NULL, 'This dance was first published by Hugh Thurston in his book Sixteen

Scottish Country Dances (1945-1967). The Flying Scotsman was (maybe still is) the fastest steam engine train to travel between London and Edinburgh.  



Jo Hamilton suggests, "When working with audience participation dancers from 8 to 80, I will form 3 couple sets and have 1st couple slip step down the middle and up to the bottom of their set in bars 17-24. This dance tells a story of a train''s journey that new dancers find easy to remember.  



1-8 The train''s journey through the hills from London to Edinburgh.  

9-16 The train''s journey from Edinburgh to London.  

17-24 The train track (rails).  

25-32 The electrical poles flashing past. (British trains are powered by electricity.) "', 44, '444  444  800  888', 1, 1, 1, 1, 58);
INSERT INTO 'dance' VALUES (2604, '1998-04-12 22:00:00+00', '2023-01-24 11:40:56.37563+00', 'Good Hearted Glasgow', 'GOOD HEARTED GLASGOW', 2, 32, 9999, 1, 3, 42, 217, '1988-01-01', 'Summary of a discussion on “Strathspey” in november 2013:  This dance is known as "Good Hearted Glasgow" but also as "The Good Hearted Glasgow Jig". The deviser, Peter Knapman, explains (thanks to Andrew Smith for sharing):



"The reason for the confusion [about the correct name] arose as a result of why the dance was originally written! The Greater Glasgow Health Board ran a campaign in 1988 where they organised a series of easy and accessible forms of exercise under the general title of ''Good Hearted Glasgow'' - one of these exercise activities being country dancing.  Hence, they needed a fairly straightforward Scottish country dance which became known as Good Hearted Glasgow or to distinguish it from other GHG exercise activities ''The Good Hearted Glasgow Jig. The original leaflet shows the title with the ''the'' and the ''jig'' in a lesser typeface.



As far as the SCD world is concerned it has always been known simply as ''Good Hearted Glasgow'' - the Bobby Brown LP is the only time the full title has been used.



So take your pick - I would simply use Good Hearted Glasgow as that is what most SCD sources use - but if you wish to use its Sunday title then that''s fine - as long as you enjoy dancing the dance select which ever title you prefer."



[In view of the second-to-last paragraph the »Jig« alias has been downgraded to »Unofficial« for the benefit of the RSCDS Index To Dances. –Anselm]', 50, '800  888  800  888', 1, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (21322, '2023-01-25 12:53:30.442583+00', '2023-01-25 15:12:39.412463+00', 'Compliments to Glasgow', 'COMPLIMENTS TO GLASGOW', 3, 32, NULL, 1, 4, 2, 640, NULL, 'Bars 1–8 depict ‘100’ to mark the centenary year.', 88, '8888/8888/8888/8008', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21323, '2023-01-25 13:00:14.508358+00', '2023-01-25 15:14:08.023731+00', 'Faerie Pools, The', 'FAERIE POOLS', 1, 48, NULL, 2, 3, 18, 11652, NULL, 'The deviser, Les Lambert, was inspired by the whirlpools and waterfalls in Glen Brittle,

Skye, whilst on holiday with his granddaughter and wife, Carolyn.', 79, '800/888/888/288/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21324, '2023-01-25 13:14:23.873078+00', '2023-01-25 15:25:43.821963+00', 'Glasgow City Strathspey', 'GLASGOW CITY STRATHSPEY', 3, 32, NULL, 1, 3, 42, 3183, NULL, 'Deviser''s note: "Written for the vibrant city, which for more than 50 years of my life, has never been far from my home”.', 56, '880/844/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21326, '2023-01-25 13:39:31.447967+00', '2023-01-25 15:27:21.204329+00', 'Jordanhill', 'JORDANHILL', 1, 32, NULL, 1, 3, 42, 1415, NULL, 'Jordanhill College was one of the teacher training establishments in Scotland. Miss Milligan

taught there for a number of years, retiring in 1948. Some of the students she instructed in

Physical Education became known as ‘Miss Milligan’s Boys’', 53, '888/888/822/844', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (18367, '2018-06-03 14:54:33.947535+00', '2023-01-25 12:52:49.925626+00', 'Pat Houghton''s Reel', 'PAT HOUGHTONS REEL', 1, 32, NULL, 2, 3, 18, 11639, NULL, 'Dance was devised by David Carter (CSCDS Inc.) for Pat Houghton who was David’s Demonstration teacher at Summer School.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21329, '2023-01-25 14:34:22.011768+00', '2023-01-25 14:34:22.011768+00', 'Athenaeum, The', 'ATHENAEUM', 3, 32, NULL, 2, 3, 18, 1415, NULL, 'The Athenaeum in Glasgow was the venue for the first meeting of the Scottish Country Dance

Society on 26 November, 1923.', 75, '800/800/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21331, '2023-01-25 14:41:51.580938+00', '2023-01-25 14:41:51.580938+00', 'Glasgow Welcome, A', 'GLASGOW WELCOME', 2, 32, NULL, 1, 3, NULL, 12033, NULL, '', 63, '800/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21332, '2023-01-25 14:51:27.222933+00', '2023-01-25 14:51:27.222933+00', 'Hundred Years Since, A', 'HUNDRED YEARS SINCE', 1, 32, NULL, 1, 3, 42, 217, NULL, 'As a tribute to the centenary of the RSCDS and Glasgow Branch this dance incorporates the

first 8 bars of the first dance in RSCDS Book 1 and the last 8 bars from the last dance in

RSCDS Book 52.', 63, '808/880/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21320, '2023-01-25 12:25:43.312787+00', '2023-01-25 15:09:54.950945+00', 'Centenary Jig, The', 'CENTENARY JIG', 2, 32, NULL, 1, 3, 42, 3183, NULL, 'Written for the centenary of Glasgow Branch of the RSCDS – the first Branch that Anne joined –

and dedicated to two Glasgow Branch teachers, Johan MacLean, who tutored her for her

preliminary certificate at Jordanhill and George Lawson who tutored her for the SCD teaching

certificates in the 1980s.', 47, '800/844/822/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21321, '2023-01-25 12:40:18.329239+00', '2023-01-25 15:11:56.460067+00', 'Seeing Stars', 'SEEING STARS', 1, 40, NULL, 3, 5, 7, 12258, NULL, 'Eilidh was helping candidates prepare for their Unit 2 examination in Glasgow and could see

the Advanced Class, on the other side of the hall, working on setting steps, which made her

think of star formations.', 40, '80800/08080/80800/82842/80800', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21327, '2023-01-25 13:47:17.204585+00', '2023-01-25 15:28:20.551537+00', 'Manual Memories', 'MANUAL MEMORIES', 2, 32, NULL, 1, 3, 42, 12258, NULL, 'Deviser’s note: “During a very busy time dancing in Glasgow, with competitions and examination preparation for multiple units – I guess I had a lot of dancing on my mind because this dance just came to me in my sleep.”', 56, '800/844/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21334, '2023-01-25 15:06:55.228441+00', '2023-01-26 09:43:47.14332+00', 'Tall Ship "Glenlee", The', 'TALL SHIP GLENLEE', 3, 32, NULL, 1, 3, 42, 12033, NULL, 'The Tall Ship “Glenlee”, now located outside the Riverside Museum on the Clyde, was built

in 1896 by A Rodger and Company in Port Glasgow. The Clydebuilt vessel went through

several names and owners before being sold to the Spanish Navy in 1922 where she spent

much of her working life, eventually falling into disrepair. The three-masted barque was saved

after being bought by the Clyde Maritime Trust in 1993 and returned to Glasgow. She was

subsequently restored and given her original name ‘Glenlee’ and now stands as a museum

ship and icon of the Clyde. The first 8 bars of the dance represent the swell and churn of the

sea while the second 8 bars portray the ship’s wayward past as a training vessel in the Spanish

Navy. The final 16 bars draw out the shape of the three-masted barque, outlining the masts,

figurehead and hull.', 63, '800/888/888/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21328, '2023-01-25 13:56:52.253931+00', '2023-01-26 09:43:09.959811+00', 'Change of Pace, A', 'CHANGE OF PACE', 4, 128, 10034, 1, 4, 1, 10803, '2021-01-01', 'Deviser’s note: "This dance was devised in the autumn of 2021 when my twin sister, Judith, and I retired from work, thus offering us the opportunity to have a change of pace! We are inspired by our parents, who still lead an active lifestyle."', 78, '8888/6666/4844/4488', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (6769, '1997-04-03 22:00:00+00', '2023-01-26 19:13:57.724745+00', 'Tune Up Your Fiddles', 'TUNE UP YOUR FIDDLES', 3, 32, 9999, 1, 4, 1, 270, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21335, '2023-01-26 20:49:53.46993+00', '2023-01-26 21:45:40.503614+00', 'Annet Burn, The', 'ANNET BURN', 4, 128, 10034, 1, 100, 2, 11759, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21333, '2023-01-25 14:58:32.085675+00', '2023-01-28 11:15:51.102959+00', 'In Celebration of Glasgow Branch', 'IN CELEBRATION OF GLASGOW BRANCH', 2, 32, NULL, 1, 100, 1, 10443, NULL, 'This dance was devised to convey the joy, pleasure and teamwork that dancing brings. The last 10

bars depict ‘100’, a fantastic milestone for Glasgow Branch.', 80, '880/844/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (1552, '1997-09-01 22:00:00+00', '2023-02-12 16:22:44.643522+00', 'Dandies'' Reel, The', 'DANDIES REEL', 2, 32, 9999, 1, 4, 1, 815, NULL, 'The dance was originally published in RSCDS Leeds 10th Anniversary Book.



Dandies is a crofter’s cottage in Uyeasound, Unst, Shetland, where part of the Peter’s family lived. Kirkstall Road (the name of the principle tune) is where the original Leeds Branch classes started in 1962.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4888, '1997-04-03 22:00:00+00', '2023-01-29 19:42:54.043397+00', 'Neaps an'' Haggis', 'NEAPS AN HAGGIS', 1, 32, 9999, 1, 2, 76, 108, '1967-01-01', 'Incribed to Miss M. Lilly, of Whitehaven.



Drewry writes in a footnote to bars 15-16 (representing the haggis): "Obviously the common right-handed Haggis (Haggis Normalis), which lives mainly on Lilly leaves and neaps. It is quite distinct from the rare left-handed Haggis (Haggis Widdershinsia), which was last seen on the Witches'' Step in Arran."', 58, '84/78/88/48', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1955, '1997-09-01 22:00:00+00', '2023-02-09 12:20:58.702221+00', 'Elizabethan Reel', 'ELIZABETHAN REEL', 1, 40, 9999, 1, 3, 42, 21, NULL, 'Inscribed "for The Royal Silver Jubilee 1977."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21336, '2023-01-29 20:00:22.69409+00', '2023-01-29 23:27:29.257957+00', 'D and D Side Caledonians, The', 'D AND D SIDE CALEDONIANS', 1, 32, NULL, 1, 3, 42, 11237, '2022-12-01', 'The "D and D Side" are the MiniCrib team consisting of David Haynes and Diana Dainton. Since 2013 they have continued the work originally started in the 1990s by Charles Upton of the Deeside Caledonian Society. Together they have provided thousands of new cribs for the benefit of the SCD community and have also been diligently revising older ones. Thank you!

', 50, '800/844/844/888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21337, '2023-01-31 14:41:08.450162+00', '2023-01-31 14:41:08.450162+00', 'Chieftain o'' the Puddin'' Race', 'CHIEFTAIN O THE PUDDIN RACE', 3, 32, NULL, 2, 3, 17, 228, '2023-01-31', 'Written under the impression of a series of Burns suppers, as an introduction to reels of three.', -1, '', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21338, '2023-01-31 17:33:41.931454+00', '2023-01-31 18:15:48.154891+00', 'Billy Gray of Saltcoats', 'BILLY GRAY OF SALTCOATS', 2, 32, NULL, 1, 3, NULL, 12260, NULL, 'Bars 1-8 draw the 6 and bars 24-32 draw the 0 of 60 to represent Billy’s 60th birthday.', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (14429, '2012-05-08 21:11:08.604637+00', '2023-02-02 20:37:13.788864+00', 'Surrey Medley', 'SURREY MEDLEY', 4, 32, 13, 1, 4, 2, 3580, '2001-10-01', 'Twice through in Strathspey time, then twice in Jig time.



Devised for students at Surrey University while lecturing and examining the MSc postgraduate course in Bridge Engineering.



Description:

Bars	Description



1-8	  1s and 4s cross right hand and cast one place towards the middle (2s step up and 3s step down on bars 3 and 4) and dance a half figure of eight through the end couples. (2143)



9-16	  With 1s facing 2s and 4s facing 3s all dance a right shoulder reel of four on the sides. (2143)



17-24	  2s with 1s and 4s with 3s dance four hands round to the left and back again. (2143)



25-32	  1s and 4s (middle couples) dance half rights and lefts across.  1s and 4s set and cross right hand back to own side. (2413)



Repeat once more in Strathspey time from new positions.



All four couples clap and repeat twice more in Jig time.

', 75, '8008/8888/8888/8008', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (9660, '2001-06-12 22:00:00+00', '2023-02-03 13:30:43.819206+00', 'Tyneside Tribute to Ian Thow, A', 'TYNESIDE TRIBUTE TO IAN THOW', 2, 96, 9999, 4, 4, 3, 523, '1993-03-25', 'Inscribed "to Ian Thow with thanks for his many years of music making for the Branch; the first figure and the ''cauld kail'' setting are references to his Aberdeen connections."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21339, '2023-02-03 21:04:57.430487+00', '2023-02-03 21:04:57.430487+00', 'Red Rose Strathspey', 'RED ROSE STRATHSPEY', 3, 32, NULL, 1, 3, 42, 10338, '2023-01-01', 'Source: MiniCrib.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (4572, '1997-09-09 22:00:00+00', '2023-02-04 16:08:34.830701+00', 'Miss Russell''s Rant', 'MISS RUSSELLS RANT', 1, 32, 9999, 2, 3, 17, 272, '1992-01-01', 'Dedicated to the late Miss Edna Russell, Chairman of the Scottish Dance Branch of the ISTD for most of the 20 years to 1986.', 58, '800/844/884/840', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21135, '2022-10-01 08:45:50.063521+00', '2023-02-05 18:32:28.669654+00', 'Otterphant, The', 'OTTERPHANT', 4, 64, 5, 1, 4, 28, 10582, '2022-01-01', 'Devised "for Heather Carson in celebration of her 60th birthday and a happy reminder of our shared sighting of Cape Clawless Otters at Olifantsbos in Cape Point."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19326, '2019-05-12 08:56:01.984326+00', '2023-02-05 21:40:45.938686+00', 'Maxwell''s Waves', 'MAXWELLS WAVES', 4, 128, 2, 4, 8, 54, 374, '2012-01-01', 'The dance was commissioned by the Orkney International Science Festival in 2012 to celebrate the life of physicist James Clerk Maxwell (1831-1879) who is best known for unifying the theories of electricity and magnetism and showing that light is an electromagnetic wave.



The comments on the <<https://youtu.be/WvhYB1Fmr80|youtube video>> give a lot more detail about him.



This is also <<https://www.scottishcountrydanceoftheday.com/daysoftheyear/maxwell''s-waves|Scottish Country Dance of the Day> for 13 June which was Maxwell''s birthday.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (2072, '2002-03-02 23:00:00+00', '2023-02-09 11:55:19.711209+00', 'Far Cuillins, The', 'FAR CUILLINS', 3, 32, 9999, 1, 100, 2, 313, '1988-01-01', 'Inscribed "For The Clan MacLeod Dancers of California."



Note on bars 17-24.



This is what we called the ``angel setting''''. First you make sure you are dancing with someone you like!



The men are behind their partners taking both hands, with both hands joined both beginning facing corners, hands about shoulder height.



The men should be pretty close to their partners. You then dance hello-goodbye setting, remaining in this position throughout.  The men must go further each time, with more drive, else it it does not work. Staying close together helps a lot.

', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1697, '1997-09-01 22:00:00+00', '2023-02-10 14:35:26.573074+00', 'Dornie Strathspey', 'DORNIE STRATHSPEY', 3, 32, 9999, 1, 3, 42, 831, NULL, 'The notes say that "Dornie lies at the point where three lochs meet, Loch Long, Loch Aish and Loch Duich. The dance represents the meeting of the waters, the middle 16 bars Eilean Donan Castle and the last 8 bars the water moving under the bridges up to the castle."', 62, '888  404  888  888', 1, 1, 0, 0, 83);
INSERT INTO 'dance' VALUES (1681, '1998-01-05 23:00:00+00', '2023-02-10 14:43:17.8943+00', 'Donna''s Diamonds', 'DONNAS DIAMONDS', 1, 32, 9999, 1, 4, 1, 151, NULL, 'From the notes: "Dedicated to Donna Wilson who dances ''Petronella Diamonds'' with such obvious enjoyment.



Most dances containing Petronella Diamonds either contain poussettes which require good pas-de-bas from both partners or more difficult formations, hence my reason for composing this little dance."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (1668, '1997-09-17 22:00:00+00', '2023-02-10 15:04:30.01541+00', 'Dr. Sally Hayes', 'DR SALLY HAYES', 2, 32, 9999, 1, 3, 42, 377, NULL, 'The notes say that the dance "was written to acknowledge the kindness, gentleness, competence and unfailing good humour of the staff of Dixon Ward, St. Richards Hospital and named after the young doctor who was in charge of my case under the surgeon who operated.', -1, '', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1635, '1997-08-25 22:00:00+00', '2023-02-10 15:18:23.236891+00', 'Devil''s Point, The', 'DEVILS POINT', 1, 32, 9999, 1, 3, 42, 108, '1981-01-01', 'The notes say that "The Devil''s Point (3303 ft.) is a conical peak formed of large, overlapping slabs of rock, which give it an inaccessible appearance when viewed from Glen Dee."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (1535, '1997-08-25 22:00:00+00', '2023-02-12 16:26:11.141228+00', 'Dancing Bees, The', 'DANCING BEES', 1, 32, 9999, 1, 3, 42, 146, NULL, 'Inscribed "For Penny and Robert Bee."', 44, '800  880  808  844', 1, 1, 0, 1, 58);
INSERT INTO 'dance' VALUES (6286, '1998-04-19 22:00:00+00', '2023-02-12 20:48:59.37669+00', 'Starkers Fell', 'STARKERS FELL', 2, 32, 9999, 1, 4, 1, 108, '1994-06-01', 'Inscribed "to all who walk alone".



Drewry writes in the notes that "when two of the dancers at the Morland Week were walking near Ullswater, they met a solitary hiker. He wore a straw hat, a rucksack, climbing boots and nothing else! This dance is a light-hearted depiction of this incident and is not to be taken too seriously!"', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (21340, '2023-02-09 22:52:58.096278+00', '2023-02-22 17:18:27.173479+00', 'Croydon Jubilee Strathspey', 'CROYDON JUBILEE STRATHSPEY', 3, 32, NULL, 2, 3, 17, 3417, NULL, '', 53, '800/884/888/808', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21342, '2023-02-16 13:10:03.357151+00', '2023-02-17 21:34:25.291049+00', 'Rumour Has It', 'RUMOUR HAS IT', 1, 32, NULL, 4, 4, 13, 1378, NULL, 'Source: <<https://youtu.be/J4DDl6vyvWE|youtube video>>.', -1, '', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21189, '2022-12-02 22:12:53.082933+00', '2023-02-13 23:15:22.725881+00', '8 - 8', '8  8', 3, 32, NULL, 1, 4, 5, 12215, '2022-08-20', '"Dance written for our gentle Scottish Dancing friend Bruce McLaren. It features, for obvious [birthday] reasons, two Double Figures of Eight."



Originally conceived as a strathspey the devisers suggest it may also be danced in different rhythms using  recordings as follows:  



  - Medley (64S+64J): Johnnie Walker (Iain MacPhail)

  - Jig: Waratah Weaver (Luke Brady)

  - Reel: The Shetland Fiddler  (Chris and Julie Dewhurst)

  - Playford: Daniel''s Reel (The Assembly Players)

', 69, '8888/8800/0044/8888', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (9136, '2002-04-19 22:00:00+00', '2023-02-13 23:41:34.455449+00', 'Getting of Wisdom, The', 'GETTING OF WISDOM', 3, 32, 9999, 1, 3, 42, 448, '1999-01-01', '', 56, '800/888/888/880', 0, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21341, '2023-02-15 23:15:15.582805+00', '2023-02-15 23:15:15.582805+00', 'Dancing Gymnast, The', 'DANCING GYMNAST', 2, 32, NULL, 1, 3, 42, 361, '1993-01-01', '"Dedicated to Suzie Kinsman in partial celebration of her earning the Bachelor of Arts degree."', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21343, '2023-02-20 00:18:06.746443+00', '2023-02-20 00:21:26.517221+00', 'Tribute to Paul, A', 'TRIBUTE TO PAUL', 3, 32, NULL, 2, 3, 17, 872, NULL, 'Devised by Marilyn Watson for Paul Readhead, a valued committee member who passed away 2015.', 81, '828/888/084/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17807, '2017-06-22 11:01:18.227349+00', '2023-02-16 13:18:08.981234+00', 'Jiggin'' Jan', 'JIGGIN JAN', 2, 32, NULL, 1, 3, 42, 10907, '2011-03-01', 'A dance for Jan Nicol a long time dancer who never seems to tire of dancing.', 55, '880/888/842/844', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (17809, '2017-06-22 11:02:37.22859+00', '2023-02-16 13:45:58.913566+00', 'Kirkwall Court', 'KIRKWALL COURT', 2, 32, NULL, 1, 3, 42, 10907, '2011-02-01', 'Kirkwall Court is the name of my residence in Stones Corner, Queensland.', 56, '880/888/800/888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (20819, '2022-05-13 17:46:55.634491+00', '2023-02-17 09:17:27.957445+00', 'Wee Bairnie Strathspey, The', 'WEE BAIRNIE STRATHSPEY', 3, 32, NULL, 6, 3, 4, 555, '2012-08-23', 'Devised "to mark the birth of Madison Inglis".



The dance was originally intended as a strathspey. However when the deviser needed a jig for a demonstration involving 3 couples it was tried in that rhythm (see <<https://my.strathspey.org/dd/list/34028/|dance list 34028>>). In that incarnation it is called The Wee Bairnie Jig which is added as an alias. It may be danced in either rhythm.', 88, '666/666/888/888', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (1437, '1998-09-29 22:00:00+00', '2023-02-17 11:58:53.135787+00', 'Crooket-Horned Ewie, The', 'CROOKETHORNED EWIE', 3, 32, 9999, 1, 3, 42, 453, '1760-01-01', 'A “crooket horned ewie”, or “sheep with bent horns” is an illicit whisky still – the name comes from the shape of the still-pot''s outlet. The clandestine preparation of untaxed spirits required highly mobile equipment since it was frequently necessary to pack up and move or hide the “distillery” in order to avoid overly curious gaugers (excisemen) whose job it was to curb illegal distilling.

', 38, '440/448/800/844', 1, 1, 1, 1, 50);
INSERT INTO 'dance' VALUES (1384, '1997-08-25 22:00:00+00', '2023-02-17 12:16:25.356813+00', 'Craig Mhor', 'CRAIG MHOR', 3, 32, 9999, 1, 2, 76, 108, '1983-01-01', 'Inscribed "for David Eastwood who, in 1983, was living in a house called "Craig Mhor" in Bucksburn, Aberdeen."', 69, '88/88/88/88', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (1285, '1997-08-25 22:00:00+00', '2023-02-17 12:35:06.667965+00', 'Collie Law', 'COLLIE LAW', 2, 32, 9999, 1, 2, 76, 146, NULL, '', 60, '88  88  80  88', 1, 1, 0, 1, 87);
INSERT INTO 'dance' VALUES (1238, '1997-08-25 22:00:00+00', '2023-02-17 13:10:44.440572+00', 'Clootie Well, The', 'CLOOTIE WELL', 1, 32, 9999, 1, 3, 42, 108, '1977-01-01', 'John Drewry noted in the original description:



*The Clootie Well is near Culloden (although others occur in other parts of the country). By tradition, it is visited on the first Sunday in May; the visitor throws a coin in the well and ties a cloot to one of the trees to symbolise the leaving of all cares behind.*



*May 1st 1977 was a Sunday. I visited the well with Simon Fraser about a week later and the lower branches of the trees surrounding the well were festooned with hundreds of bits of rag.*



*It would appear that this is the survival of a pre-Christian Celtic custom.*



In later editions of the book, John Drewry added:



*This version issued in September 1977, has an improved figure

for Bars 1-8 and this should replace the earlier version (May 1977).*



and 



*The spelling "Clootie" (rather than "Cloutie") is probably preferable

in that it gives a better indication of the pronunciation. Both spellings

are given in Chambers Scots Dictionary.*', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (998, '2002-09-25 22:00:00+00', '2023-02-21 12:33:30.763815+00', 'Cape Breton Hornpipe, The', 'CAPE BRETON HORNPIPE', 1, 32, 9999, 1, 100, 2, 555, NULL, '"Dedicated to Wilf Gillis, member of the Cape Breton Symphony and friend of the Ottawa branch."', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (827, '1998-07-08 22:00:00+00', '2023-02-21 13:32:17.843318+00', 'Brodie Castle', 'BRODIE CASTLE', 2, 32, 9999, 1, 100, 2, 108, '1977-01-01', 'The dance is dedicated to Neil Grant of Dyke, Forres.', 88, '8888  8888  8888  8008', 1, 1, 0, 1, 87);
INSERT INTO 'dance' VALUES (767, '1997-08-31 22:00:00+00', '2023-02-21 19:26:55.706358+00', 'Bras d''Or', 'BRAS DOR', 2, 40, 9999, 1, 3, 42, 108, '1988-01-01', 'This dance has been revised in February 1992.  Originally, in the Summer Collection 1988, it had 32 bars.  John Drewry revised and republished it in Bankhead Book 1 with the comment: "The original dance was 32 bars long ...  There was always a problem with entering the repeats of the dance.  I have added the extra bars to make it possible to repeat the dance without difficulty".



Inscribed "for the Scottish Country Dancers of Cape Breton Island, Nova Scotia".', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (760, '1998-09-29 22:00:00+00', '2023-02-21 19:34:20.191355+00', 'Bramble Bush, The', 'BRAMBLE BUSH', 2, 32, 9999, 1, 3, 42, 9998, NULL, '', 34, '800  800  822  844', 1, 1, 0, 1, 45);
INSERT INTO 'dance' VALUES (21345, '2023-02-22 00:20:18.422072+00', '2023-02-22 00:20:18.422072+00', 'Beltane Fires Flower', 'BELTANE FIRES FLOWER', 4, 96, 21, 6, 3, 3, 12262, NULL, '', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21346, '2023-02-22 00:29:00.37408+00', '2023-02-22 00:34:51.664444+00', 'Head Spinning', 'HEAD SPINNING', 3, 32, NULL, 1, 3, 42, 12168, NULL, 'Source: <<https://youtu.be/ebQ1LZGNo_M|youtube video>>.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21347, '2023-02-22 00:35:42.298954+00', '2023-02-22 00:35:42.298954+00', 'Spring School 2022', 'SPRING SCHOOL 2022', 2, 40, NULL, 1, 3, 42, 11915, NULL, 'Source: <<https://youtu.be/ebQ1LZGNo_M|youtube video>>.', -1, '', 1, 1, 0, 0, -1);
INSERT INTO 'dance' VALUES (21242, '2023-01-04 23:16:48.882854+00', '2023-02-22 08:40:04.769134+00', 'Delightful Diversion, A', 'DELIGHTFUL DIVERSION', 1, 32, NULL, 1, 3, NULL, 11981, NULL, '', -1, '', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (21344, '2023-02-20 12:01:36.854955+00', '2023-02-22 17:54:54.338264+00', 'Lightbulb Reel, The', 'LIGHTBULB REEL', 1, 32, NULL, 1, 3, 42, 12261, '2022-01-01', 'Source: youtube videos <<https://youtu.be/Vsq4clq3m5M>> (dance) and <<https://youtu.be/mPnCjxBzf6I>> (walk through). The deviser (Marian) starts as first woman in both videos.



The deviser''s instructions:  

1-4 – 1’s lead down the middle; 2’s step up on 3 and 4  

5-8 – 1’s turn in place; cast up behind the 3’s into 2nd place  

9-16 – 1’s and 3’s Right hands Across; Left hands back  

17-24 – 1’s, 2’s and 3’s, right shoulder reel along own lines  

25-28 – 1’s and 2’s Right hands across  

29-32 – Everyone (including the 4’s) turn their partner with their right  



Background story: None of these characters are brightest bulbs in the drawer. 

 

2’s need the 1’s help to change a lightbulb.  

1’s are eager but in confusion end up helping the 3’s instead.  It isn’t until they screw in the 3’s lightbulb (right hands across) that they realize they were supposed to help the 2’s.  Therefore, they must unscrew the 3’s lightbulb (left hands back).  

2’s and 1’s are now looking for each other and the 3’s, not having any idea of what is going on, follow the others (reel).  

Finally, the 1’s get it right and help the 2’s screw in their lightbulb (right hands across).  Everyone celebrates getting right (including the 4’s)!



Music:  Anything fun and lively.

', -1, '', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (8449, '1998-01-04 23:00:00+00', '2023-02-28 19:25:16.982229+00', 'Deanstone House', 'DEANSTONE HOUSE', 3, 32, 9999, 1, 3, 42, 352, '1996-04-30', 'It seems the instructions for bars 5-8 of this dance were updated or corrected at some point.



One version has:  

1-8: First couple cross with the right hand and cast off one place. (Second couple step up on bars 3 & 4). First couple turn each other _1 1/2 times with the right hand_.



Another, perhaps the corrected version, has:  

1-8: First couple cross with the right hand and cast off one place. (Second couple step up on bars 3 & 4). First couple turn each other _1 3/4 times with the left hand_.

', 44, '800/888/800/880', 1, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (21348, '2023-02-23 11:16:51.982632+00', '2023-02-24 20:03:05.782736+00', 'Yec''hed Mat', 'YECHED MAT', 2, 32, NULL, 1, 4, 2, 11209, '2012-05-01', 'Good health! in Breton  

Devised to celebrate the visit to Arradon as part of the twinning celebrations between Upton, Chester and Arradon.



From <<https://forvo.com/word/yec%27hed_mat/>> the pronciation is roughly as English speakers would say Yeah-Head-Mart.', 75, '8888/0880/8008/8888', 0, 1, 1, 0, -1);
INSERT INTO 'dance' VALUES (5581, '2002-08-05 22:00:00+00', '2023-02-25 14:47:10.154844+00', 'Ring of Friendship, A', 'RING OF FRIENDSHIP', 2, 32, 9999, 5, 2, 76, 152, '1982-01-01', 'One original copy of the instructions carries the following handwritten note by Betty Grant:



A Ring of Friendship



The idea behind this dance is the ring of dancers around the world who start to dance in a small group, then intermingle with the neighbouring groups, and giving hands across borders, continents and seas move on in a never-ending Ring of Friendship.



Best wishes,



Betty Grant', 100, '88/88/88/88', 1, 1, 1, 1, 100);
INSERT INTO 'dance' VALUES (21350, '2023-02-27 17:33:50.012569+00', '2023-02-27 17:33:50.012569+00', 'Catherine', 'CATHERINE', 3, 32, NULL, 1, 3, 42, 347, NULL, 'Written for Catherine Packwood-Bluett who, together with Aileen Napper, took over the running of the Isle of Wight Weekend School which was started in the 1980s by their mothers. The dance includes some of Catherine’s favoured formations.', 53, '840/844/844/888', 0, 0, 0, 0, -1);
INSERT INTO 'dance' VALUES (15374, '2014-03-18 09:13:22.812427+00', '2023-02-28 01:36:21.575422+00', 'Auld Brig o''er the Firth', 'AULD BRIG OER THE FIRTH', 2, 32, NULL, 1, 3, 42, 10623, '2014-01-01', 'Devised upon the platform at North Queensferry station waiting for a train to Perth delayed by an hour



The dance was revised injune 2016.  The previous crib read:







1–   1c cross RH | cast to centre in 2pl (2c up) ; 1c set pivoting R into BtoB facing opp. side | All set as in DTr



9–    1c set BtoB, moving ¼ round R (M facing down, W up) | all set as in DTr ; 1c set moving R ½ (M facing up, W down) | All set as in DTr



17–    1c+1cnrs pass and turn , pass Rsh ; 1c+2cnrs pass and turn



25–    2c+1M & 1W+3c RHA ; 1c pass Rsh to own side | All set (2,1,3)





', 47, '822/844/844/880', 0, 1, 1, 1, 66);
INSERT INTO 'dance' VALUES (18264, '2018-03-21 15:59:26.067326+00', '2023-02-28 10:40:52.202033+00', 'Borrower, The', 'BORROWER', 1, 32, NULL, 1, 3, 42, 1827, '2017-11-01', 'For Aileen Napper who lives on the Isle of Wight.  Due to Aleen''s and Craig''s height difference Craig always commented when dancing with Aleen that it was like dancing with a *borrower*!  Bars 19-24 suit the height difference very well.



_Useful information about borrowers:_  

*"The Borrowers" is a children''s fantasy novel by the English author Mary Norton, published in 1952. It features a family of tiny people who live secretly in the walls and floors of an English house and "borrow" from the big people in order to survive. The Borrowers also refers to the series of five novels including The Borrowers and four sequels that feature the same family after they leave "their" house.* (borrowed from <<https://en.wikipedia.org/wiki/The_Borrowers|Wikipedia>>.)



The online source link (<<https://craigellachie-band.co.uk/teacher-resources/new-dances-resource-the-borrower/>>) has the instructions, the score for the tune and a recording by Ian and Judith Muir.

', 69, '880/888/888/888', 1, 1, 1, 1, -1);
INSERT INTO 'dance' VALUES (21349, '2023-02-27 16:12:59.77487+00', '2023-02-28 15:07:39.173237+00', 'Golden Hill Fort', 'GOLDEN HILL FORT', 3, 40, NULL, 6, 3, 18, 12263, '2022-01-01', 'Devised on the occasion of the Isle of Wight Caledonian Society’s Platinum Anniversary, 2022.



The online source link (<<https://craigellachie-band.co.uk/teacher-resources/golden-hill-fort/>>) has the instructions, the score for the tune and a recording.

', 93, '888/888/888/888/844', 1, 1, 0, 1, -1);
INSERT INTO 'dance' VALUES (19604, '2019-09-02 19:29:59.815059+00', '2023-02-28 15:27:51.973725+00', 'Lochinver', 'LOCHINVER', 1, 32, NULL, 1, 3, 42, 347, '2019-04-01', 'This dance has been revised since it was first published in the Reel issue 309.  



The new version was published in the <<https://www.rscdslondon.org.uk/wp-content/uploads/2020/02/Reel-310-electronic.pdf#page=13|Reel issue 310>> (December 2019) with:  



17-24  Repeat bars 9-16 with second corners, 1st couple curve round to finish in lines across with 1st woman between 3rd couple in first place all facing down, 1st man between 2nd couple in third place all facing up.



In addition to the above link to The Reel, the tune and a recording are also available via <<https://craigellachie-band.co.uk/teacher-resources/new-dances-resource-lochinver/>>.', 56, '800/844/844/888', 1, 1, 1, 1, -1);


--
INSERT INTO 'dancealias' VALUES (19, 5032, 'Follow her over the Borders', 'FOLLOW HER OVER THE BORDERS', 2);
INSERT INTO 'dancealias' VALUES (2, 1792, 'Broun''s Reel', 'BROUNS REEL', 2);
INSERT INTO 'dancealias' VALUES (4, 6957, 'Fergus McIver', 'FERGUS MACIVER', 2);
INSERT INTO 'dancealias' VALUES (8, 633, 'Royal Child, The', 'ROYAL CHILD', 2);
INSERT INTO 'dancealias' VALUES (1, 1296, 'Jacky Tar', 'JACKY TAR', 0);
INSERT INTO 'dancealias' VALUES (5, 5497, 'Where would Bonnie Annie lie', 'WHERE WOULD BONNIE ANNIE LIE', 2);
INSERT INTO 'dancealias' VALUES (11, 5964, 'Prince of Wales, The', 'PRINCE OF WALES', 2);
INSERT INTO 'dancealias' VALUES (20, 3091, 'Will ye go and marry Ketty?', 'WILL YE GO AND MARRY KETTY', 2);
INSERT INTO 'dancealias' VALUES (13, 2046, 'Why should I Sit and Sigh?', 'WHY SHOULD I SIT AND SIGH', 2);
INSERT INTO 'dancealias' VALUES (14, 862, 'Ninesome Reel', 'NINESOME REEL', 2);
INSERT INTO 'dancealias' VALUES (15, 6233, 'Inverness Country Dance', 'INVERNESS COUNTRY DANCE', 2);
INSERT INTO 'dancealias' VALUES (378, 2432, 'Genevieve''s Jig', 'GENEVIEVES JIG', 1);
INSERT INTO 'dancealias' VALUES (17, 3617, 'Duke is Welcome to Inverness, The', 'DUKE IS WELCOME TO INVERNESS', 2);
INSERT INTO 'dancealias' VALUES (21, 2428, 'New Way of Gildon, The', 'NEW WAY OF GILDON', 2);
INSERT INTO 'dancealias' VALUES (22, 2661, 'John Black''s Daughter', 'JOHN BLACKS DAUGHTER', 2);
INSERT INTO 'dancealias' VALUES (23, 3235, 'Musselborough', 'MUSSELBOROUGH', 2);
INSERT INTO 'dancealias' VALUES (24, 3528, 'Bonny Jocky', 'BONNY JOCKY', 2);
INSERT INTO 'dancealias' VALUES (25, 5520, 'Clever Lad, The', 'CLEVER LAD', 2);
INSERT INTO 'dancealias' VALUES (26, 3631, 'Water Kelpie, The', 'WATER KELPIE', 2);
INSERT INTO 'dancealias' VALUES (27, 6566, 'Graces, The', 'GRACES', 2);
INSERT INTO 'dancealias' VALUES (28, 895, 'Flirt, The', 'FLIRT', 2);
INSERT INTO 'dancealias' VALUES (379, 1562, 'Highland Reel', 'HIGHLAND REEL', 2);
INSERT INTO 'dancealias' VALUES (30, 7576, 'Bride''s Reel, The', 'BRIDES REEL', 2);
INSERT INTO 'dancealias' VALUES (31, 5188, 'Big Apple, The', 'BIG APPLE', 2);
INSERT INTO 'dancealias' VALUES (32, 6145, 'Dracula''s Jig', 'DRACULAS JIG', 2);
INSERT INTO 'dancealias' VALUES (33, 1654, 'Very Civil Servant, The', 'VERY CIVIL SERVANT', 2);
INSERT INTO 'dancealias' VALUES (34, 1426, 'Crooked Burn, The', 'CROOKED BURN', 2);
INSERT INTO 'dancealias' VALUES (35, 2125, 'Big Grey Man, The', 'BIG GREY MAN', 2);
INSERT INTO 'dancealias' VALUES (36, 3315, 'Faithful Friend, The', 'FAITHFUL FRIEND', 2);
INSERT INTO 'dancealias' VALUES (37, 338, 'Goldberg Variation, The', 'GOLDBERG VARIATION', 2);
INSERT INTO 'dancealias' VALUES (38, 4130, 'Millenium Rant, The', 'MILLENIUM RANT', 2);
INSERT INTO 'dancealias' VALUES (39, 11, 'Arbroath Medley', 'ARBROATH MEDLEY', 2);
INSERT INTO 'dancealias' VALUES (40, 4, 'Going Courting', 'GOING COURTING', 2);
INSERT INTO 'dancealias' VALUES (41, 77, 'Dunblane Drummer, The', 'DUNBLANE DRUMMER', 2);
INSERT INTO 'dancealias' VALUES (42, 2190, 'First Fleet Hornpipe, The', 'FIRST FLEET HORNPIPE', 2);
INSERT INTO 'dancealias' VALUES (43, 126, 'Hannibal', 'HANNIBAL', 2);
INSERT INTO 'dancealias' VALUES (592, 2697, 'Good Tae See Ye', 'GOOD TAE SEE YE', 1);
INSERT INTO 'dancealias' VALUES (46, 220, 'Something New', 'SOMETHING NEW', 2);
INSERT INTO 'dancealias' VALUES (47, 315, 'Ducks of Derwentwater, The', 'DUCKS OF DERWENTWATER', 2);
INSERT INTO 'dancealias' VALUES (48, 467, 'Rites of Spring, The', 'RITES OF SPRING', 2);
INSERT INTO 'dancealias' VALUES (49, 6240, 'Bog Moss', 'BOG MOSS', 2);
INSERT INTO 'dancealias' VALUES (50, 1769, 'Boozer''s Rant, The', 'BOOZERS RANT', 2);
INSERT INTO 'dancealias' VALUES (51, 1109, 'Border Quarrel, The', 'BORDER QUARREL', 2);
INSERT INTO 'dancealias' VALUES (53, 767, 'Third Man, The', 'THIRD MAN', 2);
INSERT INTO 'dancealias' VALUES (342, 10876, 'It''s Raining Haggis …!', 'ITS RAINING HAGGIS ', 2);
INSERT INTO 'dancealias' VALUES (345, 13681, 'Bruce Frazer''s Farewell to Frimley Green', 'BRUCE FRAZERS FAREWELL TO FRIMLEY GREEN', 0);
INSERT INTO 'dancealias' VALUES (347, 13071, 'Bikie and his Moll, The', 'BIKIE AND HIS MOLL', 2);
INSERT INTO 'dancealias' VALUES (348, 8378, 'Honey Pot, The', 'HONEY POT', 1);
INSERT INTO 'dancealias' VALUES (349, 3475, 'Kiltmaker, The', 'KILTMAKER', 1);
INSERT INTO 'dancealias' VALUES (350, 12399, 'Thaddy, You Gander', 'THADDY YOU GANDER', 1);
INSERT INTO 'dancealias' VALUES (351, 14518, 'Saint Andrews Platinum Reel, The', 'SAINT ANDREWS PLATINUM REEL', 1);
INSERT INTO 'dancealias' VALUES (352, 14519, 'Uncle George', 'UNCLE GEORGE', 2);
INSERT INTO 'dancealias' VALUES (353, 14530, 'A Jig For Michi', 'JIG FOR MICHI', 0);
INSERT INTO 'dancealias' VALUES (355, 14568, 'Feisty Women', 'FEISTY WOMEN', 0);
INSERT INTO 'dancealias' VALUES (357, 14569, 'Three Feisty Women', 'THREE FEISTY WOMEN', 0);
INSERT INTO 'dancealias' VALUES (358, 9889, 'Jean McKelvie''s Jig', 'JEAN MACKELVIES JIG', 2);
INSERT INTO 'dancealias' VALUES (360, 4479, 'Miss Forbes''s Reel', 'MISS FORBESS REEL', 1);
INSERT INTO 'dancealias' VALUES (362, 7559, 'Leapin'' Lizards', 'LEAPIN LIZARDS', 1);
INSERT INTO 'dancealias' VALUES (363, 8630, 'Das Fermatische Fahrrad', 'FERMATISCHE FAHRRAD', 0);
INSERT INTO 'dancealias' VALUES (364, 3935, 'Lord Huntley''s Cave', 'LORD HUNTLEYS CAVE', 1);
INSERT INTO 'dancealias' VALUES (365, 14648, 'Double Diamond Petronella', 'DOUBLE DIAMOND PETRONELLA', 0);
INSERT INTO 'dancealias' VALUES (366, 14648, 'New version Petronella', 'NEW VERSION PETRONELLA', 0);
INSERT INTO 'dancealias' VALUES (368, 83, 'Twin City Reel, The', 'TWIN CITY REEL', 2);
INSERT INTO 'dancealias' VALUES (369, 1649, 'Diamond Jubilee Strathspey, The', 'DIAMOND JUBILEE STRATHSPEY', 2);
INSERT INTO 'dancealias' VALUES (371, 6629, 'Welcome to St Andrews', 'WELCOME TO ST ANDREWS', 2);
INSERT INTO 'dancealias' VALUES (372, 4193, 'Marquis of Huntley''s Snuffmill, The', 'MARQUIS OF HUNTLEYS SNUFFMILL', 1);
INSERT INTO 'dancealias' VALUES (370, 10166, 'Ramadance', 'RAMADANCE', 1);
INSERT INTO 'dancealias' VALUES (374, 6130, 'Double Eightsome Reel', 'DOUBLE EIGHTSOME REEL', 2);
INSERT INTO 'dancealias' VALUES (375, 3593, 'Lady C. Bruce''s Reel', 'LADY C BRUCES REEL', 1);
INSERT INTO 'dancealias' VALUES (16, 2682, 'Cameronian Rant, The', 'CAMERONIAN RANT', 2);
INSERT INTO 'dancealias' VALUES (376, 3642, 'Lady''s Briest Knot', 'LADYS BRIEST KNOT', 1);
INSERT INTO 'dancealias' VALUES (9, 1792, 'Pease Strae', 'PEASE STRAE', 2);
INSERT INTO 'dancealias' VALUES (3, 6359, 'Drops of Brandy', 'DROPS OF BRANDY', 2);
INSERT INTO 'dancealias' VALUES (10, 4309, 'Reel Duine na Marachan', 'REEL DUINE NA MARACHAN', 3);
INSERT INTO 'dancealias' VALUES (56, 7626, 'Callum''s Revelry', 'CALLUMS REVELRY', 2);
INSERT INTO 'dancealias' VALUES (57, 973, 'Larnach Castle', 'LARNACH CASTLE', 2);
INSERT INTO 'dancealias' VALUES (58, 1015, 'Port Jackson Jig, The', 'PORT JACKSON JIG', 2);
INSERT INTO 'dancealias' VALUES (59, 1106, 'Hundred Thousand Welcomes, A', 'HUNDRED THOUSAND WELCOMES', 2);
INSERT INTO 'dancealias' VALUES (60, 693, 'Nutmegger''s Fancy, The', 'NUTMEGGERS FANCY', 2);
INSERT INTO 'dancealias' VALUES (61, 1179, 'Spinning Wheel, The', 'SPINNING WHEEL', 2);
INSERT INTO 'dancealias' VALUES (62, 1212, 'Mr & Mrs James', 'MR AND MRS JAMES', 2);
INSERT INTO 'dancealias' VALUES (63, 1337, 'Reel of the 35th, The', 'REEL OF THE 35TH', 2);
INSERT INTO 'dancealias' VALUES (65, 1484, 'Draper''s Maggot', 'DRAPERS MAGGOT', 2);
INSERT INTO 'dancealias' VALUES (67, 7669, 'John Beedie''s Reel', 'JOHN BEEDIES REEL', 2);
INSERT INTO 'dancealias' VALUES (68, 1572, 'It''s Nice to See Liz''s Legs Better', 'ITS NICE TO SEE LIZS LEGS BETTER', 2);
INSERT INTO 'dancealias' VALUES (70, 1655, 'Duble the Cape', 'DUBLE THE CAPE', 2);
INSERT INTO 'dancealias' VALUES (71, 1658, 'Rosseau Reel, The', 'ROSSEAU REEL', 2);
INSERT INTO 'dancealias' VALUES (377, 3562, 'Tempest, The', 'TEMPEST', 3);
INSERT INTO 'dancealias' VALUES (7, 633, 'Rioghal Leanabh, An', 'RIOGHAL LEANABH', 3);
INSERT INTO 'dancealias' VALUES (12, 1624, 'Deuks dang ower my Daddie, The', 'DEUKS DANG OWER MY DADDIE', 2);
INSERT INTO 'dancealias' VALUES (361, 14568, 'Three Feisty Women', 'THREE FEISTY WOMEN', 1);
INSERT INTO 'dancealias' VALUES (72, 3378, 'Dreamy June', 'DREAMY JUNE', 2);
INSERT INTO 'dancealias' VALUES (55, 991, 'A Candle for Mary', 'CANDLE FOR MARY', 2);
INSERT INTO 'dancealias' VALUES (54, 834, 'Broomhill', 'BROOMHILL', 2);
INSERT INTO 'dancealias' VALUES (69, 1655, 'Dick''s Maggot', 'DICKS MAGGOT', 2);
INSERT INTO 'dancealias' VALUES (74, 1873, 'New Colony, The', 'NEW COLONY', 2);
INSERT INTO 'dancealias' VALUES (75, 1949, 'Silver Jubilee Reel, The', 'SILVER JUBILEE REEL', 2);
INSERT INTO 'dancealias' VALUES (77, 1986, 'McBunny Hop, The', 'MACBUNNY HOP', 2);
INSERT INTO 'dancealias' VALUES (367, 11195, 'Albert''s Welcome to Potten End', 'ALBERTS WELCOME TO POTTEN END', 0);
INSERT INTO 'dancealias' VALUES (346, 587, 'Blue Bell Reel, The', 'BLUE BELL REEL', 2);
INSERT INTO 'dancealias' VALUES (79, 5965, 'Failte Albannach', 'FAILTE ALBANNACH', 2);
INSERT INTO 'dancealias' VALUES (80, 7713, 'Happy Couple, The', 'HAPPY COUPLE', 2);
INSERT INTO 'dancealias' VALUES (81, 2121, 'Fuchs Trot, The', 'FUCHS TROT', 2);
INSERT INTO 'dancealias' VALUES (82, 2161, 'Rebels, The', 'REBELS', 2);
INSERT INTO 'dancealias' VALUES (83, 2184, 'Mount Gravatt Reel', 'MOUNT GRAVATT REEL', 2);
INSERT INTO 'dancealias' VALUES (84, 2219, 'Laurentian Reel, The', 'LAURENTIAN REEL', 2);
INSERT INTO 'dancealias' VALUES (85, 4914, 'Mary, May and Two Margarets', 'MARY MAY AND TWO MARGARETS', 2);
INSERT INTO 'dancealias' VALUES (86, 2322, 'London Bridge', 'LONDON BRIDGE', 2);
INSERT INTO 'dancealias' VALUES (88, 2382, 'Prince Frederick''s Hornpipe', 'PRINCE FREDERICKS HORNPIPE', 2);
INSERT INTO 'dancealias' VALUES (89, 2620, 'Lark of Greenock, The', 'LARK OF GREENOCK', 2);
INSERT INTO 'dancealias' VALUES (90, 2638, 'Watford Caledonians', 'WATFORD CALEDONIANS', 2);
INSERT INTO 'dancealias' VALUES (91, 2699, 'Moira''s Dance', 'MOIRAS DANCE', 2);
INSERT INTO 'dancealias' VALUES (92, 2707, 'Let''s All go Walkabout', 'LETS ALL GO WALKABOUT', 2);
INSERT INTO 'dancealias' VALUES (93, 2741, 'Hot Grey Grease', 'HOT GREY GREASE', 2);
INSERT INTO 'dancealias' VALUES (94, 2741, 'Pipeing Phipps', 'PIPEING PHIPPS', 2);
INSERT INTO 'dancealias' VALUES (96, 2949, 'Princess Amelia', 'PRINCESS AMELIA', 2);
INSERT INTO 'dancealias' VALUES (97, 3028, 'Olive''s Pink Tartan', 'OLIVES PINK TARTAN', 2);
INSERT INTO 'dancealias' VALUES (99, 3116, 'Scots of Kent', 'SCOTS OF KENT', 2);
INSERT INTO 'dancealias' VALUES (100, 3126, 'Kitchen Chairs', 'KITCHEN CHAIRS', 2);
INSERT INTO 'dancealias' VALUES (101, 6716, 'Is This the Right Way?', 'IS THIS THE RIGHT WAY', 2);
INSERT INTO 'dancealias' VALUES (102, 3203, 'Jenny''s Delight', 'JENNYS DELIGHT', 2);
INSERT INTO 'dancealias' VALUES (105, 3550, 'Vancouver Strathspey, The', 'VANCOUVER STRATHSPEY', 2);
INSERT INTO 'dancealias' VALUES (344, 7785, 'Marjorie and Brian', 'MARJORIE AND BRIAN', 2);
INSERT INTO 'dancealias' VALUES (356, 14568, 'Double the Trouble', 'DOUBLE THE TROUBLE', 2);
INSERT INTO 'dancealias' VALUES (76, 2095, 'Emigrant''s Farewell to Scotland, The', 'EMIGRANTS FAREWELL TO SCOTLAND', 2);
INSERT INTO 'dancealias' VALUES (380, 2956, 'Holly Bush, The', 'HOLLY BUSH', 2);
INSERT INTO 'dancealias' VALUES (106, 6897, 'Lauder Ha''', 'LAUDER HA', 2);
INSERT INTO 'dancealias' VALUES (107, 5961, 'Loch Lomond, The', 'LOCH LOMOND', 2);
INSERT INTO 'dancealias' VALUES (108, 3892, 'Royal Mountain, The', 'ROYAL MOUNTAIN', 2);
INSERT INTO 'dancealias' VALUES (109, 3868, 'Nessie''s Nightmare', 'NESSIES NIGHTMARE', 2);
INSERT INTO 'dancealias' VALUES (110, 3916, 'Open Road, The', 'OPEN ROAD', 2);
INSERT INTO 'dancealias' VALUES (111, 3927, 'My Lord Byron''s Maggot', 'MY LORD BYRONS MAGGOT', 2);
INSERT INTO 'dancealias' VALUES (112, 4060, 'Madam Robin', 'MADAM ROBIN', 2);
INSERT INTO 'dancealias' VALUES (113, 4189, 'Ted''s Folly', 'TEDS FOLLY', 2);
INSERT INTO 'dancealias' VALUES (115, 4226, 'Tranterama', 'TRANTERAMA', 2);
INSERT INTO 'dancealias' VALUES (116, 4360, 'WIldfire at Midnight', 'WILDFIRE AT MIDNIGHT', 2);
INSERT INTO 'dancealias' VALUES (117, 5720, 'Mitchell''s Folly', 'MITCHELLS FOLLY', 2);
INSERT INTO 'dancealias' VALUES (119, 4713, 'Pete the Feet', 'PETE THE FEET', 2);
INSERT INTO 'dancealias' VALUES (120, 4811, 'Waiting tae Flit', 'WAITING TAE FLIT', 2);
INSERT INTO 'dancealias' VALUES (122, 4991, 'T''Sealg, An', 'TSEALG', 2);
INSERT INTO 'dancealias' VALUES (123, 4964, 'Flirt, The', 'FLIRT', 2);
INSERT INTO 'dancealias' VALUES (124, 5110, 'Wagons West', 'WAGONS WEST', 2);
INSERT INTO 'dancealias' VALUES (125, 6588, 'Other Side, The', 'OTHER SIDE', 2);
INSERT INTO 'dancealias' VALUES (126, 5285, 'Sweetest Music of All, The', 'SWEETEST MUSIC OF ALL', 2);
INSERT INTO 'dancealias' VALUES (128, 5409, 'Fourteenth of July, The', 'FOURTEENTH OF JULY', 2);
INSERT INTO 'dancealias' VALUES (130, 5873, 'Pour Vous, Susan', 'POUR VOUS SUSAN', 2);
INSERT INTO 'dancealias' VALUES (131, 5923, 'See You Later', 'SEE YOU LATER', 2);
INSERT INTO 'dancealias' VALUES (132, 3727, 'Sheila Scott''s Jig', 'SHEILA SCOTTS JIG', 2);
INSERT INTO 'dancealias' VALUES (134, 6105, 'Left Handed Fiddler, The', 'LEFT HANDED FIDDLER', 2);
INSERT INTO 'dancealias' VALUES (135, 6144, 'Trysting Place, The', 'TRYSTING PLACE', 2);
INSERT INTO 'dancealias' VALUES (136, 6337, 'Anne Riley''s Strathspey', 'ANNE RILEYS STRATHSPEY', 2);
INSERT INTO 'dancealias' VALUES (139, 6601, 'Eight Bars of Opportunity', 'EIGHT BARS OF OPPORTUNITY', 2);
INSERT INTO 'dancealias' VALUES (140, 6899, 'Ye''re No'' Awa''', 'YERE NO AWA', 2);
INSERT INTO 'dancealias' VALUES (141, 6965, 'Whirligig', 'WHIRLIGIG', 2);
INSERT INTO 'dancealias' VALUES (142, 7139, 'Uilliam Dona', 'UILLIAM DONA', 2);
INSERT INTO 'dancealias' VALUES (143, 1088, 'Spinning Wheel', 'SPINNING WHEEL', 2);
INSERT INTO 'dancealias' VALUES (147, 557, 'Reel of the Black Walnut, The', 'REEL OF THE BLACK WALNUT', 2);
INSERT INTO 'dancealias' VALUES (148, 8514, 'Red Dragon, The', 'RED DRAGON', 2);
INSERT INTO 'dancealias' VALUES (149, 8257, 'Highland Dancer, The', 'HIGHLAND DANCER', 2);
INSERT INTO 'dancealias' VALUES (150, 8630, 'August in Erlangen', 'AUGUST IN ERLANGEN', 2);
INSERT INTO 'dancealias' VALUES (151, 8628, 'Flirt, The', 'FLIRT', 2);
INSERT INTO 'dancealias' VALUES (152, 8638, 'Eddisome Reel, The', 'EDDISOME REEL', 2);
INSERT INTO 'dancealias' VALUES (153, 8661, 'Gifhorn Windmills, The', 'GIFHORN WINDMILLS', 2);
INSERT INTO 'dancealias' VALUES (154, 1656, 'Illeana''s Strathspey', 'ILLEANAS STRATHSPEY', 2);
INSERT INTO 'dancealias' VALUES (157, 7438, 'Kathy''s Konundrum', 'KATHYS KONUNDRUM', 2);
INSERT INTO 'dancealias' VALUES (158, 7442, 'Squeezebox Saunter', 'SQUEEZEBOX SAUNTER', 2);
INSERT INTO 'dancealias' VALUES (159, 7385, 'Fred''s Fling', 'FREDS FLING', 2);
INSERT INTO 'dancealias' VALUES (160, 6359, 'Strip the Widow', 'STRIP THE WIDOW', 0);
INSERT INTO 'dancealias' VALUES (161, 2562, 'Glens of Anguish, The', 'GLENS OF ANGUISH', 0);
INSERT INTO 'dancealias' VALUES (266, 11799, 'Coming of Age', 'COMING OF AGE', 2);
INSERT INTO 'dancealias' VALUES (114, 4193, 'Royal Gift, The', 'ROYAL GIFT', 2);
INSERT INTO 'dancealias' VALUES (155, 4782, 'Mrs MacLeod of Raasay', 'MRS MACLEOD OF RAASAY', 0);
INSERT INTO 'dancealias' VALUES (144, 6477, 'Highland Plaid', 'HIGHLAND PLAID', 0);
INSERT INTO 'dancealias' VALUES (129, 5708, 'Hullachan round the House', 'HULLACHAN ROUND THE HOUSE', 2);
INSERT INTO 'dancealias' VALUES (162, 3608, 'Lady Harriet Hopeless', 'LADY HARRIET HOPELESS', 0);
INSERT INTO 'dancealias' VALUES (163, 3588, 'Lady Awkward''s Reel', 'LADY AWKWARDS REEL', 0);
INSERT INTO 'dancealias' VALUES (164, 1478, 'Cumbersome Reel', 'CUMBERSOME REEL', 0);
INSERT INTO 'dancealias' VALUES (165, 1792, 'Puke of Dearth', 'PUKE OF DEARTH', 0);
INSERT INTO 'dancealias' VALUES (166, 7109, 'White Cockup, The', 'WHITE COCKUP', 0);
INSERT INTO 'dancealias' VALUES (167, 1792, 'Duke of Perch', 'DUKE OF PERCH', 0);
INSERT INTO 'dancealias' VALUES (168, 1562, 'Revolving White Detergent, The', 'REVOLVING WHITE DETERGENT', 0);
INSERT INTO 'dancealias' VALUES (169, 1562, 'Dashing White Sturgeon, The', 'DASHING WHITE STURGEON', 0);
INSERT INTO 'dancealias' VALUES (170, 4663, 'Moray Eel, The', 'MORAY EEL', 0);
INSERT INTO 'dancealias' VALUES (171, 2978, 'Grouper and Gird Her', 'GROUPER AND GIRD HER', 0);
INSERT INTO 'dancealias' VALUES (172, 4239, 'Mackerel''s Rant', 'MACKERELS RANT', 0);
INSERT INTO 'dancealias' VALUES (173, 2934, 'Highlandman''s Kippered Mother, The', 'HIGHLANDMANS KIPPERED MOTHER', 0);
INSERT INTO 'dancealias' VALUES (174, 2004, 'Espie MacCrab', 'ESPIE MACCRAB', 0);
INSERT INTO 'dancealias' VALUES (175, 909, 'Badgers in the Canongate', 'BADGERS IN THE CANONGATE', 0);
INSERT INTO 'dancealias' VALUES (177, 1782, 'Duck and Duckess of Edinbugh, The', 'DUCK AND DUCKESS OF EDINBUGH', 0);
INSERT INTO 'dancealias' VALUES (643, 13739, 'IQ 100', 'IQ 100', 1);
INSERT INTO 'dancealias' VALUES (646, 11189, 'Ladies First', 'LADIES FIRST', 0);
INSERT INTO 'dancealias' VALUES (104, 3328, 'John of Paris', 'JOHN OF PARIS', 2);
INSERT INTO 'dancealias' VALUES (78, 2012, 'Ever Happy', 'EVER HAPPY', 2);
INSERT INTO 'dancealias' VALUES (118, 4712, 'Mr Lane''s Maggot', 'MR LANES MAGGOT', 2);
INSERT INTO 'dancealias' VALUES (178, 445, 'Knees of Baggy Trousers, The', 'KNEES OF BAGGY TROUSERS', 0);
INSERT INTO 'dancealias' VALUES (179, 4102, 'My He''s Sweating', 'MY HES SWEATING', 0);
INSERT INTO 'dancealias' VALUES (180, 5497, 'Dead Mouse, The', 'DEAD MOUSE', 0);
INSERT INTO 'dancealias' VALUES (181, 1773, 'Duchess of Atholl''s Slip-Up, The', 'DUCHESS OF ATHOLLS SLIPUP', 0);
INSERT INTO 'dancealias' VALUES (182, 2593, 'Golden Peasant, The', 'GOLDEN PEASANT', 0);
INSERT INTO 'dancealias' VALUES (183, 769, 'Bratach Banana', 'BRATACH BANANA', 0);
INSERT INTO 'dancealias' VALUES (184, 5308, 'Wheelbarrow Burn', 'WHEELBARROW BURN', 0);
INSERT INTO 'dancealias' VALUES (185, 4808, 'Mrs Stuart''s Linoleum', 'MRS STUARTS LINOLEUM', 0);
INSERT INTO 'dancealias' VALUES (186, 2158, 'Fine Mess', 'FINE MESS', 0);
INSERT INTO 'dancealias' VALUES (188, 5260, 'Pimms of Pitlochry, The', 'PIMMS OF PITLOCHRY', 0);
INSERT INTO 'dancealias' VALUES (189, 7111, 'White Leather Pig, The', 'WHITE LEATHER PIG', 0);
INSERT INTO 'dancealias' VALUES (190, 674, 'Bonnie''s Lingerie', 'BONNIES LINGERIE', 0);
INSERT INTO 'dancealias' VALUES (191, 848, 'Buxom Eightsome, The', 'BUXOM EIGHTSOME', 0);
INSERT INTO 'dancealias' VALUES (301, 10484, 'Altamont Fair', 'ALTAMONT FAIR', 2);
INSERT INTO 'dancealias' VALUES (192, 7204, 'Wimps of Gristle, The', 'WIMPS OF GRISTLE', 0);
INSERT INTO 'dancealias' VALUES (193, 6287, 'Starry Eyed Floozie, The', 'STARRY EYED FLOOZIE', 0);
INSERT INTO 'dancealias' VALUES (194, 2349, 'That''s Risky', 'THATS RISKY', 0);
INSERT INTO 'dancealias' VALUES (195, 6091, 'Filthy Lassie, A', 'FILTHY LASSIE', 0);
INSERT INTO 'dancealias' VALUES (196, 909, 'Catch a Sinning Candidate', 'CATCH A SINNING CANDIDATE', 0);
INSERT INTO 'dancealias' VALUES (197, 4827, 'Muriel and Willie', 'MURIEL AND WILLIE', 0);
INSERT INTO 'dancealias' VALUES (198, 373, 'Immoral Strathspey, The', 'IMMORAL STRATHSPEY', 0);
INSERT INTO 'dancealias' VALUES (199, 6739, 'Crisp October Morning, A', 'CRISP OCTOBER MORNING', 0);
INSERT INTO 'dancealias' VALUES (200, 3057, 'And Now it''s Farewell to All Tomorrow', 'AND NOW ITS FAREWELL TO ALL TOMORROW', 0);
INSERT INTO 'dancealias' VALUES (201, 5525, 'Wee Lovely Whitby''s Thirsty Chicken, The', 'WEE LOVELY WHITBYS THIRSTY CHICKEN', 0);
INSERT INTO 'dancealias' VALUES (202, 4928, 'Nudist Chick, The', 'NUDIST CHICK', 0);
INSERT INTO 'dancealias' VALUES (203, 7541, 'Linkumdoddie 2', 'LINKUMDODDIE 2', 2);
INSERT INTO 'dancealias' VALUES (204, 5956, 'Fiddler From Crieff, The', 'FIDDLER FROM CRIEFF', 2);
INSERT INTO 'dancealias' VALUES (205, 4195, 'Marquis of Huntly''s Highlanders, The', 'MARQUIS OF HUNTLYS HIGHLANDERS', 2);
INSERT INTO 'dancealias' VALUES (206, 8850, 'Culicoides Impunctatus', 'CULICOIDES IMPUNCTATUS', 2);
INSERT INTO 'dancealias' VALUES (207, 7349, 'Where my Whimsey Takes Me', 'WHERE MY WHIMSEY TAKES ME', 2);
INSERT INTO 'dancealias' VALUES (208, 8998, 'Peutherer''s Garrett', 'PEUTHERERS GARRETT', 2);
INSERT INTO 'dancealias' VALUES (209, 9019, 'Mo Ghenar Duit', 'MO GHENAR DUIT', 2);
INSERT INTO 'dancealias' VALUES (210, 112, 'Grace of Alvertoune', 'GRACE OF ALVERTOUNE', 2);
INSERT INTO 'dancealias' VALUES (211, 2350, 'Median Amphibian', 'MEDIAN AMPHIBIAN', 0);
INSERT INTO 'dancealias' VALUES (212, 848, 'Aching Buttsome, The', 'ACHING BUTTSOME', 0);
INSERT INTO 'dancealias' VALUES (214, 9211, 'Pine Tree Islands', 'PINE TREE ISLANDS', 2);
INSERT INTO 'dancealias' VALUES (215, 9134, 'Traversons', 'TRAVERSONS', 2);
INSERT INTO 'dancealias' VALUES (216, 7601, 'Back to Alice''s', 'BACK TO ALICES', 2);
INSERT INTO 'dancealias' VALUES (217, 9444, 'Bea''s Jig', 'BEAS JIG', 2);
INSERT INTO 'dancealias' VALUES (218, 9451, 'Weekend Strathspey, The', 'WEEKEND STRATHSPEY', 2);
INSERT INTO 'dancealias' VALUES (219, 3170, 'Sixteenth Night, The', 'SIXTEENTH NIGHT', 2);
INSERT INTO 'dancealias' VALUES (220, 9545, 'In Lieu of Dry Cleaning', 'IN LIEU OF DRY CLEANING', 2);
INSERT INTO 'dancealias' VALUES (221, 7672, '4th of July, The', '4TH OF JULY', 2);
INSERT INTO 'dancealias' VALUES (223, 9754, 'Bridgetown Rant, The', 'BRIDGETOWN RANT', 2);
INSERT INTO 'dancealias' VALUES (224, 7101, 'Peter''s Caper', 'PETERS CAPER', 2);
INSERT INTO 'dancealias' VALUES (225, 9949, 'Bonnie Buchanan', 'BONNIE BUCHANAN', 2);
INSERT INTO 'dancealias' VALUES (226, 8491, 'Twa Worthies, The', 'TWA WORTHIES', 2);
INSERT INTO 'dancealias' VALUES (227, 9966, '5th November, The', '5TH NOVEMBER', 2);
INSERT INTO 'dancealias' VALUES (228, 7742, 'Hamish''s Jig', 'HAMISHS JIG', 2);
INSERT INTO 'dancealias' VALUES (229, 9997, 'Diamond John', 'DIAMOND JOHN', 2);
INSERT INTO 'dancealias' VALUES (230, 9743, 'Anne the Quilter', 'ANNE THE QUILTER', 2);
INSERT INTO 'dancealias' VALUES (231, 10062, 'Holy Island Reel', 'HOLY ISLAND REEL', 2);
INSERT INTO 'dancealias' VALUES (232, 10075, 'Betta-known as Etta', 'BETTAKNOWN AS ETTA', 2);
INSERT INTO 'dancealias' VALUES (233, 6995, 'Weird Couple ''o Fives', 'WEIRD COUPLE O FIVES', 0);
INSERT INTO 'dancealias' VALUES (234, 10089, 'Emma''s Delight', 'EMMAS DELIGHT', 2);
INSERT INTO 'dancealias' VALUES (235, 10160, 'Perpetuum Mobile', 'PERPETUUM MOBILE', 2);
INSERT INTO 'dancealias' VALUES (236, 10157, 'Goodbye to ''You Buy''', 'GOODBYE TO YOU BUY', 2);
INSERT INTO 'dancealias' VALUES (237, 8349, 'Oh Brother Dominic', 'OH BROTHER DOMINIC', 2);
INSERT INTO 'dancealias' VALUES (238, 7973, 'Thingummy Jig', 'THINGUMMY JIG', 2);
INSERT INTO 'dancealias' VALUES (239, 10494, 'From Eight to Nine', 'FROM EIGHT TO NINE', 2);
INSERT INTO 'dancealias' VALUES (241, 10501, 'Silver Wedding Jig', 'SILVER WEDDING JIG', 2);
INSERT INTO 'dancealias' VALUES (242, 8929, 'Ness Cafe, The', 'NESS CAFE', 2);
INSERT INTO 'dancealias' VALUES (244, 10911, 'Fishing Jig, The', 'FISHING JIG', 2);
INSERT INTO 'dancealias' VALUES (245, 11004, 'Fraser''s Circle', 'FRASERS CIRCLE', 2);
INSERT INTO 'dancealias' VALUES (246, 11053, 'Fine Mixture, A', 'FINE MIXTURE', 2);
INSERT INTO 'dancealias' VALUES (247, 11062, 'Roaring Forties Reel, The', 'ROARING FORTIES REEL', 2);
INSERT INTO 'dancealias' VALUES (248, 11072, 'Javier''s Jig', 'JAVIERS JIG', 2);
INSERT INTO 'dancealias' VALUES (249, 11076, 'Which Way did She Go?', 'WHICH WAY DID SHE GO', 2);
INSERT INTO 'dancealias' VALUES (250, 10598, 'How Mixed Up Can You Get?', 'HOW MIXED UP CAN YOU GET', 2);
INSERT INTO 'dancealias' VALUES (251, 2100, 'Braes of Balnabeen, The', 'BRAES OF BALNABEEN', 2);
INSERT INTO 'dancealias' VALUES (253, 2668, 'Chase the Bustle', 'CHASE THE BUSTLE', 2);
INSERT INTO 'dancealias' VALUES (254, 3641, 'Welcome to the Dark Island', 'WELCOME TO THE DARK ISLAND', 2);
INSERT INTO 'dancealias' VALUES (255, 11534, 'Rantin'' Raving Raymond', 'RANTIN RAVING RAYMOND', 2);
INSERT INTO 'dancealias' VALUES (257, 11546, 'Looking for a Latte', 'LOOKING FOR A LATTE', 2);
INSERT INTO 'dancealias' VALUES (594, 3735, 'Lasses of Dunce., The', 'LASSES OF DUNCE', 0);
INSERT INTO 'dancealias' VALUES (259, 2806, 'Kirnfest', 'KIRNFEST', 2);
INSERT INTO 'dancealias' VALUES (260, 11691, 'Two Left Feet', 'TWO LEFT FEET', 2);
INSERT INTO 'dancealias' VALUES (261, 11713, '2001 Napier Summer School Reel, The', '2001 NAPIER SUMMER SCHOOL REEL', 2);
INSERT INTO 'dancealias' VALUES (262, 11717, 'Brief Brief, A', 'BRIEF BRIEF', 2);
INSERT INTO 'dancealias' VALUES (263, 10246, 'Wheel of Time, The', 'WHEEL OF TIME', 2);
INSERT INTO 'dancealias' VALUES (252, 5525, 'Saint Valery Reel, The', 'SAINT VALERY REEL', 0);
INSERT INTO 'dancealias' VALUES (264, 11763, 'One for the Millennium', 'ONE FOR THE MILLENNIUM', 0);
INSERT INTO 'dancealias' VALUES (256, 11543, 'Perpetual Motion', 'PERPETUAL MOTION', 0);
INSERT INTO 'dancealias' VALUES (265, 6964, 'We Twa', 'WE TWA', 0);
INSERT INTO 'dancealias' VALUES (267, 11712, 'Story of Yesterday & Today, The', 'STORY OF YESTERDAY AND TODAY', 2);
INSERT INTO 'dancealias' VALUES (268, 12005, 'Sir William Wallace', 'SIR WILLIAM WALLACE', 2);
INSERT INTO 'dancealias' VALUES (269, 12017, 'Power Failure at Ilford', 'POWER FAILURE AT ILFORD', 2);
INSERT INTO 'dancealias' VALUES (270, 10102, 'Easily Led', 'EASILY LED', 2);
INSERT INTO 'dancealias' VALUES (271, 12029, 'Arkaig Treasure, The', 'ARKAIG TREASURE', 2);
INSERT INTO 'dancealias' VALUES (272, 12034, 'Crooked Glen, The', 'CROOKED GLEN', 2);
INSERT INTO 'dancealias' VALUES (273, 12037, 'Off We Go', 'OFF WE GO', 2);
INSERT INTO 'dancealias' VALUES (274, 9222, 'Dance in Korea, A', 'DANCE IN KOREA', 2);
INSERT INTO 'dancealias' VALUES (275, 8855, 'London 1930 - 4pm', 'LONDON 1930  4PM', 2);
INSERT INTO 'dancealias' VALUES (276, 1490, 'Dancing as far as the Hills', 'DANCING AS FAR AS THE HILLS', 2);
INSERT INTO 'dancealias' VALUES (277, 10155, 'Dennis Rodger''s Delight', 'DENNIS RODGERS DELIGHT', 2);
INSERT INTO 'dancealias' VALUES (278, 8352, 'Four-Oh-Oh-Seven', 'FOUROHOHSEVEN', 2);
INSERT INTO 'dancealias' VALUES (279, 5487, 'Rebecca Dreaming', 'REBECCA DREAMING', 2);
INSERT INTO 'dancealias' VALUES (280, 9458, 'We Are Not Amused', 'WE ARE NOT AMUSED', 2);
INSERT INTO 'dancealias' VALUES (281, 8427, 'Bothy Rant, The', 'BOTHY RANT', 2);
INSERT INTO 'dancealias' VALUES (282, 6741, 'Chorus Jig', 'CHORUS JIG', 2);
INSERT INTO 'dancealias' VALUES (283, 4954, 'Cleanse the Causeway', 'CLEANSE THE CAUSEWAY', 2);
INSERT INTO 'dancealias' VALUES (284, 1600, 'Ten Up for Kingston', 'TEN UP FOR KINGSTON', 2);
INSERT INTO 'dancealias' VALUES (285, 12247, 'Mackay of Barrhead', 'MACKAY OF BARRHEAD', 2);
INSERT INTO 'dancealias' VALUES (286, 12273, 'Headmistress''s Rant, The', 'HEADMISTRESSS RANT', 2);
INSERT INTO 'dancealias' VALUES (288, 12306, 'Flirty Dancer, The', 'FLIRTY DANCER', 2);
INSERT INTO 'dancealias' VALUES (289, 12375, 'Old Urray Reel', 'OLD URRAY REEL', 2);
INSERT INTO 'dancealias' VALUES (290, 12387, 'Peter Robinson''s Rant', 'PETER ROBINSONS RANT', 2);
INSERT INTO 'dancealias' VALUES (291, 12404, 'Mrs Fillis'' Fancy', 'MRS FILLIS FANCY', 2);
INSERT INTO 'dancealias' VALUES (292, 12438, 'Reel of the 65th', 'REEL OF THE 65TH', 2);
INSERT INTO 'dancealias' VALUES (293, 2193, 'Just As We Felt in the Morning', 'JUST AS WE FELT IN THE MORNING', 0);
INSERT INTO 'dancealias' VALUES (294, 12748, 'Robyn and Brian''s Wedding', 'ROBYN AND BRIANS WEDDING', 2);
INSERT INTO 'dancealias' VALUES (295, 12783, 'Babysitter, The', 'BABYSITTER', 2);
INSERT INTO 'dancealias' VALUES (296, 12790, 'Decade, The', 'DECADE', 2);
INSERT INTO 'dancealias' VALUES (297, 2664, 'Loch an Uaine', 'LOCH AN UAINE', 2);
INSERT INTO 'dancealias' VALUES (298, 12819, 'Formby Frolic', 'FORMBY FROLIC', 2);
INSERT INTO 'dancealias' VALUES (299, 12395, 'Wayne''s Workout', 'WAYNES WORKOUT', 2);
INSERT INTO 'dancealias' VALUES (300, 12901, 'Mrs. Ann Marsh''s Bramble Tapsalteerie', 'MRS ANN MARSHS BRAMBLE TAPSALTEERIE', 2);
INSERT INTO 'dancealias' VALUES (302, 12997, 'Curse Reversed, The', 'CURSE REVERSED', 2);
INSERT INTO 'dancealias' VALUES (303, 13136, 'Bullet Train, The', 'BULLET TRAIN', 2);
INSERT INTO 'dancealias' VALUES (304, 13147, 'Big Five O, The', 'BIG FIVE O', 2);
INSERT INTO 'dancealias' VALUES (305, 13148, 'Saskatchewan Celebration', 'SASKATCHEWAN CELEBRATION', 2);
INSERT INTO 'dancealias' VALUES (306, 13218, 'After a Hangover', 'AFTER A HANGOVER', 2);
INSERT INTO 'dancealias' VALUES (307, 13351, 'Summer in Paris', 'SUMMER IN PARIS', 2);
INSERT INTO 'dancealias' VALUES (308, 6010, 'Seaton''s Ceilidh Band', 'SEATONS CEILIDH BAND', 0);
INSERT INTO 'dancealias' VALUES (309, 3759, 'The Lea Rigg', 'LEA RIGG', 0);
INSERT INTO 'dancealias' VALUES (310, 3941, 'Lord McLay''s Reel', 'LORD MACLAYS REEL', 0);
INSERT INTO 'dancealias' VALUES (311, 571, 'Blue Ribbon, The', 'BLUE RIBBON', 0);
INSERT INTO 'dancealias' VALUES (312, 8958, 'Big Kirsty', 'BIG KIRSTY', 2);
INSERT INTO 'dancealias' VALUES (313, 13601, 'Jill with a J', 'JILL WITH A J', 0);
INSERT INTO 'dancealias' VALUES (314, 13513, 'Bluebells of Yukio', 'BLUEBELLS OF YUKIO', 2);
INSERT INTO 'dancealias' VALUES (315, 13726, 'The Man Hunt', 'MAN HUNT', 2);
INSERT INTO 'dancealias' VALUES (316, 13722, 'The Gaviscon Girl', 'GAVISCON GIRL', 2);
INSERT INTO 'dancealias' VALUES (318, 13523, 'Rathad Chalum', 'RATHAD CHALUM', 2);
INSERT INTO 'dancealias' VALUES (317, 3237, 'Hey! Jenny, Come Down To Jock', 'HEY JENNY COME DOWN TO JOCK', 0);
INSERT INTO 'dancealias' VALUES (319, 2711, 'Happiness Is Scottish Country Dancing', 'HAPPINESS IS SCOTTISH COUNTRY DANCING', 2);
INSERT INTO 'dancealias' VALUES (320, 13803, 'Maxwell''s Fugue', 'MAXWELLS FUGUE', 2);
INSERT INTO 'dancealias' VALUES (321, 13648, 'Rundumadum', 'RUNDUMADUM', 2);
INSERT INTO 'dancealias' VALUES (323, 1854, 'Duns 500 Strathspey', 'DUNS 500 STRATHSPEY', 2);
INSERT INTO 'dancealias' VALUES (325, 12790, 'Jahrzent, Das', 'JAHRZENT', 2);
INSERT INTO 'dancealias' VALUES (326, 14134, 'Shetland Quadrilles Figure 1', 'SHETLAND QUADRILLES FIGURE 1', 0);
INSERT INTO 'dancealias' VALUES (327, 14134, 'Shetland Quadrilles Figure 2', 'SHETLAND QUADRILLES FIGURE 2', 0);
INSERT INTO 'dancealias' VALUES (328, 14134, 'Shetland Quadrilles Figure 3', 'SHETLAND QUADRILLES FIGURE 3', 0);
INSERT INTO 'dancealias' VALUES (329, 14134, 'Shetland Quadrilles Figure 4', 'SHETLAND QUADRILLES FIGURE 4', 0);
INSERT INTO 'dancealias' VALUES (330, 14134, 'Shetland Quadrilles Figure 5', 'SHETLAND QUADRILLES FIGURE 5', 0);
INSERT INTO 'dancealias' VALUES (331, 14134, 'Shetland Quadrilles Figure 6', 'SHETLAND QUADRILLES FIGURE 6', 0);
INSERT INTO 'dancealias' VALUES (332, 12973, 'Carry on Sue', 'CARRY ON SUE', 0);
INSERT INTO 'dancealias' VALUES (333, 14321, 'Mr. John Duckett''s Jig', 'MR JOHN DUCKETTS JIG', 2);
INSERT INTO 'dancealias' VALUES (334, 9676, 'To Scotia''s Shores We''re Noo Awa''', 'TO SCOTIAS SHORES WERE NOO AWA', 2);
INSERT INTO 'dancealias' VALUES (335, 12089, 'Big Mac', 'BIG MAC', 2);
INSERT INTO 'dancealias' VALUES (336, 9125, 'Side by Side', 'SIDE BY SIDE', 2);
INSERT INTO 'dancealias' VALUES (337, 14354, 'Nondescript Carpet Court, The ', 'NONDESCRIPT CARPET COURT THE ', 2);
INSERT INTO 'dancealias' VALUES (338, 13961, 'Maids in the Mirror', 'MAIDS IN THE MIRROR', 2);
INSERT INTO 'dancealias' VALUES (339, 1207, 'How are You?', 'HOW ARE YOU', 2);
INSERT INTO 'dancealias' VALUES (324, 5982, 'Seann Truibhas Willichan', 'SEANN TRUIBHAS WILLICHAN', 1);
INSERT INTO 'dancealias' VALUES (340, 4440, 'Miss Burns'' Reel', 'MISS BURNS REEL', 1);
INSERT INTO 'dancealias' VALUES (341, 6287, 'Starry-Eyed Lassie, The', 'STARRYEYED LASSIE', 1);
INSERT INTO 'dancealias' VALUES (382, 6451, 'Tambourine Reel, The', 'TAMBOURINE REEL', 0);
INSERT INTO 'dancealias' VALUES (383, 9350, 'Fruit Cake, The', 'FRUIT CAKE', 1);
INSERT INTO 'dancealias' VALUES (384, 14750, 'The H.L.I.', 'HLI', 2);
INSERT INTO 'dancealias' VALUES (373, 4680, 'Black Mill, The', 'BLACK MILL', 3);
INSERT INTO 'dancealias' VALUES (6, 633, 'Lagach Anna', 'LAGACH ANNA', 3);
INSERT INTO 'dancealias' VALUES (385, 2846, 'Figheadh Dannse, An', 'FIGHEADH DANNSE', 3);
INSERT INTO 'dancealias' VALUES (386, 7552, 'Military Two-Step', 'MILITARY TWOSTEP', 1);
INSERT INTO 'dancealias' VALUES (387, 1428, 'Cromartie''s Rant', 'CROMARTIES RANT', 1);
INSERT INTO 'dancealias' VALUES (595, 4562, 'Miss Nanny frowns', 'MISS NANNY FROWNS', 0);
INSERT INTO 'dancealias' VALUES (390, 7333, 'Thirteenth of September', 'THIRTEENTH OF SEPTEMBER', 1);
INSERT INTO 'dancealias' VALUES (391, 7302, 'Five-couple Fugue', 'FIVECOUPLE FUGUE', 1);
INSERT INTO 'dancealias' VALUES (392, 7332, 'Twenty-Ninth of June', 'TWENTYNINTH OF JUNE', 1);
INSERT INTO 'dancealias' VALUES (394, 14881, 'Saint Andrew and Saint George', 'SAINT ANDREW AND SAINT GEORGE', 0);
INSERT INTO 'dancealias' VALUES (393, 14883, 'Saint Andrews Square', 'SAINT ANDREWS SQUARE', 1);
INSERT INTO 'dancealias' VALUES (395, 14342, 'Rosie''s Celidh ', 'ROSIES CELIDH ', 1);
INSERT INTO 'dancealias' VALUES (396, 13003, 'Bamble Jelly ', 'BAMBLE JELLY ', 1);
INSERT INTO 'dancealias' VALUES (397, 14368, 'The Koelbls'' Reel', 'KOELBLS REEL', 1);
INSERT INTO 'dancealias' VALUES (398, 13626, 'Hungarian Bride, The', 'HUNGARIAN BRIDE', 1);
INSERT INTO 'dancealias' VALUES (400, 15087, 'TGIF', 'TGIF', 0);
INSERT INTO 'dancealias' VALUES (401, 15056, 'OOK', 'OOK', 2);
INSERT INTO 'dancealias' VALUES (402, 15148, 'Homecoming 2009', 'HOMECOMING 2009', 2);
INSERT INTO 'dancealias' VALUES (403, 13555, ' The Queen of Torquay', ' THE QUEEN OF TORQUAY', 2);
INSERT INTO 'dancealias' VALUES (404, 6712, 'Eine Reise nach Bayern', 'EINE REISE NACH BAYERN', 3);
INSERT INTO 'dancealias' VALUES (405, 8143, 'Britannia Two-Step', 'BRITANNIA TWOSTEP', 1);
INSERT INTO 'dancealias' VALUES (406, 8143, 'Britannia Twostep', 'BRITANNIA TWOSTEP', 1);
INSERT INTO 'dancealias' VALUES (596, 522, 'Birks of Endermay', 'BIRKS OF ENDERMAY', 0);
INSERT INTO 'dancealias' VALUES (408, 15206, 'Tribute to Lyon, A', 'TRIBUTE TO LYON', 2);
INSERT INTO 'dancealias' VALUES (409, 2593, 'Tungsten Turkey, The', 'TUNGSTEN TURKEY', 0);
INSERT INTO 'dancealias' VALUES (411, 15323, 'The Six-Fingered Man', 'SIXFINGERED MAN', 0);
INSERT INTO 'dancealias' VALUES (322, 313, 'Australian Ladies', 'AUSTRALIAN LADIES', 0);
INSERT INTO 'dancealias' VALUES (413, 11338, 'Millennium Rigged Ship', 'MILLENNIUM RIGGED SHIP', 1);
INSERT INTO 'dancealias' VALUES (415, 4130, 'Millennium Rant, The', 'MILLENNIUM RANT', 1);
INSERT INTO 'dancealias' VALUES (416, 10933, 'Toast to the Millennium, A', 'TOAST TO THE MILLENNIUM', 1);
INSERT INTO 'dancealias' VALUES (417, 13837, 'Alexander''s Ruby', 'ALEXANDERS RUBY', 1);
INSERT INTO 'dancealias' VALUES (418, 5807, 'St Andrews Nicht', 'SAINT ANDREWS NICHT', 1);
INSERT INTO 'dancealias' VALUES (419, 14014, 'Mo Chuachag Laghach Thu', 'MO CHUACHAG LAGHACH THU', 3);
INSERT INTO 'dancealias' VALUES (421, 10048, 'Well Done, Bernard!', 'WELL DONE BERNARD', 1);
INSERT INTO 'dancealias' VALUES (420, 10048, 'Well Done Bernard', 'WELL DONE BERNARD', 1);
INSERT INTO 'dancealias' VALUES (422, 15454, 'Mike Pagella''s Flight of Fancy', 'MIKE PAGELLAS FLIGHT OF FANCY', 2);
INSERT INTO 'dancealias' VALUES (423, 6897, 'Waggle of The Kilt, The', 'WAGGLE OF THE KILT', 1);
INSERT INTO 'dancealias' VALUES (424, 3869, 'Lochness Monster', 'LOCHNESS MONSTER', 1);
INSERT INTO 'dancealias' VALUES (425, 5801, 'Saint Andrew''s Double Foursome', 'SAINT ANDREWS DOUBLE FOURSOME', 1);
INSERT INTO 'dancealias' VALUES (410, 2604, 'Good Hearted Glasgow Jig, The', 'GOOD HEARTED GLASGOW JIG', 0);
INSERT INTO 'dancealias' VALUES (388, 1624, 'Deuks dang ow''er my Daddie, The', 'DEUKS DANG OWER MY DADDIE', 1);
INSERT INTO 'dancealias' VALUES (412, 11957, 'Millenium Reel', 'MILLENIUM REEL', 1);
INSERT INTO 'dancealias' VALUES (426, 15540, 'Relocation Reel', 'RELOCATION REEL', 2);
INSERT INTO 'dancealias' VALUES (427, 4102, 'Mairi''s Divorce', 'MAIRIS DIVORCE', 0);
INSERT INTO 'dancealias' VALUES (428, 324, 'Awa'' Whigs, Awa''', 'AWA WHIGS AWA', 1);
INSERT INTO 'dancealias' VALUES (430, 9812, 'Fourteen/Twelve', 'FOURTEEN/TWELVE', 1);
INSERT INTO 'dancealias' VALUES (432, 12335, '1964', '1964', 1);
INSERT INTO 'dancealias' VALUES (433, 13595, 'The Riverside Jig', 'RIVERSIDE JIG', 0);
INSERT INTO 'dancealias' VALUES (240, 1609, 'Changing Poussettes', 'CHANGING POUSSETTES', 2);
INSERT INTO 'dancealias' VALUES (434, 8953, 'Saint Barnabas Strathspey', 'SAINT BARNABAS STRATHSPEY', 1);
INSERT INTO 'dancealias' VALUES (435, 11363, 'Mrs Thew of Mount Wellington', 'MRS THEW OF MOUNT WELLINGTON', 1);
INSERT INTO 'dancealias' VALUES (436, 5797, 'St. Aidans Old Hall', 'SAINT AIDANS OLD HALL', 1);
INSERT INTO 'dancealias' VALUES (438, 11195, 'Albert''s Welcome', 'ALBERTS WELCOME', 2);
INSERT INTO 'dancealias' VALUES (439, 9985, 'Christie''s Strathspey', 'CHRISTIES STRATHSPEY', 1);
INSERT INTO 'dancealias' VALUES (440, 15314, 'Farewell to Chandi McCracken', 'FAREWELL TO CHANDI MACCRACKEN', 2);
INSERT INTO 'dancealias' VALUES (441, 10031, 'Retiring Sailor, The', 'RETIRING SAILOR', 2);
INSERT INTO 'dancealias' VALUES (442, 10031, 'Memories of My Paddle Wheel Days', 'MEMORIES OF MY PADDLE WHEEL DAYS', 2);
INSERT INTO 'dancealias' VALUES (443, 10031, 'Come Ashore You Silly Bugger, Come Ashore', 'COME ASHORE YOU SILLY BUGGER COME ASHORE', 2);
INSERT INTO 'dancealias' VALUES (444, 12089, 'Macdonald of the Isles, Five-couple', 'MACDONALD OF THE ISLES FIVECOUPLE', 1);
INSERT INTO 'dancealias' VALUES (597, 4728, 'Mrs Wilson''s Hornpipe', 'MRS WILSONS HORNPIPE', 0);
INSERT INTO 'dancealias' VALUES (501, 17261, 'Jingling Johnny', 'JINGLING JOHNNY', 2);
INSERT INTO 'dancealias' VALUES (502, 15982, 'Come & Follow Me', 'COME AND FOLLOW ME', 1);
INSERT INTO 'dancealias' VALUES (503, 17329, 'Proud Mary', 'PROUD MARY', 2);
INSERT INTO 'dancealias' VALUES (504, 8714, 'Other Manchester Medley, T''', 'OTHER MANCHESTER MEDLEY T', 0);
INSERT INTO 'dancealias' VALUES (505, 1485, 'Curlywee', 'CURLYWEE', 1);
INSERT INTO 'dancealias' VALUES (445, 15326, 'As You Wish, PBC', 'AS YOU WISH PBC', 2);
INSERT INTO 'dancealias' VALUES (482, 8371, 'Farnham Ruby Reel', 'FARNHAM RUBY REEL', 2);
INSERT INTO 'dancealias' VALUES (644, 7301, 'Gabor''s Wedding', 'GABORS WEDDING', 1);
INSERT INTO 'dancealias' VALUES (98, 3110, 'The Inverness Sixsome', 'INVERNESS SIXSOME', 2);
INSERT INTO 'dancealias' VALUES (448, 15918, 'Mac Murrow', 'MAC MURROW', 2);
INSERT INTO 'dancealias' VALUES (449, 15943, '1 Under Par', '1 UNDER PAR', 2);
INSERT INTO 'dancealias' VALUES (450, 13351, 'L''Ete a Paris', 'LETE A PARIS', 1);
INSERT INTO 'dancealias' VALUES (451, 15999, 'Ternes Reel, The', 'TERNES REEL', 2);
INSERT INTO 'dancealias' VALUES (452, 2394, 'Gang the same gait', 'GANG THE SAME GAIT', 0);
INSERT INTO 'dancealias' VALUES (453, 16035, 'Moon Beams Kiss the Sea', 'MOON BEAMS KISS THE SEA', 1);
INSERT INTO 'dancealias' VALUES (454, 12803, 'Floozie in the Jacuzzi, The', 'FLOOZIE IN THE JACUZZI', 1);
INSERT INTO 'dancealias' VALUES (455, 13488, 'Mrs Eightford', 'MRS EIGHTFORD', 1);
INSERT INTO 'dancealias' VALUES (456, 16059, 'Eírigh Na Gréine Air Bàth Chraig', 'EIRIGH NA GREINE AIR BATH CHRAIG', 2);
INSERT INTO 'dancealias' VALUES (458, 16158, 'Saint Magnus Quadrille', 'SAINT MAGNUS QUADRILLE', 1);
INSERT INTO 'dancealias' VALUES (459, 16072, 'Невский Проспект', 'NEVSKII PROSPEKT', 1);
INSERT INTO 'dancealias' VALUES (460, 2242, 'Flower of the Quern, The', 'FLOWER OF THE QUERN', 1);
INSERT INTO 'dancealias' VALUES (258, 11550, 'Lexelle''s Reel', 'LEXELLES REEL', 2);
INSERT INTO 'dancealias' VALUES (463, 16483, 'Shirley''s Twenty and One the Day', 'SHIRLEYS TWENTY AND ONE THE DAY', 2);
INSERT INTO 'dancealias' VALUES (464, 16687, 'Our First Lady is a New Member!', 'OUR FIRST LADY IS A NEW MEMBER', 2);
INSERT INTO 'dancealias' VALUES (465, 16699, 'Belfast Hornpipe, The', 'BELFAST HORNPIPE', 0);
INSERT INTO 'dancealias' VALUES (469, 5823, 'Sidlaw Hills', 'SIDLAW HILLS', 2);
INSERT INTO 'dancealias' VALUES (506, 17364, 'from N to M', 'FROM N TO M', 2);
INSERT INTO 'dancealias' VALUES (468, 6066, 'Sidlaw Hills', 'SIDLAW HILLS', 2);
INSERT INTO 'dancealias' VALUES (470, 13449, 'Bruce''s Men', 'BRUCES MEN', 2);
INSERT INTO 'dancealias' VALUES (471, 11188, 'Caerlaverock Castle', 'CAERLAVEROCK CASTLE', 2);
INSERT INTO 'dancealias' VALUES (45, 2769, 'Anita''s Wedding', 'ANITAS WEDDING', 2);
INSERT INTO 'dancealias' VALUES (472, 13362, 'Montreal Anniversary Jig', 'MONTREAL ANNIVERSARY JIG', 1);
INSERT INTO 'dancealias' VALUES (473, 16465, 'Chaste Lovers', 'CHASTE LOVERS', 2);
INSERT INTO 'dancealias' VALUES (475, 15589, 'Montreal Entrelac Tees', 'MONTREAL ENTRELAC TEES', 1);
INSERT INTO 'dancealias' VALUES (476, 3649, 'Laich o'' Moray, The', 'LAICH O MORAY', 1);
INSERT INTO 'dancealias' VALUES (477, 6532, '1314', '1314', 1);
INSERT INTO 'dancealias' VALUES (478, 16828, '90th Birthday, The', '90TH BIRTHDAY', 2);
INSERT INTO 'dancealias' VALUES (479, 16828, 'Ninetieth Birthday, The', 'NINETIETH BIRTHDAY', 1);
INSERT INTO 'dancealias' VALUES (480, 13269, 'Campbell''s Fancy', 'CAMPBELLS FANCY', 2);
INSERT INTO 'dancealias' VALUES (481, 12877, 'Every Which Way', 'EVERY WHICH WAY', 0);
INSERT INTO 'dancealias' VALUES (483, 14285, 'Francois'' Frolic', 'FRANCOIS FROLIC', 1);
INSERT INTO 'dancealias' VALUES (484, 8856, '10 years later', '10 YEARS LATER', 2);
INSERT INTO 'dancealias' VALUES (485, 16869, 'The Lost Forty', 'LOST FORTY', 0);
INSERT INTO 'dancealias' VALUES (437, 5797, 'St. Aidan''s Old Hall', 'SAINT AIDANS OLD HALL', 1);
INSERT INTO 'dancealias' VALUES (486, 10327, 'The OXO Reel', 'OXO REEL', 0);
INSERT INTO 'dancealias' VALUES (487, 10327, 'OXO dance', 'OXO DANCE', 0);
INSERT INTO 'dancealias' VALUES (488, 16816, 'Method Madness', 'METHOD MADNESS', 2);
INSERT INTO 'dancealias' VALUES (489, 16900, 'On yer Bike', 'ON YER BIKE', 0);
INSERT INTO 'dancealias' VALUES (461, 9470, 'Downside Up', 'DOWNSIDE UP', 2);
INSERT INTO 'dancealias' VALUES (491, 13309, 'Giradet House', 'GIRADET HOUSE', 1);
INSERT INTO 'dancealias' VALUES (492, 13309, 'EVAG', 'EVAG', 2);
INSERT INTO 'dancealias' VALUES (493, 13309, '"Meals on Wheels"', 'MEALS ON WHEELS', 2);
INSERT INTO 'dancealias' VALUES (494, 16941, 'Gathered Threads', 'GATHERED THREADS', 2);
INSERT INTO 'dancealias' VALUES (495, 8745, 'Seann Truibhas', 'SEANN TRUIBHAS', 1);
INSERT INTO 'dancealias' VALUES (496, 8744, 'Ghillie Callum', 'GHILLIE CALLUM', 2);
INSERT INTO 'dancealias' VALUES (497, 10478, 'Colonel Joshua Lawrence Chamberlain', 'COLONEL JOSHUA LAWRENCE CHAMBERLAIN', 0);
INSERT INTO 'dancealias' VALUES (498, 11331, 'One Past Midnight', 'ONE PAST MIDNIGHT', 1);
INSERT INTO 'dancealias' VALUES (474, 16794, 'Electric Pattersons, The', 'ELECTRIC PATTERSONS', 2);
INSERT INTO 'dancealias' VALUES (499, 7547, 'Nor Loch, The', 'NOR LOCH', 1);
INSERT INTO 'dancealias' VALUES (500, 17156, 'Oh Crap, He''s Back!!', 'OH CRAP HES BACK', 0);
INSERT INTO 'dancealias' VALUES (507, 17364, 'From N(ovosibirsk) to M(oscow)', 'FROM NOVOSIBIRSK TO MOSCOW', 1);
INSERT INTO 'dancealias' VALUES (508, 16461, 'Three E''s, The', 'THREE ES', 1);
INSERT INTO 'dancealias' VALUES (509, 10974, 'The  Whirry-Hole', 'WHIRRYHOLE', 2);
INSERT INTO 'dancealias' VALUES (510, 16570, '6th of August', '6TH OF AUGUST', 1);
INSERT INTO 'dancealias' VALUES (511, 16855, 'One''s with Twos, Threes & Fours', 'ONES WITH TWOS THREES AND FOURS', 1);
INSERT INTO 'dancealias' VALUES (512, 220, 'Argyl Reel', 'ARGYL REEL', 1);
INSERT INTO 'dancealias' VALUES (513, 6405, 'Hamish Henderson''s Refusal', 'HAMISH HENDERSONS REFUSAL', 0);
INSERT INTO 'dancealias' VALUES (514, 16806, 'Jenny''s Strathspey', 'JENNYS STRATHSPEY', 1);
INSERT INTO 'dancealias' VALUES (515, 9286, 'Abbott of Unreason, The', 'ABBOTT OF UNREASON', 1);
INSERT INTO 'dancealias' VALUES (516, 2119, 'Fellside Rambles', 'FELLSIDE RAMBLES', 1);
INSERT INTO 'dancealias' VALUES (517, 10433, 'The Dreamcatcher', 'DREAMCATCHER', 1);
INSERT INTO 'dancealias' VALUES (518, 10382, 'Seann Triubhas for Four', 'SEANN TRIUBHAS FOR FOUR', 1);
INSERT INTO 'dancealias' VALUES (520, 5023, '"Oban" Reel, The', 'OBAN REEL', 2);
INSERT INTO 'dancealias' VALUES (521, 271, '"Atholl" Reel, The', 'ATHOLL REEL', 2);
INSERT INTO 'dancealias' VALUES (522, 364, '"Ballater" Reel, The', 'BALLATER REEL', 0);
INSERT INTO 'dancealias' VALUES (524, 1483, '"Cupar" Jig, The', 'CUPAR JIG', 0);
INSERT INTO 'dancealias' VALUES (519, 1414, '"Crieff" Jig, The', 'CRIEFF JIG', 2);
INSERT INTO 'dancealias' VALUES (525, 1414, '"Crief" Jig, The', 'CRIEF JIG', 1);
INSERT INTO 'dancealias' VALUES (526, 13275, 'Don and Dee''s Reel', 'DON AND DEES REEL', 1);
INSERT INTO 'dancealias' VALUES (527, 12245, 'Saint Machar Strathspey, The', 'SAINT MACHAR STRATHSPEY', 1);
INSERT INTO 'dancealias' VALUES (528, 17553, 'Après le bal', 'APRES LE BAL', 1);
INSERT INTO 'dancealias' VALUES (529, 1353, 'Cornett''s Lass, The', 'CORNETTS LASS', 1);
INSERT INTO 'dancealias' VALUES (530, 17538, 'Orchards of Armagh, The', 'ORCHARDS OF ARMAGH', 0);
INSERT INTO 'dancealias' VALUES (532, 17620, 'Saint Columba''s 60th Anniversary Reel', 'SAINT COLUMBAS 60TH ANNIVERSARY REEL', 1);
INSERT INTO 'dancealias' VALUES (533, 17627, 'Joy of the Dance, The', 'JOY OF THE DANCE', 3);
INSERT INTO 'dancealias' VALUES (534, 4447, 'Miss Christy Stewart', 'MISS CHRISTY STEWART', 1);
INSERT INTO 'dancealias' VALUES (535, 15591, '2pm', '2PM', 1);
INSERT INTO 'dancealias' VALUES (536, 17201, 'Canda Rising', 'CANDA RISING', 1);
INSERT INTO 'dancealias' VALUES (537, 9903, 'Where the River Almond Flows', 'WHERE THE RIVER ALMOND FLOWS', 2);
INSERT INTO 'dancealias' VALUES (598, 18293, 'Supreme By Position', 'SUPREME BY POSITION', 2);
INSERT INTO 'dancealias' VALUES (539, 14820, 'Double Cherry Blossoms', 'DOUBLE CHERRY BLOSSOMS', 2);
INSERT INTO 'dancealias' VALUES (540, 17713, 'Quacks of Doom, The', 'QUACKS OF DOOM', 0);
INSERT INTO 'dancealias' VALUES (541, 1238, 'Cloutie Well, The', 'CLOUTIE WELL', 1);
INSERT INTO 'dancealias' VALUES (542, 17704, 'Dance with Susanne, A', 'DANCE WITH SUSANNE', 0);
INSERT INTO 'dancealias' VALUES (664, 2741, 'Smiths Round O', 'SMITHS ROUND O', 1);
INSERT INTO 'dancealias' VALUES (544, 17728, 'Raphaelle''s Jig', 'RAPHAELLES JIG', 1);
INSERT INTO 'dancealias' VALUES (545, 17647, 'Sixty Years On', 'SIXTY YEARS ON', 2);
INSERT INTO 'dancealias' VALUES (600, 17920, 'Desiree Patterson', 'DESIREE PATTERSON', 1);
INSERT INTO 'dancealias' VALUES (546, 16384, 'Spark O''Water, The', 'SPARK OWATER', 2);
INSERT INTO 'dancealias' VALUES (548, 5253, 'Pide Piper''s Lady', 'PIDE PIPERS LADY', 1);
INSERT INTO 'dancealias' VALUES (549, 17881, 'The Agile Uistman', 'AGILE UISTMAN', 3);
INSERT INTO 'dancealias' VALUES (550, 17882, 'Celebrations 2017', 'CELEBRATIONS 2017', 1);
INSERT INTO 'dancealias' VALUES (551, 3336, 'Johnny Walker (misspelling)', 'JOHNNY WALKER MISSPELLING', 1);
INSERT INTO 'dancealias' VALUES (552, 16339, 'License to Reel', 'LICENSE TO REEL', 1);
INSERT INTO 'dancealias' VALUES (553, 17903, 'Third Man, The', 'THIRD MAN', 2);
INSERT INTO 'dancealias' VALUES (554, 13446, 'Telford Hornpipe, The', 'TELFORD HORNPIPE', 2);
INSERT INTO 'dancealias' VALUES (555, 14854, 'Ladies and Lads', 'LADIES AND LADS', 2);
INSERT INTO 'dancealias' VALUES (556, 14854, 'Ladies and their Lads, The', 'LADIES AND THEIR LADS', 1);
INSERT INTO 'dancealias' VALUES (557, 14854, 'Ladies & Lads', 'LADIES AND LADS', 1);
INSERT INTO 'dancealias' VALUES (558, 14851, 'Leap in the Dark (McGregor''s)', 'LEAP IN THE DARK MACGREGORS', 2);
INSERT INTO 'dancealias' VALUES (559, 14882, 'St. Andrew Feast', 'SAINT ANDREW FEAST', 0);
INSERT INTO 'dancealias' VALUES (560, 8736, 'Saint Andrews Links', 'SAINT ANDREWS LINKS', 0);
INSERT INTO 'dancealias' VALUES (561, 8671, 'Saint Martin''s Cross', 'SAINT MARTINS CROSS', 0);
INSERT INTO 'dancealias' VALUES (562, 14826, 'Break in the Clouds', 'BREAK IN THE CLOUDS', 2);
INSERT INTO 'dancealias' VALUES (563, 14851, 'McGregor''s Leap', 'MACGREGORS LEAP', 0);
INSERT INTO 'dancealias' VALUES (564, 17949, 'CALEY 100', 'CALEY 100', 2);
INSERT INTO 'dancealias' VALUES (565, 17984, 'Innocent Railway, The', 'INNOCENT RAILWAY', 0);
INSERT INTO 'dancealias' VALUES (566, 16189, 'Hans and Ulla', 'HANS AND ULLA', 2);
INSERT INTO 'dancealias' VALUES (567, 10082, 'Rings Around the Moon', 'RINGS AROUND THE MOON', 1);
INSERT INTO 'dancealias' VALUES (601, 18389, 'Not the full Shilling', 'NOT THE FULL SHILLING', 2);
INSERT INTO 'dancealias' VALUES (602, 6518, 'Theeket House, The', 'THEEKET HOUSE', 1);
INSERT INTO 'dancealias' VALUES (570, 3172, 'J B Milne', 'J B MILNE', 1);
INSERT INTO 'dancealias' VALUES (571, 7548, 'Highland Scottische', 'HIGHLAND SCOTTISCHE', 1);
INSERT INTO 'dancealias' VALUES (572, 2604, 'Good-Hearted Glasgow', 'GOODHEARTED GLASGOW', 0);
INSERT INTO 'dancealias' VALUES (573, 13635, 'Lisi''s Graduation Reel', 'LISIS GRADUATION REEL', 2);
INSERT INTO 'dancealias' VALUES (568, 1479, 'Cumberland Square', 'CUMBERLAND SQUARE', 0);
INSERT INTO 'dancealias' VALUES (569, 1479, 'Square Eight, The', 'SQUARE EIGHT', 2);
INSERT INTO 'dancealias' VALUES (574, 10156, 'Cat Walk, The', 'CAT WALK', 1);
INSERT INTO 'dancealias' VALUES (576, 11775, 'Line Dance for Uncle, A', 'LINE DANCE FOR UNCLE', 1);
INSERT INTO 'dancealias' VALUES (577, 5826, 'Saint Fillan''s Day', 'SAINT FILLANS DAY', 1);
INSERT INTO 'dancealias' VALUES (578, 5812, 'Saint Andrew''s Square', 'SAINT ANDREWS SQUARE', 1);
INSERT INTO 'dancealias' VALUES (580, 107, 'Burn by the Hillock, The', 'BURN BY THE HILLOCK', 2);
INSERT INTO 'dancealias' VALUES (581, 8340, 'Miss Judy Hodgkins'' Reel', 'MISS JUDY HODGKINS REEL', 1);
INSERT INTO 'dancealias' VALUES (603, 12964, 'Echoes of Inverneill', 'ECHOES OF INVERNEILL', 1);
INSERT INTO 'dancealias' VALUES (583, 18123, 'Drochaid do Scalpaigh', 'DROCHAID DO SCALPAIGH', 3);
INSERT INTO 'dancealias' VALUES (584, 17789, 'Sea Otter and the Pallas Cat, The', 'SEA OTTER AND THE PALLAS CAT', 3);
INSERT INTO 'dancealias' VALUES (585, 17789, 'Калан и Манул', 'KALAN I MANUL', 1);
INSERT INTO 'dancealias' VALUES (586, 18176, 'The Rat Race', 'RAT RACE', 2);
INSERT INTO 'dancealias' VALUES (587, 18179, 'A Dordogne Greeting', 'DORDOGNE GREETING', 0);
INSERT INTO 'dancealias' VALUES (588, 17457, 'Port William Lass', 'PORT WILLIAM LASS', 1);
INSERT INTO 'dancealias' VALUES (589, 17304, 'Rendez-vous a Vichy', 'RENDEZVOUS A VICHY', 1);
INSERT INTO 'dancealias' VALUES (590, 13575, 'Tokyo Twenty Five', 'TOKYO TWENTY FIVE', 1);
INSERT INTO 'dancealias' VALUES (591, 12508, 'Deer Friends', 'DEER FRIENDS', 1);
INSERT INTO 'dancealias' VALUES (604, 18486, 'Whisky Dance', 'WHISKY DANCE', 0);
INSERT INTO 'dancealias' VALUES (605, 10852, 'Millenium Medley', 'MILLENIUM MEDLEY', 1);
INSERT INTO 'dancealias' VALUES (606, 16837, 'Star Sapphire, The', 'STAR SAPPHIRE', 2);
INSERT INTO 'dancealias' VALUES (607, 6522, 'There Came A Young Man', 'THERE CAME A YOUNG MAN', 2);
INSERT INTO 'dancealias' VALUES (608, 6607, 'Till We Meet Again', 'TILL WE MEET AGAIN', 0);
INSERT INTO 'dancealias' VALUES (609, 18520, 'Kids in the Alps', 'KIDS IN THE ALPS', 0);
INSERT INTO 'dancealias' VALUES (612, 18578, 'Birthday in Vienna', 'BIRTHDAY IN VIENNA', 3);
INSERT INTO 'dancealias' VALUES (610, 18576, 'Dodgem Reel', 'DODGEM REEL', 2);
INSERT INTO 'dancealias' VALUES (613, 18600, 'Dancing Sexagenarian, The', 'DANCING SEXAGENARIAN', 2);
INSERT INTO 'dancealias' VALUES (614, 18571, 'Spägele''s Jig', 'SPAGELES JIG', 1);
INSERT INTO 'dancealias' VALUES (615, 18631, 'Go the Other Way', 'GO THE OTHER WAY', 2);
INSERT INTO 'dancealias' VALUES (616, 18645, 'Money in Both Pockets', 'MONEY IN BOTH POCKETS', 2);
INSERT INTO 'dancealias' VALUES (593, 4239, 'Maxwill''s Rant', 'MAXWILLS RANT', 0);
INSERT INTO 'dancealias' VALUES (490, 16936, 'Geraldine''s Gigue', 'GERALDINES GIGUE', 0);
INSERT INTO 'dancealias' VALUES (617, 18571, 'Spaegele''s Jig', 'SPAEGELES JIG', 1);
INSERT INTO 'dancealias' VALUES (618, 18571, 'Spägeles'' Jig', 'SPAGELES JIG', 1);
INSERT INTO 'dancealias' VALUES (619, 17884, 'Free at last', 'FREE AT LAST', 0);
INSERT INTO 'dancealias' VALUES (622, 18945, 'Tony’s Trauma', 'TONYS TRAUMA', 2);
INSERT INTO 'dancealias' VALUES (623, 18969, 'The Ross Reel', 'ROSS REEL', 1);
INSERT INTO 'dancealias' VALUES (624, 18287, 'Twirlaholics', 'TWIRLAHOLICS', 2);
INSERT INTO 'dancealias' VALUES (625, 12014, '(Wild) Rice and Lefse', 'WILD RICE AND LEFSE', 2);
INSERT INTO 'dancealias' VALUES (626, 13358, 'Mrs. Frances MacCulloch', 'MRS FRANCES MACCULLOCH', 1);
INSERT INTO 'dancealias' VALUES (627, 19097, 'Survival of the Fittest', 'SURVIVAL OF THE FITTEST', 2);
INSERT INTO 'dancealias' VALUES (628, 224, 'Argyll''s Farewell To Stirling', 'ARGYLLS FAREWELL TO STIRLING', 1);
INSERT INTO 'dancealias' VALUES (629, 7520, 'St Columba''s Strathspey', 'SAINT COLUMBAS STRATHSPEY', 1);
INSERT INTO 'dancealias' VALUES (630, 289, 'Old Aliens', 'OLD ALIENS', 0);
INSERT INTO 'dancealias' VALUES (631, 19161, 'Mr. John Wood of Bedford, Nova Scotia', 'MR JOHN WOOD OF BEDFORD NOVA SCOTIA', 2);
INSERT INTO 'dancealias' VALUES (632, 19162, 'Does Anyone Want My Body?', 'DOES ANYONE WANT MY BODY', 2);
INSERT INTO 'dancealias' VALUES (633, 19174, 'Noetherian Ring, The', 'NOETHERIAN RING', 3);
INSERT INTO 'dancealias' VALUES (634, 19175, 'Cute Little Noetherian Ring, The', 'CUTE LITTLE NOETHERIAN RING', 3);
INSERT INTO 'dancealias' VALUES (635, 19176, 'Artinian Ring, The', 'ARTINIAN RING', 3);
INSERT INTO 'dancealias' VALUES (636, 7785, 'Marjorie & Brian', 'MARJORIE AND BRIAN', 1);
INSERT INTO 'dancealias' VALUES (639, 9889, 'Jean McKelvie''s Arran Jig', 'JEAN MACKELVIES ARRAN JIG', 2);
INSERT INTO 'dancealias' VALUES (640, 8463, 'Saint John Strathspey, The', 'SAINT JOHN STRATHSPEY', 1);
INSERT INTO 'dancealias' VALUES (641, 17630, 'Dance for Helen, A', 'DANCE FOR HELEN', 2);
INSERT INTO 'dancealias' VALUES (642, 18288, 'Fidele de Lausanne, La', 'FIDELE DE LAUSANNE', 1);
INSERT INTO 'dancealias' VALUES (399, 14679, 'Circassian Circle', 'CIRCASSIAN CIRCLE', 0);
INSERT INTO 'dancealias' VALUES (645, 19393, 'There was a wee lassie frae Gourock', 'THERE WAS A WEE LASSIE FRAE GOUROCK', 0);
INSERT INTO 'dancealias' VALUES (647, 10638, 'Dances with Shadows', 'DANCES WITH SHADOWS', 2);
INSERT INTO 'dancealias' VALUES (649, 7284, 'Capetown Wedding', 'CAPETOWN WEDDING', 1);
INSERT INTO 'dancealias' VALUES (648, 16244, 'Capetown Divorce', 'CAPETOWN DIVORCE', 0);
INSERT INTO 'dancealias' VALUES (650, 14173, 'Sandwich Man, The', 'SANDWICH MAN', 2);
INSERT INTO 'dancealias' VALUES (653, 3590, 'Lady Bellhaven''s Delight', 'LADY BELLHAVENS DELIGHT', 1);
INSERT INTO 'dancealias' VALUES (654, 5841, 'Saint Martin''s Lane', 'SAINT MARTINS LANE', 1);
INSERT INTO 'dancealias' VALUES (655, 3327, 'John of Paris', 'JOHN OF PARIS', 2);
INSERT INTO 'dancealias' VALUES (657, 2322, 'Princess of Hesse''s Jig', 'PRINCESS OF HESSES JIG', 2);
INSERT INTO 'dancealias' VALUES (658, 2322, 'Foxhunter''s Jig, The', 'FOXHUNTERS JIG', 2);
INSERT INTO 'dancealias' VALUES (660, 1484, 'Cupid''s Guess', 'CUPIDS GUESS', 2);
INSERT INTO 'dancealias' VALUES (662, 1287, 'Collier''s Daughter, The', 'COLLIERS DAUGHTER', 2);
INSERT INTO 'dancealias' VALUES (663, 2741, 'Smith''s Round O', 'SMITHS ROUND O', 2);
INSERT INTO 'dancealias' VALUES (543, 11203, 'Mr & Mrs Munro', 'MR AND MRS MUNRO', 2);
INSERT INTO 'dancealias' VALUES (665, 2751, 'Hamiltonian, The', 'HAMILTONIAN', 2);
INSERT INTO 'dancealias' VALUES (666, 19023, 'Ledbury Ladies, The', 'LEDBURY LADIES', 1);
INSERT INTO 'dancealias' VALUES (667, 750, 'Braes of Glensheil, The', 'BRAES OF GLENSHEIL', 1);
INSERT INTO 'dancealias' VALUES (668, 19228, 'Looping Man, The', 'LOOPING MAN', 2);
INSERT INTO 'dancealias' VALUES (669, 18881, 'Shanghai Calling', 'SHANGHAI CALLING', 2);
INSERT INTO 'dancealias' VALUES (670, 9499, 'Der Zwergenstein', 'ZWERGENSTEIN', 2);
INSERT INTO 'dancealias' VALUES (671, 13938, 'Café Noir, Le', 'CAFE NOIR', 1);
INSERT INTO 'dancealias' VALUES (672, 9767, 'The Bousfield Reel', 'BOUSFIELD REEL', 0);
INSERT INTO 'dancealias' VALUES (673, 12923, 'Hearts at Tynecastle', 'HEARTS AT TYNECASTLE', 2);
INSERT INTO 'dancealias' VALUES (674, 5480, 'Glenfiddich', 'GLENFIDDICH', 0);
INSERT INTO 'dancealias' VALUES (675, 11235, 'Corrieyearach', 'CORRIEYEARACH', 1);
INSERT INTO 'dancealias' VALUES (676, 14744, 'Gurness Broch', 'GURNESS BROCH', 0);
INSERT INTO 'dancealias' VALUES (677, 19576, 'Four-Hand Star', 'FOURHAND STAR', 1);
INSERT INTO 'dancealias' VALUES (678, 4347, 'Michaelmas', 'MICHAELMAS', 1);
INSERT INTO 'dancealias' VALUES (679, 19842, 'Helen Angus of Meadowbank', 'HELEN ANGUS OF MEADOWBANK', 2);
INSERT INTO 'dancealias' VALUES (680, 19843, 'The Happy Chappie', 'HAPPY CHAPPIE', 2);
INSERT INTO 'dancealias' VALUES (681, 13263, 'Hip Hop Hornpipe', 'HIP HOP HORNPIPE', 2);
INSERT INTO 'dancealias' VALUES (682, 19908, 'Faire le Velo', 'FAIRE LE VELO', 0);
INSERT INTO 'dancealias' VALUES (683, 8191, 'Buachaille Etive Mhor', 'BUACHAILLE ETIVE MHOR', 0);
INSERT INTO 'dancealias' VALUES (685, 19944, '3 Bernadettes, The', '3 BERNADETTES', 0);
INSERT INTO 'dancealias' VALUES (686, 572, 'A Happy New Year', 'HAPPY NEW YEAR', 3);
INSERT INTO 'dancealias' VALUES (287, 3026, 'April Fool', 'APRIL FOOL', 3);
INSERT INTO 'dancealias' VALUES (687, 19967, 'What You Will', 'WHAT YOU WILL', 2);
INSERT INTO 'dancealias' VALUES (688, 19913, 'Knot Square', 'KNOT SQUARE', 0);
INSERT INTO 'dancealias' VALUES (689, 11190, 'Spiers Bruce, The Pole Star', 'SPIERS BRUCE THE POLE STAR', 1);
INSERT INTO 'dancealias' VALUES (690, 19996, 'Here We Go A Wassailing', 'HERE WE GO A WASSAILING', 2);
INSERT INTO 'dancealias' VALUES (691, 17593, 'Jim Stott''s Rant', 'JIM STOTTS RANT', 0);
INSERT INTO 'dancealias' VALUES (692, 17609, 'Symetrical Jig, The', 'SYMETRICAL JIG', 1);
INSERT INTO 'dancealias' VALUES (693, 17612, '70th Anniversary Celebration in Dumfries', '70TH ANNIVERSARY CELEBRATION IN DUMFRIES', 0);
INSERT INTO 'dancealias' VALUES (694, 5817, 'Saint Anne''s Reel', 'SAINT ANNES REEL', 0);
INSERT INTO 'dancealias' VALUES (695, 3562, 'Tempete, La', 'TEMPETE', 1);
INSERT INTO 'dancealias' VALUES (696, 15675, 'Suilean', 'SUILEAN', 1);
INSERT INTO 'dancealias' VALUES (697, 20059, 'Look! No Hands!', 'LOOK NO HANDS', 2);
INSERT INTO 'dancealias' VALUES (698, 3794, 'Lewis Derrick''s Hornpipe', 'LEWIS DERRICKS HORNPIPE', 2);
INSERT INTO 'dancealias' VALUES (699, 5731, 'Roxburgh Castle Reel', 'ROXBURGH CASTLE REEL', 0);
INSERT INTO 'dancealias' VALUES (700, 20077, '1508', '1508', 0);
INSERT INTO 'dancealias' VALUES (701, 20077, 'Complaint of the Black Knight', 'COMPLAINT OF THE BLACK KNIGHT', 0);
INSERT INTO 'dancealias' VALUES (702, 20057, '150 Plus 50', '150 PLUS 50', 0);
INSERT INTO 'dancealias' VALUES (703, 18503, 'Mount Maxwell Strathspey', 'MOUNT MAXWELL STRATHSPEY', 0);
INSERT INTO 'dancealias' VALUES (704, 10413, 'King’s Delight, The', 'KINGS DELIGHT', 0);
INSERT INTO 'dancealias' VALUES (705, 20094, 'A ''Reel'' Nuisance', 'REEL NUISANCE', 0);
INSERT INTO 'dancealias' VALUES (706, 20101, 'Most Gallant Gentleman, The', 'MOST GALLANT GENTLEMAN', 0);
INSERT INTO 'dancealias' VALUES (707, 20079, 'Ebb and Flow', 'EBB AND FLOW', 0);
INSERT INTO 'dancealias' VALUES (708, 20105, 'Forty Something Reel, The', 'FORTY SOMETHING REEL', 0);
INSERT INTO 'dancealias' VALUES (709, 20115, 'August, September, October', 'AUGUST SEPTEMBER OCTOBER', 0);
INSERT INTO 'dancealias' VALUES (710, 20115, 'Michael Bentley''s Bodhran', 'MICHAEL BENTLEYS BODHRAN', 0);
INSERT INTO 'dancealias' VALUES (711, 20104, 'Magic of Cairngorms, The', 'MAGIC OF CAIRNGORMS', 0);
INSERT INTO 'dancealias' VALUES (712, 126, 'Amsbury', 'AMSBURY', 2);
INSERT INTO 'dancealias' VALUES (713, 1342, 'Coreli''s Gavot', 'CORELIS GAVOT', 2);
INSERT INTO 'dancealias' VALUES (714, 4583, 'Miss Spark''s Maggot', 'MISS SPARKS MAGGOT', 0);
INSERT INTO 'dancealias' VALUES (715, 1772, 'Dublin Bay', 'DUBLIN BAY', 2);
INSERT INTO 'dancealias' VALUES (716, 456, 'Belgia Retriev''d', 'BELGIA RETRIEVD', 2);
INSERT INTO 'dancealias' VALUES (717, 4710, 'Mr Hamilton of Washaw''s Reel', 'MR HAMILTON OF WASHAWS REEL', 1);
INSERT INTO 'dancealias' VALUES (718, 17463, 'Mr Graham W Donald', 'MR GRAHAM W DONALD', 1);
INSERT INTO 'dancealias' VALUES (719, 19258, 'Another Trip ''Round the Sun', 'ANOTHER TRIP ROUND THE SUN', 1);
INSERT INTO 'dancealias' VALUES (720, 19594, 'Frances'' Goat Track', 'FRANCES GOAT TRACK', 1);
INSERT INTO 'dancealias' VALUES (721, 9059, 'Dr William Cunningham', 'DR WILLIAM CUNNINGHAM', 2);
INSERT INTO 'dancealias' VALUES (722, 11411, 'Alpine Cascade', 'ALPINE CASCADE', 2);
INSERT INTO 'dancealias' VALUES (723, 3528, 'Kiss Quick, My Mither''s Coming', 'KISS QUICK MY MITHERS COMING', 2);
INSERT INTO 'dancealias' VALUES (429, 14365, '46664 Jig', '46664 JIG', 2);
INSERT INTO 'dancealias' VALUES (724, 14260, 'Left hand down a bit Chief', 'LEFT HAND DOWN A BIT CHIEF', 2);
INSERT INTO 'dancealias' VALUES (725, 19394, 'Train Wreck', 'TRAIN WRECK', 2);
INSERT INTO 'dancealias' VALUES (726, 8878, 'Peeped within', 'PEEPED WITHIN', 2);
INSERT INTO 'dancealias' VALUES (727, 3628, 'Lady Nellie Wemyss', 'LADY NELLIE WEMYSS', 1);
INSERT INTO 'dancealias' VALUES (751, 13121, 'JB squared', 'JB SQUARED', 2);
INSERT INTO 'dancealias' VALUES (728, 12091, 'Jimmy''s Fancy, Five-couple', 'JIMMYS FANCY FIVECOUPLE', 1);
INSERT INTO 'dancealias' VALUES (729, 11629, 'Wee Nothing, A', 'WEE NOTHING', 1);
INSERT INTO 'dancealias' VALUES (730, 11196, 'Forty Years', 'FORTY YEARS', 0);
INSERT INTO 'dancealias' VALUES (731, 19247, 'Chivalric Celebrations', 'CHIVALRIC CELEBRATIONS', 2);
INSERT INTO 'dancealias' VALUES (732, 20221, 'Witch Reel', 'WITCH REEL', 0);
INSERT INTO 'dancealias' VALUES (733, 4043, 'Dungevan Castle', 'DUNGEVAN CASTLE', 2);
INSERT INTO 'dancealias' VALUES (734, 441, 'Prince Charles'' Reel', 'PRINCE CHARLES REEL', 2);
INSERT INTO 'dancealias' VALUES (735, 19631, 'Red Squirrel, The', 'RED SQUIRREL', 2);
INSERT INTO 'dancealias' VALUES (736, 1881, 'Hay Polka, The', 'HAY POLKA', 2);
INSERT INTO 'dancealias' VALUES (737, 3030, 'Huntley Reel, The', 'HUNTLEY REEL', 1);
INSERT INTO 'dancealias' VALUES (738, 4271, 'McLaine''s Hogmanay', 'MACLAINES HOGMANAY', 2);
INSERT INTO 'dancealias' VALUES (739, 9127, 'Nonagenarian, The', 'NONAGENARIAN', 2);
INSERT INTO 'dancealias' VALUES (740, 12352, 'Oor Aileen''s Reel', 'OOR AILEENS REEL', 1);
INSERT INTO 'dancealias' VALUES (741, 5573, 'Rifle Volunteers', 'RIFLE VOLUNTEERS', 1);
INSERT INTO 'dancealias' VALUES (742, 20241, 'Rathad Uaine', 'RATHAD UAINE', 3);
INSERT INTO 'dancealias' VALUES (744, 20243, 'Caisteal Maol', 'CAISTEAL MAOL', 3);
INSERT INTO 'dancealias' VALUES (745, 20196, 'Hail in Harris', 'HAIL IN HARRIS', 3);
INSERT INTO 'dancealias' VALUES (743, 20243, 'Castle Moil', 'CASTLE MOIL', 3);
INSERT INTO 'dancealias' VALUES (746, 9026, 'J A G''s Welcome to Torremolinos', 'J A GS WELCOME TO TORREMOLINOS', 0);
INSERT INTO 'dancealias' VALUES (747, 6505, 'Teviot Brig', 'TEVIOT BRIG', 0);
INSERT INTO 'dancealias' VALUES (748, 20279, 'Establishing the Chain', 'ESTABLISHING THE CHAIN', 2);
INSERT INTO 'dancealias' VALUES (750, 20208, 'Star of Rabbie Burns', 'STAR OF RABBIE BURNS', 2);
INSERT INTO 'dancealias' VALUES (752, 19495, '33rd Priest, The', '33RD PRIEST', 0);
INSERT INTO 'dancealias' VALUES (753, 6456, 'Weaver''s Retirement, The', 'WEAVERS RETIREMENT', 0);
INSERT INTO 'dancealias' VALUES (754, 6518, 'Thatch''d House, The', 'THATCHD HOUSE', 2);
INSERT INTO 'dancealias' VALUES (755, 4581, 'Miss Soibhan''s Fancy', 'MISS SOIBHANS FANCY', 0);
INSERT INTO 'dancealias' VALUES (757, 5961, 'Scottish Man of War, The', 'SCOTTISH MAN OF WAR', 2);
INSERT INTO 'dancealias' VALUES (758, 16959, 'Flight of the Sandmartins, The', 'FLIGHT OF THE SANDMARTINS', 1);
INSERT INTO 'dancealias' VALUES (759, 2223, 'Flight of the Sandmartins, The', 'FLIGHT OF THE SANDMARTINS', 1);
INSERT INTO 'dancealias' VALUES (760, 9472, 'Tit-Bit for Dinosaurs, A', 'TITBIT FOR DINOSAURS', 2);
INSERT INTO 'dancealias' VALUES (761, 20334, 'Clementine''s Strathspey', 'CLEMENTINES STRATHSPEY', 1);
INSERT INTO 'dancealias' VALUES (762, 19194, 'Meaudre Reel, The', 'MEAUDRE REEL', 1);
INSERT INTO 'dancealias' VALUES (763, 18494, 'Montreal Diamond Anniversary Reel', 'MONTREAL DIAMOND ANNIVERSARY REEL', 1);
INSERT INTO 'dancealias' VALUES (764, 13360, 'Montreal Rendezvous', 'MONTREAL RENDEZVOUS', 1);
INSERT INTO 'dancealias' VALUES (765, 5549, 'Renwick Reel, The', 'RENWICK REEL', 0);
INSERT INTO 'dancealias' VALUES (766, 5013, 'O'' Wha''s at The Window', 'O WHAS AT THE WINDOW', 1);
INSERT INTO 'dancealias' VALUES (767, 5825, 'St Edmund Strathspey, The', 'SAINT EDMUND STRATHSPEY', 1);
INSERT INTO 'dancealias' VALUES (768, 991, 'A(nother) Candle for Mary', 'ANOTHER CANDLE FOR MARY', 2);
INSERT INTO 'dancealias' VALUES (769, 7138, 'Wick''s o'' Baiglie, The', 'WICKS O BAIGLIE', 1);
INSERT INTO 'dancealias' VALUES (770, 3288, '62430: Jingling Geordie', '62430 JINGLING GEORDIE', 0);
INSERT INTO 'dancealias' VALUES (771, 5852, 'Saint Valentine''s Day', 'SAINT VALENTINES DAY', 0);
INSERT INTO 'dancealias' VALUES (772, 11808, 'First of September', 'FIRST OF SEPTEMBER', 0);
INSERT INTO 'dancealias' VALUES (773, 20311, 'Pleiades', 'PLEIADES', 0);
INSERT INTO 'dancealias' VALUES (774, 20361, 'Seal People, The', 'SEAL PEOPLE', 3);
INSERT INTO 'dancealias' VALUES (523, 853, '"Buckie" Jig, The', 'BUCKIE JIG', 2);
INSERT INTO 'dancealias' VALUES (775, 1711, 'Black Douglas', 'BLACK DOUGLAS', 0);
INSERT INTO 'dancealias' VALUES (776, 521, 'Birks of Abergaldie, The', 'BIRKS OF ABERGALDIE', 1);
INSERT INTO 'dancealias' VALUES (777, 1943, 'Sterna elegans', 'STERNA ELEGANS', 2);
INSERT INTO 'dancealias' VALUES (779, 6536, 'Cordial Jig', 'CORDIAL JIG', 0);
INSERT INTO 'dancealias' VALUES (780, 13775, 'Galloway Dance-master, The', 'GALLOWAY DANCEMASTER', 2);
INSERT INTO 'dancealias' VALUES (781, 12394, 'Saint Magnus Reel', 'SAINT MAGNUS REEL', 1);
INSERT INTO 'dancealias' VALUES (782, 19574, 'Och, Aye!', 'OCH AYE', 1);
INSERT INTO 'dancealias' VALUES (783, 684, 'Bonnie Hoose of Airlie, The', 'BONNIE HOOSE OF AIRLIE', 1);
INSERT INTO 'dancealias' VALUES (785, 17321, '50th Tartan Ball Reel, The', '50TH TARTAN BALL REEL', 0);
INSERT INTO 'dancealias' VALUES (786, 12162, 'Caldwell''s Coral Caper, The', 'CALDWELLS CORAL CAPER', 1);
INSERT INTO 'dancealias' VALUES (787, 11582, 'Water of Life', 'WATER OF LIFE', 0);
INSERT INTO 'dancealias' VALUES (788, 20432, 'Meet and Greet', 'MEET AND GREET', 2);
INSERT INTO 'dancealias' VALUES (789, 20403, 'Mrs Jean Mair''s Strathspey', 'MRS JEAN MAIRS STRATHSPEY', 2);
INSERT INTO 'dancealias' VALUES (790, 20316, 'I Love Nice', 'I LOVE NICE', 1);
INSERT INTO 'dancealias' VALUES (791, 5824, 'St. Ebba''s Strand', 'SAINT EBBAS STRAND', 0);
INSERT INTO 'dancealias' VALUES (792, 5802, 'Saint Andrew''s Fair', 'SAINT ANDREWS FAIR', 1);
INSERT INTO 'dancealias' VALUES (793, 9768, 'Brunette d''Écosse', 'BRUNETTE DECOSSE', 1);
INSERT INTO 'dancealias' VALUES (794, 3036, 'Hurrier You Go, the Behinder You Get, The', 'HURRIER YOU GO THE BEHINDER YOU GET', 1);
INSERT INTO 'dancealias' VALUES (795, 6404, 'Susie Ferguson Centennial Reel', 'SUSIE FERGUSON CENTENNIAL REEL', 0);
INSERT INTO 'dancealias' VALUES (796, 6514, 'Jig (Lively)', 'JIG LIVELY', 0);
INSERT INTO 'dancealias' VALUES (797, 20543, 'Seagulls of Sawtell, The', 'SEAGULLS OF SAWTELL', 2);
INSERT INTO 'dancealias' VALUES (798, 11585, 'Maxwell''s Rant Again, The', 'MAXWELLS RANT AGAIN', 1);
INSERT INTO 'dancealias' VALUES (800, 20560, 'Cailín Rua', 'CAILIN RUA', 1);
INSERT INTO 'dancealias' VALUES (801, 20322, 'Chambery', 'CHAMBERY', 1);
INSERT INTO 'dancealias' VALUES (802, 20315, 'Ville Lumiere, La', 'VILLE LUMIERE', 1);
INSERT INTO 'dancealias' VALUES (803, 20318, 'Chambery Blues', 'CHAMBERY BLUES', 1);
INSERT INTO 'dancealias' VALUES (804, 17316, 'Pretty Bride of Prety, The', 'PRETTY BRIDE OF PRETY', 1);
INSERT INTO 'dancealias' VALUES (805, 18017, 'Nightcap, The', 'NIGHTCAP', 3);
INSERT INTO 'dancealias' VALUES (806, 20605, 'Queensland Breese, The', 'QUEENSLAND BREESE', 1);
INSERT INTO 'dancealias' VALUES (807, 17976, 'Till We Meet Up Again', 'TILL WE MEET UP AGAIN', 1);
INSERT INTO 'dancealias' VALUES (808, 4904, 'An Niseach', 'NISEACH', 1);
INSERT INTO 'dancealias' VALUES (809, 896, 'C J''s Reel', 'C JS REEL', 1);
INSERT INTO 'dancealias' VALUES (810, 5832, 'Saint Johnstoun Reel', 'SAINT JOHNSTOUN REEL', 0);
INSERT INTO 'dancealias' VALUES (811, 17356, 'Happy Trails', 'HAPPY TRAILS', 2);
INSERT INTO 'dancealias' VALUES (812, 17133, 'Remparts de Seville, Les', 'REMPARTS DE SEVILLE', 1);
INSERT INTO 'dancealias' VALUES (814, 19254, 'Belfast Story, The', 'BELFAST STORY', 2);
INSERT INTO 'dancealias' VALUES (815, 4026, 'MacGregor''s Gathering', 'MACGREGORS GATHERING', 1);
INSERT INTO 'dancealias' VALUES (816, 20652, 'Oh to go Dancing for Perth''s 95', 'OH TO GO DANCING FOR PERTHS 95', 1);
INSERT INTO 'dancealias' VALUES (817, 20728, 'Calico', 'CALICO', 0);
INSERT INTO 'dancealias' VALUES (818, 20730, 'A Trip to Auckland', 'TRIP TO AUCKLAND', 0);
INSERT INTO 'dancealias' VALUES (820, 18204, 'Arctophiles Jig, The', 'ARCTOPHILES JIG', 1);
INSERT INTO 'dancealias' VALUES (821, 10449, 'Flowers of Kilburn, The', 'FLOWERS OF KILBURN', 1);
INSERT INTO 'dancealias' VALUES (822, 20401, 'Anne Maclennan''s Reel', 'ANNE MACLENNANS REEL', 2);
INSERT INTO 'dancealias' VALUES (823, 15733, 'Villan''s Turnstile Jig, The', 'VILLANS TURNSTILE JIG', 0);
INSERT INTO 'dancealias' VALUES (824, 4781, 'Mrs McArthur of Netherlee', 'MRS MACARTHUR OF NETHERLEE', 1);
INSERT INTO 'dancealias' VALUES (825, 18611, 'Tune the Fiddles', 'TUNE THE FIDDLES', 0);
INSERT INTO 'dancealias' VALUES (860, 2700, 'Geud Man of Ballangigh, The', 'GEUD MAN OF BALLANGIGH', 1);
INSERT INTO 'dancealias' VALUES (819, 20733, 'On the Willow Bank', 'ON THE WILLOW BANK', 2);
INSERT INTO 'dancealias' VALUES (826, 4217, 'Mary Stewart''s Strathspey', 'MARY STEWARTS STRATHSPEY', 2);
INSERT INTO 'dancealias' VALUES (827, 10851, 'Let''s all celebrate our 75th anniversary - here''s to many more years of happy feet', 'LETS ALL CELEBRATE OUR 75TH ANNIVERSARY  HERES TO MANY MORE YEARS OF HAPPY FEET', 2);
INSERT INTO 'dancealias' VALUES (829, 20914, 'Dancing Fingers', 'DANCING FINGERS', 2);
INSERT INTO 'dancealias' VALUES (830, 20786, 'Iguazu Falls, The', 'IGUAZU FALLS', 1);
INSERT INTO 'dancealias' VALUES (831, 20228, 'Pat-a-Cake Polka', 'PATACAKE POLKA', 0);
INSERT INTO 'dancealias' VALUES (784, 11107, 'Saint Andrews Links', 'SAINT ANDREWS LINKS', 1);
INSERT INTO 'dancealias' VALUES (828, 20676, 'Give a Way to Kangaroo', 'GIVE A WAY TO KANGAROO', 0);
INSERT INTO 'dancealias' VALUES (832, 20531, 'Trefle a Quatre Feuilles, Le', 'TREFLE A QUATRE FEUILLES', 1);
INSERT INTO 'dancealias' VALUES (833, 4779, 'Mrs Mac Dougall''s Strathspey', 'MRS MAC DOUGALLS STRATHSPEY', 0);
INSERT INTO 'dancealias' VALUES (834, 20969, 'Mrs Gowans Retreat to Nairn', 'MRS GOWANS RETREAT TO NAIRN', 2);
INSERT INTO 'dancealias' VALUES (835, 20983, 'Five Sisters of Kintail', 'FIVE SISTERS OF KINTAIL', 2);
INSERT INTO 'dancealias' VALUES (749, 18569, 'Wookie Walk, The', 'WOOKIE WALK', 0);
INSERT INTO 'dancealias' VALUES (836, 13576, 'Hana Strathspey', 'HANA STRATHSPEY', 0);
INSERT INTO 'dancealias' VALUES (837, 8708, 'Kamagari no Kirameku Nagisa', 'KAMAGARI NO KIRAMEKU NAGISA', 0);
INSERT INTO 'dancealias' VALUES (838, 21104, 'Et voila !', 'ET VOILA', 1);
INSERT INTO 'dancealias' VALUES (839, 13476, 'Bobby & Kobby', 'BOBBY AND KOBBY', 0);
INSERT INTO 'dancealias' VALUES (840, 10907, 'Saint Abb''s Head Reel', 'SAINT ABBS HEAD REEL', 0);
INSERT INTO 'dancealias' VALUES (841, 1320, 'Connaughtman''s Rambles', 'CONNAUGHTMANS RAMBLES', 1);
INSERT INTO 'dancealias' VALUES (842, 337, 'Back of the Change House', 'BACK OF THE CHANGE HOUSE', 1);
INSERT INTO 'dancealias' VALUES (843, 3933, 'Cobham Hall Hornpipe', 'COBHAM HALL HORNPIPE', 2);
INSERT INTO 'dancealias' VALUES (145, 345, 'Alasdair Macmharghstiralasdair''s Jig', 'ALASDAIR MACMHARGHSTIRALASDAIRS JIG', 2);
INSERT INTO 'dancealias' VALUES (756, 6053, 'Shire of Ayr, The', 'SHIRE OF AYR', 2);
INSERT INTO 'dancealias' VALUES (844, 21169, 'Feuerzangenbowle, Die', 'FEUERZANGENBOWLE', 2);
INSERT INTO 'dancealias' VALUES (845, 21185, 'We Take It for Granite', 'WE TAKE IT FOR GRANITE', 2);
INSERT INTO 'dancealias' VALUES (846, 19848, 'Salute to Bill Hamilton of Roseneath and Netherby', 'SALUTE TO BILL HAMILTON OF ROSENEATH AND NETHERBY', 0);
INSERT INTO 'dancealias' VALUES (847, 21189, '88', '88', 1);
INSERT INTO 'dancealias' VALUES (848, 21189, '8-8', '88', 1);
INSERT INTO 'dancealias' VALUES (849, 7967, 'Tartan Track Reel, The', 'TARTAN TRACK REEL', 0);
INSERT INTO 'dancealias' VALUES (850, 7966, 'Tartan Track Jig, The', 'TARTAN TRACK JIG', 0);
INSERT INTO 'dancealias' VALUES (851, 7968, 'Tartan Track Strathspey, The', 'TARTAN TRACK STRATHSPEY', 0);
INSERT INTO 'dancealias' VALUES (852, 3765, 'Return to Benbecula', 'RETURN TO BENBECULA', 0);
INSERT INTO 'dancealias' VALUES (853, 14655, 'Shuttlecock', 'SHUTTLECOCK', 0);
INSERT INTO 'dancealias' VALUES (854, 21214, 'Jack o'' Tar Two-Step, The', 'JACK O TAR TWOSTEP', 0);
INSERT INTO 'dancealias' VALUES (855, 21227, 'Standard Quadrilles, The', 'STANDARD QUADRILLES', 0);
INSERT INTO 'dancealias' VALUES (856, 21227, 'First Set of Quadrilles, The', 'FIRST SET OF QUADRILLES', 0);
INSERT INTO 'dancealias' VALUES (857, 20780, 'Take Ten', 'TAKE TEN', 1);
INSERT INTO 'dancealias' VALUES (858, 3649, 'Laich of Moray, The', 'LAICH OF MORAY', 1);
INSERT INTO 'dancealias' VALUES (859, 5203, 'Peggie McGhie''s Reel', 'PEGGIE MACGHIES REEL', 1);
INSERT INTO 'dancealias' VALUES (861, 2700, 'Guidman of Ballangigh, The', 'GUIDMAN OF BALLANGIGH', 1);
INSERT INTO 'dancealias' VALUES (862, 21282, 'Cameronians, The', 'CAMERONIANS', 0);
INSERT INTO 'dancealias' VALUES (863, 21294, 'Fishwife''s Hornpipe, A', 'FISHWIFES HORNPIPE', 2);
INSERT INTO 'dancealias' VALUES (864, 18111, 'Found on Strathspey', 'FOUND ON STRATHSPEY', 2);
INSERT INTO 'dancealias' VALUES (865, 2604, 'Goodhearted Glasgow', 'GOODHEARTED GLASGOW', 1);
INSERT INTO 'dancealias' VALUES (866, 1012, 'Captain H. Munro', 'CAPTAIN H MUNRO', 1);
INSERT INTO 'dancealias' VALUES (867, 6428, 'T.A.Norris', 'TANORRIS', 1);
INSERT INTO 'dancealias' VALUES (868, 17619, 'Dance for Bar', 'DANCE FOR BAR', 2);
INSERT INTO 'dancealias' VALUES (869, 20302, 'Fruit Cake, The', 'FRUIT CAKE', 1);
INSERT INTO 'dancealias' VALUES (870, 20819, 'Wee Bairnie Jig, The', 'WEE BAIRNIE JIG', 2);
INSERT INTO 'dancealias' VALUES (871, 5831, 'Saint John''s Strathspey, The', 'SAINT JOHNS STRATHSPEY', 1);


--
INSERT INTO 'dancecrib' VALUES (8151, '2014-01-10 22:43:48.397555+00', '2019-03-18 23:46:23.590111+00', 1187, 2, 1, 'ace', '1–4::

  2c dance Petronella turn and set

5–8::

  2c turn LH _while_ 1&3c dance Petronella turn and set (all finish in a line down the centre, M facing up, L down)

9–::

  2M Reel3 w/1c _while_ 1W Reel3 w/3c (1c, likewise 3c, passing RS to start)  

  *Important:* The reels interlock. As they reach the interlocking point, 1L&3M, 3L&1M, 2c give LH in passing.

  1c and 3c finish in 1st and 3rd places.

17–::

  2c dance Double Triangles to finish in 2pl in the centre facing up, L on M''s left

  _while_ 1&3c set, cross R, set, change places L on sides

25–30::

  2c followed by 1c lead up, cast off round 3c (3x,1x,2x)

31–32::

  All cross R', 3);
INSERT INTO 'dancecrib' VALUES (9255, '2016-06-17 23:03:11.625669+00', '2016-06-17 23:03:11.625669+00', 12402, 2, NULL, 'ace', '1-8::

  1s,2s,3s progressive promenade, 1s end 2nd pl, 2s face out.

9-16::

  1s/2s dance ½ dble Figs of 8, (1s X up). 1s/3s dance ½ dble Figs of 8, (1s X dn).

17-24::

  1L/2s, 1M/3s ½ Lshldr Rs of 3 across, end at 3rd cnrs (posn), for ½ R of 4.

25-32::

  ½ R of 4 with 4th cnrs, all chase c’wise to pl.

33-40::

  1s/3s dance the Tournee



*(crib by Ann Gorman)*

 



', 5);
INSERT INTO 'dancecrib' VALUES (8258, '2014-04-27 14:49:55.528462+00', '2014-04-27 15:03:55.196231+00', 13076, 1, NULL, 'ace', '*3c+4c start on opposite sides (1,2,3x,4x)*



1--::

  2c+3c RHA ; 1W+2c & 3c+4W ½LHA | 2c set diagonally to 3c (both NHJ with P) as 1W+4W turn ½ RH to exchanged places

9--::

  2c+4W & 1W+3c ½LHA | 2c+3c 1¼ RHA | 1M+3c & 2c+4M ½LHA 

17--::

  3c set diagonally to 2c (both NHJ with P) as 1M+4M turn ½ RH to exchanged places | 3c+4M & 1M+2c ½LHA ; 2c+3c (women leading) dance out the end and cast R, the W crossing, to (4,3x,2,1x), middles facing ends

25--::

  ½ Rsh Reels4 on the sides ; on sidelines middles turn ends RH 1¼ into lines across and face same person 

33--::

  ½ Rsh Reels4 across ; Repeat RH turns to finish (1,2x,3,4x) with 2c facing 3c

41--::

  2c+3c change places on sides LH | 1c+3c & 2c+4c change places RH (with polite turns) ; All Circle8 L ½ (2,4,1x,3x)



', 3);
INSERT INTO 'dancecrib' VALUES (2224, '2012-01-22 19:29:26.639286+00', '2015-03-03 13:21:16.759638+00', 2156, 1, NULL, 'ace', '1–::

  1c cast off two ; cast back to places

9–::

  1c lead down the middle {3}, and up {3}, cast off to face 1cnrs (2c up)

17–::

  Turn CPCP, finish between corners

25–::

  2c+1c+3c A&R, 1c 1½ RH turn to 2pl.', 3);
INSERT INTO 'dancecrib' VALUES (1844, '2012-01-22 19:29:05.498968+00', '2014-05-04 22:12:22.63233+00', 822, 1, NULL, 'ace', '1–::

  1c (leading)+2c (dance up to begin), dance between 3c, cast up and dance to top, and 1c cast off (to 2,1,3)

9–::

  2c+1c+3c G-Chain (2c cross to start), finish 2M & 1W facing out (2,1,3)

17–::

  2W+1M turn RH 1½ _while{4}_ 2M+1W chase ½ round cclw ; 2W+1M chase ½ round clw to 1W/2M places _while{4}_ 2M+1W turn LH 1¼ to face P on 2diagonal

25–::

  2c+1c diagonal Reel4 (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1617, '2012-01-22 19:28:51.227229+00', '2014-04-30 23:23:37.109779+00', 12838, 1, NULL, 'ace', '1–::
  All A&R ; 1c long cast to 2pl (2c up) (2,1,3)
9–::
  All A&R ; 1c turn 2cnr LH and end in DTr position facing out opposite side
17–::
  Inverting DTr (set | 1c moves out as cnrs move in, into BtoB ; set | move to DTr position), 1c end facing 1cnr
25–::
  Cnrs Pass&Turn (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8143, '2014-01-01 15:18:23.133951+00', '2021-03-02 07:19:51.090743+00', 8051, 1, NULL, 'ace', '1–::

  1c cast behind own lines and back

9–::

  1c cross down into mirror Reels3 on the sides (1x,2,3)

17–::

  1c cross RH | cast (2c up) ; all turn RH

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (12218, '2019-09-15 22:17:59.921816+00', '2022-04-01 00:55:27.719296+00', 8532, 1, 202, 'ace', '1--::
  Mirror Reels3 on sides, 1c crossing down (1x,2,3)
9--::
  1c+3c L-Chain up/down. 1c face out (1x,2,3)
17--::
  1c cast off two places, meet and dance up to 2plx centre (2c up on [19-20]) ; 1M+3W+2W RHA _while{4}_ 1W+3M+2M LHA. 1c in 2plx centre face up NHJ
25--::
  1W set to 2M _as_ 1M set to 2W. On [26] 1c turn inwards and face down NHJ | 1W set to 3M _as_ 1M set to 3W ; 1c ½ Fig8 down round 3c to 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (8375, '2014-07-30 09:03:41.499783+00', '2014-07-30 09:08:56.75105+00', 6214, 1, NULL, 'ace', '1--::

  All dance ½ Reels4 on the sides ; 4c+3c+2c ½ Reels3 on own sides _while{4}_ 1c turns BH (to 2,3,4,1)

9--::

  All lead P down the middle, and turn P RH [bar 12] ; lead up | and all cast off to (2,3,4,1)

17--::

  All A&R{1+1} | repeat starting with L foot ; 2c+3c & 4c+1c ½ R&L (3x,2x,1x,4x)

25--::

  repeat [17-24] from new places (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (1616, '2012-01-22 19:28:51.162417+00', '2014-10-26 23:23:50.253427+00', 9761, 1, NULL, 'ace', '1–::

  1c+2c set | turn RH ½ and face P in the middle ; swiveling R dance out to opposite side and chase clw to (2,1,3), 1W facing down, 1M up

9–::

  1W+3c & 1M+2c reels3 across, Rsh to 3cnr (end C start Lsh), at end 1c turn LH to face 1cnr.

17–::

  Turn 1cnr RH | pass P Rsh ; turn 2cnr RH | cross Rsh (2,1,3)

25–::

  All circle6 L to own sides | all C turn BH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8016, '2013-08-26 07:39:55.14028+00', '2013-08-26 10:29:35.122463+00', 15057, 2, NULL, 'ace', '1-8::

  Reels of 3 on the sidelines: Men RSh Reel, Ladies LSh Reel (2s start up and out) 

9-12::

  1s and 2s dance half Poussette 

13-16::

  1s and 3s dance half Poussette 

17-24::

  All pass partner right shoulder, turn right about and cast to opposite sidelines, all turn BH 1½ 

25-32::

  3s and 1s dance Tournée.

', 0);
INSERT INTO 'dancecrib' VALUES (1615, '2012-01-22 19:28:51.115415+00', '2015-02-13 00:57:53.206947+00', 15, 1, NULL, 'ace', '1–::

  1c turn RH ; turn LH 1½ moving down (2c up) (2,1x)

9–::

  2W+1M & 2M+1W set and turn BH ; the W pass RH as 1M dances up W side and 2M down M side | 1c+2c turn LH to original places (1c small turn, 2c big turn)

17–::

  1c down the middle and up

25–::

  1c+2c Poussette.', 3);
INSERT INTO 'dancecrib' VALUES (8795, '2015-06-18 21:28:42.05373+00', '2015-06-18 21:28:42.05373+00', 8792, 1, NULL, 'ace', '*5 dancers in diamond pattern, 1 at top, 2,3,4 round clw, 5 in centre.*



1-::

  1+2+5 RHA {3} loop inwards ; 1+2+5 LHA

9-::

  1+5+3 Reel3 (1 Lsh to 5), finish 1 face 5

17-::

  1+5 set | turn RH ½ ; 1 (in centre) + 4 repeat

25-::

  4 (in centre) + 3 repeat ; 3 (in centre) + 2 repeat  (5,3,4,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (11224, '2018-09-30 23:31:47.955278+00', '2018-09-30 23:37:03.858266+00', 8692, 1, 202, 'ace', '1--::

  All W cast off behind P and chase clw ¾

9--::

  All M cast off behind new P and chase cclw ¾

17--::

  All turn new P RH ; All M LHA

25--::

  Intersecting ½ La-Chain ; all set to P | all set NHJ (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (3669, '2012-12-19 11:56:44.712804+00', '2015-03-03 22:20:24.239471+00', 14616, 1, NULL, 'ace', '1–::

  1c dance down the middle (2c up) and cast up round 3c ; 1c turn RH (2,1,3)

9–::

  Set and Rotate for 3 [All set pivoting R | All chase ¼ clw into lines across ; All cross P RH | All chase ¼ clw] (3,1,2)

17–::

  Reels3 across, 1c Rsh to 2cnr pos. (3,1,2)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (11225, '2018-09-30 23:51:57.751628+00', '2018-09-30 23:56:05.272892+00', 13088, 1, 202, 'ace', '1--::

  1c set | cast ; dance down between 3c and cast up to face 1cnrs

9--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag and face 3cnrs[pos]

17--::

  SetH&G. On [23-24] Petronella Turn to 2plx (3x,1x,2x)

25--::

  All PdB R then Circle6 L ½ ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9073, '2016-01-17 00:25:25.990143+00', '2016-06-13 19:27:56.370639+00', 6459, 1, NULL, 'ace', '1--::

  1c cross RH | cast (2c up) ; petronella into 2c+1M & 1W+3c in facing lines across | All set

9--::

  All A&R ; 1c petronella | All set (2,1,3)

17--::

  Circle6 and back

', 3);
INSERT INTO 'dancecrib' VALUES (8260, '2014-05-05 13:26:53.201513+00', '2014-05-05 13:26:53.201513+00', 3715, 1, NULL, 'ace', '1--::

  2c dance BtoB ; 2c set with PdB, point or highland step

9--::

  1c+3c dance BtoB ; 2c set with PdB, point or highland step

17--::

  2c “pass half round” (cast clw round 3cnr to meet P in middle ; pivot R and cast Rsh round 2cnr to 2plx) (1,2x,3)

25--::

  Opposing Reels3 on the sides, Rsh to 2cnr, to enter the reels 2c turn P RH ¾ and the corners cast. On [29] 2c turn LH ¾ and continue in the same reel (1,2x,3)

33--::

  ½ Reels3 across, Lsh to 3cnr (1x,2,3x) ; 1c+3c turn RH 1½ as 2c turn RH , all finish BHJ on midline (1,2,3) 

41--::

  3C Poussette (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8277, '2014-06-03 21:45:52.291053+00', '2014-08-12 20:08:32.379379+00', 11524, 1, NULL, 'ace', '1-- ::

  1c cross down into Mirror Reels3 on opposite side (1x,2,3), 2c facing out

9-- ::

  1c turn 2c on sideline EH 1½ (2,1x,3) ; 1c+3c repeat (2,3,1x), 3c facing out 

17-- ::

  1c cross up into Mirror Reels3 on own side (2,3,1), 3c facing out

25-- ::

  1c turn 3c on sideline EH 1½ (2,1,3)  ; 1c dance up between 2c and cast off to (2,1,3) 

', 3);
INSERT INTO 'dancecrib' VALUES (11971, '2019-07-21 06:57:41.457349+00', '2020-11-02 09:31:22.375736+00', 17505, 1, 202, 'ace', '1--::

  1c+2c S&Rotate (2,1,3)

9--::

  All W dance across RSh to P, chase clw ½ to Wside (3W,1W,2W on Wside, 2M,1M,3M on Mside) | Top two C ½ RHA _as_ bottom C cross RH (1M,2M,3M on Wside, 1W,3W,2W on Mside)

17--::

  All M repeat pattern [9-14] (3M,2M,1M on W side, 1W,3W,2W on Mside) | Top two C ½ RHA _as_ bottom C cross RH (3W,1W,2W on Wside, 2M,3M,1M on Mside)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (1628, '2012-01-22 19:28:51.804411+00', '2018-10-08 21:07:29.708758+00', 9109, 1, NULL, 'ace', '1–::

  1c+2c set | ½ RHA ; 1c+3c ½ R&L (2x,3x,1)

9–::

  1c+3c set | ½ LHA ; 2c+1c ½ R&L (to 1,2,3)

17–::

  1c lead down the middle (2c up) ; lead up to 2pl | 2c+1c+3c set

25–::

  All circle6 and back (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (8657, '2015-02-13 17:42:07.598913+00', '2015-02-13 17:43:23.098085+00', 11228, 1, NULL, 'ace', '1--::

  1c dance between 2c, behind 3c, between 4c and cast up to places (1,2,3,4)

9--::

  1c Turn RH | 1c turn 2c on own side LH : Turn P RH | turn 3c on own side LH

17--::

  1c turn P RH | turn 4c (own side) LH ; turn P RH for {4} (2,3,4,1)

25--::

  1c dance to top and back while the others clap

33--::

  All Circle8 and back (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (3491, '2012-01-22 19:30:27.667884+00', '2015-03-03 13:22:09.503922+00', 6981, 1, NULL, 'ace', '1–::

  1c cast off behind own lines and cast back

9–::

  1c lead down the middle for 3 bars, back for 3, cast off to second place to face 1cnrs (2c up)

17–::

  1c turn corner, P, corner, P to finish between corners

25–::

  All A&R ; 1c turn RH 1½ times round to own side.', 3);
INSERT INTO 'dancecrib' VALUES (9055, '2015-12-03 13:49:14.619859+00', '2018-03-20 17:43:17.991208+00', 7775, 2, 2788, 'ace', '1-8::

  1M+3L advance, ½ turn RH and cast out to opposite place, 1L+3M repeat



9-16::

  3s+2s+1s dance mirror reels of 3 on the side (1M+2L pass LSh and 1L+2M pass RSh to begin) 



17-24::

  1M+2L turn LH 1.1/2 times while 1L+2M turn RH 1.1/2 times, 3s+1s dance 1/2 double Fig of 8 (3s cast while1s cross up to begin)



25-32::

  3s+1s+2s dance the knot', 0);
INSERT INTO 'dancecrib' VALUES (10023, '2017-07-23 17:18:36.524626+00', '2017-07-23 18:07:21.758908+00', 17893, 1, 202, 'ace', '1--::

 1c+2c set | turn BH to face up NHJ ; 1c cast to 2pl (2c dance up) | 2c+1c set

9--::

 1c pass Lsh | cast R  into lines across (1W+2c & 1M+3c facing dn/up) ; all A&R{4}

17--::

 1c pass Lsh |cast R to 2plx ; 2c & 3c turn P RH _while{4]_ 1c turn P RH 1 ½ (2,1,3)

25--::

 Circle6 and back

', 2);
INSERT INTO 'dancecrib' VALUES (10348, '2017-12-22 22:43:05.461369+00', '2017-12-22 22:45:11.120549+00', 18141, 1, 202, 'ace', '1--::

  1c set | dance down between 2c, cast behind 3c ; cross RH, cast off to 2plx (2,1x,3)

9--::

  Circle6 and back

17--::

  1c ½ Fig8 down round 3c ; set | turn P LH to face 1cnrs

25--::

  Turn Corners and Partner (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1640, '2012-01-22 19:28:52.510051+00', '2023-02-12 16:51:51.1461+00', 9333, 1, NULL, 'ace', '1–::

  1c+2c+3c S&Link3 ; repeat (3x,2x,1x)

9-20::

  3c+2c+1c R&L for 3 couples (3x,2x,1x)

21-24::

  3c+2c ½ RHA _while{2}_ 1c cross RH | All set (2,3,1)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (1630, '2012-01-22 19:28:51.917489+00', '2018-10-08 21:11:04.359539+00', 10663, 1, NULL, 'ace', '1–::

  1c set | dance down the middle and out through 2pl (2c up) ; 1M+3M & 1W+3W turn EH into DTr position (1c briefly join NH)

9–::

  2c+1c+3c DTr, at end 1c turn R about to face 1cnr

17–::

  Turn CPCP, but at the end cross RH to (2,1,3)

25–::

  All Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1638, '2012-01-22 19:28:52.355859+00', '2021-02-06 13:44:02.710031+00', 10599, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; turn LH 1¼

9–::

  Lsh ½ Reels3 across with 1cnr+4cnr, to (2x,1x,3x) ; 1c turn LH 1½ to 2pl facing out

17–::

  Lsh ½ Reels3 on sides with 4cnr+3cnr, finish between the end couple ; 1c turn LH 1¼ to (3x,1x,2x)

25–::

  All S&Link3 twice (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12561, '2020-02-02 10:15:50.14471+00', '2020-02-02 10:15:50.14471+00', 14709, 1, NULL, 'ace', '1--::

  1c+2c half DblFig8, 1c crossing down ; half R&L (2,1,3)

9--::

  Circle6 and back

17--::

  1c&3c repeat [1-8]  (2,3,1)

25--::

  All petronella turn twice ; All set | All cross RH (2,3,1)', 0);
INSERT INTO 'dancecrib' VALUES (15086, '2022-09-05 15:19:10.541242+00', '2022-09-05 15:19:10.541242+00', 21090, 2, 160, 'ace', '1-8:: 1s dance down, set to partner; pull RSh back & dance out the ends, and cast to 2nd place on own sides. 2s up 1-2. ( 2 1 3) 
9-16:: Set and Rotate for 3C (3 1 2)
17-24:: Figures of eight - 1s cross passing LSh, dance Rsh around 1st corner, Lsh around 4th corner - end  in 2nd place own sides facing out.
25-32:: Chaperoned Chain Progression
', 3);
INSERT INTO 'dancecrib' VALUES (8076, '2013-10-06 23:19:06.026872+00', '2014-04-30 23:23:37.849471+00', 105, 1, NULL, 'ace', '1–::
  1c+2c & 3c+4c RHA, LHA
9–::
  1c lead down the middle ; and up and face out
17–::
  1c cast to 4pl (2c+3c+4c up) ; All turn RH
25–::
  Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (8871, '2015-08-26 22:07:03.520705+00', '2019-02-13 13:49:47.240412+00', 16526, 1, 1041, 'ace', '1--::  Mirror Reels3 on the sides, 2c start out and up

9--::  1c set | cast off (2c up) ; turn RH and cast R (2M steps down, 3W up), (to 1,2,3 on M side, 2,3,1 on W side)

17--::  3 couple Bourrel (3,1,2)

25--::  Circle6 and back (3,1,2)

', 4);
INSERT INTO 'dancecrib' VALUES (12949, '2020-07-01 03:32:44.617013+00', '2020-07-01 11:50:10.758907+00', 168, 1, 202, 'ace', '1--::
  2c lead up, cross and cast off to 2plx ; 1c+2c ½ R&L (2,1x,3)
9--::
  2c+1c L-Chain (2,1x,3)
17--::
  1c turn 3c RH on sides ; ½ Parallel Reels3, 1c LSh to 2c (3,1x,2)
25--::
  1c turn 2c RH on sides ; ½ Parallel Reels3, 1c LSh to 3c (2,1x,3)
33--::
  Circle6 {6} and back | 1c cross RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (1642, '2012-01-22 19:28:52.615223+00', '2021-03-27 12:31:57.603024+00', 7338, 1, NULL, 'ace', '{{explanation}}

The M on middle circle face clw; each face two W on inner and outer circles, facing cclw



1–::

  Trios RHA ; LHA

9–::

  M turns W on the R with RH ; turns W on the L with LH

17–::

  Rsh Reel3, finish in DTr position

25–::

  Set as in DTr | All set adv to inverted triangle (W turn in, M to R) : Set as in DTr | Set, W turning in and M turning R to meet new partners', 3);
INSERT INTO 'dancecrib' VALUES (14017, '2021-05-03 07:41:02.123564+00', '2021-05-03 08:13:54.21673+00', 6724, 1, 202, 'ace', '1--::
  1c (+2c who dance up to follow) lead down ; 2c (+1c following) lead up and cast to 2pl (1,2,3)
9--::
  2c+1c DblFig8 down round 3c (2,1,3)
17--::
  1c+3c ½ DblFig8 up round 2c (to 2,3x,1x) ; 1c cross | cast up _while{4}_ 3c cross RH | loop down to 3pl and face up (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2111, '2012-01-22 19:29:20.699117+00', '2018-01-17 23:50:43.685197+00', 12983, 1, NULL, 'ace', '1–::

  1c set | cross RH ; cast (2c up) | set advancing into BtoB facing opposite side

9–::

  DTr, finish as at start

17–::

 1c Fig8 across round end couple, start Rsh to 1cnr. at end pass Rsh to face 3cnr

25–::

  SetH&G , turning LH ¾ to finish (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1652, '2012-01-22 19:28:53.121779+00', '2019-02-05 11:34:23.811496+00', 14337, 1, NULL, 'ace', '{{explanation}}

This is a 3C/4L variation of Goldring''s Ayr Promenade



1–::

  1W+2W+3W cross and dance Rsh round P to place ; turn P RH

9–::

  1M+2M+3M cross and dance Rsh round P to place ; turn P RH, into

17–::

  3-couple promenade (1,2,3)

25–::

  1c cross RH, cast to 2pl (2c up) ; turn RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1665, '2012-01-22 19:28:53.809942+00', '2014-04-30 23:23:38.168088+00', 9381, 1, NULL, 'ace', '1–::
  1c turn BH, cast off one (2c up) ; ½ Fig8 R (M down, W up) (2,1x,3)
9–::
  Teapots R (2c+1M & 1W+3c RHA) (2,1x,3) ; 1c ½ Fig8 L (M down, W up) (2,1,3)
17–::
  1c+3c Set&Rotate (set to P | cast 1 place clw ; change place RH with P | chase 1 place clw)
25–::
  2c+3c+1c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (1651, '2012-01-22 19:28:53.077857+00', '2014-04-30 23:23:37.894949+00', 116, 1, NULL, 'ace', '1–::
  1c+2c+3c Promenade
9–::
  1c+2c RHA {3}, LHA {3} | 1c cast off on as 2c dance to top.
17–::
  2c+1c+3c circle6 and back, 1c finish facing 1cnr
25–::
  1c set to and turn 1cnr RH to join P LH ; BiL | 1c turn LH to face 2cnr
33–::
  1c set to and turn 2cnr RH to join P LH ; BiL | 1c turn LH to face 1cnr
41–::
  Reels3{6} with cnrs, Lsh to 1cnr | cross to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1663, '2012-01-22 19:28:53.690866+00', '2017-11-11 13:04:41.526546+00', 13578, 1, NULL, 'ace', '1–::

  Mirror Reels3 on the sides, 1c starts in and down

9–::

  1c dance down the middle and up, finish facing out

17–::

  1c+2c Turn EH 1½ to change places ; 2c+1c+3c A&R

25–::

  Circle6 and back



{{explanation}}

Note. Deviser''s option:join hands into circle on [22] and hold during the retire and circle.', 3);
INSERT INTO 'dancecrib' VALUES (10025, '2017-07-23 20:53:52.33101+00', '2017-07-23 20:57:49.882011+00', 17895, 1, 202, 'ace', '1--::

 1c+2c & 3c+4c RHA ; 2c+3c LHA

9--::

 All W A&R _while{4}_ all M set twice ; All M A&R _while{4}_ all W set twice

17--::

 1c followed by 2c, 3c & 4c dance down ; all cast up to places

25--::

 1c dance to 4pl (2c+3c+4c up) : all turn P RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (8488, '2015-01-15 23:12:53.001839+00', '2015-08-18 23:59:18.532878+00', 13351, 1, NULL, 'ace', '1--::

  1c+2c the “Typhon”: 1M+2W turn RH ¾, face each other, and twirl to progressed places facing out _while{4}_ 1W+2M set diagonally and cast one place clw (2,1,3) ; ½ Reels3 on sides, 1c Rsh to 2c and 1M faces out (3,1,2)

9--::

  1M, 1W following, casts up and dances down the middle, finish 1M between 2c and 1W between 3c ; 1W+3c & 1M+2c ½ Rsh Reels3 across, 1c finish facing down

17--::

  1M, 1W following, casts R round 3M’s place to 2plx (3x,1x,2x) ; All turn P RH into promhold facing down 

25--::

  3c+1c+2c the “Japonaise”: Promenade {3} to W side all facing up, slip into middle and face P {1} ; turn P RH to (2,1,3)

33--::

  Circle6 and back (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3375, '2012-01-22 19:30:22.643927+00', '2021-02-04 12:11:17.223006+00', 10877, 1, NULL, 'ace', '1–::

  1c+2c set | Circle4 L | turn BH (1,2,3)

9–::

  1c+2c promenade, 1c casting to finish (2,1,3)

17–::

  1c+3c set | 1c cross down _while_{2} 3c cast up ; ½ Reels3 on the sides, 3C starting out and L (1x,3,2)

25–::

  1c+3c set | 1c cross down _while_{2} 3c cast up ; ½ Reels3 on the sides, 1C starting out and R (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8797, '2015-06-21 06:07:45.474861+00', '2015-06-21 06:07:45.474861+00', 16460, 1, NULL, 'ace', '*Two circles RR, M outside facing W inside*



1-::

  All Circle L and meet new P

9-::

  Turn P RH ; turn LH

17-::

  Turn P BH ; dance BtoB

25-::

  All M form arches and dance in, the W dancing out (pass Rsh) | set turning to face P ; repeat (M’s arches) 

', 3);
INSERT INTO 'dancecrib' VALUES (8658, '2015-02-13 20:00:23.199659+00', '2015-02-13 20:01:07.275044+00', 15665, 1, NULL, 'ace', '1--::

  1c set | cast (2c up) ; ½ Reels3 on the sides, 1c starts in and down (3,1,2)

9--::

  1W+3c & 1M+2c ½ Reels3 across ; 1c ½ Fig8 (Lsh to 3cnr pos.), and face 4cnr (pos) (3x,1,2x)

17--::

  3M+1L & 1M+2L set twice ; turn RH

25--::

  Diagonal R&L (M down, W up) (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10112, '2017-09-08 20:37:17.328837+00', '2018-02-22 09:00:02.777541+00', 17922, 2, NULL, 'ace', '1 - 4::

  1s cast off and set advancing to face 1st corner

5-16::

  All dance to each corner and set

17-24::

  Change places - middle couple right hand to the right, middle couple left hand to the left, middle couple right hand to the right, all cross right with partner

25-32::

  1s and 3s dance the chain progression

', 2);
INSERT INTO 'dancecrib' VALUES (9427, '2016-10-11 00:47:09.405658+00', '2016-10-11 01:03:29.72737+00', 17409, 2, NULL, 'ace', '1-:: 1c+2c progressive DblFig8 (1c cross, cast ; cross up, cast _while{8}_ 2c set, cross up, cast, cross up) (2,1,3)

9-:: 1c turn P 3/4 RH | turn 1cnr LH ; turn P 3/4 RH | turn 2cnr LH to finish 1M/1W between 2c/3c facing down/up

17-:: In lines across set | change pl RH : set ; 2c+3c change pl RH _while{2}_ 1c turn P 3/4 RH to 2plx

25-:: 2c+1c+3c Circle6 and back



{{explanation}}

Note. Repeat from new positions with 1c on opposite side, so the 1c dance from both sides of the dance.', 2);
INSERT INTO 'dancecrib' VALUES (1662, '2012-01-22 19:28:53.632792+00', '2020-05-15 10:11:18.924075+00', 159, 1, NULL, 'ace', '1–::

  1c+2c RHA (2c face out) ; 1c cross down, _while{2}_   2c cast up | 1M+2W & 2M+1W Turn ¾ easy hand to line4 across facing down (1c between 2c)

9–::

  All dance down, on [12] 1c turns in and 2c meets, all NHJ ; 1c+2c dance up | 1c cast off to 2plx, _while{2}_ 2c dance to 1pl (loop is usual)

17–::

  All set | »petronella in tandem« ; repeat (to 1,2x)

25–::

  All set | ½ Circle4 Left ; 1c turn BH 1½ to 2pl.', 3);
INSERT INTO 'dancecrib' VALUES (10637, '2018-04-17 00:01:23.951712+00', '2020-10-17 10:46:48.761519+00', 8083, 1, 202, 'ace', '1--::

  1c Mirror Fig8 on own sides (start inwards, touching NH when possible)

9--::

  1c+2c set | cross RH ; set | turn RH ½ into allemande hold facing up

17--::

  2C Allemande (2,1,3)

25--::

  1c Fig8 up round 2c', 2);
INSERT INTO 'dancecrib' VALUES (3346, '2012-01-22 19:30:21.481998+00', '2020-05-15 10:14:51.192839+00', 13755, 1, NULL, 'ace', '1–::

  1c, with 2c+3c+4c dancing up and following, dance down the middle and cast up to places

9–::

  All set | 1c+2c & 3c+4c ½ RHA ; All set | 2c+1c & 4c+3c ½ LHA (1,2,3,4)

17–::

  1c+2c & 3c+4c The Bourrel (1M+2W set advancing | turn BH ½ and swivel R to face M dn, W up _while{4}_ their P dance round them ¾ cclw ; All set to P | turn P ¾ BH to exchanged places), finish (2,1,4,3) ready for

25–::

  1c+4c+3c Allemande (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (1839, '2012-01-22 19:29:05.174993+00', '2020-05-17 15:53:09.267849+00', 805, 1, NULL, 'ace', '1–::

  1W advances to 3M | both set H.Schottische | 1W returns to place

9–::

  1M+3W repeat

17–::

  1c (start inwards) mirror Fig8 on the sides

25–::

  2c dance BtoB ; all couples set H.Schottische

33-48::

  All couples full Petronella

49–::

  All C advance {1} and face down NHJ, 3c (2c+1c following) dance down {1} | out to beyond the sides {2}; up {2} | towards each other {2} to form a line across, facing down, holding hands with crossed arms

57–::

  All dance down ; backwards up and face L (to W side) in a line across, making arches with RH on the shoulder of person in front

65–::

  1W (start to the R) casts down and under each arch till she is behind 1M

73–::

  1M (start by casting L behind 1W) dances up and under each arch to the top, and all face up

81–::

  1c (2c+3c following) dance down behind the sidelines {3}, in towards P {2}, lead up {3}, 1c crossing (1,2,3)

89–::

  While 3c make an arch, 1c with 2c following, cast off behind own lines ; and dance up under arch to (1,2,3) ', 3);
INSERT INTO 'dancecrib' VALUES (9318, '2016-09-21 00:39:31.772684+00', '2020-11-15 13:00:25.073079+00', 8467, 1, 202, 'ace', '1--::
 All Circle and back
9--::
 All W Fig8, passing in front of P then in front of crn
17--::
 All M Fig8, passing in front of P then in front of crn
25--::
 All W advance | retire ; All M advance | retire to P Rsh _while{2}_ W move slightly to their L

{{explanation}}
M always have a new W on their R to begin', 2);
INSERT INTO 'dancecrib' VALUES (10349, '2017-12-22 23:02:23.010384+00', '2017-12-22 23:02:38.321409+00', 18143, 1, 202, 'ace', '1--::

  1c lead down | turn RH ½ ; lead up to top | turn RH ½ staying in middle (2c step in on [7-8])

9--::

  2C Allemande, 1c finish facing 1cnrs

17--::

  Set to and Turn Corners (2,1x,3)

25--::

  1c ½ Fig8 L round 4cnrs ; 2c+1c+3c turn P RH (2,1,3)

  ', 2);
INSERT INTO 'dancecrib' VALUES (8798, '2015-06-22 06:31:46.221478+00', '2015-06-22 06:31:46.221478+00', 16306, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; turn LH 1¼  to finish between end couples facing 3cnr 

9--::

  Lsh Reel3 across to (2,1x,3)

17--::

  1c ½ Fig8 L (1W up, 1M dn) ; 1W+2c & 1M+3c RHA (Teapots R)

25--::

  All Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9057, '2015-12-12 23:46:07.97901+00', '2020-10-15 21:43:22.298486+00', 16625, 2, 111, 'ace', '1-8::

  Reel of 3 on opposite side

9-16::

  Reel of 3 on own sides - 1C face 2C on sidelines.

17-24::

 1C 2C  R&L - start RH on sides. End with LH turn half round and face up in promenade hold.

25-32::

  Allemande', 0);
INSERT INTO 'dancecrib' VALUES (13369, '2020-11-02 09:51:48.33907+00', '2020-11-02 09:52:17.698869+00', 19244, 1, 202, 'ace', '1--::

  1c dance clw round own sides to places. 1W faces out (1,2,3,4)

9--::

  1c+2c RHA ; 1c+2c & 3c+4c turn RH on sides (1,2,3,4)

17--::

  Reels4 (1,2,3,4)

25--::

  1c (1W leading) cast off to 4plx (2c+3c+4c up) ; 1c turn P RH 1½ (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12882, '2020-06-04 22:12:52.513172+00', '2020-06-04 22:13:03.540979+00', 20000, 1, 1645, 'ace', '1-4::

  1c & 3c &frac12; turn P BH opening out into centre (W leading) |

  chase &frac12; way clw in centre & 3M+1W & 1M+3W end in tandem facing sides

5-8::

  1M+3W & 3M+1W in tandem chase &frac12; way clw outside, RSh round 2c & 4c, M end BtoB in centre facing W _while{4}_ 2c & 4c dance [1-4]

9-12::

  1W+3M & 1M+3W set | adv{1} & ret{1} _while{4}_ 2c & 4c dance [5-8] through setting cpls, all M end BtoB in centre

13-16::

  1W+3M & 1M+3W dance BtoB _while{4}_ 2c & 4c dance [9-12]

17-20::

  All &frac12; intersecting RSh Reels4 with &frac12; LHA in centre

21-24::

  M set adv to next centre place L & face out to P _while{2}_ W chase &frac14; clw |

  all turn P &frac34; RH & W face out (2,3,4,1)

25-32::

  *Corner Schiehallion:* M dance straight across & face out to L _while{2}_ W loop L round corner & face in |

  repeat 3 times{6} from new places to (2,3,4,1) 2c & 4c end facing P.

  *All turns and &frac12; LHA may be done hands free if preferred*

', 5);
INSERT INTO 'dancecrib' VALUES (3771, '2013-07-13 15:55:57.208748+00', '2014-04-30 23:23:38.258376+00', 11184, 1, NULL, 'ace', '1–::
  1c+2c cross RH and cast off two (2c leads) ; 1c cross below 3c as 2c cross below 4c | 1c+2c dance up to places (1,2,3,4)
9–::
  3c+4c repeat upwards (1,2,3,4)
17–::
  1c+4c A&R on diagonal ; 1c cast to bottom (others step up)
25–::
  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (13101, '2020-08-11 22:07:16.457143+00', '2020-08-12 07:46:46.681784+00', 19900, 1, 1645, 'ace', '1-::

  1c+2c chase &frac12; way clw (2x,1x,3) ; 1c+3c chase &frac12; way cclw (2x,3x,1)

9-::

  1c cast up (3c down) | set adv to 1cnrs ; 1c+1cnrs &frac12; diag RSh Reel4 (keeping distanced)

17-::

  1c+2cnrs &frac12; diag RSh Reel4 ; 1c "turn" 1&frac12; RSh (3,1,2)

25-::

  1c+2c Poussette without taking hands (3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (2930, '2012-01-22 19:30:03.374284+00', '2021-05-03 08:11:03.352166+00', 4948, 1, NULL, 'ace', '1–::

  1W+2M & 1M+2W set (1c advancing, 1W passing in front) and turn RH to places ; 1W+2W & 1M+2M set to and turn EH, 1c passing between 2c

9–::

  1c meet and lead down the middle and up

17–::

  1c+2c set | ½ RHA ; set | ½ LHA

25–::

  Poussette', 3);
INSERT INTO 'dancecrib' VALUES (9775, '2017-04-07 22:55:38.376709+00', '2017-04-07 22:55:38.376709+00', 9151, 1, NULL, 'ace', '1--::

  1c A&R ; dance (gypsy) round P Rsh to place

9--::

  1W+2c LHA, finishing 2c on W side and 1W in 2M place ; 1W with first 2W then 2M following cast clw round the top to 2W place, 2c finishing in 1pl (1M down on[15-16]) (2,1,3) 

17--::

  Reels3 on the sides, 1c Lsh to 3c, 1M finish facing out (2,1,3)

25--::

  1M+1W following casts behind 3M, dance up the middle and reach top together, cast off to 2pl. (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8860, '2015-08-24 17:14:34.198345+00', '2015-08-24 17:14:34.198345+00', 5803, 1, NULL, 'ace', '1--::  1c+2c Circle4 and back

9--::  1c set | cast off two (2c up) and dance up to DTr position

17--::  DTr (2,1,3)

25--::  2c+1c R&L

', 3);
INSERT INTO 'dancecrib' VALUES (8710, '2015-03-05 00:14:12.750237+00', '2015-03-05 00:14:12.750237+00', 16153, 1, NULL, 'ace', '1--::

  1c turn RH | cast off (2c up) ; turn RH ¾ | set in lines across (1W above, 1M below)

9--::

  ½ Reels3 across, 1c Rsh to 1cnr, finish BtB on midline ; All Set as in DTr | All set as 1c Petronella to 2pl (2x,1,3x)

17--::

  ½ Reels3 on sides, 1c Rsh to 4cnr, finish BtB in 2pl ; All Set as in DTr | All set as 1c Petronella to lines across, 1M +3c above and 1W+2c below 

25--::

  S&Link3 ; All set | 1c cross RH (3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (9495, '2016-11-10 23:10:01.905379+00', '2016-11-10 23:10:01.905379+00', 200, 1, NULL, 'ace', '1--::

  1c+2c+3c mirror Reels3 on opposite sides (1c cross down, 2c out and up)

9--::

  Repeat, 1c now to own sides

17--::

  1c+2c+3c Poussette, 1c+2c dance as top couple (3,1,2)

25--::

  1c+2c+3c The Knot (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9058, '2015-12-15 21:35:27.553546+00', '2015-12-15 21:40:24.140234+00', 15437, 1, NULL, 'ace', '1--::

  All W, 1W leading, dance cclw round the set, to places

9--::

  All M, 3M leading, dance cclw round the set, and join RH with P

17--::

  All lead down the middle and up

25--::

  1c+2c Allemande (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2711, '2012-01-22 19:29:54.108266+00', '2016-02-28 11:32:48.486761+00', 3974, 1, NULL, 'ace', '{{explanation}}

M on inner circle face P on outer circle



1–::

  All set, cross RH, set, cross RH

9–::

  In Allemande hold 2 steps cclw, set while turning on the spot to reverse Allemande hold ; Allemande 2 steps clw, set to P falling back

17–::

  All turn P RH to places ; All turn new P to the L LH 

25–::

  All C slip cclw ; and back', 4);
INSERT INTO 'dancecrib' VALUES (9494, '2016-11-10 16:57:52.614336+00', '2016-11-10 17:01:14.414469+00', 15432, 1, NULL, 'ace', '1--::

  1c+3c Bourrel (1M+3W set and turn BH to finish BtoB on midline M below W _while{4}_ 1W+3M cross and chase cclw to midline facing P ; 1c+3c set to P | Turn BH) (to 3,2,1)

9--::

  2W+2M following Fig8, Lsh round 1W & Rsh round 3M 

17--::

  2c lead down the middle and up (to 3,2,1)

25--::

  3c+2c the Knot (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (3721, '2013-04-05 14:28:42.750883+00', '2014-04-30 23:23:36.886514+00', 14439, 1, NULL, 'ace', '1–::
  1c+5c Rsh Fig8 on own side, 1W+5M face out
9–::
  1W+5M (Partners following) cast R and cross to opposite side (2c+4c step to end) (2,1x,3,5x,4) ; 1c+5c Turn P RH and twirl R to DDTr position facing opposite side
17–::
  Set as in DDTr | All petronella (1c+5c to opposite sidelines, others to BtoB in middle) ; Set in inverted DDTr | All petronella, 1c+5c to midline with M above W, others to sideline
25–::
  1c+5c ½ Reel4 on midline ; Turn P RH to promhold facing down (M on L)
33–::
  5c+3c & 1c+4c parallel Rsh Reels3 across, 3c/4c finishing in 3pl/5pl, and 5c+1c face down NHJ
41–::
  5c+1c dance down (4c up on [43-44]); Change side {1}, W passing under joined arms, (3c+4c up on [45-46]) and dance up {3} to (2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (10638, '2018-04-17 00:20:33.027153+00', '2019-03-21 00:21:26.699066+00', 8081, 1, 202, 'ace', '1--::

  1W+2W NHJ dance between P, cast to places | 1W+2W change places RH, with polite turn

9--::

  1M+2M NHJ dance between P, cast to places | 1M+2M change places LH, with polite turn (2,1)

17--::

  1c lead down ; and up to 2pl centre

25--::

  1c lead up, cast to 2pl ; 1c turn RH (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (3352, '2012-01-22 19:30:21.720258+00', '2014-05-05 22:54:45.697389+00', 6413, 1, NULL, 'ace', '1–::

  All set | 1W+2M cross RH ; All cross LH on sidelines | All set

9–::

  Both W cast off (both M step up ½) and lead up to face P ; turn P RH 1½ , still in line across, 1c on M side facing down, 2c facing up

17–::

  1c & 2c each dance a solo 2c Allemande (out to R, cross {2}, pass other C ; dance in-and-under, fall back (1x,2)

25–::

  All set | 1c cast as 2c dances up ; 1c cross up RH as 2c casts | 1c cast as 2c dances up (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (15159, '2022-10-05 18:04:12.507426+00', '2022-10-05 18:04:12.507426+00', 21145, 2, 2784, 'ace', ' 1-::
 1c Fig8 on sidelines, dancing in to start & joining NH when possible
 9-::
 Middle cpls Fig8 round nearest end cpls (giving RH when dancing down, LH when dancing up)
17-::
 4c Fig8 on sidelines, casting out to start & joining NH when possible
25-::
 1c cast to 4pl (2+3+4c step up on 27-28), all turn RH
', 5);
INSERT INTO 'dancecrib' VALUES (8261, '2014-05-05 23:49:44.679585+00', '2014-05-05 23:49:44.679585+00', 10594, 1, NULL, 'ace', '1--::

  1c dance down one | cast to top ; cross down into ½ Fig8 round 2c (1x,2,3)

9--::

  Reels3 on the sides, 2c starts out and up, give hands (1x,2,3)

17--::

  1c+2c set to P (mirror steps) | set : set across ; ½ RHA | turn P RH ½ (2,1,3)

25--::

  Grand Chain (2c cross RH to start) 

33--::

  1c+3c mirror single allemandes (2,3,1)

41--::

  All set | 3c cross RH as 2c+1c turn RH ; Circle6 L (2.3.1)



', 2);
INSERT INTO 'dancecrib' VALUES (8262, '2014-05-07 13:34:30.979476+00', '2014-05-07 13:34:30.979476+00', 12481, 1, NULL, 'ace', '1--::

  Reels3 on the sides, 1c cross down to start, finish (1x,2,3) with 1c facing 2c in Allemande hold

9--::

  1c+2c both dance Allemande as if 2nd couple of an allemande (2,1x,3)

17--::

  2c+1c L-Ch

25--::

  1c cross down and cast up ; All turn P RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3650, '2012-10-12 14:59:12.706847+00', '2013-07-29 21:05:57.234174+00', 3144, 2, 197, 'ace', '1–::

  All circle8 and back

9–::

  Reels4 on own sides (1,2,3,4)

17–::

  1c+2c & 3c+4c Poussette (2,1,4,3)

25–::

  1c+3c set | RHA | 1c cast off and 3c lead up (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (1627, '2012-01-22 19:28:51.756997+00', '2018-02-25 13:35:05.005138+00', 56, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c set | ½ RHA ; set | ½ LHA, 1c & 3c finish NHJ facing down

9–::

  1c+3c dance down | set to P ; dance up | cast to face 1cnrs (2c+4c up)

17–::

  1c+3c set to and turn 1cnrs RH ; set to and turn 2cnrs RH

25–::

  1c+3c turn LH | cast off on opposite sides (4c+5c up) ; turn RH 1½ (to 2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (1624, '2012-01-22 19:28:51.600342+00', '2016-05-07 12:52:32.53643+00', 51, 1, NULL, 'ace', '1–::

  1c+2c+3c Petronella without setting, to places

9–::

  1c Set, Turn BH (1W twirls) ; 1c set to 2c, turn BH ½ to change places (1c twirls)

17–::

  1c set to 3c ; turn BH ½ to change places on the side ; 1s cast up to top (2c+3c down)

25–::

  1c+2c+3c 4 hands of Non-crossing Chain (Full turns at top / bottom, 1c start across, 2c with 3c).(to 2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (1623, '2012-01-22 19:28:51.54177+00', '2014-04-30 23:23:37.27985+00', 9631, 1, NULL, 'ace', '1–::
  1c cross RH, 1W to sideline, 1M staying just inside, and face M side | turn 2c LH ½ ; 1c (1M leading) cast up and dance down the middle into lines across facing down (2c+1W & 3c+1M)
9–::
  In lines dance down ; all pivot R and dance up
17–::
  1c (1W leading) dance up and cast L into (2,1,3) ; 1c turn LH 1¼ to finish 1M below 1W
25–::
  Teapots R ; Teapots L (RHA with end couple, LHA with other end couple) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3653, '2012-11-24 02:52:39.823517+00', '2014-05-23 22:27:26.240441+00', 5395, 1, 106, 'ace', '1--::

  All set | cross RH ; set | cross RH (1,2,3)  

9--::

   1c lead down {3} , up {3} | cast off (2c up) (2,1,3)

17--::

  Mirror Reels3 on own sides, 1c start in and down

25--::

  2c+1c R&L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8279, '2014-06-09 15:46:52.146825+00', '2014-06-10 22:18:12.821936+00', 15459, 1, NULL, 'ace', '1--::

  All set | advance and touch hands ; retire | set

9--::

  1c+3c change place with opposite by half turn and cast away ; 2c+4c repeat _while{4}_ 1c+3c Turn BH {3} and pivot R to face side couple in parallel lines across

17--::

  Parallel Reels4 across

25--::

  All turn cnr RH | turn P LH ½ ; All set | Circle4 L ¼ round (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10504, '2018-03-12 19:04:09.881086+00', '2022-04-03 09:00:40.799343+00', 18204, 2, 2703, 'ace', '1-8:: 1c cross RH | cast off (2c up) ; 1/2 Fig8 L (W up, M down)

9-16:: 2c&1c&3c set | cross RH ; set | cross RH (1c face out)

17-24:: RSh reels of 3 on sides [1M+2M and 1W+2W pass RSh to start] (1c finish BtB facing own side)

25-32:: Double Triangles', 2);
INSERT INTO 'dancecrib' VALUES (8800, '2015-06-24 16:18:27.20541+00', '2015-06-24 16:18:27.20541+00', 16458, 2, 160, 'ace', '1 - 8::
  1C 2C set, turn BH ; hands 4 to left.
9 - 16::
  1C lead down the middle, on bar 4 change places with ptnr (man crosses below lady & lady under joined hands) ; lead up to top. (1x 2)
17-24::
  1C 2C set, pull back Rsh and chase 1pl cw. ; turn ptnr RH 1_1/4 round into promenade hold. (Men shoulder to shoulder - 1C facing up - 2C facing down).
25-32::
  Tournée', 0);
INSERT INTO 'dancecrib' VALUES (1953, '2012-01-22 19:29:11.646374+00', '2021-01-09 10:13:35.363656+00', 12809, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; turn RH ½ and face P RHJ | set, W swiveling R under joined arms to finish facing W side with 1M behind.

9–::

  1c dance out, W cast up, M down, meet in centre side by side ; dance out on M side ; cast (W up M down) and meet in centre, BtoB facing 1cnr.

17–::

  Cnrs Pass&Turn, at end pass Rsh to (2,1,3)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (2182, '2012-01-22 19:29:24.2719+00', '2015-02-14 01:05:55.968123+00', 1998, 1, NULL, 'ace', '1–::

  1c cast off (2c up), cross LH ; dance Lsh round 2cnrs to face 1cnrs (2,1x,3)

9–::

  Rsh Reels3 in sideline (2,1x,3)

17-28::

  »Fig8 G-Chain«: 2M+1W (side) & 2W+3M (2nd diag) & 1M+3W (side) change places RH | 3M+3W (side) & 1W+1M (1st diag) & 2M+2W (side) change LH ; repeat figure twice ;; (all dance a Fig8, men dancing down the sidelines, women up).

29-32::

  1c set and cross over RH, on first turn finish facing out (2,1,3).', 2);
INSERT INTO 'dancecrib' VALUES (8660, '2015-02-14 02:14:41.498289+00', '2015-02-14 02:14:41.498289+00', 13756, 1, NULL, 'ace', '1--::

  1c lead down {3}, up {3} and cast off (2c up)

9--::

  1c cross down below 3c and cast up ; cross up between 2c and cast to 2pl (3c step in) ready for (2,1,3)

17--::

  1c+3c Poussette (2,3,1)

25--::

  Circle6 and back

', 4);
INSERT INTO 'dancecrib' VALUES (10026, '2017-07-23 23:06:29.354905+00', '2017-07-23 23:09:17.293466+00', 17899, 1, 202, 'ace', '1--::
 1c set | cross RH ; cast one (2c up) | turn RH ¾ to midline, Rsh to Rsh, facing opp sides
9--::
 1c Teapots L, pass Lsh ; Teapots R to face 1cnr
17--::
 SetH&G , on [23-24] petronella turn with clap to 2pl (2,1,3)
25--::
 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (8661, '2015-02-14 03:00:17.916703+00', '2015-02-14 03:00:17.916703+00', 16054, 1, NULL, 'ace', '1--::

  All S&Link3 into lines across ; 2c cross up/down RH and cast to 2pl facing 3cnr while{4} 1c+3c chase one place clw | 1M+3W set facing diagonally as 1W+3M cross diagonally RH to own places and face each other (1,2,3)

9-20::

  Figure-of-eight grand chain: All change place RH between the positions (not dancers) 1M & 2M, 2W & 3W, 1W & 3M | All change place LH between the positions 2M & 3M, 1W & 2W, 1M & 3W ; repeat this pattern twice more (1,2,3) 

21-24::

  1c+2c S&Link  (2,1,3)

25--::

  All Turn BH : 1c+3c S&Link (2,3,1)

33-::

  Parallel Reels3 on the sides, 3c Rsh to 1c (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (14238, '2021-08-14 03:11:27.330881+00', '2021-08-14 23:33:10.722092+00', 19964, 1, 202, 'ace', '1--::
  Circle4 L ; all Petronella turn to midline | set
9--::
  Reel4 on midline
17--::
  All Petronella turn to opposite sides | set (to 1x,2x) ; ½ RHA | set (2,1)
25--::
  R&L (2,1)', 5);
INSERT INTO 'dancecrib' VALUES (1643, '2012-01-22 19:28:52.668993+00', '2014-04-30 23:23:37.669437+00', 14391, 1, NULL, 'ace', '1–::
  1c+2c RHA ; 2c+3c LHA
9–::
  1c Petronella turn to the midline | 2c repeat ; 3c repeat | All set to P
17–::
  All W Petronella turn to sideline | All M repeat ; All turn P RH and stay in the middle (1x,2x,3x)
25–::
  All dance up, cross at the top and cast, 1c makes arch at bottom ; 2c+3c dance up under arch and on [32] all dance to sidelines (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3017, '2012-01-22 19:30:07.050938+00', '2014-05-05 22:59:47.160853+00', 8699, 1, NULL, 'ace', '{{explanation}}

C face C RR



1–::

  Circle4 and back

9–::

  With person opposite: dance BtoB ; Turn RH ½ | ½ RHA (1x,2x)

17–::

  With person opposite: dance BtoB ; Turn LH ½ | ½ LHA (1,2)

25–::

  In Allemande hold promenade Lsh round other C 1½ and meet next C', 3);
INSERT INTO 'dancecrib' VALUES (2008, '2012-01-22 19:29:14.725469+00', '2021-02-04 12:18:55.661349+00', 10866, 1, NULL, 'ace', '1–::

  1c+2c set | ½RHA and face centre ; swivel R to dance to dance out to the sides (2x,1x) | 2c cross RH & 1c turn RH to face 1cnr

9–::

  1c Set to and turn 1cnr BH, finish between ends ; 1c set advancing and turn BH ½ and pivot R to face 2cnr

17–::

  Set to and turn 2cnr BH, finish in 2plx ; 1c set advancing and turn BH ½ and pivot R to finish BtoB facing own side (2,1,3)

25–::

  Reels3{6}, Rsh to 3cnr | 1c turn RH to 2pl', 3);
INSERT INTO 'dancecrib' VALUES (8263, '2014-05-12 08:07:42.608052+00', '2014-05-12 08:07:42.608052+00', 15427, 1, NULL, 'ace', '*Couple face couple RR*

1--::

  Circle4 and back

9--::

  All advance | clap 4 ; retire | stamp 4

17--::

  RHA ; LHA,

25--::

  All Set twice ; pass to meet next couple, clw cpls making arch.



', 3);
INSERT INTO 'dancecrib' VALUES (8265, '2014-05-12 09:43:11.275352+00', '2014-05-12 09:43:11.275352+00', 12998, 1, NULL, 'ace', '1--::

  All set | La Barratte (1x,2x,3x)

9--::

  All S&Link3 ; repeat (3,2,1)

17-20::

  3c+2c S&Link (2,3,1)

21-32::

  R&L for 3 couples (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8267, '2014-05-13 07:47:03.034353+00', '2014-05-13 07:47:03.034353+00', 11894, 1, NULL, 'ace', '1--::

  1c set | dance down ; cast up round 3c (2c up) | 1c set (2,1,3)

9--::

  1c half turn RH and twirl to face 1cnr | ½ Reel4 with 1cnrs, finish facing P on midline, W in 1pl, M in 3pl | 1c set to P

17--::

  1c half turn RH and twirl to face 2cnr | ½ Reel4 with 2cnrs, to (3x,1x,2x) | 1c set

25-::

  1c petronella to between end cpls | set ;  ½ Reels3 across, 1c Rsh to dancer on R

33--::

  1c petronella to 2pl and set (3,1,2) ; ½ Reels3 on the sides, 1c giving Rsh to dancer on R (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8085, '2013-10-12 20:06:00.266581+00', '2016-11-12 20:35:25.747188+00', 10232, 1, NULL, 'ace', '1–::

  1c+2c set | ½ RHA ; 1c+3c set | ½ LHA (2x,3x,1)

9–::

  1c set | cross RH ; cast up one (3c down) | turn LH to face 1cnr (pos)

17–::

  ½ diag Reel4 with 1cnrs, pass Lsh ; ½ diag Reel4 with 2cnrs, 1c curve R into facing lines of 3 across, 1M at top, 1W at bottom

25–::

  All S&Link3 ; 1c turn RH 1½ _while{4}_ cnrs chase clw ½ round (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8270, '2014-05-19 15:09:53.150669+00', '2014-05-19 15:09:53.150669+00', 15444, 1, NULL, 'ace', '1--::

  All half Petronella (1x,2x,3c)

9--::

  1c long cast to 2pl (2c up) ; cross down LH and cast up (2x,1,3x)

17--::

  1c+1cnrs advance diagonally {1} retire {1} | repeat with 2cnrs ; All dance BtoB

25--::

  Diagonal R&L (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (1645, '2012-01-22 19:28:52.758639+00', '2017-11-07 15:53:08.282445+00', 10845, 1, NULL, 'ace', '1–::

  All circle8 and back

9-24::

  Schiehallion Reel

25–::

  All set twice to P ; All birl (elbow grip) one place to the R (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10113, '2017-09-09 15:19:46.004377+00', '2017-09-09 15:19:46.004377+00', 17780, 2, NULL, 'ace', '1- 4::

  Women ½ Fig8 to their left (in front of partner, behind next man). Women face ccw, men cw.

5- 8::

  All cross RH, cross LH with partner; women face in, men face out

9- 12::

  Men ½ Fig8 to their left (behind partner, in front of next woman). Men face cw, Women ccw.

13 -16::

  All cross RH, cross LH with partner; all face in.

17 -24::

 Women Adv & Ret. Men Adv & Ret.

25 -32::

  All Set & Link and Turn RH', 3);
INSERT INTO 'dancecrib' VALUES (9944, '2017-06-07 00:46:03.144995+00', '2017-07-07 01:15:52.732687+00', 14726, 1, 202, 'ace', '1--::

 1c+2c Circle4 L ; 1c turn RH 1 ½ (1x,2,3), finish slightly in

9--::

 1c+3c M-Chain up/dn the middle (1x,2,3)

17--::

 1c set | cast (2c up) ; 1c ½ Fig8 RH up, all dance in on [24] (2,1,3)

25--::

 3C Promenade', 2);
INSERT INTO 'dancecrib' VALUES (9060, '2015-12-20 15:44:59.878344+00', '2015-12-20 15:55:16.342803+00', 11308, 1, NULL, 'ace', '*1c start on opposite side and face 2c (1x,2)*

1--::

  1c set to 2c | change places Rsh ; all set to P | cross Rsh 

9--::

  Repeat 1-8 to (1x,2)

17--::

  1c+2c RHA ; LHA, ending for

25--::

  1c+2c Poussette (2,1x) and face next cpl.

', 3);
INSERT INTO 'dancecrib' VALUES (9832, '2017-05-08 13:21:29.264976+00', '2020-11-08 11:27:21.547445+00', 17731, 2, 160, 'ace', '1-8::

  1C 2C progressive Reel4 across - 1L 2M pass Lsh to begin. (2 1 3)

9-10::

 1C set adv. to face 1crnrs.

11-14::

  1C+1crnrs 1/2 dia.Reel4 - end in lines 3 across - L up, man down

15-16::

  1C set adv. to face 2crnrs

17-24::

  1C+2crnrs 1/2 dia. Reel4 ; All set cross over. (3 1 2)

25-32::

 3cpl  Knot.

', 3);
INSERT INTO 'dancecrib' VALUES (8266, '2014-05-12 10:45:33.166362+00', '2014-09-17 21:13:12.266308+00', 12335, 1, NULL, 'ace', '1--::

  1c+3c turn opposite RH ½ and twirl to exchanged places ; 1c+3c Half Figs8: start with person opposite crossing out between side cpl and cast to own place.

9--::

  1c (promhold)+2c & 3c (promhold)+4c Reels3, Rsh to the M

17--::

  1c+4M+2W & 3c+2M+4W Reels3 across, Rsh to the M

25--::

  1c+3c LHA ; All turn cnr RH | all cpls promenade 1 place cclw.

', 2);
INSERT INTO 'dancecrib' VALUES (13102, '2020-08-12 10:44:45.076593+00', '2020-08-12 10:47:35.56332+00', 19897, 1, 1645, 'ace', '1-::

  1c long cast to 2pl (2c up on [3-4]) ; 1c dance RSh round P to face 3cnrs

9-::

  1c *Pass & Touch Elbows* with 3cnrs: corners, with arms crossed, change pl touching R elbows, 1c pass RSh ; repeat with 4cnrs & pass RSh to sides (3x,1x,2x)

17-::

  All chase &frac12; way clw ; set in centre, facing in (no hands) | 4 spring points

25-::

  All chase clw, ending in the centre | cast away, RSh back, to sides (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14018, '2021-05-03 16:25:00.139811+00', '2021-05-03 23:06:59.237519+00', 20342, 1, 202, 'ace', '1--::
  1c long cast to 2pl (2c up) ; 1c turn RH and face out (2,1,3)
9--::
  Chain Progression for Three Couples (3,1,2)
17--::
  1c+2c set | ½ RHA (to 3,2x,1x) ; cross RH | set (3,2,1)
25--::
  3c+2c set | ½ RHA (to 2x,3x,1) ; cross RH | set (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (8802, '2015-06-24 17:08:55.582603+00', '2020-12-29 12:32:38.464249+00', 16297, 2, 160, 'ace', '1-8::

  1L 2M set, change places RH ; 1M 2L the same. (2x 1x)

9-16::

  2C 1C adv(1) ret(1), cross RH (1C may stay in middle facing up) ;1C  half Fig.8 up round 2C. (2 1x 3)

17-24::

  1M 2C also 1L 3C RHA ; 1M 3C also 1L 2C LHA.

25-32::

  Reel3 on opp. sides (Rsh to 2crnr to begin) , 1C cross RH.', 2);
INSERT INTO 'dancecrib' VALUES (8801, '2015-06-24 16:49:07.195119+00', '2020-12-29 12:36:45.79736+00', 16296, 2, 160, 'ace', '1-8::

  1C set, adv (1) ret (1) ; turn BH, cast to 2pl.

9-16::

  Mirror reel3 on own side (1C in&down).

17-24::

 All set, adv(1) ret (1) ; turn BH, 2C set *while* 1C cast, and 3C dance to top & face out.

25-32::

  Double Fig. 8 round 2C - 1C cross up and 3C cast to begin.', 2);
INSERT INTO 'dancecrib' VALUES (13103, '2020-08-12 21:29:20.948521+00', '2020-08-13 09:47:28.580969+00', 19927, 1, 202, 'ace', '1--::
  Mirror Reels3 on opposite side, 1c crossing down (1x,2,3)
9–::
  Mirror Reels3 on own side (1,2,3)
17--::
  1M A&R _while{4}_ 1W set | cast off (2W up) ; 1W A&R _while{4}_ 1M set | cast off (2M up) (2,1,3)
25--::
  1c ½Fig8 L RSh to 2cnrs ; repeat with 4cnrs to places (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (13106, '2020-08-14 16:37:04.708674+00', '2020-08-14 16:37:28.400302+00', 17747, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 up round 2c (2,1,3)

9--::

  ½ Reels3 across, 1c LSh to 1cnrs ; ½ Reels3 on sides, 1c RSh to 2cnrs[pos]. 1c face 3cnrs[pos]

17--::

  Corners Pass and Turn (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14138, '2021-07-07 09:17:49.384411+00', '2021-07-07 09:20:21.743464+00', 4007, 1, 202, 'ace', '1--::

  1W sets | casts off (2W up) ; 1c turn RH

9--::

  1M sets to 2W | casts off (2M up) ; 1M+2W turn RH. 1M faces out

17--::

  Reel4 across (2,1)

25--::

  Circle4 L ; all turn P BH', 2);
INSERT INTO 'dancecrib' VALUES (1661, '2012-01-22 19:28:53.579382+00', '2014-07-14 08:40:09.410222+00', 9042, 1, NULL, 'ace', '1–::

  1c+2c Set adv. | dance Rsh round P 1½ times spiraling out | ½Circle4 L to (2,1,3)

9–::

  1c+3c repeat (2,3,1)

17–::

  1c lead up between 3c and cast behind 2c to top, (2c+3c down) ; 1c turn BH .

25–::

  1c+2c the Knot. (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10651, '2018-04-18 17:39:50.031927+00', '2020-03-02 13:19:04.994499+00', 13915, 1, 202, 'ace', '1--::

  1c long cast behind 2c, dance down between 3c and cast up round 3c to face 1cnrs (2c up)

9--::

  ½ Reel4 on 1diag, pass P Rsh ; ½ Reel4 on 2diag, pass P Rsh to centre

17--::

  1W+3c & 1M+2c LHA, pass P Lsh ; 1W+2c & 1M+3c RHA

25--::

  1c cast R round 2cnrs position to 2plx (to 3x,1x,2x) ; all chase clw ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9259, '2016-07-10 11:00:52.636292+00', '2016-07-10 11:00:52.636292+00', 17134, 1, NULL, 'ace', '1--::

  1c long cast to 3pl (2c+3c up) ; set | lead up to face 1cnrs (3c down)

9--::

  1cnrs Pass&Turn, pass Rsh ; 2cnrs Pass&Turn, to (2,1,3)

17--::

  All set pulling back Rsh | chase clw 2 steps | ¾ circle6L (2,1,3)  

25--::

  1c+3c RHA and face up NHJ ; 1c cast off as 3c dance up | 3c+1c set (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9062, '2015-12-26 16:27:03.24776+00', '2015-12-26 16:27:03.24776+00', 2563, 1, NULL, 'ace', '1--::

  1c+3c set diagonally, 1W+3M advancing to diagonal facing P | turn P BH ; ½ diag. Reel4 to finish (3x,2,1x)

9--::

  Circle6 and back

17--::

  3c+1c petronella to next place cclw (2c stand) | 1c+3c set diagonally ; repeat petronella to (1,2,3) | All set

25--::

  1c+2c the Knot

', 3);
INSERT INTO 'dancecrib' VALUES (3663, '2012-12-11 15:49:36.440416+00', '2013-07-29 21:06:01.032511+00', 14605, 2, 1, 'ace', '1–::

  1c turn B | cast [2c up] ; 1M dances RS round 3M _while_ 1W dances RS round 2W

9–::

  1W+2c & 1M+3c Circle3 [1c finish facing each other in the centre] ; 1c set | turn B to 1cnr

17–::

  1c+1cnr ½Reel4 [1c pass L to 2cnr] ; 1c+2cnr ½Reel4 [1c finish in 2pl opposite sides]

25–28::

  3c+1c+2c ½ chase clockwise

29–32::

  1c+3c cross R ; ½Circle4 [finish 231]', 3);
INSERT INTO 'dancecrib' VALUES (3053, '2012-01-22 19:30:08.514522+00', '2014-05-23 22:03:49.933343+00', 9926, 1, NULL, 'ace', '{{explanation}}

On 2nd chord move to (1,2,3x,4x)



1–::

  1c+4c turn RH | cast to centre (2c+3c to ends) ; turn LH 1½ to face end C in line across

9–::

  1c+2c & 4c+3c Reels4 across, finish as on [8]

17–::

  All turn facing person RH | 1c+4c ½ LHA to face diagonally opposite »cnr« ; turn that cnr RH | 4c+1c turn P LH and face cnr in line across

25–::

  2c+4c & 1c+3c Reels4 across, at end 1c+4c pass P RH and face out the end (M pivot R)

33–::

  4c+1c cross and cast to middle ; 4c+1c turn RH (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (9258, '2016-07-10 10:09:53.320328+00', '2016-09-02 16:19:14.586967+00', 17133, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; 1c ½Fig8, Lsh to 1cnr

9--::

  1c turn LH to face 1cnrs | 6 bars of set H&G, into lines across

17--::

  S&Link3 ; all set | all cross RH

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8803, '2015-06-24 17:59:06.688718+00', '2015-06-24 17:59:06.688718+00', 16299, 2, 160, 'ace', '1-8::
  1C set, cast 1pl ;  dance RHA - L up/M down.
9-16::
  1C adv+ret ; dance LHA - M up/L down.
17-24::
  1C dance up cast round 2C ;  dance down, cast up round 3C.
25-32::
  6 Hands Round & Back.', 0);
INSERT INTO 'dancecrib' VALUES (8804, '2015-06-25 08:07:36.062943+00', '2015-06-25 08:07:36.062943+00', 8128, 1, NULL, 'ace', '1--::

  1c cross LH to face side cpl (1M+3c & 1W+2c) | All set ; 1M+3c & 1W+2c RHA, all cpls finish in own places in promhold, 1c facing 2c

9--::

  In promhold Reel3 across, start 1c Rsh to 2c, all finish in P’s place facing P

17--::

  All set to P | pass P Rsh to meet next dancer and join NH facing in ; A&R to centre {1+1} | cast back to own place facing P

25--::

  3C triangular knot: turn P RH ½ to Allemande hold facing out | cast one place cclw ; as in normal knot W dance into centre and all turn LH to (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (8293, '2014-06-30 14:34:45.143603+00', '2015-04-04 13:23:45.604824+00', 15483, 1, NULL, 'ace', '1--::

  1c+2c set | cross RH ; set | turn RH ¾ to midline

9--::

  Reel4 on midline, finish in own places NHJ, 1c facing 2c 

17-28::

  Rondel in Twelve [a slowed Rondel: 1-2 under arch | 3-4 cross and loop ; 5-6 W under M arch | 7-8 cross and loop ; 9-10 1c under 2c arch | 11-12 all cast with loop to new places] (2,1)

29-32::

  2c+1c RHA (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2454, '2012-01-22 19:29:39.739097+00', '2020-03-02 18:04:50.911337+00', 8932, 1, NULL, 'ace', '1–::

  1c lead down the middle and up, on [8] 2c step in for

9–::

  1c+2c Poussette, 1c finish BtoB facing own side (2,1,3)

17–::

  DTr, 1c finish facing out on own side

25–::

  1c dance track of Reels3 across, Rsh to 3cnr _while{8}_ 2c+3c dance track of Reels3 on the sides, the 3cnrs starting Rsh (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (8711, '2015-03-07 18:14:50.766277+00', '2015-03-07 18:14:50.766277+00', 16155, 1, NULL, 'ace', '1--::

  1W, 1M following, cast to 3plx (2c+3c up) ; 1c+4c LHA (2,3,1x,4)

9--::

  1W, 1M following, cast up to 1pl (2c+3c down) ; 1c+2c RHA (1,2,3,4)

17--::

  All set | All turn P BH ½ , opening to ; 1c+2c & 3c+4c Circle4 L (1x,2x,3x,4x)

25--::

  1W+2M change places LH | 1M+2W & 1W+3W change places RH ; 1M+3M & 1W+4M change places LH | 1M+4W change places RH (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (3450, '2012-01-22 19:30:26.016633+00', '2014-05-30 14:17:21.860132+00', 6813, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c DblFig8, 1c+4c cast to start, and face out at the end

9–::

  1c+4c cast to middle as 2c+3c dance to the ends | 1c+4c turn BH into ; Circle4 L, at end pivot R into the centre and face »cnrs« (order 2,1,4,3)

17–::

  1c+4c set »Double H&G« (all set as in normal H&G), finish in the centre facing opposite »cnr« (order 2,4x,1x,3)

25–::

  4c & 1c, passing through the ends turn cnr EH, to sidelines (2,4x,1x,3) ; 4c & 1c ½Fig8 through nearest end C (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1677, '2012-01-22 19:28:56.104946+00', '2014-04-30 23:23:38.389735+00', 221, 1, NULL, 'ace', '1–::
  1c+2c+3c ½ RH turn and remain in middle, swivel R and dance out to opposite side ; repeat, to own places
9–::
  1c+2c+3c Circle6 and back, 1c & 3c finish facing down / up the middle
17–::
  1c+3c R&L up / down, to own places
25–::
  1c+2c Tournée.', 4);
INSERT INTO 'dancecrib' VALUES (9827, '2017-05-07 00:47:51.424386+00', '2020-11-08 11:31:21.171805+00', 17733, 2, 160, 'ace', '1-8::

  1C 2C Set&Link ; 1C 3C Set&Link. (2 3 1)

9-16::

  Reel3 on sides - 1C pass 3C Rsh to begin.

17-24::

  3C 1C Poussette. (2 1 3)

25-32::

  1L 2C + 1M 3C RHA ; 1M 2C + 1L 3C LHA.', 3);
INSERT INTO 'dancecrib' VALUES (12884, '2020-06-08 21:29:14.764462+00', '2020-06-08 22:24:18.258267+00', 17399, 1, 1645, 'ace', '1-::
  1c set | cross RH ; 1c+2c set | turn RH into allemande hold, 1c facing up, 2c facing down
9-::
  1c & 2c curve L to line across, 1c facing down, 2c facing up | set ; 1c turn LH _while{4}_ 2c turn 1&frac12; LH to face P and own side
17-::
  LSh Reel4 across, end in promhold, 1c facing up, 2c facing down
25-::
  1c & 2c promenade round &frac34; clw ; turn &frac34; RH (2,1)
', 5);
INSERT INTO 'dancecrib' VALUES (14139, '2021-07-08 21:37:37.532481+00', '2021-07-08 21:58:39.741323+00', 20368, 1, 202, 'ace', '1--::

  1c turn RH | cast off (2c up) ; turn LH (2,1,3)

9--::

  2c+1W & 1M+3c RHA, pass P RSh ; 2c+1M & 1W+3c LHA (2,1,3)

17--::

  1c+2cnrs turn RH on sides ; 1c+1cnrs turn LH on sides (2,1,3)

25--::

  Circle6 and back.', 2);
INSERT INTO 'dancecrib' VALUES (8663, '2015-02-14 05:00:17.561008+00', '2015-02-14 05:00:17.561008+00', 2475, 1, NULL, 'ace', '*2c start on opposite side (1,2x,3)*

1--::

  All set | dance BtoB | set

9--::

  All M RHA ; All W LHA and face out

17--::

  All set in Triple Triangles (= NHJ in circle) | Invert (M to middle, W out) ; set as before | invert back 

25--::

  All set | change place RH ; All set | change place LH, finishing in circle facing in

33--::

  Circle6 and back (3,1x,2)

', 3);
INSERT INTO 'dancecrib' VALUES (3656, '2012-11-29 13:29:58.816059+00', '2013-07-29 21:06:01.776718+00', 13964, 2, 1, 'ace', '1–::

  1W (followed by 1M) casts, dances up, round 2M, to W side

  in 2pl (1M to M side) *while* 4M (followed by 4W) casts up,

  dances down, round 3W and to M side in 3pl (4W to W side)

  (3c+4c out on [7-8])

9–::

  2c+1c & 4c+3c dance LHA ; RHA

17–::

  Reels4 (RS) on sides, on [24] 1W+4W (also 1M+4M) join LH, 1M and 4W face out

25–::

  1c+4c dance En Rond (change on sides L | S to partners ; circle4 R)

', 3);
INSERT INTO 'dancecrib' VALUES (3492, '2012-01-22 19:30:27.707328+00', '2014-06-02 09:51:59.577069+00', 8829, 1, NULL, 'ace', '1–::

  1c set | 1W casts off below 2W, crosses, and casts up _while{6}_ 1M crosses, casts off round 2W and dances up the middle (to 1x,2)

9–::

  1c set to 2c and turn EH ½ (1c passing outside) ; 1c set to 2c | 1c cross up Rsh as 2c dance down into

17–::

  1c+2c Poussette

25–::

  2c+1c Circle4 and back', 3);
INSERT INTO 'dancecrib' VALUES (14500, '2022-01-01 19:37:39.713989+00', '2022-01-11 08:21:48.963926+00', 20579, 1, 202, 'ace', '1--::

  1c & 4c cast inwards (2c & 3c step out) | 1c+4c set ; 1c+4c RHA ½ pivoting R to face nearest cnrs | all set (2,4x,1x,3)

9--::

  Intersecting Reels4 (quick ½ LHA in the middle) and face nearest cnrs again (2,4x,1x,3)

17--::

  All set | turn cnrs EH middle couples through ends ; 4c & 1c ½ Fig8 through ends (2,4,1,3)

25--::

  4c+1c Poussette (2,4,1,3)



*Deviser''s note* : The  poussette  is  deliberately  symmetrical,  unlike  the  version  currently  described in  the  RSCDS  Manual  of  SCD.  Instead  of  forming  a  single  diagonal  line,  both couples  are  in  the  middle  of  the  set  at  the  end  of  bars  one,  four  and  seven,  one above  the  other.', 2);
INSERT INTO 'dancecrib' VALUES (8662, '2015-02-14 04:14:29.507855+00', '2015-02-14 04:37:20.123924+00', 16055, 1, NULL, 'ace', '1--::

  1c turn RH | cast (2c up) ; Turn RH to finish BtoB facing own side (2,1,3,4)

9--::

  Triangle figure (see below) 1c finish in middle facing own side

17--::

  1c set advancing and face in | 2c+1c+3c set ; 2c+1c+3c turn P RH (2,1,3,4)

25--::

  2c+1c+3c Circle6 and back (2,1,3,4)

33--::

  1c turn RH | cast (3c up) ; Turn RH and face out on own side 

41--::

  Second Figure (see below), finish (2,3,1,4)

49--::

  1c set | cast (4c up) ; All couples turn RH 

57--::

  Circle8 and back (2,3,4,1)



*The dance is 4 x 64, but two figures differ for each couple*



Triangle figure

  ::

    for 1c:  Double Triangles

  ::

  for 2c:  Inverted Double Triangles (Set, Invert, Set, Revert)

  ::

  for 3c:  Crown Triangles (clockwise)

  ::

  for 4c:  Crown Triangles (anti-clockwise)



Second Figure:

  ::

  for 1c:  Fig8 on side (M starts up / W down)

  ::

  for 2c:  3c+1c+4c Reels3 on the sides (M starts up / W down)

  ::

  for 3c:  1c cast round person on R | cross down/up to 3plx ; repeat back to 3pl

  ::

  for 4c:  1c Inveran Reel3 with 3c+4c (M starts up / W down)

', 3);
INSERT INTO 'dancecrib' VALUES (8713, '2015-03-07 23:58:46.786972+00', '2015-03-07 23:58:46.786972+00', 11500, 1, NULL, 'ace', '1--::

  1c cast (2c up) | cross RH ; cast behind 3c and lead up on opposite sides

9--::

  2c+1c RHA ; 1c+3c LHA, 1c finish facing 1cnr

17--::

  1c Set H&G, finish with pivot R to face out the end (W down, M up)

25--::

  1c cast R to 2plx and turn RH 1½ to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10028, '2017-07-24 03:34:46.718966+00', '2018-08-19 22:34:30.330069+00', 17897, 1, 202, 'ace', '1--::

 1c set | turn RH and face out ; cast one (2c up) | turn RH and face out (2,1,3)

9--::

 Reels3 on sidelines, 1c Rsh to 3cnr to start, 1c face 1cnr at end

17--::

 1c+1cnrs pass and turn , pass Rsh ; 1c+2cnrs pass and turn (2,1,3)

25--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (8664, '2015-02-14 12:12:25.322935+00', '2015-02-14 12:12:25.322935+00', 15037, 1, NULL, 'ace', '1--::

  All set | 1c+2c ½ RHA as 3c cross RH ; All chase clw half round (3,1,2)

9--::

  Reels3 across, 1c Rsh to 2cnr (pos), 1c finish at top NHJ and 3c in 2pl

17--::

  Mirror Reels3 on own side, 3c start in and down, touch hands when possible (1,3,2)

25--::

  Set&Rotate for 3 (2,3,1) [All set | all cast ¼ round clw ; all cross RH with opposite | all chase ¼ clw]

', 3);
INSERT INTO 'dancecrib' VALUES (9061, '2015-12-22 15:27:55.567933+00', '2015-12-22 15:27:55.567933+00', 14323, 2, 1, 'ace', '1–4::
  1M casts off behind men''s line, followed by 1L, 2L, 2M (dancing through each other''s places)
5–8::
  All pull back RS and retrace path back to original places
9–12::
  1C+2C RH across
13–16::
  1C lead down through 3C, cross, cast up [2,1x,3]
17–::
  Mirror Reels3 on sides (1C start up and in, 2C&3C start by casting)
25–28::
  1C lead up through 2C, cross, cast off [2,1,3]
29–32::
  1C+3C LH across', 3);
INSERT INTO 'dancecrib' VALUES (3018, '2012-01-22 19:30:07.088735+00', '2015-02-14 13:24:29.470354+00', 13479, 1, NULL, 'ace', '{{explanation}}

On 2nd chord, 3c+4c cross (to 1,2,3x,4x)



1–::

  1c+4c cross RH | cast to middle (2c+3c step to end) ; ½ R&L, W face out (2,4x,1,3x)

9–::

  2c+4c & 1c+3c M-Chain

17–::

  Reels4 on the sides, 4c+1c finish in the centre facing their corner

25–::

  4c+1c turn cnr RH | ½ LHA ; Turn new cnr RH | 1M+4W & 1W+4M turn LH ½ (to 2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (12470, '2020-01-02 22:53:10.423059+00', '2020-01-02 23:01:19.34714+00', 12799, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c Circle4 and back (1,2,3,4)

9--::

  1c+2c & 3c+4c R&L, finish in a circle of 8

17--::

  In circle: Set| Set adv. ; All cast clockwise ½ round into longwise set (4x,3x,2x,1x)

25--::

  3c+2c contine another ½ chase to (4x,2,3,1x) ; All set | 4c cross down LH 2 places (2c+3c up) _as_ 1c cross (2,3,4,1) 

', 3);
INSERT INTO 'dancecrib' VALUES (13104, '2020-08-12 21:45:12.680497+00', '2021-02-04 14:51:54.733914+00', 19930, 1, 202, 'ace', '1--::
  3c (2c & 1c following) dance down | set and face up ; dance up | Petronella turn to places (W RSh back, M LSh back (1,2,3)
9--::
  1c ½Fig8 and back same way (1,2,3)
17--::
  1c+2c Set&Rotate (2,1,3)
25--::
  Circle6 L {3}, cross R foot over and pivot L ; chase cclw (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12756, '2020-04-11 11:06:09.537237+00', '2020-04-12 08:08:35.948836+00', 19924, 1, 202, 'ace', '1--::
  All set | all W change places RH ; all W turn opposite M BH
9--::
  All set | all M change places LH ; all M turn P BH
17--::
  All RHA ; Circle4 L 1½ to original places
25--::
  All Gr-Chain, 2 bars per hand, start RH to opposite person', 2);
INSERT INTO 'dancecrib' VALUES (12831, '2020-05-15 07:29:08.41062+00', '2020-05-15 07:33:32.172478+00', 16289, 1, 202, 'ace', '1--::

  Mirror Reels3 on opposite sides, 1c crossing down (1x,2,3)

9--::

  1c ½ Fig8 down round 2c ; dance down between 3c (2c up) | cast up to face 1cnrs

17--::

  SetH&G. On [23-24] 1c set advancing, pulling RSh back 1M(1W) facing up(down)

25--::

  Reels3 on sides, 1c LSh to 3cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10352, '2017-12-22 23:58:07.951436+00', '2021-06-06 19:31:50.078056+00', 18145, 1, 202, 'ace', '1--::

  1c+2c the Knot, on [7-8] 1c pass P Lsh to BtoB facing own side

9--::

  DTr (2,1,3)

17--::

  Circle6 and back

25--::

  Reels3, 1c Rsh to 4cnrs to start (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1700, '2012-01-22 19:28:57.364878+00', '2020-05-15 10:06:23.600621+00', 313, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c S&Link ; 2c+1c & 4c+3c S&Link (1,2,3,4)

9–::

  1c & 3c ½ Fig8 round couple below ; 2c & 4c ½ Fig8 round couple above (1x,2x,3x,4x)

17–::

  All C set, facing ¼ L on second step | slip R to own side (2 slip steps) passing P BtoB, and pivot R to face P (PdB L foot) ; repeat back (1x,2x,3x,4x)

25–::

  1c cross RH and cast off to 4pl _while{4}_ 2c+3c+4c Turn RH ½ and face up | dance up to next place own side ; all couples Turn LH (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (1673, '2012-01-22 19:28:54.269817+00', '2021-02-18 15:23:14.513415+00', 9839, 1, NULL, 'ace', '1–::

  1M+2W cross RH, 1W+2M cross RH ; 2c+1c turn RH

9–::

  1M+2W cross LH, 1W+2M cross LH ; 1c+2c turn LH

17–::

  1c down the middle (2c up) ; and up to 2pl

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (1686, '2012-01-22 19:28:56.591896+00', '2014-09-18 09:18:01.168991+00', 3791, 1, NULL, 'ace', '1–::

  1c+3c DblFig8 round 2c, to begin 1c crosses down, 3c casts up

9–::

  1c+2c Poussette

17–::

  1c dance in and down one and face P (2c up) | set ; dance Rsh round 4cnr to face 1cnr

25–::

  SetH&G (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8274, '2014-05-31 21:16:26.435151+00', '2014-05-31 21:16:26.435151+00', 15456, 1, NULL, 'ace', '1--::

  1c turn ¾ RH moving down (2c up) | 6 bars of Crown Triangles, end facing 2cnr

9--::

  Rsh Reels3 on sidelines | turn LH to face 1cnr

17--::

  Cnrs Pass&Turn, end facing 1cnr

25--::

  Lsh Reels3{6} on sidelines | cross to (2,1,3)



', 2);
INSERT INTO 'dancecrib' VALUES (10351, '2017-12-22 23:47:26.377515+00', '2017-12-22 23:47:49.879775+00', 18144, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA (to 2x,1x,3,4) ; 1M+3W & 1W+3M set | 1/2 LHA (2x,3x,1,4)

9--::

  1c+4c set | ½ RHA (to 2x,3x,4x,1x) ; All turn P RH 1 ½ (2,3,4,1)

17--::

  1c slip up to top (2c+3c+4c down on [19-20]) ; 1c cast, dance behind own lines to 4pl (2c+3c+4c up on [23-24])

25--::

  Circle8 and back (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13779, '2021-03-02 09:53:43.887391+00', '2021-03-02 09:58:19.895289+00', 20237, 1, 202, 'ace', '1--::

  1c+2c Poussette (1,2,3)

9--::

  1c set | 1c dance down between 2c (2c up on [11-12]), out and behind 3c, meet P and dance up to 2pl centre. On [16] 2c & 3c step in (2,1,3)

17--::

  3C Allemande (3,1,2)

25--::

  ½ Mirror Reels3 on sides, 1c RSh to 3c ; all set | turn P BH (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (3140, '2012-01-22 19:30:13.012177+00', '2022-01-29 17:20:04.509411+00', 5688, 1, NULL, 'ace', '1–::

  1W+2M turn RH ½ to face each other | set ; turn LH back to places, set

9–::

  1M+2W repeat

17–::

  1c lead down the middle and up

25–::

  1c+2c Allemande

33–::

  2c+1c R&L.



{{explanation}}

Note: [1-2] and [9-10] now specify half turns, superseding older instructions.', 3);
INSERT INTO 'dancecrib' VALUES (9462, '2016-11-05 00:28:13.160678+00', '2016-11-13 00:02:05.45921+00', 17463, 1, NULL, 'ace', '1--::

  1c+2c S&Rotate and 1c face out (2,1,3),

9--::

  1c chase clw ½ round set as 2c+3c RHA (2,1x,3) ; 1c turn BH 1¼ into 2c+1W & 1M+3c in facing lines across

17--::

  All set advancing into line of 6 across, R shoulder to person opposite | All chase clockwise to 2c+1W & 1M+3c  in lines of 3 across (2c+3c now on opposite sides) | 2c+3c change places on sides RH _while{4}_ 1C turn BH ¾, ending in middle facing up, 1W on L

25--::

  1c dance to top and cast to 2plx (3x,1x,2x) ; All turn partner BH 1½ (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (3079, '2012-01-22 19:30:10.325027+00', '2016-11-14 13:17:43.04578+00', 10773, 1, NULL, 'ace', '1–::

  1c+2c DblFig8 (1c cross down, 2c dance up, no cast), at the end 2c face out

9–::

  Crossover Reels3 on the sides (1c cross down, 2c out and up), finish 1c side by side at top facing down, W on the R, 2c facing out

17–::

  1c (together) +2c Lead-change Reel3 across, Rsh to 2M.  2c finish in 1pl with 1c in between facing down

25–::

  1c dance down, cast up round 3c, lead up, cross between 2c and cast off (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8275, '2014-06-03 08:11:03.97985+00', '2014-06-03 08:11:03.97985+00', 6897, 1, NULL, 'ace', '1--::

  1c cast off, lead through 3c (2c up), cast up, turn LH

9--::

  1M+2M+3M & 1W+2W+3W RHA (1c pass Rsh) ; 1W+2M+3M & 1M+2W+3W RHA (same hand!), 1c finish facing 1cnr

17--::

  1c ½Reel4 with 1cnrs, pass Lsh, ½Reel4 with 2cnrs and face 3cnr

25--::

  1c turn 3cnrs (1cnr person) RH ½, corners turn LH 1½ (or ½) ; 1c turn cnr RH ½, 1c turn LH to face 4cnr (2cnr person) 

33--::

  Repeat with 2cnr persons, 1c finish the LH turn (2,1,3).



*Note: on [13], the description says “change places”, so 1c could also make a fast ½ LH turn into the other wheel)*

', 3);
INSERT INTO 'dancecrib' VALUES (8276, '2014-06-03 09:41:03.912668+00', '2014-06-03 09:41:03.912668+00', 8410, 1, NULL, 'ace', '1--::

  1c petronella to midline | set ; turn ¾ RH moving down to 2plx as 2c cast up on [7-8] (2,1x,3)

9--::

  1c petronella to midline | set ; turn LH 1½ to face 1cnr

17--::

  1c turn 1cnr RH | P LH ; 2cnr RH | pass P LH to finish 1W between 2c and 1M between 3c

25--::

  In lines of 3 across all dance down the middle ; and up, to finish (2,1,3)

33--::

  All turn RH ; All turn LH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9063, '2015-12-26 23:49:51.156912+00', '2015-12-26 23:49:51.156912+00', 1743, 1, NULL, 'ace', '1--::

  1c pass Rsh into 1W+2M & 1M+2W set | 1c (passing outside) turn 2c EH to (2,1x,3) ; 1c ½ Fig8 round 2c (2,1,3)

9--::

  1c pass Rsh into 1W+3M & 1M+3W set | 1c (passing inside) turn 3c EH to (2,3,1x) ; 1c ½ Fig8 round 3c (2,1,3)

17--::

  All set | 2c+3c cross RH as 1c Turn RH ¾ into facing lines across ; All set | 2c change places with 3c RH as 1c Turn LH to face 3cnr (pos)

25--::

  ½ Reel4 on 1diag. and 1c face 4cnr ; ½ Reel4 on 2diag., finish (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8432, '2014-10-31 15:03:50.765752+00', '2014-10-31 15:03:50.765752+00', 5797, 1, NULL, 'ace', '1--::

  Snowball Grand Chain, 1c cross to start (3,2x,4,1)

9--::

  Reels4 on the sidelines

17--::

  All set | 3c+2c & 4c+1c  6 bars of DblFig8, 2c & 1c cast up to begin (2,3,1x,4)

25--::

  1c cross and cast off (4c up) ; 1c Turn BH 1½ (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (1913, '2012-01-22 19:29:09.534439+00', '2020-05-15 14:59:38.873069+00', 11375, 1, NULL, 'ace', '1–::

  1c turn RH ; Turn LH

9–::

  1c+2c DblFig8 across, to start 1c cross down, 2c dance up

17–::

  1c+2c Turn P RH ¾ and face P up/dn holding RH | set ; dance to opposite sides & swivel R | set (1x,2x)

25–::

  »Spiral Progression« [1M+2W turn RH to join LH with P | BiL on 1diag , on 2nd PdB 1W+2M swivel L to face clw, NHJ with P ; line turns ¼ clw | »outers« (1W+2M) dance to next place _while{2}_ »inners« (1M+2W) continue turn to finish opposite P (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (12950, '2020-07-01 18:35:18.327356+00', '2020-07-02 09:05:18.08838+00', 205, 1, 202, 'ace', '1--::
  1c cross down RH to 2plx _while_ 2c cross down LH to 3plx _while_ 3c cast up to 1pl (to 3,1x,2x) | all set ; all repeat same pattern [1-4] (2x,3x,1)
9--::
  All repeat same pattern [1-4] (to 1,2,3) ; 1c+2c RHA (1,2,3)
17--::
  1c+2c The Knot (2,1,3)
25--::
  2c+1c LHA ; 1c+3c R&L one step per hand (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (13285, '2020-10-17 22:56:39.182803+00', '2020-12-27 12:31:58.80939+00', 14, 2, 35787, 'ace', '1-8::

  C1 set, cross RH; cast below 3s: cast up to 2d place (M1 face out, W1 face in).

9-16::

  C1 & C2 Ladies'' Chain.

17-24::

  C1 give RS to C3 for reels on the side.

25-32::

  C1 & C3 continue reel for 2 bars, C1 dance 1/2 fig-8 to 2d place on own side.', 0);
INSERT INTO 'dancecrib' VALUES (3688, '2013-01-22 13:39:18.615703+00', '2021-01-01 18:40:03.751751+00', 13709, 2, 1, 'ace', '1–4::

  1c turn R | cast off [2c up]

5–8::

  All S | 2c turn R ½ (keeping hands joined) _while_ 1c+3c+4c cross R

9–12::

  2c continue turning R to own sides | 2c+1c ½ RH across

13–16::

  1c+2c+3c chase clockwise halfway

17–::

  All Circle8 and back

25–28::

  2c+1c+4c [bottom 3] chase anticlockwise halfway

29–32::

  1c+2c ½ LH across [1c keep LH joined at end] | 1c turn L ½

', 3);
INSERT INTO 'dancecrib' VALUES (14443, '2021-11-08 00:02:09.877489+00', '2021-11-08 00:02:31.824414+00', 3014, 1, 1645, 'ace', '1--::

  1W & 4M, followed by P, cast inwards | cross to opp side (2c & 3c step out) ; 1c+4c LHA (2,1x,4x,3)

9--::

  1W & 4M, followed by P, cast to ends | cross to own side (2c & 3c step in) ; 1c+2c & 3c+4c LHA (1,2,3,4)

17--::

  2c+3c set twice ; 2c dance up as 3c dance down | cast off/up to original places

25--::

  1c cross RH | cast to 4pl (2c+3c+4c up) ; 1c turn 1&frac12; RH (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (14140, '2021-07-09 00:59:18.866481+00', '2021-07-09 01:06:47.237736+00', 20367, 1, 202, 'ace', '1--::

  1c cross RH | cast off 2 places (2c up) ; cross LH | cast up to 2pl (2,1,3)

9--::

  2c+1W & 1M+3c RHA, pass RSh ; 2c+1M & 1W+3c LHA (2,1,3)

17--::

  1c turn RH ; all Circle6 L ½ (3x,1x,2x)

25--::

  1c turn LH ; all Circle6 R ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8665, '2015-02-14 13:27:40.845753+00', '2015-02-14 13:40:42.770261+00', 16056, 1, NULL, 'ace', '1--::

  1c lead down crossing, cast behind 3c, lead up crossing and behind 2c to places (1,2,3) | All set

9--::

  “Chain rights & lefts” [1M+2W & 2M+3W change places RH | 1W+3W & 1M+3M change LH ; 2M+1W & 2W+3M change RH] | All set (3,2,1)

17--::

  2c+1c Tourbillon (3,1,2)

25--::

  All Circle6 L | All set (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (10350, '2017-12-22 23:18:14.25946+00', '2017-12-23 00:01:47.915729+00', 18142, 1, NULL, 'ace', '1--::

  All set | half-turn P and cast away | All set (1x,2x,3x)

9--::

  Reels3{6} on the sides (2c start out and up) | 1c curve in to finish into BtoB, facing 2c 

17--::

  1c+2c The Spurtle, 1c finish facing out (2,1x,3x) ; 1c+3c 1/2 DblFig8, 3c cross up to begin (2,1,3)

25--::

  Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3027, '2012-01-22 19:30:07.443801+00', '2015-02-15 15:06:48.423956+00', 5296, 1, NULL, 'ace', '1–::

  1c+3c cross RH | cast off (2c+4c up) ; lead down one, cast up one (2,1x,4,3x,5)

9–::

  2c+1c &4c+3c, ½ R&L ; 1c+2c & 3c+4c Petronella twice to next position cclw in their square (2,1x,4,3x,5)

17–::

  2c+1M & 1W+4c+3M & 3W+5c RHA to sidelines ; 2c+1W, 1M+4c+3W & 3M+5c LHA (to 2,1x,4,3x,5))

25–::

  1c+3c cross RH | cast off one place (4c+5c up) ; all turn P RH (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (9778, '2017-04-08 03:39:43.686809+00', '2018-07-11 17:49:24.013842+00', 15278, 1, 202, 'ace', '1-- ::
 1c ½ Fig8 with 2c ; 1c ½ Fig8 with 3c to 2pl (2c up)
9-- ::
 1c cross LH | cast L to between end couples ; turn RH 1 ¼ to face 1cnrs
17-- ::
 1c Cnrs Pass&Turn (2,1,3)
25-- ::
 Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (3682, '2013-01-18 14:32:42.335377+00', '2019-03-18 15:57:41.826967+00', 1251, 2, 1, 'ace', '1–::

  Circle8 & back (retain hds at sides)

9–::

  »The Crescent«: Retaining hds, 4W leads other W up M''s side

  _while_ 4M leads other M up W''s side (going outside W''s crescent) ;

  all S | all ½ turn R to finish in the middle facing up

17–::

  Allemande (4 couples)

25–::

  »The Doorways and Gateways«: 1W+2W & 3W+4W join NH, dance across

  between ptrs, cast behind ptrs and back to places ; 1M+2M & 3M+4M R

  going outside ptrs to begin [on 32, 1M&3M turn R about, 2M&4M L about]

33–::

  1c cross R ; cast off [2c up] | 1c cross down L [3c up] ; 1c cast off

  round 4c [4c up]', 3);
INSERT INTO 'dancecrib' VALUES (3683, '2013-01-18 14:38:04.317846+00', '2019-08-18 17:04:11.001714+00', 8068, 2, 1, 'ace', '1–::

  All S | cross R ; S | ½turn ptr R to finish in ctr facing up

9–::

  Promenade (3 couples)

17–::

  1c cross R | cast off 2pl [2+3 up] ; dance ½ fig 8 round 3c [231]

25–::

  Circle6 & back', 3);
INSERT INTO 'dancecrib' VALUES (15438, '2023-02-04 15:59:56.053868+00', '2023-02-04 16:08:34.855949+00', 4572, 1, 202, 'ace', '1--::

  1c (1W leading) cast off | cross to 2plx (2c up) ; 1c (1M leading) cast off | cross to 3pl (3c up) (2,1,3)

9--::

  1c set | dance up to 2pl centre (3c down) ; all M LHA _while{4}_ all W RHA

17--::

  1c (3c+2c following) dance up, cross and cast off (to 2x,3x,1x) ; 2c+1c 4 bars of DblFig8, 1c crossing up (2,3x,1)

25--::

  3c+1c 4 bars of DblFig8, 1c crossing up (to 2,3,1x) ; 1c ½ Fig8 up round 3c (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3042, '2012-01-22 19:30:08.051682+00', '2020-05-15 10:28:55.33198+00', 5347, 1, NULL, 'ace', '1–::

  1c cast off one (2c up) | turn BH ; 2c repeat (1c up) (1,2,3)

9–::

  1c clap and cast off (2c up) | 2c+1c cross RH ; 2c+1c ½R&L, but with full LH turn on the sides (2,1,3)

17–::

  2c+1c RHA ; 1c+3c LHA

25–::

  2c+1c+3c G-Chain (2c cross to start) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1674, '2012-01-22 19:28:54.361096+00', '2020-05-15 15:03:40.563542+00', 218, 1, NULL, 'ace', '1–::

  1c+2c+3c circle6 and back

9-14::

  1W+2W+3W A&R ; set _while{6}_ 1M+2M+3M set | A&R

15-16::

  1c+2c+3c cross RH (1x,2x,3x)

17–::

  1c+2c set, 1c cross LH down to 2pl _while{2}_ 2c cast up ; 2c+1c+3c ½Reels3 on the sides, 1W going down, 1M up, finish passing Lsh to face 1cnr positions

25–::

  ½Reel4 with 1cnrs ; 1c meet in centre and twirl Rsh back to face 4cnr position ; ½Reel4 with 4cnrs, finish (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8806, '2015-06-25 21:49:30.596204+00', '2015-06-25 21:49:30.596204+00', 16462, 1, NULL, 'ace', '1--::

  All set | All cast Rsh back into facing lines across ; All change place RH with P | All chase clw ¼ and 1M faces out (3,2,1) (Set&Rotate for 3 couples)

9-12::

  1M+1W following cast up behind M line (2c down) , and cast in (1M round 3M, 1W round 2M) into lines across facing down 

13-24::

  3c+1M & 2c+1W dance down in lines across, all pivot R ; and up, at end 1M pivots R ; 1c turn RH 1¼ to face 1cnr

25--::

  1c Cnr Pass and turn with 1cnrs, pass Rsh ; with 2cnrs, pass Rsh to (3,1,2)

33--::

  Circle6 and back.

', 3);
INSERT INTO 'dancecrib' VALUES (1675, '2012-01-22 19:28:54.404438+00', '2020-05-15 15:15:11.380202+00', 219, 1, NULL, 'ace', '1–::

  1c+2c set | circle4 | 1M+2M & 1W+2W turn BH to finish BtoB with P _while{2}_ 3c step up to between 1pl and 2pl

9-14::

  All M LHA _while{4}_ all W RHA ; on meeting 1c dance up in promhold and cast to M side, turning LH to 1W below 1M, 2c likewise to W side, 2M below 2W , 3c to top

15-16::

  1c turn LH ½ (1M to 2pl and 1W to 3pl) _while{2}_ 2c turn RH ½ (2M to 3pl and 2W to 2pl) _while{2}_ 3c in 1pl turn RH ½ (3W polite turn) and all face »cnr« in the circle

17–::

  All set to cnr | turn BH and open into ; ½ circle6 (to sidelines, 1c on W side, 2c on M side, 3c in 3pl)

25–::

  1c+2c half L-Chain ; 2c+1c+3c turn BH, 1c turning 1½ times (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12480, '2020-01-05 07:50:49.631835+00', '2020-01-05 07:54:45.01393+00', 14517, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; turn P LH 1¾ to 2pl centre (2,*1*,3)

9--::

  Reels3 on sides, 1c LSh to 3cnrs (2,1,3)

17--::

  Reels3 across, 1c RSh to 2cnrs (2,1,3)

25--::

  3C »Threadneedle« R&L [: 2c+3c R&L _while{8}_ 1c cross RH | dance RSh round 1cnrs[pos] ; cross LH up/down | dance LSh round 3cnrs[pos]] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2879, '2012-01-22 19:30:01.295267+00', '2020-05-15 16:52:51.624951+00', 4796, 1, NULL, 'ace', '1–::

  1c+3c advance | turn person opposite RH into ; RHA with adjacent side couple (2c or 4c)

9–::

  In rows across parallel Reels4, finish 2c+4c in own places, the pairs facing them

17–::

  All set | pairs (NHJ) dance out, split, and cast to meet P in own place _while{4}_ 2c+4c split to dance in, meet and join NH, dance to places | all C turn BH

25–::

  All circle8 left ½ round ; turn P RH to promhold (W inside) | Promenade 1 place clw (2,3,4,1).', 2);
INSERT INTO 'dancecrib' VALUES (13540, '2021-01-09 21:49:49.761983+00', '2021-01-09 21:49:49.761983+00', 11720, 3, NULL, 'ace', '1-8::

  1s+2s set, 1/2 turn LH into 1/2 LH across, 2s+1s set. 2 1 3

9-16::

  1s dance Fig 8 on sides (start up, LSh to 2s)

17-24::

  1s+3s set, 1/2 turn RH into 1/2 RH across, 3s+1s set

25-32::

  3s+1s dance RH across; 2s+3s dance LH across. End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (3414, '2012-01-22 19:30:24.413624+00', '2020-06-09 14:41:56.025454+00', 8110, 1, NULL, 'ace', '1–::

  1c 1½ RH turn ; cast to 2pl (2c up), turn LH to face 1cnrs

9–::

  ½Reel4 with 1cnrs, pass Lsh,  ½Reel4 with 2cnrs, ending facing 1cnrs (in 3cnr position)

17–::

  1c set to and turn 1cnr (persons) ; set to and turn 2cnr (persons), finish facing 1cnr (persons)

25–::

  Reels3{6} on the sides, Lsh to 1cnrs | 1c cross RH to (3x,1x,2x) opposite side

33–::

  3c+1c+2c ½ circle6 left ; all turn P RH

', 2);
INSERT INTO 'dancecrib' VALUES (3552, '2012-01-22 19:30:30.673666+00', '2021-02-05 12:48:48.872641+00', 10776, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; 2c+1W & 1M+3c RHA, 1c face 1cnr

9–::

  1c+1cnrs diagonal Reel4, on [15-16] 1c turn RH to face M up W down

17–::

  1c dance Rsh round 2cnr into ; 2c+1M & 1W+3c RHA, 1c face 2cnr

25–::

  1c+2cnrs Diagonal Reel4, to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8019, '2013-08-26 21:06:40.420942+00', '2013-08-27 06:21:42.611087+00', 10649, 2, NULL, 'ace', '1-4::

  L1 turn L2 LH 1½ on the sideline and M1 turn M2 RH 1½ on the sideline 

5-8::

  L1 turn L3 RH 1½ on the sideline and M1 turn M3 LH 1½ on the sideline 

9-12::

  1st cpl dance up 2 places and cast down 1 place (2 1 3) 

13-16::

  All dance DoSiDo with partner 

17-20::

  L1 dance RA with 2s and M1 dance RA with 3s, 1s pass RSh to 

21-24::

  L1 dance LA with 3s and M1 dance LA with 2s 

25-32::

  1s dance ½ fig. of eight round 3s, 1s dance ½ fig. of eight round 2s.', 0);
INSERT INTO 'dancecrib' VALUES (8285, '2014-06-16 15:44:19.281662+00', '2014-06-23 08:01:20.021982+00', 15470, 1, NULL, 'ace', '1--::

  1c+2c Chain Progression (turn RH ¾ | middles turn LH 1½ as outsides chase ½ clw | 2c+1c turn RH ¾) and 1c face out (2,1,3)

9--::

  1c cast R round 3cnr and meet | turn RH 1½ and twirl R into DTr positon, 1W facing up

17--::

  DTr, but at end 1c pivot R (1W full turn) to face down NHJ, 1M on L.

25--::

  1c dance down the middle{3}, change sides, W passing above M and under joined arms {2}, and up (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8709, '2015-03-04 22:14:07.426915+00', '2015-03-08 08:53:03.415808+00', 16154, 1, NULL, 'ace', '*All form a big circle facing in, M with P on their R*

1--::

  All W fig8, Lsh round P ; Rsh round cnr

9--::

  All M fig8, Rsh round P ; Lsh round cnr

17--::

  All Gr-Chain, 2 bars per hand, start RH to P

25--::

  M joins 5th W in promhold and promenade cclw, finish facing in (M turns W under his arm)



*continue with new P.*

', 5);
INSERT INTO 'dancecrib' VALUES (11226, '2018-10-01 00:09:45.800469+00', '2018-10-01 00:17:26.811955+00', 9443, 1, 202, 'ace', '1--::

  1c set | cross RH ; cast (2c up) | all turn P RH ½, face P (2x,1,3x)

9--:: 

  All cast away to exchanged places and Circle6 L ½ (to 3,1x,2) | 1c turn RH to face 2cnrs

17--::

  Corners Pass and Turn on 2diag. On [20] 1c turn P RH to face 1cnrs ; Corners Pass and Turn on 1diag to 2pl (3,1,2)

25--::

  3C Knot (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3861, '2013-07-20 20:24:46.661873+00', '2014-07-23 17:56:50.911433+00', 3337, 1, NULL, 'ace', '{{explanation}}

C face C RR, 1c facing clw



1–::

  RHA ; LHA

9–::

  1c fig8 round 2c

17–::

  2c fig8 round 1c

25–::

  All Advance and Hooch | Retire ; &R ; Turn person opposite RH 1½ to meet next cpl', 3);
INSERT INTO 'dancecrib' VALUES (3135, '2012-01-22 19:30:12.785652+00', '2014-08-24 09:46:06.498793+00', 8576, 1, NULL, 'ace', '1--::

  1c+2c lead down | lead up ; 1c cast off as 2c leads up and casts into 1pl | 2c+1c cross RH (2x,1x)

9--::

  2c+1c set passing P Lsh and twirl R to face P, turn BH to own side facing other cpl ; repeat up/dn along sidelines (to 1,2)

17--::

  1c+2c circle4 L ; ½Poussette (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (3109, '2012-01-22 19:30:11.66395+00', '2014-07-01 08:30:43.410824+00', 5576, 1, NULL, 'ace', '1–::

  1c, with 2c following (dance up first), cast off behind own lines ; turn inwards and dance up to places, 2c leading and curving down through 1pl to 2pl facing out)

9–::

  1c+2c DblFig8, 2c finish facing out to curve up for

17–::

  1c, with 2c following, lead down the middle (2c divide to let 1c lead) and up

25–::

  1c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (8714, '2015-03-08 23:16:51.633608+00', '2015-03-08 23:16:51.633608+00', 13557, 1, NULL, 'ace', '1--::

  1c+2c S&Link (1M faces out) ; 1M, 1W following, cast up and down the midline

9--::

  1W+2c & 1M+3c Rsh Reels3 across

17--::

  1W+2M & 1M+3M turn RH ; 1W+2W & 1M+3W turn LH

25--::

  1M, 1W following, casts up on M side and crosses to 2plx : 1c turn RH 1½ (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9776, '2017-04-07 23:58:50.385084+00', '2017-10-04 22:07:09.634868+00', 15276, 1, 202, 'ace', '1-- ::

  1c+2c Circle4 R ; 1c set | cast to 2pl (2c up) (2,1,3)

9-- ::

  1c lead down ; 1c lead up, dance behind 3c to 2pl

17-- ::

  1c turn 1cnrs RH, pass P Rsh ; turn 2 cnrs RH, pass P Rsh to finish 1W between 2c facing up and 1M between 3c facing down

25-- ::

  1c cast R to 2pl | 2c+1c+3c set ; 1c+3c Circle4 L



*Note. At end, 1c+3c (now 2c) retain hands ready to start Circle4 R*', 2);
INSERT INTO 'dancecrib' VALUES (8286, '2014-06-22 20:20:45.066225+00', '2016-09-19 00:36:20.486026+00', 15480, 2, 1, 'ace', '1–::

  1c turn BH | dance down ; turn BH | dance up (2c come in)

9–::

  1c+2c allemande

17–20::

  1M+3M turn RH _while_ 1W+3W turn LH

21–24::

  1c+3c set & link

25–::

  Circle (6H) round and back', 5);
INSERT INTO 'dancecrib' VALUES (3184, '2012-01-22 19:30:14.829892+00', '2016-05-19 10:11:09.595787+00', 7520, 1, NULL, 'ace', '1–::

  2c+4c RHA ; lead out between end couples and cast back to face 1cnrs

9–::

  2c+4c cnrs pass and turn (change places Rsh with 1cnrs, who turn RH, change back, pass P Lsh and repeat with 2cnrs), finish with wide curve to midline facing P with M below W

17–::

  Reel4 on the centre line, to own places

25–::

  2c+3c+4c+5c set | 2c+4c cast off one _while{2}_ 3c+5c dance up one (touch NH) ; 1c+2c turn RH and cast off one (3c+5c up). (to 3,1,5,2,4)



{{explanation}}

Note: In »corners pass and turn«, 1c normally pass Rsh on [4]; for this dance the instructions explicitly specify Lsh', 3);
INSERT INTO 'dancecrib' VALUES (9260, '2016-07-10 12:55:08.94595+00', '2016-07-23 19:39:52.856853+00', 17135, 2, 1, 'ace', '1–::

  1c cross R | 1c+2c ½turn “obvious” H ;

  2c+1c ½ double fig 8 (2c dance out&down, 1c cross up) [to 213]

9–::

  Mirror reels of 3 on sides (1c in and down; give NH where possible)

17–20::

  1c+3c dance round clockwise towards centre, pull RS back to twirl,

  and dance out to fin diag opp from starting posn [2x,3x,1x]

21–24::

  All set | all ½turn BH to own sides [231]

25–::

  3c+1c dance Rose progression [to 213]', 3);
INSERT INTO 'dancecrib' VALUES (1726, '2012-01-22 19:28:58.619172+00', '2020-10-18 09:52:36.977446+00', 9170, 1, NULL, 'ace', '1–::

  All C set | turn BH ; Turn BH | Set

9–::

  Teapots R ; Teapots L [2c+4c RHA with C on R (RHA with 3, 4, 3 hands) ; LHA with C on L (3,4,3, hands)]

17–::

  1c+3c Fig8 round C below, finish on diagonals, 1c with 2c and 3c with 4c for

25–::

  1c+2c & 3c+4c half Poussette (5c step in on [28]) (2,1,4,3,5) ; 1c+4c & 3c+5c half poussette (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (8861, '2015-08-24 20:06:47.234338+00', '2015-08-25 08:41:30.437031+00', 3524, 1, NULL, 'ace', '*4C longways set, Gl.H. positions (1c+3c on M side face 2c+4c on W side)*



*Part 1  Reel*

1--::  1c+2c & 3c+4c R&L, starting RH to P, along sideline

9-12::  1W+2M+3W+4M (the middle dancers) dance on out, cast round P, lead RHJ into the middle

13-20::  1W+2M+3W+4M RHA, LHA, finish facing P

21-24::  All set to P | Turn P RH 

25--::  1c+3c & 2c+4c Reels4 on the sideline, finish in original positions



*Part 2  Strathspey*

33--::  Gr. Chain, finish in square set in diagonal orientation, 1M+2W are nearest to the “top”.

41--::  1c+4c Rsh Reel4, M pass Lsh to start, and finish facing each other in the centre

49--::  1M+4M set H.Schottische ; Turn RH | dance round P Rsh to place

57--::  Circle8 and back



*Part 3  Strathspey*

65-96::  Repeat Part 2, with 2c+3c dancing the middle 32 bars.  Finish in lines across, 2c+1c (above) facing 4c+3c (below)



*Part 4  Reel*

97-128::  Repeat Part 1 from new positions.  Finish facing P and bow.

', 3);
INSERT INTO 'dancecrib' VALUES (3699, '2013-02-06 00:34:29.22771+00', '2015-02-14 14:35:22.828342+00', 14711, 1, NULL, 'ace', '1–::

  1c+2c the Knot, 1c turning on to face 1cnr

9–::

  Cnrs pass and turn (with 1cnrs, pass Rsh, with 2cnrs) (to 2,1,3)

17–::

  All set | cross RH ; Circle6 ¾ clw into facing lines across

25–::

  All set | cross up/down LH ; Circle6 ¾ cclw (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8250, '2014-04-24 11:29:01.729391+00', '2014-07-14 20:06:50.691307+00', 14183, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; ½ Fig8 through 3c to face 1cnrs

9–::

  1c set to 1cnr | dance Rsh round P to face 2cnr ; ½ Reel4 and face 4cnr

17–::

  1c set to 4cnr | dance Rsh round P to face 1cnr ; ½ Reel4 passing Rsh to face out in 2pl (3x,1,2x)

25–::

  1c cast L as 2cnrs cross RH, 1c turn 2cnr LH ½ ;1c cast R as 1cnrs cross LH, 1c turn 1cnr RH ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8020, '2013-08-27 14:58:43.546508+00', '2021-03-22 15:34:43.795057+00', 8067, 2, 1, 'ace', '1–::

    1c+2c RH across & LH back

9–::

    1c lead down the middle and up

17–::

    1c cast off (2c up on 3–4); 1c dance down below 3c | cast up to 2pl

25–32::

    2c+1c Rights & Lefts', 3);
INSERT INTO 'dancecrib' VALUES (14597, '2022-02-05 02:22:06.243053+00', '2023-02-04 01:23:04.029287+00', 18516, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place (2s & 3s step up/down); 1s & 4s
    dance 1/2 Fig 8 round 2s/3s
9-16::
    2s+1s also 4s+3s dance RH across; 1s+4s (middle couples) dance 1/2
    LH across to face corners  on sides & set to corners. 2 (4) (1) 3
17-24::
    All dance reels of 4 on sides
25-32::
    1s & 4s dance DoSiDo with corners & face partner across set; 4s+1s
    turn partner 1.1/2 RH to own side. 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12471, '2020-01-03 21:40:42.319503+00', '2020-01-04 22:24:13.134318+00', 15239, 1, NULL, 'ace', '1--::

  1c+4c set | cross (no hands) inwards and face out (2c+3c step to ends) (2,1x,4x,3) ; 1c+4c cast to own end, join RH with P and dance in to meet

9--::

  1c+4c RHA and face nearest cnr _while{4}_ 2c+3c chase cclw ½ round ; 1c+4c turn cnr LH, pass Lsh in middle, finish BtoB facing opp. cnr (order 3x,1,4,2x)

17--::

  2c +3c intersecting diag. Reels4 with LHA in the middle _while{8}_ 1c+4c dance Rsh round their cnr, pass Lsh in middle to face the next cnr (one place cclw), dance Rsh round that cnr to finish 1W (top) & 4M (bottom) between end cpls and 4W+1M on middle of own sideline

25--::

  1c+4c set adv | ½ RHA (3x,1x,4x,2x) ; All set and cross RH (3,1,4,2)







', 4);
INSERT INTO 'dancecrib' VALUES (8666, '2015-02-14 15:13:51.740907+00', '2015-02-14 15:15:50.077951+00', 16061, 1, NULL, 'ace', '1--::

  All Circle 6 and back

9--::

  Middles with persons on their R RHA ; with persons on their L LHA

17--::

  Middles turn person on R RH 1½ ; New Middles turn person on L LH 1½

25--::

  All turn opposite RH 1½ to meet new trio.

', 3);
INSERT INTO 'dancecrib' VALUES (3837, '2013-07-13 15:56:18.853008+00', '2014-06-26 20:06:35.409372+00', 14649, 1, NULL, 'ace', '1–::

  1c cross between 3c and cast up (2c up) ; ½Fig8 L (W up, M down)  (2,1,3)

9–::

  All cross RH | chase clw ¼ to lines across ; All cross up/dn RH | chase clw ¼ (3x,1x,2x)

17–::

  Chain R&L (mid dancers change place RH with cnrs diagonally R | new mid dancers repeat LH with cnrs to L ; repeat to the R (2x,1x,3x) | 2c Cross RH _while{2}_ 1c+3c turn RH ½ into

25–::

  1c+3c Allemande (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3784, '2013-07-13 15:56:05.684794+00', '2018-04-26 22:51:03.53705+00', 12674, 1, NULL, 'ace', '1–::

  1c+2c & 4c+5c RHA ; LHA

9–::

  2c+3c+4c A&R ; Turn P RH

17–::

  1c dance between 2c, behind 3c, between 4c, behind 5c (who step up as 1c passes)

25–::

  Circle10 and back', 2);
INSERT INTO 'dancecrib' VALUES (8294, '2014-07-02 19:57:42.356266+00', '2014-07-02 19:59:35.304433+00', 15526, 1, NULL, 'ace', '1--::

  Gr-chain, 1 bar/hand

9--::

  All TurnR ¾ | All M chase one place clw _while{2}_ all W ½ LHA ; All pairs turn RH ½ | All W chase one place clw _while{2}_ all M ½ LHA, All M finish BtoB facing P (2,3,4,1)

17--::

  All set Highland ; All cpls Tulloch turn (2,3,4,1

25--::

  All circle L ½, dance into middle, pivot R and dance clw to (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8292, '2014-06-29 05:27:49.128983+00', '2014-06-29 12:00:17.725418+00', 15494, 1, NULL, 'ace', '1--::

  1c cross | cast (2c up) ; turn LH to face 1cnr

9--::

  1c+1cnrs Corners Pass and Turn ; 1c+2cnrs repeat, 1c finish in 2plx BtoB facing opposite side (DTr position, no hands)

17--::

  All set | 2c+3c cast 1 place clw round the square _while{2}_ 1c dance as in DTr to face own side ; repeat , 1c finishing facing 1cnr position (3cnr person) 

25--::

  1c+1cnrs ½ diag. Reel4, 1c pass P Lsh ; 1c+2cnrs ½ diag. Reel4 (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8667, '2015-02-14 15:27:44.486146+00', '2015-02-14 15:27:44.486146+00', 16062, 1, NULL, 'ace', '*Couple face couple RR*

1--::

  Circle4 and back 

9--::

  RHA ; LHA

17--::

  L-Chain

25--::

  A&R ; Turn opposite 1½ to meet next couple



Repeats: 1) Walking  2) Walking Strongly  3) Lilting Run  4) Running

', 3);
INSERT INTO 'dancecrib' VALUES (9496, '2016-11-14 15:50:00.576369+00', '2016-11-14 15:50:00.576369+00', 12457, 1, NULL, 'ace', '1--::

  1c+3c turn P RH ¾ | set ; 1c+3c Turn P RH (2c+4c up on [7-8])

9--::

  1W+3M chase clw ½ round while{4} 2c+1M & 3W+4c RHA ; 1c+3c ½ Reel4 on midline

17--::

  1W+3M chase clw ½ round while{4} 2c+3W & 1M+4c RHA ; 1c+3c ½ Reel4 on midline

25--::

  1c+3c turn P RH ¾ and 1c face 3c | All set ; 1c+3c ½ RHA | 3c+1c dance to (2,3,4,1)| 

', 2);
INSERT INTO 'dancecrib' VALUES (8291, '2014-06-27 23:29:53.851114+00', '2017-06-09 23:55:42.747044+00', 14724, 2, 2007, 'ace', '1-4 :: 1C set & cross over RH.



5-8 :: 1C dance half fig. 8 round 2C (cross down to begin).



9-16 :: 1C lead down and up. 2C & 3C step in on last bar ready for Allemande.



17-24 :: 1C, 2C, 3C Allemande



25-28 :: 3C cast to original place WHILE 2C & 1C dance up one place (taking nearer hands briefly).  All set.



29-32 :: All turn partner RH once round.', 0);
INSERT INTO 'dancecrib' VALUES (3220, '2012-01-22 19:30:16.234417+00', '2019-02-02 15:34:19.100765+00', 5936, 1, NULL, 'ace', '1–::

  All Rsh Reels3 on sidelines (2c starts up)

9–::

  1M+2M & 1W+2W turn RH 1½ on sidelines ; 1M followed by 1W cast out M side to top and down the middle

17–::

  1W+2c & 1M+3c in lines across dance down the middle (all swivel R) and up (top line swivel R)

25–::

  set in lines across | 1c petronella to 2plx _while_ 2c+3c set ; all set | 1c cross RH', 2);
INSERT INTO 'dancecrib' VALUES (10054, '2017-08-30 13:24:59.264549+00', '2017-09-10 09:02:38.471405+00', 17780, 1, NULL, 'ace', '*Big Circle, Man has Woman on his R*



1--::

  All W ½ Fig8 L (in front of P, behind next M and face him) ; Change place RH | Change place with P LH, all M face out

9--::

  All M ½ Fig8 L (behind P, in front of next W and face her) ; Change place RH | Change place with P LH, all face in

17--::

  All W A&R ; All M A&R

25--::

  All S&Link with P ; turn P RH and meet new P.

', 3);
INSERT INTO 'dancecrib' VALUES (8290, '2014-06-25 11:11:46.712017+00', '2016-09-16 18:43:32.089938+00', 8987, 1, NULL, 'ace', '*Four dancers stand in a square, ‘1’ at the top, ‘5’ in the middle facing ’1’.*

1--::

  ‘5’ Rsh Fig8 round ''1'' and ''3''

9--::

  ‘5’ Reel3 across with ‘4’ + ‘2’, Lsh to ‘4’ 

17--::

  ‘5’ turn ‘1’ RH ; ‘5’ turn ‘3’ LH 1½ putting ‘3’ into the middle

25--::

  ‘3’ sets alone _while{4}_ the “outsides” chase 1 place cclw and set facing in; “outsides” advance to centre and retire (2,5,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8668, '2015-02-15 00:07:17.471542+00', '2015-02-15 07:54:20.084787+00', 8334, 1, NULL, 'ace', '1--::

  1c+2c set | cross RH ; set | petronella to midline facing P (M above W)

9--::

  1c+2c ½ Reel4 on midline ; turn P RH 1¼ to sidelines (2,1,3)

17--::

  1c+3c R&L

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8796, '2015-06-19 22:27:36.450626+00', '2015-06-26 20:59:34.915283+00', 16461, 1, NULL, 'ace', '*5c in centre face P, 5M/5W have backs to 4c/2c*



1-::

  1c(promhold) + 5c (Pass P Rsh and face R) + 3c(promhold) ½ Reel4 ; 5c pass Rsh into 2c(promhold) +5M+5W +4c(promhold) ½ Reel4 (3,4,1,2,5)

9-::

  “Teapot Chain”: Middles with head couples (5W+1c & 5M+3c) RHA 2/3 _while{2}_ 2c+4c turn RH ½ | New middles (1W+3W) turn LH ¾ _while{2}_ all outsides turn the next person LH ½ ; Middles with side pairs (1W+3M+5W & 3W+1M+5M) RHA 2/3 _while{2}_ top and bottom pairs turn RH ½ | New middles (5c) turn LH ¾ _while{2}_ outsides turn the next person LH ½ (to 1,2,3,4,5) with 5c facing 4c, all couples in promhold

17-::

  5c+4c change places Rsh | 4c+3c repeat _while_ 5c set ; 3c+2c repeat _while_ 5c+4c set | 2c+1c repeat _while_ 5c+4c+3c set (2,3,4,5,1), 1c finish facing P across, just as 5c started

25-::

  Outside couples Circle8 and back _while{8}_ 1c set | turn RH ½ ; repeat (2,3,4,5,1)

', 5);
INSERT INTO 'dancecrib' VALUES (3077, '2012-01-22 19:30:09.702383+00', '2014-08-24 12:18:25.082847+00', 5463, 1, NULL, 'ace', '1–::

  1c+2c+3c dance Rsh Reels3 on own sides (1,2,3)

9–::

  1c lead down the middle and up

17–::

  1c+2c Allemande, 1c finish facing 1cnrs

25–::

  1c turn 1cnr, P, 2cnr, pass Rsh to finish BtoB facing own side

33–::

  DTr, finish (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8669, '2015-02-15 08:16:54.233528+00', '2015-02-17 11:29:47.747598+00', 16067, 1, NULL, 'ace', '1--::

  1c+4c set | cast inwards (2c+3c step to end) ; 1c+4c ½ R&L (2,4x,1x,3)

9--::

  2c+3c repeat (4x,3x,2x,1x)

17--::

  Half Reels4 on the sides ; All dance BtoB (1x,2x,3x,4x)

25--::

  1c set | 1c+2c ½ RHA ; 1c+3c ½ LHA | 1c+4c ½ RHA (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9064, '2015-12-27 14:29:12.221337+00', '2015-12-27 14:34:12.157934+00', 14719, 1, NULL, 'ace', '1--::

  1c+2c Chain progression (Turn P RH ¾ | middles turn 1 ½ LH as outers chase clw ½ | turn P RH ¾) (2,1,3)

9--::

  1c ½ Fig8 L to 2plx facing 1cnr ; turn 1cnr LH 1¼ to finish BtoB facing 1cnr

17--::

  All set | 1c cast to cnr position behind them _while{2}_ 1cnrs chase 1 place clw _while{2}_ 2cnrs dance in and pivot R to face the position they left ; repeat figure on 2diag. (all set | middles to corner behind, 2diag corners chase, free corners (=1c) to middle facing 3cnr).  

25--::

  on 1diag ½ Reel4, pass Rsh ; ½ Reel4 on 2diag, 1c finish BtoB facing own side

33--::

  2c+3c chase clw ½ _while{4}_ 1c set and cast behind to 2plx ; All set and cross RH (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (9780, '2017-04-08 07:55:14.99349+00', '2017-08-26 10:11:42.135+00', 15280, 1, 202, 'ace', '1--::

 1c set | dance down one in centre (2c up) ; retaining hands and facing P, 1c set | set again, 1W pulling back Rsh to turn under P L arm, retiring to sidelines (2,1x,3)

9--::

 1c+3c R&L, 1c finishing facing 1cnrs

17--::

 1c SetH&G (2,1,3)

25--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10586, '2018-04-06 21:02:12.336251+00', '2020-06-09 22:07:23.300346+00', 707, 2, 1, 'ace', '1–:: All set | 1c&3c&5c cast off ; set | petronella to a line down the centre

    _while{6}_ 2c&4c&6c&7c ½ turn R (2c&4c&6c moving up a place) ; pull RS

    back and cast out [to opp sides] | set

9–:: 1c&3c&5c dance ½ Reel6 [fin 531, M facing down, L facing up] | turn RH

    to fin facing 3crnr posns

17–:: 5c&3c&1c ½ diag Reel4s w/3rd crnr posns, pass RS | ½ diag Reel4s w/4th

    corner posns [fin in 2c,4c,6c''s pl, own sides]

25–:: 5c&3c&1c ½ diag R&L w/1st crnr posns | ½ diag R&L w/2nd crnr posns

    [fin 7563412]', 3);
INSERT INTO 'dancecrib' VALUES (9783, '2017-04-08 10:29:43.766938+00', '2017-08-26 12:23:19.240166+00', 15284, 1, 202, 'ace', '1--::

 All cross RH | set ; cross LH | set (1,2,3)

9--::

 1c turn RH | cast (2c up) ; cross LH | cast L finishing BtoB in centre facing opp. sides

17--::

 1c+2c+3c set as in Dtr | 1c+1cnrs turn RH ; repeat [17-18] | 1c+2cnrs turn LH to finish 1M between 2c and 1W between 3c

25--::

 Reels3{6} across, 1c Rsh to 3cnrs | 1c pass Lsh to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1676, '2012-01-22 19:28:54.449457+00', '2014-04-30 23:23:38.376631+00', 11376, 1, NULL, 'ace', '1–::
  1c+3c RHA ; from the middle 1M/1W dance Lsh round 2W/2M and both cast L, 1W leading, to own places (3c doing likewise with 4c)
9–::
  1c+3c LHA and repeat figure mirrored (1c/3c round 4c/2c, Rsh)
17-32::
  2c+4c repeat [1-16] (all to own places)
33–::
  1c+3c set to P | change places RH ; 1W+3W change places LH | 1M+3M change places RH
41–::
  All W R&L on the diagonal, to start 1W change with 2W and 3W with 4W
49–::
  All M R&L on the other diagonal, to start 1M change with 4M and 3M with 2M
57–::
  2c+4c repeat [33-40]  2M+4M remain facing out (to 3,4,1,2, M facing out)
65–::
  All C turn RH 1¼  (W finish backs to centre) ; set to P | turn LH ¾ to face cnr
73–::
  All dance interlocking Reels4 (round cnr Rsh, pass P Lsh, round other cnr Rsh, the M finish in place
81–::
  All W dance a curve in front of cnr and behind the M opposite to original place ; All M dance as curve in front of their new cnr and behind P to original place (1,2,3,4)
89–::
  All Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (9429, '2016-10-11 21:14:18.282304+00', '2016-10-24 02:30:37.598172+00', 117, 1, NULL, 'ace', '1--::

  1W+2M set adv. | turn BH ¾ and twirl R to face cnr on 1diag ; set to cnr | turn BH ½ to sidelines (all have moved 1 place cclw in the square)

9--::

  1M+2W repeat [1-8], finish (2x,1x)

17--::

  2c ½ Fig8 round 1c ; 1c ½ Fig8 round 2c (2,1)

25--::

  2c+1c Poussette (2,1)



*note: on bar 12 M face M, W face W*', 4);
INSERT INTO 'dancecrib' VALUES (2577, '2012-01-22 19:29:48.341437+00', '2020-03-03 19:06:50.753138+00', 10912, 1, NULL, 'ace', '{{explanation}}

Trios facing trios RR



1–::

  All circle6 & back

9–::

  All turn opposite person RH ; repeat LH

17–::

  Middle person with the persons on the R  RHA ; LHA

25–::

  All A&R {2} | & pass RH to meet next trio', 2);
INSERT INTO 'dancecrib' VALUES (8870, '2015-08-26 22:05:54.214226+00', '2018-10-13 15:03:36.154471+00', 16525, 1, 1041, 'ace', '1--::  1c dance down below 3c | cast up 1 place ; dance up to 1pl facing out | 1c+2c ½ turn EH, 2c face out

9--::  2c+1c DblFig8, 1c crossing up

17-20::  1c+3c turn P RH ¾ and face P up/dn | set ; 

21-28::  (½ Celtic Reel) 1c+3c pass Rsh | “outers” chase ¼ way clw _while{2}_ “inners” turn (no hands) ¾ Lsh to face same person ; repeat

29-32::  1c+3c Turn P RH ¾ | all set

', 4);
INSERT INTO 'dancecrib' VALUES (9430, '2016-10-13 05:55:42.602291+00', '2016-10-13 05:55:42.602291+00', 7201, 1, NULL, 'ace', '1--::

  1c+3c set | turn RH ¾ ; 1M+3W turn LH 1½ _while{4}_ 1W+3M chase clw to other end of midline

9--::

  Reel4 on midline, finish in same places, facing P

17--::

  3c+1c set to P | petronella to own side (3,2,1) ; All turn P LH ready for 

25--::

  Promenade, on [31-32], 3c cast off to 3pl and 2c+1c dance up (2,1,3)

*On 2nd time through, finish (2,3,1) to bring original 1c to 4pl*

', 3);
INSERT INTO 'dancecrib' VALUES (10114, '2017-09-10 08:21:20.507765+00', '2018-04-06 09:19:51.396797+00', 15102, 1, 202, 'ace', '1--::

 1c cross RH | cast (2c up) ; ½ Fig8 R (2,1,3)

9--::

 1c ½ diag R&L with 1cnrs ; ½ diag R&L with 4cnrs (3x,1,2x)

17--::

 3c+1c+2c set | turn P BH ; chase clw ½ (2,1x,3)

25--::

  1c+3c set | ½ R&L (to 2,3x,1) | 3c cross RH (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (9781, '2017-04-08 09:22:22.581658+00', '2017-08-26 12:00:32.355935+00', 12892, 1, 202, 'ace', '1--::

 1c set | cast (2c up) ; dance down between 3c | cast to 2pl (2,1,3)

9--::

 1c+1cnrs A&R ; turn RH

17--:: 

 1c+2cnrs A&R ; turn RH, 1c passing Rsh to 2pl

25--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10639, '2018-04-17 06:48:21.907574+00', '2018-04-17 07:13:09.720884+00', 15680, 1, 202, 'ace', '1--::

  1c+2c set | 1c followed by 2c dance down between 3c, cast up to 1pl/2pl centre ready for

9--::

  1c+2c Poussette. On [15-16], 1c drop top hands, pivot on spot BtoB facing own side

17--::

  1M+2M+3M & 1W+2W+3W RHA, pass P Rsh ; 1M+2W+3W & 1W+2M+3M LHA, 1c end facing 1cnrs

25--::

  SetH&G. On [31] all clap as 1c Petronella turn to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8670, '2015-02-15 10:17:22.557804+00', '2015-02-15 10:17:22.557804+00', 13688, 1, NULL, 'ace', '1--::

  1c dance down | set to P and face up ; All M LHA and all W RHA

9--::

  1c dance up, cast off (2c up) and finish on midline Lsh to Lsh ; 2c+1W & 1M+3c RHA, 1c finish facing 1cnr

17--::

  Set “H&G, at end turn RH ¾ to (2,1,3)

25--::

  Circle6 and back

', 3);
INSERT INTO 'dancecrib' VALUES (8716, '2015-03-11 10:12:45.654982+00', '2015-03-11 10:12:45.654982+00', 16157, 2, 1, 'ace', '1–::
  1c long cast (2c up) ; 1c dance 1½ gipsy turn (twirl at end to face 1corners)
9–::
  Hello-Goodbye setting (at end 1c turn BH ¾ to face down, NH joined)
17–::
  1c dance down the middle, change places under arm, and dance up to
  1pl own sides (crossing over and twirling)
25–::
  1c+2c dance The Knot', 2);
INSERT INTO 'dancecrib' VALUES (13646, '2021-02-05 16:30:25.738643+00', '2021-02-05 16:30:25.738643+00', 20216, 2, NULL, 'ace', '1-4:: 3rd couple dance up and cast round 2nd couple

5-8:: 2nd couple dance up and cast round 1st couple

9-16:: All dance reels of three (2nd couple dance in and down to start)

17-20:: 1st couple dance out and up and curve to middle

21-24:: 1st L and 2nd L ½ turn RH while 1st M and 2nd M ½ turn LH, 1st L and 3rd L ½ turn LH while 1st M and 3rd M ½ turn RH

25-28:: All set twice

29-32:: 1st L and 3rd L, 1st M and 3rd M turn RH on sides while 2nd couple turn RH

', 0);
INSERT INTO 'dancecrib' VALUES (8387, '2014-08-25 06:44:55.522292+00', '2014-08-26 22:49:25.123347+00', 8058, 1, NULL, 'ace', '1--::

  All A&R ; 1c+2c & 3c+4c ½ R&L [alternative: RHA]

9--::

  All A&R ; 2c+1c & 4c+3c ½ R&L [alternative: LHA]

17--::

  1c lead down and up

25--::

  1c cast off to 4pl (2c+3c+4c up) ; All turn P RH

', 3);
INSERT INTO 'dancecrib' VALUES (2753, '2012-01-22 19:29:56.011263+00', '2020-11-15 13:06:58.240648+00', 9742, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c RHA ; LHA

9–::

  All M in hornpipe position set & coupe twice _while{4}_ W dance to P, swivel R and back to place ; All C (M still in Hornpipe position) two Petronella turns to (1x,2x,3x,4x)

17–::

  4c, other Cs following, dance down NHJ, on [20] W pass under M''s arms (M passes below) and all dance up to own places BHJ to P for

25–::

  4c Poussette (2c+3c+4c dance as 2nd C, 1c progresses to 4pl during [26-27]', 3);
INSERT INTO 'dancecrib' VALUES (12481, '2020-01-05 08:21:36.740895+00', '2020-01-05 08:24:35.823363+00', 14515, 1, 202, 'ace', '1--::

  1c lead down {3}, lead up {3} ; cast off (2c up) (2,1,3)

9--::

  All dance BtoB ; 2c+1M & 1W+3c LHA (2,1,3)

17--::

  All dance BtoB, LSh to P ; 2c+1W & 1M+3c RHA (2,1,3)

25--::

  3C »Threadneedle« R&L [: 2c+3c R&L while{8} 1c cross RH | dance RSh round 1cnrs[pos] ; cross LH up/down | dance LSh round 3cnrs[pos]] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1679, '2012-01-22 19:28:56.20218+00', '2014-04-30 23:23:38.419547+00', 223, 1, NULL, 'ace', '1–::
  1c+2c circle4 and back (1,2,3,4)
9–::
  1c lead down, cross and cast behind 3c, cross LH and cast off behind 4c
17–::
  1c lead up, cross and cast up behind 3c, cross LH and cast up behind 2c to original places
25–::
  1c+2c R&L
33–::
  1c+2c ½RHA | set ; 1c+3c ½LHA | set
41–::
  1c+4c ½RHA | all set ; all C turn RH 1½ to (2,3,4,1).', 3);
INSERT INTO 'dancecrib' VALUES (3439, '2012-01-22 19:30:25.56136+00', '2014-07-14 21:32:34.424873+00', 6748, 1, NULL, 'ace', '1–::

  1c lead down the middle and up, 1M presents 1W to 2M

9–::

  1W+2M (NHJ), followed by 1M, dance down the middle ; 1W+2M turn inwards and 1M joins (1W hands crossed and joined to outer hands of 1M+2M, their NH making arch above 1W), all three dance up in TRIUMPH to finish 2M in own place and 1c BHJ on opposite sides

17–::

  1c Poussette down the middle to bottom pl (¼ R turn, progress, ¼ turn, ¼ turn, progress, progress with ¼ turn, ½ turn to own side, fall back to sides), (all other couples step up on 23-24).', 3);
INSERT INTO 'dancecrib' VALUES (10459, '2018-02-26 07:19:11.907588+00', '2018-07-17 00:21:42.456447+00', 17122, 1, 202, 'ace', '1--::

  1c A&R{1+1} taking (or shaking) RH briefly | turn LH ½ facing down ; cross LH between 2c and cast up to 1pl

9--::

  1c+2c The Knot, 1c finish facing 1cnrs (2,1,3)

17--::

  Corners Pass and Turn BH (2,1,3)

25--::

  All chase clw ½ ; turn BH ½, face each other | cast R to exchanged places (3,1,2)', 5);
INSERT INTO 'dancecrib' VALUES (2175, '2012-01-22 19:29:23.927826+00', '2015-03-11 13:20:12.391012+00', 1969, 1, NULL, 'ace', '1--::

  1W+3M change pl RH, cast clw to P’s right, NHJ ; 1c+3c dance across and cast clw to 3pl facing 1pl in the middle _while{4}_ 2c set adv, pull back Rsh and skip-change to places. 

9--::

  3c+1c+2c Circle6 and back, finish 3c facing 1c in the middle (3,2,1)

17--::

  3c+1c set | 3c+1c RHA | 3c cast to 3pl _while{2}_ 1c dance to 1pl and face out.(1,2,3)

25--::

  1c+2c ¾ Dbl Fig8 (2c cross up) | 1c cross RH to 2pl. (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8808, '2015-06-26 22:25:27.917095+00', '2015-06-26 22:25:27.917095+00', 16309, 2, 160, 'ace', '1-8::
  1C cross RH, cast  to 2pl ; half reel3 across - 1M with 2C , 1L with 3C. 1C curve  L about to end with 1M between 2C facing up/1L between 3C facing down.
9-12::
  1C dance CW half round the set to end 1L between 2C facing down & 1M between 3C facing up ; 
13-16::
  2C 3C set twice *while* 1C petronella into 2pl on opp. sides and set.
17-24::
  All cross RH, 1L followed by ptnr cast behind 3L ; dance up the middle, cast behind 2M into 2pl own sides.
25-32::
  1C 3C RHA ; 1C 2C LHA', 0);
INSERT INTO 'dancecrib' VALUES (8809, '2015-06-26 22:48:29.774402+00', '2015-06-26 22:48:29.774402+00', 16308, 2, 160, 'ace', '1-8::
  1C set, cast 1pl. ; all adv&ret.
9-16::
  1L2C and 1M3C Reel3 across (Lsh).
17-24::
  1L2C and 1M3C dance RHA ; change ends and 1M2C and 1L3C dance LHA.
25-32::
  1C half fig. 8 round 2C ; half fig.8 round 3C.', 0);
INSERT INTO 'dancecrib' VALUES (10458, '2018-02-26 05:52:53.9875+00', '2018-02-27 03:53:37.995622+00', 5084, 1, 202, 'ace', '1--::

  1c set | 1W followed by 1M casts round 3W, 1W dances up round 3M and 1M dances up the middle, to 2plx (2c up on [7-8]) (2,1x,3)

9--::

  2c+1c La-Chain, 1c finish facing 1cnrs

17--::

  SetH&G, 1c finish facing 2cnrs

25--::

  1c ½ Reels3 on opposite sides, 1c Rsh to 2cnrs to start, pass Rsh ; ½ Reels3 on own sides, 1c Rsh to 4cnrs position to start (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10115, '2017-09-10 17:48:10.692483+00', '2018-04-08 08:53:39.047277+00', 15099, 1, 202, 'ace', '1--::

 1c+3c DblFig8 (1c cross down to start)

9--::

 1c followed by 2c+3c dance down the middle (2c & 3c divide) ; 1c (leading) +2c+3c dance up, 1c+2c ready for

17--::

 1c+2c ½ Poussette, 3c step in on [20] for ; 1c+3c ½ Poussette (2,3,1) 

25--::

 Circle6 and back (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (14922, '2022-06-27 11:53:13.479127+00', '2022-06-27 11:57:02.1053+00', 20445, 1, 202, 'ace', '1--::

  1c+2c Chain and Turn (2,1,3)

9--::

  3C Set&Rotate (3,1,2)

17--::

  ½ Reel4 on 1diag, pass LSh ; ½ Reel4 on 2diag, pass RSh to 2pl (2x,1,3x)

25--::

  2c+3c ½ DblFig8 ; all turn P BH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12483, '2020-01-06 07:25:19.301909+00', '2020-01-06 07:31:59.988024+00', 19811, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; ½ Fig8 up round 2c (2,1x,3)

9--::

  Mirror Reels3 on sides, 1c in and down, 3c out and up (2,1x,3)

17--::

  3C S&Link twice (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1799, '2012-01-22 19:29:02.93538+00', '2021-07-01 09:08:03.403213+00', 650, 1, NULL, 'ace', '1–::

  1c+2c set twice ; RHA

9–::

  1c+2c set twice ; LHA

17–::

  1c ½Fig8 down (with hands) ; cross RH, cast off

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (8671, '2015-02-15 15:44:55.073861+00', '2015-02-15 19:29:11.528053+00', 14363, 1, NULL, 'ace', '1--::

  1W sets | casts off : ½ Fig8 Rsh round 3M and face down _while{8}_ 1M stands | sets ; crosses and casts off (2c up) to behind 1W 

9--::

  3W+1c LHA and 1c (1W leading) faces 2M ; 2M+1c+3W ½ Rsh Diag. Reel3, and 1c faces 3M

17--::

  3M+1c RHA and 1c face 2W ; 2W+1c+3M ½ Lsh Reel3, finish in lines across, 3c+1M (above) facing 2c+1W (below)

25--::

  All set | All set pivoting R ¾ on the spot ; 3c+2c chase ½ clw _while{4}_ 1c turn RH 1¼ to finish (2,1x,3)

  

  On the next time through, 1M and 1W interchange roles.

', 3);
INSERT INTO 'dancecrib' VALUES (8391, '2014-08-26 17:16:18.157979+00', '2014-08-26 17:16:56.831052+00', 15576, 1, NULL, 'ace', '1-- ::

  2c+3c Poussette _while{8}_ 1c+4c set | cross RH ; chase half round clw (4,2,3,1)

9--::

  All Rsh Reels4 on the sides (no loops at end)

17--::

  4c+2c & 3c+1c ½ R&L ; All set | cross RH (2,4,1,3)

25--::

  2c+4c & 1c+3c RHA ; LHA

', 3);
INSERT INTO 'dancecrib' VALUES (8392, '2014-08-26 19:26:10.694452+00', '2014-08-26 19:26:10.694452+00', 15577, 1, NULL, 'ace', '1--::

  1c lead down and up

9--::

  1c+2c RHA ; LHA

17--::

  1c+2c+3c Promenade

25--::

  1c cast off and make arch in 4pl, while 2c+3c+4c follow and dance up under arch (2,3,4,1) 

 

', 3);
INSERT INTO 'dancecrib' VALUES (8393, '2014-08-26 20:21:09.993678+00', '2014-08-26 20:25:16.109468+00', 15579, 1, NULL, 'ace', '1--::

  2c+3c Set&Rotate (1,3,2,4)

9--::

  3c with 1c+2c full diag. R&L  (2x,3,1x,4)

17--::

  1c with 3c+4c full diag. R&L (first on L diagonals, then R) (2x,4x,1x,3x)

25--::

  Reels4 on the sides

33--::

  All set | cross RH ; 2c+4c & 1c+3c RHA

', 3);
INSERT INTO 'dancecrib' VALUES (8810, '2015-06-26 22:53:29.351007+00', '2015-06-26 22:53:29.351007+00', 16307, 2, 160, 'ace', '1-8::
  1C full fig.8 round 2C.
9-16::
  1C 2C poussette.
17-24::
  Lsh Reel3 across the dance - 1L with 2C/1M with 3C
25-32::
  1C dance down between 3C cast up to 2pl ; dance up between 2C and cast into 2pl.', 2);
INSERT INTO 'dancecrib' VALUES (12832, '2020-05-15 10:48:42.074688+00', '2020-05-15 10:48:42.074688+00', 6928, 1, NULL, 'ace', '1--::

  1c+2c & 4c+5c R&L

9--::

  2c+3c+4c Circle6 and back (1,2,3,4,5)

17--::

  1c set adv and slip BHJ  to 5pl _while{4}_ 5c cast to 1pl ; 5c set adv and slip BHJ  to 5pl _while{4}_ 1c cast to 1pl (1,2,3,4,5)

25--::

  1c+3c cross RH and cast off one (2c+4c up) ; 1c+3c cross LH and cast off one (4c+5c up) (2,4,1,5,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8862, '2015-08-25 22:24:18.836172+00', '2015-08-27 02:15:58.143394+00', 16567, 2, NULL, 'ace', '1 - 8::  1s cast 1 place, ¾ turn RH & dance LH across (1L+2s & 1M+3s) to end facing each other just inside 2nd pl opposite sides

9-16::  1s set, turn BH & dance ½ fig 8, 1L around 2s & 1M around 3s (2,1,3)

17-24::  1L+2M & 1M+3L dance ½-way round each other RSh & cast into each other’s places, all cross RH & set

25-32::  1L+2M & 1M+3L dance ½-way round each other RSh & cast into each other’s places, all cross RH & 1s+3s cross LH on sides (2,3,1)

', 5);
INSERT INTO 'dancecrib' VALUES (9065, '2016-01-04 23:24:35.682076+00', '2016-01-05 01:56:50.895363+00', 16758, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 R and face 1cnr

9--::

  Set “H&G” for {4} and face 2cnr ; ½ diag. Reel4 on 2diag, finish facing 4cnr

17--::

  Set “H&G” for {4} and face 1cnr ; ½ diag. Reel4 on 1diag, at end 1c turn LH to (3x,1,2x)

25--::

  Diagonal R&L (1W up, 1M down) (2,1,3)



*Repeat from 2pl in Reel time*

', 3);
INSERT INTO 'dancecrib' VALUES (8390, '2014-08-26 16:29:35.554376+00', '2016-12-31 21:27:44.929812+00', 15575, 1, NULL, 'ace', '1- 16	::

  1c+3c petronella to midline and set ; 1c+3c Reel4 on midline ; 1c+3c petronella to opposite side | all set (1x,2,3x)

17--::

  1M+2W & 1W+2M & 3c turn RH 1½ ; 1c ½ Fig 8 L (2,1,3)

25--::

  	All Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1781, '2012-01-22 19:29:02.030245+00', '2018-07-15 00:28:31.860103+00', 588, 1, NULL, 'ace', '1–::

  1W+2M A&R ; dance BtoB

9–::

  1M+2W repeat

17–::

  1c lead down the middle and up

25–::

  1c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (9498, '2016-11-14 23:51:11.1686+00', '2016-11-15 00:58:56.130502+00', 14679, 2, NULL, 'ace', '{{explanation}}

Circle RR, all face in, W on M''s right



1-:: All C advance to centre and retire ; repeat

9-:: All W advance to centre, clap and retire ; All M advance to centre, turn and advance to partners

17-:: All swing partners into promhold facing cclw

25-:: All C promenade cclw to reform original circle



{{explanation}}

Note. With progression:

13-:: All M advance to centre, turn and advance to cnr (W on M''s left in original circle)

17-:: All swing new partners into promhold facing cclw

', 2);
INSERT INTO 'dancecrib' VALUES (14813, '2022-05-05 14:04:53.702331+00', '2022-05-05 14:04:53.702331+00', 19875, 2, 963, 'ace', '1-4::  
  All set|1C dance dwn to face 3C as 2C cast up  
5-8::  
  1C turn 3c EH|1C flwd by 3C dance up to top  
9-12::  
  1C,3C,2C HA women RH, men LH  
13-16::  
  1C cast off and cross RH to opp side WHILE 3C cast dwn to 3rd plc  
17-24::  
  R3 on the sides, 1C giving Rsh to 1st corner.  1C finish facing each other in the middle
25-32::  
  1M pulls back Lsh to face up and, flwd by 1W, casts behind 2M, across 2nd plc, behind 3W to 3rd plc (3rd cpl up on 31&32)  
33-40::  
  All circle   2,3,1', 5);
INSERT INTO 'dancecrib' VALUES (8811, '2015-06-26 23:22:53.956959+00', '2015-06-26 23:22:53.956959+00', 16314, 2, 160, 'ace', '1-4::
  1C set, cross RH ;
3-6::
 2C set ; cross RH
5-8::
 3C set, cross RH.
9-16::
  Men: adv(2), ret(2) ; set and cross LH with partner *Meanwhile*  Ladies: set, adv(2) ; ret(2), cross LH with partner.
17-24::
  1C turn RH ; cast to 2pl, set advancing turning R about to face own sides in DT position.
25-32::
  All set, 1C 3C change places HH and skch *while* 2C set ; all set in DT position, 3C set advancing and turn R about to end in 2pl own sides *while* 2C 1C set.', 0);
INSERT INTO 'dancecrib' VALUES (11227, '2018-10-01 10:08:19.517301+00', '2018-10-01 10:11:14.772251+00', 18633, 1, 1645, 'ace', '1-::

  All set | 1W & 3M slow cast off/up followed by their lines to (3,2,1) | all &frac12; turn P BH (3x,2x,1x)

9-::

  Repeat [1-8] from new places back to (1,2,3)

17-::

  1c+2c &frac12; R&L ; 1c+3c &frac12; R&L (2x,3x,1)

25-::

  All circle6 to L only ; 2c & 3c turn 1&frac12; BH _while{4}_ 1c turn BH (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (8295, '2014-07-27 22:41:29.111834+00', '2014-07-29 13:05:54.851119+00', 8930, 1, NULL, 'ace', '1--::

  1M+2W & 3M+4W A&R diagonally ; dance BtoB

9--::

  1W+2M & 3W+4M repeat (1,2,3,4)

17--::

  1c turn RH ½ | 1c+2c ½ RHA ; 2c turn RH _while{4}_  1c turn RH ½ | 1c+3c ½ RHA (2x,3x,1,4)

25-28::

  2c+3c RHA _while{4}_  1c Turn RH ½ | 1c+4c ½ RHA (2x,3x,4x,1) 

29-32::

  2c+3c+4c set and cross _while{4}_  1c set twice (2,3,4,1)



{{explanation}}

Warning: some cribs distributed before 2014 had errors', 3);
INSERT INTO 'dancecrib' VALUES (3648, '2012-10-12 14:16:50.898016+00', '2022-12-19 02:36:51.446886+00', 1201, 2, 197, 'ace', '1–::

  1c dance between 2c, behind 3c, between 4c; cast up behind 4c, dance between 3c, behind 2c to place.

9–::

  1c+2c  RHA; LHA

17–::

  1c+2c circle4 and back.

25–::

  1c BHJ slip down and back to 4pl (2,3,4,1)

33–::

  2W leads 3W 4W and 1W, with hands joined, across, down behind all the men, across, and back up to place. 

41–::

  2M leads 3M 4M and 1M, with hands joined, across, down behind all the women, across, and back up to place. (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (14019, '2021-05-04 07:06:52.857325+00', '2021-05-04 12:51:29.970922+00', 1770, 1, 202, 'ace', '1--::

  1c set advancing | 6 bars of *Modified Poussette* : same as Poussette except on [8] where couples turn P BH ¼ to midline

9--::

  Reel4

17--::

  All set | Petronella turn ; set | cross RH (2,1)

25--::

  RHA ; LHA', 4);
INSERT INTO 'dancecrib' VALUES (8396, '2014-09-01 15:21:54.424804+00', '2021-06-28 00:42:31.517889+00', 871, 2, 2088, 'ace', '1-4::

 1c set & cast 2nd place 2c step up.

5-8::

 All set - turn RH finish in centre of set.

9-14::

 6 bar reel 3 - 2c & 1c face up 3c face down. 2c & 3c cast into reel (2c pass in front     of 3c, emphasise retaining inside hands - Finish 2,1,3 on own sides).

15-16::

 1c pass left shoulder face 1st corner.

17-24::

 Hello Goodbye setting (finish facing 2nd corner)

25-30::

 Reel 3 on sides pass 2nd corner RSh

31-32::

 1c cross RH (retain hold)

33-36::

 1c turn RH and cast own sides to 3rd place - 3c step up bars 35-36.

37-40::

 1c turn RH (finish 3rd place own sides (double handed quick turn or birl)', 2);
INSERT INTO 'dancecrib' VALUES (1681, '2012-01-22 19:28:56.297292+00', '2021-07-04 10:50:35.101812+00', 229, 1, NULL, 'ace', '1–::

  1M+2W change place RH, 1W+2M repeat ; 1M+3M repeat, 1W+3W repeat (2x,3x,1)

9–::

  1c cross RH | cast to 1pl (2c+3c down) ; All set | cross RH (1,2,3)

17–::

  1c lead down the middle and up

25–::

  1c+2c ½R&L ; set | cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12833, '2020-05-15 11:14:30.257035+00', '2021-07-14 09:24:54.837986+00', 1943, 1, 202, 'ace', '1--::

  1M+2W change places RH | 1c+2c chase clw one place ; 2c+1c RHA (2,1,3)

9--::

  1W+3M change places LH | 1c+3c chase cclw one place ; 3c+1c LHA (2,3,1)

17--::

  1c set | lead up to top ; cross (3c down) | cast off (2,1x,3)

25--::

  All A&R ; 1c turn P BH 1½ _while{4}_ 2c & 3c turn P BH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8863, '2015-08-25 22:48:23.186346+00', '2015-08-25 22:48:23.186346+00', 16568, 2, NULL, 'ace', '1 - 8::  1s+2s set, facing diagonally in on 2nd pdb, 1M+2L cast up/off to middle of dance (1M just above 1 st pl, 2L just below 2nd pl) while 1L+2M turn ¾ RH to finish facing partner in line of 4 & 1s+2s dance ½ reel of 4

9-16::  2s+1s set, petronella turn to sides & dance ½ R&L (1M finishes facing out) (1,2,3)

17-24::  1 M, followed by 1L, casts off 1 pl & crosses to 2nd pl opp side, then 1s pull LSh back & 1L, followed by 1M, casts off 1 pl & crosses to 3rd pl (2s step up on 19-20, 3s on 23-24) (2,3,1)

25-32::  1s, followed by 3s, dance up the middle, cast off around 2s, dance down & cast up to 2nd pl while 3s dance into 3rd pl (2,1,3)

', 0);
INSERT INTO 'dancecrib' VALUES (14141, '2021-07-09 06:10:31.19762+00', '2021-07-09 06:14:20.95161+00', 20366, 1, 202, 'ace', '1--::
  2c dance up round 1c to 2pl ; 1c+2c RHA (1,2,3)
9--::
  2c dance down round 3c to 2pl ; 2c+3c LHA. 2c in tandem (2M leading) face 1M (1,2,3)
17--::
  ½ Reel3 on 1diag in tandem (with lead change), 2M RSh to 1M ; ½ Reel3 on 2diag in tandem (with lead change), 2W RSh to 3M (3x,2x,1x)
25--::
  2c turn RH | cast off (1c up) ; all cross RH | all set (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (8403, '2014-09-15 21:01:58.147072+00', '2014-09-15 21:54:52.678257+00', 15623, 1, NULL, 'ace', '1--::

  1c+4c set | cast in ; ½ Fig8 round own end (2c+3c step to end)  finish BtoB in middle facing cnr  (2,1x in middle,4x in middle,3) 

9--::

  All set | turn cnr RH and join LH in centre ; All balance in cross | 1c+4c ½ LHA to face opposite cnr

17--::

  repeat [9-14] | 4c+1c turn P LH ½ and face out the end 

25--::

  1c+4c lead out the end, cross and cast in ; All turn or spin RH (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8865, '2015-08-26 09:17:26.687633+00', '2017-08-26 14:05:39.434198+00', 16571, 1, NULL, 'ace', '1--::

 1c lead down (2c up) ; on [5] turn RH ½ and lead up to 2plx (2,1x,3)

9--::

 2c+1c La-Chain

17--::

 Parallel Reels3, 1c Rsh to 3c

25--::

 1M followed by 1W cast (3c up) and cross to 3pl ; 3c+1c S&Link (2,1,3)



*Note. After 2nd time through or in a 3 couples longwise set:*

25--::

 1M followed by 1W cast (3c up) and cross to 3pl ; 3c+1c RHA.', 3);
INSERT INTO 'dancecrib' VALUES (8676, '2015-02-17 14:48:51.594549+00', '2015-02-17 14:48:51.594549+00', 16071, 2, 1, 'ace', '1–4::
  1c turn RH ½ (moving down to 2pl in middle, 2c up) |
  1c set, pull RS back to face 2cnr
5–16::
  Dance to each corner and set (starting w/2cnr)
  [fin in 2plx facing down, NH joined]
17–::
  1c dance down the middle (on bar 20, 1L dances under 1M''s arm),
  then up to 2pl own sides
25–::
  Diagonal rights and lefts', 3);
INSERT INTO 'dancecrib' VALUES (8819, '2015-07-25 23:26:24.315943+00', '2017-05-31 12:54:12.251163+00', 16510, 2, NULL, 'ace', '1-8::

  1C  cast to 2pl [4 bars] ; dance down between 3C cast up to 2nd pl.

9-16::

  1C and 1crnr adv&ret ; dance 1/2 back to back, pull back Rsh and cast to places..

17-24::

  1C and 2crnr repeat - 1C pass each other by Rsh.

25-32::

  Six hands round and back.', 5);
INSERT INTO 'dancecrib' VALUES (8282, '2014-06-14 20:58:10.326069+00', '2014-09-09 12:25:13.435597+00', 15429, 1, NULL, 'ace', '1--::

  All face P and dance ½ G-Chain (no hands) ; turn P RH (3,4,1,2)

9--::

  Repeat [1-8],  all turn P into Waltzhold.  (1,2,3,4)

17--::

  1c+3c slip across, M passing BtoB | and back, W passing BtoB

25--::

  2c+4c repeat [17-24]

33--::

  1M+3M in centre dance free steps _while{8}_ the others circle6 L, pivot L and chase to places

41-48::

  Top four dancers (1M, 1W, 2W, 4M) + Bottom four LHA ; RHA

49-64::

  2M+4M in middle, repeat [33-48], the “side fours” dancing the LHA ; RHA

65-80::

  1W+3W in middle, repeat [33-48]

81-96::

  2W+4W in middle, repeat [33-48], the “side fours” dancing the LHA ; RHA

97-112::

  Repeat [17-32]

112-128::

  Repeat [1-16],  all turn P into Waltzhold.



', 3);
INSERT INTO 'dancecrib' VALUES (8679, '2015-02-20 22:40:16.002454+00', '2015-02-20 22:40:16.002454+00', 5696, 1, NULL, 'ace', '1--::

  All set | keeping NHJ with P all RHA 2/3 round | All set facing in (2,3,1)

9--::

  All turn P BH | open into Circle6 L 2 places | all turn P BH and face in (3,1,2)

17--::

  All M fig8 in front of P and behind next W (3,1,2)

25--::

  All in promhold dance Reel3, 3c Rsh to 2c. (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (8400, '2014-09-09 14:01:32.383461+00', '2014-09-10 15:35:53.97603+00', 15619, 2, 1, 'ace', '1–::

  1c set | cast off (2c up) ; turn RH | cast up (2c down)

9–12::

  1c change places with 2c EH (1c start by dancing in; fin w/polite turn to face ptr) | 1c set

13–16::

  1c turn 3c EH [to 213] (1c start by dancing in)

17–20::

  1c Petronella turn (fin M between 3c, L between 2c) | all set

21–24::

  All turn opposite RH ½ and twirl (fin 1M+3c at top facing 1L+2c in 3rd pl)

25–28::

  Set & Link for three [to 3x,1x,2x]

29–32::

  1c birl 1½ times to own sides _while_ 2c+3c chase clockwise to places', 3);
INSERT INTO 'dancecrib' VALUES (14812, '2022-05-05 09:06:36.842271+00', '2022-05-05 09:10:56.110514+00', 20788, 1, 202, 'ace', '1--::

  2c+3c RHA, finish BtoB on sides ; all set up/down | change places RH into Reel4 position (2,1,4,3)

9--::

  Reels4 (2,1,4,3)

17--::

  1c+4c Chain Progression (2,4,1,3)

25--::

  All turn P RH ; 4c & 1c cast off one pl _while{2}_ 3c dance up to 2pl | all set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (8402, '2014-09-12 20:26:30.816864+00', '2014-09-14 13:02:30.252696+00', 15622, 1, NULL, 'ace', '1--::

  2c set | cross RH ; cast R round 1cnr and pass Lsh to face 2cnr (1c+3c are corners to 2c)

9--::

  2c+2cnrs Pass & Turn, 2c pass Rsh ; 2c+3cnrs Pass &Turn, 2c pivot R into DTr position, 2M facing up, 2W down

17--::

  Set in DTr | 2c set to face opposite side (= ¼ clw) as 1c+3c dance one place clw ; All set in DTr | 2c set to face ¼ clw (M down, W up) as 1c+3c dance one place clw 

25--::

  2c cast Rsh round 4cnr _while{4}_ 3c+1c set and cross RH (3,2,1) ; 2c+1c dance up and cast round 3c to (3,1,2)

', 5);
INSERT INTO 'dancecrib' VALUES (13541, '2021-01-09 21:53:01.36265+00', '2021-01-09 21:55:03.394214+00', 13638, 3, NULL, 'ace', '1-8::

  All 4 couples set, 1s+2s turn 1/2 LH into 1/2 LH across while 3s+4s 1/2 turn RH into 1/2 RH across, all set. 2 1 4 3

9-16::

  1s dance Fig 8 on sides round 2s & 3s (start up, LSh to 2s) while 4s+3s dance RH across, 4s+2s dance LH across (1s & 4s pass LSh on bar 13). 2 413

17-24::

  All 4 couples set, 2s+4s turn 1/2 LH into 1/2 LH across while 1s+3s turn 1/2 RH in 1/2 RH across 4 2 3 1

25-32::

  2s dance Fig 8 on sides round 4s & 1s (start up, LSh to 4s) while 3s+1s dance RH across, 3s+4s dance LH across (2s & 3s pass LSh on bar 13). End 4 3 2 1



{{explanation}}

Repeat once only from new positions', 0);
INSERT INTO 'dancecrib' VALUES (1682, '2012-01-22 19:28:56.348343+00', '2016-06-05 13:21:05.490157+00', 231, 1, NULL, 'ace', '1–::

  Mirror Reels3, 1c cross down to start, finish 2pl NHJ facing down:

9–::

  1c A{1}&R{1} between 3c who A{1}&R{1} on sides | 1c turn 3c easy hand and face up NHJ ; Repeat with 2c, 1c finish facing 1cnr

17–::

  Set to and turn cnrs

25–::

  Mirror Reels3 on own side, 1c cross between 2c to start



', 3);
INSERT INTO 'dancecrib' VALUES (9068, '2016-01-10 01:58:01.707622+00', '2016-01-10 01:58:01.707622+00', 16838, 1, NULL, 'ace', '1--::

  Circle8 and back

9--::

  1c+3c Men’s Chain

17-28::

  12 bars of Schiehallion reel (4,1,2,3)

29-32::

  All Birl or Turn P RH (4,1,2,3)

', 3);
INSERT INTO 'dancecrib' VALUES (13452, '2020-12-03 10:18:35.389999+00', '2020-12-03 10:25:33.669991+00', 6173, 1, 202, 'ace', '1--::

  1c+3c DblFig8, 1c crossing down. All couples finish in centre NHJ, 1c facing down, 2c & 3c facing up (1,2,3)

9--::

  All set | 1c dance down to 2pl centre under 2c making arch _while_ 2c dance up to 1pl ; 1c & 3c set | 1c dance down to 3pl under 3c making arch, turn inwards and face up _while_ 3c dance up to 2pl (2,3,1)

17--::

  Mirror Reels3 on sides, 2c in and down, 3c out and up, 1c in and up

25--::

  Circle6 and back (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2496, '2012-01-22 19:29:45.088875+00', '2021-03-02 14:17:12.347864+00', 9091, 1, NULL, 'ace', '1–::

  1c dance down and cast up ; turn RH and face out

9–::

  1c Cast into Fig8 round 2c, finish own place facing out

17–::

  1c turn 2c on sides easy hand, finish facing 2c ; set to 2c, change places RH

25–::

  2c+1c RHA ; LHA', 2);
INSERT INTO 'dancecrib' VALUES (9066, '2016-01-05 01:41:23.462519+00', '2016-01-05 01:53:05.428948+00', 16758, 2, NULL, 'ace', '1-4::

  1C cross over giving RH and cast off one place. 2C step up on bars 3 & 4. 

5–8::

  1C dance ½ Figure of 8, 1L down cross down around 3L while 1M crosses up around 2M. Finish facing 1st corners 

9 -12::

  1C dance ½ Hello & Goodbye setting. Finish facing 2nd corners. 

13–16::

  1C dance ½ Diagonal Reel of 4 with 2nd corners. 1C finish facing partner’s 2nd corner position 

17–20::

  1C dance ½ Hello & Goodbye setting. Finish facing 1st corners. 

21-24::

  1C dance ½ Diagonal Reel of 4 with 1st corners. On bars 23 & 24, 1C turn LH to finish 2nd place own sides. 

25-32::

  1C dance Diagonal Rights & Lefts. 1L dances up, 1M dances down to begin both times.



*Repeat from second place in Reel time*

', 4);
INSERT INTO 'dancecrib' VALUES (11006, '2018-08-17 12:30:10.040973+00', '2018-08-21 16:07:01.365182+00', 15298, 1, 202, 'ace', '1--::

  ½ Gr-Chain, on [4], turn P LH into promhold ; all chase clw ½ (1,2,3,4)

9--::

  1c+3c ½ La-Chain ; 2c+4c repeat 

17--::

  All M cast L and chase cclw ½ ; all set with P twice (3,4,1,2)

25--::

  Top & bottom cpls ½ M-Chain ; sides cpls repeat

33--::

  All W cast R and chase clw ½ ; all set with P twice (1,2,3,4)

41--::

  Circle8 L ¾ (to 2,3,4,1) | all set', 4);
INSERT INTO 'dancecrib' VALUES (11487, '2019-01-02 10:57:22.79355+00', '2019-01-02 11:06:27.527426+00', 14020, 1, 202, 'ace', '_Strathspey_

1--::

  1c+2c A&R ; dance BtoB (1,2,3)

9--::

  The Tournée (2,1,3)



_Reel_

17--::

  1c A&R ; ½ Fig8 R _while{8}_ 2c+3c stand still | A&R | stand still (2,1x,3)

25--::

  All repeat [17-24] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8251, '2014-04-24 11:29:03.221858+00', '2016-11-06 20:16:19.63042+00', 2119, 1, NULL, 'ace', '{{explanation}}

Couple face couple RR.



1–::

  Circle4 and back

9–::

  RHA ; LHA

17–::

  Ladies Chain

25–::

  A&R ; Pass person opposite Rsh to meet next couple.', 3);
INSERT INTO 'dancecrib' VALUES (14361, '2021-10-11 19:57:15.95138+00', '2021-10-12 07:37:07.45342+00', 20290, 1, 202, 'ace', '1--::

  1c turn BH opening to face down NHJ (2c up) | dance down, 1W to 2W place, 1M facing P close to her. 1c release hands on [4] ; 1W advance _while{2}_ 1M retire | 1W retire and on [8] pulls LSh back to face 3W _while{2}_ 1M advance

9--::

  ½ Reel3 in tandem (with lead change) on 1diag, 1W RSh to 3W ; ½ Reel3 in tandem (with lead change) on 2diag, 1M RSh to 2W

17--::

  Repeat [9-16], 1W curving R to 2pl (2,1,3)

25--::

  Poussette (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (12473, '2020-01-04 23:42:13.530744+00', '2020-01-04 23:45:48.476054+00', 19804, 1, NULL, 'ace', '*Big Circle RR, W has P on her L*

1--::

   All Circle L 

9--::

    All A&R to centre twice, all face P

17--::

    7 hands of Gr-Chain (1bar/hand), 8th person is new P 

25--::

    Birl new P, finishing back in the circle', 1);
INSERT INTO 'dancecrib' VALUES (8404, '2014-09-16 20:14:54.853795+00', '2014-09-16 20:14:54.853795+00', 5386, 1, NULL, 'ace', '1--::

  1c turn RH | cast off (2c up) ; 1c turn RH ¾ into lines across , 2c facing 3c and 1c facing out the ends | All set NHJ 

9--::

  Reels3 across, Rsh to 4cnr, 1c finish RHJ with 2cnr and LHJ with P

17--::

  BiLine | turn 2cnr RH | turn 1cnr LH ; turn 1cnr LH and join P RH in a diagonal line | BinLine

25--::

  Reels3{6} on the sides, start Lsh to 1cnr | cross RH to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8813, '2015-06-26 23:44:39.963277+00', '2015-06-26 23:44:39.963277+00', 16321, 2, 160, 'ace', '1-8::
  1C2C half turn HH (1C out and down), 6 bar mirror reel3 on own sides (1C in and down to begin).
9-16::
  down the middle and up (to 2pl, center of the dance, facing up).
17-24::
  1M  LHA with Men *while* 1L RHA with Ladies ; 1C half fig.8 up. (2 1x 3)
25-32::
  All turn RH ; all set twice - 2M 1L 3M turning R about on spot, 2L 1M 3L turning L about on spot. (2 1x 3)', 2);
INSERT INTO 'dancecrib' VALUES (2226, '2012-01-22 19:29:26.722565+00', '2015-02-18 21:33:54.247726+00', 11367, 1, NULL, 'ace', '{{explanation}}

On 2nd chord 3c+4c cross over (1,2,3x,4x)



1–::

  2c+3c set | turn RH ½ ; cross out through the end and cast to place (1,2,3x,4x)

9–::

  1c+2c & 3c+4c double Fig8 (1c & 4c cast to start), 1c+4c stay facing out (1,2,3x,4x)

17–::

  1c+2c & 3c+4c on sides turn EH 1½ ; 1c+4c ½ R&L (2,4,1x,3x)

25–::

  Parallel Reels4 on the sides, but on [31-32] the middle dancers turn BH ½ (Skip-Ch)

33–::

  All circle8 and back (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (14600, '2022-02-08 13:01:44.83803+00', '2022-02-08 13:30:09.948348+00', 11525, 1, 202, 'ace', '1--::

  Gr-Chain, 1c crossing (1,2,3)

9--::

  Inveran Reels (1,2,3)

17--::

  1c cross RH | cast off two places (2c+3c up) : turn P BH 1½

25--:: Circle6 and back (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3252, '2012-01-22 19:30:17.656325+00', '2014-09-21 00:33:01.816188+00', 6052, 1, NULL, 'ace', '1--::

  1c lead down to bottom ; cast up outside to top.

9--::

  G-Chain (1c&4c start across)

17--::

  1c+2c & 3c+4c set | ½RHA ; set | ½LHA, end 1c. facing down and others facing up, all NHJ

25--::

  (“authentic version”: Over the Waves) 1c making an arch change places with 2c | repeat with 3c ; and with 4c | 4c+1c turn P LH, 4c finish facing down

25--::

  (“popular version”: Over The Waves-Zig-Zag setting) 1c+2c NHJ set advancing, passing to exchanged places, 1c+3c repeat ; 1c+4c repeat (to 2341), 4c+1c turn P LH, 4c finish facing down

33--::

  1c lead up the centre followed by 4c (start down) ; divide at the top & cast to bottom (2,3,4,1)





', 3);
INSERT INTO 'dancecrib' VALUES (8405, '2014-09-21 22:29:10.154171+00', '2014-09-21 22:29:10.154171+00', 15403, 1, NULL, 'ace', '1--::

  1c set | cross down RH (2c up) ; set to P | turn LH ¾ to between ends facing 1cnr 

9--::

  ½ Reels3 across, 1c Lsh to 1cnr, 1c pass Lsh into ; ½ Reels3 across, Lsh to 3cnr, 1c finish side by side in the middle facing 4cnr 

17--::

  All M & All W RHA on the sides ; 1c cast Rsh round 4cnr to 2pl while{4} 2W+3W & 2M+3M set and change places RH to (3,1,2)

25--::

  Set&Rotate for three [All Set | all cast clw to lines across ; all cpls  change place RH | all chase clw to (2,1,3)]        

', 3);
INSERT INTO 'dancecrib' VALUES (2882, '2012-01-22 19:30:01.413168+00', '2016-11-15 01:23:45.025913+00', 4804, 1, NULL, 'ace', '1–::

  1c+2c set twice and cross over, W going under arch formed by the M, and turn inwards to face P

9–::

  Repeat [1-8]

17–::

  1c lead down the middle and up, into

25–::

  1c+2c Allemande', 3);
INSERT INTO 'dancecrib' VALUES (8814, '2015-06-26 23:57:34.661134+00', '2015-06-26 23:58:04.336277+00', 16325, 2, 160, 'ace', '1-8::

  1C set, cross RH ; cast to 2pl., set.

9-16::

  Reel3 across - 1M down (Rsh to 3M) 1L up (Rsh to 2L). 1C end in center facing down, 1L behind 1M.

17-24::

  1C set, adv & ret (facing down), pass Rsh to end- 1L btwn 3C facing down and 1M btwn 2C facing up.

25-32::

  1C cast R, cross to own sides passing Rsh ; all turn RH once round.', 2);
INSERT INTO 'dancecrib' VALUES (3059, '2012-01-22 19:30:08.754472+00', '2014-10-31 22:39:19.896995+00', 5407, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; ½ Fig8 Lsh round 1cnr (2,1x,3)

9–::

  1M+2c and 1W+3c Lsh Reels3 across, at end 1c LH turn to face 1cnrs

17–::

  1c+1cnrs change places RH _while{2}_ 2cnrs set | centre dancers change places LH _while{2}_ the others chase clw one position ; repeat from new positions

25–::

  Repeat from new positions, but to finish 1c turn LH to 2plx ; 2c+1c+3c set | 1c cross RH.', 3);
INSERT INTO 'dancecrib' VALUES (9431, '2016-10-14 15:09:42.489262+00', '2016-10-14 21:23:51.250413+00', 17406, 2, NULL, 'ace', '1- 8::

  1s set & cross into middle of set, 1L dances LH across with 2s as 1M dances RH across with 4s 

9-16::

  1s cross down between 3c and cast up outside the set to own place | 1c set

17-20::

  All, NHJ with partner, Advance & Retire with corner 

21-24::

  All Set&Link 

25-28::

  All Advance to centre with corner, Retire to Sq set formation with next person (1M+3L, 2M+4L, 3M+1L, 4M+2L) 

29-32::

  All Set&Link 

33-40::

  1st & 3rd positions (2M+4L & 4M+2L) ½R&L & ½ Ladies’ Chain 

41-48::

  2nd & 4th positions repeat

', 5);
INSERT INTO 'dancecrib' VALUES (1841, '2012-01-22 19:29:05.294738+00', '2015-02-28 21:03:49.920391+00', 819, 1, NULL, 'ace', '1–::

  1W+2W+3W A&R to P ; 1M+2M+3M repeat

9–::

  1c followed by 2c+3c cast off to 3pl, join RH and lead up to places

17–::

  1c+2c+3c circle6 and back, 1c+2c finishing ready for

25–::

  Poussette', 3);
INSERT INTO 'dancecrib' VALUES (7965, '2013-08-21 08:31:51.91276+00', '2023-02-04 01:23:14.045921+00', 7188, 3, NULL, 'ace', '1-8::
    1s lead down to the bottom & dance up behind 4s, between 3s, behind
    2s back to places
9-16::
    All set to partners (Ladies Glasgow Highlanders setting steps, Men
    Rocking Steps)
17-24::
    All set, cross RH Men making arches, set & cross back Men making
    arches
25-32::
    All dance reels of 4 on sides
33-40::
    1s+2s dance 1/2 RH across, 1s+3s 1/2 LH across, 1s+4s 1/2 RH across
    & all Cross RH', 0);
INSERT INTO 'dancecrib' VALUES (8406, '2014-09-23 01:36:03.969007+00', '2017-03-27 13:45:52.502435+00', 8044, 2, 1505, 'ace', '1-:: 1c cast behind lines and back 

9-:: 1c Fig8 round 2c 

17-:: 1c lead down the middle and up 

25-:: 1c + 2c Allemande', 0);
INSERT INTO 'dancecrib' VALUES (1867, '2012-01-22 19:29:07.004355+00', '2017-07-07 13:35:35.169631+00', 899, 1, NULL, 'ace', '1–::

  1c cast off behind own lines and back

9–::

  1c turn RH | cast off ; ½ Fig8 up round 2c and cross up to 1pl (2c steps in) ready for

17–::

  1c+2c Allemande

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (12485, '2020-01-06 23:06:09.92501+00', '2020-01-06 23:06:09.92501+00', 19817, 2, NULL, 'ace', '1-4::

   Walk 4 steps forward, turn towards each other and walk backwards to the same direction.

5-8::

   Repeat this direction.

9-12::

   Step towards each other, away each other, turn the outside person in front of to the middle.

13-16::

   Step towards, step away, turn partner under left arm to meet new partner.

', 1);
INSERT INTO 'dancecrib' VALUES (2974, '2012-01-22 19:30:05.214083+00', '2015-03-11 23:09:06.014895+00', 12538, 1, NULL, 'ace', '1–::

  All change places with P RH and join LH with next person | set in circle ; repeat, to places, all W facing out

9-24::

  Full Schiehallion Reels, to places, W facing out

25–::

  All M ½LHA _while{2}_ all W chase 1 place clw | join RH in wheel and set ; repeat [25-26] | Turn ½ RH to bring W to centre

33–::

  repeat [25-32] (to 3,4,1,2)

41–::

  repeat [25-32]

49–::

  repeat [25-32], but M finish BtoB in centre, facing P

57–::

  All set | All M set moving one place R _while{2}_ all W petronella turn to next place on R ; repeat

65–::

  All turn P RH ; Promenade cclw, guiding P to own place with LH

73–::

  1c+3c L-Chain

81–::

  2c+4c L-Chain

89–::

  Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (14384, '2021-10-12 08:52:53.115267+00', '2021-10-12 08:57:06.421227+00', 20512, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; all cross RH. 1c retain hands | 1c turn P RH ¾ to midline facing P

9--::

  1c set | cast off round 2cnrs[pos] to 2plx ; all cross RH. 1c retain hands | 1c turn P RH ¾

17--::

  Reels3 across, 1c RSh to 4cnrs. 1W between 2c face down, 1M between 3c face up

25--::

  1c set | cross RH ; dance RSh round 2cnrs to 2plx | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8867, '2015-08-26 20:29:42.305452+00', '2015-08-26 20:34:53.798336+00', 13887, 2, NULL, 'ace', '1 - 8::  1L sets adv to 1M, 1s turn RH (1L moving down set) & dance LH across with 2L

9-16::  1s dance RH acros with 2M, 1L followed by 1M dances across the set & casts off behind 2L to finish in 2nd pl opp sides (facing down)

17-24::  2s+1s+3s dance reels of 3 on sides (1s+3s passing LSh to begin)

25-32::  1s dance RH across (1M+2s & 1L+3s), 1s turn LH 1 1/4 to 2nd pl own sides

', 0);
INSERT INTO 'dancecrib' VALUES (8410, '2014-09-28 12:22:04.686833+00', '2014-09-28 12:24:11.576827+00', 3536, 1, NULL, 'ace', '1--::

  1c+3c cross down into ½ Fig8 (1x,2,3x,4) ; 1c+2c & 3c+4c ½ L-Ch up/dn (the M start across), all finish on the side beside own P, W facing out

9--::

  All W dance Lsh round P, finish BtoB on 2diag. facing P ; on both diags ½ Lsh Reel4, all couples finish in promhold with M on the L, with 1c/3c facing up in 2Mpl/4Mpl, and 2c/4c facing down in 1Wpl/3Wpl

17--::

  All in promhold ½ Rsh Reel4 [6 bars] | dance on to finish 4c+3c+2c in promhold facing up and 1c in 4pl 

25--::

  4c+3c+2c Allemande (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (9789, '2017-04-12 03:51:44.370961+00', '2019-01-28 22:44:58.657891+00', 15183, 1, 202, 'ace', '1--::

 Circle8 and back

9--::

 1c Fig8 on own sides round 2c+3c (start inwards)

17--::

 All turn RH ; turn LH

25--::

 All dance BtoB ; 1c cast to 4pl (2c+3c+4c up)', 2);
INSERT INTO 'dancecrib' VALUES (8411, '2014-09-29 09:10:06.373055+00', '2014-09-29 09:10:06.373055+00', 14350, 1, NULL, 'ace', '1--::

  1c lead down the middle and up

9--::

  1c+2c+3c Allemande (3,2,1)

17--::

  3c+2c S&Link ; 3c+1c S&Link (2,1,3) 

25--::

  All set | All cross RH ; All chase ½ clw (3,1,2)



{{explanation}}

This unusual progression works both in a 3C and a 4C set.

', 3);
INSERT INTO 'dancecrib' VALUES (15160, '2022-10-06 09:41:44.419606+00', '2022-10-09 09:44:30.002814+00', 21136, 1, 202, 'ace', '1--::
  Circle 8 and back (1,2,3,4)
9--::
  1c+3c The Swirl
17--::
  1W+3M+2c & 1M+3W+4c RHA ; LHA
25--::
  1c+3c RHA ; 1c (1M leading) & 3c (3M leading) chase clw outside the set to original places (1,2,3,4)
33-64::
  All repeat [1-32] with 2c+4c dancing The Swirl (1,2,3,4)', 4);
INSERT INTO 'dancecrib' VALUES (2219, '2012-01-22 19:29:26.392363+00', '2016-07-06 00:10:44.329792+00', 11773, 1, NULL, 'ace', '1–::

  1c set | cross RH ; cast off two (2c up) and dance up to face 1cnr

9-20::

  1c+1cnr set | change places RH, the 1cnrs pass Lsh and face 2cnrs ; 2W+3W & 2M+3M repeat ;; 1W+2W & 3M+1M repeat, 1c finish facing opposite side

21-24::

  All set as in DTr | 2c+3c chase 1 place clw _while{2}_ 1c (PdB) dance round each other to face down NHJ, W on the L

25–::

  1c dance between 3c | cast up ; dance between 2c | cast to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8394, '2014-08-28 04:16:28.901955+00', '2014-09-30 08:05:43.752331+00', 13595, 1, NULL, 'ace', '























































































































*Longwise set, any length, couple facing couple across, M has P on his R.*

1--::

  A&R twice

9--::

  All facing couples RHA ; LHA

17--::

  All dance BtoB with P ; BtoB with opposite

25--::

  Top two couples face down in line across making arches and haste to the bottom (all others step up)



*Some Possible Variants:*

1-8::

  All advance {3}, stamp and clap ; retire with stamp and clap

9-24::

  Switch 9-16 with 17-24; switch 17-20 with 21-24

', 4);
INSERT INTO 'dancecrib' VALUES (3489, '2012-01-22 19:30:27.587777+00', '2015-06-14 21:20:01.857225+00', 12635, 1, NULL, 'ace', '1–::

  1c+3c cross down to DblDTr position (2c+4c up) | All set ; 1c+3c dance Rsh round 1cnr to midline and face P

9–::

  1c+3c Reel4 on midline _while(8)_ 2c+4c+5c Lsh Reels3 on the sides, (4c starts in and L)

17–::

  1c+3c pass P RH and cast R round 2cnr ; Turn 1½ RH to (2,1,4,3,5)

25–::

  1c+4c & 3c+5c S&Link ; All C turn RH (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (8412, '2014-10-01 23:28:35.542128+00', '2014-10-04 10:35:12.958166+00', 2933, 1, NULL, 'ace', '1--::

  1c+3c ½ Reel4 on midline, to start dance Rsh round P ¾ ; 3c+1c turn P RH 1¼  to (3,2,1)

9--::

  All set to P | cross RH ; chase clw to (1,2,3)

17--::

  1c+2c ½ RHA and set ; 1c+3c ½ LHA and set (2x,3x,1)

25--::

  1c lead (LH) to top, cross and cast to 2plx (3c down) ; All set | cross RH (2,1,3); 

', 4);
INSERT INTO 'dancecrib' VALUES (8414, '2014-10-05 00:05:02.089132+00', '2020-03-06 21:01:02.644573+00', 12595, 1, NULL, 'ace', '1--::

  1c cast off (2c up) | dance down between 3c and cast up (2,1,3) | 2c+1c turn P RH ¾ to midline

9--::

  2c+1c Reel4 on midline

17--::

  2c+1c Turn P RH 1¼, and 1c face out ; 1c turn 3c EH (with polite turn) to (2,1,3)

25--::

  All dance BtoB and clap ; All turn RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1683, '2012-01-22 19:28:56.44216+00', '2020-11-15 13:10:13.461744+00', 240, 1, NULL, 'ace', '1–::

  1c cast (2c up) | all set ; cnrs chase ½ clw _while{4}_ 1c turn RH and face 3cnr (1cnrpers)

9–::

  ½ diag. Reel4 with 1cnrs ; repeat chase & turn, 1c face 2cnr

17–::

  ½ diag. Reel4 with 2cnrs ; cnrs set & change places on the sides _while{4}_  1c turn RH to face own side for

25–::

  DTr, with cnrs crossing RH to own side on [27-28] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13454, '2020-12-04 17:43:47.863324+00', '2020-12-04 17:48:59.051137+00', 19705, 1, 202, 'ace', '1--::
  1c+3c DblFig8, 1c crossing down (1,2,3)
9--::
  1M+2W cross RH _while{2}_ 1W & 2M set | 1W+2M cross RH _while{4}_ 1M & 2W set (to 2x,1x,3) ; 2c+1c ½ R&L (1,2,3)
17--::
  Inveran Reels3, 1c crossing down (1,2,3)
25--::
  1c lead down |turn P RH ½ ; lead up {1} (2c step up) then turn P BH {3} (skip change) 1½ to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2550, '2012-01-22 19:29:47.2766+00', '2019-12-10 08:05:09.718593+00', 13070, 1, NULL, 'ace', '1–::

  1c set, advancing on bar 2 | dance down NHJ (2c up) ; W passes under arm as M changes sides below her | dance up to DTr position opposite side

9–::

  DTr, finish facing 2cnr

17–::

  Turn 2cnr RH | P LH | 1cnr RH | P LH and face out to own side

25–::

  Reels3 on own sides, Lsh to 4cnr (to 2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (8415, '2014-10-05 00:46:29.605822+00', '2014-10-05 00:46:57.529952+00', 10713, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; 1c dance between 3c and cast up to (2,1,3)

9--::

  1c ½ Fig8 up between 2c ; All A&R (2,1x,3)

17--::

  2c+1c L-Ch

25--::

  1c ½ Fig8 between 3c ; All dance BtoB (2,1,3)



{{explanation}}

Can be danced as Reel, Jig or Strathspey

', 3);
INSERT INTO 'dancecrib' VALUES (8417, '2014-10-05 08:50:51.073485+00', '2014-10-05 08:50:51.073485+00', 15405, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; 1c ½ Fig8 round 2c (2,1x,3)

9--::

  2c+1M & 1W+3c Reel3 across, Lsh to 3cnr (2,1x,3)

17--::

  1c set | turn RH ¾ ; 2c+1M & 1W+3c LHA to (2,1,3)

25--::

  2c+1c R&L (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10560, '2018-03-29 11:47:16.661725+00', '2020-10-18 10:34:26.762515+00', 17052, 1, 202, 'ace', '1--::

  1c lead down (2c up) ; and up, cross over to finish BtoB between 2c facing opposite sides

9--::

  1c+2c Reel4 across

17--::

  1c set to 2c, 1M+2W turn RH as 1W+2M turn LH to 2plx ; 1c set | cross RH (2,1)

25--::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (8418, '2014-10-05 09:32:55.414224+00', '2014-10-05 09:32:55.414224+00', 14216, 1, NULL, 'ace', '*One chord, 3c+4c start on opposite side (1,2,3x,4x)*

1--::

  1c+2c & 3c+4c S&Link, finish 1c facing 4c (no polite turn) ; 1c+4c set | turn opposite RH (2,1,4x,3x)

9--::

  2c+1c & 4c+3c LHA, to sidelines ; 1c+4c RHA, finish in promhold facing out and R on the side the M started (W make polite turn), 

17--::

  2M+1c+3W & 2W+4c+3M Rsh Reels3 on the sides, finish (2,4x,1,3x) with 2c & 3c facing in and 4c+1c ready to cast 

25--::

  2c+4c & 1c+3c ¾ Dbl Fig8 | change place EH on the side (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (12474, '2020-01-04 23:52:18.602589+00', '2020-01-22 09:06:17.020433+00', 19805, 1, NULL, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 up (2,1,3)

9--::

  1c+3c Turn LH on sides ; 2c+1c turn RH on sides  

17--::

  Parallel Reels3 on the sides, 1c Rsh to 2c (2,1,3)

25--::

  1c dance to top and cast to bottom (3c up) ;  All Turn P BH (2,3,1)  



*crib is doubtful*





', 1);
INSERT INTO 'dancecrib' VALUES (8420, '2014-10-07 15:15:02.207564+00', '2014-10-07 15:15:02.207564+00', 10423, 1, NULL, 'ace', '1--::

  1c+2W Reel3 across (1W Rsh to 1M) finish in line across 1W (on M side)+ 1M+2W facing down,, on [8] 2M steps in to face 1M

9--::

  All dance down (2M backwards), on [4] the W join 2M in line across ; All dance up (1M backwards), finish in middle (1x,2)

17--::

  Poussette (2,1x)

25--::

  1c ½ Fig8 round 2c ; 1c turn 2c EH on the sides (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8421, '2014-10-07 20:43:55.563172+00', '2014-10-07 20:47:07.594124+00', 15631, 1, NULL, 'ace', '1--::

    1c+2c set | turn BH ; open into Circle L (1,2,3)

9--::

  1c lead down {3}, up and cast to 1cnr (2c up) 

17--::

  CPCP to (2,1,3)

25--::

  Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8423, '2014-10-07 22:01:12.059087+00', '2014-10-07 22:01:12.059087+00', 15652, 1, NULL, 'ace', '1--::

  1c+2c Espagnole, 1c finish facing 1cnr

9--::

  1c+1cnrs Diagonal Reel4, at end pass Lsh to face 2cnr

17--::

  1c+2cnrs Diagonal Reel4, finish Lsh to Lsh facing opposite sides 

25--::

  2c+1W & 1M+3c RHA ; all cpls turn BH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11230, '2018-10-01 12:02:42.265967+00', '2018-10-01 12:07:48.822174+00', 18675, 1, 202, 'ace', '1--::

  Parallel Reels3 on sidelines, 1c RSh to 2c. 1W faces out (1,2,3)

9--::

  1W cast (2W up) | all set ; 1W cast to 3pl (3W up) | all set

17--::

  3C Bourrel. On [23-24], all turn P LH to opposite sides (3x,1x,2x)

25--::

  3C S&Link twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10024, '2017-07-23 18:30:26.461019+00', '2022-10-08 23:49:13.088993+00', 17892, 1, 202, 'ace', '1--::
 1c+2c RHA ; LHA
9--::
 1c lead down | set RHJ ; lead up | cast to 2pl (2c up) (2,1,3)
17--::
 1c+3c DblFig8, 1c crossing down (2,1,3)
25--::
 Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (8424, '2014-10-07 22:43:53.814388+00', '2014-10-07 22:43:53.814388+00', 15654, 1, NULL, 'ace', '1--::

  1M, with 2M+3M following, dance across the top, down behind opposite side, and up the middle _while{8}_ All W wait {4} ; set advancing, and turn single R to finish in promhold with P

9--::

  All promenade, 1c cast off and 2c dance up (2,1,3)

17--::

  2c+1W & 1M+3c RHA ; with 1c leading Rsh Snake Pass to (3,1,2)

25--::

  1c turn LH to sideline facing 4cnr ; ½ Reel3 on side, Lsh to 4cnr (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1902, '2012-01-22 19:29:08.937253+00', '2017-07-07 13:54:39.801017+00', 1017, 1, NULL, 'ace', '1–::

  1c+2c+3c ½Reel3 on own sides, 1c starting by going in and down ; 3c+2c+1c turn partners RH

9–::

  3c+2c+1c ½Reel3 back to original places (continue in the same reel) ; 1c+2c+3c turn partners RH

17–::

  1c lead down the middle {3}, lead up {3} and cast to 2pl (2c up)

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (2670, '2012-01-22 19:29:52.425001+00', '2020-04-11 23:18:03.174631+00', 3788, 1, NULL, 'ace', '1–::

  1c lead down, cross below 2c and cast to top ; 1c facing 2c set | 1c+2c set facing diagonally, 1c finish together facing down (1x,2)

9–::

  1c in promhold Rsh Reel3 across with 2c, on [15-16] 1c turns LH ½ to own side (1,2)

17–::

  1c+2c set | turn BH (1c ½, 2c full turn) finishing M on L facing other couple ; advance up/dn {1} retire {1} | advance {1}, retire to sidelines (1x,2)

25–::

  1c+2c set to P | turn BH 1¼ to form a line on the midline, M joining LH ; the line wheels ½ cclw and all face P, then 1c (with RH) and 2c (with LH) turn ¾ to (2,1).

', 3);
INSERT INTO 'dancecrib' VALUES (12562, '2020-02-04 01:29:55.246463+00', '2020-02-04 01:55:05.166344+00', 8312, 1, NULL, 'ace', '1--::

  1W+2M change place RH and cast clw to places ; 1c+2c RHA 

9--::

  1M+2W change place LH and cast cclw to places ; 1c+2c LHA,  finish NHJ in circle(1,2)

17--::

  All set | Circle L ½ ; set | Circle L ½ (1,2)

25--::

  1c+2c Espagnole (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9788, '2017-04-11 13:53:46.406976+00', '2020-09-03 08:14:40.617468+00', 5516, 1, 202, 'ace', '1--::

 1c turn RH to 2pl centre facing out (2c up) ; cast L to between end couples | All in lines across set

9--::

 1c cast to 2pl | turn LH | 2c+1c+3c set

17--::

 1c teapots R ; passing *Lsh*, 1c teapots L then face 1cnrs

25--::

 1c+1cnrs ½ Reel4 ; 1c+2cnrs ½ Reel4 (3x,1,2x)

33--::

 Diagonal R&L (1M down, 1W up) (2,1,3)

41--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (8419, '2014-10-05 20:21:08.215316+00', '2020-04-18 23:17:25.671517+00', 7943, 1, NULL, 'ace', '1--::

  1c+5c cross RH | cast in (2c+4c to ends) ; ½ Fig8 round end cpl (2,1,3,5,4)

9--::

  2c+1W & 1M+3c+5W & 5M+4c Reels(3/4/3) across, 1c+5c finish facing 1cnr 

17--::

  1c+5c each CPCP “in own square”

25--::

  2c+1W & 1M+3c+5W & 5M+4c RHA, and 1c & 5c change to other wheel ; 2c+1M & 1W+3c+5M & 5W+4c LHA, 1c+5c finish on midline M above W

33--::

  1c+5c ½ Reel4 on midline ; 5c turn RH 1¼ to sides while{4} 3W+1W & 3M+1M turn 1¾ EH (3c start inwards) to (2,5,1,3,4)



', 2);
INSERT INTO 'dancecrib' VALUES (13455, '2020-12-05 00:02:36.728291+00', '2020-12-05 00:07:51.307887+00', 10690, 1, 202, 'ace', '1--::

  1c Mirror Fig8 on sides starting between 2c (1,2,3)

9--::

  Mirror Reels3 on opposite sides, 1c crossing to 2plx (1,,2,3)

17--::

  Mirror Reels3 on own sides, 1c crossing to 2pl (1,2,3)

25--::

 1c lead down {3}, lead up {3} | cast off (2c up) (2,1,3)



*Deviser''s note:*  

On second time through, 1c cast to the bottom and bottom couple step up on [31-32].', 2);
INSERT INTO 'dancecrib' VALUES (9264, '2016-07-13 20:24:16.673845+00', '2018-10-14 13:54:28.154164+00', 17137, 1, 1041, 'ace', '*Cpl face cpl Round the Room*   

1--::  W turn RH 1¼ _while_ M chase round set clw ¾ (all to P''s place) ; repeat from exchanged places (1,2)

9--::  All set NHJ, advancing on 2nd step | join hands with opposite and set, retiring on 1st step ; RHA

17--::  All set, advancing on 2nd step | join hands with P and set, retiring on 1st step ; LHA

25--::  All dance BtoB with opposite ; pass opposite Rsh and meet next cpl (2,1)

', 4);
INSERT INTO 'dancecrib' VALUES (8422, '2014-10-07 21:21:42.485509+00', '2018-08-19 22:28:00.029568+00', 15634, 1, NULL, 'ace', '1--::

  1c+2c S&Rotate (2,1,3)

9--::

  1c ½ Fig8 through 3c ; ½ Fig8 through 2c (2,1,3)

17--::

  1c+3c RHA ; 2c+1c LHA

25--::

  Parallel Reels3 on the sides, 1c Rsh to 3c, (2,1,3)

33--::

  Circle6 and back

', 3);
INSERT INTO 'dancecrib' VALUES (2608, '2012-01-22 19:29:49.762252+00', '2014-10-13 00:26:03.888059+00', 12124, 1, NULL, 'ace', '1--::

  All Set | [1c+3c+5c petronella to midline ; Set to P | petronella to opp.side] _while{6}_ [2c+4c cast 1 place clw (M up, W down) ; cross between the setting couple (2W+4M pass RH) | cast R to face P on midline (M below W)]

9--::

  2c+4c Reel4 on midline, finish facing own side

17--::

  1c+2W & 2M+3c+4W & 4M+5c LHA to opp. sidelines ; All set | all cross RH (1,2,3,4,5)

25--::

  1c+2c & 3c+4c S&Link ; 1c+4c & 3c+5c S&Link (2,4,1,5,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8199, '2014-02-14 10:34:19.399332+00', '2015-06-28 14:49:36.570966+00', 8159, 2, 776, 'ace', '_Formation:_ couples around the room in heading anti-clockwise, nearer hands joined, ladies on the outside. 







_Slow march_



1-8:: 	With nearer hands joined, walk slowly along the line of dance

9-16:: 	With nearer hands joined, walk slowly against the line of dance back to starting point



_Waltz_



17-20::	With nearer hands joined, facing along line of dance, balance away from partner and back towards partner twice. 

21-24::	Waltz along line of dance. 

25-32::	Repeat bars 17-24. 



_Polka_



33-36::	With nearer hands joined, facing along line of dance, balance away from partner and back towards partner twice. 

37-40::	Polka along line of dance. 

41-48::	Repeat bars 33-40.





Source: http://www.scottishdance.net/ceilidh/dances.html#SwedishMasquerade', 0);
INSERT INTO 'dancecrib' VALUES (8426, '2014-10-14 07:35:51.036795+00', '2014-10-14 07:35:51.036795+00', 11991, 1, NULL, 'ace', '1--::

  1c+2c S&Rotate (2,1,3)

9--::

  ½ Reels3 on the sides, 1c Lsh to 3c ; All set | 3c+1c ½ RHA as 2c cross RH (1x,3x,2x)

17--::

  All S&Link3 twice (2,3,1)

25--::

  Circle6 and back (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2329, '2012-01-22 19:29:31.753518+00', '2014-10-14 22:00:50.286667+00', 2494, 1, NULL, 'ace', '{{title}}

Strathspey



{{explanation}}

part



1–::

  1c+2c turn partners ¾ BH to centre line | ½Reel4 | turn BH, 2c to 1pl with 1M between 2c and 1W between 3c, all facing down

9–::

  1W (1M) lead 3c (2c) down the middle ; all turn R about and lead up, to finish line facing line across



{{title}}

Reel



{{explanation}}

part



17–::

  All clap, ½ Reels3 on sides, Rsh to 1cnr ; 1c turn RH to finish facing in lines across (1W between 3c at top and 1M between 2c)

25–::

  All clap, ½ Reels3 on sides, Lsh to 2cnr position ; 1c turn 1¼ LH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3643, '2012-08-23 21:06:24.048293+00', '2014-05-14 15:05:13.735653+00', 14533, 1, NULL, 'ace', '1–::

  Inveran Reels3 on the sides, 1c crossing down to start (1,2,3)

9–::

  1c+2c DblFig8, 1c cross down to start

17–::

  1c lead down the middle and up, finishing for

25–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (11228, '2018-10-01 11:00:55.024928+00', '2018-10-01 11:04:30.406585+00', 16290, 1, 202, 'ace', '1--::

  1c cast behind own lines and back (1,2)

9--::

  1c lead down {3}, lead up {3} | cast to 2pl (2c up) (2,1)

17--::

  2W+1M cross RH and loop R round P to places ; 2c+1c RHA (2,1)

25--::

  2M+1W cross LH and loop L round P to places ; 2c+1c LHA (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (8427, '2014-10-17 20:52:16.240264+00', '2014-10-17 22:41:58.283686+00', 15282, 1, NULL, 'ace', '1--::

  1c+2c Mirror S&Link (1c cast, 2c dance up) ; 1c turn LH to face out M side, M below W and NHJ

9--::

  1c Mirror Figs8 across, M round 3c, W round 2c and finish between end couples facing P _while{8}_ 2c+3c dance Mirror BtoB, W pass between M to start ; repeat with other shoulder.  

17--::

  1c dance BtoB ; turn RH 1¼  (2,1,3)

25--::

  Circle6 and back

', 3);
INSERT INTO 'dancecrib' VALUES (15158, '2022-10-05 12:21:07.597168+00', '2022-10-09 09:40:03.68937+00', 21139, 1, 202, 'ace', '1--::
  1c+2c Mirror Set&Link, 1c casting off (to 2,1,3) ; 1c cross RSh | cast off to 2pl centre facing up
9--::
  Mirror Reels3 on sides {6}, 1c out and up, 2c in and down | 2c+1c continue the reel to exchanged places. 2c face out (1x,2,3)
17--::
  1c+2c turn EH ½ on sides | 1c cast up to 1plx _while{2}_ 2c cross down to 2plx and face out (to 1x,2x,3) ; 1c dance down | turn P BH ½ to 2pl _while{4}_  2c cast up | cross RH (2,1,3)
25--::
  1c+3c The Espagnole (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (8428, '2014-10-17 23:19:05.69401+00', '2014-10-19 13:10:34.110403+00', 15413, 1, NULL, 'ace', '1--::

  1M+3M set adv and swivel R to face P | set to P ; 1c+3c ½ Reel4, on [7-8] 2M+4M dance into the centre and 1W+3W finish in opposite places

9--::

  All M LHA, on [12] 1M+3M dance out next to P and 2M+4M face P ; 2c+4c ½ Reel4, finish all M in the middle facing P

17--::

  All set | turn P LH ¾ into circle facing P ; All dance BtoB

25--::

  All pass P Rsh and the M face R about | all chase 1 place cclw ; All turn P LH



*In the next rounds 2M+4M start, then 1W+3W, then 2W+4W.  When the W start, the half reels4 are Lsh and the W start in the middle; the women’s wheel [9-12] is RHA; and the ¾ turn of [19-20] is RH.  However, [25-32] is unchanged.*

', 3);
INSERT INTO 'dancecrib' VALUES (8429, '2014-10-18 12:22:43.749401+00', '2014-10-19 14:14:33.339512+00', 13884, 1, NULL, 'ace', '1--::

  1M+2M dance Rsh round 2W/3W, dance up and face W side ; with hands as DDTr set | cast to own place

9--::

  1W+2W dance Lsh round 2M/3M, dance up and face M side ; with hands as DDTr set | cast to own place

17--::

  1c cross RH | cast off (2c up) ; ½ Fig8 L (M down, W up)  (2,1,3)

25--::

  Circle6 and back



*After each second time through, 1c step down on [1-2] as 4c step in and up to 3pl.*', 2);
INSERT INTO 'dancecrib' VALUES (8140, '2013-12-25 23:42:03.821531+00', '2015-02-21 00:54:21.729942+00', 8158, 1, NULL, 'ace', '{{explanation}}

Couples form big circle Round the Room, W on the R of M.



1–::

  All advance {4} ; retire {4}

9–::

  All W A&R ; All M advance and pivot R | dance back to face P

17–::

  All set twice ; All turn P RH into promhold facing rond (M inside)

25–::

  All promenade cclw, finish in circle as before

33–::

  All Circle L



{{explanation}}

The dance becomes progressive if the man dances to the next W on [15-16].', 3);
INSERT INTO 'dancecrib' VALUES (13780, '2021-03-02 11:28:15.261083+00', '2021-03-02 12:14:45.185929+00', 18909, 1, 202, 'ace', '1--::

  1M+2W change places RH | 1W+2M & 1M+3M change places LH ; 1W+3W change places RH | all set (2x,3x,1)

9--::

  2c cross RH _while{2}_ 3c+1c RHA ½ (to 2,1x,3) | 2c (2W leading) & 3c (3M leading) chase clw ½ to exchanged places (to 3x,1x,2x) | all set, 1c advancing to face 3cnrs[pos]

17--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2 diag and face 1cnrs

25--::

  Corners Pass and Turn (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8715, '2015-03-09 23:54:24.299187+00', '2015-03-14 17:18:02.344157+00', 16156, 1, NULL, 'ace', '1--::

  1c cross down into mirror reels on the sides (1x,2,3)

9--::

  1c dance down | change place (W under joined arms) and face up ; dance up and cast to 2pl (2c up) (2,1,3)

17--::

  1c set adv and pivot R | set as in DTr ; 1c Gipsy Rsh round P to (2,1,3)

25--::

  All Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8678, '2015-02-19 14:33:24.931352+00', '2015-03-19 13:18:23.321549+00', 12767, 2, 524, 'ace', '1-8::

 1c+2c+3c cross RH, chase clw 1/2 way round and cross RH (3x 2x 1x)

9-16::

 1c set| cast up (2c down); lead up, cross, cast (3x 1 2x)

17-24::

 1c RH across (W with 3c, M with 2c)| LH across (W with 2c, M with 3c)

25-32::

 Diagonal R & L (1m down, 1w up) (2 1 3)', 3);
INSERT INTO 'dancecrib' VALUES (2079, '2012-01-22 19:29:18.683193+00', '2021-02-06 11:22:38.436021+00', 10669, 1, NULL, 'ace', '1–::

  1c set | cross down (2c up) ; cast round 3c up to 2pl (2,1x,3)

9–::

  Mirror Reels3 on the sides, 1c starts out and up (2,1x,3)

17–::

  S&Link3 ; 1c turn BH 1½ _while_{4} cnrs chase clw 2 places (to lines across, 1M up between 2c, 1W down between 3c) (2x,,3x)

25–::

  S&Link3 ; 1c turn BH twice _while_{4} cnrs chase clw 2 places (3x,1x,2x)

33–::

  1c chase clw ½ _while_{4} [3W+2M cross RH | 3M+2W cross RH] ; All Turn P  (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2989, '2012-01-22 19:30:05.81386+00', '2014-10-27 00:27:00.48625+00', 5179, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; turn LH to 1cnr

9–::

  Turn CPCP, finish facing 1cnrs

17–::

 “Corners Pass and Turn” (1c+1cnrs pass Rsh, and 1cnrs turn RH | pass back and 1c pass Rsh to face 2cnr ; repeat with 2cnrs) (2,1,3)

25–::

  2c+1c+3c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (14306, '2021-09-11 00:42:09.858852+00', '2021-09-11 01:07:13.346639+00', 17478, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::
  1c+2c & 3c+4c 4 bars of Espagnole (to 2,1,4x,3x) ; 2c & 3c turn RH _while{4}_ 1c+4c LHA. 1c & 4c BtoB in centre face nearest cnrs into St Andrews Cross
9--::
  1c+4c Double SetH&G. 1c & 4c face diagonally opposite cnrs
17--::
  Reels4 on sides (2,4,1x,3x)
25--::
  4c & 1c ½Fig8 round nearest ends (to 2,4x,1,3x) ; 4c & 1c cross RH | all set (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (8430, '2014-10-19 22:27:48.218796+00', '2014-11-09 00:29:37.484111+00', 15678, 1, NULL, 'ace', '::

  *Couples in circle RR, facing inward.*

:: 

  *On first chord take RH and bow to P; on the second turn into Allemande hold facing cclw*

1--::

  Allemande, finish in two circles, M outside, W inside 

9--::

  Pass Rsh with next person opposite to the L, and cast R to P’s place (½ Fig8 L) ; Set adv. to P | turn P BH ¾ into one circle, and face P (M face cclw, W clw)

17--::

  ¾ interlocking Reels4 (all start as if in end position) | set to P (M face clw. W cclw)

25--::

  Turn P RH {3}, pass P and next person Rsh {3} | Turn next person RH ¾ into Allemande hold facing cclw

', 3);
INSERT INTO 'dancecrib' VALUES (1946, '2012-01-22 19:29:11.290062+00', '2014-04-30 23:23:44.301684+00', 1210, 1, NULL, 'ace', '1–::
  1c+2c R&L
9–::
  1c+2c set twice to P ; turn P BH
17–::
  L-Chain
25–::
  Poussette (to 2,1), and join adjacent couple', 3);
INSERT INTO 'dancecrib' VALUES (11488, '2019-01-03 01:22:54.637318+00', '2019-01-03 01:29:50.33902+00', 11553, 1, 202, 'ace', '1--::

  1c+2c set | 1c cast (2c dance up) ; 2c+1c ½ DblFig8, 1c crossing up. 2c face out (2x,1x)

9--::

  Espagnole up/dn, 1c leading up. On [13-16] turn RH 1½ on W side, LH 1½ on M side (1,2)

17--::

  The Tourbillon (2,1)

25--::

  2c+1c set | Turn Halfway and Cast | cross RH (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (9791, '2017-04-12 18:58:23.218839+00', '2017-04-13 23:16:30.567053+00', 17711, 1, NULL, 'ace', '1--::

  All set | turn P RH ½ and cast to opposite side | chase ¼ round clw into facing lines across (M below W)

9--::

  All set | turn P RH ½ and cast to opposite line | chase ¼ round clw into (3x,2x,1x)

17-20::

  3c+2c ½ RHA as 1c turn RH ½ | All set (2,3,1)

21-32::

  R&L for 3 couples (2,3,1)

', 4);
INSERT INTO 'dancecrib' VALUES (8431, '2014-10-28 12:53:18.107651+00', '2014-10-28 12:53:18.107651+00', 13567, 1, NULL, 'ace', '1--::

  1c cast (2c up) | Reels3{6} across, 1c Lsh to 1cnr 

9--::

  1c turn 1chr RH | pass Rsh ; Turn 2cnr RH | cross Rsh to (2,1,3)

17--::

  All set | 1c dance between 3c and cast to top (2c down) | 1c+2c set advancing into

25--::

  1c+2c Half Poussette, and 3c dance in ; 1c+3c Half poussette (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2658, '2012-01-22 19:29:51.889711+00', '2014-11-05 14:04:28.434162+00', 13081, 1, NULL, 'ace', '1–::

  2c turn RH ½ and twirl R to opp. side ; 1c+3c repeat _while{4}_ 2c cast R to between end cpl

9–::

  2c turn LH 1½ _while{4}_ 1c+3c chase ½ clw ; 3c+2M & 2W+1c RHA, 2c finish facing 3cnr (position)

17–::

  Reel4 on 1diag, 2c pass Lsh to face 2cnr

25–::

  Reel4 on 2diag (3,2,1)

33–::

  3c+2c turn RH ½ | ½ RHA ; 3c+1c turn RH ½ | ½ RHA (2,1,3)

41–::

  All set | cross RH ; Chase ½ clw (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (12434, '2019-12-11 23:23:24.407277+00', '2019-12-11 23:50:16.767647+00', 17462, 1, NULL, 'ace', '1--::

  Circle8 and back

9--::

  1W, the other W following, cross and cast behind 1M, 1W alone loops round 1M _while_ 2W, with 3W, 4W and 1W following dance behind opposite sideline to bottom, cross and cast up on own side, finishing  in order (2,3,4,1)

17--::

  the M repeat figure [9-16] (2,3,4,1)

25--::

  All dance BtoB with P ; All turn P RH or Birl (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (11229, '2018-10-01 11:47:27.685203+00', '2018-10-01 11:53:14.255191+00', 18674, 1, 202, 'ace', '1--::

  1W+2W+3W A&R | set _while{6}_ 1M+2M+3M set | A&R | 1c & 3c turn P RH ½ and face down/up _while{2}_ 2c cross RH and face out (1x,2x,3x)

9--::

  ½ Mirror Reels3 on sidelines, 1c in, 2c up and out (to 3x,2x,1x) ; 1c turn 2c EH on sidelines 1½, 1c face 1cnrs[pos]

17--::

  SetH&G. On [23-24] 1c Petronella Turn to 2pl (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11231, '2018-10-01 12:23:46.838136+00', '2018-10-01 12:30:48.902056+00', 18676, 1, 202, 'ace', '1--::

  1c cross | cast  _while{4}_ 3c turn 2c on sidelines EH (3c up and out) to 1pl ; 1c ½ Fig8 up round 3c (3,1,2)

9--::

  Repeat [1-8] same pattern (2,3,1)

17--::

  2c+3c ½ RHA | 2c+1c ½ LHA ; 2c cross LH | all set (3x,1x,2x)

25--::

  3C S&Link twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12885, '2020-06-10 07:29:03.981539+00', '2020-06-10 07:46:15.993299+00', 17397, 1, 202, 'ace', '1--::

  1c dance down _while{4}_ 3c dance up making arche ; repeat [1-4] 1c making arche all back to original places (1,2,3)

9--::

  1c & 3c Petronella in tandem _while{2}_ 2c Petronella | all set ; repeat [9-12] (3x,2x,1x)

17--::

  3c cross down no hands to 3pl _while{2}_ 1c dance up outside to 1plx _while{2}_ 2c set (to 1x,2x,3) | 1c+2c 6 bars of DblFig8, 1c crossing down (2,1x,3)

25--::

  1c set twice ; turn P RH 1½ _while{8}_ 2c & 3c turn P RH ; set twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1608, '2012-01-22 19:28:50.668196+00', '2020-11-15 13:17:37.328522+00', 6532, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  All dance interlocking Rsh Reels4

9–::

  1c+3c turn P ¾ RH | Promenade clw ½ round set | ½ RHA to places _while{8}_   2c+4c (face P) Petronella Turn | set (others pass between) ; Petronella Turn | turn RH ½ to places

17–::

  Repeat with exchanged figures (1c+3c Petronella Turn etc ; 2c+4c turn ¾ RH, etc)

25–::

  Circle8 and back

33–::

  All C set to and turn P RH ; set to and turn cnr LH (and W face out)

41-56::

  Schiehallion reel

57–::

  All C turn P RH | turn cnr LH ; repeat



{{title}}

Reel



65-120::

  Repeat [1-56] in reel time ;

121-128::

  All C turn R elbow grip ; turn L elbow grip (or 8 bars R elbow grip)', 3);
INSERT INTO 'dancecrib' VALUES (3642, '2012-08-21 21:49:08.059946+00', '2020-11-15 13:19:15.803239+00', 14531, 1, NULL, 'ace', '1-4::

  1W dances a clw circle in front of 1M , to own place facing down

5-12::

  2c+3c RHA, LHA _while{8}_ 1W, 1M following, dance down W side, cross below 3c, up M side, and to places (1,2,3)

13-16::

  1c set | set advancing and passing, finish BtoB in 1pl

17–::

  1c&2c turn EH ½ on the sides (to 2,1x,3) | 1c ½ Fig8 round 2c (2,1,3) | 1c set advancing to face 1cnr

25–::

  1c turn 1cnr RH into lines across | all set ; 1c petronella to 2plx and cross to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13457, '2020-12-06 10:20:42.309314+00', '2020-12-06 10:21:29.504451+00', 19984, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 L round 4cnrs then face 1cnrs

9--::

  ½ Reel4 on 1diag (cnrs can twirl), pass RSh ; ½ Reel4 on 2diag (cnrs can twirl) to 2plx (3x,1x,2x)

17--::

  All chase cclw ½ ; all birl (2,1,3)

25--::

  Circle6 L. All twirl on [28] ; Circle6 R', 2);
INSERT INTO 'dancecrib' VALUES (8433, '2014-11-03 23:44:21.54158+00', '2014-11-03 23:44:21.54158+00', 8482, 1, NULL, 'ace', '1--::

  1c+2c Circle4 and back

9--::

  1c cross down RH between 2c, cast off ; cross up RH between 3c and cast up to 1pl (2c step in), finish for 

17--::

  1c+2c Rondel (2,1,3)

25--::

  2c+1c+3c G-Chain (2c cross to start)

', 4);
INSERT INTO 'dancecrib' VALUES (10034, '2017-08-01 13:44:47.50238+00', '2020-10-09 08:09:07.143163+00', 15371, 2, 160, 'ace', '1-8::

  Turn RH, cast 1 place ; cross down RH & cast up behind 3C. 2 1x 3

9-16::

  Mirror Reel3 on sides- 1C in&up to begin.

17-24::

  1C cross up RH, cast behind 2C ; Turn RH. 2 1 3

25-32::

  Mirror reel3 on sides 1C in&down.

33-40::

  Six hands round & back.', 0);
INSERT INTO 'dancecrib' VALUES (8434, '2014-11-05 11:15:52.152613+00', '2014-11-05 11:15:52.152613+00', 15697, 1, NULL, 'ace', '1--::

  1c+4c set | 1W & 4M, with P following, cast clw half round the set (4x,2,3,1x) | 4c+1c curve R about into middle places as  2c+3c step to end, finish  middles facing ends (2,4x,1x,3)

9--::

  Reels4 on the sides (2,4x,1x,3)

17--::

  2c+4c & 1c+3c turn RH on the sides, 4c passing 1c Rsh at the turn’s end (with polite turns) (2,1x,4x,3) ; 1c+4c set to P | turn RH ½ and face up

25--::

  1c+4c Allemande (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3774, '2013-07-13 15:56:01.654926+00', '2014-04-30 23:23:44.798928+00', 14552, 1, NULL, 'ace', '1–::
  1c+2c Set&Rotate (2,1,3)
9–::
  1c cross RH | cast R round 1cnr ; cross up/dn LH | cast L to face 1cnr
17–::
  1c+1cnrs corners pass and turn, pass Rsh ; repeat with 2cnrs, to own side
25–::
  Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8682, '2015-02-23 01:02:35.336127+00', '2015-02-23 01:15:02.775742+00', 16106, 1, NULL, 'ace', '1--::

  2c+3c Poussette (1,2,3,4)

9--::

  1c+2c & 3c+4c RHA, All finish NHJ with P, 1c+2c facing up and 3c+4c facing down ; 2c+3c dance out the end and cast to end place _while{4}_ 1c+4c cast to the middle and finish ready for

17--::

  1c+4c Allemande (2,4,1,3)

25--::

  Circle8 and back

', 3);
INSERT INTO 'dancecrib' VALUES (1901, '2012-01-22 19:29:08.886856+00', '2015-02-23 12:31:52.218834+00', 13581, 1, NULL, 'ace', '1–::

  1c+2c Set&Rotate, finish 1c facing 2c (2,1,3)

9–::

  Rsh Reels3 on the sides

17–::

  1c set | turn ¾ RH ; 2c+1W & 1M+3c LHA (to 2,1x,3)

25–::

  1c set | turn ¾ RH ; 2c+1M & 1W+3c LHA (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9266, '2016-07-13 20:35:50.962333+00', '2018-10-14 14:08:06.799302+00', 17139, 1, 1041, 'ace', '1--::  All Circle8 & back  

9--::  Reels4 on the sides  

17--::  1c followed by 2c+3c+4c cast off behind own lines ; meet and dance up to finish in the middle  

25--::  1c retain hands and set twice | cast off to 4th place _while{8}_ 2c+3c+4c Promenade, and finish in (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (8681, '2015-02-23 00:47:59.311094+00', '2015-02-23 21:25:02.704991+00', 16107, 1, NULL, 'ace', '1--::

  1c cross down into mirror reels on opposite sides (1x,2,3)

9--::

  1c lead down {3}, up {3} | cross and cast off (2c up) (2,1,3)

17--::

  1c fig8 to the R (W up M down)

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8684, '2015-02-24 08:12:46.848684+00', '2015-02-24 08:12:46.848684+00', 16110, 1, NULL, 'ace', '1--::

  All Petronella to midline facing P | Set ; ½ Reel 4

9--::

  All turn P RH, to midline ; ½ Reel4, finish in places (1,2)

17--::

  1c+2c The Knot (2,1)

25--::

  1c Fig8 round 2c (cross up)

33--::

  2c Fig8 round 1c (cross down)

41--::

  All set to P | Turn P BH ; open to Circle4 L (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8726, '2015-03-14 18:29:59.034753+00', '2015-03-14 18:52:44.610332+00', 16161, 1, NULL, 'ace', '1--::

  1c turn RH ¾ moving down (2c up) and face P RHJ | 1c La Baratte, [turn RH ½ ; change place up/down, W under arms | turn LH ½] to finish facing 3cnr

9--::

  1c+3cnrs ½ Diag Reel4, pass Rsh ; 1c+4cnrs ½ diag Reel4, pass Rsh to face 1cnr (pos)

17--::

  “1cnrs Pass & Turn” _while{4}_ 2cnrs chase ½ clw ; “2cnrs Pass & Turn” _while{4}_ 1cnrs chase ½ clw 

25--::

  Circle6 and back (2,1,3)



Repeat from 2nd place in Reel time.

', 3);
INSERT INTO 'dancecrib' VALUES (11491, '2019-01-04 01:06:52.273123+00', '2019-01-04 01:10:51.757583+00', 6744, 1, 202, 'ace', '1--::

  1c set | cast to 3pl (2c+3c up) ; set | cross up to 2plx (3c down) (2,1x,3)

9--::

  2c+1c DblFig8, 2c crossing down (2,1x,3)

17--::

  1c+3c DblFig8, 3c crossing up. 1c in DTr[pos] face opp side (2,1x,3)

25--::

  DTr (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11492, '2019-01-04 01:32:05.818453+00', '2019-01-04 01:34:45.310995+00', 1470, 1, 202, 'ace', '1--::

  1c set | cast to 3pl (2c+3c up) ; set | cross RH (2,3,1x)

9--::

  1c set to 3c | change places LH on W side, RH on M side ; 1c set to 2c | turn RH on W side, LH on M side (2,1x,3)

17--::

  Reels3{6}, 1c in and down, 3c out and up | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11493, '2019-01-04 14:28:47.75229+00', '2019-01-04 14:29:00.566364+00', 19037, 1, 1645, 'ace', '1-::

  1c+2c S&Link ;  1c+3c S&Link, 2M turns to face out (2,3,1)

9-::

  2c+3c+1c RSh Reels3, 1c end in centre facing up

17-::

  1c lead up LH, cross & cast round 2c (2,1x,3) ; turn 1&frac12; RH (2,1,3)

25-::

  2c+1c poussette (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (8683, '2015-02-24 00:26:13.68025+00', '2015-02-24 00:28:02.2224+00', 16109, 1, NULL, 'ace', '1--::

  Snowball Chain, to start 1c+2c change places RH, continue as Gr-Chain. (3x,1x,2x)  

9--::

  3c (casting) + 2c (crossing up) ½ DblFig8 round 1c ; 1W+2c & 1M+3c ½ Fig8 L (Rsh to 4 cnr pos) (3,1,2)

17--::

  All cross RH | chase ½ round clw | all turn P RH ½ into promhold

25--::

  All Promenade (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8441, '2014-11-12 11:04:50.003322+00', '2014-11-12 11:04:50.003322+00', 15460, 1, NULL, 'ace', '*Couple face couple RR*

1--::

  All Circle 4 and back

9--::

  RHA ; LHA

17--::

  W to W A&R ; M repeat

25--::

  with opposite dance BtoB ; with P in promhold, pass Lsh to meet next couple

', 3);
INSERT INTO 'dancecrib' VALUES (14260, '2021-08-21 16:45:22.538761+00', '2022-12-04 13:57:32.933877+00', 20402, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA (to 2x,1x,3) ; 1c+3c S&Link (2x,3,1x)

9--::

  Reels3 on sides, 1c RSh to 3c (2x,3,1x)

17--::

  2c & 1c set | cross RH (to 2,3,1). 3c+1c face up/down ; 3c+1c set | change places LH (2,1,3)

25--::

  Circle6 and back (2,1,3) ', 2);
INSERT INTO 'dancecrib' VALUES (13645, '2021-02-04 17:22:01.273501+00', '2021-02-04 18:45:55.054455+00', 14184, 1, 202, 'ace', '*3c & 4c start on opposite sides*
1--::
  1M & 4M (partners following) Fig8 on sides starting in, finishing on exchanged places. 1c & 3c face down, 2c & 4c face up (1x,2,3x,4)
9--::
  All set to opposite person on sides | change places RH ; 2c+1c & 4c+3c RHA to sides into Reel4 position (2,1x,4,3x)
17--::
  Reels4 (2,1x,4,3x)
25--::
  1c & 4c ½Fig8 out through ends (to 2,1,4x,3x) ; 1c+4c ½ R&L. 1M & 4M face out (2,4,1x,3x)
33--::
  4c+1c L-Chain. Polite turn can be omitted. 2c & 1c face down, 4c & 3c face up (2,4,1x,3x)
41--::
  2c+4c & 1c+3c DblFig8, 2c & 3c crossing', 2);
INSERT INTO 'dancecrib' VALUES (13702, '2021-02-26 19:54:37.011575+00', '2021-08-15 06:07:58.12969+00', 14991, 2, 963, 'ace', '1-8::

  1s tandem R3 on women''s side Lsh to 2w to begin. On bar 4, thru 3w''s place,1m takes the lead  

9-16::  

  1s tandem R3 on men''s side, Rsh to 2m to begin.  On bar 12, thru 3m''s place, 1w takes the lead.  1c finish at the top facing down, 1w on partner''s left  

17-24::  

  1c dance below 3c, cast to 2nd place own side (2s up 19-20); All turn RH  

25-32::  

  2s+1s+3s circle 6H round to left, bar 28 all cross R foot over L, pulling back LSh & chase ccw to place 2 1 3', 2);
INSERT INTO 'dancecrib' VALUES (13781, '2021-03-02 12:22:59.269927+00', '2021-03-02 12:28:39.484609+00', 13380, 1, 202, 'ace', '1--::

  1c & 3c Petronella Turn | set ; 1c+3c ½ Reel4

9--::

  3c & 1c set to P | turn P BH ready for ; ½ Poussette (1,2,3)

17--::

  1c+2c ½ RHA | 2c & 1c cross RH (to 2,1,3) ; 1c+3c ½ LHA | 3c & 1c cross LH (2,3,1)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (3622, '2012-07-21 11:46:05.941256+00', '2014-11-11 20:13:20.059946+00', 5623, 1, NULL, 'ace', '1-16::

  4-couple »meanwhile« fugue

::

  C1: Set | turn RH ; cast to bottom ;; dance up through 3pl and cast to top ; dance through 2pl and cast to 3pl facing down and in.  

::

  C3: Wait {4} ; set | turn RH ;; cast to bottom and dance up ; continue out through 2pl and cast to top facing in  

::

  C2: Wait {8} ;; set | turn RH ; cast to 3pl and dance up to 2pl facing up and out.  

::

  C4: Wait {12} ; set | turn RH and face out (3,2,1,4)

17–::

  Mirror Reels4 on the sidelines

25–::

  3c+1c set twice ; turn RH moving down one _while_{8}   2c+4c cast up | cross down ; cast up | cross RH (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (8435, '2014-11-07 01:36:39.239534+00', '2014-11-09 00:44:49.630953+00', 13462, 1, NULL, 'ace', '1--::

  1c+3c cross RH | cast off ; cross LH | cast up to places (1,2,3,4)

9--::

  2c+4c cross RH | cast up ; cross LH | cast down to places (1,2,3,4)

17--::

  1c dance down NHJ and turn inwards (2c+3c+4c up) ; 1c dance up between 4c and cast to 4pl (2,3,4,1)

25--::

  Circle8 and back

', 3);
INSERT INTO 'dancecrib' VALUES (8436, '2014-11-09 21:44:23.289648+00', '2014-11-09 21:44:23.289648+00', 10784, 1, NULL, 'ace', '1--::

  1c cross down into Fig8 round 2c

9--::

  1c+2c dance BtoB ; Turn RH

17--::

  2c cross up into Fig8 round 1c

25--::

  1c+2c dance Lsh BtoB ; Turn LH

33--::

  1c+2c RHA ; LHA

41--::

  1c cross | cast to bottom and swing (2c+3c+4c up) (2,3,4,1)

only 1c+2c start, but at each repeat both 1c+2c and 3c+4c dance 

', 3);
INSERT INTO 'dancecrib' VALUES (3175, '2012-01-22 19:30:14.491454+00', '2016-11-15 10:43:52.074757+00', 5795, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; ½ Reels3 across, Rsh to 4cnr, finish facing 1cnr (pos)

9–::

  Turn CPCP, finish 1W with 1M behind facing 1M place.

17–::

  Lead-change Rsh ½ Reel3 on 1diag, finish 1M (1W behind) facing 3M place ; repeat on 2diag, 1c finish in middle on own side facing up

25–::

  1c dance to top and cast off (3,1,2) ; Mirror ½ Reels3 on the sides, 1c start in and down (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10353, '2017-12-23 19:37:29.788517+00', '2017-12-23 19:37:46.939571+00', 18183, 1, 202, 'ace', '1--::

  1c+3c DblFig8

9--::

  1c set | turn RH ; cast 2 places (2c up) | dance up to 2pl BtoB facing own side for

17--::

  6 bars of DTr | 1c dance round each other to face 1M(1W) up(down) _while{2}_ 2c & 3c set

25--::

  1c cast R round 2cnrs to 2plx ; ½ Fig8 L to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3596, '2012-07-21 11:45:28.210864+00', '2014-11-11 00:43:21.468315+00', 10537, 1, NULL, 'ace', '1–::

  All set | turn BH ; open into 1c+2c & 3c+4c circle4 L

9–::

  1c+4c cross and cast in (2c+3c step to ends) ; 1c & 4c ½ Fig8 round end couple (2,1,4,3)

17–::

  1c+4c Poussette

25–::

  1c+4c+3c S&Link3 ; repeat (2,3x,4x,1x)

33–::

  3c+4c+1c cross | circle6 L (to 2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (8685, '2015-02-24 12:01:31.506321+00', '2015-02-24 12:04:41.505579+00', 9815, 1, NULL, 'ace', '1-::

  1c set | cast (2c up) ; turn RH 1¾  to face 1cnr _while{4}_ 2c+3c ½ R&L 

9-::

  ½ Reel4 with 1cnrs ; repeat with 2cnrs, 1c fast turn LH ½ into

17-::

  Teapots R (M down) ; Teapots L (M up), pass Lsh into

25-::

  Reels3{6} on sides, LSh to 1cnr | 1c cross RH

', 3);
INSERT INTO 'dancecrib' VALUES (8037, '2013-09-15 22:48:00.869435+00', '2014-04-30 23:23:37.248987+00', 14974, 1, NULL, 'ace', '1–::
  All set | turn BH twice | set
9–::
  1W+2M set adv. | turn BH ; pass Rsh to exchanged places | set
17–::
  1M+2W repeat (2x,1x,3)
25–::
  2c cross down into Reels3 on sides, 1c start out and up, and cross up at end (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3384, '2012-01-22 19:30:23.152877+00', '2021-01-09 21:53:40.827448+00', 13638, 1, NULL, 'ace', '1–::

  All set | 1c+2c turn LH ½ into ½ LHA _while{8}_ 3c+4c the same RH | All set (2,1,4,3)

9–::

  1c parallel Fig8 on sideline round 2c & 3c, starting Lsh to 2c, _while{8}_ 4c+3c RHA ; 2c+4c LHA ((1c & 4c pass Lsh on [13]  (to 2,4,1,3)

17–::

  repeat [1-8] from new positions (2c+4c LH, and 1c+3c RH) (to 4,2,3,1)

25–::

  2c parallel Fig8 on sideline round 4c & 1c, starting Lsh to 4c, _while{8}_ 3c+1c RHA ; 3c+4c LHA ((2c & 3c pass Lsh on [13]  (to 4,3,2,1)



{{explanation}}

Repeat once only from new positions', 4);
INSERT INTO 'dancecrib' VALUES (11232, '2018-10-01 13:18:35.765316+00', '2018-10-01 13:37:46.50754+00', 18677, 1, 202, 'ace', '1--::

  1c cross | cast  _while{4}_ 3c turn 2c on sidelines EH (3c up and out) to 1pl (to 3,1x,2) ; 3c cross | cast  _while{4}_ 2c turn 1c on sidelines EH (2c up and out) to 1pl (to 2,3x,1x)

9--::

  2c cross | cast  _while{4}_ 1c turn 3c on sidelines EH (1c up and out) to 1pl (to 1x,2x,3x) ; 1c cross | cast  _while{4}_ 3c turn 2c on sidelines EH (3c up and out) to 1pl (to 3x,1,2x)

17--::

  3C S&Link twice (2,1x,3)

25--::

  1c turn RH ; ½ Fig8 L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10533, '2018-03-20 10:12:07.741086+00', '2018-03-20 10:27:50.415595+00', 17432, 1, 202, 'ace', '1--::

  1W+2W+3W NHJ advance | all set (M individually) ; release hands & dance Rsh round P to places

9--::

  M repeat [1-8] (1,2,3)

17--::

  ½ Mirror Reels3 on sidelines, 1c start in (to 3,2,1) ; 3c & 1c set | 3c cast to 3pl _while{2}_ 1c dance up to 1pl (1,2,3)

25--::

  1c set | cast (2c up) ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8874, '2015-08-26 22:09:03.464787+00', '2018-10-14 05:45:46.732818+00', 16533, 1, 1041, 'ace', '1--::  1c set | cast off (2c up) ; Teapots R

9--::  tandem Reel3 across with 2c: 1W (with 1M close behind) Rsh to 2W (2,1,3)

17--::  1c set | ¾ turn RH ; Teapots L

25--::  tandem Reel3 across with 3c: 1M (with 1W close behind) Rsh to 3M (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (2131, '2012-01-22 19:29:21.734767+00', '2015-03-14 22:03:20.883597+00', 1841, 1, NULL, 'ace', '{{explanation}}

Form groups of 3 couples in a circle with each M to left of P



1–::

  All circle6 and back

9–::

  All dance BtoB with P ; All turn P RH

17–::

  All wheel RH (take hands on diameter) ; on bar 21 the W whose hand is lowest moves under to join new P, on bar 23 next W moves under to join new P

25–::

  All three »new free couples« Promenade to anywhere in the room to form trio with 2 other couples.



{{explanation}}

Presented to the Dunedin Dancers in 1991; only bars 9-16 differ from the Borrowdale Exchange', 3);
INSERT INTO 'dancecrib' VALUES (8440, '2014-11-11 16:11:24.821644+00', '2020-08-07 10:36:12.770032+00', 7065, 2, 1, 'ace', '1–::

  1c set | cross R ; cast off [2c up] | cross R

9–::

  1c+2c Circle4 to L | 1c+2c LH across back

17–::

  All set | cross R ; set | cross R

25–28::

  Circle6 ¾ round to L

29–30::

  1c turn L about and cast ccw to 2pl _while_ 2c+3c dance 1 place on

31–32::

  1c cross R', 3);
INSERT INTO 'dancecrib' VALUES (8438, '2014-11-11 15:58:12.738535+00', '2020-10-12 16:52:29.412206+00', 15648, 2, 1, 'ace', '1–4::

  1c dance ½Fig8 round 2c _while_ 2c+3c set and cross R

5–8::

  All set | turn R ½ [fin ready for Promenade]

9–::

  All promenade [1c fin facing 1st corners]

17–20::

  1c set to corners

21–24::

  1c pass 2nd corners RS and cast to 2nd pl own sides | 1c cross R

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (12757, '2020-04-12 00:08:54.619302+00', '2021-01-02 16:12:58.813207+00', 12923, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; 1c (starting inwards) turn 3c EH on sides (2,1,3)

9--::

  1c+1cnrs Corners Pass  and Turn using LSh/LH. On [12] 1c meet P in centre and pull RSh back to face 2cnrs ; repeat with 2cnrs (2,1,3)

17--::

  1c set advancing BtoB on midline, 1W(1M) facing up(down) into Crown Triangles

25--::

  2c+1M & 1W+3c LHA, 1c pass LSh ; 2c+1W & 1M+3c RHA (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (8443, '2014-11-12 17:24:19.534991+00', '2014-11-12 17:24:19.534991+00', 15700, 1, NULL, 'ace', '1--::

  1c set | turn RH ½ into promhold ; dance to bottom, cross and cast up (2c up) to (2,1x,3)

9--::

  Mirror Reels3 on the sides, 1c starts in and up

17--::

  1c half Fig8 up ; ½ Fig8 down (2,1x,3)

25--::

  Teapots R (2c+1M & 1W+3c RHA) ; all chase ½ clw (3x,1,2x)

33--::

  3c+1W & 1M+2c Circle L, at end 1c pivot R to face P on midline ; 1c set | 1c cast up on opposite side (3c down) (1x,3x,2x)

41--::

  All A&R {2} | Link3 ; A&R | Link3 (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8213, '2014-03-18 21:55:33.902764+00', '2016-06-23 18:59:51.958941+00', 15374, 1, NULL, 'ace', '1--::

  1c turn RH | cast off (2c up) : set pivoting R into BtoB facing own side | set as in DTr

9--::

  1c set BtoB moving ¼ round R (M face up, W down) | All set as in DTr ; 1c dance (Sk-Ch) ½ clw into BtoB (M face down, W up) | All set as in DTr and 1c face 1cnr

17--::

  1c+1cnrs pass and turn , pass Rsh ; 1c+2cnrs pass and turn (2,1,3)

25--::

  2c+1c R&L (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (8447, '2014-11-18 16:07:04.372705+00', '2014-11-18 16:07:04.372705+00', 15703, 2, 160, 'ace', '1–::

 1C 2C hands four to left, once round ; 1C 2C set, 1C cast as 2C dance up and face out in top place.

9–::

 Mirror Reel3 on sides - 1C in and up, 2C out and down, 3C cast up to begin. Give hands during reel.

17–:: 3 couple Knot. 1C end facing 1st corners. (3 1, 2)

25–::

 1st corners Pass & Turn, 1C pass Rsh in centre to face 2nd corners; 2nd corners Pass & Turn, 1C pass Rsh to own sides.', 2);
INSERT INTO 'dancecrib' VALUES (1940, '2012-01-22 19:29:10.925089+00', '2019-12-12 00:07:10.027364+00', 1176, 1, NULL, 'ace', '1–::

  1c+2c set | Petronella in tandem ; repeat (2x,1x,3)

9–::

  2c+1c set | 2c cross RH _while{2}_ 1c turn LH ¾ ; 2c+1W & 1M+3c RHA (Teapots) to sidelines (2,1,3)

17–::

  1c+3c S&Link ; 3c+1c Circle4 left, end 3c facing 1c for

25–::

  Gr-Chain (2c cross to start) (2, 3, 1)', 3);
INSERT INTO 'dancecrib' VALUES (13930, '2021-04-05 08:12:16.520427+00', '2021-04-05 08:18:39.508158+00', 2639, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA ; set | cross RH (2,1,3)

9--::

  Diagonal R&L (3x,1,2x)

17--::

  3c & 1c set | Petronella turn to midline ; set to P | Petronella turn to sides _while{8}_ 1c cross RH | cast R ; dance clw between 3c/2c setting on midline | cast R to face 1cnrs[pos]

25--::

  ½ Reel4 on 1diag, pass P RSh ; ½ Reel4 on 2diag, pass P RSh. 1W between 2c face 2M, 1M between 3c face 3W

33--::

  ½ Reels3 across, 1c RSh to 4cnrs[pos] ; 1c turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13283, '2020-10-16 05:09:59.710893+00', '2020-10-16 05:15:59.386696+00', 20120, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; ½ Fig8 L round 2cnrs (2,1x,3)

9--::

  3C »Mixed Cross and Rotate« [: 1c cross RH _while{2}_ 2c+3c change places RH on sides | all chase clw ¼ ; 1c change places RH _while{2}_ 3c&2c cross RH | all chase clw ¼]. 1c in 2pl start passing RSh. (3x,1,2x)

17--::

  1c dance RSh round 2cnrs[pos], meet in centre, pivot RSh to face 1cnrs _while{4}_ dancers on 2diag turn RH ½, face each other | cast R to exchanged places ; 1c dance RSh round 1cnrs[pos] and across to 2pl _while{4}_ dancers on 1diag turn RH ½, face each other | cast R to exchanged places (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (8444, '2014-11-12 23:47:17.825264+00', '2019-02-12 23:42:58.590496+00', 15684, 1, NULL, 'ace', '1--::

  1c+2c Knot, 1c finish facing 1cnrs

9--::

  1c set to 1cnr | 1c cast Rsh round each other to 3cnr position while 1cnrs dance into centre, and swivel R to face own cnr ; repeat, 1cnrs finishing in exchanged places, and 1c twirl to face 2cnr

17--::

  Repeat with 2cnrs (3x,1x,2x)

25--::

  All set | All turn P BH 1½ and face P | twirl R to own side (3,1,2)', 5);
INSERT INTO 'dancecrib' VALUES (10117, '2017-09-11 21:00:22.388836+00', '2018-04-08 10:29:54.879427+00', 15107, 1, 202, 'ace', '1--::

 1W+2M dance Rsh round P ; turn RH to pl

9--::

 1M+2W dance Lsh round P ; turn LH to pl (1,2,3)

17--::

 1c+2c changes pl LH on sidelines | 2c+1c+3c Reels3{6}, 1c Rsh to 3c to start (2,1,3)

25--::

 2c+1c+3c Gr-Chain (2c cross to start) (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10231, '2017-11-05 13:11:48.196984+00', '2018-04-10 09:07:08.093156+00', 15105, 1, 202, 'ace', '1--::

  1c set | turn RH ; cast (2c up) | turn RH into promhold between 2c facing 2W

9--::

  1c+2c Reel3 across, 1c Rsh to 2W to start, finish between 3c facing 3W

17--::

  1c+3c Reel3 across, 1c Lsh to 3W to start

25--::

  1c cross, cast off to 2pl centre (3c step in on [28]) into 1diag BHJ ; 1c+3c ½ Poussette (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (11233, '2018-10-01 13:54:17.2463+00', '2018-10-01 13:57:56.833262+00', 18678, 1, 202, 'ace', '1--::

  1c Fig8 on sidelines, 1c casting to start (2c up on [7-8]) (2,1,3)

9-20::

  3C R&L (2,1,3)

21-24::

  All set | 1c turn LH to face 1cnrs

25--::

  Corners Pass and Turn (2,1,3)



', 2);
INSERT INTO 'dancecrib' VALUES (8449, '2014-11-18 17:21:51.083446+00', '2021-07-02 14:07:16.349181+00', 443, 2, 160, 'ace', '1–::

 Turn RH, cast off and cross to face 1crnr ; diagonal half Reel4 - finish in prom hold facing Mside.

9–::

 Diagonal Reel3 with 2crnrs - pass 3M Lsh to begin.

17–::

 Diagonal Reel3 with 1crnrs - pass 3L (in top M''s place) by Rsh to begin. End facing 2crnr.

25–::

 Diagonal half Reel4 - end 2pl opp. side ; Crnrs chase CW half round *while* 1C turn RH 1-1/2 to own sides.', 2);
INSERT INTO 'dancecrib' VALUES (14020, '2021-05-04 21:19:07.315162+00', '2021-05-04 21:19:07.315162+00', 13390, 2, 963, 'ace', '1-8::  
  1c set, cast (2s up), cross RH below 3C to 2,1x,3  
9-12::  
  Set and Link for 3  
13-16::
  1C adv one, twirl right about to face out 2nd pl own side, dance out 2nd pl to right, finish 1M btwn 3C (top), 1W btwn 2C (bottom) facing opp side  
17-20::  
  1C dance 1/2 Lsh reel across  
21-24::  
  1C dance 1/2 Lsh reel on own side, finish 1W btwn 2C (top), 1M btwn 3C (bottom)  
25-28::
  Set and Link for 3 to 3,1,2         
29-32::
  1C turn RH
  ', 2);
INSERT INTO 'dancecrib' VALUES (8452, '2014-11-18 18:51:27.896184+00', '2022-04-26 09:32:55.068862+00', 15704, 2, 160, 'ace', '1–::

 1C2C set and Link ; (2,1)

5–::

 1C3C Bourrel (Birl) (2,3,1)

13–::

 3C1C set and link. (2,1,3)

17–::

 1C Petronella turn, set ; turn RH 1_3/4 to 2pl opp. side facing out.

25–::

 Reel3 on sides, Rsh to 1crnr - 1C dance to 2pl on own sides from end of reel.', 2);
INSERT INTO 'dancecrib' VALUES (14601, '2022-02-08 14:14:39.135646+00', '2022-02-08 15:17:12.917676+00', 13470, 1, 202, 'ace', '1--::
  1c ½ Fig8 down round 2c ; turn 2c EH 1¼ on sides into promhold facing 2M
9--::
  Reel3 across, 1c RSh to 2M. 2c finish in 1pl, 1c in 2plx centre facing down
17--::
  1M+2W+3W LHA _while{4}_ 1W+2M+3M RHA ; 1M+2W+3W RHA _while{4}_ 1W+2M+3M LHA. 1c in 2pl centre face up
25--::
  1c (+3c following) dance up and cast off (to 2,3,1x) ; 1c ½ Fig8 up round 3c (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (8442, '2014-11-12 14:04:16.81239+00', '2020-10-14 11:19:18.937385+00', 15699, 1, NULL, 'ace', '1--::

  1c cross RH and cast (2c up)  ; 2c+1c S&Link, 1M faces out (1x,2,3,4)

9--::

  1c+2c+3c Rsh Reels3 on the sides, 1M face out

17--::

  1M, 1W following, cast off and cross to own side (2c up) ; 1c+3c LHA (2,1,3,4)

25--::

  2c+1c+3c Reels3 on sides, Rsh to 2c (2,1,3,4)

33--::

  1c set | 1W casts off one ; crosses | casts up _while{6}_ 1M crosses ; casts off | dances up the middle and faces out on W side (2,1x,3,4)

41-64::

  1c+3c+4c repeat [9-32] (2,3,1,4)

::

  on next [1-2] 4c step up as 1c step down to 4pl.

', 3);
INSERT INTO 'dancecrib' VALUES (14143, '2021-07-10 14:47:19.841763+00', '2021-07-10 14:59:15.724284+00', 20370, 1, 202, 'ace', '1--::

  1c set | cast of (2c up) ; ½ Fig8 up round 2c (2,1x,3)

9--::

  Reels3 on sides {6}, 1c RSh to 2cnrs | 1c cross RH (2,1x,3)

17--::

  3C Chain Progression (2,1,3)

25--::

  Circle6 L ½ ; all turn P RH 1½', 2);
INSERT INTO 'dancecrib' VALUES (1694, '2012-01-22 19:28:56.989792+00', '2021-03-14 23:18:36.61501+00', 8728, 1, NULL, 'ace', '1–::

  1c turn RH | cast off one (2c up) ; 1c turn LH | cast left (W up, M down) into

9–::

  Reels3 across, Rsh to 1cnr, finish facing 1cnr

17–::

  1c set to and turn 1cnr BH ; in lines of 3 across advance, 1c changing lines quickly BH (1M now up, 1W down) | all retire.

25–::

  Reels3 across, 1c Lsh to 2cnr, finish facing 2cnr

33–::

  1c set to and turn 2cnr BH to (2, 1x,3) ; All advance, 1c again changing lines quickly BH ; all retire (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9792, '2017-04-14 21:25:05.717704+00', '2022-10-02 11:58:06.113362+00', 9679, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; 1c+3c LHA (2,1,3)

9--::

  All M A&R twice _while{8}_ All W set | A&R | set (2,1,3)

17--::

  1c fast turn LH ¾, cast Lsh round 3cnr,  meet in middle and turn RH ¾, cast Rsh round 4cnr to (2,1,3)

25--::

  All turn P LH ½ and keep LHJ | All set ; All chase ½ cclw to (3,1,2)

33--::

  1c set twice to P ; birl  (3,1,2)



*Note: the unusual progression does work*

', 3);
INSERT INTO 'dancecrib' VALUES (10461, '2018-02-26 10:42:57.938076+00', '2018-02-26 10:49:38.235966+00', 3549, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; ½ Fig8 round 2c (2,1x,3)

9--::

  2M+3W cross RH | 2W+3M cross RH ; all turn P RH (3x,1x,2x)

17--::

  S&Link3 twice (2,1,3)

25--::

  Repeat [17-24] (3x,1x,2x)

33--::

  All dance BtoB ; all cross Rsh under M arches (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (3816, '2013-07-13 15:56:13.601038+00', '2015-08-27 00:21:15.307903+00', 9933, 1, NULL, 'ace', '{{explanation}}

On 2nd chord, 2c cross (1,2x,3).  2c is dancing couple.



1–::

  1M+2c+3W ½ diag Reel4 (2c Rsh to 3cnr), 2c pass Rsh and face 4cnr ; ½ Rsh Reel4 on 2diag, finish (3x,2,1x)

9–::

  ½ Reels3 across, 2c Rsh to 2cnr pos, and face 1cnr pos (3,2x,1) ; ½ Lsh Reel3 on the sides  (1,2x,3)

17–::

  All set Highland Schottische ; 2c dance down and cast up round 3c (1,2x,3)

25–::

  1c+2c (on sides) & 3c Turn BH ½ | All Circle6 L ½ (3,1x,2) ; repeat figure (2,3x,1)', 3);
INSERT INTO 'dancecrib' VALUES (1695, '2012-01-22 19:28:57.109451+00', '2014-04-30 23:23:38.793031+00', 11269, 1, NULL, 'ace', '1–::
  1c+2c set twice ; 1M+2W turn RH ½ to face, and spiral out to the R to exchanged places
9–::
  1W+2M repeat that figure ; 2c+1c repeat with P (to 2,1,3)
17–::
  1c dance Lsh round 1cnr, on [20] 2cnrs advance for ; 1c + 2cnrs RHA (2,1x,3)
25–::
  1c dance Rsh round 4cnr, on [28] 1cnrs advance for ; 1c + 1cnrs LHA (2,1,3)
33–::
  1c+3c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (8129, '2013-12-03 23:54:00.216687+00', '2015-03-15 16:20:21.762743+00', 15272, 1, NULL, 'ace', '*5c in the middle faces 1c*

1--::

  1c+5c RHA ; 5c+3c LHA

9--::

  1c+5c+3c Rsh parallel Reels3, and 5c face 4c

17--::

  4c+5c+2c Lsh parallel Reels, at end 5M with 5W behind face 1W 

25--::

  5c+1c change places Rsh and 1c, M leading W, face 4W | 1c+4c repeat ; 4c+3c repeat | 3c+2c repeat and 2c face 1c (5,3,4,1,2)





', 3);
INSERT INTO 'dancecrib' VALUES (9962, '2017-06-18 12:44:33.472388+00', '2020-11-08 12:02:00.77925+00', 17790, 2, 2697, 'ace', 'Strathspey

1-8::

    1s (long) cast to 2nd place; turn RH or LH (men''s choice) 

9-16::

    1c  RSh reel of three on own sides, 1c start facing 3rd crnrs  (if turn on bars 5-8 was RH) or LSh reel to 4th crnrs (if turn on bars 5-8 was LH), finishing on own sides 

17-24::

    2s+1s+3s Promenade for 3 cpl

25-32::

    2s+1s+3s circle 6h round and back



Reel: repeat from 2nd place', 3);
INSERT INTO 'dancecrib' VALUES (12184, '2019-09-06 21:21:08.513963+00', '2020-06-12 16:51:09.243171+00', 19550, 1, NULL, 'ace', '1--::

  1c+2c RHA {3}, LHA{3} | 1c cast as 2c dance up (2,1,3)

9--::

  1c+1cnrs set | La Baratte to change places

17--::

  1W+2c & 3c+1M Circle3 R ; Merge (1c leading) into Circle6 R to (3,1,2) 

25--::

  3c+1c+2c Slip Knot for 3, at the end 1c+3c ½ LHA as 2c cross (231) 

', 3);
INSERT INTO 'dancecrib' VALUES (8864, '2015-08-26 06:51:06.662451+00', '2015-08-28 06:16:34.766376+00', 16569, 2, NULL, 'ace', '1-:: 1c+2c Espagnole, 1c finish in tandem, 1W facing 1cnr, 1M behind 1W

9-:: 1W leading, 1c+1cnrs 1/2 diag. Reel3 (Rsh to 2M), finish in tandem with 1M leading facing 3M ; 1M leading, 1c+2cnrs 1/2 diag. Reel3 (Rsh to 3M), finish in tandem with 1W leading facing 2M

17-:: 1W leading, 1/2 Reel3 across with 2c (Lsh to 2M) ; 1W leading, 1/2 Reel3 across with 3c (Lsh to 3W) to 2pl (3,1,2)

25-:: All set | cross RH ; chase clw 1/2 to (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (1696, '2012-01-22 19:28:57.158262+00', '2018-11-26 00:13:43.192958+00', 9380, 1, NULL, 'ace', '1–-::

  1c set | dance down ; dance to top and cast off _while{8}_   

2c stand {2} | set ; cast off round 3c and lead to top facing out _while{8}_   

3c stand {6} | set, swiveling (downwards) to face out (2,1,3)  

9-–::

  Reels3 on the sides, 1c starts in and down

17-–::

  SetH&G for {6} | 1c turn RH ¾

25-–::

  All circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2264, '2012-01-22 19:29:28.553386+00', '2021-02-07 10:36:34.794482+00', 10555, 1, NULL, 'ace', '{{explanation}}

Trios face trios RR.



1–::

  All dance BtoB with opposite ; one PdB (Right) circle6 L half round (6 slip steps)

9–::

  Repeat

17–::

  Men + both W on his left Rsh Reel3

25–::

  Men + both W on Right RHA ; A&R in trios | pass Rsh to meet next trio', 2);
INSERT INTO 'dancecrib' VALUES (8879, '2015-08-28 06:16:34.828763+00', '2015-08-28 06:16:34.828763+00', 16569, 1, NULL, 'ace', '1-::  1c+2c Espagnole, 1c finish facing 2M, 1M behind 1W

9-::  1c+1cnrs ½ Rsh lead-change diag Reel3, finish facing 3M with 1M leading ; 1c+2cnrs ½ Rsh lead-change diag. Reel3, finish facing 2M (in 3W pos) with 1W leading 

17-::  ½ Lsh Reel3 across, 1c dancing in tandem (no lead change), finish facing 1M pos ; ½ Reel3 across with 3c (Lsh to 3W) to (3,1,2)

25-::  All set | All cross RH ; All chase clw ½  (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8729, '2015-03-15 21:46:57.399895+00', '2015-03-15 21:51:29.25797+00', 15762, 1, NULL, 'ace', '*Trio face Trio*



1--::

  All set | Pass opposite RH ; Chase clw half round

9--::

  Centre turn partner on the R with RH ; turn L Partner LH 

17--::

  Rsh reels3 in each trio

25--::

  Each trio RHA ; RH partner leads cclw chase to opposite places and all face next trio.

', 3);
INSERT INTO 'dancecrib' VALUES (10120, '2017-09-12 23:57:14.311237+00', '2017-09-12 23:57:14.311237+00', 17927, 2, 1, 'ace', '1–::
  1c+2c dance Tourbillon [1c fin facing out]
9–::
  1c cast to R to fin 1M between 2c, 1L between 3c | ½ Reel3 across,
  1c passing LS w/2nd corner {4} | 1c turn L ¾ (to 2x 1x 3x, 1c facing out)
17–::
  1c cast to L to fin 1M between 2c, 1L between 3c | ½ Reel3 across,
  1c passing RS w/2nd corner person {4} | 1c turn R ¾ (to 213)
25-::
  1c+3c poussette', 3);
INSERT INTO 'dancecrib' VALUES (14604, '2022-02-09 00:27:22.976486+00', '2022-02-09 00:27:40.84042+00', 6918, 1, 1645, 'ace', '1-::

  1M+2W set adv | turn RH ; 1W+2M set adv | turn RH into promhold facing M side

9-::

  2M+1W (promhold) diag Reel3 with 1M & 2W, starting RSh to 1M

17-::

  1c+2M RHA, 2M ends in original place ; 1c+2W LHA, 1c end on opp side (1x,2)

25-::

  1c set | cast off (2c up) ; &frac12; Fig8 up through 2c (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (8087, '2013-10-14 23:59:50.774314+00', '2013-11-16 21:02:37.853291+00', 15175, 2, 160, 'ace', '1–::
  1C dance up and cast to 2nd place _AS_ 2C dance up and cast (independently) to 3rd place _AS_ 3C dance up and cast into top place
5–::
2C+3C turn RH _AS_ 1C turn LH
8–::
1L+3C, 1M+2C dance RH Across; 1C change ends dance LH Across. 1C face 1 corners
17–::
1s+1 corners dance diagonal Reel of 4. 1C dance around by Lsh to face 2 crnr
25–::
1s+2 corners dance diagonal Reel of 4. 1C end 2nd place on own sides.
', 2);
INSERT INTO 'dancecrib' VALUES (10228, '2017-11-04 22:49:04.889133+00', '2020-10-06 14:56:03.324921+00', 15101, 1, 202, 'ace', '_Strathspey_

1--::

  1c cross RH | cast (2c up) ; ½ Fig8 R. On [8], 1c meet in centre _while_ 2c & 3c step in ready for

9--::

  2c+1c+3c Allemande. On [15-16], 1c retire{1} and advance{1} to face 1cnrs



_Reel_

17--::

  ½ Reel4 on 1diag, 1c pass Lsh ; ½ Reel4 on 2diag (2x,1x,3x)

25--::

  2c+1c+3c Petronella turn | set ; repeat (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2047, '2012-01-22 19:29:16.897258+00', '2021-01-08 10:10:06.308048+00', 9406, 1, 202, 'ace', '1--::

  1c set | turn RH ½ moving down to 2pl centre (2c up) and pivoting R to face 1cnrs ; 1c set | turn 1cnrs BH (skip ch) into lines3 across, 1c facing 4cnrs

9--::

  Reels3 across, 1c LSh to 4cnrs. 1c between ends face P

17--::

  1c set | turn RH ½ and pivot R to face 2cnrs ; 1c set | turn 2cnrs BH (skip ch) into lines3 across, 1c facing 3cnrs

25--::

  Reels3 across, 1c LSh to 3cnrs. 1c cross RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3542, '2012-01-22 19:30:30.08393+00', '2021-02-06 15:25:09.746009+00', 10579, 1, NULL, 'ace', '1–::

  1c+2c LHA ; RHA _while_{8} 3c+4c RHA ; LHA

9–::

  1W+2M & 3M+4W change places (resp. LH and RH) and 1W+4W joining nearer hands set ; 1M+2W & 3W+4M change places (resp. RH and LH) and 1M+4M joining nearer hands set (2x,1x,4x,3x)

17–::

  1c+4c petronella to own side

25–::

  2c+3c ½ Fig8 inward to own side ; 2c+1c & 4c+3c set to and ½ turn each other on sides (end couples start inwards) (1,2,3,4)

33–::

  1W followed by P cast off one and cross over (2c up) ; repeat (3c up)

41–::

  Repeat (4c up) ; all advance (1c quickly switch places) and retire (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2130, '2012-01-22 19:29:21.680342+00', '2015-02-26 23:41:42.410174+00', 1838, 1, NULL, 'ace', '1–::

  2c+4c petronella (to 1,2x,3,4x)

9–::

  1c+2c & 3c+4c L-Chain

17–::

  1c+3c petronella (to 1x,2x,3x,4x)

25–::

  1W+2M cross LH | 1M+2W & 1W+3W cross RH ; 1M+3M & 1W+4M cross LH | 1M+4W cross RH (2,3,4,1).



{{explanation}}

[25-32] represent tacking the ship, therefore no polite turns', 3);
INSERT INTO 'dancecrib' VALUES (8092, '2013-10-15 16:32:47.605091+00', '2013-10-15 16:32:47.605091+00', 15218, 2, 160, 'ace', '1–8::
  1s & 3s dance down for 2 steps as 2s & 4s step up; 1s dance up to top & cast off to 4th pl while 3s dance up to top & cast off to 2nd pl.   2-(3)-4-(1).
9–16::
3s & 4s dance RH across & LH back,end facing up on the ladies’ side and down on the men’s side.
17–24::
Dolphin reels of three on the sides: to begin, 3M+4W (as a unit) give RSh to 2W (in and up), while 3W+4M (as a unit) give RSh to 1W (in and down).
25–32::
All set, half turn & twirl, and set.  Finish in order (2)-3-(4)-1.', 2);
INSERT INTO 'dancecrib' VALUES (14240, '2021-08-15 06:02:43.563756+00', '2021-08-15 06:07:58.131354+00', 14991, 1, 202, 'ace', '1--::

  Reel3 in tandem on Wside, 1c (1W leading) LSh to 2W. On [4] 1M takes the lead

9--::

  Reel3 in tandem on Mside, 1c (1M leading) RSh to 2M. On [12] 1W takes the lead. 1c ends in 1pl centre facing down (1,2,3)

17--::

  1c dance down between 3c, cast up to 2pl (2c up) ; all turn P RH (2,1,3)

25--::

  Circle6 L {3}, cross R foot over and pivot L ; chase cclw (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10796, '2018-05-28 04:26:09.404797+00', '2020-11-09 10:35:31.597994+00', 17870, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; 1c Petronella turn _while{2}_ 2c & 3c step inwards to 2pl | all set

9--::

  1c Petronella turn to 2plx _while{2}_ 2c & 3c Petronella turn in tandem, 2W+3W (2M+3M) in 1pl(3pl) facing dn(up) | all set ; repeat figures [9-12], ending 1M(1W) in 1pl(3pl) facing dn(up), 3c+2c in 2plx | all set

17--::

  1c turn LH ¾ to 2plx _while{2}_ 3c & 2c step out (to 3x,1x,2x) | all set ; all turn P RH

25--::

  All set | chase clw ½ | all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11495, '2019-01-04 15:40:39.875455+00', '2019-01-04 15:55:04.2539+00', 12344, 1, 202, 'ace', '1--::

  2c+3c cross RH | set ; ½ R&L (1,3,2,4)

9--::

  All cross RH | set ; 1c+3c & 2c+4c ½ R&L. 1W & 4M face out (3,1,4,2)

17--::

  1W & 4M both followed by their P Fig8 with 3c/2c, LSh to 3W/2M back to places facing each other on sides (3,1,4,2)

25--::

  1c+4c change places RH on sides _while{2}_ 3c & 2c turn RH | 3c+4c & 1c+2c change places LH on sides ; 3c+2c change places RH on sides _while{2}_ 4c & 1c turn RH | 4c+2c & 3c+1c change places LH on sides (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14603, '2022-02-08 21:28:23.693485+00', '2022-02-08 21:31:16.32345+00', 20661, 1, 1645, 'ace', '1--::

  1c set adv | turn BH & face up ; cast off (2c up) | turn LH

9--::

  2c+1W & 1M+3c RHA, 1c pass RSh ; LHA, 1c pass LSh to face 1cnrs

17--::

  1c set H&G with 1cnrs & 2cnrs, end passing RSh to 2pl (2,1,3)

25--::

  2c+1c Poussette (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11496, '2019-01-04 16:21:11.298067+00', '2019-02-19 16:12:08.039358+00', 12343, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c RHA ; 1W & 4M both followed by their P chase clw ½ (4x,2,3,1x)

9--::

  4c+2c & 3c+1c RHA ; 4M & 1W both followed by their P chase clw ½ (1,2,3,4)

17--::

  1c+2c & 3c+4c R&L (1,2,3,4)

25--::

  1c cross RH | cast (2c up) ; cross RH | cast to 4pl (3c+4c up) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (8093, '2013-10-15 21:08:52.212545+00', '2013-10-15 21:08:52.212545+00', 14931, 2, 160, 'ace', '1–8::
  1C cross RH, cast off (2C up); dance down btwn 3C cast up to 2nd place
9–16::
1C set to and turn 2C  RH 1/2 round; 1C set to and turn 2C LH 1/2 round. men face out
17-24::
1C 2C dance Ladies'' Chain.
25-32::
2C 1C 3C adv & ret; 1C dance 1/2 fig. 8 round 3C', 0);
INSERT INTO 'dancecrib' VALUES (1787, '2012-01-22 19:29:02.330948+00', '2015-02-28 21:00:44.568226+00', 611, 1, NULL, 'ace', '1–::

  All Circle6 and back

9–::

  1c, followed by 2c+3c, lead down to (3,2,1) ; 1c set adv | turn BH ¾, opening to finish BtoB in 2pl, W facing up, M down _while_{4} 2c set adv | Turn RH to 1pl _while_{4} 3c cast off to 3pl

17–::

  2c+1W Reel3 across (Lsh to 2M) _while_{8} 1M+3c Circle3 and back

25–::

  2c+1W Circle3 and back _while_{8} 1M+3c Reel3 across (Lsh to 3W)

33–::

  1c dance between 3c, cast up, dance between 2c, cast to 2pl (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1956, '2012-01-22 19:29:11.946383+00', '2021-05-06 13:52:30.227922+00', 4727, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1c dance in and lead down | set to P ; lead to top in centre | set to P

17–::

  1c wide cast off (2c up), meet and dance between 3c ; cast up | turn BH

25–::

  2c+1c+3c Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (1636, '2012-01-22 19:28:52.252804+00', '2017-11-06 23:34:45.088131+00', 77, 1, NULL, 'ace', '{{explanation}}

also called The Dunblane Drummer



1–::

  1c set |cross RH ; cast (2c up) | Turn LH to face 1cnr

9–::

  2c+3c dance tracks of Reels3 on the sides, starting inwards _while_{8} 1c dance along tracks of Reels3 across starting Rsh to 1cnr, at end 1c turn LH to face 3cnr

17–::

  Repeat [9-16], starting Rsh to 3cnr, at end turn LH to face 1cnr

25–::

  1c turn 1cnr RH | pass Rsh ; turn 2cnr LH (cnrs dance 4 bars) and dance to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1701, '2012-01-22 19:28:57.405219+00', '2014-04-30 23:23:38.937215+00', 314, 1, NULL, 'ace', '{{explanation}}
On 2nd chord 3c+4c change sides to 1,2,3x,4x. Centro-symmetrical dance.

1–::
  2c+3c Petronella Turn and set ; turn ¾ RH into ½RHA to form pairs in promhold facing out (3W+2M on M side ; 2W+3M on W side).
9–::
  1c+4c Petronella Turn | set ; ½ RH turn and Promenade clw to the side positions, forming a square set _while_{8} the pairs cast R | pass between end Cs ; Promenade clw to other end
17–::
  1c+4c ½ L-Chain across ; the pairs ½ M-Chain, finishing with a full RH turn to put M on the right of P (2c at top, 3c at bottom)
25–::
  All set | ½ circle8 L {3}, dance in on L foot into centre and all swivel R {1} | spiral out into longwise set (2,4,1x,3x)', 4);
INSERT INTO 'dancecrib' VALUES (11012, '2018-08-19 14:35:47.862715+00', '2019-02-12 11:07:13.138998+00', 878, 1, 202, 'ace', '1--::
  1c Fig8 up (1,2)
9--::
  1c+2c set twice ; turn P RH (1,2)
17--::
  Circle4 and back (1,2)
25--::
  2C Knot (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (3842, '2013-07-13 15:56:20.687193+00', '2020-05-24 08:20:56.184551+00', 14670, 1, NULL, 'ace', '1–::

  1c cross RH| cast (2c up) ; cross down and cast up to face 1cnr

9–::

  Turn CPCP (2,1,3)

17–::

  All set | cross RH ; chase clw ½ (3,1,2)

25–::

  Circle6 and back (3,1,2)





Unusual progression: 1c+2c+4c repeat; finishing (3,4,1,2) and 1c step down to (3,4,2,1); 3c starts the 3rd time through.  Can be danced in a 3c set with no changes  

', 3);
INSERT INTO 'dancecrib' VALUES (14308, '2021-09-13 07:40:05.196838+00', '2021-09-13 07:44:16.381303+00', 20483, 1, 202, 'ace', '1--::

  1c Petronella turn | set ; repeat [1-4] (1x,2,3)

9--::

  1c turn RH ½ into promhold facing up | 1C Allemande (2c up on [9-10] | 1c set advancing to face 2cnrs

17--::

  Reel4 on 2diag. 1c face 2cnrs

25--::

  1c+2cnrs set | turn BH ¾ to 2plx ; 1c set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8094, '2013-10-15 22:06:47.1671+00', '2021-04-04 13:17:43.471996+00', 339, 2, 160, 'ace', '1–8::

  1C 2C RH Across; LH Across 

9–16::

1C cross over RH, cast to 2pl (2C up); Turn RH 1.1/2

17–24::

2C 1C 3C adv & ret; dance Back-to-Back

25-32::

2C 1C 3C dance 6 hands round and back', 2);
INSERT INTO 'dancecrib' VALUES (2173, '2012-01-22 19:29:23.841419+00', '2016-10-25 02:57:06.183742+00', 1961, 1, NULL, 'ace', '1–::

  1W cross above P, dance down behind men, 2W follows on bar 3, 3W on bar 5, all cross below 3M and up own side to places

9–::

  Men repeat (Rsh to P)

17–::

  1c+2c 6 bars of Knot, ½ LHA (to 1,2,3)

25–::

  1c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (1711, '2012-01-22 19:28:57.848605+00', '2021-07-03 14:21:14.90445+00', 335, 1, NULL, 'ace', '1–::

  1c+2M Reel3 across the dance, 2M starting by giving Rsh to 1W

9–::

  1c+2W Reel3 across the dance, 2W starting by giving Lsh to 1M

17–::

  1W+2M cross RH, 1M+2W cross RH ; 2c+1c dance half R&L

25–::

  1c cross RH, cast one place ; dance ½ Fig8 round 2c', 2);
INSERT INTO 'dancecrib' VALUES (8730, '2015-03-15 21:58:33.090308+00', '2015-03-15 21:58:33.090308+00', 15763, 1, NULL, 'ace', '*Trios in circle RR.  “Ends” of each trio face clw, “centres” face cclw and take step back*



1--::

  “Centre” turns LH “end” with the LH ; RH “end” with the RH

9--::

  Each trio Circle L ; on [12] centre dances forwards raising arms, & pulling Rsh back dance under arches: “ends” keep NHJ behind his back ; In lines of 3 promenade clw

17--::

  “Ends” drop NH and face clw as “centre” keeping HJ with “ends” swivels L under raised arms, and all promenade cclw ; All set twice in triangle facing its centre 

25--::

  Reel3 with “ends”, start Rsh, and at the end “centres” dance forward to join next pair of “ends”.



', 3);
INSERT INTO 'dancecrib' VALUES (8881, '2015-08-31 09:42:11.335731+00', '2015-08-31 09:43:57.587449+00', 16698, 2, NULL, 'ace', '1-:: 1c+2c RHA into a diag line for ; 1c+2c 1/2 Poussette (2,1,3)

9-:: ½ Rsh Reels3 on the sides ; ½ Lsh Reels3 across (3x,1x,2x)

17-:: 1W+3M+2M A&R {1+1} giving hands briefly in a triangle | 1M+3W+2W repeat ; All Turn P BH 1½ into promhold facing up

25-:: 3c+1c+2c Allemande to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8880, '2015-08-29 07:10:27.863134+00', '2015-11-19 10:19:42.10378+00', 16678, 1, NULL, 'ace', '1--::  1c+3c ½ RHA | twirl to diagonally opposite position ; chase clw to original position

9--::  1c+3c R&L, finish facing corner

17--::  Interlocking Reels4

25-48::  2c+4c repeat [1-24]

49--::  All ½G-Chain | turn or spin P

57--::  Repeat back to places, W facing out

65-80::  Schiehallion Reel

81--::  All circle8 and back

', 3);
INSERT INTO 'dancecrib' VALUES (9071, '2016-01-13 23:29:57.54203+00', '2016-01-14 10:47:27.213969+00', 16843, 1, NULL, 'ace', '*Couple face couple round the room*

1--::

  All advance joining hands high and cheer, and retire ; RHA

9--::

  All advance joining hands high and cheer, and retire ; LHA

17--::

  All turn person opposite RH ; turn P LH, finish couple facing couple

25--::

  All pass 4 couples with “Arches over and under”; 2 bars per arch, couples facing cclw make first arch.  Face 5th couple.

', 3);
INSERT INTO 'dancecrib' VALUES (10462, '2018-02-26 22:45:10.165625+00', '2018-02-26 22:55:11.605831+00', 6169, 1, 202, 'ace', '1--::

  1c+2c set | ½ R&L | 1c turn P RH ¾ to face 2cnrs _while{2}_ 2c cross RH

9--::

  Corners pass and turn, on [11] 1c meet Rsh to P and pivot R to face 1cnrs ; Corners pass and turn, on [15] 1c meet P in centre and pivot R to finish BtoB 1W(1M) facing up(dn)

17--::

  1W+2c & 1M+3c RHA ; 1c ½ Fig8 L (2,1x,3)

25--::

  1W+2c & 1M+3c LHA ; 1c ½ Fig8 R (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11732, '2019-03-25 23:52:57.283332+00', '2019-03-26 18:29:16.97699+00', 14502, 1, NULL, 'ace', '*Triangular Set*

1--::

  All S&Link ; S&Link 

9--::

  All RHA ; LHA

17--::

  All dance BtoB R with P ; All dance BtoB L with cnr

25--::

  Circle6 and back

33--::

  Interlocking Reels4, all start Rsh to P, dancing as an "end dancer". (1,2,3)

41--::

  All turn P RH putting M in centre | M 2/3 LHA _while_ W chase clw 1 place ; Repeat  (2,3,1)





', 3);
INSERT INTO 'dancecrib' VALUES (8728, '2015-03-14 21:12:35.946033+00', '2015-03-16 13:53:09.051178+00', 16159, 1, NULL, 'ace', '1--::

  1c set | 1W casts behind 3W and dances up to place while{6} 1M dances down round 3M and casts up to place (1,2,3)

9--::

  1c+2c set | cast one place clw ; ½ RHA | 1M+2W set _while{2}_ 1W+2M change places RH (2,1,3)

17--::

  1c fig8 on own side, start in and down (2c facing 3c make arches)

25--::

  2c+1c+3c Allemande (3,1,2)



Dance three times as Strathspey, then three times as Reel.

', 4);
INSERT INTO 'dancecrib' VALUES (2045, '2012-01-22 19:29:16.788701+00', '2015-08-31 13:44:37.199285+00', 1537, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; turn LH 1¼ to face out and down on W side, 1M behind 1W (see note)

9–::

  2W+1c+3W Rsh lead-change Reel3 on W side (1W leads down, 1M up), at end face out and down on M side 

17–::

  2M+1c+3M Lsh lead-change Reel3 on M side, 1c end in promhold facing W side

25–::

  1c pass Rsh round 3W, dance to top and cast to 2pl



{{explanation}}

Note: during the reels 1M and 1W always cover parallel to the sidelines.', 3);
INSERT INTO 'dancecrib' VALUES (1713, '2012-01-22 19:28:57.945148+00', '2015-11-15 15:34:15.256717+00', 11216, 1, NULL, 'ace', '1–::

  1c dance BtoB ; turn RH and cast off (2c up) (2,1,3)

9–::

  1c dance BtoB ; turn RH 1½ to the side in 2plx, facing 1cnr (2,1x,3)

17–::

  »Pushme-Pullyou Reels«:  1c dance Fig8 on the side round corner positions, starting Rsh to 1cnr _while_{4} 2c facing 3c dance BtoB Rsh on the sides ; repeat figure, 1c Lsh to 2cnr and Lsh BtoB.

25–::

  1c+1cnr turn RH, into DTr position, 1c facing 2cnr and 1cnr | All set as in DTr ; 1c dance R, out between end couple and cast R to (2,1,3)



{{explanation}}

(after second turn, 1c either dance down the middle to 4pl (4c up) on [1-2], or repeat [1-8] with 4c', 3);
INSERT INTO 'dancecrib' VALUES (1710, '2012-01-22 19:28:57.80425+00', '2021-03-06 12:05:19.533019+00', 9076, 1, NULL, 'ace', '1–::

  1W+1M+2M & 3M+2W+3W RHA ; Circle3 L, finish (1,2,3) with 1W+3M a bit inwards from sideline

9–::

  1W+3M cross and cast Lsh round 2M/2W to meet and Turn LH ¾ ; RHA with same dancers as before, to (1,2,3) with 1W+3M facing out

17–::

  1c+3c chase clw to exchange places, finish 3c facing 1c NHJ (3x,2,1x) ; 1c+3c ½ R&L starting up/dn (2c up) and ending (2,1,3) with 1c facing 1cnr

25–::

  Turn CPCP to (2,1,3)



{{explanation}}

On second time 1c cross down to 4pl (4c up)', 2);
INSERT INTO 'dancecrib' VALUES (8686, '2015-02-27 22:38:38.022989+00', '2015-02-27 22:43:53.8152+00', 4038, 1, NULL, 'ace', '1--::

  R&L

9--::

  1c set | cast off (2c up) ; 1c ½ Fig8 up (2,1x)

17--::

  La-Chain

25--::

  1c set | cast up ; cross RH and cast off (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15361, '2022-12-19 09:21:15.637388+00', '2022-12-19 09:27:18.496646+00', 9909, 1, 202, 'ace', '1--::

  All set | cross to P''s place (4 slip steps) M facing down, W facing up ; repeat pattern of [1-4] W facing down, M facing up (1,2,3,4)

9--::

  Circle8 and back. 1c & 4c end in centre NHJ (1,2,3,4)

17--::

  1c & 4c A&R ; advance, turn opposite person LH 1½ to sides (2c & 3c step out on [21-22]) (2,4,1,3)

25--::

  Reels4 on sides (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13936, '2021-04-05 20:44:49.002206+00', '2021-10-13 08:58:48.704257+00', 20299, 1, 202, 'ace', '1--::
  1c+2c The Espagnole. 1c face out (2,1,3)
9--::
  Reels3 on sides, 1c LSh to 4cnrs. On [12] 1c turn RH to continue the reel on opposite sides. 1c face 1cnrs (2,1x,3)
17--::
  Set to and Turn Corners (2,1x,3)
25--::
  Reels3 on sides, 1W crossing up, 1M crossing down (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1865, '2012-01-22 19:29:06.896125+00', '2015-02-28 02:35:29.25438+00', 894, 1, NULL, 'ace', '1–::

  1c+2c+3c Petronella Turn into midline, set ; all turn P BH 1¼ to (1,2,3)

9–::

  “Teapots”: 1c+2W & 2M+3c RHA ; 1c+2M & 2W+3c LHA , to (1,2,3) with 1c facing out and 2c facing up in promhold 

17–::

  2c (promhold) +1W+1M Reel3 across (Rsh to 1W), at end all dance in for

25–::

  2c+1c+3c Allemande (to 3,1,2).', 3);
INSERT INTO 'dancecrib' VALUES (13931, '2021-04-05 08:33:24.313+00', '2021-04-05 08:44:39.315692+00', 20295, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c Poussette. All finish in centre NHJ, 1c & 3c facing down, 2c & 4c facing up (1,2,3,4)

9--::

  All dance up/down under 2c & 3c making arches and cross to opposite sides | all set (to 2x,1x,4x,3x) ; 1M+4W change places RH | 1W+4M change places RH (2x,4,1,3x)

17--::

  1c+4c ½ R&L (2x,1x,4x,3x) ; all turn P RH 1½, 2c to sides, 1c, 4c & 3c into Allemande hold facing up

25--::

  3C Allemande (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (9072, '2016-01-13 23:29:57.565833+00', '2016-01-13 23:29:57.565833+00', 16843, 2, NULL, 'ace', '*couples facing each other round the room*

1-8::

  All take hands and adv (bringing hands in the air and cheer) & ret, RHA

9-16::

  All take hands and adv (bringing hands in the air and cheer) & ret, LHA

17-24::

  Turn person opposite RH, partner LH

25-32::

  Progression: Changing arches: couples facing counter clockwise make arch and let the other couple pass under to face a new couple, then couple facing clockwise make arch and the other couple pass under and so on (2 bars per change – 4 changes in total to face 5th couple). 

', 5);
INSERT INTO 'dancecrib' VALUES (2218, '2012-01-22 19:29:26.349152+00', '2017-02-28 00:41:36.399415+00', 13385, 1, NULL, 'ace', '1–::

  All Circle and back

9–::

  All W dance cclw round P keeping NHJ raised above heads ; All M repeat clw

17–::

  All C advance to centre and retire ; repeat

25–::

  All turn P RH ; All turn cnr LH, into promhold, M on L

33–::

  All new couples promenade freely through the room to reform circles of any size



{{explanation}}

This »mixer« dance works for any number of couples per circle', 3);
INSERT INTO 'dancecrib' VALUES (9945, '2017-06-07 01:23:16.538228+00', '2017-07-07 01:10:26.006672+00', 14722, 1, 202, 'ace', '1--::

 1W followed by 1M cast off one | cross to 2plx (2c up) ; 1c turn BH 1 ½ (2,1,3,4)

9--::

 Reels3 on sidelines, 1c Rsh to 4cnr (2,1,3,4)

17--::

 1c+3c S&Link (to 2,3,1,4) ; 1c+4c set | set adv ready for

25--::

 1c+4c ½ Poussette ; all turn BH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10058, '2017-09-03 19:40:36.592148+00', '2017-09-13 14:08:24.863634+00', 17925, 1, NULL, 'ace', '1--::

  3c+1st Double Corners (1M+2M+3c+4W+5W) ½ diag Reel4 (Rsh to 1cnrs) (corners dance in tandem) 4W stops in 1M place and 2M in 5W place ; the others continue the reel, at end 1M/5W are in 2M/4W places and 3c pass P Lsh to face 2cnrs. 

9--::

  3c+2nd Double Corners (1W+2W+3c+4M+5M) repeat (to 4x,1,3,5,2x)

17--::

  4c+2c cross into ½ Fig8 round their end cpl while{4} 3c turn RH ; 3M dances up middle and casts off to 2Mpl (1M down) while{4} 3W dances down the middle and casts to 4Wpl (5W up)

25--::

  Circle10 and back (M: 4,3,1,5,2 ; W: 4.1.5.3.2)

', 3);
INSERT INTO 'dancecrib' VALUES (14142, '2021-07-09 16:45:29.89332+00', '2021-07-10 04:25:04.024801+00', 10003, 1, 202, 'ace', '1--::

  All W advance | set pivoting R back to centre ; all dance BtoB

9--::

  All turn P RH ½ | all set ; all M LHA back to places except 1M & 3M

17--::

  1c+3c Reel4, 1M & 3M RSh to P (1,2,3,4)

25--::

  2c & 4c in promhold chase clw round the square to places (1,2,3,4)

33--::

  1c & 3c advance | give RH to opposite person and set to nearest sides couples ; lead out and cast to original places (1,2,3,4)

41--::

  2c & 4c repeat [33-40]

49--::

  All M with P on the outside ½ LHA ; all W with P on the outside ½ RHA (1,2,3,4)

57--::

  Circle8 and back (1,2,3,4)', 2);
INSERT INTO 'dancecrib' VALUES (2122, '2012-01-22 19:29:21.269492+00', '2015-07-12 08:49:10.711927+00', 1792, 1, NULL, 'ace', '1–::

  1c turn RH, cast off (2c up) ; turn LH to face 1cnrs

9–::

  Turn CPCP, to face 1cnrs

17–::

  1c set to and turn 1cnrs BH ; set to and turn 2cnrs BH

25–::

  Reels3{6} on the sides (Lsh to 1cnr) | 1c cross RH to 2pl.', 3);
INSERT INTO 'dancecrib' VALUES (9074, '2016-01-17 00:26:52.891567+00', '2016-01-17 00:26:52.891567+00', 1985, 1, NULL, 'ace', '1--::

  1c+3c cross RH | cast off (2c+4c up) ; 1c+3c ½ Fig8 through 4c & 5c respectvely (2,1,4,3,5)

9--::

  2c+1c+4c+3c Mirror Reels4 on the sides (1c+3c in and up, 2c+4c out and down), 4c finish facing out (2,1,4,3,5)

17--::

  1c+4c+3c+5c Mirror Reels4 on the sides (1c+3c in and down, 4c+5c out and up)

25--::

  1c+3c set | dance up the middle one place ; cast off (4c+5c up) to (2,4,1,5,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9907, '2017-06-05 00:18:44.975635+00', '2017-06-08 13:23:07.273789+00', 5355, 1, NULL, 'ace', '*3c+4c cross on 2nd chord (1,2,3x,4x). Centro-symmetrical dance.*

1--::

  1c+4c set | ½ turn LH ; 1W & 4W, followed by P, dance between nearest cpl, and out opposite side | split, W casting L to exchanged places and M R to original places

9--::

  DblFig8 at top and bottom, to start end pairs cross in and middle cpls dance to end

17--::

  End pairs set | cross RH ; set | cross into line across in the middle, W to opposite sides facing in and M into BtoB between them, facing P, _while{2}_ 2c+3c cast to the ends

25--::

  1c+4c Reel4 across, but at end 1M+4M turn RH ½ and join NH with P into line of 4

33--::

  Line turns ½ clw ; W dance ½ Fig8 R through end cpls _while{4}_ M turn RH (2,4,1x,3x)

41--::

  Circle8 and back

', 3);
INSERT INTO 'dancecrib' VALUES (10712, '2018-04-29 23:31:26.864999+00', '2020-10-19 10:00:27.840959+00', 17125, 1, 202, 'ace', '1--::

  1c cross RH | cast off 2 places ; cross LH | cast up to 1pl (1,2,3)

9--::

  all A&R ; dance BtoB (1,2,3)

17--::

  1c+2c ½ R&L (to 2x,1x,3) ; 2c+1c set | 2c cross RH _while{2}_ 1c turn RH ½ into centre BHJ, 3c step in on [24] for (2,1,3)

25--::

  1c+3c Poussette (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2277, '2012-01-22 19:29:29.319276+00', '2020-12-18 20:58:52.196196+00', 7738, 1, NULL, 'ace', '{{explanation}}

3c+4c start on opposite sides.



1–::

  1c+4c cross RH and cast to 2pl/3pl (2c+3c step to ends) ; 1c+4c RHA, at end 4W+1M & 1W+4M make pairs in promhold and face out on W (M) side (similar to The Bees of Maggieknockater)

9–::

  Both pairs ½ Rsh Reel3 on sidelines (to »1cnr«), at end the pairs dance in from the end for 1c+4c LHA, finishing in promhold with P, 1c (4c) facing M (W). (Men hold LH and turn towards P)

17–::

  ½Reels on sidelines (as in 9-12) starting Lsh to 3M & 2M, at end 1c+4c meet NHJ ; 4c makes arch, dance down and cast up to 3pl _while{4}_ 1c dance up under arch and cast off to 2pl

25–::

  1c+4c set advancing individually to touch hands in circle and retire to sidelines _while{4}_ 2c+3c chase clw ½ round (2W+3W cast to begin) ; all C circle8 left half way to order 2, 4, 1, 3 (1c+3c on opp sides)', 2);
INSERT INTO 'dancecrib' VALUES (13546, '2021-01-10 08:49:32.559124+00', '2021-01-10 08:54:53.35789+00', 2430, 1, 202, 'ace', '1--::

  1c dance down between 3c, cast up to 2pl ; cross RH and dance round 1cnrs into facing lines3 across

9--::

  All set | 1c turn RH 	¾ to 2plx ; all set | 1c turn LH ¾ into lines3 across. 1c face 1cnrs

17--::

  Reels3 across, 1c LSh to 1cnrs (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (1709, '2012-01-22 19:28:57.755196+00', '2021-03-02 22:31:56.161576+00', 9082, 1, NULL, 'ace', '1–::

  1c+3c cross RH, cast off one (2c+4c up) ; cross LH, cast L and finish in the middle, 1M & 3W having passed Lsh

9–::

  Reels across: 1M+3W+4c Reel4 _while_{8} 1W+2c & 3M+5c Reels3, start and finish facing 1cnr

17–::

  1c+3c Turn CPCP into

25–::

  RHA for: 1W+2c and 1M+4c+3W and 3M+5c ; 1c+3c turn P LH and cast off on own side (4c+5c up) (to 2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (14385, '2021-10-12 10:46:11.50032+00', '2021-10-13 08:31:04.402149+00', 20357, 1, 202, 'ace', '1--::
  All (1M & 4W leading) chase clw ½ ; 4c+3c & 2c+1c ½ RHA | all turn P RH ½ (3x,4x,1x,2x)
9--::
  All repeat same pattern [1-8] (1,2,3,4)
17--::
  All W A&R ; set twice _while{8}_ all M set | A&R | set (1,2,3,4)
25--::
  1c cross down RH to 2plx (2c dance up) | cast off behind 3c (3c up) ; cross down LH to 4pl (4c dance up) | all set (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (1718, '2012-01-22 19:28:58.217402+00', '2017-01-31 21:55:52.699069+00', 13720, 1, NULL, 'ace', '1–::

  1c+2c set | Circle4 L | turn BH into promhold facing up

9–::

  1c+2c Allemande, 1c finish with LH turn to face 1cnr

17–::

  1c dance Rsh round 1cnr and pass Rsh to face 2cnr _while{4}_ 1cnrs turn RH ½ to face and cast R to exchanged places ; repeat with 2cnrs

25–::

  3c+1M & 1W+2c RHA, opening (1c leading) into ; chase clw ½ (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10534, '2018-03-20 17:17:21.447377+00', '2018-03-20 17:43:17.991754+00', 7775, 1, 202, 'ace', '1--::

  1M+3W »Half-turn and cast away« [turn RH ½, face each other | cast R to exchanged places ; 1W+3M repeat [1-4] and face out (3x,2,1x)

9--::

  Mirror Reels3 on sidelines, 1c start out and up, 2c in and down (3x,2,1x)

17--::

  1c turn 2c EH 1 ½ (to 3x,1x,2) ; 3c+1c ½ DblFig8, 1c cross up to start (3,1,2)

25--::

  3C Knot (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10395, '2018-01-20 17:14:15.309762+00', '2018-04-18 17:07:38.184923+00', 18226, 1, 202, 'ace', '1--::

  All set | 1c+2c & 3c+4c ½ RHA ; all set | 1c+4c ½ RHA, 2c facing 4c & 1c facing 3c at end (2x,4x,1x,3x)

9--::

  All Petronella Turn into 2 lines of 4 across | set ; parallel ½ Reels4 across

17--::

  All Petronella Turn to sidelines | set ; parallel ½ Reels4 (3,1x,4x,2)

25--::

  3c & 2c cross RH | ¾ Circle8 L into 2 lines of 4 across (2,4,1,3)



*Repeat in Strathspey time, and twice in Reel Time*



Note from deviser:



*At the end of the 2nd repeat, every one will be opposite where they started, i.e. in their partner’s original place.*', 4);
INSERT INTO 'dancecrib' VALUES (11234, '2018-10-01 18:42:39.847493+00', '2022-04-26 01:47:48.073707+00', 15609, 1, 202, 'ace', '1--::

  1c+2c Bourrel. On [7-8], 2c turn RH to 1pl _as_ 1c turn RH to centre, 1W(1M) facing down(up)

9--::

  Reels3 across, 1c RSh to 2cnrs, 1c face 1cnrs

17--::

  Corners Pass and Turn. On [23-24] 1c turn LH to centre, 1W(1M) facing up(down)

25--::

  Reels3 across, 1c LSh to 1cnrs (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (13542, '2021-01-09 22:39:25.612006+00', '2021-01-09 22:41:55.096457+00', 7084, 1, 1645, 'ace', '1-::
  2c followed by 1c dance down below 3c & cast up (2,1,3) ; 1c followed by 3c dance up & cast round 2c (2,3,1)
9-::
  2W+1M change pl RH | cast to R _while{4}_ 2M & 1W set | turn LH to face P on 1cnr diagonal ;
  2c+1c &frac12; diag RSh Reel4, end in centre NHJ, 1c facing down, 2c up (1,3,2)
17-::
  1c+3c+2c set | &frac12; circle6 to L, dance into centre on [22], pull RSh back & chase &frac12; way clw (1,3,2)
25-::
  1c+3c+2c Knot (2,3,1)
', 2);
INSERT INTO 'dancecrib' VALUES (1722, '2012-01-22 19:28:58.41351+00', '2014-11-10 22:49:36.647576+00', 11556, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; turn LH to 2pl facing in (2,1,3)

9–::

  2c+1W & 1M+3c reels3 across, Lsh to 1cnr

17–::

  2c+1M & 1W+3c reels3 across, Rsh to 2cnr (2,1,3).

25–::

  All circle6 & back.', 2);
INSERT INTO 'dancecrib' VALUES (9947, '2017-06-08 14:07:56.864798+00', '2019-08-22 16:58:14.373784+00', 14514, 2, 160, 'ace', '1-8::

  1C set, Turn RH 1_1/2 [4], cast 1pl. (2 1x 3 4)

9-16::

  1C 3C 4C dance Reel3 on sides (1C in & down).

17-24::

  2C 1C 3C dance Reel3 on sides (1C in & up).

25-32::

  1C turn RH 1_1/2 ; cast to bottom, All set. (2 3 4 1) ', 3);
INSERT INTO 'dancecrib' VALUES (8731, '2015-03-16 23:50:23.979743+00', '2015-03-16 23:52:53.439149+00', 5016, 1, NULL, 'ace', '1-16::

  All petronella to midline facing P and set ; 1c+2c+3c Rsh Reel6{12b} _while_ 4c petronella to 4plx, set ; and wait

17-20::

  1c+2c+3c petronella to opp. side and set (1x,2x,3x,4x)

21-28::

  [W’s solo] 2W+3W+4W set adv. and join hands with Men (RH with P) | BiL _while{4}_ 1W casts off to 4M pl ; 2W+3W+4W dance out between M and cast L round M on L to finish on M side (2W,3W,4W,1W)

29-36::

  [M’s solo] 2M+3M+4M set adv. and join hands with W (LH with P) | BiL _while{4}_ 1M casts off to 4W pl ; 2M+3M+4M dance out between W and cast R round P to finish on W side (2x,3x,4x,1x) 

37-40::

  All set and cross RH (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2394, '2012-01-22 19:29:35.36013+00', '2015-08-31 14:14:49.302701+00', 10790, 1, NULL, 'ace', '1–::

  1c+2c RHA ; 1c cast as 2c dance up | 1c+3c ½ LHA, W face down, M up (2,3x,1x,4)

9–::

  3W+1W in tandem with 2M & 4M Rsh change-lead Reel3 on M side _while{8}_ 3M+1M in tandem with 2W & 4W Rsh lead-change Reel3 on W side, 3c+1c finish in the centre in a circle

17–::

  3c+1c set, moving one place L on 2nd PdB | repeat (2,1,3,4) ; 1c+3c dance between 2c and cast (2,3,1,4)

25–::

  All set | 2c+3c turn RH _while{4}_ 1c turn RH and cast off _while{4}_ 4c turn RH moving to 3pl |  All set (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2410, '2012-01-22 19:29:36.33002+00', '2018-01-21 22:04:15.338514+00', 2809, 1, NULL, 'ace', '1–::

  1c+3c circle4 L ; in circle set across {1}, to P {1} | dance out to place, finish BtoB

9–::

  2c & 4c in promhold Rsh Reels3 with (1M+3W) resp (3M+1W)

17–::

  2c+4c RHA ; LHA

25–::

  2c+4c chase ¼ cclw, make parallel loops Lsh around next couple (M round M, W round W), chase ¼ to opposite place

33–::

  2c+4c circle4 R ; set and dance out as in [5-8] (1,4,3,2)

41–::

  1c+3c in promhold Rsh Reels3 with (2M+4W) resp (4M+2W)

49–::

  1c+3c RHA ; LHA

57–::

  1c+3c repeat chase ¼ cclw + parallel loops + chase ¼, end in opposite place (3,4,1,2)

65–::

  1W+3W cross Lsh, dance Lsh round opposite M, to own places ; 1M+3M cross Rsh, dance Rsh round P, to own places

73–::

  2W+4W repeat ; 2M+4M repeat

81–::

  All turn P RH ; turn P LH 1¼, placing W in the centre', 4);
INSERT INTO 'dancecrib' VALUES (1724, '2012-01-22 19:28:58.507674+00', '2014-04-30 23:23:39.428882+00', 392, 1, NULL, 'ace', '1–::
  1c followed by 2c+3c acknowledge partner and cast off behind own lines to 3pl ; cross RH (pass other dancers Rsh) and cast up to (1x,2x,3x)
9–::
  1c+2c+3c A&R ; all cross RH and set
17–::
  1c lead down the middle and up
25–::
  1c+2c Rondel', 3);
INSERT INTO 'dancecrib' VALUES (12887, '2020-06-14 00:35:46.107583+00', '2021-05-05 23:43:05.771841+00', 10255, 1, 202, 'ace', '1--::
  Double L-Chain, all M casting to P place (1,2,3,4)
9--::
  1c+3c Reel4 up/down, both W passing RSh in centre, both M casting to P place (1,2,3,4)
17--::
  Double R&L, 1c & 3c changing places RH with P  (1,2,3,4)
25--::
  All W Petronella turn to next place cclw | All M repeat ; all turn P LH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (9871, '2017-05-20 06:00:04.513005+00', '2017-08-26 12:19:39.677711+00', 16477, 1, 202, 'ace', '1--::

 1c+2c S&Link ; RHA  (2,1,3)

9--::

 1c dance up | cast to 2pl ; dance down | cast to 2pl (2,1,3)

17--::

 1c+3c S&Link ; RHA (2,3,1)

25--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (9798, '2017-04-15 23:19:08.83996+00', '2021-05-25 12:51:13.582864+00', 3200, 1, 202, 'ace', '1--::

 1c cross down RH (2c up) | 1c set to 3c ; 1W turn 3M LH ½ _while{2}_ 1M turn 3W RH ½ | 1c dance up (2,1x,3)

9--::

 1c set to 2c | 1W turn 2M RH ½ _while{2}_ 1M turn 2W LH ½ (to 2,1x,3) ; 1c ½ Fig8 between 2c to finish facing 1cnrs

17--::

 1c+1cnrs diagonal Reel4 then passing Lsh

25--::

 1c+2cnrs diagonal Reel4 (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1721, '2012-01-22 19:28:58.368456+00', '2021-07-03 14:05:06.301669+00', 377, 1, NULL, 'ace', '1–::

  1c+2c+3c mirror Reels3 on the sides, 1c crossing down to begin

9–::

  Repeat, 1c crossing back to own sides

17–::

  1c dance NHJ between 2c, face each other and set ; dance to top and cast off to face 1cnr (2c up)

25–::

  Turn CPCP (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11499, '2019-01-05 12:14:44.006565+00', '2022-02-15 15:41:33.859881+00', 14450, 1, 1645, 'ace', '1-::

  1c+2c poussette

9-::

  1c lead down (2c up on [11-12]) & back up to (2,1)

17-::

  2c+1c RHA ; 2W+1M &frac12; turn RH & twirl away _while{4}_ 2M & 1W chase &frac12; way clw (1x,2x)

25-::

  1c+2c LHA ; 1W+2M &frac12; turn LH & twirl away _while{4}_ 1M & 2W chase &frac12; way cclw (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15362, '2022-12-19 11:24:30.957152+00', '2022-12-19 11:32:21.879433+00', 16732, 1, 202, 'ace', '1--::
  1M+2W cross RH | set ; 1W+2M cross LH | set (2x,1x,3)
9--::
  2c+1c ½ R&L ; 2c & 1c turn P RH into allemande hold
17--::
  2C Allemande. 1c face 1cnrs
25--::
  Turn CPCP. 1c finish between ends facing 1cnrs
33--::
  Reels3 across, 1c LSh to 1cnrs (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14309, '2021-09-13 13:43:48.555674+00', '2021-09-13 13:46:00.446762+00', 10492, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; 2c+1W & 1M+3c RHA. 1c meet in 2pl centre facing down

9--::

  1c lead down ; and up to 2pl (2,1,3)

17--::

  Circle6 and back (2,1,3)

25--::

  Reels3 across, 1c LSh to 1cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8815, '2015-06-29 12:17:23.099345+00', '2015-09-29 08:44:00.019917+00', 13869, 1, NULL, 'ace', '1-::

  Crossover Reels3 on the sides, to start 2c cross up (no hands) and 1c+3c cast and loop at the end (1,2x,3)

9-::

  All S&Link3 ; ½ Circle6 L (lines across)

17-::

  All S&Link3 ; ½ Circle6 L (3x,2,1x))

25-::

  2c+1cnrs ½ diag Reel4, 2c with twirl R finish BtoB in middle, W facing up, M down ; 2c+4cnrs ½ diag Reel4, finish (1,2,3) 2c facing 3c 

33-::

  Modified Gr-Chain: 1c turn RH _while{2}_ 2c+3c pass RH | 2c turn LH _while{2}_ 1c+3c pass LH ; 3c turn RH _while{2}_ 2c+3c pass RH | 1c turn RH _while{2}_ 2c+3c pass RH (2,3,1)



*1c continues into next reel without polite turn*

', 3);
INSERT INTO 'dancecrib' VALUES (1864, '2012-01-22 19:29:06.836623+00', '2015-02-28 21:41:40.545818+00', 893, 1, NULL, 'ace', '1–::

  1c+2c+3c set and cross RH ; repeat, 2c face out

9–::

  1c turn RH ½ shifting to 2pl facing up NHJ _while_{2} 2c cast into 1pl NHJ facing 2c | 2c+1c set ; ½RHA | 1c cast off, 2c turn RH ½ shifting to 1pl (2,1,3)

17–::

  1c cross RH | cast R ; cross up/down LH | cast L _while_{8} corners set diagonally | adv {1} & retire {1} NHJ to the sides ; repeat , but now retire NHJ up/down

25–::

  2c+1c+3c set | circle6 L, dance into centre, swiveling R to spiral clw to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1669, '2012-01-22 19:28:54.041255+00', '2019-03-19 23:33:41.331109+00', 195, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  All dance intersecting reels of 4, the M start passing Lsh in centre, the W finish in centre facing P

9-24::

  All C set | petronella turn ; repeat 3 times

25–::

  All C set H.Schottische ; turn RH 2¼ , finish W facing out

33-48::

  All dance Schiehallion Reels



{{explanation}}

Reel	Repeat in reel time, setting on [25-28] with »PdB coupé« in place of H.Schottische.', 2);
INSERT INTO 'dancecrib' VALUES (3868, '2013-07-27 07:45:53.506973+00', '2018-11-09 22:52:30.728783+00', 917, 1, 1041, 'ace', '1--::

  1c+2c & 3c+4c RHA ; ½ Circle8 L (4x,3x,2x,1x)

9--::

  4W+3W & 2W+1W dance between opposite men, divide and dance back to sideline and face ; ½Reel4

17--::

   Men repeat (1x,2x,3x,4x)

25--::

   1c cross RH and cast to 4pl _while{4}_ others set and cross up RH ; All turn P BH (2,3,4,1)

', 4);
INSERT INTO 'dancecrib' VALUES (10039, '2017-08-03 07:20:59.372601+00', '2019-08-29 15:29:47.346461+00', 17464, 1, 202, 'ace', '1--:: 1c dance to between 3c | turn 3c EH ¾ (2c up) ; dance to top | turn 2c EH ¾ (2,1,3)

9--:: 1c cross down to between 3c | turn 3c EH ¾ (to 2,1x,3) ; dance to top | cast to 2plx

17--:: ½ Reel4 in 1diag, pass Lsh ; ½ Reel4 in 2diag, pass Rsh to 2plx (3x,1x,2x)

25--:: All chase clw ½ ; All turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1727, '2012-01-22 19:28:58.677989+00', '2014-07-14 15:19:34.931685+00', 13149, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; ½ Fig8 L (2,1x,3)

9–::

  All set | 1c cross Rsh ; 1c+3cnr turn RH 1½  (to 1,2,3 on M side, 2,3,1 on W side)

17–::

  3C Bourrel: 2W+3M chase cclw half round to midline _while_{4} 1M+3W & 2M+1W set adv | turn BH ¾ and pivot R, all facing P on midline (3,1,2) ; All set | All C turn BH ¾ to sidelines

25–::

  All chase clw ½ round ; all turn P RH ½ and twirl R to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1729, '2012-01-22 19:28:58.766877+00', '2014-10-27 20:57:09.584276+00', 413, 1, NULL, 'ace', '1–::

  1c+3c turn RH and face clw ; chase ½ round set into

9–::

  3c+1c RHA ; LHA to exchanged places (3,2,1,4)

17-32::

  2c+4c repeat [1-16] (3,4,1,2)

33–::

  1c+3c turn LH and face cclw ; chase½ round set to own places

41–::

  1c+3c R&L (1,4,3,2)

49-64::

  2c+4c repeat [33-48] (1,2,3,4)

65–::

  All C NHJ advance | retire »diagonally« NHJ with cnr ; all W dance clw round their cnr

73–::

  All pairs advance | retire NHJ with P to places ; all M dance clw round P

81–::

  All circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (1730, '2012-01-22 19:28:58.819292+00', '2018-11-08 22:57:03.237081+00', 12021, 1, NULL, 'ace', '1–::

  1c turn RH ; cast off (2c up) | set advancing swiveling R to face own side in DTr position

9–::

  DTr, on [15-16] 2c+3c set advancing and 1c finish in middle, all rready for

17–::

  Allemande (to 3,1,2)

25–::

  1c+2c R&L', 3);
INSERT INTO 'dancecrib' VALUES (13543, '2021-01-09 22:57:49.627907+00', '2022-05-06 01:40:23.445923+00', 11602, 1, 1645, 'ace', '1-::

  1c cross down into Reels3 on sides, 1c & 2c end facing down/up on sides (1x,2,3)

9-::

  1c+2c set twice facing on sides ; turn 1&frac12; LH on sides, M end facing out (2,1x,3)

17-::

  2c+1c L-Chain (2,1x,3)

25-::

  2c+1c+3c A&R ; 1c turn 1&frac12; BH (2,1,3)

::

  *Alternative for [29-32]: all turn BH ending on own sides*

', 2);
INSERT INTO 'dancecrib' VALUES (8732, '2015-03-17 00:13:24.775231+00', '2015-03-17 00:26:01.202023+00', 1775, 1, NULL, 'ace', '1--::

  1c turn RArmsLinked ; repeat LArmsLinked

9--::

  1c cast off and meet (2c up) ; 1c turn RArmsLinked moving to between 2c, finishing BtoB facing opposite side

17--::

  All set to P H.Schottische ; 1W+2M & 1M+2W turn RArmsLinked to (2,1x)

25--::

  All set to P H.Schottische ; 2c & 1c RArmsLinked turn to (2,1) (2c turn twice)

', 3);
INSERT INTO 'dancecrib' VALUES (2501, '2012-01-22 19:29:45.305753+00', '2014-04-30 23:23:55.643773+00', 3237, 1, NULL, 'ace', '1–::
  1c+2c A&R ; circle4 half round to the left
9–::
  1M+2W turn RH 1½ to own places ; 1W+2M repeat
17–::
  1c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (3811, '2013-07-13 15:56:12.76105+00', '2015-03-18 09:46:48.69813+00', 14528, 1, NULL, 'ace', '1--::

  1c+4c turn RH | cast inwards (2c+3c step out) ; 1c+4c turn P LH | ¾ LHA (M at top, W at bottom) to face cnrs

9-24::

  Intersecting Figure: 2c+3c dance the pattern of two intersecting diagonal reels4, using ½ LHA to pass in the centre _while{16}_ 1c+4c dance Mairi’s Wedding pattern (Rsh round cnr | pass Lsh in centre to face next cnr cclw ; repeat 3 times). At the end 1c+4c pass P Lsh and finish between end couple facing own side

25--::

  4c+2c & 1c+3c Reels4 across, finishing (2,4,1,3) 

33--::

  Circle8 and back (2,4,1,3)



*Note:  This crib follows the CUSRC video: 1c+4c pass Lsh in the middle; the official Rsh pass is impractical.*

', 3);
INSERT INTO 'dancecrib' VALUES (14144, '2021-07-11 21:17:47.238711+00', '2021-07-11 21:20:44.94921+00', 20364, 1, 202, 'ace', '1--::

  1c set, dance down round 3c and cast up to original places _while{6}_ 2c starting on [3] repeat same movement _while{4}_ 3c starting on [5] repeat same movement (1,2,3)

9--::

  ½ Mirror Reels3 on sides, 1c in and down (to 3,2,1) ; 1c turn P RH ½ | lead up to face 1cnrs[pos] (2c down)

17--::

  Corners Pass and Turn (3,1,2)

25--::

  All chase clw ½ (to 2x,1x,3x) ; all turn P RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9799, '2017-04-16 18:15:46.060398+00', '2021-04-04 19:32:27.548046+00', 6837, 1, 202, 'ace', '1--::

 1M+2M making arch & 1W+2W cross to opposite side, turning in to face P ; repeat, W making arch 

9--::

 1c+2c RHA ; LHA

17--::

 1c lead down {3}, up {3}, and cast (2c up) (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (9797, '2017-04-15 22:47:03.796833+00', '2021-06-07 10:09:58.816132+00', 2251, 1, 202, 'ace', '1--::

 1c+2c RHA ; LHA

9--::

 1c lead down (2c up) ; lead up (2,1)

17--::

 1c turn RH ; turn LH', 2);
INSERT INTO 'dancecrib' VALUES (13932, '2021-04-05 09:41:17.250421+00', '2022-08-15 14:09:06.948532+00', 20301, 1, 202, 'ace', '1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 1c+4c LHA and face nearest cnrs (2,1x,4x,3)

9--::

  Crossing double Reels4 (swift ½ LHA in the middle)

17--::

  1c+4c LHA to sides (2,1x,4x,3) ; ½ R&L (no polite turn) (2,4,1,3)

25--::

  2c+4c & 1c+3c Circle4 L ; 4c+1c Circle4 R (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8088, '2013-10-15 10:35:59.415203+00', '2022-10-14 21:41:55.291725+00', 8055, 1, NULL, 'ace', '1–::

  1M+3W set twice ; turn RH to places

9–::

  1W+3M repeat LH

17–::

  1c cross | cast off 2 (2c+3c up) ; ½ Fig8 round 3c, casting to 4pl (4c up)

25–::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (1891, '2012-01-22 19:29:08.373552+00', '2015-08-31 14:21:38.130328+00', 984, 1, NULL, 'ace', '*Couple face couple RR*

1–::

  All turn P RH ; all set advancing and join LH with P, the W joining RH | BiL

9–::

  W turn RH ½  into L-Chain (along line of dance), finish in own places

17–::

  R&L, starting RH to opposite couple

25–::

  A&R with the other couple ; advance passing Rsh to meet the next couple.', 2);
INSERT INTO 'dancecrib' VALUES (9801, '2017-04-17 17:54:58.578948+00', '2017-08-26 06:59:14.911757+00', 15190, 1, 202, 'ace', '1--::

 1M+3M turn RH ¾ | cast L through side C to exchanged places ; top & bottom C A&R

9--::

 2M+4M turn RH ¾ | cast L through top & bottom C ; side C A&R

17-28::

 ¾ G-Chain starting RH to P (two bars per hand)

29-32::

 All turn P RH (4,1,2,3) ', 2);
INSERT INTO 'dancecrib' VALUES (1728, '2012-01-22 19:28:58.720874+00', '2017-07-07 13:02:11.989618+00', 410, 1, NULL, 'ace', '1–::

  All A&R, cross Rsh (men make arches)

9–::

  Repeat (women''s arches)

17-32::

  1c turn RH 1½ | into »strip the willow« (turn next cpl LH | P RH ; repeat twice) end with ½ RH turn and make BH arch

33–::

  2c (leading)+3c+4c cast to bottom and dance up under arch to new places (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (9802, '2017-04-17 18:33:50.526722+00', '2017-07-07 15:50:17.087026+00', 15660, 1, 202, 'ace', '1--::

 1c cross RH | cast (2c up) ; ½ Fig8 R to face 1cnrs

9--::

 1c+1cnrs set, 1c pulling Rsh back to face P | 1c turn RH to face 2cnrs ; 1c+2cnrs set, 1c pulling Rsh back to face P | 1c turn RH to face 3cnrs

17--::

 1c+3cnrs set, 1c pulling Rsh back to face P | 1c turn RH to face 4cnrs ; 1c+4cnrs set, 1c pulling Rsh back to face P | 1c turn RH to 2plx (2,1x,3)

25--::

 All turn P LH ; 1c cross RH | set _while{4}_ 2c&3c turn RH', 2);
INSERT INTO 'dancecrib' VALUES (9800, '2017-04-16 18:33:39.269456+00', '2017-08-26 13:56:12.310512+00', 6654, 1, 202, 'ace', '1--::

 1c+2c R&L

9--::

 RHA ; LHA

17--::

 1c lead down {3}, up {3}, and cast (2c up) to face 1cnrs

25--::

 Turn CPCP (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11747, '2019-03-26 23:37:23.392769+00', '2019-03-27 00:04:39.857451+00', 19051, 1, NULL, 'ace', '1--::

  1c & 4c ½ Fig8 round next cpl (1x,2,3,4x) ; ends (start inwards) turn middles 1¼ EH into lines across, 1c & 4c (middles) facing ends 

9--::

  1c+2c & 3c+4c Reels4 across, finish as [8]

17--::

  All set | 1c/4c (start towards own end) turn 2c/3c EH ¾ ; All set on sides | 1c & 4c cross to own side,  passing between W (2,1,4,3)

25--::

  1c+4c Espagnole (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (1736, '2012-01-22 19:28:59.109086+00', '2015-10-27 19:00:55.312743+00', 11587, 1, NULL, 'ace', '1–::

  1c set | cross RH ; 1c set to 2c | change places LH and M face out (2,1x,3)

9–::

  2c+1c L-Chain, 1M faces out (2,1x,3)

17–::

  1M casts, 1W following, round 3W, 1M casts up round 3M and 1W dances up the middle, to 2pl ; 1c turn 2c on the side LH (2,1,3)

25–::

  Reels3 on the sides, 1c Rsh to 3c (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11235, '2018-10-01 21:43:53.526659+00', '2019-03-19 22:22:02.043096+00', 463, 1, NULL, 'ace', '1--::

  1c set | cast (2c up) ; turn LH to face 1cnr

9--::

  CPCP and face 1cnr

17--::

  Reels3{6} on the sides, Lsh to 1cnr | 1c cross up as 2c cast off (1,2,3)

25--::

  [form a square set]  1c set | turn RH ½ and face down in 1pl(Sq. set) ; 4c set | turn LH into 3pl(Sq) 

33--::

  2c+3c set twice to P advancing 2nd time ; 2c turn BH ¾ to 2pl(Sq) as 3c turn BH 1¼ to 4pl(Sq)  (in Sq set: 1,2,4,3) 

41--::

  All face P for ½ Gr Chain | All turn P RH 

49--::

  Continue Gr-Chain | Turn P RH and face in (in Sq set: 1,2,4,3)

57--::

  1c+4c La-Chain, finish all facing cnr

65--::

  All set to cnr twice ; turn BH (in Sq set: 1,2,4,3)

73--::

  2c+3c La-Chain, finish all facing cnr

81--::

  All set to cnr twice ; turn BH (in Sq set: 1,2,4,3)

89--::

  Circle8 and back.  Honour corner, then P

', 3);
INSERT INTO 'dancecrib' VALUES (10262, '2017-11-18 06:07:57.091131+00', '2021-07-12 07:57:40.435051+00', 1943, 2, 645, 'ace', '1–8::

  1M+2W XR | 1c+2c Chase clw 1/4 ; 2c+1c RHA (213)

9–16::

  1W+3M XL | 1c+3c Chase aclw 1/4 ; 3c+1c LHA (231)

17–24::

  1c Set | 1c LeadUp & Cross  | 1c Cast off (Bar 5-6 3c StepDown) (21x3)

25–32::

  2c+1xc+3c Adv+Ret ; 2c TB, 1xc TB1 1/2, 3c TB (213)

', 4);
INSERT INTO 'dancecrib' VALUES (10396, '2018-01-22 19:45:38.55485+00', '2018-01-23 02:32:30.65888+00', 18227, 1, 202, 'ace', '1--::
  1c+2c S&Rotate (2,1,3)
9--::
  2c+1c DblFig8, 1c cross up to start, finishing facing 1cnrs
17--::
  1c+1cnrs ½ Reel4 in 1 diag, pass Rsh ; 1c+2cnrs ½ Reels4 in 2 diag, pass Rsh
25--::
  Repeat 17-24 to sidelines (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (2706, '2012-01-22 19:29:53.873638+00', '2019-03-20 00:12:51.167269+00', 127, 1, NULL, 'ace', '1–::

  1c+2c S&Link ; 1c+3c S&Link, 1M faces out (2,3,1)

9–::

  1M (1W following) cast up to 1plx (2c+3c down) ; 1c+2c ½RHA | 1c+3c ½LHA and 3c face up (2x,3x,1x)

17–::

  Parallel Rsh Reels3 on sides

25–::

  3c+1c ½LHA | 2c+1c ½RHA, 1M faces out ; 1M (1W following) cast to 3pl (2c+3c up) (to 2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (8689, '2015-03-02 13:27:58.468705+00', '2015-03-02 13:36:06.907883+00', 1791, 1, NULL, 'ace', '*Duples in long set for as many as will.*

1--::

  1c+2c RHA, LHA

9--::

  1c chassee down | and up ; 1c cast off as 2c dance up

17--::

  All cpls Allemande R [RHJ with P Adv{1}&Ret{1} | change places RHJ, W passing under arms (both face down) ; All Allemande L

25--::

  All turn 1st corner RH ; turn P LH 



  *Variant for [9-16]: 1c chassee down ; chassee up and cast off (2c up)*

', 2);
INSERT INTO 'dancecrib' VALUES (12476, '2020-01-05 00:19:24.327062+00', '2020-01-05 00:24:34.131368+00', 14504, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA ; 1c+2c set | 1c turn RH ¾ to 2pl centre, RSh to P facing opposite sides _while{2}_ 2c turn RH ½ (2,*1*,3)

9--::

  Reels3 on sides, 1c RSh to 1cnrs, 1c pass RSh 

17--::

  Corners Pass and Turn to 2pl (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3581, '2012-07-21 11:45:11.495434+00', '2014-04-30 23:23:39.70342+00', 433, 1, NULL, 'ace', '1–::
  1M+2M+2W+3W ½ diag R&L _while_{4}   1W+3M chase cclw ½ round (3x,2x,1x) ; 3M+2M+2W+1W repeat _while_{4}   1M+3W chase clw ½ (1,2,3)
9–::
  1M+2M+2W+3W RHA ; LHA _while_{8}   1W+3M dance once round cclw (1,2,3)
17–::
  1c set | cast off (2c up) ; 1c dance ½ Fig8 up (2,1x,3)
25–::
  1c set | cast off (3c up) ; 1c dance ½ Fig8 up (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (9101, '2016-02-29 01:27:57.302902+00', '2021-05-06 23:30:53.75909+00', 16885, 1, NULL, 'ace', '*On 2nd chord, 2c & 4c cross to opposite sides (1,2x,3,4x)*

1--::

    1c+2c & 3c+4c mirror set and link with 1c and 4c casting ; 1M+4W & 4M+1W in prom hold dance ½ reel3 across (1M+4W Rsh to 2M, 4M+1W Rsh to 3M) (2,4,1x,3x)

9--::

    Repeat from new places to (4x,3,2x,1) ending with 1c & 4c facing out

17--::

    3c & 2c dance path of double figure of 8 in top & bottom halves _while{8_} 4c & 1c dance ½ reel3 on the sides ; 1c & 4c ½ double figure of 8 to (1x,3,2x,4)

25--::

    3c+2c dance LHA ; 1c+3c & 2c+4c turn RH 1½ on the sides to (3,1x,4,2x)', 5);
INSERT INTO 'dancecrib' VALUES (9099, '2016-02-25 01:25:32.287765+00', '2016-02-25 01:29:14.102096+00', 16883, 1, NULL, 'ace', '1--::

  1c set | cross RH ; cast (2c up) | turn RH to face 1cnr

9--::

  1c Set to and turn corners BH (2,1x,3)

17--::

  Reels3{6} on the sides, 1c Lsh to 1cnr, | 1c cross RH (2,1,3)

25--::

  All Circle6 and back (2,1,3)



  

', 3);
INSERT INTO 'dancecrib' VALUES (1734, '2012-01-22 19:28:59.011202+00', '2021-03-01 18:52:13.690348+00', 9113, 1, NULL, 'ace', '1–::

  1c+2c RHA ; set up/down | 1W+2W turn RH ½ _while_{2} 1M+2M turn LH ½ (to 2,1,3,4)

9–::

  Reels4 on sides, Rsh for the W, Lsh for the M

17–::

  1c+3c petronella, overlapping to form line 1W,3W,1M,3M _while_{2} 2c+4c cross RH on the sides | all dancers face up/down toward centre and set ; 1c+3c petronella to opposite side _while_{2} 2c+4c cross LH | all set

25–::

  Repeat

33–::

  1c cross RH, cast off two (3c+4c up) ; 1c 1½ BH turn', 2);
INSERT INTO 'dancecrib' VALUES (10559, '2018-03-29 09:48:59.086234+00', '2020-10-18 10:31:30.286919+00', 17051, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; all turn P BH (2,1x,3)

9--::

  2c+1c La-Chain

17--::

  1c ½ Fig8 round 3c ; dance up between 2c and cast to 2pl (2,1,3)

25--::

  1c+3c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (1869, '2012-01-22 19:29:07.133486+00', '2015-07-01 13:09:11.203748+00', 902, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1c dance down {1} and up {1} | cast off (2c up) ; dance between 3c and cast up to face 1cnrs.

17--::

  1c+1cnrs PdB R {1} into ½Reel4, pass Lsh ; 1c+2cnrs repeat, finish (3x,1x,2x).

25--::

  All PdB R {1} and circle6 L ½ ; All turn P RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (8816, '2015-07-01 12:39:20.098097+00', '2015-07-06 21:51:23.141407+00', 16464, 1, NULL, 'ace', '1--::  1c+2c A&R diagonally ; 1M+2M dance Rsh round P

9--::  1c+2c A&R diagonally ; 1W+2W dance Lsh round P

17--::  All set {1} and ½Circle4 L in skip-change {3} ; set in circle NHJ {1} and ½Circle4 L in skip-change {3} 

25--::  All turn P RH, straight into ; turn opposite LH 1½ to face next couple, M making polite turn L

', 5);
INSERT INTO 'dancecrib' VALUES (10233, '2017-11-08 23:33:47.794161+00', '2018-01-27 02:38:45.906375+00', 18044, 1, NULL, 'ace', '1--::

  1c+2c cross RH | ½ RHA ; 1c+3c LHA and 1c keep LHJ

9--::

  1c turn LH 1¼ to midline ; 2c+1W & 1M+3c RHA to (2,1,3)

17--::

  2c+3c set and cross RH _while{4}_ 1c cross RH and cast R into facing lines across ; 2c+3c set and change places LH _while{4}_ 1c change places LH and cast L to (3x,1,2x)

25--::

  3c+2c set and cross RH _while{4}_ 1c cross LH and cast L into facing lines across ; 3c+2c set and change places LH _while{4}_ 1c change places RH and cast R to (2,1,3)

::

  *After 2nd repeat, 1c dance [1-4] again with 4c to end in 4pl*

', 3);
INSERT INTO 'dancecrib' VALUES (12978, '2020-07-24 07:09:03.449297+00', '2022-12-19 14:34:44.810557+00', 8864, 1, 202, 'ace', '1--::

  1M set advancing, pulling RSh back to face P | 1c set to P ; turn P BH (PdB) to 1pl (1,2,3,4)

9--::

  Circle8 and back, retaining hands (1,2,3,4)

17--::

  All A&R ; 1c (1M followed by 2W, 2M & 3W, 1W followed by 4M, 4W, 3M) dance across the set into facing lines4 up/down

25--::

  All A&R ; All turn opposite person BH ½ into a new square set (3,4,1,2)



*Deviser''s note:  

Repeat three more times with new first couples each time (original second couple, then original third couple, then original fourth couple).*', 2);
INSERT INTO 'dancecrib' VALUES (3292, '2012-01-22 19:30:19.285994+00', '2016-07-15 17:29:13.261046+00', 6188, 1, NULL, 'ace', '{{explanation}}

Cpl face Cpl in circle RR, M on L of P.



1–::

  ½ R&L, beginning with facing person ; join NH with other couple and set to P, turn P BH just over once round into diagonal line with men in middle

9–::

  ½Reel4 ; ½Poussette and meet next couple.', 2);
INSERT INTO 'dancecrib' VALUES (2589, '2012-01-22 19:29:48.847243+00', '2016-11-15 15:40:46.615203+00', 3558, 1, NULL, 'ace', '1–::

  1c+2c ½RHA, turn P RH ½ to own sides ; 2c+1c ½LHA, turn P LH ½ (1,2,3)

9–::

  1c ½Petronella figure (2c up on [9-10]  (2,1x,3)

17–::

  All circle6 and back

25–::

  Reels3{6} on the sides, 1c giving Rsh to their R | 1c cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10702, '2018-04-28 10:05:11.961817+00', '2021-05-07 06:41:45.705347+00', 1770, 2, 10819, 'ace', '1-2:: 1s+2s set advancing to meet.
3-8:: 1s+2s dance three quarters of a “Border” style poussette, (i.e. on bar 8 they make - quarter turn only).
9-16:: 1s+2s dance a reel of four up and down the set.
17-18:: 1s+2s face partner and set.
19-22:: 1s+2s dance a quarter petronella, to turn out to the opposite side and set.
23-24:: 1s+2s cross over giving right hand.
25-32:: 1s+2s dance right hands across in a wheel for four steps and back with the left hand.', 4);
INSERT INTO 'dancecrib' VALUES (1738, '2012-01-22 19:28:59.24421+00', '2016-08-30 23:13:42.799876+00', 442, 1, NULL, 'ace', '1–::

  1W+2W & 1M+2M turn BH | open into circle4 L | 1c+2c turn P BH (on [8] 3c dance in) into

9–::

  1c+2c+3c Promenade, on [15-16] 1c cast off & 2c dance up (2,1,3)

17–::

  1c+3c RHA to sidelines (1W long turn) ; 2c+1c LHA, 1c finish facing down

25–::

  2c+1c+3c Rsh Reels3 on the sides (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10122, '2017-09-15 07:19:47.69178+00', '2017-09-15 07:19:47.69178+00', 6859, 2, NULL, 'ace', '1-8::

  1s 2s & 3s all set, 6H ½ round to L; each side inverts to 3, 2, 1 by leftmost person (1M, 3L) casting 2 places to L followed by rest of line (2 bars), all pass partners RH to own sides

9-16::

  1s turn once RH and cast 1 place (2s step up), all set and cross RH with partners

17-24::

  All set, 6 hands ½ round to L to own sides; then 1s turn once LH to 2nd places facing anticlockwise (1M down, 1L up) WHILE 2s & 3s dance halfway clockwise round set (order now 2x, 1, 3x)

25-32::

  1s dance anticlockwise around set to 2nd places opp. sides WHILE 2s & 3s turn 1½ BH to own sides, 1s set and cross RH

', 3);
INSERT INTO 'dancecrib' VALUES (8882, '2015-08-31 18:59:46.351617+00', '2015-08-31 19:00:54.57488+00', 6644, 1, NULL, 'ace', '1-::  Inveran reels (1c cross down, and cross up on [5]), finish 1c facing 3c NHJ

9-::  1c+3c set | ½ RHA and face up RHJ ; 3c cross up & cast to 3pl while{4} 1c lead up, cross and cast to face 1cnr 

17-::  1c+1cnrs Pass+Turn , pass Rsh ; 1c+2cnrs Pass+Turn, finish for

25-::  Double Triangles (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1845, '2012-01-22 19:29:05.555617+00', '2017-04-21 22:44:39.312626+00', 827, 1, NULL, 'ace', '{{explanation}}

3c+4c change sides to start (1,2,3x,4x)



1–::

  All set | 1c+4c turn RH, lead to the middle crossing to 2plx/3pl, and cast back to own end to face the set down/up NHJ _while_{8} 2c+3c cross RH, cast out to own end, cross to other side and face away from the set, joining NH with 1c/4c in lines across in 1pl/4pl.

9–::

  Set in lines across | end pairs make half turns EH to bring ends of line into the centre ; set in line | turn again to put 1c+4c in the middle

17–::

  1c+4c in promhold Reels3 across with the other C of its line, Rsh to the M

25–::

  1c+4c in promhold pass Lsh dn/up, dance through opposite end, crossing to other side, cast to 3pl/2plx and cross RH (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (9805, '2017-04-23 06:58:19.994684+00', '2017-04-23 06:58:19.994684+00', 17715, 1, NULL, 'ace', '1--::

  1c+2c set | Turn P BH ; Circle4 L

9--::

  Espagnole (2,1)

17--::

  S&Link ; RHA (1,2)

25--::

  Tourbillon (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8687, '2015-02-28 02:12:17.320063+00', '2015-03-11 09:20:32.584468+00', 7053, 1, NULL, 'ace', '1--::

  1c cross down (2c up) and set to 3c ; 1c dance to 3plx as 3c cross up | 2c set to 3c (2,3x,1x)

9--::

  2c cross down as 3c dance up | 2c set to 1c ; 2c dance to 3plx and wait _while{4}_ 1c dance to top and cast off one (3x,1x,2x)

17--::

  3c+1M & 1W+2c RHA ; 1c pass Lsh and cast R round 3cnr _while{2}_ 3c+2c cross RH to own side | In lines across All set 

25--::

  1W+2W+3W & 1M+2M+3M RHA ; 1c pass Lsh and cast R round 4cnr to 2pl _while{2}_ 3c+2c change places RH on the sides | All set (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9949, '2017-06-08 18:35:49.124548+00', '2017-07-06 10:41:04.384732+00', 1148, 1, 202, 'ace', '1--::

 1c cross RH below 2c and cast behind 3c ; dance to top and cast to 2plx (2c up) (2,1x,3)

9--::

 All set | 1c set adv and pivot outwards to face down _while{2}_ 2c & 3c cross RH ; 2W+1W+3W RHA as 2M+1M+3M LHA, 1c ending in centre

17--::

 1c BHJ slip down | slip up to 2plx facing out on [20] ; ½ Reels3, 1c start out and up (3x,1x,2x)

25--::

 All set | all turn P RH ½ to face up NHJ ; 3c followed by 1c & 2c dance to top and cast (2c casting into 1pl) (2,1,3)



*Deviser''s notes: End of 2nd time through, on [29-32]*



- *3c in 1pl cast to 3pl and dance up to 2pl*

- *1c in 2pl dance to top and cast to 3pl*

- *2c in 3pl dance to top and cast into 1pl*', 2);
INSERT INTO 'dancecrib' VALUES (8886, '2015-08-31 22:42:59.463753+00', '2015-08-31 22:42:59.463753+00', 9465, 1, NULL, 'ace', '*Couples with W on the R, face cclw in circle RR*

1--::  All couples, NHJ, dance RR cclw, pivot inwards ; All couples dance clw, finish facing cclw

9--::  All W dance Rsh round M in front of her P and Lsh round P, to places 

17--::  All M dance Lsh round W in front of his P and Rsh round P, to places

25--::  All couples BHJ slip cclw ; slip clw {2} | All retire with clap, and advance to next person to the R

', 3);
INSERT INTO 'dancecrib' VALUES (1739, '2012-01-22 19:28:59.313823+00', '2021-03-06 21:50:45.154401+00', 9022, 1, NULL, 'ace', '1–::

  1c+2c S&Link ; 1c turn BH and open to face up

9–::

  Mirror Reels3 on the sides (1c start up NHJ) (take hands when possible) , 1c finish facing 1cnr

17–::

  1c+1cnr Pass and Turn, 1c pass Rsh ; 1c+2cnr Pass and Turn, 1c finish in 2pl RHJ facing up, 1W on the L

25–::

  1c lead up| cross and cast off ; dance between 3c and cast to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10123, '2017-09-15 07:21:07.693264+00', '2017-09-15 07:21:07.693264+00', 1876, 2, NULL, 'ace', '1-8::

  1s set & cast 1 place (2s step up), set & cast to left to face 1st corners, 1L between 2s & 1M between 3s

9-16::

  ½ RSh reels of 3 across, at end 1s curl to R into 2nd places opp. sides as corners curve in to meet partners NHJ at top & bottom of set; all set facing centre of set, 6H ½ round to L onto sidelines (3x 1 2x)

17-24::

  1s turn BH, cast clockwise round 3rd corner positions to top & bottom of dance,  change places RH up & down to end facing, 1L between 3s at top, 1M between 2s at bottom

25-32::

  All set facing partners, 1s cast to R to 2nd place own sides as corners turn ½ RH to face centre NHJ; 1s cross RH as 2s set to 3s; all 6H ½ round to L to own sides

', 3);
INSERT INTO 'dancecrib' VALUES (10640, '2018-04-17 07:35:27.055964+00', '2018-04-17 07:47:41.78419+00', 5234, 1, 202, 'ace', '1--::

  1c+2c S&Link, finishing 1c(2c) facing up(dn) ; 2c+1c+3c Parallel ½ Reels3 on sidelines, 1c start Rsh to 2c (3,1,2,4)

9--::

  1c+2c S&Link, finishing 1c(2c) facing up(dn) ; 2c+1c+4c Parallel ½ Reels3 on sidelines, 1c start Rsh to 2c (3,4,1,2)

17--::

  All set | 3c+4c & 1c+2c ½ RHA, M(W) facing dn(up) at end (to 4x,3x,2x,1x) ; all chase clw ½ (1,2,3,4)

25--::

  Parallel ½ Reels4 (to 4,3,2,1) ; 4c+3c+2c Parallel ½ Reels3, 3c start Rsh to 4c (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (1737, '2012-01-22 19:28:59.189776+00', '2019-09-01 11:08:42.984735+00', 7349, 1, NULL, 'ace', '1–::

  1c cross RH, cast off (2c up) ; 2c+1c+3c turn P RH (2,1x,3,4,5)

9–::

  2c+1c+3c circle6 & back.

17–::

  1c cross LH | cast off 1 place (3c up) ; 3c+1c+4c turn P LH (2,3,1,4,5)

25–::

  1W+3c & 1M+4c Lsh Reels3{6} across, 1c lead down crossing to between 5c, M facing W, 4c finish in 3pl and 3c in 2pl (both make matching loops)

33–::

  1c+5c Reel4 across, (to 2,3,4,5,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2679, '2012-01-22 19:29:52.788884+00', '2015-09-29 19:58:36.357624+00', 3834, 1, NULL, 'ace', '1–::

  1c+2c circle4 and back

9–::

  1c+2c RHA ; LHA

17–::

  1c lead down the middle and up

25–::

  1c+2c Poussette.', 3);
INSERT INTO 'dancecrib' VALUES (8690, '2015-03-02 16:24:58.294003+00', '2015-03-02 16:24:58.294003+00', 3989, 1, NULL, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 round 2c (2,1,3)

9--::

  1c+1cnrs turn RH into facing lines across | 1c set to P ; 1c+2cnrs turn LH into facing lines across | 1c set to P 

17--::

  All dance BtoB with opposite ; All turn P RH to (2,1,3)

25--::

  Circle6 and back

', 3);
INSERT INTO 'dancecrib' VALUES (11236, '2018-10-01 23:52:24.46654+00', '2018-10-01 23:58:19.431937+00', 16293, 1, 202, 'ace', '1--::

  1c+5c LSh Fig8 on own side, 1W+5M face out

9--::

  1W & 5M (P following) cast R and cross to 2plx/4plx (2c & 4c step out) ; 2c+1c & 5c+4c  LHA (2,1x,3,5x,4)

17--::

  1c+3c+5c Diagonal R&L (2,5,3,1,4)

25--::

  3c turn RH, lead down between 4c (1c up on [29-30], cast up to 4pl (2,5,1,3,4)', 2);
INSERT INTO 'dancecrib' VALUES (2361, '2012-01-22 19:29:33.395387+00', '2015-03-02 23:48:13.514979+00', 2602, 1, NULL, 'ace', '{{explanation}}

2c and 4c cross on 2nd chord (1,2x,3,4x)



1–::

  1W+4W cast off behind own line to the other end and cross, _while{4}_ the others set once and change places diagonally RH ; 2M+3M repeat (3,4x,1,2x)

9–::

  All circle8 and back

17–::

  3W & 2W, each followed by the others in their line, cast to the other end of the set ; 2c+1c & 3c+4c circle4 L (2x,1,4x,3)

25–::

  2c+1c & 3c+4c RHA {3}, LHA {3} | 2c & 3c cast to middle _while{8}_ 1c & 4c lead out and cross to end places, facing out (1x,2x,3,4)

33–::

  Centres turn ends once EH ; 1c+2c & 3c+4c half DblFig8 across to finish, 1c+2c facing up, 3c+4c facing down (1,2,3x,4x) for

41–::

  Interlocking Allemandes, finish (2,4x,1,3x)', 2);
INSERT INTO 'dancecrib' VALUES (8893, '2015-09-06 12:43:10.666367+00', '2019-01-05 22:49:58.773061+00', 16466, 1, NULL, 'ace', '1--::  1c cross down (2c up) | 1c cast cclw (M up, W down) round 2c+3c to face 1cnr with LHJ

9--::  1c+1cnrs set, 1c also turning LH ¼ | 1c turn 1cnrs RH ½ ; ½ diag. Reel4, the cnrs passing Lsh to start, 1c finish in 3cnr positions and 1cnr(persons) finish LHJ facing 2cnr positions on opposite side 

17--::  All cnr persons repeat [9-16] on 2diag., 2cnr(persons) finish LHJ facing 1cnr positions on own side

25--::  2cnr(persons)+1c repeat [9-16], 1c finish in the middle

33--::  1c turn LH ¾ to 2pl _while{2}_ all cnr persons chase clw one place (2,1,3) | All set : 1c dance up and cast off to (2,1,3)



', 5);
INSERT INTO 'dancecrib' VALUES (9681, '2017-03-27 11:51:52.050722+00', '2021-05-07 19:27:36.272372+00', 4597, 2, 3069, 'ace', '1-4:: 1st, 2nd, 3rd C dance half mirror reels of 3

5-8:: 1st C dance half Figure 8 round 2nd C

9-12:: 1st, 2nd, 3rd C dance half reel of 3

13-16:: 1,2,3 C back to back

17-20:: 1st C dance down between & face 3rd C, 1 & 3 Set

21-24:: 1st C dance up between & face 2nd C, 1 & 2 Set

25-32:: 1st, 2nd, 3rd C dance mirror reels of 3, 1st cross to begin.', 0);
INSERT INTO 'dancecrib' VALUES (7981, '2013-08-21 08:31:52.315358+00', '2023-02-04 01:23:14.836071+00', 11772, 3, NULL, 'ace', '1-4::
    1L+2M 3/4 turn RH, turn partners LH once round, pull back LSh to
    face clockwise, join RH & nearer hand to partner - all in diagonal
    line
5-8::
    Line rotates clockwise 1 place, 1M+2L dance on 1 more place _while_
    1L+2M continue turn to place opposite partner in order (2) (1)
9-16::
    2s+1s 1/2 turn partners RH, pull back RSh & all dance out  to own
    sides. 2s+1s circle 4H round to left
17-24::
    1s set, turn 2H opening out to face up, dance up & cast to 2nd place
25-32::
    2s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (8883, '2015-08-31 19:29:19.49974+00', '2015-08-31 19:29:19.49974+00', 8079, 1, NULL, 'ace', '1--::  1c+2c+3c A&R ; All Turn P RH

9--::  1c+2c+3c A&R ; All Turn P LH

17--::  1c lead down and up to 2pl (2c up on [19-20])

25--::  Circle6 and back

', 3);
INSERT INTO 'dancecrib' VALUES (3613, '2012-07-21 11:45:49.709711+00', '2019-02-06 00:51:30.592746+00', 14420, 1, NULL, 'ace', '1–::

  Mirror Reels3{6} on the sides, 1c start in and down | 1c+2c continue to change places (2,1,3)

9-20::

  3-couple R&L

21-24::

  All turn BH

25–::

  All set and cross RH ; All set | 2c cross RH  _while_{2}   1c+3c ½ RHA (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (8884, '2015-08-31 19:51:06.752265+00', '2015-08-31 19:51:06.752265+00', 6449, 1, NULL, 'ace', '1--::  1c+2c Circle4 and back

9--::  All turn P BH (skip-change) ; All dance BtoB

17--::  RHA ; LHA

25--::  1c facing 2c clap {4}(clap, clap, clap-clap-clap | clap, clap, clap-clap-clap) ; pass opposite RSh to meet new couple

', 3);
INSERT INTO 'dancecrib' VALUES (8733, '2015-03-19 08:21:32.777751+00', '2015-03-19 08:21:32.777751+00', 3665, 1, NULL, 'ace', '1--::

  All set | cross RH ; 1c+3c Petronella to midline and set

9--::

  1c+3c ½ Reel4 on midline, at end 1W+3M pass Lsh to face opposite side ; 1W+2c+3M ½ Reel4 across, at end 1W+3M pass Lsh to face P on midline

17--::

  3c+1c ½ Reel4 on midline ; 1c+3c dance round P Rsh to original places | All set (1,2,3)

25--::

  1c+2c “The Bourrel”: 1W+2M cross and cast cclw to midline _while{4}_ 1M+2W set advancing, turn BH ½ and twirl to face P ; set to P | turn BH to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8885, '2015-08-31 20:27:15.647469+00', '2015-08-31 20:29:26.858678+00', 11709, 1, NULL, 'ace', '1--::  1M dances across, behind 1W, in front of 2W, behind 3W, cross and dance up behind M side to (1,2,3,4) 

9--::  1c slip down and up 

17--::  2c+3c+4c Circle6 and back

25--::  All chase round cclw (1,2,3,4)

33--::  1c dance under 2c+3c+4c making arches (step up) ; 2c turn RH (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9804, '2017-04-18 06:33:49.707149+00', '2021-04-10 11:11:36.692286+00', 6522, 1, 202, 'ace', '1--::

 1c dance down between 2c | cast to 1pl ; 1c&2c turn RH to finish in promhold facing up

9--::

 1c+2c Promenade

17--::

 1c dance down | cast up round 3c to 2pl ; 1c dance up and cast round 2c (2c up) to 2pl (2,1,3)

25--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (14243, '2021-08-15 23:30:30.620557+00', '2021-08-16 14:00:23.980373+00', 12140, 1, 202, 'ace', '1--::

  1c cast off (2c up) | cross RH ; cast up to top | dance down to 2pl centre (2,1x,3)

9--::

  1M+2W+3W LHA _while_ 1W+2M+3H RHA ; 1c dance down | cast up round 3c to 2plx (2,1x,3)

17--::

  2c+1M & 1W+3c RHA, pass P RSh ; 2c+1W & 1M+3c LHA (2,1x,3)

25--::

  1c ½ Fig8 R round 3cnrs ; all turn P RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14246, '2021-08-16 22:38:04.4063+00', '2021-08-16 22:42:17.063751+00', 20429, 1, 1645, 'ace', '1-::

  All dance BtoB ; all turn RH & face clw

9-::

  All chase round clw

17-::

  1c lead down & up

25-::

  1c cast off to 4pl (2c+3c+4c up on [3-4]) ; 1c turn RH (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (3772, '2013-07-13 15:55:58.22111+00', '2015-09-02 15:13:01.032423+00', 454, 1, NULL, 'ace', '1–::

  1c turn RH ½ and twirl to exchanged places ; 2c repeat (1x,2x,3)

9–::

  3c repeat ; All repeat (1,2,3)

17-::

  1c slip down the middle ; and up (1,2,3)  

25-::

  1c set and cast off (2c up) ; 1c starting inwards turn 3c EH 1½ (2,3,1)  



*(Note: A variant for [25-32] is now named Wes Clindinning''s Hornpipe)*', 3);
INSERT INTO 'dancecrib' VALUES (9950, '2017-06-08 19:59:04.350753+00', '2019-02-12 23:37:16.145925+00', 14725, 1, 202, 'ace', '1--::

 1c dance down | set to P ; dance up to 1pl | All turn BH ready for

9--::

 3C Promenade (1,2,3)

17--::

 1M+2M make arch and dance to W side as 1W+2W NHJ dance under arch to M side | 1M+2M changes pl LH as 1W+2W change pl RH ; 2c & 1c cross RH | 1c cast to 3pl (3c up) (2,3,1)

25--::

 3c+1c Poussette (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3582, '2012-07-21 11:45:12.4852+00', '2015-02-26 14:44:45.362963+00', 13593, 1, NULL, 'ace', '1–::

  1c cross RH | cast off 2 (2c+3c up) ; ½ mirror Reels3 on opposite side, 1c start inwards (1x,3,2)

9–::

  1c cross down into Mirror Reels3 on own side (1,3,2)

17–::

  3c+2c Set&Rotate (1,2,3)

25–::

  1c+2c ½ R&L ; 1c+2c Turn RH 1½ (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13933, '2021-04-05 10:53:12.667112+00', '2021-04-05 10:56:51.066996+00', 20300, 1, 202, 'ace', '1--::

  1c+2c The Espagole. 1c face out (2,1,3)

9--::

  1c dance LSh round 2cnrs | cross LH on midline ; dance LSh round 3cnrs to 2pl | all set (2,1,3)

17--::

  Reels3 on sides, 1c RSh to 4cnrs. 2c & 3c loop to places (2,1,3)

25--::

  2c+1W & 1M+3c RHA ; LHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1748, '2012-01-22 19:29:00.251721+00', '2014-07-25 22:39:39.423007+00', 488, 1, NULL, 'ace', '1–::

  1c Turn RH, finish side by side facing up ; 1c cast off one (2c up), 2c+1c+3c set

9–::

  All A&R ; all turn P LH to finish for

17–::

  2c+1c+3c Promenade

25–::

  1c dance between 3c, cast up ; dance between 2c and cast to (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (1747, '2012-01-22 19:29:00.208062+00', '2014-04-30 23:23:39.985185+00', 480, 1, NULL, 'ace', '1–::
  1c+2c set | ½ RHA ; set | ½ LHA
9–::
  1c down the middle and up, into
17–::
  1c+2c Allemande, 1c finishing facing 1cnr
25–::
  Turn CPCP', 3);
INSERT INTO 'dancecrib' VALUES (1750, '2012-01-22 19:29:00.455069+00', '2014-11-05 16:19:34.501433+00', 9289, 1, NULL, 'ace', '1–::

  1c slip down ; and up, staying in the middle

9–::

  1c long cast to face 1cnr (2c up on 9-10) ; set to 1cnr, set to 2cnr, swiveling R at end to face P up/down on the centre line

17–::

  1c turn 1¼ RH to 2plx ; ½Reels3 on the sideline, Rsh to 1cnr

25–::

  1c chase cclw round end couples (1M up, 1W down) to 2pl _while_{4} 2c+3c turn RH ; 3c+1c+2c ½ Rsh Reels3 on the sideline (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15172, '2022-10-16 21:34:03.550757+00', '2022-11-03 12:57:03.128744+00', 21151, 1, 1645, 'ace', '1--::

  1c cast off (2c up) | turn RH to centre line facing own side ; &frac12; fig8 LSh round 4cnr to face 1cnr on diagonal

9--::

  All dance RSh diagonal Weasel reel: &frac12; reel4 on diagonal & chase &frac12; way clw via 2cnr pos to re-enter reel, corners end in same places, 1M ends below 1W on centre line

17--::

  2c+1W & 1M+3c RHA, 1c pass RSh ; 2c+1M & 1W+3c LHA, 1c end facing 2cnrs

25--::

  All dance LSh diagonal Weasel reel with &frac12; cclw chase. 1c do not pass RSh on [32] but curve L to face out in 2pl (2,1,3)  

  *After their 2nd turn 1c cast off as 4c step up on [1-2] of next repeat*

', 5);
INSERT INTO 'dancecrib' VALUES (1754, '2012-01-22 19:29:00.687984+00', '2016-06-03 13:36:29.464554+00', 8722, 1, NULL, 'ace', '1–::

  1c set adv. | Turn BH to face down ; lead down, cross below 3c | cast up (2c up) (2,1x,3)

9–::

  All A&R ; All Turn P BH

17–::

  2c+1c Circle4 L, to sidelines ; 2c cast off as 1c cross up (no hands) | 1c cast off, 2c lead up and 3c dance in for

25–::

  2c+1c+3c Promenade', 3);
INSERT INTO 'dancecrib' VALUES (1755, '2012-01-22 19:29:00.74244+00', '2014-04-30 23:23:40.129554+00', 518, 1, NULL, 'ace', '1–::
  1c+2c Circle4 and back
9–::
  1W+2W cross between P and cast back ; 1M+2M repeat
17–::
  1c Fig8 round 2c
25–::
  The Knot (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (8887, '2015-09-01 21:36:37.432835+00', '2015-09-01 21:43:05.119348+00', 1038, 1, NULL, 'ace', '1--::  1M, 2M+3M following, dance across the top and down W side _while{4}_ all W set and cross ; repeat, the W crossing at the top as the M set and cross (3,2,1)

9--::  1c turn RH 1½ ; 1c cast up (2c down) and turn LH ¾ 

17--::  3c+1W & 1M+2c RHA, 1c pass Rsh ; 3c+1M & 1W+2c LHA, unwinding into 

25--::  Snake pass: 1M (leading) +3M+3L & 1W (leading) +2W+2M, all passing the others Rsh, finishing (2,1.3) ; All turn P RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8216, '2014-03-21 00:50:04.717131+00', '2015-03-11 11:48:06.079826+00', 14964, 1, NULL, 'ace', '1–::

  1c+2c Espagnole (2,1,3)

9–::

  2c+1W & 1M+3C RHA, 1c pass Rsh ; 2c+1M & 1W+3C LHA (2,1,3)

17–::

  1c+3c »The Rosette«: 1+3c set to P | turn P RH ½ and cast away to opp. side | chase clw ½ (2,3,1)

25–::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (1751, '2012-01-22 19:29:00.502261+00', '2016-09-10 22:18:49.167135+00', 497, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  1c turn RH 1½ and cast off ; ½Fig8 up (2c up on [7-8] and face 1cnr

9–::

  Reel4 with 1cnrs, at end pass Lsh into



{{title}}

Reel



17–::

  Reel4 with 2cnrs to (2,1,3)

25–::

  2c+1c+3c circle6 and back (2,1,3)







', 3);
INSERT INTO 'dancecrib' VALUES (1753, '2012-01-22 19:29:00.606581+00', '2019-03-08 18:04:01.291888+00', 7351, 1, NULL, 'ace', '1–::

  1c+3c dance down the middle | Turn BH ; dance up & cast off (2c+4c up)

9–::

  2c+1c & 4c+3c Poussette

17–::

  1c+3c set | turn RH ½ 1M&3W finish facing out ; 1M & 3W, P following, cast R to finish (2,3,4,1)

25–::

  All Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (9806, '2017-04-24 05:47:20.316037+00', '2017-04-25 11:31:02.467649+00', 17704, 1, NULL, 'ace', '1--::

  1c dance down (2c up) | turn BH and stay in middle ; cast R to own side and Rsh round 3cnr into lines across 

9--::

  2c+1M & 1W+3c half Reels3 across, 1c Lsh to 2cnr (with final loops) ; set in lines across | 1c turn LH to face 1cnr (pos)

17--::

  1c+1cnrs pass, cnrs turn BH ½, and cast away as 1c meet and pass Rsh ; repeat with 2cnrs, and 1c face out (3,1,2)

25--::

  Chaperoned Chain Progression (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9807, '2017-04-24 14:10:19.927925+00', '2017-04-25 08:22:52.31324+00', 16086, 2, 1824, 'ace', '1-8:: 1s set & cast off one place (2s step up), dance half Figs of 8 round 2s

9-16:: 2s & 1s dance ladies chain

17-24:: 1s dance half Figs of 8 round 3s, 2s+1s+3s turn partners RH finish in promenade hold facing up

25-32:: 2s+1s+3s dance promenade

', 2);
INSERT INTO 'dancecrib' VALUES (10641, '2018-04-17 08:27:37.114099+00', '2018-04-17 08:35:06.284019+00', 15683, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; 2c+1c+3c set | turn P RH ½ into Allemande hold facing down

9--::

  Inverted 3C Allemande (face down to start) (3x,1x,2x)

17--::

  All cross RH | chase clw ¼ into facing lines of 3 across ; repeat [17-20] (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2799, '2012-01-22 19:29:57.882494+00', '2017-07-07 14:15:39.340376+00', 4440, 1, NULL, 'ace', '1–::

  1c turn RH 1½ ; 1M+2W & 1W+2M turn LH  (1x,2)

9–::

  1M+2W & 1W+2M turn RH ; 1c turn LH 1½  (1,2)

17–::

  1c lead down the middle and up

25–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (1756, '2012-01-22 19:29:00.791978+00', '2018-08-06 16:18:00.735642+00', 521, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; 1c set | cast off (3c up)

9–::

  1c set | dance up to 1pl (2c+3c down) ; 1c cross RH | cast (2c up) (to 2,1x,3)

17–::

  2c+1c R&L, 1c finish facing 1cnrs

25–::

  1c set to and turn corners

33–::

  1c dance down between 3c, divide and cast up one ; turn BH to face up in the middle, opposite side

41–::

  1c dance up between 2c, divide and cast off one ; 1½ BH turn to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8825, '2015-07-31 01:40:55.488655+00', '2015-07-31 01:40:55.488655+00', 16521, 2, NULL, 'ace', '1-8::

  1C2C set, RH Across x1, 1C cast 1pl. as 2C dance up the center & face out.

9-16::

  Mirror Reel3 on own sides - 1C in & down to begin - 1C pass Lsh to face 1crnrs.

17-24::

  Half Reel4 w/1crnr. -1C pass by Rsh ; Half Reel4 w/2crnrs - 1C end 2pl. (3x 1x 2x)

25-28:: 

  All set, turn RH half round & face up in the center.

29-32::

  3C, followed by 1C 2C, cast to bottom to invert the set. (2 1 3)', 2);
INSERT INTO 'dancecrib' VALUES (13289, '2020-10-21 03:46:15.434618+00', '2020-10-22 20:22:30.239957+00', 5391, 2, 35787, 'ace', '1- 8::

  W1 followed by M1 cast into fig-8; she goes home; M1 ends in 2nd pl (M2 up on 7&8)

9-16::

  1s+2s RHA, LHA

17-24::

  1s+2s poussette with other M/W

25-32::

  Repeat 1-8, with M1 leading W2', 0);
INSERT INTO 'dancecrib' VALUES (1668, '2012-01-22 19:28:53.995446+00', '2020-05-15 11:45:44.465282+00', 183, 1, NULL, 'ace', '1–::

  1c cross RH, cast off (2c up), ½ Fig8 up (2,1,3,4)

9–::

  1W Reel3 across with 2c (Lsh to 2M) _while{8}_ 1M ½ Lsh Reel3 with 3c then ½Reel3 with 4c (Rsh to 4M)

17–::

  1c+3c LHA ; 1W+2c & 1M+4c RHA

25–::

  1c pass Lsh into ½Reel4 across with 3c (3c to 2pl), at end 1c turn RH to 3plx RHJ _while{2}_   4c set advancing to join in | 1c+4c ½RHA (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (3583, '2012-07-21 11:45:12.702606+00', '2015-02-28 21:29:26.197249+00', 8294, 1, NULL, 'ace', '1–::

  1c cross down and cast off (2c+3c up) to (2,3,1x) ; 2c repeat (3,1x,2x)

9–::

  3c repeat (1x,2x,3x) ; All turn P 1½  to (1,2,3) [no handing indicated]

17–::

  Circle 6 and back

25–::

  All set | dance BtoB | 1c cast off (2c up) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1760, '2012-01-22 19:29:00.973685+00', '2014-05-30 14:45:35.858005+00', 535, 1, NULL, 'ace', '1–::

  1c & 3c ½ RH turn moving down 1 place (2c & 4c up) and set ; cross LH and cast left 1 place to face 1cnr (1M & 3W passing Lsh between 4c)

9–::

  1W+2c & 1M+4c+3W Rsh & 3M+5c Rsh Reels3/4/3 across (1M+3W finish Rsh), at end 1c+3c join RH to 1cnr and LH to P

17–::

  BiL | ½ turn 1cnr RH ; BiL | ½ turn 1cnr RH and face 2cnr

25–::

  ''2cnrs pass & turn'' (pass 2cnr no hands, corners Turn RH, pass back) ; 1c & 3c 1½ RH turn to own side and cast off 1 place (4c+5c up) (2,4,1,5,3)



{{explanation}}

Can also be danced as a 3C or 7C or .. dance, always reels of 3 at both ends, reels of 4 in the middle', 2);
INSERT INTO 'dancecrib' VALUES (2835, '2012-01-22 19:29:59.376336+00', '2021-05-07 19:34:19.505298+00', 4595, 1, NULL, 'ace', '1–::

  1c+2c set | cross RH ; repeat

9–::

  1c+2c RHA ; LHA

17–::

  1c lead down the middle (2c up) and up to face 1cnrs

25–::

  Turn CPCP', 3);
INSERT INTO 'dancecrib' VALUES (8818, '2015-07-15 22:29:57.708789+00', '2015-07-15 22:29:57.708789+00', 14793, 1, NULL, 'ace', '1--::  1c set | cast off (2c up) ; 1c cross RH and cast off (3cup) (2,3,1x,4)

9--::  3c+1c La-Ch, finish middle couples facing ends (2,3,1x,4)

17--::  Parallel Rsh Reels4 on the sides

25--::  1c turn 4c RH 1½ on the sides ; 1c set to P | cross RH (2,3,4,1)

33--::  Circle8 and back

', 3);
INSERT INTO 'dancecrib' VALUES (8817, '2015-07-15 03:54:44.842775+00', '2015-07-15 04:13:42.994723+00', 14797, 1, NULL, 'ace', '1--::  All Circle6 and back

9--::  Middles Petronella to make facing lines across | all set ; middles repeat (trio faces trio) | All set

17--::  Outsides RHA ; and chase around middles half way round 

25--::  Each trio 1/2 Reel 3, middle giving Rsh to dancer on his R ; All turn person opposite RH to face the same way as originally, and meet next trio', 3);
INSERT INTO 'dancecrib' VALUES (1762, '2012-01-22 19:29:01.074052+00', '2014-05-05 14:59:42.466227+00', 542, 1, NULL, 'ace', '1–::

  1c+2c advance {2}, give RH to P and W dance R about under his arm, and back to places as M retire (= Allemande right) ; RHA

9–::

  1c+2c Allemande left ; LHA

17–::

  1M followed by 1W cast | cross up between 2c ; cast off round 2W, cross to own side (2c up) (2,1)

25–::

  2c+1c R&L.', 3);
INSERT INTO 'dancecrib' VALUES (1579, '2012-09-01 19:40:32.166258+00', '2017-11-11 13:04:41.525802+00', 13578, 2, 1, 'ace', ' 1-8::

   Mirror reels3 on sides, 1C starting in and down

 9-16::

   1C dance down the middle and up, fin facing out

17-20::

   1M+2M turn 1½ LH _while_ 1W+2W turn 1½ R

21-24::

   2C+1C+3C adv&ret

25-32::

   2C+1C+3C circle6 and back

', 2);
INSERT INTO 'dancecrib' VALUES (15161, '2022-10-07 07:00:44.264184+00', '2022-10-09 10:10:57.565581+00', 21137, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; ½ Fig8 R round 3cnrs, pass P LSh and face 1cnrs
9--::
  SetH&G. 1c face 3cnrs
17--::
  Reel4 on 1diag. 1c pass P RSh to face 2cnrs
25--::
  *Corners Pass and Turn Reel* : 1c+2cnrs Corners Pass and Turn. 1c pass P LSh and face 4cnrs ; repeat [25-28] with 4cnrs (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (3612, '2012-07-21 11:45:49.118852+00', '2016-07-15 22:45:43.831109+00', 13726, 1, NULL, 'ace', '{{explanation}}

C face C round the room, M has P on the R.



1–::

  with dancer opposite Allemande R [advance {2} & take RH, W dance R about under the arms to place as M retires] ; 1c+2c RHA

9–::

  M-Chain

17–::

  M set to opposite (W only curtsey) | M set to other M ; M set to P (who curtsey) | M set turning R about to face P

25–::

  W dance G-Chain {2 steps/hand} weaving between the M (start RH to W opposite), join with the waiting M', 3);
INSERT INTO 'dancecrib' VALUES (8734, '2015-03-19 12:48:48.436665+00', '2015-03-19 13:18:23.32219+00', 12767, 1, 106, 'ace', '1--::

  All cross RH | chase clw ½ | cross RH (3x,2x,1x)

9--::

  1c set | cast up (2c down) ; lead up, cross and cast off (3x,1,2x)

17--::

  3c+1W & 1M+2c RHA ; 3x+1M & 1W+2c LHA (3x,1,2x)

25--::

 Diagonal R&L (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11718, '2019-03-20 16:37:11.065136+00', '2019-03-20 16:46:25.813065+00', 19244, 2, NULL, 'ace', '1-8::

   1W cast three places and dance back to place facing out while 1M dances down the middle and casts up around 4M to place.  

9-12::

   1s+2s RHA, 

13-16::

   1s + 2s & 3s + 4s RH Turn on side lines.   

17-24 ::

    Reel of four on the side lines.  

25-28 ::

    1W cast three places and dances into 4M place, 1M follows   

29-32 ::  

   1s RH Turn  

', 0);
INSERT INTO 'dancecrib' VALUES (9883, '2017-05-26 22:02:06.709731+00', '2017-08-26 09:53:55.080845+00', 15970, 1, 202, 'ace', '1--::

 Reel4 (1W & 2W pass Lsh as 1M & 2M dance slightly to the R to face W)

9--::

 Set to opp person | turn opp person RH ; set to P | turn P RH

17--::

 RHA ; LHA

25--::

 Rondel', 2);
INSERT INTO 'dancecrib' VALUES (1743, '2012-01-22 19:28:59.498938+00', '2016-02-08 15:19:45.351782+00', 462, 1, NULL, 'ace', '1–::

  1M cross, cast off round 2W to finish in the middle facing up _while{4}_ 1W crosses between 2M and 3M, casts up to the middle facing down _while{4}_ 3c do the same round 4c (2c & 4c step up ½ place) ; 1c+2c & 3c+4c RHA

9–::

  1c+3c Reel4 in the centre of the dance

17–::

  1c+3c turn ¾ RH to finish facing up NHJ _while{2}_ 2c & 4c dance up ½ place on the sides and in to face down NHJ. All set ; 2c+1c & 4c+3c circle4 L (to sidelines 2,1x,4,3x)

25–::

  1c/3c lead up & cross between 2c/4c and cast off one ; 1c+3c turn BH, opening to face down | 1c dance to 4pl _while{2}_ 3c cast up to 2pl. (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (1758, '2012-01-22 19:29:00.890463+00', '2016-05-13 13:56:01.580707+00', 523, 1, NULL, 'ace', '1–::

  1c cross down RH into mirror Reels3 on opp. side (hands when possible), finish in DTr position 1c facing opp. side

9–::

  »Rotation DTr«: Set as in DTr | In each »triangle« Petronella 1 place cclw ; Set as in DTr | Centres switch sides as in DTr _while_{2} cnrs petronella 1 pl cclw round the square (3M faces W side, 2W faces M side)

17–::

  Repeat [9-14], bringing 1c to centre facing opp side | All cnrs set _while_{2} 1c switch places and pivot R to finish in promhold facing down (2x,1,3x)

25–::

  1c in promhold+3c ½ Rsh Reel3 across ; 1c+2c ½ Reel3 across, Lsh to 2cnr pos, 1c finish facing down RHJ for second turn (2,1,3)



{{explanation}}

After second turn, 1c finishes in 4pl', 3);
INSERT INTO 'dancecrib' VALUES (1761, '2012-01-22 19:29:01.026454+00', '2017-07-07 12:59:38.059943+00', 541, 1, NULL, 'ace', '1–::

  1c turn RH ; LH

9–::

  1M leads 1W to just below 3W, he brings back 3W

17–::

  1M+3W & 1W+3M turn RH ; LH

25–::

  1M leads 3W back to place {3}, leads back his P | 1c cast to 2pl (2c up).', 3);
INSERT INTO 'dancecrib' VALUES (10356, '2017-12-26 13:57:47.925595+00', '2017-12-26 14:05:52.151265+00', 14894, 1, 202, 'ace', '1--::

  1c set | 1W followed by 1M casts round 3W, 1W dances up round 3M and 1M dances up the middle, to 2plx (2c up on [5-6]) (2,1x,3)

9--::

  Parallel Reels3, 1c Lsh to 2c to start, finish 2M & 1M facing out

17--::

  La-Chain, finish 1c facing 1cnrs

25--::

  SetH&G (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1764, '2012-01-22 19:29:01.161984+00', '2014-10-26 23:48:44.922486+00', 8328, 1, NULL, 'ace', '1–::

  1c set | turn RH ; cast off (2c up) | turn LH ¾ to face 3cnr

9–::

  Opposing Reels3 across, Lsh to 3cnr, at end 1c turn LH to face 1cnr

17–::

  Opposing Reels3 across, Lsh to 1cnr, at end 1c pass Rsh to face 1cnr

25–::

  Set »H&G with turns«: 1c set to 1cnr, finish facing P across | turn P RH ¾ to face 2cnr ; set to 2cnr, finish facing P up/dn | turn P RH to (2,1,3),', 3);
INSERT INTO 'dancecrib' VALUES (2834, '2012-01-22 19:29:59.337025+00', '2018-02-13 18:04:43.475186+00', 4585, 1, NULL, 'ace', '1–::

  1c+2c advance diagonally & touch hands, retire ; RHA

9–::

  Repeat Left

17–::

  1c+2c DblFig8 (1c cast)

25–::

  1c cast off (2c up) | turn R ; lead up | cast to 2pl', 2);
INSERT INTO 'dancecrib' VALUES (10535, '2018-03-20 18:34:42.108926+00', '2018-03-20 18:52:43.578997+00', 7828, 1, 202, 'ace', '1--::

  1c & 3c cross RH | cast (2c & 4c up) ; ½ Fig8 up round 2c/4c (2,1,4,3,5)

9--::

  1W+2c & 1M+4c+3W & 3M+5c RHA ; 1c & 3c turn LH and cast off (4c & 5c up). (to 2,4,1,5,3)

17--::

  All dance BtoB ; set | cross RH (2x,4x,1x,5x,3x)

25--::

  All set | 2M & 1M cast off 2 places _while{2}_ 1W & 3W cast up 2 places _while{2}_ 2W & 3M cross to P places _while{2}_ 4c & 5 c set (to 1W,4W,3W,5W,3M on M side, 2W,4M,2M,5M,1M on W side) ; 4c & 5c ½ Reels4 in 1diag (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (9952, '2017-06-10 21:58:33.262396+00', '2017-06-13 14:18:49.794068+00', 17787, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 through 3c (2,1,3)

9--::

  All pass P Rsh and chase ¼ clw into lines across ; All A&R up/down

17--::

  All pass P Rsh and chase ¼ clw to sidelines ; All A&R (3x,1x,2x)

25--::

  1c+1cnrs ½ diag. Reel4, 1c pass P Rsh ; repeat with 2cnrs (to 2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (13544, '2021-01-09 23:13:51.145417+00', '2021-01-09 23:14:10.818587+00', 4320, 1, 1645, 'ace', '1--::

  1c+2c & 3c+4c &frac12; RHA | 1c+4c change pl LH on sides ; 2c+4c & 1c+3c &frac12; RHA | 1c+4c cross LH (4x,2,3,1x)

9--::

  4c+2c & 3c+1c &frac12; LHA | 4c+1c change pl RH on sides ; 2c+1c & 4c+3c &frac12; LHA | 1c+4c cross RH (1,2,3,4)

17--::

  1c+2c &frac12; R&L (2x,1x,3,4) ; 1c+3c+4c &frac12; Reel3 on sides, 3c start out (2x,4,3,1x)

25--::

  3c+1c circle4 to L ; 2c & 1c set | cross RH _while{4}_ 4c set to 3c | change pl RH on sides (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (13547, '2021-01-10 09:11:32.866393+00', '2021-01-10 09:23:04.880957+00', 1155, 1, 202, 'ace', '1--::

  1c+2c set | 6 bars of R&L. 1c face out (2,1,3)

9--::

  1c dance RSh round 3cnrs into Fig8 across to 2plx facing 1cnrs (2,1x,3)

17--::

  Reels3 on sides, 1c RSh to 1cnrs into 2diag, LSh to 2cnrs

25--::

  1c turn 2cnrs LH | turn 3cnrs RH into lines3 across ; 1c turn P RH ¾ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12758, '2020-04-12 21:27:31.718688+00', '2020-04-12 21:27:44.176582+00', 19953, 1, 1645, 'ace', '1-::

  1W+3M &frac12; turn RH & cast away ; chase clw to place as 2c & 4c advance & retire

9-::

  1c & 3c change places, 1c  between 3c ; repeat to place, 3c between 1c

17-::

  1c+3c RHA ; LHA

25-::

  All circle8 to L, pivot ; chase back cclw to original places

::

  *Repeat starting with 2W+4M, then 3W+1M and finally 4W+2M*

', 0);
INSERT INTO 'dancecrib' VALUES (1766, '2012-01-22 19:29:01.247106+00', '2016-06-05 13:40:26.420903+00', 547, 1, NULL, 'ace', '{{explanation}}

All Cs start on opposite side (1x,2x,3x,4x)



1–::

  4c up the middle and down, 3c step in for

9–::

  3c+4c Allemande (down and left) (1x,2x,4x,3x)

17–::

  2c+4c+3c Rsh Reels3 across (4W up, 4M down)

25–::

  2c+4c+3c Circle 6 R ; and back



{{explanation}}

4c repeat from 3plx, and step up to 1plx when next couple starts', 2);
INSERT INTO 'dancecrib' VALUES (8104, '2013-11-08 17:14:20.759453+00', '2014-04-30 23:23:37.192596+00', 41, 1, NULL, 'ace', '1–::
  All set | cross RH ; set | cross LH (1,2,3)
9–::
  1c lead down the middle and up
17–::
  Circle6 and back
25–::
  1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9809, '2017-04-24 15:07:49.042103+00', '2017-05-10 11:03:11.817481+00', 16499, 1, NULL, 'ace', '1--::

  1c set | cross RH ; cast off 2 places (2c up) | cross up between 3c and face out (2,1,3)

9--::

  1c turn 3c EH ¾ | 1c dance to top ; 1c turn 2c EH ¾ | 1c set adv. to 1cnr 

17--::

  1c+1cnrs Pass, Turn BH ½ and cast away, 1c pass P Lsh ; 1c+2cnrs repeat, 1c meet P

25--::

  1c turn P LH  1½ _while{4}_ cnrs chase ½ clw ; 2c+1W & 1M+3C RHA (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10125, '2017-09-15 07:30:52.568667+00', '2017-09-15 07:30:52.568667+00', 6947, 2, NULL, 'ace', '*Note: most of this dance is a fugue. The "first subject" (Bars 1-32) comprises a clockwise chase to 2nd place below, a RH turn moving down another place, and an anticlockwise chase to the bottom. A "second subject" (Bars 33-56) involves a long clockwise chase into RH wheels and then LH wheels which eventually die away.*

1-8::

  1L (with partner following) casts one place & crosses towards 2M place; 1s turn once RH moving down to 3rd places opp. sides, 1L facing out (2s & 3s step up in 3-4 & 7-8 respectively)

9-16::

  1L (with partner following) casts one place and crosses to bottom places own sides and turn once LH WHILE 2s repeat track of 1s in Bars 1-8, i.e. clockwise chase to centre & turn RH moving down to 3rd places opp. sides

17-24::

  3s repeat track of 1s in Bars 1-8 to 3rd places opp. sides WHILE 1s & 2s LH across once round and 1s dance 2 places up opp. sides as 2s chase anticlockwise to bottom places own sides (as 1s in Bars 9-12) 

25-32::

  3s chase anticlockwise to bottom places own sides (as 1s in Bars 9-12 - 2s step up on 27-28) WHILE 4s repeat clockwise chase of 1s Bars 1-4 to centre, just below 2nd places and (NB) turn 1½ RH moving UP to top places own sides (order now 4, 1, 2, 3)

33-40::

  4L (with partner following) casts 3 places to bottom of L side (others step up 1 place in 35-36), then 4L crosses at bottom and casts up to 3M place, 4M to own place, WHILE 1s chase similarly, 1L to 4L place, 1M to 3L place (2s & 3s step up in 39-40)

41-48::

   4s & 1s (on M & L sides respectively) RH across once round and back LH across WHILE 2s and 3s repeat clockwise chases of 4s & 1s respectively in Bars 33-40.

49-56::

  2s & 3s, passing same-sex persons RSh as they dance in, RH across just ¾ round (NB), then turn partners LH to own sides, 3s once in 4 bars to 3rd places, 2s ½ to 4th places & stand for 2 bars WHILE 1s leading 4s reverse their chases, anticlockwise up L side to 1st & 2nd places own sides (order now 1, 4, 3, 2).

57-64::

  With Ls casting off to start, all chase clockwise halfway round set  & turn partners 1½ RH to end 2, 3, 4, 1

', 3);
INSERT INTO 'dancecrib' VALUES (10460, '2018-02-26 08:09:48.343122+00', '2018-03-02 14:10:00.974649+00', 169, 1, 202, 'ace', '1--::
  1c cast (2c up) | cross RH ; 1c cast R round 1cnrs, pass Rsh to finish BtoB facing own side
9--::
  2c+1c+3c DTr (2,1,3)
17--::
  1c followed by 3c Fig8 round 2c (2,3,1)
25--::
  3c+1c set | ½ RHA ; set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2922, '2012-01-22 19:30:03.05119+00', '2021-05-03 08:13:54.324733+00', 4932, 1, NULL, 'ace', '1–::

  1c+2c set and cross RH ; repeat

9–::

  1c+2c set | ½ RHA ; set | ½ LHA

17–::

  1c lead down | set ; lead to top and cast off (2c up) (2,1,3)

25–::

  1c+3c circle4 L ; 2c+1c R&L (one step per hand)', 3);
INSERT INTO 'dancecrib' VALUES (14083, '2021-06-20 12:19:32.370915+00', '2021-07-13 22:31:20.176538+00', 20313, 1, 1645, 'ace', '1--::

  1c cross RH | cast off (2c up) ; &frac12; Fig8 down round 3c (2,1,3,4)

9--::

  1c &frac12; Fig8 up round 2c ; cross RH | cast off (3c up) to (2,3,1,4)

17--::

  3c+1c change pl, 1c up between 3c | 2c+1c turn on sides, 2c start down between 1c ; 1c+3c change pl, 3c up between 1c | 1c+4c change pl, 1c down between 4c (2,3,4,1)

25--::

  All circle8 & back (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (1771, '2012-01-22 19:29:01.493577+00', '2021-01-30 10:55:15.151134+00', 11108, 1, NULL, 'ace', '1–::

  1c set | cast off 2 (2c+3c up) ; 1c turn RH  (2,3,1)

9–::

  3c+1c S&Link ; 1c+3c circle4 L

17–::

  2c+1c set and »reversed link« (RH person dance inside, LH person cast Lsh) ; 1c+2c circle4 R, finishing for

25–::

  1c+2c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2827, '2012-01-22 19:29:59.057505+00', '2021-05-07 20:09:18.391832+00', 4561, 1, NULL, 'ace', '1–::

  Giving hands in lines of 3 all advance {1}, retire {1}, the M Petronella to between the two W on their R ; repeat in new lines, M finishing in exchanged places

9–::

  Men Reel3 with ''new'' partners, Rsh to W on the R (W make loops at end)

17–::

  All W Petronella Turn to next W place to the R | set facing diagonally ; repeat Petronella Turn to facing lines (with original partners) | All set

25–::

  All dance BtoB with the person opposite, NHJ for first and last step ; all advance one step, bow/curtsey | All keeping NHJ, W on the L making arch dances ½ circle clw, and W on the R dances ½ circle cclw, she and the M passing under the arch.  All face next trio.', 3);
INSERT INTO 'dancecrib' VALUES (7982, '2013-08-21 08:31:52.325544+00', '2023-02-04 01:23:14.856393+00', 7204, 3, NULL, 'ace', '1-8::
    1s & 3s Petronella turn into centre & set to partners; 1s+3s dance
    1/2 Reel of 4 up & down centre of dance
9-16::
    3s & 1s Petronella turn onto own sides & 3s+2s+1s set; 3s+2s+1s turn
    partners RH to end ready for Allemande
17-24::
    3s+2s+1s dance Allemande
25-32::
    1s cross RH & cast down 1 place, dance 1/2 Fig of 8 round 2s to end
    in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (3130, '2012-01-22 19:30:12.592382+00', '2015-09-02 12:42:45.601693+00', 5637, 1, NULL, 'ace', '1–::

  All Circle8 and back

9–::

  Double L chain (women ½ RHA, turn opposite M LH ; ½ RHA, turn P LH, to own places)

17–::

  1c+3c Reel4, (W pass left shoulder, M set on [17-18], at the end W slow down and M speed up, face and acknowledge P and pull back inner shoulder to face corners.

25–::

  All set to corner H.Schottische ; turn cnr BH twice

33-48::

  2c+4c repeat [17-32]

49–::

  Women Circle4 L (at end pull back Rsh to face out) ; set to and turn P BH.

57–::

  Men circle4 R, pull back Lsh ; set to and turn P BH.

65–::

  G-Chain (one step per hand)

73–::

  Promenade cclw round the set in Allemande hold, M bring W into middle of set and hold RH for bow and curtsey', 3);
INSERT INTO 'dancecrib' VALUES (8456, '2014-11-18 23:10:17.341904+00', '2017-04-24 16:29:47.096285+00', 7316, 1, NULL, 'ace', '1--::

  1c+2c Circle4 L ; RHA (1,2)

9--::

  1c+2c set to P | ¾ R&L, cross LH to start (2,1)

17--::

  2W+1M chase cclw ½ and face in _while{4}_ 2M+1W [= “1diag.”] turn RH 1½ and face clw (1x,2x) ; 1W+2M chase clw ½ to exchanged places in _while{4}_ 1M+2W turn LH 1½ to finish on 1diag. facing P

25--::

  Diag. Reel4, at end 2W & 1M curl R to (2,1)

', 4);
INSERT INTO 'dancecrib' VALUES (12508, '2020-01-14 16:30:16.126086+00', '2021-07-14 08:24:51.573581+00', 19820, 2, NULL, 'ace', '1--::

  1c lead down and up, crossing into line across LHJ with P and RHJ with opposite M and W 

9--::

  Set in line of 4 | turn Middles into ends RH ; Repeat (1c in middle)

17--::

  Reel4 across to (1,2)

25--::

  Circle4 and back

33--::

  Poussette (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (8888, '2015-09-02 15:24:26.862229+00', '2015-09-02 15:24:26.862229+00', 16699, 1, NULL, 'ace', '1–::

  1c turn RH ½ and twirl to exchanged places ; 2c repeat (1x,2x,3)

9–::

  3c repeat ; All repeat (1,2,3)

17-::

  1c slip down the middle ; and up (1,2,3)  

25-::

  1c starting inwards turn 2c 1½ EH ; 1c starting outwards turn 3c EH 1½ (2,3,1)  

*In a variant the opposite hands are used for [25-32]*

', 3);
INSERT INTO 'dancecrib' VALUES (1776, '2012-01-22 19:29:01.770238+00', '2021-07-01 22:55:50.114846+00', 571, 1, NULL, 'ace', '1–::

  1M dances Lsh round 3W and Rsh ound 2M, to place

9–::

  1W dances behind 2W and Lsh round 3M, to place

17–::

  1c dance up and cast off ; dance between 3c and cast up to (2,1,3)

25–::

  1c dances Lsh round 1cnr | turn RH ; dance Lsh round 2cnr | pass RH

33–::

  Reels3{6} on opposite side, Lsh to 1cnr | 1c cross RH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1774, '2012-01-22 19:29:01.650143+00', '2014-04-30 23:23:40.590102+00', 564, 1, NULL, 'ace', '1–::
  1c ½ Fig8 round 2c ; RHA, men face out
9–::
  Reel4 across (to start W pass Lsh , M curve R), at end the M turn LH into BtoB facing P
17–::
  Set to P | turn BH ; open into Circle4 L to (1x,2)
25–::
  All set | ¾ DblFig8, 1c cast and 2c cross up) (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (14814, '2022-05-07 21:18:55.925082+00', '2022-05-07 21:31:51.68507+00', 1562, 2, 1558, 'ace', '1-8:: Circle 6H round and back

9-16::  Center dancer set to dancer on right and turn RH to face dancer on the other end.  Repeat with dancer on the left ending facing dancer on the right.

17-24::  Reel of 3 starting with left shoulder to dancer on the right.

25-32::  In lines of 3, all advance and retire, then pass through.', 0);
INSERT INTO 'dancecrib' VALUES (13649, '2021-02-06 18:16:14.139846+00', '2021-02-06 18:16:23.718383+00', 20082, 1, 1645, 'ace', '1-4::

  1c & 3c petronella to centre line | set

5-16::

  Dance to Corners and Set in diamond formation: 1W & 3M change pl with P & pass each other RSh to face 2c as 2c set, repeat from new places until &frac12; way round, all ending in inverted places, 3c & 1c facing P on centre line

17-::

  3c+1c &frac12; LSh Reel4 on centre line ; 1c & 3c turn P &frac34; LH to sides (1,2x,3)

25-::

  1c cross RH | 1c+2c change LH on sides ; 2c+1c cross RH | set (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (8048, '2013-09-22 23:36:48.43656+00', '2014-04-29 12:51:54.173983+00', 12699, 1, NULL, 'ace', '1--::

  1M+3W & 1W+3M ½ turn and cast away to opposite place ; chase clw to exchanged place with P (1x,2,3x,4) (x indicates exchanged place) 

9--::

  2c+4c repeat (1x,2x,3x,4x)

17-20::

  All S&Link, the W finish facing out  (1,2,3,4)

21-32::

  Schiehallion reel for 12 bars (4,1,2,3)

33--::

  Circle8 and back

', 3);
INSERT INTO 'dancecrib' VALUES (9811, '2017-04-25 20:35:12.982212+00', '2017-04-26 10:50:12.049276+00', 17716, 1, NULL, 'ace', '1--::

  1c+3c cross RH | cast off (2c+4c up) ; turn LH to 1cnrs 

9--::

  1c+3c The Spoke with their cnrs, finish on midline with 1M facing 3W in the middle

17--::

  Lsh Reel4 on midline, to start 1M & 3W pass Rsh, finish on sides (2,1,4,3,5)

25--::

  1c+4c+3c+5c set | 1c+3c cast off (4c+5c up) ; 1c+3c Turn RH (or spin) (2,4,1,5,3)

33--::

  Circle10 and back

', 3);
INSERT INTO 'dancecrib' VALUES (1783, '2012-01-22 19:29:02.149723+00', '2019-03-06 11:13:19.838621+00', 8658, 1, NULL, 'ace', '1–::

  1c+4c BH slip down(up) the middle | and back to places ; 1c+2c & 3c+4c turn ½ on the sides (LH or RH, 1c & 4c passing on the outside), 1c+4c cross RH (finish in order 2,1x,4x,3)

9–::

  2c+3c repeat (1x,2x,3x,4x)

17–::

  1c+2c ½RHA, set ; 1c+3c ½LHA, set

25–::

  1c+4c ½RHA, set ; 2c+3c+4c+1c turn RH to (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (1773, '2012-01-22 19:29:01.590264+00', '2018-12-16 16:59:44.615589+00', 9562, 1, NULL, 'ace', '1–::

  1c+2c+3c ½ RH turn | twirl R to opposite place ; chase clw half round (3,2,1)

9–::

  3c+2c ½ R&L _while_{4} 1c cross RH and set ; 3c+1c ½ R&L _while_{4} 2c cross RH and set (to 2,1,3)

17–::

  Teapots R (pass Rsh) ; Teapots L, 2c+3c finish facing out

25–::

  Mirror Reels3 on the sides, joining hands where possible, 1c starts in and up', 3);
INSERT INTO 'dancecrib' VALUES (2976, '2012-01-22 19:30:05.298828+00', '2014-10-19 15:43:54.608541+00', 12796, 1, NULL, 'ace', '1–::

  1c cross RH | Cast (2c up) ; ½ Fig8 R to face 1cnrs

9–::

  1c+1cnrs Diag. Chain (turn cnr RH ½ | 1c chase clw ½ round _while{4}_ cnrs turn LH 1½ | 1c turn cnrs RH ½) and face 3cnr pos.

17–::

  Reels3 on sides, Rsh to 3cnr, finish passing P Lsh to face 2cnrs

25–::

  1c+2cnrs Diagonal Chain, 1c finish facing 4cnr

33–::

  Reels3 across, Rsh to 4cnr, at end loop to face 1cnr

41–::

  1c ½ Diag. Reel4 with 1cnrs, pass P Lsh ; repeat with 2cnrs and pass P Rsh to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9815, '2017-04-28 21:19:54.231141+00', '2019-08-03 09:00:41.431677+00', 8063, 1, NULL, 'ace', '1--::

  All M A&R ; All W A&R

9--::

  All M pass P Rsh, dance down behind the W and up own side to positions 4,3,2,1

17--::

  All W pass opposite M Lsh, dance down behind the M and up own side (4,3,2,1)

25--::

  1c makes BH arch.  The other couples dance NHJ under arch and up own sides (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10357, '2017-12-26 14:46:21.236124+00', '2020-05-12 23:04:00.155907+00', 824, 1, 202, 'ace', '1--::

  1c+2c+3c set | Petronella turn ; turn BH ¾ | all set (1x,2x,3x)

9--::

  all A&R{1+1} twice ; turn BH

17--::

  Mirror Reels3, each couple crossing down from the top, finishing 1c NHJ facing 2c NHJ for

25--::

  1c+2c Rondel (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14145, '2021-07-13 00:32:49.046133+00', '2021-07-14 08:47:25.30739+00', 19820, 1, 202, 'ace', '1--::

  1c lead down ; lead up and cross to between 2c into BiL position

9--::

  BiL | middles turn ends RH ½ ; repeat [9-12]

17--::

  Reel4 across (1,2)

25--::

  Circle4 and back (1,2)

33--::

  Poussette (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (9632, '2017-03-04 12:13:22.315201+00', '2021-07-14 11:56:48.602152+00', 8478, 1, NULL, 'ace', '1--::

 1c+2c R&L

9--::

 1c slip down the middle (2c up on [11-12])  ; and up (2,1)

17--::

 2c+1c set | cross RH ; repeat

25--::

 1c Fig8 round 2c (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (14245, '2021-08-16 12:45:06.729581+00', '2021-08-16 12:47:54.746969+00', 13139, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c in (1,2,3)

9--::

  1c set | cast off (2c up) ; dance RSh round 1cnrs into lines3 across

17--::

  ½ Reels3 across, 1c LSh to 4cnrs ; 3C S&Link (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10140, '2017-09-22 21:18:27.325027+00', '2020-08-29 12:05:43.904867+00', 452, 2, 160, 'ace', '1-8::

  1s+2s RHA; LHA.

9-16::

  1s set, cast (2s up); dance down between 3s and cast up to 2nd place.

17-20::

  2M +1M turn LH _as_ 2W+1W turn RH (1s in+up);

21-24::

  1M+3M turn RH _as_ 1W+3W turn LH (1s in+down).

25-32::

  All set, turn partner RH once round. and set.', 3);
INSERT INTO 'dancecrib' VALUES (9267, '2016-07-13 21:33:49.503698+00', '2020-10-21 20:07:24.937865+00', 17140, 1, 1041, 'ace', '1--::  1M+4W set | A&R | set _while{8}_ 1W+4M stand | set ; advance | set (bar 5-8 RHJ with P)

9--::  1c+2M & 4c+3W RHA (2M+3W finish in end places) | 1c+2W & 4c+3M LHA (2c+3c now in end places, 1c+4c finish outside set on opp. side, 1W & 4M facing out)

17--::  1W & 4M, each followed by P, cclw cast 2 places and finish on midline BtoB with P, 4c above 1c, M facing up, W down ; 2c+4M & 1W+3c circle3 _while{4}_ middles  turn LH ½ | clap and turn RH ½

25--::  1W+3c & 4M+2c set as in DTr _while{2}_ middles ½ turn BH | 1W+4W & 1M+4M change places as in DTr _while_ 2c+3c set ; repeat [25-28] from exchanged places, but finish 1c & 4c (with W on L) in middle facing up NHJ  

33--::  1c followed by 4c lead up and cast off, 1c to 3plx, 4c to 2plx ; 1c+4c ½ Fig8 round end cpl (2,4,1,3)

41--::  All ½ turn P RH, finish in the middle, facing P RHJ | set ; pass RSh to own side | All set (2,4,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (11501, '2019-01-07 11:24:27.628866+00', '2019-01-07 11:31:43.702395+00', 14401, 1, NULL, 'ace', '1--::

  1c lead down (2c up), on [4] 1W crosses in front and, 1M following, casts up (round any standing M), to finish 1c in 2pl  facing 3W

9--::

  3W+1c+2M Rsh lead-change diag. Reel3 ; 1M dancing the full reel, _while for [13-16]_ 1W turns 3M LH to finish behind 1M, both on midline facing up

17--::

  2W+1c+3M Rsh lead-change diag. Reel3 ; 1W dancing the full reel, _while for [21-24]_ 1M turns 3W LH to finish 1c in 2plx, 1W facing out 

25--::

  1c dance up (1W Rsh to 2M, 1M Rsh to 2W) | 1c dance Rsh round 2W to 2pl | All set.', 3);
INSERT INTO 'dancecrib' VALUES (8921, '2015-09-22 20:40:03.328889+00', '2023-02-04 01:23:14.962003+00', 16768, 3, NULL, 'ace', '1-8::
    1s lead down the middle (3 bars) & back (3 bars) & cast off to
    finish facing 1st corners.
9-16::
    1s turn corner, partner, corner, partner & finish in 2nd place on
    opposite sides facing out
17-24::
    1M with 2s, 1L with 3s dance reels of 3 across, giving LSh to 2nd
    corner to begin _while_ corners dance Reels of 3 on the side.  On
    bars 23-24 1s turn RH
25-32::
    1L casts down round 3M _while_ 1M casts up round 2L to finish in 2nd
    place opposite sides.  1s Tulloch turn to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (13456, '2020-12-06 00:11:28.597723+00', '2020-12-06 00:19:43.99597+00', 15960, 1, 202, 'ace', '1--::

  All set | 1c & 3c advance diagonally. 1c face up, 3c face down ; 1c+2c+3c ½ Reels3, 1c up and out, 2c in and up, 3c down and out (3,2,1,4)

9--::

  All set | 2c & 4c advance diagonally. 2c face up, 4c face down ; 2c+1c+4c ½ Reels3, 2c up and out, 1c in and up, 4c down and out (3,4,1,2)

17--::

  1c+2c set | ½ RHA (to 3,4,2x,1x) ; 4c+2c set | ½ LHA (3,2,4x,1x)

25--::

  3c+2c set | ½ RHA (to 2x,3x,4x,1x) ; all set | cross RH (2,3,4,1)

33--::

  Circle8 and back (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (1782, '2012-01-22 19:29:02.105195+00', '2019-02-04 17:50:03.675877+00', 594, 1, NULL, 'ace', '1–::

  1c+2c (leading) lead down, on [4] 1c cross ; 2c lead up to 2pl _while_{4} 1c cast to the top, and curve in to finish BtoB between 2c facing opposite side

9-24::

  The Spurtle:

9-12::

  1c+2c, ½Reel4, 2c ends in 1plx (cast up) as 1c moves down with quick RH turn to face 3c in the same way

13-16::

  1c+3c repeat

17-20::

  1c+4c repeat

21-24::

  1c continue fast RH turn to 4plx (best as      a double turn) | all set (2x,3x,4x,1x)

25–::

  All ½ Petronella to own side (2,3,4,1).', 2);
INSERT INTO 'dancecrib' VALUES (9076, '2016-01-20 11:33:24.291197+00', '2016-01-22 22:50:07.131281+00', 16478, 1, NULL, 'ace', '1--::

  1c+3c & 2c+4c L-Chain (W make RHA in the middle) 

9--::

  All set to and turn P RH ; set to and turn cnr LH, finish in own places, W facing out

17--::

  Half Schiehallion Reel (3,4,1,2)

25--::

  Circle8 and back



*Repeat once only in Reel time.*

', 3);
INSERT INTO 'dancecrib' VALUES (10355, '2017-12-24 19:21:28.857925+00', '2018-09-19 09:48:45.7684+00', 17405, 1, 202, 'ace', '*Square set plus 5M / 5W in middle face P with backs to 4c / 2c*

1--::

  2c+5M+5W+4c (cpls in promhold) Reel4, 5c pass P Rsh to start, ending passing P Lsh

9--::

  5M pass 2c Rsh to between 2M & 3W _while{4}_ 5W pass 4c Rsh to between 4M & 1W ; 2M+5M+3W & 1W+5W+4M A&R

17--::

  1M+2W & 3M+4W turn RH _while{2}_ 5c turn P ½ (and twirl optional) ending 5M facing 3M+4W & 5W facing 1M+2W | all (cnrs NHJ) set ; 5M+2W+1M & 5W+4W+3M RHA, 5c passing P Rsh to end facing 4c, 5W behind P

25--::

  (all cpls M leading) 5c+1c chase clw 1/2, 5c in 1pl | 1c+4c repeat ; 4c+3c repeat | 3c+2c repeat



*(The set is now formed by (5,3,4,1, and 2c in the middle)*', 2);
INSERT INTO 'dancecrib' VALUES (3853, '2013-07-13 15:56:23.780541+00', '2018-06-12 11:16:15.756877+00', 14577, 1, NULL, 'ace', '1–::

  1c+3c turn RH ½ and twirl R to opp. side ; cast off (2c+4c up) | turn LH to face 1cnr

9–::

  1c+3c Set H&G, finish facing 3cnr

17–::

  1c+3c Corners Pass and Turn, pass Rsh ; repeat with 4cnrs, finish with ½ turn RH and face down on opp. side RHJ

25–::

  1c+3c lead down | cross, W passing under arms and M crossing below her ; lead up on own side | cast off (4c+5c up) (2,4,1,5,3)', 4);
INSERT INTO 'dancecrib' VALUES (14307, '2021-09-13 01:22:39.14073+00', '2021-09-13 14:23:23.989071+00', 9355, 1, 202, 'ace', '1--::

  1c+3c Double Fig8, 1c crossing down (1,2,3,4)

9--::

  2c+4c Double Fig8, 2c crossing down (1,2,3,4)

17--::

  1c & 3c cross RH | cast off (2c & 4c up) (to 2,1,4,3) ; 1M+3W change places RH | 1W+3M change places RH (2,3,4,1)

25--::

  Circle8 and back (2,3,4,1)', 5);
INSERT INTO 'dancecrib' VALUES (8223, '2014-03-26 17:34:28.668679+00', '2020-08-07 04:42:02.885127+00', 4863, 2, 160, 'ace', '1–8::

 1C+2C adv&ret ; 1C+2C half R&L. (2)(1)

9–16::

 2C+1C set, 1C cast up cross over RH _while_ 2C turn RH moving down 1pl., 1C+2C set. 1 (2)

17–24::

 1C cast off to below 2C ; turn RH once round (2), cast up to place(2).

25–32::

 1C half fig.8 down, 1C+2C half R&L.', 2);
INSERT INTO 'dancecrib' VALUES (15174, '2022-10-16 21:53:29.950267+00', '2022-11-03 12:57:47.400207+00', 21149, 1, 1645, 'ace', '1--::

  M LHA ; all S&Link (1x,2x,3x)

9--::

  W LHA ; all S&Link (1,2,3) & end with W facing out

17--::

  4 bars of Schiehallion Reels, passing LSh in centre, W end facing out (2,3,1) ; turn cnr LH & face P | turn P BH & open out into a circle

25--::

  Circle6 & back (2,3,1)

', 5);
INSERT INTO 'dancecrib' VALUES (3036, '2012-01-22 19:30:07.796435+00', '2014-04-30 23:24:06.109071+00', 9641, 1, NULL, 'ace', '1–::
  1W+2W+3W cross, passing P Rsh, with 1W leading dance up, cross at the top and down own side | 1c+2c+3c set
9–::
  1M+2M+3M cross, passing W opposite Lsh, with 1M leading dance up, cross at the top and down own side | 3c+2c+1c set (3,2,1,4)
17–::
  3c+1c cross RH | cast off one (2c+4c up) ; ½ Fig8 up (2,3,4,1)
25–::
  Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (3621, '2012-07-21 11:46:04.393625+00', '2015-02-26 14:47:41.594891+00', 13594, 1, NULL, 'ace', '1–::

  1c+3c ½ Fig8 down ; 1c+2c & 3c+4c turn 1½ (or birl) on the sidelines (1c & 3c start inwards) (2,1x,4,3x)

9–::

  Mirror Reels4 on the sides (Lsh on W side)

17–::

  1c+4c dance out the ends and cast in to places ; 1c+4c turn RH or Birl (2,1x,4,3x)

25–::

  1c+4c set | ½ RHA (2,4x,1,3x) ; 4c+3c ½ Fig8 up (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3076, '2012-01-22 19:30:09.648901+00', '2016-10-23 20:42:02.510198+00', 5462, 1, NULL, 'ace', '1–::

  1c+2c R&L

9–::

  1c lead down the middle and up

17–::

  1c+2c Allemande

25–::

  2c+1c+3c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (10364, '2017-12-28 21:34:08.333773+00', '2017-12-28 21:39:10.428385+00', 14908, 1, 202, 'ace', '1-4::

  1c set | cast (2c up) (2,1,3)

5-16::

  3C R&L (2,1,3)

17--::

  S&Link3 twice (3x,1x,2x)

25--::

  ½ Reels3 across, 1c Rsh to 4cnrs position to start (to 3,1,2) ; ½ Reels3 on sidelines, 1c Lsh to 3cnrs position to start (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13934, '2021-04-05 12:45:46.439878+00', '2021-04-05 12:52:56.167103+00', 20296, 1, 202, 'ace', '1--::

  Mirror Reels3 on opposite sides, 1c crossing down (1x,2,3)

9--::

  1c cross RH | cast off (2c up) ; dance down between 3c | cast up and face 1cnrs

17--::

  ½ Reel4 on 1diag, pass P RSh ; ½ Reel4 on 2diag (3x,1x,2x)

25--::

  3C S&Link twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3841, '2013-07-13 15:56:20.325383+00', '2020-12-17 22:24:16.97656+00', 6036, 1, NULL, 'ace', '1–::

  1c lead down RHJ one place | turn LH _while_ 2c making arch dance to 1pl ; 1c+3c repeat (2,3,1)

9–::

  1c lead up RHJ one place | turn LH _while_ 3c making arch dance to 3pl ; 2c+1c repeat (1,2,3)

17–::

  1c cast off 2 and lead up the middle

25–::

  1c+2c Allemande', 3);
INSERT INTO 'dancecrib' VALUES (8820, '2015-07-25 23:52:57.895394+00', '2015-07-25 23:52:57.895394+00', 16511, 2, 160, 'ace', '1-8::
  1C turn RH, cast 1 pl.; Turn LH 1_3/4 to end  with 1M btwn 2C facing up/1L btwn 3C facing down.
9-12::
  1M cast L around 2M into 2pl and pass ptnr by Lsh to face 1crnr. 1L, similarly, cast L around 3W & pass ptnr to face 1crnr ;
13-16::
  Half diagonal Reel 4 with 1crnrs - 1C pass Rsh in the center to end 1M btwn 3L+2L (in top pl) facing up & 1L btwn 2M+3M (in 3pl) facing down.
17-20:: 1M cast R around 2L into 2pl. and pass ptnr Rsh to face 4crnr, 1L, similarly, cast R around 3M and cross to face 4crnr  ;
21-24::
  Half Left shoulder Reel of 4 with 4crnrs - 1C dance diagonally across and into 2pl on ptrs sides.
25-32::
  Set&Link3; Repeat.', 2);
INSERT INTO 'dancecrib' VALUES (1784, '2012-01-22 19:29:02.192208+00', '2017-04-21 23:04:27.146129+00', 604, 1, NULL, 'ace', '1–::

  All C set | turn BH to finish in the middle NHJ, 1c facing down, 2c+3c up ; All set, 1c+2c advancing to change places | 2c turn BH to face down, _while_{2} 1c+3c set advancing to change places (2,3,1, in middle)

9–::

  2c+3c set advancing to change places _while_{2} 1c turn BH to face up | continue sequence 3 more times (to 1,2,3)

17–::

  1c+2c Rondel, at end 1c cross down and face out (2,1x,3) _while_{2} on [17-18] 3c dance down a bit and cast up into 3pl

25–::

  1c turn 3c EH (2,1x,3) ; 1c ½ turn 2c EH (other) | 1c cross down _while_{2} 2c cast up (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1785, '2012-01-22 19:29:02.234405+00', '2014-04-30 23:23:40.882361+00', 608, 1, NULL, 'ace', '1–::
  1c cast off 2 places (2c+3c up) | turn BH ; 2c cast off 2 places (3c+1c up) | turn BH (3,1,2)
9–::
  All set | turn P BH ; 3c cast off 2 places (long cast) (1c+2c up) (1,2,3)
17–::
  1c+3c circle4 L, 1c moving down to meet 3c ; 1c dance up | cast to 2pl (2c up)
25–::
  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (1786, '2012-01-22 19:29:02.282446+00', '2014-04-30 23:23:40.91857+00', 610, 1, NULL, 'ace', '1–::
  1c+2c circle4 and back
9–::
  1c lead down the middle and up
17–::
  1c+2c Allemande', 2);
INSERT INTO 'dancecrib' VALUES (9277, '2016-07-28 14:26:31.560715+00', '2016-07-28 14:26:31.560715+00', 16298, 2, 160, 'ace', '1-8::
  1C set, cast 1 place (2C up) ; 1C turn RH 1+3/4 to face 1st corner.
9-24::
  1C set to 1st corner + pull back Lsh, turn LH 3/4 to face 4th corner;
  Repeat with 4th corner, 3rd corner and 2nd corner - end turning LH to face 1st   corner.
25-40::
  1C dance 4 consecutive half Reel4 with 1crnr; 2crnr.  3crnr; and 4crnr - passing Rsh in the middle - finish in 2nd place own sides.
41-48::
  6 hands round and back.', 2);
INSERT INTO 'dancecrib' VALUES (1788, '2012-01-22 19:29:02.373301+00', '2014-04-30 23:23:40.976352+00', 615, 1, NULL, 'ace', '{{explanation}}
2 chords to honour P and corner.

1–::
  All dance BtoB with cnr ; 1c+3c ½R&L
9–::
  Repeat BtoB ; 2c+4c ½R&L (3,4,1,2)
17–::
  All M dance into centre to face next woman on R | all set ; ½ RH turn (women to next place, in centre facing P) | all set
25–::
  All C dance BtoB ; all C turn RH 1¼, to (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (8107, '2013-11-16 20:54:15.9056+00', '2013-11-16 20:54:15.9056+00', 15173, 2, 160, 'ace', '1-8::
  Reel of 3 on own sides. Begin 1s in and down.
9-16::
  1s 2s Rondel. 1s cross down under arch on bars 15+16 to face out 2nd place opp. side.
17-22::
  Reel 3 on opp. side. Begin 1s out and down.
23-24::
  1s turn RH to end 2nd place ptnrs side. 2s 3s cross RH.
25-32::
  Set & Link 3; Set & Link 3.', 2);
INSERT INTO 'dancecrib' VALUES (9591, '2017-02-09 22:14:28.150635+00', '2022-05-07 21:41:01.092007+00', 16010, 2, 160, 'ace', '1-8::

  All turn RH ; all turn LH.

9-16::

  1C slip down and up - face down NH joined.

17-20::

  1M 2M turn RH 1_1/2 to change places *as* 1L 2L turn LH 1_1/2 to change places.

21-24::

  1M 3M repeat LH *as* 1L 3L repeat RH.

25-32::

  6H round & back.', 3);
INSERT INTO 'dancecrib' VALUES (12436, '2019-12-14 09:55:33.671263+00', '2019-12-14 10:02:15.564866+00', 19517, 2, 1, 'ace', '1–::
  1c cast off (2c up) | 1c set adv (towards ptr) ; 1c turn 3cnr LH (to 2,1,3)
9–::
  1c+3c ¾R&L | 1c+3c  set
17–::
  1c cast up (3c down) | 1c set adv (towards ptr) ; 1c turn 4cnr RH (to 2,1,3)
25–::
  Circle6', 3);
INSERT INTO 'dancecrib' VALUES (8824, '2015-07-31 01:06:20.25705+00', '2017-01-30 22:51:41.664474+00', 16018, 2, 160, 'ace', '1-8::

  Poussette Right round

9-16:: Cast 1 pl, dance down btwn 3C; cast up through 2pl to face 1crnr.

17-24::

 1C+1crnr set adv, pass Lsh w/ crn, top & bottom cpls cross RH while centers dance around by the Rsh to face 2nd crn pos ; set adv, pass Lsh w/ crn., 1C  in center dance around each other RS to 2nd pl (2x, 1x, 3x) 

25-32::

  All set, dance RS around partner and out to own sides, all set.', 2);
INSERT INTO 'dancecrib' VALUES (8106, '2013-11-16 20:43:50.442498+00', '2017-05-14 00:33:52.497559+00', 15152, 2, 160, 'ace', '1–8::

  1s cross RH, cast (2s up); cross LH, cast - 1M down & 1L up to lines of 3 across.

9-16::

  Reel 3 across, begin Rsh to 1crnr

17-24::

  Reel 3 on sides, begin Lsh to 2crnr. End in lines of 3 across (lady up, man down)

25-32::

 All  adv, ret.; 1s turn RH to own side.', 2);
INSERT INTO 'dancecrib' VALUES (1789, '2012-01-22 19:29:02.425167+00', '2014-04-30 23:23:40.992894+00', 616, 1, NULL, 'ace', '1–::
  1c set | cross to 2plx (2c up) ; 2c+1c set | ½ RHA (1,2x,3)
9–::
  All Circle6 L | the M ½ RHA _while_{2} the W cast cclw (to 2x,1,3x) ; All Circle6 R | the W ½ LHA _while_{2} the M cast clw (to 2,3x,1) (remember: each time the M move round one place cclw, the W one place clw)
17–::
  3c+1c set | 3c cross down as 1c cast up ; All C turn RH, 2W+3M stay facing out (2,1,3)
25–::
  2W+3M chase clw ½ round _while_{4} the others ½ diag R&L (no polite turn) ; 2M+3W chase ½ round cclw _while_{4} the others ½ diag R&L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1803, '2012-01-22 19:29:03.125691+00', '2020-05-15 13:12:17.389298+00', 670, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  1c cast off to 4pl _while{4}_ 4c lead up to 1pl ; 4c+2c & 3c+1c ½R&L  (2x,4x,1x,3x)

9-12::

  4c+1c ½ RHA, 2c+1c & 4c+3c ½ LHA  (1x,2,3,4x) ;

13-16::

  1W+2W & 3M+4M change places RH, 1M+2M & 3W+4W change diagonal places RH, (to 2x,1,4,3x)



{{title}}

Reel



{{explanation}}

(note: [17-28] repeats the Strathspey figures [1-12]



17–::

  2c cast off to 4plx _while{4}_ 3c lead up to 1plx ; 3c+1c & 4c+2c ½ R&L (1x,3,2,4x)

25-28::

  3c+2c ½ RHA, 1c+2c & 3c+4c ½ LHA (2,1,4,3) ;

29-32::

  1c+4c+3c ½Reel3 on own sides (1c+3c in, 4c out and down) (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (1790, '2012-01-22 19:29:02.468424+00', '2020-10-04 11:53:00.826776+00', 627, 1, NULL, 'ace', '1–::

  1M+2c Reel3 across (Lsh to 2W), on [5] 1M picks up 1W on R in promhold

9–::

  1W+2c continue ½ Reel3 (2M/2W finish in 2W/1M place) _while{4}_ 1M long cast off ; 1M+3c start Reel3 across (Lsh to 3W) _while{4}_ 1W long cast off (2M up)

17–::

  1M picks up P on R in promhold and continues reel ; 1M dances up between 2c and cast to 2Mpl _while{4}_ 1W continues reel, all finish (2x,1,3x)

25–::

  1c dances between C on R and cast (round 4cnr pos) to (2x,1,3x) ; 1c set | turn RH and face out

33–::

  2c+3c dance ½ Petronella _while{8}_ 1c cast R | pass between end couple as they set ; cast R to 2plx | cross LH (2,1,3)



{{explanation}}

Optional variant: on 29-32 1c Turn RH {4}.', 3);
INSERT INTO 'dancecrib' VALUES (3088, '2012-01-22 19:30:10.729906+00', '2021-03-01 20:12:24.308073+00', 9102, 1, NULL, 'ace', '1–::

  All Circle8 and back

9–::

  1c BHJ slip down the middle and up

17–::

  1c, with 2c+3c+4c following cast to 4pl and form arch ; 2c+3c+4c NHJ dance up under arch (2,3,4,1)

25–::

  All clap (8 times) ; All turn P RH', 3);
INSERT INTO 'dancecrib' VALUES (14244, '2021-08-16 00:26:20.604614+00', '2021-08-16 14:20:13.467282+00', 20428, 1, 202, 'ace', '1--::

  All Petronella turn | set ; Petronella turn to opposite sides | turn P RH into allemande hold facing up

9--::

  3C Allemande (3,2,1)

17--::

  1c cast up (2c down) | 1c set ; 1c turn P RH _while{6}_ 2c+3c six bars of R&L (2,1,3)

25--::

  Circle6 and back (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (9822, '2017-05-04 20:23:29.896167+00', '2020-12-30 21:45:09.177256+00', 15406, 1, 202, 'ace', '1--::

 1c set | cross RH ; cast (2c up) | turn LH to face 1cnrs

9--::

 Turn CPCP, finish in 2pl middle facing up NHJ

17--::

 1c dance up between 2c | cast to 2pl ; dance down between 3c | cast to 2pl (2,1,3)

25--::

 1c+3c Tournée', 2);
INSERT INTO 'dancecrib' VALUES (1880, '2012-01-22 19:29:07.845483+00', '2020-05-15 13:17:13.093022+00', 950, 1, NULL, 'ace', '1–::

  1W+2M & 1M+2W set (1c advancing and passing Rsh) and turn EH to face P ; repeat figure (again 1c passing) to own places, 2c facing out

9–::

  1c followed by 2c (cast up) lead down between 3c, cast up on own side, dance up NHJ to own places (1c loops, 2c dances straight in) | 1c+2c set (1,2,3)

17–::

  Reels3 on own side, 1c starts in, 2c out and up, Touch hands every time in the middle (1,2,3)

25–::

  6 bars of Reels3{8} on sides, all crossing from top (1c on [1], 2c on [3], 3c cross at top on [5-6] (to 3x,1x,2x) | all set (3,1,2)

33–::

  2c+3c cross RH, set up/down ; 2c (passing outside)+3c change places EH _while{2}_ 1c cast off one | cross RH ; cast up to 2pl | all set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1793, '2012-01-22 19:29:02.60195+00', '2014-05-30 13:29:48.461512+00', 635, 1, NULL, 'ace', '1–::

  1W+3M cast into 1c+3c chase ½ clw _while_{4} 2c set and cross RH ; 3c+2c+1c turn RH (3x,2x,1x)

9–::

  1M+3W cast into 1c+3c chase ½ cclw _while_{4} 2c set and cross LH ; 1c+2c+3c turn LH

17–::

  1c+2c cross, W passing between the M | and back (men between women) into ; mirror turns (1c RH, 2c LH), finish for

25–::

  1c+2c Allemande', 2);
INSERT INTO 'dancecrib' VALUES (10044, '2017-08-11 18:07:18.385878+00', '2017-08-11 18:07:18.385878+00', 17902, 2, 202, 'ace', '1-8:: 1s+3s double fig of 8 round 2s (1s start by crossing down)
9-16::  All set&cross Rh; chase ½ way
17-24::  3s+2s Set & Rotate
25-28::  All turn Rh; (1L faces out, 2s+3s remain in the centre making arches)
29-32::  1L followed by partner dances up behind ladies’ line, down under the arches, and back to 3 rd place. On the last 2 bars 2s+3s retire to places.', 2);
INSERT INTO 'dancecrib' VALUES (8115, '2013-11-17 13:04:51.353673+00', '2017-09-08 22:04:06.97261+00', 12884, 1, NULL, 'ace', '1--::

  1c cross RH | cast off ; ½ Fig8 up (2c up) (2,1,3)

9--::

  1c cross RH | cast off ; ½ Fig8 up (3c up) (2,3,1)

17--::

  All A&R ; All turn P RH

25--::

  Circle6 and back

', 3);
INSERT INTO 'dancecrib' VALUES (11008, '2018-08-17 14:39:40.396033+00', '2020-12-29 11:23:43.469772+00', 13363, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

  1M+2W & 3W+4M turn RH ½, retain hands | 1c+2c & 3c+4c RHA, 1W+2M & 3M+4W retain hands | 1W+2M & 3M+4W turn RH ½, 1W&4W face out (2x,1x,4,3)

9--::

  1c & 4c cast out, meet into promhold, pass W Rsh, 1c(4c) face 3M(2M) ; ½ Reels3 across, 1c(4c) start Rsh to 3M(2M), finish on M(W) sides

17--::

  1c+4c ¾ RHA, on [20] 1M(4M) pivot to face 1c(4c) down(up) (to 2,4x,1,3x) ; 4c cross up between 2c and cast to 2pl _while{3}_ 1c cross down between 3c and cast to 3plx. On [24], 4c+1c changes places Lsh into Reel4 position (2,1x,4,3x)

25--::

  Parallel Rsh Reels4. On [31-32], 1c(4c) curl into 3plx(2pl) (2,4,1x,3x)', 4);
INSERT INTO 'dancecrib' VALUES (3169, '2012-01-22 19:30:14.232783+00', '2014-04-30 23:24:08.614439+00', 8839, 1, NULL, 'ace', '1–::
  1c set | 1c+2c set ; 1c+2c+3c set | 1c+2c+3c set advancing into
9–::
  1c+2c+3c Promenade, at end 2c to top and 1c casts to 2pl (2,1,3)
17–::
  All circle6 and back
25–::
  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (9086, '2016-01-29 20:50:15.140861+00', '2016-01-30 23:53:31.038146+00', 14457, 1, NULL, 'ace', '1--::

  1c lead down (2c up on [3-4]) ; change sides, W passing under joined arms and M crossing below her and lead up to 2plx RHJ (2,1x,3)

9--::

  Mirror Reels 3 on the sides, joining hands where possible, 1c starting up NHJ and out and 2c dancing in and down, 1c finish facing 1cnr

17--::

  Set “H&G”, at end 1c turn ¾ RH 

25--::

  Circle6 and back

', 5);
INSERT INTO 'dancecrib' VALUES (14924, '2022-06-27 12:15:53.524785+00', '2022-07-04 12:55:21.668931+00', 10589, 1, 202, 'ace', '1--::
  1c+2c Mirror Set&Link, 1c casting off ; 1c ½ Fig8 up round 2c (2,1x,3)
9--::
  1c+3c Repeat [1-8] (2,3,1)
17--::
  All Petronella Turn | set ; turn P BH ½ | Petronella Turn (2,3,1)
25--::
  Circle6 and back (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3467, '2012-01-22 19:30:26.703726+00', '2017-07-07 14:15:06.204918+00', 6885, 1, NULL, 'ace', '1–::

  1c+2c Poussette

9–::

  1c dance in into promhold (1W on R) for Fig8 round 2c, Rsh to 2W, finish in 1pl facing down RHJ

17–::

  1c lead down the middle and up

25–::

  1c+2c Allemande', 3);
INSERT INTO 'dancecrib' VALUES (1797, '2012-01-22 19:29:02.82518+00', '2019-02-05 00:13:42.102418+00', 11091, 1, NULL, 'ace', '1–::

  1c+2W Reel3 across, 1c begins Rsh, end in own places

9–::

  1c+2M Reel3 across, 1c begins Lsh

17–::

  1c+2c RHA ; turn P RH | 1c cast off _while_{4} 2c dance up (2,1,3)

25–::

  1c+3c repeat (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (13650, '2021-02-07 17:08:30.726592+00', '2021-02-07 17:22:16.064395+00', 17974, 1, 202, 'ace', '1--::

  1c cast off (2c up) | set ; turn RH 1¼ in tandem position on midline, 1W leading facing down

9--::

  Reel3 on 2diag, 1c in tandem RSh to 3M: 1W dancing the full reel _while on [13-16]_ 1M +3W turn RH. 1c in 2plx face out (2,1x,3)

17--::

   Reels3 on sides, 1c LSh to 2cnrs {6} | 1c turn LH in tandem position on midline, 1M leading facing down

25--::

  Reel3 on 1diag, 1c in tandem LSh to 3W: 1M dancing the full reel _while on [29-32]_ 1W +3M turn LH. 1c in 2pl face out (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8827, '2015-08-01 04:32:30.480228+00', '2015-08-01 04:37:31.705902+00', 16522, 1, NULL, 'ace', '

1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 R (round 3cnr) to join with P LH and 1cnrs RH





9--::  The Spoke: BiL{1}, advance LHJ cclw to next cnr {1} | repeat 3 times, finish facing 1cnr





17--::  1c+1cnrs ½ diag Reel4, pass Rsh ; 1c+2cnrs ½ Diag Reel4 (3x,1x,2x)





25--::  all chase clw half round ; teapots R (2,1,3)





 ', 3);
INSERT INTO 'dancecrib' VALUES (8111, '2013-11-16 23:44:21.863289+00', '2013-11-16 23:48:38.186604+00', 8735, 1, NULL, 'ace', '1--::

  1c cast behind own lines (2c up) and back to (2,1)

9--::

  1c ½ Fig8 round 2c ; 2c+1c A&R (2,1x)

17--::

  1c ½ Fig8 round 2c ; 2c+1c A&R (2,1)

25--::

  2c+1c RHA ; LHA



', 3);
INSERT INTO 'dancecrib' VALUES (1798, '2012-01-22 19:29:02.874533+00', '2016-10-30 13:01:26.139535+00', 8102, 1, NULL, 'ace', '1–::

  1c+3c dance down | turn BH ; dance up | turn BH to face 2c & 4c who step in

9–::

  1c+2c & 3c+4c Rondel (2,1,4,3)

17–::

  All set | 2c+1c & 4c+3c ½R&L | all cross RH (1,2,3,4)

25–::

  1M+2W cross RH | 1c+(2M+3M) cross LH ; 1c+(3W+4W) cross RH | 1W+4M cross LH (2x,3x,4x,1x)

33–::

  All A&R ; turn BH 1½', 2);
INSERT INTO 'dancecrib' VALUES (9278, '2016-07-28 14:42:04.038164+00', '2020-12-29 12:29:26.63266+00', 16300, 2, 160, 'ace', '1-4::

  1C set:- 1L adv to the centre and 1M ret to behind men''s line,

  1C slip down below 3C;

5-8::

  1C set:- 1L ret to behind ladies'' line as 1M adv to the middle,

  1C slip up to place.

9-16::

  1C dance Rsh round ptnr[4] ; cast to 3pl and set facing up *WHILE*

  2C 3C adv & ret ; step up, and set.

17-24::

  Reel3 on own sides - 1C in and up.

25-28::

  1C dance up (end btwn 2C), 3/4 Mirror turn 2C (HH); On 27-28 3C dance in & down     to 3pl + face out;

29-32::

  1C 3C turn HH.

  ', 0);
INSERT INTO 'dancecrib' VALUES (11424, '2018-12-23 09:21:49.890772+00', '2022-12-19 16:40:33.617768+00', 11020, 1, 202, 'ace', '_Strathspey_

1--::

  All M ½ LHA to opp M place | chase cclw ½ to places (1,2,3,4)

9--::

  1c+3c ½ M-Chain ; 1M+3W & 3M+1W set to new P | turn LH

17--::

  2c+4c ½ M-Chain ; 2M+4W & 4M+2W set to new P | turn LH

25--::

  4M+3W+1M+4W & 2M+1W+3M+2W Reels4 across, top and bottom cpls starting LSh to P

33--::

  3M+2W+4M+3W & 1M+4W+2M+1W Reels4 on sides, sides cpls starting LSh to P

41--::

  All W ½ RHA to opp W place | chase clw ½ to places

49--::

  1c+3c ½ La-Chain ; 1c & 3c set to P | turn P RH

57--::

  2c+4c ½ La-Chain ; 2c & 4c set to P | turn P RH (3,4,1,2)



_Reel_

65-128::

  Repeat [1-64]', 2);
INSERT INTO 'dancecrib' VALUES (3196, '2012-01-22 19:30:15.279642+00', '2021-08-04 17:07:05.062315+00', 8970, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; turn LH to DTr position own side

9–::

  ½ DTr to face 1cnr ; ½Reel4 with 1cnr, 1c meet in middle and swivel R to face end couples, M facing down, W up

17–::

  ½ DTr up/dn to face 2cnr ; ½Reel4 with 2cnr, to (3x,1x,2x)

25–::

  S&Link3 ; repeat (2,1,3)

33–::

  All circle6 L and pivot L ; chase cclw to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14602, '2022-02-08 14:59:40.379172+00', '2022-02-08 15:00:22.916449+00', 17608, 1, 202, 'ace', '1--::

  DblFig8, 1c crossing down (1,2,3)

9--::

  1c (+2c following) lead down ; 2c (+1c following) lead up. 1c face out (2,1,3)

17--::

  1c+3c DblFig8, 3c crossing up (2,1,3)

25--::

  1c+3c The Espagnole (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (1819, '2012-01-22 19:29:04.117018+00', '2021-04-05 21:32:19.852463+00', 9455, 1, NULL, 'ace', '1–::

  1M+3W & 1W+3M ½ RH turn and set ; 2c+4c making arches A&R _while{4}_ 1W followed by 1M & 3W followed by 3M dance under an arch and chase cclw to opposite places

9–::

  1M+3W & 1W+3M ½ LH turn and set ; 2c+4c make arches and A&R _while{4}_ 1M followed by 1W and 3M followed by 3W dance under arch and chase clw to own places.

17–::

  2M+4W & 2W+4M ½ LH turn _while{2}_ 1c+3c chase clw one place round the set to join hands across the set | 1M+4W+2M+3W & 1W+4M+2W+3M BiL ; all turn ends in and BiL again.

25–::

  Reels4 across the dance, inside people start outwards

33–::

  4W followed by 4M & 2W followed by 2M, dance clw around outside to own places _while{4}_ 1M followed by 1W & 3M followed by 3W dance RHA to place ; All turn RH.

41–::

  Circle8 and back.



{{explanation}}

Repeat with 2c & 4c as dancing couples.', 2);
INSERT INTO 'dancecrib' VALUES (9279, '2016-07-28 14:54:06.584166+00', '2019-01-30 01:12:23.710914+00', 16301, 2, 160, 'ace', '1-8::

  Top two/bottom two - 4 hands round and back.

9-16::

  Top two/bottom two - R&L.

17-24::

  End cpls turn RH ; cast to the middle (middles step out), 1C 4C set (1L 4M pull  Rsh back).

25-32::

  Chases: 1L leads ptnr out & down around 3C into 3pl. *AS*  4M leads ptnr out & up around 2C into 2pl.

', 0);
INSERT INTO 'dancecrib' VALUES (3189, '2012-01-22 19:30:15.026903+00', '2019-03-22 13:58:44.291691+00', 8463, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1c cross RH, cast off one (2c up) ; ½ Fig8 up around 2c

17–::

  1c down the middle and up

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (8830, '2015-08-12 07:47:13.365153+00', '2015-08-13 09:14:53.613504+00', 16502, 1, NULL, 'ace', '*3c+4c cross on second chord (1,2,3x,4x)*



1--::  1W+2W & 3W+4W set alone | cross, passing between P, and cast around P up/down back to places 

9--::  Men repeat. 

17--::  All A&R; turn P RH into 

25--::  Interlocking Allemande (to 2 4x 1 3x) 

33--::  All A&R ; middle two couples turn RH 1½ (2,4,1x,3x)

', 5);
INSERT INTO 'dancecrib' VALUES (8829, '2015-08-05 11:14:58.788669+00', '2019-01-31 23:46:01.609639+00', 16538, 2, 197, 'ace', '1–4::
  1s+2s+3s set.  1s cross right, 2s+3s half turn with both hands
5–8::
  1s+2s+3s repeat 1-4
9–16::
  1s+2s set and link.  2s+1s RH across
17-24::
  2s+1s+3s dance reels of 3 on own sides, 1s give L shoulder to 3s to begin
25-32::
  1s+3s LH across.  1s ½ turn 3C LH  on sides. 3s + 1s set.
33-40::
  2s+3s+1s circle6 
', 5);
INSERT INTO 'dancecrib' VALUES (1573, '2012-01-20 13:06:12.721555+00', '2019-02-03 21:43:07.030211+00', 12777, 2, 166, 'ace', ' 1-8::

  1C cast behind own lines and cast back to place

 9-16::

  1C cross RH, cast (2C up); dance ½ figure of eight around 2C to face 1cnrs corners

17-24::

  1C turn 1cnrs RH, pass RSh (cnrs dance for {4}); turn 2cnrs RH (same), and cross RSh to (2,1,3)

25-32::

  All circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (9087, '2016-01-30 16:02:24.478035+00', '2019-04-02 20:37:32.885758+00', 12324, 2, 160, 'ace', '1–8::

  1C 1/2 figure 8 round 2C ; 1C 2C Back-to-Back ptnr.

9–16::

  All Set&Link on sidelines ; All Set&Petronella in tandem. 

17-24::

   All Set, dance La Baratte with ptnr.

25-32::

  All dance 1/2 Ladies Chain ; 1C 1/2 fig. 8 round 2C', 0);
INSERT INTO 'dancecrib' VALUES (1575, '2012-01-20 13:06:12.731212+00', '2019-06-01 12:54:34.335194+00', 6443, 2, 1, 'ace', '1-8::

    1s cross down, cast up round 2s, cross R and set.

9-16::

    2s cross up, cast off, cross R and 1s&2s set.

17-20::

    1s followed by 2s lead down the middle.

21-24::

    2s followed by 1s lead up again.

25-32::

    2s and 1s R&L.', 2);
INSERT INTO 'dancecrib' VALUES (11239, '2018-10-02 09:36:02.755266+00', '2018-10-02 09:39:44.751991+00', 18690, 1, 202, 'ace', '1--::

  1c dance between 2c and cast up ; 2c dance to top and cast back to place (1,2,3)

9--::

  1c+2c The Knot (2,1,3)

17--::

  3c dance up between 1c and cast back to place ; 1c dance to bottom and cast back to 2pl centre, on [24] 3c step in (2,1,3)

25--::

  1c+3c Allemande (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11808, '2019-04-25 15:25:08.692297+00', '2019-12-15 21:08:31.061246+00', 14343, 1, NULL, 'ace', '*6-couple set. All couples have M on left.   1c+3c+5c are on M side, 2c+4c+6c om W side   

2W  2M  4W  4M  6W  6M    

1M  1W  3M  3W  5M  5W  

On each time through, only the top four or the bottom four couples are dancing  

the progression of couples resembles the progression of individuals in a normal 2C/3L set*  



1--::

  All set across | 1c+2c & 3c+4c ½ RHA ; All set | 1c+2c & 3c+4c ½ LHA

9--::

  1c+4c ½ diag R&L ; 2c+3c ½ diag R&L 

17--::

  3c+4c+1c+2c cross RH | set to opposite{1} and P {1} ; change place with P | Set to P {1} and opposite {1}

25--::

  Circle8 and back (1c+2c are now in the middle position, 3c+4c at the top)  



*1c+2c repeat with the couples below*', 3);
INSERT INTO 'dancecrib' VALUES (1587, '2012-01-20 13:06:12.789097+00', '2021-02-06 13:04:24.278777+00', 10642, 2, 1, 'ace', ' 1-8::

  1C turn R | cast off (2C up) ; 1C turn L 1¼ to face 1crnrs

 9-16::

  Corners pass & turn, 1C turning ½L at end to fin LS to LS facing opp sides

17-20::

  1M RH across w/3C _while_ 1W RH across w/2C

21-24::

  1M LH across w/2C _while_ 1W LH across w/3C, 1C fin facing 1crnrs

25-32::

  Hello-goodbye setting (1C fin w/petronella turn to 2nd pl own sides)

', 3);
INSERT INTO 'dancecrib' VALUES (3442, '2012-01-22 19:30:25.704332+00', '2016-07-28 21:26:41.502389+00', 6768, 1, NULL, 'ace', '1–::

  3c set advancing and turn R about | 6 bars of DTr

9–::

  3c+1cnrs diag. Reel4 _while{8}_ 1c+2W & 4M+5c Lsh Reels3, at end 3c dance Rsh ¾ round each other to face 2cnrs

17–::

  3c+2cnrs diag. Reel4 _while{8}_ 1c+2M & 4W+5c Rsh Reels3 (1,2,3,4,5)

25–::

  All set | 1c+2c & 3c+4c ½ RHA _while{4}_ 5c turn LH 1/2 ; 1c+4c & 3c+5c ½ LHA _while{4}_ 2c turn RH 1/2 | All set (2,4,1,5,3)', 4);
INSERT INTO 'dancecrib' VALUES (1598, '2012-01-20 13:06:12.842664+00', '2019-09-14 20:37:54.458339+00', 750, 2, 1, 'ace', ' 1-8::

  1C turn R, cast off (2C up) ; 1C turn L to 1cnrs

 9-16::

  1C set to and turn corners BH (fin between corners)

17-24::

  1C dance reels of 3 w/cnrs (starting LS to 1cnr){6} | 1C cross R

25-32::

  Circle6', 3);
INSERT INTO 'dancecrib' VALUES (3877, '2013-08-09 16:11:42.469102+00', '2021-03-26 17:13:54.363177+00', 15055, 1, 1041, 'ace', '_Reel_



1-8:: 1st and 2nd couple lead down the middle and up

9-16:: Poussette (no hands)



_Strathspey_



17-24:: Diamond Poussette

25-32:: Rights and Lefts', 5);
INSERT INTO 'dancecrib' VALUES (10536, '2018-03-20 19:47:06.718432+00', '2018-03-20 19:53:26.993336+00', 7589, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; ½ Fig8 up round 2c (2,1x,3)

9--::

  Mirror Reels3 on sidelines (take NH when possible), 1c start in and down. On [16], 1c turn RH ½ finishing in centre Rsh to partner, 1M(1W) facing up(dn)

17--::

  1c dance out between ends | cast R to 2plx _while{4}_ 2c & 3c set | cross RH, 2c facing 3c at end (to 2x,1x,3x) ; 1c cross RH | cast R, on [24] 1c turn LH ½ to face 1cnrs position _while{4}_ 2c+3c set | change places RH

25--::

  1c ½ Reel4 in 1diag, pass Rsh ; ½ Reel4 in 2diag, cross RH to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1577, '2012-01-20 13:06:12.740839+00', '2021-02-22 11:38:38.075481+00', 9557, 2, 1, 'ace', '1-4::

  1C X down below 2C, cast up _while_ 2C S pulling »lower« shoulder back

  [3-4] to face out

5-8::

  1C turn 2C 1½ w/obvious hand [fin facing out]

9-12::

  1C cast off around 3pl, dance up to 2pl _while_ 2C+3C ½R&L

13-16::

  1C turn BH ⅔ round then S pulling RS back to face 1crnr (in 3crnr''s pl)

  _while_ 2C+3C turn R

17-24::

  1C and 1crnrs ½ reel4, pass L; 1C and 2crnrs ½ reel4, pass L

  [fin facing 1crnr in orig pl]

25-32::

  Hello-goodbye setting fin w/petronella turn to 2pl', 3);
INSERT INTO 'dancecrib' VALUES (1590, '2012-01-20 13:06:12.80345+00', '2014-01-23 22:50:36.115158+00', 8571, 2, 1, 'ace', '1-8::

  1C ½turn RH, fin in ctr facing down | lead down crossing below 3C (2C up) ;

  cast up to 2pl | set

9-16::

  1C+1cnrs adv&ret 1 step on diagonal | 1C+2cnrs repeat ; all dance BtB

17-20::

  1C cross up to 1pl (no hds) _while_ 2C cast off ; 1C+2C ½turn EH

21-24::

  1C cross down to 3pl (no hds) _while_ 3C cast up ; 1C+3C ½turn EH

25-30::

  Reels3 across (1C giving LS to 1cnr to begin)

31-32::

  1W+3W ½turn LH _while_ 1M+3M ½turn RH [to 2,3,1]

', 3);
INSERT INTO 'dancecrib' VALUES (3586, '2012-07-21 11:45:16.538292+00', '2018-10-02 11:49:27.022052+00', 10256, 1, NULL, 'ace', '1–::

  1c cross | cast off (2c up) ; ½ Fig8 to the R (W down M up) at end make fast turn LH ½ to face 3cnr

9–::

  Teapots R, (RHA with 1M up, 1W down) making 2/3 turn, at end the middles (2M & 3W) switch wheels with fast LH turn ; repeat figure (2W+3M switch)

17–::

  repeat figure, at end 1c turn LH ¾ to face M up, W down ; 1c dance out the end and cast L to (3x,1,2x)

25–::

  Diagonal R&L (2,1,3)



{{explanation}}

Note: during the teapots, the dancers not switching dance on at uniform speed', 3);
INSERT INTO 'dancecrib' VALUES (14743, '2022-04-03 10:33:41.529779+00', '2022-04-03 10:43:05.11536+00', 20745, 2, NULL, 'ace', '1-8::

  All set and cross RH with opp person, repeat back to places

9-16::

  All dance DoSiDo with opp person, then dance DoSiDo with partner

17-24::

  All dance RH across, then LH across with opp couple

25-32::

  Top 2 couples take hands in a line across and form arches to dance to the bottom of the set WHILE other couples move up (through arches) ; top 2 couples turn or birl on the sidelines

', 3);
INSERT INTO 'dancecrib' VALUES (1599, '2012-01-20 13:06:12.847444+00', '2021-01-01 18:53:22.059229+00', 13620, 2, 1, 'ace', ' 1-8::

  1+2C set twice ; 1+2C RH across

 9-16::

  1+2C set twice ; 1+2C Circle4 L

17-24::

  1C cross R, cast off (2C up) ; 1C cross L, cast off two pl (3+4C up)

25-32::

  All turn R ; all turn L

', 3);
INSERT INTO 'dancecrib' VALUES (1605, '2012-01-20 13:06:12.875191+00', '2013-07-29 21:07:30.600296+00', 5640, 2, 82, 'ace', ' 1-4::

  1C cross RH and cast 2 places and come in to join RH

 5-8::

  1C lead up to the top, crossing, and cast to 2nd pl

 9-12::

  1M with 3C, 1W with 2C RHA, 1C turning LH at the end ready for

 13-16::

  1M with 2C, 1W with 3C RHA, 1C turning LH at the end to face 1st corners

 17-24::

  1C and 1st corners Reel4, 1C turning LH at the end to face 2nd corners

 25-32::

  1C and 2nd corners Reel4, 1C turning RH at the end to finish in 2nd place.

', 2);
INSERT INTO 'dancecrib' VALUES (10391, '2018-01-19 01:57:39.280701+00', '2020-11-11 12:29:29.920518+00', 17962, 2, 963, 'ace', '1-4::

  1c+2c  ½ R&L, no polite turn  

5-8::

  1c, flwd by 2c, lead down middle  

9-12::

  2c, flwd by 1c, lead back up  

13-16::

  2c+1c set, cross RH to own side  

17-20::

  2c+1c RHA  

21-24::

  2c+1c chase cw once round  

25-32::

  2c+1c circle round and back

', 5);
INSERT INTO 'dancecrib' VALUES (10359, '2017-12-26 20:32:07.92945+00', '2017-12-26 20:40:27.640983+00', 14895, 1, 202, 'ace', '1--::
  1c+2c+3c turn RH ½, face each other | cast R to exchanged places ; all chase clw ½ (3,2,1)
9--::
  3c cross RH | cast to 3plx _while{4}_ 2c+1c set | cross up 1 place, W passing in front of P (to 2x,1x,3x) ; 1c set advancing | turn BH ½ and cast R to face 3cnrs position
17--::
  ½ Reel4 in 1diag, pass Rsh ; ½ Reel4 in 2diag to 2pl (3,1,2)
25--::
  3C Knot (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1708, '2012-01-22 19:28:57.708444+00', '2014-04-30 23:23:39.067978+00', 329, 1, NULL, 'ace', '1–::
  1W+2W+3W cross and dance Rsh round P to place ; turn P RH
9–::
  1M+2M+3M cross and dance Rsh round P to place ; turn P RH, into
17–::
  1c+2c+3c promenade (to 1,2,3,4)
25–::
  1c cross RH | cast to 3pl (2c+3c up), cross RH | on the sides change places LH with 4c (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3215, '2012-01-22 19:30:16.028874+00', '2014-04-30 23:24:09.39181+00', 5921, 1, NULL, 'ace', '{{explanation}}
Couple face couple round the room

1–::
  A&R NHJ ; circle4 L
9–::
  L-Chain
17–::
  Set twice to P ; turn P RH 1½
25–::
  Set to person opposite, cross RH ; set to P, cross LH to face next couple', 3);
INSERT INTO 'dancecrib' VALUES (10465, '2018-02-27 11:20:34.443183+00', '2018-02-27 11:34:49.896817+00', 3170, 1, 202, 'ace', '1--::

  1c+2c S&Link ; RHA, 1c finishing in middle RHJ facing up

9--::

  Reels3 on opposite sides, 1c crossing up to start (2,1x,3)

17--::

  1c dance up between 2c and cast ; ½ diagonal R&L with 3cnrs

25--::

  1c cross RH | 1c cast R round 1cnrs position into facing lines of 3 across ; all dance towards P and loop R to places | all chase clw ¼ to own sides (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (3724, '2013-04-07 22:51:59.116046+00', '2013-07-29 21:07:32.346124+00', 14799, 2, 1, 'ace', '1–::
  1c+2c & 3c+4c set & rotate
9–12::
  2c+1c & 4c+3c RH across
13–16::
  1c+4c LH across
17–::
  Reels of four on the sides (finish 1c facing 2c, 3c facing 4c on sidelines)
25–28::
  1c+2c & 3c+4c turn RH on the sides
29–32::
  1c+4c ½ LH across | 1c+4c cross LH to own sides [2413]', 3);
INSERT INTO 'dancecrib' VALUES (3229, '2012-01-22 19:30:16.588507+00', '2014-04-30 23:24:09.603251+00', 5963, 1, NULL, 'ace', '1–::
  1c cast off 2 , meet below 3c , lead up the middle, cross and cast off (2c up) (2,1x,3)
9–::
  1c+3c circle4 L ; 2c+1c 4-bar R&L, 1c finish facing 1cnrs
17–::
  1c set to and turn corners (2,1x,3) to face 1cnr
25–::
  Lsh Reels3{6} on opposite sides | 1c cross to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9957, '2017-06-15 10:02:01.722957+00', '2018-03-25 11:51:21.556097+00', 15302, 1, 202, 'ace', '1--::

 1c set | cross RH ; cast to 2plx (2c up) | all set (2,1x,3)

9-20::

 3C R&L (2,1x,3)

21-24::

 1c ½ Fig8 R (2,1,3)

25--::

 Cnrs Pass&Turn, 1c starting from sidelines (2,1,3)

33--::

 Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (14241, '2021-08-15 08:50:23.056112+00', '2021-08-15 08:57:14.514843+00', 14383, 1, 202, 'ace', '1--::

  2C Set&Rotate (2,1,3)

9--::

  1c set advancing and face 1cnrs | turn 1cnrs BH into lines3 across. 1c face 4cnrs ; ½ Reels3 across, 1c LSh to 4cnrs into facing lines3 across

17--::

  1c set advancing and face 3cnrs[pos] | turn 3cnrs[pos] BH into lines3 across. 1c face 2cnrs[pos] ; ½ Reels3 across, 1c LSh to 2cnrs[pos] into facing lines3 across

25--::

  3C S&Link (to 2x,1x,3x) ; all set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14146, '2021-07-15 08:10:41.434917+00', '2021-07-15 08:24:04.900484+00', 13797, 1, 1645, 'ace', '1-::
  All set | 1c & 4c cast inwards as 2c/3c cross LH/RH to ends (2x,1,4,3x) ; 1c/4c &frac12; Fig8 round 2c/3c (2x,1x,4x,3x)
9-::
  2c+1c & 4c+3c bars 1-6 of standard Tourbillon | then set facing up/down (1,2,3,4)
17-::
  Reels4 on the sides
25-::
  1c+2c & 3c+4c turn 1&frac12; RH on sides ; 1c+4c turn 1&frac12; LH on sides (2,4,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (1594, '2012-01-20 13:06:12.823372+00', '2022-01-29 01:41:10.062156+00', 5891, 2, 1, 'ace', ' 1-4::
  1C set | cast off (2C up)
 5-8::
  2C+1C+3C turn R (1C fin facing women''s side w/NH joined, 2C+3C fin in sidelines)
 9-16::
  Mirror Reels3 across the dance (1C dancing out women''s side to begin). Fin by 1C casting to R into 2pl own sides, 2C+3C dancing long way round
17-20::
  All adv&retire (1 step) | all set
21-24::
  1C turn R
25-32::
  Circle6 round & back
', 3);
INSERT INTO 'dancecrib' VALUES (3227, '2012-01-22 19:30:16.509768+00', '2022-01-29 17:47:23.722782+00', 7511, 1, NULL, 'ace', '1–::

  1c+2c R&L

9–::

  1c turn RH | cast (2c up) ; turn LH 1¼

17–::

  Opposing Reels3 across, Lsh to 1cnr

25–::

  2c+1c+3c A&R ; dance BtoB', 2);
INSERT INTO 'dancecrib' VALUES (14605, '2022-02-10 09:39:06.075525+00', '2022-02-11 10:16:50.32902+00', 20663, 1, 202, 'ace', '1--::

  1c cast behind own lines ; turn outwards and dance up to places (1,2,3)

9--::

  Mirror Reels3 on sides, 1c in and down (1,2,3)

17--::

  1c turn 2c EH ½ on sides | 2c+1c+3c BiL ; turn 3c EH ½ | 2c+3c+1c BiL (2,3,1)

25--::

  1c dance up to top | cast off _while{4}_ 3c pivot (3M to the L and 3W to the R with 2 PdB)  and face in | step down ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15162, '2022-10-07 15:56:41.791994+00', '2022-10-09 16:18:06.533145+00', 21138, 1, 202, 'ace', '1--::

  1c & 4c set | cast inwards (2c & 3c step out) (to 2,1,4,3) ; cross RH | cast out one place (2c & 3c step inwards) finishing as for Reel4 positions (1x,2,3,4x)

9--::

  *Modified Set to Corners and Cast Away* : same as Set to Corners and Cast Away but on sidelines instead of diagonal line (4x,3,2,1x)

17--::

  Reels4 on sides (4x,3,2,1x)

25--::

  4c (4M leading) & 1c (1W leading) chase clw ½ to exchanged places (to 1,3,2,4) ; 1c+3c & 2c+4c ½ RHA. All retain RH with P | all turn P RH 1½ (3,1,4,2)', 4);
INSERT INTO 'dancecrib' VALUES (3723, '2013-04-07 21:02:23.859012+00', '2013-07-29 21:07:31.400448+00', 7563, 2, 1, 'ace', '1–4::
  1c+2c dance ½ double fig of 8 (1c cross down, 2c cast up to begin)
5–8::
  1M+2M turn LH _while_ 1L+2L turn RH
9–::
  1c+2c+3c dance Inveran reels (1c crossing from opp sides to begin)
17–20::
  1c+2c dance ½ double fig of 8 (1c cross down, 2c dance up to begin)
21–24::
  1M+2M turn RH 1½ times _while_ 1L+2L turn LH 1½ times (1c fin ready for DT)
25–::
  2c+1c+3c dance Double Triangles', 3);
INSERT INTO 'dancecrib' VALUES (14558, '2022-01-19 01:21:50.61881+00', '2022-05-06 20:39:23.590907+00', 6264, 1, 1645, 'ace', '1--::

  All set | turn P BH ; 1c & 3c cross in LH, 1M+3W & 3M+1W cross RH out through 4c/2c & cast to longwise set (Mside: 3W,4M,4W,1M; Wside: 3M,2W,2M,1W)

9--::

  All A&R{1+1} | cross RH ; Circle8 &frac12; way to L (Mside: 1M,4W,4M,3W; Wside: 1W,2M,2W,3M)

17--::

  M full diag R&L starting diag to R _while{8}_ 1W+4W & 2W+3W set | cross RH ; repeat & face up/down on sides

25--::

  &frac12; RSh Reels4 on sides ; turn facing person 1&frac14; RH to lines across

33--::

  &frac12; RSh Reels4 across ; turn facing person 1&frac14; RH to sidelines (Mside: 3M,2W,2M,1W; Wside: 3W,4M,4W,1M)

41--::

  W full diag R&L starting diag to L _while{8}_ 3M+4M & 2M+1M set | cross RH ; repeat & all face in

49--::

  All A&R{1+1} | cross RH ; Circle8 &frac12; way to L ending in square set (1,4,3,2)

57--::

  4c & 2c cross in LH, 4M+2W & 2M+4W cross RH out through 1c/3c & cast to original pl ; all turn P BH | set (1,2,3,4)

', 2);
INSERT INTO 'dancecrib' VALUES (3280, '2012-01-22 19:30:18.797425+00', '2015-05-01 20:56:59.504914+00', 6152, 1, NULL, 'ace', '1–::

  1c+2c circle4 to the left ; 1c set | cast off (2c up)

9–::

  1c+3c RHA ; LHA, 1c finish facing 1cnrs

17–::

  1c set to and turn corners, finish facing 1cnrs

25–::

  Reels3{6} with cnrs (Lsh to 1cnr), 1c cross RH (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (10360, '2017-12-26 21:59:27.666406+00', '2017-12-26 22:02:24.805531+00', 14897, 1, 202, 'ace', '1--::

  Mirror Reels3, 1c crossing down to start (1x,2,3)

9--::

  »Modified Espagnole up/down«, 1c lead down to start, on [13-16] all turn EH 1 ½ (2x,1,3)

17--::

  Mirror Reels3, 2c crossing down to start (2,1,3)

25--::

  1c cast up, dance down to between 3c ; turn 3c EH to sidelines (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2518, '2012-01-22 19:29:45.97041+00', '2017-04-27 21:05:32.325406+00', 11890, 1, NULL, 'ace', '1–::

  Reels3 on the sides, 1c cross down to start (1x,2,3)

9–::

  1c dance down the middle, 1W with 1M following cast round 3M (2c up) to midline W above M (touch NH) ; 2c+1W LHA _while{4}_ 1M+3c RHA

17–::

  1c dance out W side, cast L round 2W and down the middle NHJ, M on left ; Hands across with cnrs (1M LHA, 1W RHA)

25–::

  1c NHJ set to 3c and turn inwards | set to 2c ; 1c cross up and cast to 2pl. (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3577, '2012-05-29 00:40:45.360089+00', '2020-05-15 13:37:21.969369+00', 5120, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c DblFig8, 1c & 4c cast to start (1,2,3,4)

9-12::

  1c cast to 3pl | turn BH and face down _while{4}_ 3c turn BH to face up | dance up between 2c

13-16::

  1c dance between 4c | cast up to 3pl _while{4}_ 3c cast off to 3pl | turn BH and face down

17-20::

  1c turn BH and face up | dance up between 2c _while{4}_ 3c dance down between 4c | cast up to 3pl

21-24::

  1c cast to 3pl | turn LH to face 2cnrs _while{4}_   3c turn BH to face up | dance to top (3,2,1,4)

25–::

  1c+2cnrs Pass&Turn, 1c turning R to face 1cnr ; 1c+1cnrs Pass&Turn , finish (3,2,1,4)

33–::

  All set | 3c+2c & 1c+4c RHA | 3c cast off _while{2}_ 2c dance up and 1c dance down and 4c cast up (2,3,4,1)



{{explanation}}

Note: On [9-24] 1c & 3c both repeat the sequence »cast-turn-dance« for eight segments, starting at different points. Good phrasing is required on [11], [17] and [23] when 3c dances away from 3pl as 1c comes in to turn.', 3);
INSERT INTO 'dancecrib' VALUES (8246, '2014-04-22 22:03:03.79337+00', '2016-08-09 15:35:19.540641+00', 15425, 1, NULL, 'ace', '1--::

  1c cross down and dance between side couples into Fig8 round them,  to (1x,2,3,4) 

9--::

  1c set | turn BH ½ and face 3c ; 1c+3c ½ R&L into lines across facing side cpls (no polite turns) 

17--::

  Parallel Reels4 across, on [24] 1c+3c turn LH ½ for

25--::

  1c+3c LHA ¾  (1c face 4c & 3c face 2c) ; 1c+3c pass opposite Rsh and chase clw to own place

33--::

  Circle8 and back (1,2,3,4)

Repeat 3 times, with 2c, 3c, 4c starting in turn

', 4);
INSERT INTO 'dancecrib' VALUES (3240, '2012-01-22 19:30:17.050162+00', '2014-04-30 23:24:09.814909+00', 8830, 1, NULL, 'ace', '1–::
  1c set and cross RH ; Set | turn RH to face down NHJ
9–::
  1c set | dance down just over 2 ; 1M+3M+4M RHA and 1W+3W+4W LHA, 1c finish as started
17–::
  1c set, turning in and face up | dance up 1 ; 1M+2M+3M LHA and 1+2W+3W RHA, 1c finish as started
25–::
  1c dance up and cast to 4pl (2c+3c+4c up) ; All A&R', 3);
INSERT INTO 'dancecrib' VALUES (10464, '2018-02-27 08:08:19.432783+00', '2018-02-27 12:34:19.17192+00', 6643, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; 1c ½ Reels3 on opposite sides, 1c crossing down to start (3,1x,2)

9--::

  3c+1c ½ Double Fig8 (1c cross to start) ; 1c+2c ½ Double Fig8 (1c cross to start) (3x,1x,2x)

17--::

  1c turn P 1 ¼ ; 1M+3c & 1W+2C RHA (3x,1x,2x)

25--::

  All chase clw ½ to own sides, 3W & 2M leading ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2954, '2012-01-22 19:30:04.37718+00', '2017-04-27 21:04:34.840694+00', 9503, 1, NULL, 'ace', '1–::

  1c set | cast off ; dance between 3c and cast up to finish LHJ to P and RHJ to 1cnr

9–::

  1c + cnrs dance the spoke.

17–::

  1W+2c & 1M+3c ½ Reels3 across, 1c start Lsh to 1 cnr ; 1c ½ Reels3 on opp side (Rsh to 2cnr pos), 1c finish facing 3cnr positions and 2c + 3c curve into place.

25–::

  1c ½ Diag Reel4 with 1cnrs, pass Lsh to face 4cnr position ; ½ Diag Reel4 with 2cnrs, to (2,1,3).

33–::

  All Circle6 and back.', 2);
INSERT INTO 'dancecrib' VALUES (14744, '2022-04-03 10:53:36.350682+00', '2022-04-03 10:55:37.993391+00', 1064, 1, 1645, 'ace', '1-::

  1c &frac12; turn RH & face down _while_ 2c dance up sides | 1c followed by 2c  dance down ; 2c followed by 1c dance up | 2c cast off _while_ 1c dance up & curve into pl (1x,2)

9-::

  1c+2c L-Chain ending in prom hold, 1c facing down, 2c facing up, 3c step in & take promhold

17-::

  LSh Reel3 in promhold, end after 7 bars facing P in centre, retire{1} to sides (1x,2,3)

25-::

  All set | cross RH (1,2x,3x) ; set | 1c cast off _while_ 2c cross up RH _while_ 3c cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2158, '2012-01-22 19:29:23.08565+00', '2016-11-15 15:38:51.407411+00', 1909, 1, NULL, 'ace', '1–::

  1c set | 1M casts off (2M up) ; crosses and turns 3W RH to stand between 2W and 3W

9–::

  1W+2M set, 1W casts off (2W up) ; turns 3M RH | 1c cross RH (2,1,3)

17–::

  2c+1c+3c circle6 and back

25–::

  1c+2c R&L', 3);
INSERT INTO 'dancecrib' VALUES (13651, '2021-02-07 18:59:37.899138+00', '2021-02-07 19:03:44.294036+00', 17972, 1, 202, 'ace', '1--::

  1c+2c The Espagnole. 1W face out and down (2,1,3)

9--::

  1c+3c turn RH twice on sides ; 1c+2c turn LH twice on sides (2,1,3)

17--::

  Parallel Reels3 on sides, 1c RSh to 3c. Crns loop to places where appropriate (2,1,3)

25--::

  1c+3c »Maurice progression« [: 1M+3W dance BtoB _while{4}_ 1W & 2M cast off one place {1}, advance to centre, meet and face P {1}, advance as P retire {2} into 1diag, ready for ; ½ Poussette] (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (9467, '2016-11-08 15:45:14.073251+00', '2016-11-08 15:45:14.073251+00', 17480, 1, NULL, 'ace', '1--::

  1M with 1W following cast off | cross below 2c ; cast off | cross to 3pl (2c+3c up) (2,3,1)

9--::

  3c+1c RHA ; LHA (2,3,1)

17--::

  1W with 1M following cast up | cross above 3c ; cast up | cross to 1pl (2c+3c down) (1,2,3)

25--::

  1c+2c turn RH 1½ on side ; 1c+3c turn LH on side (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9069, '2016-01-13 10:21:15.861709+00', '2017-04-28 13:21:40.414625+00', 8371, 1, NULL, 'ace', '1--::

  1c set and cast (2c up) ; 1c+1cnrs dance BtoB (2,1,3)

9--::

  2c+1W & 1M+3c RHA ; ½ Reels3 across, Rsh to 1cnr, 1c finish facing out on own side (2x,1,3x)

17--::

  1c cast round 3cnr into facing lines across ; 1c +1cnrs (in 4cnr pos) dance BtoB

25--::

  1M+2W+3W & 1W+2M+3M RHA ; ½ Reels3 on the sides, Rsh to 4cnr (3x,1,2x)

33--::

  1c dance down between 2c and cast up while{4} 3c+2c ½ R&L starting along the sides ; All turn P RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (14815, '2022-05-07 22:14:19.663045+00', '2022-05-07 22:14:41.123189+00', 15733, 1, 1645, 'ace', '1--::

  1c+2c+3c Circle6 to L and back, 1c & 3c end in the middle facing down/up

9--::

  1c cross down into mirror Reels3 on opp sides

17--::

  1c cross down into mirror Reels3 on own sides, 1c & 3c end NHJ in the middle facing down/up

25--::

  1c set | set advancing to 3c (2c up) _while{4}_ 3c set twice ; 1c+3c RHA (2,1,3)



', 2);
INSERT INTO 'dancecrib' VALUES (3747, '2013-05-23 12:27:07.486829+00', '2022-12-20 12:37:30.174513+00', 13627, 1, NULL, 'ace', '1–::

  1c dance (touch hands) between 2c, behind 3c (2c up) ; meet and dance up NHJ | W dances under P''s arm, and face down in promhold

9–::

  1c with 2W+3M Rsh Reel3

17–::

  1c with 2M+3W Lsh Reel3, on [24] 2c+3c dance to centre and face up in promhold

25–::

  Circulating Allemande : All dance as in a 3c Allemande, 1c starting down and crossing to own side RH on [31-32] (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (1801, '2012-01-22 19:29:03.018791+00', '2017-07-07 13:56:58.672107+00', 654, 1, NULL, 'ace', '1–::

  1c+2c+3c Mirror Reels3 on opposite sides, (1c crossing down)

9–::

  Mirror Reels3 on own sides

17–::

  1c cross down RH, cast down behind 3c, lead up, cross at top and cast to 2pl (2c up)

25–::

  2c+1c+3c Circle6 and back

33–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (10582, '2018-04-05 13:00:15.054166+00', '2022-10-10 15:42:48.055296+00', 18275, 1, 202, 'ace', '1--::

  2c Fig8 R, Lsh to 1cnrs (1,2,3)

9--::

  Reels3 on sidelines, 2c start Lsh to 3cnrs (1,2,3)

17--::

  2c dance down with a loop to 3pl _while{2}_ 3c continue the reels to 2pl (to 1,3,2) | 3c turn RH 1¼ into midline ; 3M+1c & 3W+2c LHA

25--::

  3M+2c & 3W+1c RHA ; Lsh Snake Pass [unwind the RHA, 3c leading, pass other snake Lsh through 2plx and chase cclw] (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (9162, '2016-06-11 14:16:12.977641+00', '2021-08-16 22:50:10.971463+00', 17021, 1, NULL, 'ace', '1--::

    1c set adv past 2c | 1c+3c turn BH ; all &frac12; LSh Reels3 on sides (3,1,2)

9--::

    All S&Link3 but 3M & 2W turn LH to centre facing corners they just left ; 1c lead path of snake pass to end in 1st corner pos (M side: 1W,3M,2M; W side: 3W,2W,1M)

17--::

    Repeat 9-16 from new places (M side: 2W,1W,2M; W side: 3W,1M,3M)

25--::

    Modified bourrel: 2W+1M & 1W+3M set advancing | full turn BH _while{4}_ 3W & 2M chase &frac12; way cclw ; all set to P up/dn centre | turn BH to sides (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (3746, '2013-05-23 12:04:20.74128+00', '2013-07-29 21:07:34.242496+00', 14891, 2, 106, 'ace', 'Original description added at the author''s request

1- 8::

  All 4 couples dance eight hands round and back.

9-16::

  All 4 couples promenade round to original places.

17-24::

  1st man and 3rd woman dance a figure of eight round 2nd couple, while 1st woman and 3rd man dance a figure of eight round 4th couple. 

25-32::

  2nd man and 4th woman dance a figure of eight round 3rd couple, while 2nd woman and 4th man dance a figure of eight round 1st couple.

33-40::

  1st and 3rd couples dance half rights and lefts; they continue to dance half rights and lefts with 2nd and 4th couples as in grand chain.

41-48::

  All 4 women dance  right hands across half way round; they set to and turn partners once round.

49-56::

  2nd and 4th couples repeat bars 33-40.

57-64::

  All 4 men dance left hands across and repeat bars 41-48

65-72::

  All 4 women cast by the right and dance outside the set back to original places; dance in front and round partner’s place.

73-80::

  All 4 men cast by the left and repeat bars 65-72.

81-88::

  All 4 couples dance eight hands round and back.



', 5);
INSERT INTO 'dancecrib' VALUES (10042, '2017-08-11 14:50:47.802636+00', '2017-08-11 18:00:26.748637+00', 17890, 2, 202, 'ace', '1-8:: 1s followed by 2s, 3s and 4s cast to the bottom of the set, meet partner and dance up. On bar 8, 1s and also 3s turn towards each other and face down, to end all up/down the middle, 1s facing 2s and 3s facing 4s
9-16:: 1s+2s and 3s+4s dance “The Rondel” (2s, 1s, 4s, 3s)
17-20:: 2s and 1s turn partner with both hands and face up
21-24:: 2s and 1s, facing up, set using HS setting step _WHILE_ 4s and 3s turn partner with both hands and face up
25-28:: 2s, followed by 1s, cast to 4th and 3rd place _WHILE_ 4s, followed by 3s, dance up to 1st and 2nd place and set to the right, using HS setting step
 29-32:: 4s and 3s complete the HS setting step; 4s, followed by 3s, cast to 2nd and 1st place (3s, 4s, 1s, 2s)
33-40:: 4s+1s dance “The Ring”
41-48:: 8H round and back

*The Ring formation:*
1-2:: Pass partner RSh and turn right to face partner in the middle
3-4:: Pull back RSh and dance to opposite sides, ladies facing up and men facing down
5-8:: Chase ½ way (3s, 1s, 4s, 2s)', 3);
INSERT INTO 'dancecrib' VALUES (3751, '2013-05-27 22:25:59.046773+00', '2018-10-17 11:33:40.020073+00', 14909, 1, NULL, 'ace', '1–::

  1c cross down RH (2c up) | change place with 3c EH (2,3,1x) ; 1c dance up NHJ and turn 2c EH (3c down) (2,1x,3)

9–::

  Reels3 across, 1c Rsh to 4cnr (2,1x,3)

17–::

  2c+1M & 1W+3c RHA ; 1c ½ Fig8 L (W up, M down) (2,1,3)

25–::

  1c+3c Espagnole (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (9280, '2016-08-11 16:36:26.806289+00', '2016-08-11 16:36:26.806289+00', 17152, 2, NULL, 'ace', '1- 8::

  1C set and cast one place. 1C set. 1M casts off to between 3C while 1L casts up to between 2C

9-16::

  1C dance reels of 3 across – begin by passing person on their right by RS and finish facing 1st corners

17-24::

  1C set to corner and pull RS back to face partner across the dance. 1C turn 3/4 RH to face 2nd corners. Repeat with 2nd corners – set to finish facing partner up and down the set, turn 3/4 RH to 2nd place

25-32::

  ‘Corners pass and turn’   1C cross RH and dance out to their right to pass 1st corners RS, dance in the ends and cross RH, loop out round 2nd corners RS and cross RH to 2nd place while 1st corners and then 2nd corners dance in, turn RH and back to place



', 3);
INSERT INTO 'dancecrib' VALUES (3743, '2013-05-23 10:55:06.515178+00', '2013-07-29 21:07:34.17876+00', 13223, 2, 106, 'ace', 'Original description added at the request of the author

1- 4::

  1st couple, giving right hands, cross over and cast off to second place, 2nd couple step up on bars 3-4.

5- 8::

  1st couple dance a half figure of eight round 2nd couple.

9-16::

  1st couple dance reels of three on the opposite side with 3rd and 4th couple.

17-20::

  1st couple lead up to the top, cross over and cast off to second place.

21-24::

  2nd and 1st couples dance right hands across once round.

25-32::

  1st, 3rd and 4th couples poussette.

::

  Repeat, with a new top couple.



', 5);
INSERT INTO 'dancecrib' VALUES (13545, '2021-01-09 23:27:47.511657+00', '2021-01-09 23:28:34.870541+00', 603, 1, 1645, 'ace', '1--::

  1c+2c RHA ; LHA back

9--::

  *Modified Bourrel:* 1M+2W turn &frac23; RH to face up/down | set pulling RSh back to end BtoB facing P

  _while{4}_ 1W & 2M chase &frac12; way cclw to centre line facing P; set to P | turn &frac34; RH (2,1,3)

17--::

  2c+1c+3c Reels3 on own sides, 1c start RSh to 3cnr & end BtoB facing own sides

25--::

  DTr (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3515, '2012-01-22 19:30:28.72744+00', '2021-10-11 22:47:24.092331+00', 7055, 1, NULL, 'ace', '1–::

  1c+2c+3c mirror Reels3 on opposite sides (1c cross down, 2c out and up)

9–::

  Repeat, 1c now to own sides

17–::

  1c lead down ; and up to top to face 2c from the middle diagonally

25–::

  1c set to 2c | dance to the bottom (2c+3c+4c up) and turn inwards into ; 4c+1c Circle4 L (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2021, '2012-01-22 19:29:15.338759+00', '2019-06-11 21:34:48.74359+00', 1465, 1, NULL, 'ace', '1–::

  1c+2c+3c mirror Reels3 on the sides (2c start out and up)

9–::

  1c+2c DblFig8 (1c start crossing down)

17–::

  1c cross down to 3plx & cast up to 2plx _while_{4} 2c set+cross down to 3plx _while_{4} 3c cast up to 1pl and cross ; all turn RH (3x,1x,2x)

25–::

  3c+1c+2c S&Link twice', 2);
INSERT INTO 'dancecrib' VALUES (1633, '2012-01-22 19:28:52.109469+00', '2014-11-10 22:17:43.013373+00', 11195, 1, NULL, 'ace', '1–::

  1M promenades cclw inside set, first with 1W | 1M drops 1W taking 4W ; drops 4W taking 3W | drops 3W take 2W, all finish facing cnr

9–::

  All set adv | Turn cnr BH into cross, M outside, all facing clw ; ½ RHA, at end W move out to face M in the centre (W are one place clw from start, M 1 place cclw)

17-20::

  All pairs R.elbow pivot turn, to same places ;

21-32::

  Intersecting Rsh Reels4, using ½ LHA {2} in the centre, to same places

33–::

  All M SetH&G , finish next to P, facing out

41–::

  4c L-Chain, giving RH in centre. (4,1,2,3)', 3);
INSERT INTO 'dancecrib' VALUES (10537, '2018-03-20 20:04:41.166345+00', '2018-03-20 20:12:42.483283+00', 7681, 1, 202, 'ace', '1--::

  All set | 1c, all following, dance down the middle and cast up to places

9--::

  1c & 4c set | cast inwards (2c & 3c step out) ; 1c & 4c ½ Fig8 up/dn (2,1x,4x,3) 

17--::

  1c+4c Circle4 L ; ½ R&L (no polite turn), finishing in Reel4 position (2,4,1,3)

25--::

  Parallel Reels4 (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2185, '2012-01-22 19:29:24.543524+00', '2016-11-15 15:40:11.385523+00', 2004, 1, NULL, 'ace', '1–::

  1c+2c+3c set and cross RH ; repeat

9–::

  1c lead down the middle and up

17–::

  1c set | cast off (2c up) ; turn RH

25–::

  2c+1c+3c Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (14400, '2021-10-26 14:36:53.105313+00', '2022-04-05 12:41:07.470723+00', 20143, 1, 202, 'ace', '1--::
  1c Fig8 on sides, starting in (1,2,3)
9--::
  R&L (1,2,3)
17--::
  1c dance down ; and up. 1c face out (1,2,3)
25--::
  1c+2c turn on sides EH 1½ ; 1c+3c turn on sides EH 1½ (2,3,1)

*Deviser''s note* : May be danced as jig or reel.', 3);
INSERT INTO 'dancecrib' VALUES (10363, '2017-12-27 22:25:34.512301+00', '2018-07-18 03:26:49.960583+00', 14903, 1, 202, 'ace', '1--::
  1c turn RH | cast (2c up) ; 1W+2c & 1M+3c RHA, 1c facing 1cnrs at end
9--::
  Corners Pass and Turn, on [16] 1c pull Rsh back to finish BtoB in centre facing opposite side
17--::
  DTr, on [23-24] 1c Petronella turn to 2pl (2,1,3)
25--::
  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11506, '2019-01-09 23:51:36.105244+00', '2019-01-09 23:51:36.105244+00', 15402, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 1c turn P RH _while{4}_ 2c+3c set and turn P RH ½, all into Allemande hold facing down

9--::

  3C Allemande, finish (3x,1x,2x)

17--::

  S&Link3 into lines across ; All turn opposite dancer BH

25--::

  S&Link3 to sidelines ; All turn P BH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10538, '2018-03-20 20:43:41.155006+00', '2019-10-19 12:25:37.561606+00', 17529, 1, 202, 'ace', '1--::
  1c set | lead down {4} | set turning inwards to face up
9--::
  1c lead up between 2c, cross and cast to 2plx (2c up) | 1c turn LH to face 1cnrs
17--::
  1c Set to and Turn cnrs (2,1x,3)
25--::
  All A&R ; 2c & 3c turn RH _while{4}_ 1c turn RH 1 ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1632, '2012-01-22 19:28:52.010642+00', '2015-02-27 17:36:20.170889+00', 10113, 1, NULL, 'ace', '1–::

  1c+2c+3c circle6 and back.

9–::

  2c dance up one | cast off ; dance down one | cast up to face 1cnr

17–::

  2c cnrs pass and turn (change pl. Rsh with 1cnr who turn RH | change back, 2c passing Rsh to face 2cnr ; repeat with 2cnr, 2c finishing in own place) (1,2,3)

25–::

  3-couple knot, but on [31-32] 1c finish in 3pl _while_{2}    2c+3c dance ½ LHA (to 2,3,1) (this figure is the slipknot).', 3);
INSERT INTO 'dancecrib' VALUES (1732, '2012-01-22 19:28:58.905097+00', '2018-08-07 21:00:31.55564+00', 428, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; turn LH 1½ and face out (2,1x,3)

9–::

  1c dance cclw half round the set _while_ 2c+3c RHA (2,1,3) ; 1c turn LH 1¼ to face 1cnr _while_ cnrs chase ½ clw (3x, 1 in middle, 2x)

17–::

  1c ½ Reel4 with 1cnrs pass Rsh ; ½ Reel4 with 2cnrs (2,1,3)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (1635, '2012-01-22 19:28:52.202549+00', '2014-04-30 23:23:37.534201+00', 74, 1, NULL, 'ace', '1–::
  1c set | cross RH ; 1c+2c S&Link (2,1x,3)
9–::
  2c+1c set | Petronella in tandem and face P up/dn ; S&Link (1M face up, 2M down)
17–::
  Reel4 on the midline (at start W pass Lsh), at end 2W+1M & 2M+1W chance places RH, still on midline
25–::
  2W+1W turn LH  _while_{4}   1M+2M chase clw ½ round ; 2c Turn RH 1¾ to 1pl  _while_{4}    1c turn RH 1¼ moving to 3pl  (3c step up on [31-32] (2,3,1)

{{explanation}}
Note: this 2c dance is danced in a 3c set to give space for the reel on the midline.  Alec Hay prefers no hands to be held during »linking«.', 3);
INSERT INTO 'dancecrib' VALUES (1634, '2012-01-22 19:28:52.15863+00', '2014-10-23 15:52:39.060861+00', 68, 1, NULL, 'ace', '1-16::

  1c turn RH ½ moving down to face P (2c up) | set swiveling R to face 1cnr ; Dance to Each Corner and Set {12} (every 2 bars: free cnrs set _while{2}_ centres & cnrs pass Rsh plus a Rsh pass in the centre to face the cnr to the R). Finish cnrs in diagonally opposite place and 1c facing 3cnr (pos.),

17--::

  1c+3cnr turn RH ¾ & face diagonally |  set NHJ ; all four RHA ¾, 1cnrpersons to places, 1c to 2pl facing out

25--::

  1c+4cnr turn LH ¾ & face diagonally | set NHJ ; all four LHA ¾ (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12486, '2020-01-07 09:24:00.439685+00', '2020-01-07 18:10:58.618395+00', 13544, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; ½ Fig8 L round 4cnrs. 1c face 1cnrs (2,*1*,3)
9--::
  2 bars of SetH&G (to 2,1x,3) | turn P LH ¾ and face 1cnrs ; ½ Reel4 on 1diag, pass LSh to face 2cnrs
17--::
  2 bars of SetH&G | turn P LH ¾ and face 2cnrs ; ½ Reel4 on 2diag to 2plx (3x,1x,2x)
25--::
  ½ Reels3 on sides, 1c LSh to 1cnrs[pos] ; ½ Reels3 across, 1c LSh to 3cnrs[pos]', 2);
INSERT INTO 'dancecrib' VALUES (2296, '2012-01-22 19:29:30.393975+00', '2016-11-15 15:42:15.522065+00', 695, 1, NULL, 'ace', '1–::

  1c set and cross RH, 1c+2c S&Link, 2W+1W finish facing out. (2,1x,3)

9–::

  2c+1c M-Chain.

17–::

  1c ½ Fig8 L (Rsh to 4cnr) ; All turn RH (2,1,3)

25–::

  All Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10046, '2017-08-16 14:06:02.329342+00', '2017-08-16 14:06:02.329342+00', 6521, 1, NULL, 'ace', '1--::

  1c+2c R&L, at end 1M+2W face out

9--::

  Reel3 on the sides, start 2c Rsh to 3c (1,2,3)

17--::

  1c cross RH | 1c cast to 2plx as 2c dance up ; 2c cast off as 1c cross up | 1c (starting out) turn 2c EH ½ on the sides (2,1,3)

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8117, '2013-11-19 15:38:58.21725+00', '2013-11-19 15:38:58.21725+00', 6959, 3, NULL, 'ace', '1- 8::

  All Adv+Ret, all advance & cross over with Ladies dancing under Mens arches

 9-16::

  Repeat back to places but Men dance under Ladies arches

17-24::

  1s Slip-Step down to bottom & back again

25-32::

  1s followed by 2s+3s+4s+5s cast & 1s make an arch at bottom as 2s+3s+4s+5s dance up under arch.  2 3 4 5 1

33-48::

  2s+3s+4s+5s face & dance down as 1s dance up under 5s arch as 5s dance down over them & 1s dance over 4s & ‘under & over’ to top etc & as all reach bottom/top they turn about & dance up/down ‘under & over’ back to places 2 3 4 5 1  

', 0);
INSERT INTO 'dancecrib' VALUES (8740, '2015-03-19 23:56:39.127701+00', '2015-03-20 00:03:05.094998+00', 16176, 1, NULL, 'ace', '1--::

  In circles of four, NHJ, A&R twice to centre, raising hands and shouting ‘Ildikó‘ on [2] and [6]

9--::

  All W dance round P holding hands ; M repeat

17--::

  All dance BtoB with opposite ; turn opposite RH

25--::

  All A&R with opposite ; change places RH, with the next opposite LH, and join next couple.

', 3);
INSERT INTO 'dancecrib' VALUES (9956, '2017-06-13 23:17:38.688351+00', '2021-07-30 07:53:57.365+00', 3201, 1, 202, 'ace', '1--::

 1M+2W & 4M+3W cross RH | 2M+1W & 3M+4W cross LH (to 2x,1x,4x,3x) ; 1c+4c ½ R&L (2x,4,1,3x)

9--::

 Parallel Reels4

17--::

 4c+1c RHA ; 2c+4c & 1c+3c LHA

25--::

 4c & 1c ½ Fig8 up/dn (to 2x,4x,1x,3x) ; all turn P RH 1 ½ (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1658, '2012-01-22 19:28:53.431538+00', '2014-04-30 23:23:38.017953+00', 152, 1, NULL, 'ace', '1–::
  1c cast | cross up between 2c ; cast to 2plx (2c up) | set advancing to finish BtoB facing opposite sides
9–::
  Inverted triangles (in PdB: set as in DTr | 2c+3c advance in and 1c out, all face R about ; set as inverted DTr | advance back, 1c to face 1cnr)
17–::
  1c turn 1cnr RH, pass P Rsh ; turn 2cnr LH | 1c pass RH
25–::
  Reels3{6} across the dance, Rsh to 4cnr | 1c cross RH.

{{explanation}}
(on 2nd time through 1c cross to 4pl as 4c cast up).', 3);
INSERT INTO 'dancecrib' VALUES (9693, '2017-03-31 10:15:10.303255+00', '2020-12-29 12:14:45.010611+00', 17686, 1, 202, 'ace', '1--::

  Mirror Reels3 on the sides, 1c crossing down to start

9--::

 Repeat, 1c crossing back to own sides

17--::

 1c long cast to 3pl (2c+3c up) ; 1c set | cast (4c up)

25--::

 All set | A&R{4} | set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13662, '2021-02-13 09:42:30.341122+00', '2021-05-07 21:43:17.185784+00', 17958, 1, 202, 'ace', '_Strathspey_
1--::
  All advance {2} | retire with cnrs {2} and face P ; turn P RH ¾, all W BtoB in centre facing P in original place centre
9-24::
  *Double Celtic Reel* : pass P RSh | "outsides" chase clw ¼ _while{2}_ "insides" dance LSh cclw ¾ and face P. Repeat [9-12] 3 times (1,2,3,4)
25--::
  All set to P | turn P RH 1¼ to places | set to P (1,2,3,4)
33--::
  Interlocking Reels4. All W face out (1,2,3,4)
41--::
  ½ Schiehallion Reels (3,4,1,2)
49--::
  All set to P | Gr-Chain (2 bars per hand) | all set facing in (1,2,3,4)
57--::
  Circle8 and back

_Reel_
1-64::
  Repeat in Reel time', 5);
INSERT INTO 'dancecrib' VALUES (10539, '2018-03-21 08:24:30.289079+00', '2018-03-21 08:32:24.574994+00', 7686, 1, 202, 'ace', '1--::

  1c+2c set | 1c cast _while{2}_ 2c dance up to 1pl ; 2c+1c+3c ½ Mirror Reels3 on sidelines, 1c start in and down (3,1,2)

9--::

  1c Reel4 on 2diag, 1c start Lsh to P (3,1,2)

17--::

  1M+2c & 1W+3c ½ Reels3 across, 1c start Lsh to 1cnrs position ; 1M+3c & 1W+2c ½ Reels3 across (3,1,2)

25--::

  All set | cross RH (to 3x,1x,2x) ; all chase clw ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11507, '2019-01-10 01:20:54.275951+00', '2019-01-10 11:37:48.662153+00', 2284, 1, 202, 'ace', '1--::
  1c set | turn RH _while{2}_ 2c set ; cast below 3pl _while{2}_ 2c turn RH and 3c set | cross RH _while{2}_ 2c lead up to 1pl and 3c turn RH to 2pl. 2c and 1c face out, 3c face up (2,3,1x)
9--::
  Mirror Reels3 on sides, 3c lead up, 2c out and down. 1c face out (2,3,1x)
17--::
  3c+1c change places RH on M side, LH on W side and retain hands | 1c+3c set, 3c pivoting to face in. On [20] release hands ; 2c+1c turn EH on sides, 1c in and up (2,1x,3)
25--::
  1c lead down | cast to 2plx _while{4}_ 2c & 3c set | cross RH (to 2x,1x,3x) ; all set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9281, '2016-08-12 16:20:24.070615+00', '2016-08-13 07:18:16.647852+00', 5569, 1, NULL, 'ace', '1--::

  Inveran Reels3 on the sides, to (1,2,3), 2c facing out

9--::

  1c cross down into Reels3 across: 1M+2c (Lsh to 2W) and 1W+3c (Lsh to 3M), 1c pass Rsh to face 1cnr

17--::

  1c+1cnrs Reel4, at end dance Rsh round P to face 2cnr

25--::

  1c+2cnrs Reel4, at end 1c pass Rsh to face 2cnr

33--::

  Reels3{6} on the sides, Rsh to 2cnr | cross RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1606, '2012-01-22 19:28:50.450853+00', '2014-04-30 23:23:36.824503+00', 1930, 1, NULL, 'ace', '1–::
  Mirror Reels3 on opposite sides (1c cross down), finish 2c in 1pl and 1c BtoB in 2pos facing opposite sides
9–::
  Crown Triangles (starting across), 1c finish BtoB facing 2cnr
17–::
  Reels3{6} on sides (Rsh to 2cnr) | 1c cross LH (2,1,3)
25–::
  1c Fig8 round couple on right (Lsh to 1cnr)', 3);
INSERT INTO 'dancecrib' VALUES (2368, '2012-01-22 19:29:33.768506+00', '2015-09-04 19:55:11.751996+00', 10072, 1, NULL, 'ace', '1--::  1c set | 1M cast to 2pl (2M up) ; 1M+2W ½ Fig8 up  (2c now faces 1c across)

9--::  All set NHJ on sides | Circle6 L {2}, turn P BH and reform circle {2}, finish circle in circle shape 

17--::  All W set, advancing slightly, RHA and cast Lsh round P to place in circle

25--::  All M set, advancing slightly, RHA and turn P LH to finish in promhold facing cclw, M on inside

33--::  All C promenade cclw once round, 2c folllowed by 1c & 3c dance down the middle, all drop LH and face up RHJ

41--::  All lead up to top and cast off to (2x,1x,3x) | 2c cross RH _while{2}_ 1c+3c ½ RHA (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (3767, '2013-06-30 12:12:01.046379+00', '2021-02-24 19:42:36.095842+00', 9407, 2, 1, 'ace', '1–::

  1c+3c advance & retire ; 2c+4c R

9–::

  1c+3c dance ½ rights & lefts ; 2c+4c R

17–::

  Ladies petronella 1pl anti-clockwise | all S ; men petronella 1pl anti-clockwise | all S

25–::

  All circle round & back', 3);
INSERT INTO 'dancecrib' VALUES (2303, '2012-01-22 19:29:30.695866+00', '2015-10-29 23:21:40.276239+00', 13585, 1, NULL, 'ace', '1–::

  1c+2c Circle4 L and face up/dn NHJ ; Set | 1c turn inwards and cast as 2c dance up and 3c step in for

9–::

  1c+3c Rondel, 3c finish facing 1cnr

17–::

  3c set to and turn cnrs, finish on sidelines (2,3x,1) with 1c facing 2c

25–::

  3c dance up | cast off ; lead down LHJ, cross and cast up _while{8}_ 2c+1c R&L, starting along the sides (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (11721, '2019-03-20 23:17:53.042771+00', '2019-03-20 23:17:53.042771+00', 6861, 1, NULL, 'ace', '1--::

  1c set | turn RH ¾ ; set | turn RH ¾ (1x,2,3)

9--::

  1c (dance down)+2c (cross up) DblFig8 (1x,2,3)

17--::

  1c dance on opp. side behind own line to below 3c, lead to the top, cross and cast off one (2c up) (2,1,3)

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3764, '2013-06-13 09:50:35.477257+00', '2021-06-16 16:34:10.8181+00', 13771, 1, NULL, 'ace', '1--::

  1c dance down | turn BH ; dance up and cast to 2pl (2c up) (2,1,3)

9--::

  S&Link3 into lines across ; Half Diag R&L to the L (in each line only the middle and RH persons dance)

17--::

  S&Link3 to sidelines; Half Diag R&L to the L (in each line only the middle and RH persons dance) (3x,1x,2x)

25--::

  All set | All turn P ½ RH and twirl to sideline | All set



', 3);
INSERT INTO 'dancecrib' VALUES (8118, '2013-11-25 05:58:54.1864+00', '2015-05-03 12:20:24.45784+00', 3770, 1, NULL, 'ace', '1--::

  All set | cross RH ; set | Turn RH 1/2 into promhold facing up

9--::

  All promenade (1,2,3)

17--::

  1c cross RH | cast off (2Cup) ; 1/2 Fig8 up (2,1,3)

25--::

  1c+3c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9816, '2017-04-29 15:35:16.038243+00', '2017-04-29 22:02:51.952916+00', 17717, 2, NULL, 'ace', '1-8::

  1c+2c dance the Knot; 1c finish in center 1W above 1M both pulling Left shoulder back to face own side, 2c face CCW

9-12::

 1W+2c, 1M+3c LH across; 1c finish pulling Left shoulder back to face 1st corner

13-16::

  Set to 1st corner, 1c dance around each other by right shoulder to 1M above 1W, pulling Right shoulder back to face own side

17-20::

  1M+2c, 1W+3c RH across; 1c finish pulling Right shoulder back to face 2nd corner

21-24::

  Set to 2nd corner, 1c dance around each other by right shoulder to 2nd place own sides

25-32::

  2c+1c+3c circle 6h round and back

', 5);
INSERT INTO 'dancecrib' VALUES (9821, '2017-05-04 19:57:48.316442+00', '2020-12-30 21:40:55.42311+00', 15411, 1, 202, 'ace', '1--::

 1c/3c dance down between 2c/4c and cast up one ; 1c+2c & 3c+4c circle(4) L

9--::

 2c/4c dance up between 1c/3c and cast off one ; 1c+2c & 3c+4c circle(4) R

17--::

 1c+2c set | ½ RHA ; 1c+3c set | ½ LHA (2x,3x,1,4)

25--::

 1c+4c set | ½ RHA ; 2c+3c+4c+1c set | cross RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (14247, '2021-08-17 23:19:46.438765+00', '2021-08-19 14:01:11.457865+00', 20430, 1, 202, 'ace', '1--::

  2C S&Link ; 2c+1c chase clw ½ (1x,2x)

9--::

  1c+2c RHA ; all set | cross RH. 1c face out (1,2)

17--::

  1c dance down behind own lines (2c up) ; turn away and dance up to 2pl (2,1)

25--::

  2C Poussette (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (2647, '2012-01-22 19:29:51.403886+00', '2018-10-03 21:21:50.257309+00', 7795, 1, NULL, 'ace', '1–::

  1c lead down the middle and up, and face up in the middle

9–::

  1c cast (2c up) | cross Lsh and dance Rsh round 1cnr | turn P LH to face 1cnr

17–::

  1c+1cnrs cnr-Chain, finish facing 2cnr

25–::

  1c+2cnrs cnr-Chain, finish (2,1,3)



{{explanation}}

Cnr-Chain: 1c turn cnr RH ½ | cnrs turn LH ; 1c turn same cnr RH ½ | 1c turn LH to enter next figure', 3);
INSERT INTO 'dancecrib' VALUES (14606, '2022-02-13 23:59:34.131243+00', '2022-02-14 00:01:40.001029+00', 15014, 1, 202, 'ace', '1--::

  All set | Petronella turn ; repeat [1-4] (1x,2x,3x)

9--::

  1c+2c set | RHA ½ (to 2,1,3x) ; 1c+3c repeat [9-12] (2,3,1x)

17--::

  Circle6 and back (2,3,1x)

25--::

  1c ½ Fig8 up round 3c ; all turn P RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12583, '2020-02-15 02:27:05.470534+00', '2022-04-05 13:13:11.746604+00', 19155, 1, 202, 'ace', '1--::

  1c lead down and up (1,2,3)

9--::

  Mirror Reels3 on sides, 1c out and down, 2c in and up, joining hands where possible (1,2,3)

17--::

  1c cast (2c up) | pass P RSh to face end cpl ; 2c+1W  & 1M+3c Circle3 L, flow into

25--::

  Circle6 and back (2,1,3)   

', 3);
INSERT INTO 'dancecrib' VALUES (14148, '2021-07-15 22:24:50.696095+00', '2021-07-15 22:24:59.88759+00', 19271, 1, 1645, 'ace', '1-::

  1c slip down (2c up on [3-4]) ; 1c set | dance up NHJ to 2pl centre

9-::

  M LHA _while_ W RHA, 2c+1c retain hands ;  1M+2M turn LH _while_ 1W+2W turn RH (2,1,3)

17-::

  All A&R ; 1c turn 1&frac14; RH, retain RH & take LH with 2cnrs

25-::

  1c BiL with 2cnrs | set adv to take LH with 1cnrs ; BiL with 1cnrs | &frac12; turn RH to sides (2,1,3)

33-::

  Circle6 & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3595, '2012-07-21 11:45:24.372216+00', '2015-09-05 04:31:46.367868+00', 14405, 1, NULL, 'ace', '1–::

  1c+3c ½Fig8 down ; 1c+2c & 3c+4c 1½ mirror turns on sideline EH (1c+3c start inwards) into

9–::

  2c+1c+4c+3c+5c Double DTr, finish facing 1cnr

17–::

  1c & 3c with 1cnrs pass and turn ; repeat with 2cnrs, and face out own side (2,1,4,3,5)

25–::

  1c & 3c cast R round 3cnr, cross in diagonally to opposite side (1W & 3 M pass Rsh) (2,1x,4,3x,5) ;  cross RH | cast off (4c+5c up) (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (2266, '2012-01-22 19:29:28.649378+00', '2014-10-05 19:32:44.199912+00', 13450, 1, NULL, 'ace', '1–::

  1c set | cross RH ; cast (2c up) | turn RH to face 1cnr

9–::

  1c+1cnrs Rsh Pass and Turn, to own sideline facing 3cnr (2,1,3) ; ½ Rsh Reels3 on the sides. On [16] 1c turn LH to face 2cnr

17–::

  1c+2cnrs _Lsh_ Pass and Turn, to own sideline facing 4cnr (3,1,2) ; ½ Lsh Reels3 on the sides. On [24] 1c turn RH ½ to face out (2,1x,3)

25–::

  1c+3c ¾ Dbl Fig8 (cross up with Easy Hand) | 1c turn BH (2,3,1)

', 4);
INSERT INTO 'dancecrib' VALUES (8218, '2014-03-22 00:03:18.292496+00', '2014-04-30 23:23:41.26843+00', 14014, 1, NULL, 'ace', '1–::
  1c set | turn RH ½ moving down, lead between 3c, cast up , dance up between 2c to top facing out _while_{8} 2c wait {2} | repeat [1-6] above to 2plx _while_{8} 3c wait {4} ; set | turn RH ½ and face down (1x,2x,3x)
9–::
  Mirror Reels3 on the sides, 2c starts in and up, at the end loop into place (1x,2x,3x)
17–::
  All set | petronella in tandem for 3 into lines across ; repeat to (3,2,1)
25–::
  All set advancing and face down NHJ | 1c cast to top and dance down to 2pl _while_{4} 2c follow down and cast to top _while_{4} 3c follow down and cast to 3pl | All set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1741, '2012-01-22 19:28:59.412589+00', '2017-04-21 22:41:08.063374+00', 445, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; 1c+3c RHA, finish as pairs 1M+3W & 3M+1W facing out on W/M side in promhold

9–::

  Pairs+ 2c+4c Rsh ½Reels3 on sides ; pairs meet & take P in promhold for Lsh ½Reels3 on sides

17–::

  Meet and repeat (as pairs Rsh ½Reels3 ; with P Lsh ½Reels3)

25–::

  1c (passing inside) turn 3c 1½ Easy Hand ; 1c cross and passing inside turn 4c EH 1½ (to 2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (1805, '2012-01-22 19:29:03.256449+00', '2018-09-08 10:47:43.074944+00', 13586, 1, NULL, 'ace', '1–::

  1c dance below 3c cast up, dance between 2c and cast off (2c up) (2,1,3)

9–::

  All turn P BH ½ and twirl to P''s place (2x,1x,3x) ; All circle6 L ¾ into lines across, (M at top)

17–::

  1c change place RH | 1c cast R _while{2}_ 3M+2W change place diagonally RH (2,1,3) ; 1c cross RH | 1c cast R _while{2}_ 2M+3W change places RH, finish in lines across (W at top)

25–::

  All turn P BH ½ and twirl to P''s place ; All circle6 L ¾ to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11240, '2018-10-03 01:39:55.149097+00', '2018-10-03 10:27:07.98805+00', 18697, 1, 202, 'ace', '1--::

  1c dance down between 3c | cast up to 2pl (2c up) ; 1c turn LH 1¼ to face 1cnrs

9--::

  ½ Reel4 on 1diag, 1c face 1cnrs[pos] ; 4 bars of SetH&G, 1c face 2cnrs

17--::

  ½ Reel4 on 2diag, 1c face 2cnrs[pos] ; 4 bars of SetH&G. On [24] 1c pivot R between ends to face 2cnrs[pos]

25--::

  All chase clw ½ ; 1c turn RH 1¼ to 2pl (2,1,3)



*Deviser''s note:  

On bars 23/24: all three couples can set & turn R about to face clockwise.*', 2);
INSERT INTO 'dancecrib' VALUES (8211, '2014-03-14 21:13:42.280966+00', '2014-04-30 23:23:41.389722+00', 679, 1, NULL, 'ace', '{{explanation}}
3c+4c start on opposite side (1,2,3x,4x)

1–::
  1c+4c cross RH | cast inwards ; ½ Fig8 round own end _while_{8} 2c+3c turn P RH ½ and face own end | cross out the end ; cast to own place | dance to end and face out (2,1,4x,3x)
9–::
  1c (promhold) +2c & 4c (promhoold) +3c Reels3 across, starting Rsh to 2W & 4W, finish 1c on M side and 4c on W side, still in promhold, and 2c & 3c facing out
17–::
  Reels3 on the sides, 1c/4c giving Rsh to 2W/3W, finish (2,[1c facing 4c across], 3)
25–::
  1M & 4M turn opposite W BH ½ into exchanged places, facing up/down still holding NH | Set to P up/down ; Circle4 L 1¼ , to finish (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (2396, '2012-01-22 19:29:35.52568+00', '2016-11-15 15:46:57.851965+00', 2745, 1, NULL, 'ace', '1–::

  1W set advancing to 2M | turn 3M BH, finishing between these M ; 1M sets advancing to 2W | turn 3W BH to between 3c (2c up, and 1W moves up between them)

9–::

  2c+1c+3c in lines across set twice ; 1c turn ¾ BH to 2pl on opposite sidelines

17–::

  2c+1c+3c set twice ; 1c turn BH ½ to own side 2pl

25–::

  Circle6 and back



{{explanation}}

note: In the BH turns in PdB, 1c dances backwards to the sidelines on the last step, but may also break earlier and dance out forwards', 3);
INSERT INTO 'dancecrib' VALUES (1687, '2012-01-22 19:28:56.644017+00', '2016-12-06 20:08:57.906543+00', 271, 1, NULL, 'ace', '1–::

  1M+2W A&R ; 1W+2M A&R

9–::

  All dance clw »around the square« - 2 bars per side

17–::

  1c followed by 2c lead down ; 2c followed by 1c lead up (2,1)

25–::

  R&L', 2);
INSERT INTO 'dancecrib' VALUES (8741, '2015-03-23 13:34:52.882048+00', '2015-03-23 16:48:39.795227+00', 16177, 1, NULL, 'ace', '1-10::

  All set | Parallel Reels4 on sidelines (1,2,3,4)

11-20::

  2c+3c set | turn RH ½ into | 2c+3c ½ RHA | 2c+3c chase clw ½ {4} (1,2x,3x,4)

21-30::

  1c+2c & 3c+4c DblFig8 (2c & 3c cross to start), and continue figure for [29-30] (2,1,4,3)

31-40::

  1c facing 4c S&Link {4} and face P (2,1x,4x,3) | 1c+4c S&Link {4} | turn P RH ½ (2,4,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (3348, '2012-01-22 19:30:21.56186+00', '2021-03-22 12:41:41.120325+00', 8085, 1, NULL, 'ace', '1–::

  1c Fig8 round 2c

9–::

  Mirror Reels3 on the sides, 2c start out and up

17–::

  1c lead down the middle and up

25–::

  1c+2c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8116, '2013-11-18 14:58:14.745608+00', '2021-02-07 12:17:22.132992+00', 10533, 2, 223, 'ace', '1-8:: First and second couples dance chain progression: 1st and 2nd couples turn right hand ¾, 1st man and 2nd lady turn left hand 1½ while partners dance clockwise half way round, 2nd couple turn ¾ right hand to progressed places while 1st couple finish facing second corners.

9-12:: First man dance half reel of three with 2nd couple while first lady dance half reel of three with 3rd couple, first couple give right shoulder to 2nd corners to start and finish in second place on opposite sides.

13-16:: First man gives left shoulder to 3rd man and dances a half reel of three with the two men on the ladies'' side while first lady does the same with the two ladies on the mens'' side.

17-20:: All set and link for three.

21-24:: All set and link for three.

25-32:: Six hands round and back.



Repeat having passed a couple.', 0);
INSERT INTO 'dancecrib' VALUES (3838, '2013-07-13 15:56:19.011379+00', '2016-08-16 14:50:01.959591+00', 14532, 1, NULL, 'ace', '1–::

  1W casts off 2, cross below 3c, cast up to between 3c _while_{8}   1M cross, cast off, (2c up) cross, cast up to between 2c.  All face down

9–::

  In lines across dance down ; the cnrs swivel R to dance back  _while_{4}   1c turn RH moving up to finish between 3c, M facing W for

17–::

  1c+3c ½ Reel4 across ; 1c turn LH moving up to between 2c, 1M facing 2M and 1W facing 2W  _while_{4}   3c set and cross RH

25–::

  1c+2c ½ Lsh Reel4 across ; 1c turn LH to 2pl  _while_{4}   2c set and cross (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2429, '2012-01-22 19:29:38.278766+00', '2016-11-15 15:47:42.911465+00', 2924, 1, NULL, 'ace', '1–::

  1c long cast to 2pl (2c up on [3-4] ; 1c+3c RHA  (2,1,3)

9–::

  2c+1c LHA, 1W faces out ; 1W followed by 1M cast up round 2W and down the middle of set, 1W between 3c and 1M between 2c, all facing down

17–::

  In lines of 3 down the middle (all swivel R) and up

25–::

  1M followed by 1W dance up, cast round 2W and into 2pl ; 1c turn RH

33–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (1808, '2012-01-22 19:29:03.423065+00', '2014-05-31 13:56:56.920874+00', 694, 1, NULL, 'ace', '{{explanation}}

3c+4c start on opposite sides (1,2,3x,4x)



1–::

  All set, 1c+4c cross over RH _while_{2} 2c+3c ½ RHA ; all set and cross over RH (1,3x,2,4x)

9–::

  3c+2c circle4 L ; set | turn RH to finish in the centre in Allemande hold facing the other couple

17–::

  3c+2c Glasgow Highland step to R and L ; with the M keeping L shoulders close Promenade cclw once & face »2cnr«.

25–::

  1W+2c & 3c+4W pass Lsh, 2c+3c dance round corner position _while_{4} 1W+4W turn LH in the middle ‑ and passing corners and other couple Lsh again return to the middle ; repeat 1M+3c & 2c+4M to finish, 2c above and facing 3c, as 1c+4c step in facing the nearest end for :

33–::

  1c+3c Allemande up, 2c+4c Allemande down (3,1,4x,2x)', 2);
INSERT INTO 'dancecrib' VALUES (2495, '2012-01-22 19:29:45.032155+00', '2016-11-15 15:48:39.850236+00', 12542, 1, NULL, 'ace', '1–::

  1c Turn RH, cast (2c up) ; All circle6 L ¾ into lines across (W facing down, M up)

9–::

  All set | change places RH with P ; All circle6 L left ¾ and end in middle facing up (3,1,2) for

17–::

  Allemande (2,1,3)

25–::

  1c+3c Bourrel : 1M+3W set adv. | Turn BH ¾ & twirl to end BtoB in middle, 3W facing up & 1M down _while_{4} 1W+3M chase cclw to face P ; set to P | Turn BH ¾ to (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2251, '2012-01-22 19:29:27.909786+00', '2017-06-13 23:54:16.88704+00', 2242, 1, NULL, 'ace', '{{explanation}}

3c+4c begin on opposite side (1,2,3x,4x)



1–::

  1c+2c & 3c+4c, circle4 L, finish NHJ 1c facing 2c & 3c facing 4c ; All set | 1c+4c cast (long way) to middle passing LH on the side _while{2}_ 2c & 3c dance to ends (2,4x,1,3x)

9–::

  4c+1c lead out the end, cross and cast inwards, 4c & 1c change places LH on the sides ; repeat figure at other end, again passing LH on the sides, finish middles facing ends (2,4x,1,3x)

17–::

  Reels4 on the sides, finish mid cpls facing end cpls

25–::

  All set to facing cpl | 4c & 1c, passing inside turn end cpl Easy Hand on sideline ; 4c+1c ½Fig8 round same end cpl (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (13370, '2020-11-06 20:43:27.629313+00', '2020-11-11 18:21:50.919268+00', 17968, 2, 963, 'ace', '1-8::  

  1+2c dance the Poppy (dance in for 1 on the diag, pull back Rsh, dance out for 1|curve into next plc cw; curve on one more plc cw| RHA 1/2 back to place)  

9-12::  

  1+2c set, 1c cast as 2s dance up  

13-16::  

  1+3c LHA  

17-24::  

  2,1,3c dance the knot   3,1,2

25-28::  

  3,1,2 chase ccw halfway  2x,1x,3x

29-32::  

  2,1,3 pass prtn L sh to own sides and all set

  ', 5);
INSERT INTO 'dancecrib' VALUES (9825, '2017-05-06 16:05:03.226526+00', '2020-08-31 15:19:03.764933+00', 3937, 2, 111, 'ace', '1-8::

  1C turn, cast 1pl ; turn LH to face out in 2pl.

9-16::

  RH Mixed chain: 2crnrs turn RH 1/2 (face out in 2pl) as 1C loop L, 1C+2crnrs 1/2 turn LH ; crnrs turn RH 1/2 as 1C loop L, 1C+2crnrs Turn LH 1/2 -1C face out 2pl.

17-24::

  LH Mixed chain with 1crnrs.

25-32::

  6 Hands round & Back.', 3);
INSERT INTO 'dancecrib' VALUES (1810, '2012-01-22 19:29:03.544601+00', '2021-06-29 09:45:11.539863+00', 700, 1, NULL, 'ace', '1–::

  1W+2W A&R ; turn RH

9–::

  1M+2M A&R ; turn LH

17–::

  L-Chain

25–::

  All set to P | set diagonally ; set to dancer opposite | pass RH to face next C.', 2);
INSERT INTO 'dancecrib' VALUES (9824, '2017-05-06 14:08:25.589466+00', '2017-08-26 13:45:19.110893+00', 17729, 1, 202, 'ace', '1--::

 1c+2c RHA ; 1W & 2W followed by Ps chase clw ½ (2x,1x)

9--::

 2c+1c RHA ; 2M & 1W followed by Ps chase clw ½ to midline, dance up/dn, 2M & 1W meet, pull Rsh back to face P ending in midline of 4

17--::

 Reel4

25--::

 1c+2c turn P 1 ¼ (to 1x,2x) : chase clw ½ (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2613, '2012-01-22 19:29:50.011253+00', '2016-11-15 15:55:01.949115+00', 3617, 1, NULL, 'ace', '{{explanation}}

or The Duke is Welcome to Inverness  

On 2nd chord, 1c changes sides, where they remain till the have reached the bottom



1–::

  1c cast off one, turn RH, cast off one, turn LH

9–::

  1c lead up to the top and cast off one (2c up) ; 2c+1c+3c circle6 to the left

17–::

  1W+2c & 1M+3c circle3 to the left ; 1W+2M+3M & 1M+2W+3W circle3 to the left (the transition is not explained)

25–::

  1c lead down between 3c and cast up to 2pl opposite side ; 2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (11242, '2018-10-04 05:05:00.537489+00', '2018-10-04 05:32:53.570516+00', 18722, 1, 202, 'ace', '1--::
  1c lead down ; cross down between 3c and cast up to 2plx (2,1x,3)
9--::
  3C S&Link ; 1c turn BH to 2plx (3,1x,2)
17--::
  3C S&Link ; 1c turn BH to face 1cnrs
25--::
  Corners Pass and Turn (2,1,3) ', 2);
INSERT INTO 'dancecrib' VALUES (3358, '2012-01-22 19:30:21.95535+00', '2021-03-01 16:51:49.444387+00', 9122, 1, NULL, 'ace', '1–::

  1c+3c DblFig8 around 2c (1c crossing in, 3c cast up)

9–::

  1c+2c+3c set, cross RH ; set, cross LH

17–::

  1c lead down the middle and back, ending with 2c ready for)

25–::

  1c+2c ½Poussette ; 1c+3c ½Poussette', 2);
INSERT INTO 'dancecrib' VALUES (14149, '2021-07-15 22:31:53.028252+00', '2021-07-15 22:37:22.57242+00', 3452, 1, 202, 'ace', '1--::

  1c lead down {3}, lead up {3} | cast off (2c up) (2,1,3)

9--::

  1c Fig8 on sides, in and down, giving hands where possible (2,1,3)

17--::

  1c cross RH | dance down behind opposite lines ; dance back to 2plx | cross RH (2,1,3)

25--::

  1c Fig8 on sides, out and up, giving hands where possible (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1812, '2012-01-22 19:29:03.717268+00', '2015-06-22 11:05:00.298325+00', 713, 1, NULL, 'ace', '{{explanation}}

Start with groups of 3 couples forming a circle, M on left of P



1–::

  All circle6 and back

9–::

  All A&R into centre ; Dance BtoB with P

17–::

  All wheel RH (take hands with dancer opposite) ; on bar 5 the W whose hand is lowest moves under to join new P, bar 7: next W moves under to join new P

25–::

  All three »new free couples« Promenade to anywhere in the room to form trio with 2 other couples.



{{explanation}}

only bars 9-16 differ from the Dunedin Festival Dance', 3);
INSERT INTO 'dancecrib' VALUES (9088, '2016-02-12 16:46:26.08483+00', '2016-02-12 16:46:26.08483+00', 7559, 1, NULL, 'ace', '1--::

  1W with 1M following, cast off one and crosses (2c up) to (2,1x,3) ; All set and cross LH (2x,1,3x)

9--::

  2c+1c La-Chain up/down the set (2x,1,3x)

17--::

  Diagonal R&L (3,1,2)

25--::

  All set | cross RH ; Half Circle6 L (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9090, '2016-02-12 21:18:07.048308+00', '2016-02-12 21:18:07.048308+00', 16871, 1, NULL, 'ace', '*Strathspey time* 

1--::

  1c+2c petronella to midline | set ; ½ Reel4

9--::

  All turn P BH nearly twice into ; Half Poussette (1,2)

17--::

  1c cross down into fig8 round 2c (1,2)

25--::

  1c+2c The Knot (2,1)



*Reel time* 

1--::

  1c+2c petronella to midline | set ; ½ Reel4

9--::

  All turn P RH ¾ into ½ RHA ; Cross RH and set (1,2)

17--::

  1c cross down into fig8 round 2c (1,2)

25--::

  1c+2c The Knot (2,1)

', 4);
INSERT INTO 'dancecrib' VALUES (2580, '2012-01-22 19:29:48.460369+00', '2022-12-20 12:42:20.844918+00', 3529, 1, NULL, 'ace', '1–::

  1c set, cast (2c up) ; 1c+3c circle4 L

9–::

  1c set and cast up (2c down) ; 1c+2c circle4 L

17–::

  1c lead down | up ; cast off (2c up) | turn RH and face down RHJ

25–::

  1c lead between 3c, cast up to 2pl ; 2c+1c+3c turn RH



{{explanation}}

Note: Changed by Miss Millligan; in »99 more SCD« the circle on[13-16] was to the R', 3);
INSERT INTO 'dancecrib' VALUES (14550, '2022-01-12 09:25:44.245747+00', '2022-08-15 15:21:34.146887+00', 20620, 1, 202, 'ace', '1--::

  1c+2c RHA ; LHA. 1M faces out (1,2,3)

9--::

  1c (1M leading) cast off | cross to 2plx (2c up) ; cast off | cross to 3pl (3c up) (2,3,1)

17--::

  Circle6 and back (2,3,1)

25--::

  1c dance up to top and cast off (3c down) ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15166, '2022-10-10 16:30:29.387273+00', '2022-10-10 17:47:52.256014+00', 21123, 1, 202, 'ace', '1--::
  1c+2c set | turn BH ; Circle 4 L (1,2,3)
9--::
  1c ½ Fig8 on opposite sides, 1c crossing down ; ½ Fig8 on own sides, 1c crossing up (1,2,3)
17--::
  Mirror Reels3 on sides, 1c in and down, 2c out and up (1,2,3)
25--::
  1c+2c Set&Link ; 1c+3c Set&Link (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (9091, '2016-02-12 23:10:02.282086+00', '2016-02-12 23:10:02.282086+00', 8666, 1, NULL, 'ace', '1--::

  1c cross down into Reels3 on the sides (1x,2,3)

9--::

  1c cross RH and cast off (2c up) ; 1c dance between 3c and cast up (2,1,3)

17--::

  2c+1W & 1M+3c Reels3 across, Lsh to1cnr, 1c finish BtoB facing 4cnr

25--::

  1c "corners pass and turn" on 2diag and pass Rsh to face 1cnr ; repeat on 1diag (2,1,3) 

', 3);
INSERT INTO 'dancecrib' VALUES (8126, '2013-11-29 06:14:35.537406+00', '2013-11-29 06:14:35.537406+00', 5786, 1, NULL, 'ace', '1--::

  1c+2c 1/2 RHA | cross RH ; 1/2 LHA | cross LH

9--::

  1c set | cast off 2 (2c+3c up) ; 3c+1c set | turn 3/4 or 1 1/4 to midline, the M BtoB in the middle

17--::

  HS Poussette, finishing (2,1x,3)

25--::

  Reels3{6} on the sides, 1c Lsh to 1cnr | 1c cross RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9089, '2016-02-12 20:31:19.587882+00', '2016-02-13 11:17:48.168841+00', 16870, 1, NULL, 'ace', '1--::

  1c+2c Espagnole, 2c finish facing out and 1c facing up in promhold

9--::

  1c in promhold+2c Rsh Reel3 across, 1c finish NHJ facing up just below 2c who face down the sidelines

17--::

  1c+2c join EH and set in line | turn EH 3/4 to (2,1) ; 2c+1c advance (no H), join RH with P and the W turn under the joined arms | all dance to sidelines, M retiring

25--::

  2c+1c R&L

', 3);
INSERT INTO 'dancecrib' VALUES (10398, '2018-01-23 03:07:03.672118+00', '2018-01-23 03:07:28.004446+00', 18229, 1, 202, 'ace', '{{title}}

Strathspey

1--::

  2c+3c Knot (1,3,2,4)

9--::

  3c+2c set | Petronella in tandem ; repeat [9-12] (1,2x,3x,4)



{{title}}

Reel

17--::

  2c+3c ½ R&L ; 1c+3c set | ½ RHA _while{4}_ 2c+4c set | ½ LHA (3x,1x,4x,2x)

25--::

  All set | cross RH ; 3c+1c Circle4 L _while{4}_ 4c+2c Circle4 R (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (3787, '2013-07-13 15:56:06.461143+00', '2015-09-05 21:16:19.242759+00', 14643, 1, NULL, 'ace', '1–::

  1c set | 1W casts, 1M following, round 3W, 1W dances up round 3M and 1M dances up the middle to 2pl opposite side facing 2c (2c up on 7-8) (2,1x,3)

9–::

  Parallel Reels3 on the sides, 1c giving Lsh to 2c, 1c finish in centre facing W side NHJ, 1W on the L, 2M+3M loop to places

17–::

  2c+3c cross RH | set ; cross RH | set _while_{8} 1c dance out, cast and meet in the middle, dance out on M side, and cast to (2,1,3)

25–::

  All chase clw ½ round ; ½ Circle6 L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9828, '2017-05-07 01:18:40.390355+00', '2021-05-08 20:46:34.266778+00', 4346, 2, 160, 'ace', '1-8::

  1C cross, cast ; 1/2 fig. 8s --1L up  rnd. 2C & 1M down rnd. 3C - end b-t-b 1L facing up & 1M facing down.

9-16::

  Petronella DTs. End 1L facing up 1M facing down.  (3x 1 2x)

17-24::

  1L 3C and  1M 2C RHA, 1C pass by R + dance LHA other end. (3x 1 2x)

25-32::

  Half Diagonal RL - lady up, man down - twice.', 3);
INSERT INTO 'dancecrib' VALUES (9093, '2016-02-19 11:49:04.117146+00', '2021-02-09 12:18:46.133153+00', 10392, 2, 2866, 'ace', '1–8::

 All circle round and back

9–16::

 Right and lefts

17–24::

 Right hand across, left hand across

25–32::

 Advance and retire; pass by the right shoulder to meet a new couple

', 4);
INSERT INTO 'dancecrib' VALUES (1811, '2012-01-22 19:29:03.66537+00', '2019-02-12 22:06:37.521796+00', 7353, 1, NULL, 'ace', '1–::

  1c turn RH ; 1W, 1M following, cast behind 2W and cross (2c up) (2,1x,3)

9–::

  Circle 6 and back

17–::

  1c+3c mirror allemande (turn P RH ½ to allemande hold, facing away from other C | each C as bars 3-8 of allemande, passing the other C) (to 2,3x,1)

25–::

  All petronella to midline | 3c set to P _while_{2} 1c+2c change places RH ; All petronella to own side and set (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (9092, '2016-02-16 23:02:13.746761+00', '2016-02-16 23:05:26.659007+00', 16872, 1, NULL, 'ace', '1--::

  1c+3c+5c turn P RH ; LH _while{8}_ 2c+4c cast clw and chase half round (1,4x,3,2x,5)

9--::

  3c (lead couple)+4c+2c Diagonal R&L, 3c finish facing 3cnr (1,2,3,4,5)

17--::

  3M+2M+1M & 3W+4W+5W Rsh Reels3 on own sidelines, 3c finish facing 4cnr

25--::

  3M+4M+5M & 3W+2W+1W Lsh Reels3 on own sidelines (1,2,3,4,5)

33--::

  1c weave down (dance between 2c, behind 3c, dance between 4c, behind 5c to 5pl (1c+2c+3c+4c up on [39-40] (2,3,4,5,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10658, '2018-04-19 16:56:30.529618+00', '2019-03-09 23:36:13.435136+00', 12392, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 R round 3cnrs to centre facing 1cnrs, Lsh to P, LHJ

9--::

  1c+1cnrs set, swivel ½ inwards and join RH | 1c+3cnrs set ; 1c turn 4cnrs LH to centre facing 2cnrs, Lsh to P, LHJ

17--::

  1c+2cnrs set, swivel ½ inwards and join RH | 1c+4cnrs set ; 1c turn 1cnrs LH to 2plx (2,1x,3)

25--::

  Reels3{6}, 1c start Rsh to 2cnrs | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3049, '2012-01-22 19:30:08.354977+00', '2019-06-27 06:58:45.12749+00', 14024, 1, NULL, 'ace', '1–::

  1c+2c S&Link ; Circle4 L (2,1,3)

9–::

  1c turn RH | turn 1cnr LH ; turn P RH | turn 2cnr LH, into lines across, 2c+1M facing 3c+1W

17–::

  All A&R ; 1c cross RH up/down and cast R to (2,1,3)

25–::

  All A&R ; All turn P RH', 3);
INSERT INTO 'dancecrib' VALUES (2440, '2012-01-22 19:29:38.944393+00', '2020-04-13 08:48:52.947877+00', 13579, 1, NULL, 'ace', '1–::

  1c set | cast off, meet below 4c and dance up for

9–::

  1M+2M+3M LHA _while_ 1W+2W+3W RHA ; 1c dance up, cast off (2c up) and meet in the middle

17–::

  1M+3M+4M RHA _while_ 1W+3W+4W LHA to sidelines (2,1,3,4) ; 1c set | cast off 2 (3c+4c up) (2,3,4,1)

25–::

  All Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (2644, '2012-01-22 19:29:51.28487+00', '2021-05-16 08:55:52.081635+00', 3711, 1, NULL, 'ace', '1–::

  1c+2c+3c circle6 and back

9–::

  1c dance down the middle and up, cross to finish BtoB between 2c

17–::

  1c+2c Reel4 across, finishing 2c in 1pl and 1c in the middle facing up

25–::

  1c dance up, cast off, meet below 2c, dance down through 3c, cast up to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14249, '2021-08-19 15:31:54.221656+00', '2021-08-19 15:45:28.422149+00', 20433, 1, 202, 'ace', '1--::
  2C S&Rotate. 2c+1c face up/down (2,1,3)
9--::
  3C Gr-Chain, 3c crossing RH (2,1,3)
17-28::
  3C R&L
29-32::
  All turn P BH (2,1,3)
33--::
  1c+3c S&Link ; 3c+1c RHA (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (3646, '2012-09-01 10:40:33.437185+00', '2014-04-30 23:24:13.811185+00', 6791, 1, NULL, 'ace', '1-4::
  1W&3W cast off to midline and face up _while_{4} 2M+4M cast up to midline and face down
5-12::
  Rsh Reel4 on midline
13-16::
  2M+1W & 4M+3W turn RH to places (1,2,3,4)
17–::
  1M+2W & 3M+4W turn RH to places ; 1c+2c & 3c+4c Circle4 L (1,2,3,4)
25–::
  All A&R ; 1c lead to 4pl (2c+3c+4c up) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (7985, '2013-08-21 08:31:54.106419+00', '2023-02-04 01:23:14.984177+00', 7210, 3, NULL, 'ace', '1-8::
    1s cast 1 place, turn 2H, cast down 1 place own sides & turn 2H
9-16::
    1s lead up to top, cross RH & cast down 1 place, 2s+1s dance R&L (1
    bar per hand) 1s end facing 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners (1s end in 2nd
    place opposite sides)
25-32::
    2s+1s+3s Adv+Ret & turn 2H all ending on own sides', 0);
INSERT INTO 'dancecrib' VALUES (3726, '2013-04-12 11:23:41.872689+00', '2013-07-29 21:07:33.146153+00', 14634, 2, 1, 'ace', '1–4::
  1c&4c set | cast to center (2c&4c step out)
5–8::
  1c dance ½ fig 8 round 2c (4c likewise round 3c)
9–::
  Top two couples, bottom two couples Circle4 and back
17–18::
  1c&4c ½ turn R (finish in centre w/NH joined, 1c facing down, 4c up)
19–22::
  1c+4c set | 1c dance down under arch made by 4c who dance up (finish in sidelines)
23–24::
  All set
25–::
  All advance & retire ; all turn RH', 3);
INSERT INTO 'dancecrib' VALUES (1816, '2012-01-22 19:29:03.935961+00', '2014-04-30 23:23:41.657407+00', 8142, 1, NULL, 'ace', '1–::
  Holding nearer hands and facing cclw: Balance away, balance together, walk 3 steps and turn alone on 4th ; Repeat the above.
9–::
  Hold both hands, facing, balance (woman''s right, mans left) balance in other direction, 2 slow slide steps in first direction (This balance is similar to the English setting) ; in ballroom hold, 4 2-steps once around, end in ''open'' position ready to dance again.

{{explanation}}
(The Boston Two Step probably has many regional variations).', 2);
INSERT INTO 'dancecrib' VALUES (2807, '2012-01-22 19:29:58.22926+00', '2020-12-12 10:59:56.424759+00', 4476, 1, NULL, 'ace', '1–::

  1c lead down, cross RH between 3c, 1M+3W turn LH _while{2}_ 1W+3M turn RH (2c up) (2,1x,3) ; All A&R

9–::

  Circle6 and back

17–::

  2c followed by 1c & 3c lead down the middle (when 1c meet they turn RH ½  to lead down on own sides) ; and up, 3c casting through 1pl to 3pl , 1c+2c to own places

25–::

  1c set, cast off one (2c up) ; 1c turn RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1593, '2012-01-20 13:06:12.818334+00', '2019-03-17 11:41:40.897103+00', 2089, 2, 1, 'ace', '1-8::

  All cross RH ; set | 1C+3C dance petronella turn ; set

9-12::

  1C+3C ½Reel4 up and down the dance

13-16::

  1C+3C dance petronella turn [to 3x,2x,1x,4x] ; all set

17-24::

  3C+2C circle to L ⅜ ; 2M+3W turn R ⅞ _while_ 2W+3M continue circle ⅜ |

  2W+3M turn R ⅞ _while_ 2M+3W continue circle ⅜ ; 2C+3C circle to L ⅜ to fin

  where they started the fig. _Meanwhile_, 1C+4C dance likewise.

25-32::

  3C+2C (likewise 1C+4C) dance 2cpl Knot (starting by setting on RF and

  dancing in on LF to join hands w/ptr in Allemande hold facing down; continue

  as in normal Knot) [to 2,3,4,1]', 3);
INSERT INTO 'dancecrib' VALUES (11957, '2019-07-06 02:53:39.179561+00', '2022-02-14 00:01:39.998357+00', 15014, 2, 963, 'ace', '1-8::

  All 3c set & pet into ctr; set & pet to opp sides  

9-16::

  1&2c set|RHA 1/2;1&3c set|RHA 1/2  2,3,1x  

17-24::

  6 hands round and back  

25-32::

  1c half fig 8 xing up to start; all turn prtn RH', 3);
INSERT INTO 'dancecrib' VALUES (9829, '2017-05-07 06:59:55.941934+00', '2017-07-07 15:13:58.933983+00', 17429, 1, 202, 'ace', '1--::

 1c+2c dance diag in 1 step, pull Rsh back, dance diag out 1 step | circle4 L (to 2x,1x) ; repeat [1-4] (1,2,3)

9--::

 3c followed by 2c+1c dance down | all turn P BH ; all dance up | 1c cast to 2pl _while_ 2c turn BH to 1pl & 3c turn BH to 3pl (2,1,3)

17--::

 Circle6 and back

25--::

 1c ½ Fig8 to R ; all set | 1c cross RH', 2);
INSERT INTO 'dancecrib' VALUES (2829, '2012-01-22 19:29:59.138526+00', '2017-05-08 07:26:19.099126+00', 4563, 1, NULL, 'ace', '1–::

  1W+2M & 1M+2W turn RH (1W starts in & down, 1M across top), to finish 2c in 2pl and 1W above and facing 1M on the midline ; 1c set | 1c turn RH ¾ and face down, W on the R

9-12::

  1c lead down, 1M guiding 1W to face out below 3W | 1M+3W dance up NHJ and in the middle face out above 1pl _while{2}_ 1W casts up to 3W''s place

13-16::

  3M+1W dance up NHJ and in the middle face out above 1pl _while{2}_ 1M+3W cast down to 1pl | 3M+3W dance down to 3pl _while{2}_ 1W casts off to own place (1,2,3)

17–::

  1c set | cast to face 1cnr (2c up) ; set to 1cnr | set to 2cnr, and face down [**]

25–::

  1c dance between 3c and cast up on opposite side ; lead to top, cross and cast to (2,1,3)



{{explanation}}

[**]  TACnotes says: to face down on [24], 1M turns left about, 1W right about', 3);
INSERT INTO 'dancecrib' VALUES (9095, '2016-02-19 15:54:05.085034+00', '2016-06-03 15:52:35.611173+00', 15181, 2, 2866, 'ace', '1-8::	

 1s +2s RHA, LHA

9-16::

 	1s lead down & up

17-24::

	1s cast to the bottom, everyone else steps up; all 4 couples turn RH.

25-32::	All circle round and back', 0);
INSERT INTO 'dancecrib' VALUES (3660, '2012-12-09 23:25:14.954039+00', '2020-02-05 15:54:41.993572+00', 14536, 2, 1, 'ace', '1–::

  1c+2c dance the Knot [1c finish facing 1cnrs]

9–::

  1c+1cnrs ½ Reel4, pass RS ; 1c+2cnrs ½ Reel4 [finish 3x1x2x]

17–::

  All set | 1c petronella _while_ 2c&3c cast 1 place clockwise ;

  all set in lines across | 1c petronella _while_ 2c&3c cast 1 place clockwise (2,1,3)

25–28::

  All set | all turn BH [2c finish at top own sides, 1c&3c ready for …]

29–32::

  1c+3c ½ Poussette', 2);
INSERT INTO 'dancecrib' VALUES (1720, '2012-01-22 19:28:58.315588+00', '2014-04-30 23:23:39.354237+00', 9543, 1, NULL, 'ace', '1–::
  All set to P | turn RH ½ and form ring, M facing out ; All set | All turn P RH to places, W face out
9–::
  All W cast clw  behind P, makes Rsh loop round next M, and continue to opposite W place
17–::
  Repeat [1-8], but start LH to »new P, finish M facing out
25–::
  all M Repeat [9-16], casting cclw and looping Lsh, to (3,4,1,2)
33–::
  1c+3c R&L, finish in promhold facing in and R
41–::
  1c+3c promenade cclw inside the set, to (3,4,1,2)
49-64::
  2c+4c repeat [33-48]
65–::
  All A&R and face P ; All set, M pivoting R | all chase one place clw (2,3,4,1)
73–::
  Repeat [65-72] to (1,2,3,4)
81–::
  Circle 8 and back', 3);
INSERT INTO 'dancecrib' VALUES (8271, '2014-05-22 12:45:48.662465+00', '2017-06-15 22:31:12.26527+00', 10298, 1, NULL, 'ace', '1--::

  1c+2c DblFig8, 2c begins out and up

9--::

  1c+2c turn EH 1½ on sidelines ; cast off behind 3c and cross up to (2,1x,3)

17--::

  Mirror Reels3 on the sides, 1c starts out and up , At the end 1c cross to (2,1,3)

25--::

  Mirror Reels3 on the sides, 1c starts out and up , At the end 1c face up NHJ between 3c

33--::

  1c dance to top, cast off ; All turn P RH (2,1,3)



*The deviser prefers his original [33-40]: 1c dance up and turn 2c EH (2,1,3) ; 1c turn 3c other hand (2,1,3)*

', 3);
INSERT INTO 'dancecrib' VALUES (3752, '2013-06-04 19:17:00.727705+00', '2013-07-29 21:07:34.687908+00', 14940, 2, NULL, 'ace', 'Original dance description published here at the deviser''s request



*Strathspey*



1-16::    2nd couple dances 16 bars of petronella and set to return to original places while 1st and 3rd couples dance as in petronella double triangles (each dancer petronella to the corner position to their right around the set and then set). All take hands facing up and down or across as appropriate when setting. 



17-24::    1st couple lead down the middle and up using the highland strathspey traveling step if desired. 



25-32::    1st and 2nd couple dance right hands across and back by the left ending ready to dance a half poussette. 



33- 36::   1st and 2nd couple dance a half poussette



37-40::    1st and 3rd couples dance a half poussette



41-48::    Circle six hands around and back.



*Reel* 



1-16::    All couples dance petronella petronella figure as in bars 1-16 of the strathspey



17-24::    1st couple lead down the middle and up



25-32::    All three couples dance a 3 couple poussette



*Second time through the reel*



1-16::    2nd couple dances 16 bars of petronella and set to return to original places _while_   

1-16::    1st and 3rd couples dance as follows: 1st lady and 3rd man pass each other right shoulder using two pas de basque to change places diagonally, while 1st man and 3rd lady turn about on the spot pulling back right shoulder. All set facing up and down and then repeat with roles reversed. Repeat.



17-24::    1st couple lead down the middle and up



25-32::    Circle 6 hands around and back.





', 5);
INSERT INTO 'dancecrib' VALUES (9847, '2017-05-14 00:30:50.054725+00', '2017-05-14 00:30:50.054725+00', 16491, 1, NULL, 'ace', '1--::

  All set | A&R | set

9--::

  1cast off (2c up) | dance between 3c and cast up to 2pl | All set (2,1,3)

17--::

  1c+3c DblFig8 (to start 1c cross down and 3c dance up) (2,1,3)

25--::

  Reels3 on own sides, 1c start in and up, corners finish with loops

33--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (14745, '2022-04-05 14:49:48.806456+00', '2022-04-05 14:49:48.806456+00', 8145, 2, 1, 'ace', 'Couples round the room facing each other, M with their back to the centre, L facing centre.

1::
  Point RF to side, tap RF beside LF, point RF to side, close.
2::
  Repeat w/LF.
3::
  Point RF diagonally back, tap RF bseide LF, point RF diagonally back, close.
4::
  Repeat w/LF.
5::
  Lift R knee and touch w/L elbow, point RF to side, lift R knee/touch w/L elbow again, close.
6::
  Repeat with L knee/foot and R elbow.
7::
  Kick R leg across L, close, kick L leg across R, close.
8::
  With both feet together, jump L to face new partner ; nod to new partner, clap.

Repeat *ad nauseam*.', 3);
INSERT INTO 'dancecrib' VALUES (7986, '2013-08-21 08:31:54.119434+00', '2023-02-04 01:23:15.016673+00', 7215, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    All set, cross RH, set cross back RH
9-16::
    1s+2s also 3s+4s dance double Fig of 8  (1s & 4s crossing down/up to
    start)
17-24::
    1s & 4s 1/2 turn RH moving down/up & face up/down _while_ 2s & 3s
    dance to ends & face 1s/2s, all set, 1s+2s & 3s+4s dance RH across
25-32::
    1s & 4s dance 1/2 Fig of 8 round 2s/3s, 1s+4s dance 1/2 R&L.  2 4
    (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (9830, '2017-05-07 07:15:57.974745+00', '2022-08-15 08:44:24.492152+00', 17430, 1, 202, 'ace', '1--::

 Circle8 and back

9--::

 1c+3c R&L

17--::

 2c+4c A&R{4} ; 2c+4c dance BtoB

25--::

 W chase cclw outside one pl | M chase cclw outside one pl ; all turn P RH (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (12372, '2019-11-27 07:29:56.645953+00', '2019-12-17 21:45:03.41161+00', 19778, 1, NULL, 'ace', '1--::

  1c+2c RHA ; 2c+3c LHA  (1,2,3)

9--::

  Reels3 on the sides, 2M Lsh to 3M and 2W Rsh to 1W (1,2,3)  

17--::

  2c+3c set | Petronella in tandem ; change place with P up/down | Petronella in tandem (1,3,2)

25--::

  3C Knot (2,3,1)  

  

 

', 2);
INSERT INTO 'dancecrib' VALUES (3350, '2012-01-22 19:30:21.640774+00', '2016-11-15 16:06:19.52343+00', 6406, 1, NULL, 'ace', '1–::

  1c+2W circle3 L ; 1c+2M circle 3 L, 1c finish in the middle

9–::

  1c lead down | up ; cast off (2c up) | set advancing and swivel R to face own sides

17–::

  DTr (to 2,1,3)

25–::

  1M+3c & 1W+2c ½ Reels3 across (Lsh to 1cnr) ; 1M+2c & 1W+3c ½ Reels3 across

33–::

  2c+1c+3c circle6 and back.', 2);
INSERT INTO 'dancecrib' VALUES (13652, '2021-02-08 10:01:28.136295+00', '2021-02-08 10:14:39.629598+00', 17970, 1, 202, 'ace', '1--::

  1c+2c 6 bars of Chain progression | 1c turn P RH ¾ to 2pl _while{2}_ 2c changes places RH _while{2}_ 3c turn P RH ¾ to midline (on midline, 2W,2M,3W,3M in Reel4 position)

9--::

  »Weasel Reel« [: All continuously dance ½ Reel4 on midline, dancers who reach the end cast clw on own side and rejoin the reel at the other end. All finish as on [9]. Dancers entering and leaving the reel pass RSh.]

17--::

  1c set | cross RH ; repeat _while{8}_ 2c & 3c set | changes places RH ; set | Petronella turn (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3880, '2013-08-15 19:09:47.642136+00', '2013-08-15 19:09:47.642136+00', 15075, 2, 1, 'ace', '1–::
  1c+2c Tourbillon
9–::
  2c+1c+3c mirror Reel3 on sides [1c in and down; join NH where appropriate; fin facing
  1cnr]
17–::
  1c+1cnr pass & turn [1c pass R] ; 1c+2cnr pass & turn [1c pass R to 2pl]
25–::
  Circle6 and back
', 3);
INSERT INTO 'dancecrib' VALUES (11748, '2019-03-27 10:03:31.890355+00', '2019-03-27 11:51:45.357326+00', 13085, 1, NULL, 'ace', '1--::

  1c+2c The Knot, 1c finish just inside sidelines (2,1,3)

9--::

  1c dance "Gypsy Poussette"[=Box Setting + Gypsy Turn]: Set to P R and pivot R ¼ to face away from P {1}, Set L and pivot R ¼ {1} | Set to P R and pivot R ¼ to face away from P {1}, Set L and NO pivot {1} ;  Dance RSh round P 1¼ to opp. sideline facing 1cnr (2,1x,3).

17-28::

  "Fig8 Grand Chain": All dancers change places, alternately RH, LH, RH, ..., 2 bars per hand, sequentially through the positions 1W, 2W, 3W, 1M, 2M, 3M, 1W (or opposite way),  i.e. 2 short changes on the sides, plus a long change on a diagonal.  End as started (2,1x,3)

29-32::

  1c Turn P BH 1½ to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3604, '2012-07-21 11:45:40.7017+00', '2015-09-05 21:18:20.493255+00', 14419, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; cross LH | cast L into facing lines across

9–::

  All A&R (up/down) ; ½ Circle6 L

17–::

  Diagonal R&L up/down (omit final polite turn)

25–::

  Reels3{6} across, Rsh to 2cnr, to (2,1,3) | All set', 3);
INSERT INTO 'dancecrib' VALUES (3009, '2012-01-22 19:30:06.731338+00', '2019-03-21 00:19:26.992605+00', 5236, 1, NULL, 'ace', '1–::

  All A&R, cross Rsh, M making arches

9–::

  All chase clw to own sides ; ½ Rsh Reel4 (1,2,3,4)

17–::

  All A&R, cross Lsh, M making arches

25–::

  All chase cclw to own sides ; ½ Rsh Reel4, 2c&3c don''t pass but form »star«, LHJ in middle and RHJ with end dancer

33–::

  All set »in star« | turn RH ½ to bring ends into middle ; set »in star« ; Turn ½ RH to take ends out

41–::

  3c+2c LHA ; RHA to face out through the sides (1,3,2,4)

49–::

  3c+2c cast round cnrs and dance in through ends NHJ ; 3c set to 2c | set to P (end couples step in)

57–::

  1c+3c & 2c+4c Poussette (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (3755, '2013-06-06 23:25:05.418722+00', '2021-07-15 22:37:54.455852+00', 13681, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c RHA finish c facing c ; all set | 1c+4c cross inwards and face out _while_{2} 2c+3c dance to end and face in (2,1x,4x,3)

9–::

  2c turn 1c & 4c turn 3c EH on the sides and face up/dn ; ½ Reels4 on the sides, Rsh on M side, Lsh on W side (3,4x,1x,2)

17–::

  4c+1c ½ R&L ; 3c+2c turn P RH

25–::

  All circle8 and back (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (9835, '2017-05-09 12:31:50.763265+00', '2019-01-26 07:00:36.898431+00', 17736, 1, 202, 'ace', '1--::

 1c lead down (2c up) ; on [4] 1M dances below 1W, who turns under her arm ; lead up to 1plx facing out (1x,2,3)

9--::

 1c+2c turn EH on sidelines ; 1c+2c set | ½ RHA (2x,1,3)

17--::

 1c+3c set | ½ LHA ; 2c+3c+1c set | cross RH (2,3,1)

25--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (14147, '2021-07-15 22:17:35.914788+00', '2021-07-17 08:17:06.99855+00', 20392, 1, 202, 'ace', '1--::

  1c turn RH ; turn LH (1,2)

9--::

  1c+2c RHA ; LHA (1,2)

17--::

  1c cross RH | cast off (2c up) ; ½ Fig8 up round 2c  (2,1)

25--::

  Circle4 and back (2,1)', 5);
INSERT INTO 'dancecrib' VALUES (8727, '2015-03-14 20:25:20.891715+00', '2016-05-14 20:33:40.733895+00', 16160, 1, NULL, 'ace', '1--::

  1M+1W following dance Fig8 round 3c, start Rsh to 3M, finish facing 2M

9--::

  1M Lsh Fig8 round 2M & 3M _while{8}_ 1W turn 2M RH ; turn 3M LH, finish 1W with 1M behind facing 2W

17--::

  1W Rsh Fig8 round 2W & 3W _while{8}_ 1M turn 2W LH ; turn 3W RH, finish 1c facing 1cnr 

25--::

  Set H&G, Petronella to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9836, '2017-05-09 13:18:43.615566+00', '2019-07-24 11:57:24.915219+00', 10460, 1, 202, 'ace', '1--::

 1c cross RH | cast (2c up) ; set | turn RH, finishing 1W in 2Mpl facing out & 1M behind 1W

9--::

 ½ Reel3 on Mside, 1W with 1M following Rsh to 2M, on [11-12] 1W pulling Rsh back casts behind 1M, both facing Wside ; ½ Reel3 on Wside, 1M with 1W following Rsh to 3W, on [15-16] 1M pulling Rsh back casts behind 1W who faces out the top

17--::

 1c cast to 2plx ; ½ miror Reel3 on sidelines, 1c starts between 3c (2,1x,3)

25--::

 1c ½ Fig8 between 2c (to 2,1,3) ; 1W+3W turn LH _while_ 1M+3M turn RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9103, '2016-02-29 01:40:13.902729+00', '2023-01-14 16:02:06.572602+00', 16887, 1, NULL, 'ace', '1--::

  1c+4c cross RH | cast inwards, W 1 place, M 2 places passing RSh ;

  1c+4c set | &frac12; LHA to St Andrew''s cross

9--::

  BiL | &frac12; RH turn and move on 1/8 place to St George''s cross ;

  BiL | 1M+2W & 1W+3M &frac12; RH turn into prom hold, 1c on L facing 3cnr pos

  _while{2}_ 4M+2M & 4W+3W &frac12; RH turn & dance up/down to lines across

17--::

  &frac12; RSh Reel3 across to 1M+2W & 1W+3M facing 4th cnr pos ;

  1M+2W+3W & 1W+3M+2M LHA, 1c changing prom partner to 3W/2M, 1c still on L facing 1cnr pos

25--::

  &frac12; RSh Reel3 across to 1M+3W & 1W+2M facing 2cnr pos ;

  1M+3W+4W & 1W+2M+4M LHA, 1c end in centre RHJ across with P & 4c RHJ up/down with P

33--::

  1c+4c &frac12; RHA | 1c RH turn moving up to 2pl _while{4}_ 4c spiral around them to 3pl | all set (3,1,4,2)

', 5);
INSERT INTO 'dancecrib' VALUES (10124, '2017-09-15 07:24:44.907867+00', '2017-09-15 07:24:44.907867+00', 276, 2, NULL, 'ace', '*Note: this dance uses a "Petronella-to-left" sequence (4 pas-de-basque, with the middle two used to progress to the diagonal L). Also in the usual 4-bar "Petronella-to-right" sequence (Pet. turn to R & set), use both the first two pas-de-basques to progress to the diagonal R.*

1-8::

  1s dance usual Petronella-to-right sequence (Petronella turn and set, 2s step up); 1s then turn ¾ LH back to own places WHILE 2s dance usual 4-bar Petronella-to-right *(order clockwise around the "diamond" from 1M place is now 1M, 2L, 1L, 2M)*

9-16::

  1L & 2M stand (4 bars) while 2L & 1M change places by usual Petronella-to-right and Petronella-to-left respectively (1M passes inside 2L, i.e. closer to centre of the "diamond"); all RH across once round *(clockwise order from 1M place now 2L, 1M, 1L, 2M)*

17-24::

  1M & 2L, 2M & 1L change places in pairs in 4 bars, M with normal Petronella-to-right while L pass inside them with Petronella-to-left; all LH across once round *(order now 1M, 2L, 2M, 1L)*

25-32::

  *(Snowball chase, led by 1L, to progress:)* 1L dances just over once anti-clockwise around set to 2L place WHILE 1M (next clockwise) makes Petronella turn to R (2 bars) & follows 1L to 2M place, 2L stands 2 bars, makes Pet. turn to R & follows to 1L place, 2M stands 4 bars, makes Pet. turn to R and follows to 1M place

', 3);
INSERT INTO 'dancecrib' VALUES (9831, '2017-05-08 13:04:06.630648+00', '2020-11-08 11:06:53.178634+00', 17730, 2, 160, 'ace', '1-8::

  Set, cross ; cast, set adv.

9-16::

  1C 1crnrs 1/2 Reel4 (pass Lsh) ; 1C 2crnrs 1/2 Reel4. (3x 1x 2x)

17-24::

  All set, LaBaratte (3 1 2)

25-32::

  All chase CW to opp.side ; all set, cross RH to own side.', 3);
INSERT INTO 'dancecrib' VALUES (13548, '2021-01-10 09:50:44.891404+00', '2021-01-10 09:52:51.705411+00', 9020, 1, 202, 'ace', '1--::

  1W (1M following) cast off 2 places and cross (2c+3c up) ; all set | cross RH (2x,3x,1)

9--::

  1M (1W following) cast up 2 places and cross (2c+3c down) ; all set | cross LH (1,2,3)

17--::

  1c lead down | set to P ; lead up | turn BH. On [24] 2c step in ready for

25--::

  1c+2c ½ Poussette ; 1c+3c ½ Poussette', 2);
INSERT INTO 'dancecrib' VALUES (11717, '2019-03-19 21:29:26.863605+00', '2019-03-21 16:56:51.06189+00', 18356, 1, NULL, 'ace', '1--::

   1c+2c set pivoting R | chase 2 places clw {4} | 2c cross RH to own side as 1c advance, touch RH and twirl R to face 1cnr _while{8}_  3c+4c+5c set | 3c cast off one (4c up) ; 4c+3W & 3M+5c RHA, at end 3c face 1cnr

9--::

  1c & 3c ½ diag. Reel4 with 1cnrs, and pass P Rsh ; 1c & 3c turn 2cnr RH and pass P Rsh to face 3cnr 

17--::

  1c & 3c ½ diag Reel4 with 3cnrs, and meet P on midline ; 1c & 3c turn P RH ¾ and cast off one (4c+5c up) (2,4,1,5,3)

25--::

  2c+4c & 5c+3c Circle4 and back _while{8}_ 1c turn (or birl) R and L (2,4,1,5,3)







', 3);
INSERT INTO 'dancecrib' VALUES (9270, '2016-07-14 15:45:22.178519+00', '2018-10-10 20:58:22.665776+00', 17142, 1, 1041, 'ace', '1--::

  1c turn RH moving down to face 3cnr (2c up on 1-2) ; ½ Reel4 with 3cnrs, pass Lsh to face 4cnr

9--::

  ½ Reel4 with 4cnrs, curve right to face 4cnr again ; dance Rsh round 4cnr, 1c finish RHJ with P and LHJ with 3cnr

17--::

  6 bars of the Spoke (BiL{1}, advance RHJ clw to next cnr {1}, repeat twice) | 1c turn RH (3x,1x,2x)

25--::

  All chase clw ½ ; all turn P RH (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (9826, '2017-05-07 00:41:08.711999+00', '2020-11-08 11:35:06.578993+00', 17734, 2, 160, 'ace', '1-8::

  1C set, cast 1pl ; all turn RH 1/2 & Cast to opp. sides.  (2x 1x 3x) 

9-16::

  All set, dance La Baratte to end on own sides. (2 1 3)

17-24::

  All Set&Link3 twice. (3x 1x 2x)

25-28::

  Rsh 1/2 Reel3 on sides - man up lady down (2x 1x 3x);

29-32::

  Lsh 1/2 Reel3 across - man up + lady down.', 3);
INSERT INTO 'dancecrib' VALUES (9097, '2016-02-24 01:32:47.607937+00', '2016-02-24 01:32:47.607937+00', 14435, 1, NULL, 'ace', '1--::

  1c+2c set | ½ RHA ; 1c+3c set | ½ LHA (2x,3x,1)

9--::

  Reels3 on the sides, start 3c Lsh to 1c, 1W finishes facing out (2x,3x,1)

17--::

  1W with 1M following cast up and cross (3c down) ; 1c turn LH (2x,1x,3x)

25--::

  All dance down, on [28] change sides, all W crossing above the M and passing under the joined arms, and dance up to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9834, '2017-05-08 13:42:25.505362+00', '2020-11-08 11:38:42.025584+00', 17735, 2, 160, 'ace', '1-8::

  Set, cast 1pl ; Petronella Turn to lines of three across, all set.

9-16::

  Lines3 adv&ret ; 1C Petronella Turn to opp. sides, all set.

17-28::

   Rights+Lefts(3C) [12]

29-32::

  1C Turn RH 1_1/2 to own sides.', 3);
INSERT INTO 'dancecrib' VALUES (8095, '2013-10-15 23:10:36.876841+00', '2023-02-07 22:11:48.946366+00', 4246, 1, NULL, 'ace', '{{explanation}}

Couples stand in a double circle RR, M inside, facing P



1–::

  Set to P | change places RH  ;  repeat 

9–::

  W fig8 Rsh to next M to her R and Lsh to P, finish in place

17–::

  M fig8 Lsh to next W on his L and Rsh to P, finish in place

25–::

  In promhold dance cclw ; the M stand as the W dance on, past one M and join the second as new P', 3);
INSERT INTO 'dancecrib' VALUES (10365, '2017-12-28 22:27:23.440546+00', '2017-12-28 22:32:06.645861+00', 14907, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; 1c ½ Fig8 R ending BtoB in centre W(M) facing up(down)

9--::

  4 bars of Crown Triangle, 1c ending BtoB W(M) facing down(up) ; 1c cast R round 2cnrs ending BtoB in centre facing opposite sides

17--::

  4 bars of DTr ; 1c cast R round 3cnrs into lines of 3 across facing 2cnrs

25--::

  Reels3{6} across, 1c Lsh to 2cnrs to start | 1c turn P RH ¾ to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10164, '2017-10-08 16:21:16.303197+00', '2020-11-11 20:16:27.984019+00', 17981, 1, 202, 'ace', '1--::

  1c set advancing into BtoB | cast to 2plx (2c up) ; turn P RH 3/4 | pivot R to finish between end cpls facing out

9--::

  1c cast to 2plx _while{2}_ 2c+3c ½ RHA ; All chase{4} to own sides | set advancing to midline ready for (2,1,3)

17--::

  3C allemande, on [23-24], 1c turn P RH to own sides facing out (3,1,2)

25--::

  1c cast to between end cpls _while{2}_ 2c+3c ½ RHA | All chase{4} ¾ clw to own sides, 3M & 2W leading | 1W+3W & 1M+2M change places RH (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (2104, '2012-01-22 19:29:20.322493+00', '2020-11-11 20:57:03.053043+00', 9059, 1, NULL, 'ace', '1–::

  1c set | lead down crossing RH (2c up) ; cast behind 3c | lead up to 1cnr _while_{2} all cnrs set facing diagonally

9–::

  »Petronella and link with 1cnrs«: 1c set to 1cnr | 1c+1cnrs petronella , placing each 1cnr on R of 1M/W, the pairs facing each other diagonally NHJ ; S&Link, 1cnrs to place and 1c to 2plx facing out

17–::

  Reels3{6} with cnrs (Lsh to 2cnr), finish between end couples (1W above, 1M below) | 1c pass Lsh to face 2cnr _while_{2} cnrs set facing diagonally

25–::

  »Petronella and link« with 2cnr, finish with 1M/1W between 2c/3c facing out

33–::

  Reels3{6} across, (Lsh to 3cnr), 1c finish in 2plx | 1c pass Lsh to own side _while_{2} cnrs set facing diagonally [39] and partner [40]', 3);
INSERT INTO 'dancecrib' VALUES (10047, '2017-08-19 21:36:41.065039+00', '2017-08-19 21:36:41.065039+00', 3855, 1, NULL, 'ace', '1--::

  1c+2c+3c Reels3 on the sides, 2c starts out and up _while{8}_ 4c+5c DblFig8 (5c cross up) (1,2,3,4,5)

9--::

  1c+2c dbl Fig8 (1c cross down _while{8}_ 3c+4c+5c Rees3 on the sides (4c starts out and down) (1,2,3,4,5)

17--::

  All set | dance BtoB | set

25--::

  2c+3c & 4c+5c RHA ; LHA (finish one place up) _while{8}_ 1c cross RH | cast off 2 ; cross LH | cast off two (2,3,4,5,1)

', 3);
INSERT INTO 'dancecrib' VALUES (11243, '2018-10-04 05:30:22.552635+00', '2018-10-04 05:31:33.403184+00', 18724, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; cross down between 3c and cast up to 2plx (2,1x,3)

9--::

  2c+1c La-Chain (2,1x,3)

17--::

  All turn P RH ; chase clw ½ (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1821, '2012-01-22 19:29:04.208944+00', '2014-08-23 05:24:04.868193+00', 739, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; 2c+1c Circle4 L

9–::

  1c dance up | cast off ; dance down | cast up to 1cnr

17–::

  1c set to and turn corners

25–::

  1c Reels3{6} with cnrs (Lsh to 1cnrs) | 1c cross RH.', 2);
INSERT INTO 'dancecrib' VALUES (8036, '2013-09-15 21:17:15.24079+00', '2015-09-05 21:20:16.711322+00', 15126, 1, NULL, 'ace', '1–::

  1c+2c set | cross RH ; change place LH on sides | 2c cross RH _while_{2} 1c+3c change place RH on sides (2,3,1x)

9–::

  1c set | dance up, cast round 2c and meet in middle, pivot R to face 1cnr

17–::

  1c set to 1cnr | 1c curve R into 3cnr place _while_{2} the cnrs dance in and pass Rsh to face opposite cnr (place) ; 1c set to cnrs | turn cnr BH ½ to face 2cnr

25–::

  repeat [17-24] with 2cnrs, at end 1c finish in middle, 1W facing up with 1M behind

33–::

  1c dance up, cast R round 3M and cross (3x,1x,2x) ; all turn P BH 1½ (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (8131, '2013-12-07 00:30:06.87338+00', '2014-04-30 23:24:03.613253+00', 7473, 1, NULL, 'ace', '1–::
  Mirror Reels3 on own side, 2c start out and up (1,2,3)
9–::
  1c+2c S&Link ; all dance round P Rsh (no hands) (2,1,3)
17–::
  1c ½ Fig 8 R (W up, M down) ; 2c+1W & 1M+3c LHA (2,1x,3)
25–::
  Reels3{6} on the sides, 1c start Rsh to 2cnr | 1c cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3002, '2012-01-22 19:30:06.45629+00', '2023-02-08 15:29:42.822488+00', 10428, 1, NULL, 'ace', '1–::

  1c down the middle and up, finishing BtB, 1W facing 2c and 1M facing 3c (2c up on 5-6)

9–::

  1c dances as in DTr up/down, but finishes BtB facing out to opposite side _while_{8} 2c+3c set as in DTr | petronella 1 place cclw ; repeat

17–::

  1c cast L round 2cnr (pos.), pass P up/down RH, cast R round 4cnr (pos) to (3x,1,2x)

25–::

  Diagonal R&L (1W up, 1M down)', 3);
INSERT INTO 'dancecrib' VALUES (11723, '2019-03-22 20:44:33.767926+00', '2019-03-22 20:57:08.910467+00', 19246, 1, NULL, 'ace', '1--::

  1M+4W Birl R ; Birl L

9--::

  1W+4M repeat

17--::

  2c+3c RHA, LHA

25--::

  1c Birl to bottom (2c+3c+4c up) ; All Birl

', 3);
INSERT INTO 'dancecrib' VALUES (9959, '2017-06-16 16:19:47.674515+00', '2017-07-06 14:55:04.319887+00', 15297, 1, 202, 'ace', '1--::

 1c & 4c set | cast inwards (2c & 3c step out) ; 1c & 4c ½ Fig8 up/dn (2,1x,4x,3)

9--::

 1c+4c ½ R&L (no polite turn) ; 2c+4c & 1c+3c turn RH on sidelines (2,4,1,3)

17--::

 Parallel Reels4

25--::

 2c+4c & 1c+3c RHA ; 4c+1c LHA', 2);
INSERT INTO 'dancecrib' VALUES (9960, '2017-06-17 10:41:22.355468+00', '2017-06-17 10:41:22.355468+00', 17791, 2, NULL, 'ace', '*Cpls form big circle, M inside and facing P. The line of dance is cclw.(M dance forward on L foot, W on R foot.)*



1-4::

  slide three times (1-2, 1-2, 1-2) in the line of dance (that is, M dances left and W dances right) then lightly tap (never stomp) both heels twice at the same time (that is, up on the toes, down on the heels);

5-6::

  turn the W clockwise twice in-place

7-10::

  repeat the slides and taps above

11-14::

  house in-place making one revolution

15-16::

  with M reversing, walk, walk, walk, walk

17-18::

  with W reversing, walk, walk, walk, walk

19-20::

  step to the center 1-2-tap front and tap behind (same foot, W right, M left)

21-24::

  house in-place making one revolution



*repeat as desired.*', 5);
INSERT INTO 'dancecrib' VALUES (1820, '2012-01-22 19:29:04.169004+00', '2017-07-08 14:20:18.908958+00', 738, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; 1c set | cast Lsh back (W up, M down), (2W step down, 3M up) (to positions 1W,2W,3W and 2M,3M,1M respectively)

9–::

  1W+3M+2M & 1M+2W+3W diagonal Reels3, to enter 1W+3M & 1M+2W pass Lsh, and 2M & 3W cross the set, all finish in starting places, dancers facing out in 1pl and 3pl for

17–::

  Reels3 on the sides, 1c starting Rsh to middle dancer, at end they again pass that dancer Rsh, 2c+3c finish in 1pl/3pl and 1c facing 1cnr

25–::

  1c set to and turn cnrs, finish NHJ facing M side, M below W

33–::

  1c dance out between M and cast back ; dance out between W and cast to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9109, '2016-03-05 16:12:05.882637+00', '2016-03-05 17:33:39.563546+00', 16895, 2, NULL, 'ace', '1--::

  1C 1½ turn RH into: ; 1C&2C on side 1½ turn LH  

9--::

  at top 2C with partner and on side 1C&3C 1½ turn RH ; 2C&3C&1C circle 6H to left and back (2+2 steps)  

17--::

  3C (middleC) and 1st corners pass Lsh (crn turn LH) and 3C pass partner Lsh; 3C and 4th corners repeat (to 231, all in opp. pl.) 

25--::

  all set, cross over RH;  circle 6H to left and back (2+2 steps) (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (9958, '2017-06-15 12:12:00.666961+00', '2020-10-13 16:43:35.859449+00', 11163, 1, 202, 'ace', '1--::

 1c set | cast off (2c up) ; all set twice, 1c advancing to 1cnrs on [7-8] (2,1,3)

9--::

 Turn CPCP (2,1,3)

17--::

 1c set | cast off (3c up) ; all turn P BH (2,3,1)

25--::

 Circle6 and back (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (14311, '2021-09-15 11:32:31.168852+00', '2021-09-19 19:04:00.002106+00', 10493, 1, 202, 'ace', '1--::
  1c & 3c Petronella turn | turn P RH ; repeat [1-4] (1x,2,3x)
9--::
  Mirror Reels3 on sides {6}, 1c out and down, 2c in and up | 1c+2c continue the reel to exchanged places (2,1x,3x)
17--::
  1c+3c ½ R&L (to 2,3,1) ; 2c cast off to 3pl centre (3c & 1c move up one place centre on [23-24]), all into promhold (3,1,2)
25--::
  3C Allemande (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (11875, '2019-06-07 12:30:12.530728+00', '2021-04-05 21:47:37.384245+00', 7419, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 L to face 1cnrs

9--::

  »Set to Corners and Cast Away« [: 1c set to 1cnr | 1c cast RSh round P to 3cnr[pos] _while{2}_ cnrs on 1diag dance into centre and swivel R BtoB to face own cnr[pos] ; repeat, cnrs on 1diag finishing in exchanged places, and 1c facing 2cnrs]

17--::

  Repeat [9-16] with 2cnrs. On [23-24] 1c pass P RSh, finish 1M facing 1cnr[pos], 1W behind 1M

25--::

  ½ Reel3 on 1diag in tandem (with lead change). 1c face 2M, 1W leading ; ½ Reels3 on 2diag in tandem (with lead change) to 2pl (2,1,3)



*Note:  

»Set to Corners and Cast Away« is also called "Best Set in the Hall Figure".*', 2);
INSERT INTO 'dancecrib' VALUES (9428, '2016-10-11 13:56:39.302401+00', '2016-10-20 16:22:20.483866+00', 17347, 2, 2213, 'ace', '1-8::  1s cross down through 2s into reels of 3 on opp side (1x, 2, 3)

9-16::  1s ½ fig. of 8 through 2s; 1M ½ fig 8 through 2s and fin. between 2s facing down giving RH to ptnr and LH to 2L while 1L cross and cast behind 2M and face up to give RH to ptnr and LH to 2M in line across

17-24::  Balance in line| 1M & 2L turn LH while 1L & 2M turn LH ½; 1M dance down to give RH to ptnr while 1L dance down behind 3M and up to give RH to ptnr| 1s ½ turn RH and join with 3s (M to M, L to L)

25-32::  Balance in line| 1M & 3M also 1L & 3L turn LH ¾; 1L dance ½ fig. 8 down through 3s to 2nd place opp side while 1M cross and cast up to 2nd place opp side. (2, 1x, 3)

Repeat with 1s dancing partner''s track, starting from opposite sides

', 2);
INSERT INTO 'dancecrib' VALUES (8451, '2014-11-18 17:50:13.624664+00', '2017-08-19 22:13:55.038323+00', 693, 2, 160, 'ace', '1–::

 Cross, cast ; set advancing, set pulling Rsh back to face 1crnr.

9–:: 

 Turn 1crnr Rh ; dance Rsh round ptnr to end 1L btwn 2C facing up and 1M btwn 3C facing down.

17–::

 Half Lsh Reel3 across - 2M3L face out ; 1C cast R to 2pl own sides as 2L3L/2M3M (on opp. sides) change place RH. (3x, 1, 2x) | all set

25–::

 Diagonal RL - L up, M down both times.', 4);
INSERT INTO 'dancecrib' VALUES (10643, '2018-04-17 12:39:04.421625+00', '2022-12-11 11:24:51.484334+00', 13923, 1, 202, 'ace', '1--::

  Circle8 and back.

9--::

  1M set to 2W | cast (2M up) ; 1W set to 2M | cast (2W up) (2,1,3,4)

17--::

  1c cross RH | 1c+3c change places LH ; 1c cross RH | 1c+4c change places LH (2,3,4,1)

25--::

  4c+1c set advancing into midline joining hands (to 4M,4W,1M,1W) _while{2}_ 3c set advancing, 3M(3W) turning L(R) ¼ _while{2}_ 2c set, 2M(2W) turning slightly L(R) into a Y shape (>--) | all set ; 2c set to P _while{2}_ 3c & 4c & 1c retire to places | all set', 4);
INSERT INTO 'dancecrib' VALUES (7876, '2013-08-21 08:31:50.196504+00', '2023-02-04 01:23:08.577131+00', 10540, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s lead down LH, cross below 3s & cast
    up 1 place to face 1st corners
9-16::
    1s dance 1/2 diagonal reels of 4 with 1st corners; 1s pass RSh to
    give RH to partner & LH to 3rd corner (1st corner person),
    Bal-in-Line & 1s turn partner RH 1.1/4 times to face 2nd corner
17-24::
    1s repeat  9-16 with 2nd corners & 1s 1/2 turn RH to 2nd places
    opposite sides
25-32::
    3s+1s+2s chase clockwise 1/2 way & all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (10048, '2017-08-19 22:13:55.039322+00', '2017-08-19 22:13:55.039322+00', 693, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; set adv | set pivoting R to face 1cnr

9--::

  1c turn 1cnr RH ; 1c dance Rsh round P to finish between 1cnr and 4cnr, facing out the ends 

17--::

  All ½ Lsh reel3 across ; 1c continue to 2pl as 2M+3M & 2W+3W change place RH on the side (polite turns) | All set (3x,1,2x)

25--::

  Diagonel R&L (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2776, '2012-01-22 19:29:56.945634+00', '2016-11-15 16:16:34.903583+00', 4324, 1, NULL, 'ace', '1–::

  1c turn RH | cast off one place (2c up) ; 1c turn LH | cast off to 3pl (3c up) (2,3,1)

9–::

  2c+3c+1c circle6 once round to the left {6} 1c lead up to face 1cnrs (3c down)

17–::

  1c set to and turn corners and face 1cnr

25–::

  1c Lsh Reels3 with the corners {6}, 1c cross over



{{explanation}}

TACNotes says 1c NHJ on 15-16; some teachers say RHJ', 2);
INSERT INTO 'dancecrib' VALUES (9837, '2017-05-09 20:09:45.912172+00', '2017-05-09 20:09:45.912172+00', 9800, 1, NULL, 'ace', '1--::

  1c long cast (2c up) ; turn LH to face 1cnr

9--::

  1c set to 1cnr | Turn 1cnr RH ¾ into lines across and face 4cnr ; ½ Lsh Reel3 across into facing lines across

17--::

  Lines A&R ; 1c dance Rsh round P to face 3cnr (pos) 

25--::

  repeat [9-16] with these corners, finishing 1M between 2c facing 1W between 3c

33--::

  1c set adv and join RH | set RHJ, 1W turning under the arms and 1c face up RHJ still on opp. side ; 1c cross up and cast to 2pl (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10366, '2017-12-29 07:21:40.290236+00', '2017-12-29 18:56:18.504299+00', 14906, 1, 202, 'ace', '1--::
  1c+2c S&Link ; 2c+1c+3c chase clw ½, 1c ending Lsh to P in centre facing own sides
9--::
  1M+3c & 1W+2c RHA ; LHA (3x,1x,2x)
17--::
  Diagonal R&L (2,1x,3x)
25--::
  1c turn RH 1 ½ ; 1c+3c S&Link (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (9440, '2016-10-21 07:33:11.147676+00', '2016-10-21 07:33:11.147676+00', 15191, 1, NULL, 'ace', '1--::

  1c+2c R&L

9--::

  1M dances behind 2M, in front of 3M, behind 4M to beside him ; 1W dances behind 2W, in front of 3W, behind 4W to beside her

17--::

  1c lead up to 1pl ; All turn P RH

25--::

  1c cast to 4pl (2c+3c+4c up) ; All turn P LH (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (14248, '2021-08-18 16:45:32.302085+00', '2021-08-20 11:02:01.994627+00', 20431, 1, 202, 'ace', '1--::

  1W+2M cross RH | dance RSh round own P to exchanged places ; cross LH | dance LSh round own P to places (1,2)

9--::

  1M+2W cross LH | dance LSh round own P to exchanged places ; cross RH | dance RSh round own P to places (1,2)

17--::

  1W+2W & 1M+2M set | Petronella turn in tandem ; set | change places RH

25--::

  Repeat [17-20] ; all turn P BH (2,1)', 5);
INSERT INTO 'dancecrib' VALUES (8133, '2013-12-07 12:38:26.887509+00', '2014-04-30 23:23:37.765273+00', 15273, 1, NULL, 'ace', '1–::
  1c set | cast off (2c up) ; set advancing | turn BH to face 1cnr (M may twirl W under raised RH)
9–::
  Set H&G, at end 1c turn R about in PdB to face P
17–::
  1c cross up/dn | cast R to 2pl ; half turn and cast away to 2plx facing 1cnr
25–::
  Reels3 on the sides, Rsh to 1cnr, on [28] 1c turn LH to swap reels, at end join RH with LH raised palm to palm, and 1M turns W under R arm to finish in 2pl (2,1,3)

{{explanation}}
After second time through, the old 1c set and cast as new 1c do the same.  
All twirls are optional but recommended.', 3);
INSERT INTO 'dancecrib' VALUES (9110, '2016-03-05 17:33:39.56435+00', '2016-03-06 14:10:42.636378+00', 16895, 1, NULL, 'ace', '1--::

  1c turn 1½ RH ; 1c turn 2c 1½ LH on sides  (2,1x,3)

9--::

  2c turn 1½ RH as 1c turn 3c 1½ RH on sides ; All Circle L {2} and back {2} (2x,3,1x)

17--::

  3c+1cnrs "Lsh/LH Cnrs Pass and Turn", pass Lsh and face 4cnr ; 3c+4cnrs repeat, to (2x,3x,1x)

25--::

  All set | cross RH ; All Circle L {2} and back {2} (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2842, '2012-01-22 19:29:59.695864+00', '2016-03-05 17:11:06.274354+00', 4629, 1, NULL, 'ace', '1–::

  1c turn BH, cast off (2c up) ; dance NHJ between 3c, cast up to 1cnrs

9–::

  Turn CPCP to finish between end cpl facing 1cnrs, 1W above, 1M below

17–::

  Lsh Reels3{6} across (to 2,1,3) | All C turn BH

25–::

  »Cnrs Pass and Turn«: 1c pass Rsh and loop Rsh round 1cnr positions _while{4}_ 1cnrs turn each other BH, to places ; 1c pass Rsh in the middle and repeat with 2cnrs, 1c pass each other Rsh to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9965, '2017-06-18 18:58:55.896063+00', '2018-05-04 15:30:42.301144+00', 16384, 1, 202, 'ace', '1--::

 1c+2c Circle4 L ; 1c & 2c turn P BH 1 ¼ to midline

9--::

 Reel4

17--::

 1c & 2c Petronella | set ; turn P RH into allemande hold

25--::

 2C Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (13940, '2021-04-06 23:25:35.291511+00', '2021-04-06 23:28:26.173983+00', 20303, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c in and down (1,2,3)

9--::

  1c dance down ; turn RH | cast up behind 3c to 2pl (2c up) (2,1,3)

17--::

  ½ Reels3 across, 1c LSh to 1cnrs ; ½ Reels3 on sides, 1c RSh to 2cnrs[pos] (3x,1x,2x)

25--::

  1c ½ Fig8 L round 4cnrs[pos] _while{4}_ 3c+2c ½ R&L up/down ; all turn P RH (or Birl) (2,1,3)



*Deviser''s note* : During the last time through all couples birl.', 0);
INSERT INTO 'dancecrib' VALUES (10049, '2017-08-21 19:00:46.969135+00', '2017-09-10 08:02:05.499236+00', 17920, 1, NULL, 'ace', '1--::

  1c+4c set | cast inwards (2c+3c to ends) ; RHA, finish NHJ with P and facing “corner” on 1diagonal

9--::

  1c+4c “Tandem SetH&G” to cnrs :  1c+2M & 4c+3L set, 1c+4c moving “in tandem” to sidelines | 1c set to 4c, moving “in tandem” to face corner on 2diag ; set to cnrs and move “in tandem” to between end cpls in lines of 4 across | Set to opposite line4 across

17--::

  4c (1W leading) +2c & 1c (1M leading) +3c Rsh Reels3 across, at end flowing into 

25--::

  4c+1c LHA, finishing (2,4x,1x,3) ; 4c+ 1c turn P LH 1½ (2,4,1,3)

33--::

  2c+4c & 1c+3c Poussette (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (1698, '2012-01-22 19:28:57.257407+00', '2021-01-10 14:13:48.540914+00', 10580, 1, NULL, 'ace', '{{explanation}}

Start in cross pattern: W in the middle facing M on the outside



{{title}}

Strathspey:



1–::

  All set to P | Adv.{1} & Ret. {1} (Highland style) ; Turn P BH 1¼ to form square set

9–::

  Interlocking Reels4, start Rsh to P, M finish ready for

17–::

  Intersecting M-Chain (M ½ LHA | M turn opposite W RH ; ½ LHA, M turn P RH into middle)

25–::

  All dance the Square Knot (turn RH ½ | in allemande hold ¼ round cclw ; LH turn 1½  to bring W into the middle).



{{title}}

Jig:



33–::

  All M coupé+PdB twice _while{4}_ W 2 spring points+PdB twice ; All turn P RH 1¼ to face P

41–::

  Interlocking Reels4, start Rsh to P, M finish ready for

49–::

  Intersecting M-Chain

57–::

  All dance The Knot, ending opposite original starting positions



{{explanation}}

Repeat once', 3);
INSERT INTO 'dancecrib' VALUES (1822, '2012-01-22 19:29:04.253864+00', '2014-04-30 23:23:41.74831+00', 743, 1, NULL, 'ace', '1–::
  1c Turn RH, cast off (2c up) ; turn LH, 1M/1W cast L (down/up) to between 3c/2c
9–::
  Set twice in lines of 3 across ; 1c cast back and Turn RH to (2,1,3)
17–::
  All set twice in sidelines ; turn partners BH
25–::
  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (1823, '2012-01-22 19:29:04.298013+00', '2014-04-30 23:23:41.763394+00', 745, 1, NULL, 'ace', '1–::
  1c set H.Schottische, turn 1¾ BH (2c up) to between end couples, in facing lines across
9–::
  All set H.Schottische, facing pairs turn BH 1½ into facing lines across
17–::
  Repeat bars 9-16, but 1c finish between end couples facing 4cnr
25–::
  Rsh Reels3 across, 1c pass Rsh to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2070, '2012-01-22 19:29:18.17854+00', '2016-10-25 03:07:37.785945+00', 8859, 1, NULL, 'ace', '1–::

  Tourbillon and Link: 1c+2c Tourbillon for {6}, ending 2c facing 1c up/down NHJ | 2c+1c Link across the set (to 2,1,3)

9–::

  All Set, Circle6 ½ round ; S&Link3 into facing lines across

17–::

  Repeat [9-16], to (3x,1x,2x)

25–::

  All Advance {1}, retire {1} | Turn BH 1½ | set (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (9442, '2016-10-24 23:00:56.262728+00', '2016-10-25 13:43:14.669073+00', 8676, 1, NULL, 'ace', '1--::

  1M+2W set adv | dance Rsh round the other, to places ; Circle4 L ½ | set facing in (2x,1x)

9--::

  1W+2M repeat, finish on 1diag facing P 

17--::

  Reel4 on 1diag, finish as started

25--::

  1c+2c Turn BH into | ½ Poussette | All set (2,1)



', 3);
INSERT INTO 'dancecrib' VALUES (11246, '2018-10-04 08:04:53.683458+00', '2018-10-04 08:07:07.646961+00', 9493, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 up round 2c (2,1,3)

9--::

  2c cross RH | cast to 3plx _while{4}_ 3c turn RH ½ and dance up to 1plx ; all turn RH (3x,1,2x)

17--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11245, '2018-10-04 05:45:15.450412+00', '2018-10-06 12:22:55.480832+00', 18726, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c RHA ; LHA into Reel4 position (1,2,3,4)

9--::

  Parallel Reels4 (1,2,3,4)

17--::

  1c+2c ½ R&L ; 1c+3c ½ R&L (2x,3x,1,4)

25--::

  1c+4c ½ R&L ; all set | cross RH (2,3,4,1) ', 2);
INSERT INTO 'dancecrib' VALUES (9111, '2016-03-05 18:17:03.675089+00', '2016-06-03 14:04:19.199014+00', 16896, 2, 1, 'ace', '1–::

  1c cross down LH, 1W/1M Figs8 round 2c/3c (pass between, meet & touch NH,

  out between same couple, cast up, turn RH ½ to place.

9–::

  *[Circular rose progression]*

  W set _while_ M dance RA and pull RS back to face next W clockwise |

  M dance out _while_ W (passing M by RS) dance RA

  and pull RS back to face ptr ;

  all ½turn BH & pivot in place ¾ to fin M facing acw, W cw |

  all dance round ptr RS to sides [3, 1, 2]

17–::

  Interlocking reels4 (start RS to ptr, on bar 24 turn RH to prom hold

  facing acw)

25–:: *[Three-couple circular tournée, all dancing as 2nd couple]*

  All prom 2 places round, on bar 28 M pass W in front of them and turn about

  [M finish on outside facing cw, W on inside facing acw] ;

  All turn R 1¼ to sides [to 2, 3, 1]', 3);
INSERT INTO 'dancecrib' VALUES (13288, '2020-10-21 00:00:26.573474+00', '2020-10-21 20:34:57.248915+00', 9293, 2, 35787, 'ace', '1-8::
  1s Fig 8 round 2s while 2s set & cross & repeat
9-16::
  M1 & W2 set advancing, turn 2H to end facing ptnr; ½reel-4 along diagonal
17-24::
  W1 & M2 repeat, ending with 1s & 2s having changed places
25-28::
  2s+1s set; RHA halfway
29-32::
  1s+2s set & link', 0);
INSERT INTO 'dancecrib' VALUES (9961, '2017-06-17 21:18:12.711829+00', '2021-01-04 12:12:03.281002+00', 14156, 1, 202, 'ace', '1--::

 1c cross RH | cast (2c up) ; 1c+1cnrs S&Link finishing facing each other (to 2W+3W+1M on W side, 1W+2M+3M on M side)

9--::

 Reels3{6}, 1c (in 1diag) Rsh to 1cnrs (in 2pl) | 1c cross diag RH (to 2W+3W+1W on W side, 1M+2M+3M on M side)

17--::

 3W+1W & 1M+2M S&Link ; All turn P BH (2,1,3)

25--::

 2c+1c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1825, '2012-01-22 19:29:04.407012+00', '2018-07-21 05:52:55.636492+00', 754, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; cross RH | cast off (3c up) (2,3,1x)

9–::

  3c+1c circle4 L, to sidelines ; 1c dance to the top | cast off to face 1cnrs (3c down)

17–::

  1c set to and turn corners

25–::

  Reels3{6} on the sides (Lsh to 1cnr) | 1c cross over (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8135, '2013-12-08 21:49:37.008286+00', '2019-02-12 23:37:16.143413+00', 14725, 2, 1058, 'ace', '1-8:: 1s dance down two steps, set to each other, dance back to places &1s, 2s & 3s turn BH ending in Prom hold.

9-16:: 1s, 2s &3s promenade

17-24:: 1M & 2M make an arch & cross to ladies side while 1L & 2L take hands and cross  under M’s arch,1M & 2M change place LH, while, 1L & 2L change RH,  	2s &1s cross RH, 1s, cast to 3rd pl while 3s step up.

25-32:: 3s & 1s Poussette right round.', 0);
INSERT INTO 'dancecrib' VALUES (10311, '2017-12-13 05:53:05.788049+00', '2020-11-12 10:26:00.484475+00', 18063, 2, 160, 'ace', '1-8::  1C cross RH, cast (2C up)  ; dance around ptner 1_1/4 by Lsh to finish 1M btwn 2C facing up and 1W btwn 3C facing down.

9-12::  half reels 3 across - Give Rsh to person on the right  (2nd corner) ;.

13-16::  1C complete the track of the reel _While_ corners dance 1/2 mirror reel 3 on opp. sides - 3C dancing up the side cut the reel in front of 2C  (women  -on men''s side pass Lsh and the men (on the women''s side) pass Rsh).

17-24::  1C dance Rsh round 2nd corner position into 2nd place opp. side ; change places with 1/2 turn&twirl. _While_ corners set, turn with RH once round [4] and twirl to end back in place. 3x 1 2x

25-32::  Half Right&Left on diagonal - woman up+man down; that again.

33-40::  6 hands round and back

', 2);
INSERT INTO 'dancecrib' VALUES (12325, '2019-10-30 00:19:44.24706+00', '2020-11-13 10:19:37.624539+00', 18181, 1, 202, 'ace', '_Reel_



1--::

  Mirror Reels3 on sides, 1c crossing down (1x,2,3)

9--::

  1c set | cast off (2c up) ; turn 2cnrs RH twice (2,1x,3)

17--::

  1c set | turn P LH to face 1cnrs ; turn 1cnrs RH 1¾ into facing lines3 across

25--::

  1c cross RH | dance RSh round 2cnrs to 2plx ; cross RH | set _while{8}_ 2c+3c R&L up/down (2,1,3)



_Strathspey_  

  Repeat [1-32]', 2);
INSERT INTO 'dancecrib' VALUES (10166, '2017-10-08 21:45:19.237239+00', '2020-11-12 08:19:39.201485+00', 17986, 1, 202, 'ace', '1--::
  1c turn RH | cast off (2c up) ; turn LH | cast off (3c up) (2,3,1,4)
9--::
  1c dance down between 4c | cast up to 3pl ; dance up between 3c | cast off to 3plcentre, on [16], 2c & 3c step in ready for
17--::
  2c+1c+3c Promenade (2,3,1,4)
25--::
  4c turn RH | cast up (1c down) ; turn LH | cast up (3c down) (2,4,3,1)
33--::
  4c+3c ½ RHA | 4c & 3c turn{6} P RH 1½ (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (7988, '2013-08-21 08:31:54.135534+00', '2023-02-04 01:23:15.066032+00', 7220, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, 2s set & cast back to places
9-16::
    1L+2M cross RH, 1M+2L cross RH, 2s+1s turn partners RH 1.1/2 times
17-24::
    1s lead down below 3s, cross & cast to 2nd place, 2s+1s+3s Adv+Ret
25-32::
    1s dance reels of 3 on opposite sides (RSh to 2nd corners to start)
    & 1s cross LH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (9842, '2017-05-13 16:01:09.00893+00', '2017-08-26 13:41:22.180383+00', 14641, 1, 202, 'ace', '1--::

 1c+2c Tournée (2,1,3)

9--::

 1W+2c & 1M+3c RHA ; 1W+3c & 1M+2c LHA, 1c pass Lsh to face 1cnrs

17--::

 SetH&G (2,1,3)

25--::

 1c+3c Tourbillon (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (9848, '2017-05-14 01:43:25.114094+00', '2017-08-26 11:56:52.192734+00', 14073, 1, 202, 'ace', '1--::

 1c+2c S&Link ; 2c+1c cross RH | 2c+1c set (2x,1x,3)

9--::

 1c+3c S&Link ; 3c+1c cross RH | 3c+1c set (2x,3x,1)

17--::

 1c cast to 1pl _while_  2c+3c cross down LH | all set ; all turn RH into promhold

25--::

 1c+2c+3c Promenade, on [31-32] 1c cast off & 2c dance up (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13550, '2021-01-10 17:47:12.478411+00', '2021-01-10 17:48:12.587454+00', 9236, 1, 1645, 'ace', '1-::

  *Muirland Willie figure:* 1c lead down RH, cross & cast up to 2plx _while{4}_ 2c set | cross down RH _while{4}_ 3c cast up to 1pl | cross RH (3x,1x,2x) ; all repeat [1-4] from new places, but 3c & 1x lead/cross down LH (2,3,1)

9-::

  All repeat [1-4] from new places (1x,2x,3x) ; all set | cross RH (1,2,3)

17-::

  Circle6 & back

25-::

  1W+2W & 1M+2M continue slipping R, W face down, M face up | set to P ; change pl LH with P | chase &frac14; cclw (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3789, '2013-07-13 15:56:07.002381+00', '2015-03-24 13:23:26.896024+00', 8674, 1, NULL, 'ace', '{{explanation}}

1- 4::

  1c+3c Turn RH ¾ | set to P and face P

5-16::

  All “Dance to each ''Corner'' & Set”, finish in diagonally opposite places.  *[explanation: [5-6] In the diamond pattern, each “centre” dancer changes place Rsh with the facing “corner _while{2}_ these “corners” pass Rsh in the centre to face the “corner” to the R _while{2_} the other two “corners” set.  Repeat figure 5 more times.]*

17-24::

  1s+3s ½ Reel4 on midline ; All set to P | All turn P LH to finish 3c in 3pl and 1c+2c ready for

25-32::

  1c+2c Poussette.  (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9839, '2017-05-11 07:10:18.747628+00', '2017-08-23 22:15:28.496222+00', 17749, 1, 202, 'ace', '1--::

 1c turn RH ½ | lead down ; lead up to between 2c BtoB in middle | set

9--::

 Reel4 across

17--::

 1c set twice to face down ; cross down | cast to 1pl

25--::

 1c+2c RHA ; ½ poussette (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (9845, '2017-05-13 18:59:37.716981+00', '2017-05-13 18:59:37.716981+00', 17750, 2, NULL, 'ace', '1-8::

  Lead down and up.

9-16::

  Chase:- IL followed by ptnr dance down behind ladies, cross below 3C ; dance up behind 3M, cross to 2nd place own side - 1C finish facing down in 2pl own sides.

17-24::

  All dance Grand Chain.

25-32::

  6 hands round and back.', 3);
INSERT INTO 'dancecrib' VALUES (3728, '2013-04-15 19:08:02.002573+00', '2014-04-30 23:24:15.677349+00', 14811, 1, NULL, 'ace', '1–::
  1c lead down the middle {3}, up {3} cross and cast off (2c up) (2,1x)
9–::
  R&L
17–::
  La-Chain
25–::
  All A&R ; 1c turn RH 1½ (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (10645, '2018-04-17 15:21:36.223682+00', '2022-07-21 15:02:13.277419+00', 10069, 1, 202, 'ace', '1--::

  1c dance in, cast to 2pl ending BtoB in centre, 1W(1M) facing up(dn) ; 1W+2c & 1M+3c Circle3 {3} L, on [8] 1c pull Rsh back into facing lines of 3 across

9--::

  All set | 3C Petronella turn ; repeat [9-12]

17--::

  All set | Circle6 L, 1c finishing BtoB facing 3cnrs position

25--::

  ½ Reel4 on 1diag, 1c turn P RH to face 2cnrs position ; ½ Reel4 on 2diag (2,1,3) ', 2);
INSERT INTO 'dancecrib' VALUES (9846, '2017-05-14 00:25:36.568142+00', '2017-08-25 06:18:47.993847+00', 17751, 1, 202, 'ace', '*3c+4c start on opp sides*

1--::

 1c&4c turn RH ½ | lead dn/up (2c&3c step out) ; 1c+4c RHA, finish in centre

9--::

 ½ tandem Reel4 in 1diag, M leading (change lead on [11]), Cs pass Rsh ; ½ tandem Reel4 in 2diag, W leading (change lead on[15]), Cs pass Lsh to (3,1,4x,2x)

17--::

 Parallel Reels4

25--::

 3c+1c & 4c+2c Circle4 and  back

33--::

 All A&R ; all turn RH', 3);
INSERT INTO 'dancecrib' VALUES (1715, '2012-01-22 19:28:58.04024+00', '2016-03-06 18:57:12.360519+00', 353, 1, NULL, 'ace', '1–::

  1c pass Rsh (2c dance up sidelines) to finish BtoB, 1M facing 3c and 1W facing 2c | ¾ of Crown Triangles (set to 1cnr+4cnr | to 4cnr+3cnr | to 3cnr+2cnr)

9–::

  Diagonal Reel4 with 2cnrs, pass Rsh

17–::

  Diagonal Reel4 with 1cnrs, at end pass Rsh to (2,1x,3,4)

25–::

  1c set | cast off one (3c up) ; cross RH | 1c+4c change places LH (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (9112, '2016-03-06 21:34:02.786638+00', '2016-03-06 21:34:02.786638+00', 10699, 1, NULL, 'ace', '1--::

  1c lead down 2 | cross below 3c (2c up) ; cast up | 1c set to 2c (2,1x,3)

9--::

  2c+1c L-Chain

17--::

  All Circle6 and back

25--::

  1c ½ Fig8 L (round 4cnr) ; All turn P RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1961, '2012-01-22 19:29:12.180569+00', '2016-08-20 20:59:17.38923+00', 1274, 1, NULL, 'ace', '1–::

  1c+2c dance BtoB ; turn RH

9–::

  1M dances Rsh round 2W to 2M place _while{4}_ 2M, passing behind 1M, dances Rsh round 1W to 1M''s place ; all clap and Circle4 L

17–::

  1W+2W dance Rsh round P (who is not opposite her), 1W passing in front, to finish in exchanged places (2,1) ; all clap and Circle4 L

', 4);
INSERT INTO 'dancecrib' VALUES (9849, '2017-05-14 17:02:50.290463+00', '2017-08-09 06:09:28.71551+00', 16488, 1, NULL, 'ace', '1-4::

  1c Turn BH 1¼ moving down to face 1cnr (2c up) 

5-16::

  Dance to each cnr and set, 1c turn RH ½ to face opp. side 

17--::

  3c+1M & 1W+2c LHA ; Rsh Snake Pass (unwind the LHA, 1c leading, pass other snake Rsh through 2plx and chase clw to (2x,1,3x)

25--::

  Circle6 L ½ ; All turnP BH to own side (1c 1½ turn)

', 3);
INSERT INTO 'dancecrib' VALUES (9867, '2017-05-19 16:46:21.458452+00', '2017-08-25 17:38:14.458919+00', 10658, 1, 202, 'ace', '1--::

 1c/3c cross RH to 2plx/4plx (2c/4c up) | 1c & 3c cast R to midline, 1M & 3W BtoB in centre, 1W/3M between 2c/5c facing P ; 1c & 3c set | turn RH into promhold facing 4W and 5W respectively

9--::

 Parallel Reels3 in 1diag, 1c & 3c finishing in middle facing down

17--::

 1c/3c dance down between 4c/5c | cast to 2plx/4plx (to 2,1x,4,3x,5) ; 1c & 3c set to P | turn RH into promhold facing 2W and 4W respectively

25--::

 Parallel Reels3 in 2diag (2,1,4,3,5)

33--::

 1c+4c & 3c+5c Espagnole (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (6825, '2013-08-21 08:31:31.517939+00', '2023-02-08 15:29:42.828201+00', 10428, 3, NULL, 'ace', '1-8::

    1s lead down the middle & back to 2nd place BtoB in middle (Lady

    facing up & Man down)

9-16::

    1s dance Double Triangles (Lady with 2s & Man with 3s to start) when

    1s change places corners petronella 1 place to right & 1s end BtoB

    facing opposite sides _while_ corners end diagonally opposite

    original places

17-24::

    1s cast LSh round 2nd corners, pass giving RH & cast RSh round 4th

    corners to 2nd place own sides

25-32::

    1s dance Diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (8134, '2013-12-07 21:50:18.545834+00', '2013-12-07 21:50:18.545834+00', 15279, 2, 1, 'ace', '1–::
  1L+2L+3L dance round partner RSh and back to place | 1c+2c+3c cross RH
9–::
  1M+2M+3M dance round partner Rsh and back to place | 1c+2c+3c cross RH (1c fin facing out)
17–::
  1c cast off 2 places (2c up on 17–18), dance up, cast off
25–::
  2c+1c+3c Adv+Ret ; 2c+1c+3c turn RH', 3);
INSERT INTO 'dancecrib' VALUES (11503, '2019-01-08 10:57:44.486234+00', '2022-02-15 15:31:04.286+00', 14441, 1, 1645, 'ace', '1-::

  1M casts off, crosses below 3c, casts round 3W to face up between 3c _while{8}_ 1W+2c circle3 & back to line across in 1pl

9-::

  1c set adv | turn &frac34; BH to face 1cnrs ; 1c &frac12; Reel4 with 1cnrs & pass LSh to face 2cnrs

17-::

  1c &frac12; Reel4 with 2cnrs (3x,1x,2x) ; 1c cross RH | set, pulling RSh back to face out (3x,1,2x)

25-::

  1 cast R, dance in through ends & turn &frac34; RH, 1M ends facing out _while{8}_ 3c & 2c set facing down/up | change RH on sides ; set to P | cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13290, '2020-10-23 15:13:38.178122+00', '2020-10-24 19:01:50.045587+00', 20136, 1, 202, 'ace', '1--::
  1c cross RSh | cast off (2c up) ; ½ Fig8 L round 4cnrs (2,1,3)
9--::
  All set | cross RSh ; chase clw ½ (3,1,2)
17--::
  3c+2c DblFig8, 3c casting (3,1,2)
25--::
  All set | cross LSh ; chase cclw ½ (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (9116, '2016-03-15 11:49:48.204556+00', '2016-05-25 08:46:52.405403+00', 16904, 1, NULL, 'ace', '*Strathspey*

1-6::

  1c+3c ½ R&L and set _while{6}_ 2c+4c set and ½ R&L, finish facing out (2W+4W twirl L)

7-8::

  All turn corner EH ½ into square set all facing in (all now face P)

9--::

  2c+4c dance in to meet P | dance out between side cpls ; split and dance apart, and form longwise set middles facing ends | all set.



*Reel*



17--::

  Reels4 on both sides, finish in a square set, all facing clw, the W ready to cast R

25--::

  The M chase just over ½ round clw, as each W loops R and follows the M who started behind her, finish in a square set | All set.



*On each repeat, the men move one place clw, the women one place cclw.*

', 3);
INSERT INTO 'dancecrib' VALUES (8197, '2014-02-13 23:59:10.867227+00', '2015-08-18 15:06:45.972625+00', 14813, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; 1c Petronella to between end couples and set _while{4}_ 2W + 3M stand and change places RH

9-12::

  1c Petronella to 2plx and set _while{4}_ 3W + 2M stand and change places RH (3x,1x,2x)

13-24::

  R&L for 3 couples (no polite turn at end) (3x,1x,2x)

25–::

  All Turn P RH ; all chase ½ clw (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10392, '2018-01-19 02:04:39.708973+00', '2020-11-11 12:55:30.664809+00', 17965, 2, 963, 'ace', '1-8::

  1c+3c lead down middle and back. 1c face out  

9-16::

  1c+5c fig 8 on side around 3c, 1s down and out, 5s in and up to start  

17-20::

  1c cast to 5th place, 2,3,4,5 up on 19&20  

21-24::

  All turn partner RH  

25-32::

  Circle 10 hands round and back	

', 3);
INSERT INTO 'dancecrib' VALUES (9499, '2016-11-15 01:12:10.639239+00', '2016-11-19 16:39:10.83728+00', 17481, 2, 1, 'ace', '1–4::

  1c cross RH | cast off (2c up) _while_ 4c cross RH | cast up (3c down)

5–8::

  1c+4c RH across

9–12::

  2c cross LH | cast off (1c up) _while_ 3c cross LH | cast up (4c down)

13–16::

  1c+2c, 3c+4c LH across

17–::

  All set | ½turn & twirl RH to own sides | set adv

25–::

  “Interlocking Poussettes”: 1c+2c, 3c+4c dance poussette but 1c and 4c

  move past each other to fin in order 2413.', 5);
INSERT INTO 'dancecrib' VALUES (2854, '2012-01-22 19:30:00.200689+00', '2016-12-23 01:13:35.047936+00', 4662, 1, NULL, 'ace', '1–::

  Inveran reels{6} (1c cross down from top, cross up from bottom) | 1c cross RH to (1x,2,3)

9–::

  1c set advancing | turn BH ; dance down between 2c, cast behind 3c, finish BtoB between 3c facing opp. side

17–::

  1M+3W & 1W+3M set & turn EH ¾ (1c start out between 2c and 3c) ; 1c dance up , cast up behind 2c, finish BtoB between 2c facing opp. side

25–::

  1M+2W & 1W+2M set & turn EH ¾ (1c start out between 2c and 3c) ; 1c ½Fig8 round 2c to (1,2,3)

33–::

  1c+2c Circle4 L ; 1c facing 2c NHJ set and 1c face up | 1c cast off _while{2}_ 2c lead up (2,1,3)

41–::

  1c+3c repeat [33-40] to (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (9966, '2017-06-18 23:32:01.375719+00', '2017-06-18 23:57:25.281206+00', 12516, 1, 202, 'ace', '1--::

 1c cross RH | cast to 2plx (2c up) ; 2c+1c RHA (2,1x)

9--::

 2c+1c Circle4 and back

17--::

 2c+1c Petronella in tandem | set ; repeat [17-20] (1,2x)

25--::

 1c+2c ½ R&L ; 1c ½ Fig8 through 2c (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (9689, '2017-03-31 00:27:00.872659+00', '2021-03-19 10:48:33.509712+00', 8485, 1, 202, 'ace', '1--::

 1c+2c RHA ; LHA

9--::

 All set | cross RH ; repeat [9-12]

17--::

 1c lead down the middle (2c up) ; and up to face 1cnrs

25--::

 SetH&G to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9117, '2016-03-15 14:08:02.640837+00', '2016-03-15 22:58:51.696649+00', 16508, 1, NULL, 'ace', '1--::

  1c+2c The Knot (2,1,3)

9--::

  1c dance down | turn BH ; dance up | turn BH ½ and cross to face out on own side (2,1,3)

17--::

  Chaperoned Chain Progression, finish on sidelines (3,1,2) [2c+3c turn RH ¾ as 1c cast ¼ clw | 2M+3W turn 1½ LH as 1c+outers in promhold chase ½ clw | 3c+2c turn RH ¾ as 1c chase to 2pl]

25--::

  1c+2c Poussette (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (9445, '2016-10-26 00:24:36.183891+00', '2016-10-26 00:34:31.988752+00', 220, 1, NULL, 'ace', '1--::

  1c+2W RHA ; 1c (W leading)+2M LHA, to places

9--::

  1c+2c R&L

17--::

  1c lead down and up (1,2)

25--::

  1c+2c dance “New Poussette”: 

::

  25-26   set adv. to meet P and turn BH 3/8 (M above and to W side of W), couples side by side

::

  27-28   set BHJ advancing diagonally to sideline (to 1c opposite 2c) and turn cclw ¼ 

::

  29-30   set BHJ advancing diagonally to midline, facing P, 2c above 1c, M above W

::

  31-32   turn P RH to (2,1)



*(crib is uncertain)*

', 1);
INSERT INTO 'dancecrib' VALUES (9850, '2017-05-14 19:55:08.703776+00', '2017-05-14 19:55:08.703776+00', 16489, 1, NULL, 'ace', '1--::

  All set | 2c turn RH ¾ to face 4cnr ; ½ Rsh Reels3 across, to (1x,2,3x) 

9--::

  All set | 2c turn LH ¾ to face 3cnr ; ½ Lsh Reels3 across, at end 2c pass Lsh to face 1cnr

17--::

  1c+1cnrs Pass &Turn (cnrs turn BH), 2c pass Rsh ; 1c+2cnrs Pass & Turn, 2c pass Rsh to (1,2,3)

25--::

  2c + 3c following dance up and cast off to (1,3,2) ; 3c + 1c following dance down and cast up to (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (9851, '2017-05-14 20:19:57.97492+00', '2017-05-14 20:19:57.97492+00', 16490, 1, NULL, 'ace', '1--::

  1c dance down two and cast up (2c up) ; All turn P RH to allemande hold facing up (2,1,3)

9--::

  3C Allemande (3,1,2), 1c finish facing 1cnr (pos)

17--::

  1c+1cnrs change place Rsh on 1diag as other cnrs set | “outsides” chase 1 pos clw as “centres” turn LH to face the cnr that they left ;  repeat [17-20] from new places

25--::

  Repeat from new places, 1c in the middle turning LH to face their 3cnr (pos) ; ½ Lsh Reels3 across, 1c meet and turn L about into

33--::

  Double Triangles (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9967, '2017-06-18 23:57:03.647882+00', '2018-09-19 09:48:36.284985+00', 17797, 1, 202, 'ace', '1--::

 1c+2c set | Circle4 L | 1c dance to 2pl (2c up) _while{2}_ 3c set (2,1,3,4)

9--::

 1c+3c Circle4 L ; 1c followed by 3c lead down through 4c and cast up to places (2,1,3,4)

17--::

 2c+1c+3c mirror Reels3, 1c start in and up

25--::

 1c+3c ½ R&L ; 3c & 1c cross RH | 1c+4c change pl LH on sidelines (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12760, '2020-04-13 09:18:48.271974+00', '2020-04-13 09:19:12.018654+00', 19954, 1, 1645, 'ace', '1-::

  1c set advancing | turn BH & face out ; &frac12; turn 2c EH (2,1,3) | set advancing to 1cnrs

9-::

  1c+1cnrs Pass & turn BH, 1c pass touching BH & face 2cnrs ; repeat with 2cnrs to own sides (2,1,3)

17-::

  1c+3c dance up | cast off (2,3,1) ; all set | turn BH & open out for

25-::

  Circle6 to L, pivot ; chase back (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (10646, '2018-04-17 15:45:01.465719+00', '2018-04-18 15:39:16.160485+00', 13921, 1, 202, 'ace', '1--::
  1c cross RH | cast (2c up) ; cross down LH between 3c | cast up to 2pl (2,1,3)
9--::
  1W+2c & 1M+3c RHA, pass Rsh ; 1W+3c & 1M+2c LHA, pass P Lsh into
17--::
  Reels3 across, 1c start Lsh to 1cnrs (2,1,3)
25--::
  All set | dance BtoB | set (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (1827, '2012-01-22 19:29:04.512166+00', '2017-11-14 15:46:17.391118+00', 13003, 1, NULL, 'ace', '1–::

  1c cross RH, cast off (2c up) ; lead up and cross, cast off (2,1,3)

9–::

  2c+1W & 1M+3c RHA ; 1c turn LH 1½ to face 2 cnrs

17–::

  Turn 2cnr RH, P LH, 1cnr RH, P LH (2,1,3)

25–::

  2W+1W & 1M+3M (=1c+4cnr position) set, turn RH ; 1W+3W & 2M+1M set, turn LH', 2);
INSERT INTO 'dancecrib' VALUES (2119, '2012-01-22 19:29:21.122432+00', '2016-05-31 07:50:16.188436+00', 1786, 1, NULL, 'ace', '1–::

  1c+2c set, ½ RHA ; set, ½ LHA

9–::

  1M+2W set advancing, turn RH ; 1W+2M repeat

17–::

  1c cross RH, cast off (2c up) ; ½ Fig8 up round 2c

25–::

  2c+1c R&L.', 3);
INSERT INTO 'dancecrib' VALUES (11247, '2018-10-04 10:28:38.223194+00', '2022-08-17 18:44:38.358556+00', 18741, 1, 202, 'ace', '1--::

  2c dance down round 3c and cast up to 2pl ; 2W+3W & 1M+2M S&Link

9--::

  3C Bourrel. On [15-16] 2c turn BH to face 1cnrs (3,2,1)

17--::

  CPCP. On [23-24] 2c turn LH to 2pl centre facing up

25--::

  2c dance to top | cast to 3pl (1c up) ; all turn P RH (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (9283, '2016-08-22 19:30:30.91499+00', '2016-08-22 21:16:01.476942+00', 17194, 1, NULL, 'ace', '1--::

  1c+2c Circle4 R ; and back, into

9--::

  1c+2c Allemande (2,1,3)

17--::

  1c set advancing pivoting R to DTr position | All 6 bars of DTr, finish 1c RHJ to 1cnr

25--::

  CPCP to (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (9852, '2017-05-14 22:15:05.008075+00', '2017-05-14 22:15:05.008075+00', 16492, 1, NULL, 'ace', '1--::

  2c+3c Circle4 L ; 2c & 3c dance out their own end and cast back to (1,2,3,4)

9--::

  2c+3c RHA ; 1c+2c & 3c+4c LHA (1,2,3,4)

17--::

  Lsh Reels4 on own sides (1,2,3,4)

25--::

  1c+2c change places LH on sides | 1c+3c repeat RH ; 1c+4c repeat LH | All set (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9119, '2016-03-16 20:11:49.42455+00', '2016-03-16 20:11:49.42455+00', 16906, 2, NULL, 'ace', '1-8::

  1C 2C Tourbillon.

9-12::

  All Set and Link3 to lines of 3 across ;

13-16::

  All set,  turn opp. BH half-round and twirl to end Back-to-Back with opp.

17-20::

  Lines of 3 chase clock-wise back to lines of 3 across top and bottom places ;

  Note- corner couples are now in partner''s place.

21-24::

  All set and link3 to end on the sides - 3, 1x, 2

25-32::

  6 Hands round and back. On bars 27-28 1C exchange places by turning RH 3/4 as the circle continues round to the left.', 2);
INSERT INTO 'dancecrib' VALUES (1967, '2012-01-22 19:29:12.463235+00', '2017-08-25 23:31:27.639309+00', 8732, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; 1c petronella to between end couples (W up, M down) | 1c set

9--::

  Opposing Reels3 across, 1c Rsh to 1cnr, at end 1c quick LH turn into

17--::

  Opposing Reels3 across, 1c Rsh to 3cnr, finish 1M between 2c, 1W between 3c, and facing P 

25--::

  1c set adv (pass Rsh) to face 1cnr | turn 1cnr RH to between other end couple ; 1c set adv. to face 2cnr (pass Lsh) | turn 2cnr LH to finish BtoB facing 1cnr

33--::

  1c set to 1cnr | to 2cnr into 2plx ; turn RH 1½ to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10399, '2018-01-25 12:48:28.126947+00', '2022-01-29 17:15:22.204569+00', 18228, 1, NULL, 'ace', '1--::

  1c lead down (2c up on [3-4]) ; and up, crossing to face out above 1pl

9--::

  1c cast off to 2plx | All set ; All A&R but 1c remains in centre facing P (2,1x,3)

17--::

  1c slip down | turn RH ½ ; slip up | turn RH to face 1cnrs

25--::

  1c set H&G (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11497, '2019-01-05 11:33:45.750896+00', '2022-02-15 15:35:47.942047+00', 14443, 1, 1645, 'ace', '1-::

  All turn P &frac34; RH | &frac12; Reel6 on centre line, end facing P up/down (3,2,1)

9-::

  All set to P | 3c & 1c turn &frac34; RH to sides _while{2}_ 2c turn RH ; 3c+2M & 2W+1c LHA

17-::

  2M+3c & 2W+1c snake passing RSh to (1,2,3) ; all set | turn P BH, 1c & 2c finish ready for

25-::

  1c+2c &frac12; poussette ; 1c+3c &frac12; poussette (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (14818, '2022-05-08 08:52:56.967359+00', '2022-05-08 08:56:23.245773+00', 1915, 2, NULL, 'ace', '1-8:: 

  All 4Cs set and cross.  Set and cross back RH both times.

9-16::

  1C and 2C and 3C and 4C  RHA & LHB ending 1s  facing 2s and 3s

facing 4s.

17-24::   

All set twice, 1C and 3C joining hands with partner.  1s and 3s drop hands and turn their opposite for 4 bars, ending in lines on the side in original places.

25-32::  

1C lead down the middle to 4th place as 2s, 3s, and 4s step up.  All 4 couples dance back to back.

', 3);
INSERT INTO 'dancecrib' VALUES (3315, '2012-01-22 19:30:20.189655+00', '2016-03-18 00:22:48.996223+00', 10684, 1, NULL, 'ace', '1–::

  1c set | cross RH ; cast off (2c up) | Turn LH ¾ to face 1cnr

9–::

  1c+1cnrs set | La Baratte [turn RH ½ to full arms'' length | change back sideways, W passing in front with her back to M, changing hands overhead to LH | turn LH ½ to exchanged places], 1c face out and 1cnrs face in

17–::

  1cnrs turn RH, and dance through 2pl to own place _while_{4} 1c dance Lsh round 2cnr and in through the ends ; 1c turn LH 1¾ to face 2cnr

25–::

  1c+2cnrs set | La Baratte, 1c face out and 2cnrs face in

33–::

  2cnrs turn RH, to own place facing 1c _while_{4} 1c dance Lsh round 3cnr into 2pl facing 4cnr ; 1c+4cnr dance BtoB (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1691, '2012-01-22 19:28:56.877149+00', '2019-01-11 21:32:27.419543+00', 289, 1, NULL, 'ace', '1–::

  1M+2W change places RH | 1W+2M & 1M+3M repeat LH ; 1W+3W & 1M+4W repeat LH | 1W+4M repeat LH (2x,3x,4x,1x)

9–::

  2c & 1c cross RH _while_{2} 3c+4c ½ RHA | Middles face Ends and change places LH (4,2,1,3) ; all turn P RH into

17–::

  4c+2c (facing up) Allemande & 1c+3c (facing down, M on the R) Mirrored Allemande (start to L, curve to R), at end 4c & 3c pass LH into BtoB facing opposite side

25–::

  4c+3c cast round end couple, meet and dance in to 2plx/3plx ; 4c+3c ½R&L (2,3,4,1) (option: dance the ½R&L starting up/dn)', 3);
INSERT INTO 'dancecrib' VALUES (9120, '2016-03-18 23:06:08.151466+00', '2016-03-18 23:06:08.151466+00', 2833, 1, NULL, 'ace', '1-4::

  2c half Fig8 L through end couple (1,2x,3)

5-8::

  All M pass W on his R Rsh (brief touch of LHA), next W Lsh into next free place

9-12::

  All W pass M on her L Lsh  (brief touch of RHA), next M Rsh, into next free place (3,1x,2)

13-16::

  1c half Fig8 R (3,1,2)

17--::

  All set twice ; cross RH | Circle6 L half (2,1,3)

25--::

  3-couple knot (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (9444, '2016-10-25 23:46:19.309385+00', '2016-10-26 00:36:42.982721+00', 546, 1, NULL, 'ace', '1--::

  1c with 2c+3c following cast off to (3,2,1) | All set ; repeat to place 3c leading (1,2,3)

9--::

  All set | cross RH ; set | cross RH

17--::

  1c lead down the middle and back (1,2,3)

25--::

  1c+2c dance “New Poussette”: 

	::  25-26  take promhold (W on R) to face out (1c to M side, 2c to W side) 



	::  27-28  dance diagonally to sideline (to 1c opposite 2c) and face L



	::  29-30  dance in diagonally to face P on midline, 2c above 1c, M above W



	::  31-32  turn P RH to (2,1,3)



*(crib is uncertain)*

', 1);
INSERT INTO 'dancecrib' VALUES (13644, '2021-02-04 01:22:18.192938+00', '2023-02-04 01:23:10.429608+00', 7062, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Grand Chain (1s cross, 2s+3s change places RH on side
    to start)
9-16::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s
17-24::
    Mirror reels of 3 on sides (1s in/down, 3s out/up).  1s end facing
    1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting. 1s end in centre BtoB facing 2nd
    corners
33-40::
    Reels of 3 on sides (6 bars), 1s pass 2nd corner RSh to start, 1s
    cross RH to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13549, '2021-01-10 14:47:58.915982+00', '2021-01-10 14:48:13.873883+00', 11427, 1, 1645, 'ace', '1--::

  1c set | cast to centre line (2c up) ; 2c+1W & 1M+3c RHA, 1c end on centre line

9--::

  1c set LHJ | dance to opp side & turn to face in ; set | cross RH & face out

17--::

  2c+1c+3c mirror Reels3 on own sides, taking hands where possible, 1c start out & up  

  *(Optional variation: RSh Reels, 1c start out, RSh to 3cnr)*

25--::

  Circle6 & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2084, '2012-01-22 19:29:18.917878+00', '2019-10-29 19:59:20.328743+00', 1647, 1, NULL, 'ace', '1–::

  1c+4c 1½ RH turn and face out ; cast to middle (2c+3c step to ends) | 1M+4M & 1W+4W turn LH, finish middles facing ends (2,1x,4x,3)

9–::

  Reels4 on the sides, at the end 2c+3c make loops and 1c+4c do not pass but curve R to finish BtoB in the centre facing corners in a St. Andrew''s Cross

17–::

  1c+4c set to corner and change place RH ; repeat with LH, finish facing centre for

25–::

  1c+4c RHA _while{4}_ 2c+3c set and cross RH ; all set and cross RH (2,4,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (8241, '2014-04-08 14:50:48.075699+00', '2019-02-05 16:56:08.119995+00', 9546, 2, 160, 'ace', '1-8::
 1C set, 1W cast off, cross below 3C, dance up behind 3M into 2nd place _while_ 1M cross at the top, cast down & dance in below 3W & up the middle to 2nd place W''s side. 2 (1) 3
9-16::
 Reels on the sides, 2C 1C pass Lsh to begin.
17-24::
 2C 1C Ladies'' Chain
25-32::
Half fig 8 round 3C ; 2C 1C 3C adv & ret', 2);
INSERT INTO 'dancecrib' VALUES (10466, '2018-02-27 14:43:32.567891+00', '2018-02-27 15:08:17.448432+00', 5506, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c RHA ; 2c+3c LHA, 2M & 3W face out at end (1,2,3,4)

9--::

  2M followed by 2W & 3W followed by 3M chase cclw to ends (1W & 4M step inwards on [9-10], 1M & 4W step inwards on [11-12]) (to 3x,1,4,2x) ; 1c+4c ½  R&L (3x,4x,1x,2x)

17--::

  All set | cross RH, 1c & 2c face out at end (to 3,4,1,2) ; 1c & 2c cast up 2 _while{4}_ 3c & 4c lead down 2 | all set (1,2,3,4)

25--::

  1W dance down, out between 3M & 4M, round 4M to 4pl (2W+3W+4W up on [27-28]) |all set

33--::

  1M dance down, out between 4W & 1W, round 1W to 4pl (2M+3M+4M up on [35-36]) | all set (2,3,4,1)

41--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (11505, '2019-01-09 14:52:45.171835+00', '2022-02-15 15:37:24.694209+00', 14445, 1, 1645, 'ace', '1-::

  1c cross RH | cast off (2c up) ; turn 1&frac34; LH to lines across

9-::

  1W+2c & 1M+3c LSh Reels3 across, ending on sides (2,1,3)

17-::

  1c turn 1&frac12; RH (2,1x,3) ; &frac12; circle6 to L (3x,1,2x)

25-::

  Diagonal R&L (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3769, '2013-07-13 15:55:57.155188+00', '2016-11-27 10:35:07.569298+00', 12665, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; ½ diag R&L with 1cnrs

9–::

  ½ diag R&L with 2cnrs ; 1c set and cast off (2c up) (3x,2x,1)

17–::

  1c cross RH | cast to top (2c+3c down) ; All set | turn RH ½ and face up for

25–::

  1c+3c+2c Allemande (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (9282, '2016-08-21 08:42:40.852249+00', '2016-08-24 21:16:40.141238+00', 17175, 2, NULL, 'ace', '1-4::

	1C set & cross down RH to 2nd place, facing out;



5-12::

	2 & 3C dance full reels 3 on sides while 

	1C ½ reel 3 opposite sides (1W cast up, 1M cast down), cross R (or burl once) to 2nd place own sides.

	1C ½ reels 3 own sides (iM cast up, 1W cast down).

	Finish in 3s across (1M between 2C, 1W between 3C)



13-16::

	All set, 1C turn L ½ to face 1st corners.



17-24::

	1C set to corners and partner (Hello, goodbye), turn R to 2nd place own sides.



25-32::

	All chase clockwise halfway round set; 

	2 & 3C continue chase to places while 1C turn R 1½ to 2nd place.

', 4);
INSERT INTO 'dancecrib' VALUES (13551, '2021-01-10 19:05:09.667427+00', '2021-01-10 19:05:35.006701+00', 8295, 1, 1645, 'ace', '1-::

  1c A&R ; turn BH

9-::

  1c Fig8 down round 2c

17-::

  1c lead down & up

25-::

  1c followed by 2c+3c+4c cast off to 4pl, 1c make an arch & 2c+3c+4c dance up (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (2035, '2012-01-22 19:29:16.288201+00', '2019-12-06 11:31:16.005048+00', 12810, 1, NULL, 'ace', '1–::

  1c+2c Set&Link ; Circle4 L (2,1,3)

9–::

  All set | cross RH ; ½Circle6 L | 3c+2c cross RH _while_{2} 1c turn RH to face 3cnr (= 1cnr person)

17–::

  1c+1cnrs ½Reel4, 1c pass Rsh to face 4cnr ; 1c+2cnrs ½Reel4 (to 2,1,3)

25–::

  1c+3c Circle4 L into a diagonal line for ; 1c+3c ½Poussette (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (1830, '2012-01-22 19:29:04.670032+00', '2019-03-19 10:47:59.922756+00', 776, 1, NULL, 'ace', '1–::

  1c Fig8 on own sideline, Rsh to 2c, both finish facing W side

9–::

  1W followed by 1M cast behind W side, 1M goes round 2W and 1W round 3W to dance up the middle 1M leading ; cast behind M side, 1M goes round 3M and 1W round 2M to

17–::

  1W+2c & 1M+3c Reels3 across (Rsh to the W), at end 1c face up

25–::

  1c+2W+3W RHA ; 1c+2M+3M LHA, finish (2,3,1) (2W+3W step up)', 2);
INSERT INTO 'dancecrib' VALUES (8244, '2014-04-17 22:19:53.466497+00', '2014-04-30 23:23:44.829435+00', 15424, 1, NULL, 'ace', '1–::
  All S&Link3 into lines across ; 1M+3W change places RH | All change place with P RH
9-24::
  All chase ¼ clw (3,2,1) | R&L for 3 couples {12} | All set (3,2,1)
25–::
  1c+2c Rondel (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (9853, '2017-05-14 23:35:09.116544+00', '2017-05-14 23:35:09.116544+00', 16493, 1, NULL, 'ace', '*On second chord 3c+4c cross (1,2,3x,4x)*

1--::

  Double ended Snowball chain: 1c+4c cross RH | continue normal G Ch, at end all M face out (4,2x,3,1x)

9--::

  4c+2c & 3c+1c  L-Ch and all M face out (4,2x,3,1x)

17--::

  1M+4M, their P following, chase cclw half round _while{4}_ 3c+2c RHA ; 4c+3c & 2c+1c ½ LHA | 4c+1c ½ RHA (2,4x,1,3x)

25--::

  4c+1c Circle4 L ; 4c+1c turn P RH ½, face and cast away to (2,4,1x,3x)

*Repeat once as Strathspey and twice as Reel*

', 3);
INSERT INTO 'dancecrib' VALUES (8109, '2013-11-16 21:55:58.393259+00', '2017-11-10 02:56:29.023465+00', 15231, 1, NULL, 'ace', '1–::

  1c set | cross RH ; cast (2c up) | turn LH to face 1cnr

9–::

  1c+1cnrs »Pass, Turn, Face and Cast away« [pass cnr Rsh, cnrs turn RH ½ and face | cnr cast R to diagonally opposite place as 1c returns to centre], 1c pass Rsh ; 1c+2cnrs »Pass, Turn and Cast away« to (3x,1x,2x)

17–::

  ½ Reels3 across, 1c giving Rsh to 4cnr pos (3,1,2) ; ½ Reels3 on the sides, 1c Lsh to 3cnr pos (2,1,3)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (1619, '2012-01-22 19:28:51.343867+00', '2018-10-08 20:32:50.655862+00', 29, 1, NULL, 'ace', '{{explanation}}

Trios WMW face trios RR.



1–::

  All A&R ; repeat

9–::

  Teapots R ; and L (centres RHA with persons on R ; repeat L)

17–::

  ½ diagonal R&L (L+centre persons) ; repeat other diagonal (centre + R persons), centres remain facing out between new partners

25–::

  Reels3 in the trios, centres start Rsh ; finish (W with loops) facing next trio RR.



{{explanation}}

The centres face alternate ways, the outsides progress RR', 3);
INSERT INTO 'dancecrib' VALUES (9969, '2017-06-19 14:47:32.837299+00', '2017-06-19 15:22:45.642845+00', 17800, 1, 202, 'ace', '1--::

 1c cast off behind own lines and back

9--::

 1c Reels3 on opp sides (1x,2,3,4)

17--::

 1c Reels3 on own sides (1,2,3,4)

25--::

 1c cast, the others following, and make an arch at the bottom ; all others dance up through the arch (2,3,4,1)

33--::

 2c+3c & 4c+1c RHA ; LHA (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12761, '2020-04-13 09:22:22.091148+00', '2020-04-13 09:23:03.877932+00', 19308, 1, 1645, 'ace', '1-::

  1c turn BH | dance down & cross below 3c ; cast up | turn &frac34; RH

9-::

  2c+1M & 1W+3c LHA, pass LSh ; &frac34; RHA, 2c & 3c &frac12; turn RH to centre line as 1c cast to 2pl facing clw

17-::

  All dance Weasel Reel: &frac12; Reel4 on centre line (M down, W up) & &frac12; chase clw to same places

25-::

  2c & 3c set on centre line | &frac34; turn RH ; 2c+1c+3c chase &frac12; way clw (3x,1x,2x)

33-::

  All set | all dance La Baratte (3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (1831, '2012-01-22 19:29:04.733577+00', '2021-02-07 10:51:58.960343+00', 10545, 1, NULL, 'ace', '1–::

  1c set and pass | ½ turn 2c EH and cross ; ½ turn 3c EH and cross | ½ turn 4c (2,3,4,1x)

9–::

  Repeat from bottom up (1c set and pass | ½ turn 4c and cross ; repeat with 3c | ½ turn 2c (1,2,3,4)

17–::

  1c+2c The Knot, at end 3c steps in for

25–::

  1c+3c ½ Poussette, and 4c steps in for ; 1c+4c ½ Poussette (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (9844, '2017-05-13 18:13:46.912616+00', '2021-06-06 21:29:34.418392+00', 14335, 1, 202, 'ace', '1--::

 1c dance down | cast round 3c to 2pl (2c up) ; 1c turn LH to join 1cnrs RH

9--::

 1c+1cnrs making arches BiL twice _while{4}_ 2cnrs chase cclw under arches to exchanged places ; 1c turn LH to join 2cnrs RH

17--::

 1c+2cnrs making arches BiL twice _while{4}_ 1cnrs chase cclw under arches to exchanged places ; 1c cast Lsh round 3cnr pos to face 1cnr pos

25--::

 ½ Reel4 on 1diag, pass Rsh ; ½ Reel4 on 2diag, pass Rsh (2,1,3)



*Note: End of 2nd time through [31-32], 1c cross down to 4pl (4c up)*', 2);
INSERT INTO 'dancecrib' VALUES (14153, '2021-07-18 19:38:54.19293+00', '2021-07-18 19:42:56.985583+00', 20393, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 up round 2c (2,1,3)

9--::

  1c+3c RHA ; 2c+1c LHA (2,1,3)

17--::

  Parallel Fig8 on sides, 1c RSh to 3c (2,1,3)

25--::

  Circle6 and back (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (9970, '2017-06-19 16:27:11.238786+00', '2017-06-19 19:11:20.877256+00', 6267, 1, 202, 'ace', '1--::
 1M+2W turn RH, ending 1M between 2c facing up, 2W in original place facing down (on [4], 2M faces down) ; 1W dances Rsh round P under arches by 1M+2c, 1W finishing in middle above P
9--::
 1W, followed closely by P, Reel3 across with 2c, 1W starts Rsh to 2M, ending 1W in midline with P behind both facing down, 2c in 2pl facing up
17--::
 1c+2c+3c Reels3 on sidelines, 1W Rsh to 3W & 1M Lsh to 3M to start, ending 1c NHJ in middle facing down and 2c NHJ in middle facing up
25--::
 1c+2c ½ Rondel (3 bars of Rondel in {4}) ; 2c+1c set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11724, '2019-03-22 21:31:04.141579+00', '2019-03-22 22:00:54.821571+00', 4127, 1, NULL, 'ace', '1--::

  All set | turn P RH {4} | Set

9--::

  1c cast off as 2c dance up NHJ | 1c cross RH as 2c cast off ; 1c cast below 3c as 2c cross | 1c lead to top crossing to own side as 2c cast off (3c up) (1,3,2x)

17--::

  1c+2c set | turn P RH ½ ; ½ RHA | 2c (upwards) and 1c (downwards) cross and face out (to 2,3,1x)

25--::

  Reels3{6} on the sides, 3c start in and down, and 1c cross up on [27] | 3c+1c change places EH (3c in and down)



*On second time, make full turns on [31-32]*

', 3);
INSERT INTO 'dancecrib' VALUES (9790, '2017-04-12 09:03:24.615453+00', '2017-08-26 07:00:33.083367+00', 15184, 1, 202, 'ace', '1--::

 1c&4c turn RH ; 2c&3c turn LH

9--::

 All turn BH ; All dance BtoB

17--::

 Circle8 and back

25--::

 1c lead down casting to 4pl (2c+3c+4c up) ; All A&R clapping 3 times for each step on [31-32]', 2);
INSERT INTO 'dancecrib' VALUES (3775, '2013-07-13 15:56:01.846142+00', '2016-11-27 10:40:06.956336+00', 9420, 1, NULL, 'ace', '1–::

  All chase each other in a large 8-pattern through these positions in turn: 1W, 2W, 3M(crossing behind), 4M, 4W, 3W, 2M(crossing in front), 1M, 1W (back)  (1,2,3,4)  Option: RHA at top and LHA at bottom.

9–::

  On the sidelines, 1c+2c turn RH as 3c+4c turn LH ;  1W (2W+3W+4W follow) dance down the middle as 4M (3M+2M+1M follow) dance up the middle (to 4,3,2,1, still inside the sidelines, facing P)

17–::

  4c+3c & 2c+1c Circle4 L¾ and dance to sidelines (no cast) ; 4c+2c turn P RH | 2c cast to top   _while_{2}   4c lead RHJ to 3pl in centre

25–::

  2c+3c & 4c+1c DblFigs8 (2c+4c cross down) (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (9121, '2016-03-22 20:41:36.543925+00', '2016-03-22 20:58:14.550339+00', 14453, 1, NULL, 'ace', '*Strathspey*



1--::

  All W RHA ¾ to face new M ; set | all pairs turn RH

9--::

  All M LHA ¾ to face new W ; set | all pairs turn LH (all new pairs face P across the set)

17--::

  2c+4c cross RH with P | both new pairs (W leading) cast ¼ clw outside the set ; dance into centre, the W round the standing pair and the M between them | meet own P and turn BH ½, breaking (M leading)  to finish 2c in 1pl and 4c in 3pl (“Tourbillon turns”)

25--::

  1c+3c (= side pairs) repeat figure (to 2,3,4,1)

33--::

  Circle8 and back



*Dance twice as Strathspey, twice as Reel.  In the Reel the Tourbillon turns are danced in skip-change.*

', 3);
INSERT INTO 'dancecrib' VALUES (1832, '2012-01-22 19:29:04.803691+00', '2014-05-04 21:35:25.71967+00', 779, 1, NULL, 'ace', '1–::

  1c+3c Petronella (to 1x,2,3x)

9–::

  All A&R ; 1c+3c cross RH | All set (1,2,3)

17–::

  1c lead down the middle (2c up) and up, finish 1W between 2c and 1M between 3c, both facing 1cnr

25–::

  Reels3{6} across, Rsh to 1cnr | 1c turn LH to finish (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14817, '2022-05-08 01:51:21.762617+00', '2022-08-29 11:19:02.795132+00', 20783, 1, 202, 'ace', '1--::
  1c set | cast off (2c up) ; lead down, cross | cast to 2pl (2,1x,3)
9--::
  All set | turn P BH ½ (PdB) ; 1c dance in towards P, pivot R into facing lines3 across, 1M between 2c, 1W between 3c
17--::
  All set | turn opposite person BH ½ (PdB) ; 1c dance in towards P, pivot R to 2pl (3x,1,2x)
25--::
  1c A&R _while{4}_ cnrs chase clw ½ ; all turn P RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (1795, '2012-01-22 19:29:02.712966+00', '2016-08-27 22:39:00.977616+00', 640, 1, NULL, 'ace', '1–::

  1M+2W set | turn RH ; 2M+1W repeat

9–::

  1c+2c circle4 to left ; 1c set | cast off (2c up) to face 1cnr

17–::

  Set to and turn corners

25–::

  Reels3{6} with corners, Lsh to 1cnr | 1c cross RH (2,1,3)



{{explanation}}

The Pilling "Wee Green Books" all have the reels on [25] wrong, starting Rsh to 2cnr.', 3);
INSERT INTO 'dancecrib' VALUES (9122, '2016-03-23 21:09:44.822633+00', '2019-04-24 22:50:05.27822+00', 16469, 2, 177, 'ace', '1- 8::

  1M+2M+3M dance RSh round partners & 1s+2s+3s turn RH

9-16::

  1L+2L+3L dance LSh round partners & 1s+2s+3s turn LH ending LH joined facing up 

17-24::

  1s+2s+3s dance Allemande

25-32::

  3s + 2s dance Tourbillon', 4);
INSERT INTO 'dancecrib' VALUES (10647, '2018-04-17 16:27:22.918061+00', '2018-04-18 15:37:58.761979+00', 13920, 1, 202, 'ace', '1--::
  1c+2c The Knot, 1c facing 1cnrs at end
9--::
  Corners pass and turn (2,1x,3)
17--::
  Reels3{6} on sidelines, 1c passing P Rsh start Rsh to 3cnrs, finishing  1M(1W) between 3c(2c) facing P | 1c turn RH ¾ facing down, RHJ
25--::
  1c lead down {4}, change sides (W crossing above, under M’s arm) ; lead up to 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (8742, '2015-03-24 23:26:54.366695+00', '2015-03-24 23:29:30.115614+00', 13497, 1, NULL, 'ace', '1--::

  Half mirror Reels3 on the sides, 2c start out and up ; 1c (inwards) turn 2c EH 1½, finish in DTr pos (3,1,2)

9--::

  4 bars of DTr ; 1c+1cnrs ½ Rsh diag. Reel4, 1c pass Rsh to DTr pos facing own side

17--::

  4 bars of DTr ; 1c+2cnrs ½ Lsh diag. Reel4, 1c pass Lsh to 2pl facing out (2x,1,3x)

25--::

  1c cast L round 4cnr and cross diagonally to 2plx ; All set | cross RH

 

 

', 3);
INSERT INTO 'dancecrib' VALUES (9124, '2016-03-27 02:02:37.13293+00', '2016-04-04 01:18:51.795853+00', 859, 1, NULL, 'ace', '1--::

  1c+2c+3c Mirror reels on own side, 2c starts out and up (1,2,3)

9--::

  1c cross RH | cast off (2c up) ; dance Rsh round 2cnr to finish (2,1x,3) 

17-28::

  “Double circles of three”: All W slip L to next W place | and set _while{4}_ all M set | and slip R to next M place, in 2pl dancer slipping passes behind the dancer setting.  Repeat these 4 bars twice (2,1x,3)

29-32::

  All turn P RH, finish (2,1x,3), 1c facing out

33--::

  1c cast R round 1cnr to meet in middle and pivot R to finish BtoB ; dance out the ends and cast R to finish (2,1,3)



*On second time through 4c step up on [39-40] as 1c finish in 4pl.*

 

', 3);
INSERT INTO 'dancecrib' VALUES (10298, '2017-12-09 19:08:22.309664+00', '2020-11-12 10:35:49.679277+00', 18103, 2, 160, 'ace', '1-8::  Head cpls set and link 3/4 to a line of four; set and turn BH  x1.

::  .

:: _Head couples dance a Half Sloth Reel_.

9-12::  End dancers set advancing one place, set again advancing to pass one another - middles dance two petronella turns and become ends.

13-16::  Repeat from new positions - dancers will be half way through a normal reel of 4. 

::  .

17-20::  Heads turn RH into allemande hold facing anti clockwise, dance half round (back to original end)

21-24::  Dance LH Across 3/4 round with  twirl to face the side couples.

25-26:: Heads and sides change places passing Rshoulders,

27-32::  Center couples chase anti-clockwise 3/4 round into head positions, and all four couples  set', 5);
INSERT INTO 'dancecrib' VALUES (9968, '2017-06-19 00:38:34.448968+00', '2020-07-26 02:52:22.366945+00', 17799, 1, 202, 'ace', '1--::

  1c+2c set | 1c cast off _while_ 2c dance up and face out ; ½ Mirror Reels3 on sides giving hands when possible, 1c in and down. 1c face 1cnrs[pos]

9--::

  Set to Corners (to 3,1x,2) ; Circle6 L ½ into midline (2c,1c,3c) all facing P, 2M & 3M facing up, 1M facing down

17--::

  1c change places RH _while_ 2c & 3c set to P ; all Petronella turn to sides (2x,1x,3x) ; all turn P BH 1½ (2,1,3)

25--::

  2c+1c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (9854, '2017-05-15 13:34:04.106299+00', '2017-05-15 13:36:35.613309+00', 16494, 1, NULL, 'ace', '*On 2nd chord 2c+4c cross (1,2x,3,4x)*

1--::

  Half Reels4 on the sides, 1M+4M face out ; 1M+4M chase clw half round as all others set twice

9--::

  Half Reels4 on the sides, 1W+4W face out ; 1W+4W chase clw half round as all others set twice (4,2x,3,1x)

17--::

  4c+2c & 3c+1c ½ M-Chain ; 4c+2c & 3c+1c chase one place clw in their square ; all cross RH (2,4x,1,3x)

25--::

  Circle8 and back (2,4x,1,3x)

 

', 3);
INSERT INTO 'dancecrib' VALUES (9447, '2016-10-28 17:57:08.368498+00', '2016-10-28 17:57:08.368498+00', 17315, 1, NULL, 'ace', '1--::

  1c+2c Poussette

9--::

  1c lead down {3}, up {3} and cast to 2pl (2c up) (2,1,3)

17--::

  1c+3c Tourbillon

25--::

  Circle6 and back (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9855, '2017-05-15 13:56:09.780077+00', '2017-05-15 13:56:09.780077+00', 16496, 1, NULL, 'ace', '1--::

  1c+2c set | ½ RHA ; 2M, 2W following, casts off two places and crosses (1c+3c up) (1x,3,2)

9--::

  1c+3c set | ½ LHA ; 3W, 3M following, casts off two places and crosses (1c+2c up) (1,2,3)

17--::

  1c set | long cast to below 3c (2c up) | dance up to 2pl in middle 

25--::

  All M LHA as All W RHA ; 1c dance up through the top and cast to (2,1,3) 

', 3);
INSERT INTO 'dancecrib' VALUES (12437, '2019-12-16 23:53:40.762582+00', '2019-12-18 07:11:36.366728+00', 19797, 2, NULL, 'ace', '

1-4::

    1W+2M advance and cast by the right back to place | 1W cast down, 2M cast up AS 1M 2W dance through the middle to progressed places - 4s+5s similarly. (2 1 3 5 4)

5-8::

    hands 4 to left top & bottom. (still 2 1 3 5 4)

9-16::

    middle 3 couples LHA once round; W chase up btwn 2C and cast to own sides AS M chase down btwn 4C and cast up to own sides. (2 5 3 1 4)

17-24::

    bottom 3 cpls Set & Rotate (2 5 4 1 3)

25-32::

    5s half fig 8 up btwn 2s AS 1s half fig 8 down btwn 3s; 5s 1s cross LH, all set. (2 5 4 1 3) ', 2);
INSERT INTO 'dancecrib' VALUES (8231, '2014-04-02 21:12:02.558552+00', '2014-04-02 21:12:02.558552+00', 10485, 2, 160, 'ace', '1–8::
 1C cross, cast; turn RH.
9–16::
 2C+1C dance LH Across & 1C face out; 1C dance CCW half round the set to own side 2pl.
17–24::
 1C+3C dance LH Across & 1C face out; 1C dance CCW half round to 2pl on opp. side.
25–32::
 2C+1C+3C dance of 3 on sides - pass 2nd corner Rsh to begin, 1C cross LH to own side.', 2);
INSERT INTO 'dancecrib' VALUES (8232, '2014-04-02 21:26:01.72432+00', '2014-04-02 21:26:01.72432+00', 10487, 2, 160, 'ace', '1–8::
 1W+3C dance reel of 3 across. 1W+3M pass Rsh to begin. (2W up on 3-4).
9–16::
 1M+3C dance reel of three across - 1M+3W pass Lsh to begin (2M up on 11-12)
17–24::
 2C+1C+3C dance mirror reel of 3 on sides - 1C in+up to begin.
25–32::
 2C+1C Rights&Lefts.', 2);
INSERT INTO 'dancecrib' VALUES (8233, '2014-04-03 00:03:38.230466+00', '2014-04-03 00:03:38.230466+00', 10490, 2, 160, 'ace', '1–8::
 1C in and down to begin dance figure of 8 on own sides.
9–16::
 1C Lead down the middle for 3, up for 3, cast to 2nd place.
17–24::
 1W figure of 8 up through 2C _while_ 1M dance figure of 8 down through 3C.
25–32::
 1W+2C, 1M+3C  dance RH Across; change ends dance LH Across.', 0);
INSERT INTO 'dancecrib' VALUES (1917, '2012-01-22 19:29:09.710549+00', '2021-02-12 18:29:03.282987+00', 10071, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; ½ Fig8 L (M up, W down) (2,1x,3)

9–::

  ½Reel3 on sides, Lsh to 1cnr and face 2cnr, the corners finish with loops ; ½Reel4 on 2diagonal

17–::

  ½Reel3 across, Lsh to 3cnr pos. and face 4cnr ; ½Reel4 on 2 diagonal, 1c pass LSH or fast turn LH ¾

25–::

  1c dance out through end couples (M up, W dn) and cast L to 2pl ; All turn RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8145, '2014-01-05 21:27:24.555697+00', '2016-01-18 14:16:53.685066+00', 780, 1, NULL, 'ace', '1–::

  1c slip down BHJ ; dance NHJ between 3c and cast up behind 2c (1,2,3)

9–::

  1c+2c espagnole, 1c turn more to face 4cnr

17–::

  ½ Reel4 on 2diag, pass Rsh to face 1cnr ; ½ Reel4 on 1diag, with fast ¼ turn LH to face own side (M above W)

25–::

  3c+1M & 1W+2c RHA to (3x,1x,2x) ; All chase ½ clw (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12889, '2020-06-14 23:10:21.675365+00', '2020-06-14 23:15:03.628654+00', 13780, 1, 202, 'ace', '1--::

  1c+2c+3c RHA ; LHA (1,2,3)

9--::

  1W (2W+3W following) dance across the set, LSh round 1M _while_ others continue behind Mside ; 2W (3W+1W following) dance behind Mside, across the set to Wside

17--::

  All M repeat same pattern [9-16] (2,3,1)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (9125, '2016-03-27 15:16:27.02503+00', '2016-03-27 15:20:26.133586+00', 16224, 1, NULL, 'ace', '1--::

  “Lacross”: 1c+3c cross (no hands; M pass outside the W) | change place RH on side, with polite turn | cross back as before while{6} 2c turn P RH 1½ | 3c+2c+1c set (3,2x,1)

9-12::

  2c turn RH 1½ (3,2,1)

13-24::

  3 couple R&L (3,2,1)

25--::

  “Untie the knot”: 2c+1c turn RH into Allemande hold facing down on W side | dance R and up to face up the middle in allemande hold {3}, turn in to face P, W passing under her R arm, hands still joined {1} | drop hands and cast out, starting downwards, to own side (3,1,2)

 

 

', 3);
INSERT INTO 'dancecrib' VALUES (9448, '2016-10-29 11:35:50.259202+00', '2016-10-29 11:37:56.479707+00', 13675, 1, NULL, 'ace', '1--::

  All dance Reels4 on own side 

9--::

  1c+2c set | ½ RHA ; 1c+3c set | ½ LHA 

17--::

  1c+4c set | ½ RHA ; All turn P RH ½ and cast to own side (2,3,4,1)

25--::

  Circle8 and back

', 3);
INSERT INTO 'dancecrib' VALUES (1833, '2012-01-22 19:29:04.847925+00', '2014-04-30 23:23:41.959235+00', 10650, 1, NULL, 'ace', '{{explanation}}
Square set, with 5c in the middle facing 1c.

1–::
  1c+5c ½ R&L (1M no polite turn) ; 1M+4c & 1W+2c RHA, finish 1M above 1W, facing P
9–::
  1c set | Turn RH ½ ; 5c+1W & 1M+3c LHA, finish 1M/1W facing 4M/2M
17–::
  Opposing Lsh Reels3 across (1M+4M+2W & 1W+2M+4W).  Finish in lines of 3 across, BtoB with P, facing top/bottom
25–::
  All set with NHJ | 5c&3c pass the lines of 3 who make arches ; all set pivoting R | all pass back
33–::
  1c in centre turn any way they wish, finish facing 1pl _while_{8} other cpls turn RH and chase clw ¾, M leading (2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (10248, '2017-11-10 19:17:25.586846+00', '2018-12-07 17:49:54.526152+00', 15230, 1, 202, 'ace', '1--::

  1c lead down the middle and up {6} | cast off (2c up) (2,1,3)

9--::

  Mirror Reels3, 1c start in and down (2,1,3)

17--::

  1c ½ Fig8 to L ; turn P RH 1 ½ to 2pl (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (9856, '2017-05-15 16:17:03.084223+00', '2017-05-15 16:17:03.084223+00', 16497, 1, NULL, 'ace', '1--::

  1c lead down {3} and up facing out | 1c turn 2c EH ½ (2,1,3)

9--::

  Reels3 on own sides, 1c begin in and down, 2c+3c finish with loops (2,1,3)

17--::

  1W+2M & 1M+3W La Baratte {6} | 1W+3W & 2M+1M change places RH

25--::

  All S&Link  into lines across ; 1c petronella to 2plx while the corners cross RH | All set

33--::

  1W+3M & 1M+2W La Baratte {6} | 1W+2W & 3M+1M change places RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1834, '2012-01-22 19:29:04.896981+00', '2014-10-05 08:28:22.859071+00', 10288, 1, NULL, 'ace', '1–::

  All A&R ; all cross RH, the M making arches

9–::

  Repeat, the W making arches

17–::

  1c slip down the middle and up

25–::

  1c cast, the others following, and make an arch at the bottom ; all others dance up through the arch

33–::

  2c to 5c make arches, 1W dances up under them, 1M dancing up behind M line ; 1M dances down under arches, 1W dancing down behind W line

41–::

  All Birl



{{explanation}}

Notes.  If dancers do not reach their new places on [32], make up for the delay by a shorter birl.', 2);
INSERT INTO 'dancecrib' VALUES (14250, '2021-08-19 19:14:16.719375+00', '2021-08-20 07:58:42.517281+00', 20434, 1, 202, 'ace', '1--::

  1c lead down ; 1c change sides, 1W passing above 1M under joined arms, and dance up NHJ to 1pl centre between 2c who dance up on [5-6].

9--::

  1c turn 2c EH ¾ {3} to sides, 1c turn 3c EH to sides {3} | all set (2,1x,3)

17--::

  2c+1M & 1W+3c RHA, pass RSh ; 2c+1W & 1M+3c LHA (2,1x,3)

25--::

  1c ½ Fig8 R round 3cnrs ; all turn P BH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9879, '2017-05-23 17:35:37.80844+00', '2017-08-26 07:16:14.272496+00', 15975, 1, 202, 'ace', '1--::

 1c lead{1}, turn{2} RH ½, lead{1} to 1pl facing out ; 1c cast to 3pl  _while{2}_ 3c cross to 1pl | 1c turn 2c EH ½ (3x,1,2)

9--::

 Mirror Reels3, 1c start out and down, Cs touching NH briefly, on [15-16] 1c lead down and stay in centre

17--::

 ½ Reel3 across, 1c in promhold start Rsh to 2M finishing in midline 1M/1W facing up/dn ; 1c turn RH ¾ | cast R to 2plx (3x,1x,2x)

25--::

 S&Link3 twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9298, '2016-09-18 06:47:41.651712+00', '2017-08-26 09:46:57.660668+00', 17382, 1, 202, 'ace', '1-::

 1c cross into mirror Reel3{6} on opp. side, 1M+2W & 1W+2M turn EH into DTr position, 1c  facing opp. side

9-::

 “Petronella DTr“: Set as in DTr | 1c switch sides as in DTr _while_{2} cnrs petronella 1 pl cclw round the square ; Set as in Dtr | 1W swivel R on the spot & 1M petronella to 1W Lsh, 1c finish in promhold facing 2M _while_{2} cnrs petronella 1 pl cclw round the square

17-::

 1c ½ Diag Reel3 with 1 crns ; ½ Diag Reel3 with 2crns, 1c finish in middle facing up

25-::

 1c lead up between 2c cross and cast off ; lead down between 3c cross and cast up to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3680, '2013-01-13 00:36:57.926749+00', '2017-11-11 00:17:38.506882+00', 14661, 1, NULL, 'ace', '{{explanation}}

2c and 4c begin on opposite side (1,2x,3,4x)



1–::

  All S&Link in tandem: All set | on each sideline the 2 leftmost dancers dance in and 2 places R, curving in round Rsh, the two rightmost cast 2 places L (3,4x,1,2x) ; 4c+1c RHA 7/8 , finish 4W+1M following facing 1M place and 1W+4M following facing 4W place (both pairs face men)

9–::

  ½ Lead-change Reel4 on 1st diagonal, 1c&4c ½ turn P fast LH and the same pairs, W leading, face the end; ½ Lead-change Reel4 on 2nd diagonal, finish (2,4,1x,3x), middles facing nearest end and in

17–::

  Middles turn ends EH on sidelines ; middles ½ Fig8 round ends (2,4x,1,3x)

25–::

  Circle8 and back  (2,4x,1,3x)', 3);
INSERT INTO 'dancecrib' VALUES (9972, '2017-06-20 00:53:41.723033+00', '2018-09-19 09:43:32.624152+00', 17802, 1, 202, 'ace', '1--::

 1c Fig8 on sidelines, 1c Rsh to 2c to start (1W casting), ending 1W facing out

9--::

 1W, followed by P, cast one | dances to midline (2c up), down between 3c, cast up round 3M to 2pl (2,1,3)

17--::

 1c+3c S&Link ; 2c & 3c & 1c dance BtoB

25--::

 Circle6 and back (2,3,1) ', 2);
INSERT INTO 'dancecrib' VALUES (8237, '2014-04-07 15:15:25.779593+00', '2016-02-08 15:03:49.579065+00', 15038, 2, 55, 'ace', '1-6::

  Reel of three on the sides, 1s crossing

7-8::

  1s dance down to face 3m, promenade hold, 2c dance to 1st place

9-16::

  1s dance R Sh reel of three with 2nd corners

17-24::

  1s dance L Sh reel of three with 1st corners

24-32::

  1s cross down between 3s, cast up to 2nd place, dance up between 2s, cast to 2nd place own sides

', 0);
INSERT INTO 'dancecrib' VALUES (9857, '2017-05-15 21:32:06.090248+00', '2017-05-15 21:32:06.090248+00', 16498, 1, NULL, 'ace', '1--::

  2c+3c+4c ½ Reels3 on the sides (to start 2c cross down, 3c out and up) ; 3c+2c+5c ½ Reels3 on the sides (2c in  and down) (1,4,5,2x,3)

9--::

  4c+5c+2c ½ Reels3 on the sides 5c out and down, 2c cross up) ; 1c+2c+5c ½ Reels3 on the sides (2c in and up) (5,2,1,4,3) 

17--::

  2c+1c & 4c+3c S&Rotate (5,1,2,3,4)

25--::

  Circle10 and back 

', 3);
INSERT INTO 'dancecrib' VALUES (9126, '2016-03-28 06:24:31.857407+00', '2016-03-28 06:28:39.823783+00', 14548, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; cross down RH and cast up to (2,1x,3)

9--::

  2c+1c La-Chain

17--::

  Reels3{6} on the sides, 1c Rsh to 3c | 1c turn 3c RH ½ on sides (2,3,1x)

25--::

  3c+1c M-Chain (2,3,1x)

33--::

  1W followed by 1M cast up and cross to own side (3c down) ; 1c+3c Circle4 L (2,1,3)

 

', 3);
INSERT INTO 'dancecrib' VALUES (10402, '2018-01-25 20:09:44.493736+00', '2019-07-05 19:52:01.855115+00', 15180, 2, 963, 'ace', '1-8::
  1c, followed by 2c+3c, lead down; 3c followed by 2c+1c lead back up and cast to orig places  
9-16::
  1c+2c dance set and rotate 1M finishes facing out  
17-24::
  1M, followed by 1W, casts below 3M and dances up btwn 3c, pulling back Lsh to face 1W; 1c turn LH 1-1/2 to face 1st crnrs  
25-32::
  1c set to crnrs and partner with petronella turn to 2nd place  
33-40::
  2c+1c+3c circle six hands round and back  ', 5);
INSERT INTO 'dancecrib' VALUES (14256, '2021-08-20 23:50:21.703107+00', '2022-08-15 15:13:48.646053+00', 20398, 1, 202, 'ace', '1--::

  Circle8 and back

9--::

  Reels4 on sides

17--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 1c+4c ½ R&L (2,4,1,3)

25--::

  2c+4c & 1c+3c RHA ; all turn P RH (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (8245, '2014-04-21 15:54:20.878164+00', '2014-04-21 15:54:20.878164+00', 12039, 1, NULL, 'ace', '1--::

  Parallel Rsh ½ Reels3 on the sides (3,2,1) ; 1W with 1M following cast up to 2pl and turn LH to face up LHJ while{4} 2c step down and then 2c+3c step in, and face up LHJ for (3,1,2)

9--::

  3C Allemande (2,1,3)

17--::

  2c+3c R&L while{8} 1c turn LH to face end (M up, W down) | cast R round 2cnr pos to 2pl ; turn P LH to finish BtoB facing own side 

25--::

  Double Triangles (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1837, '2012-01-22 19:29:05.066552+00', '2014-10-23 21:39:18.886743+00', 796, 1, NULL, 'ace', '1--::

  1c+2c+3c mirror Reels3{6} on own sides (2c out and up) | 1c continues down to outside 2pl facing up while{2} 2c continues to top facing in and 3c meet turning inwards to face out 

9--::

  Men RHA and W LHA, (one hand per bar), 1c crossing to other wheel on [10] and back on [13] (the others stay in their own wheel), 1c finish in the middle

17--::

  1c dance down the middle, 3c & 2c following, all NHJ ; 1c lead up, 3c & 2c divide and lead up (all lead RH) 

25--::

  1c+3c+2c Allemande (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9128, '2016-03-28 23:33:26.128456+00', '2016-03-28 23:52:44.09206+00', 3174, 1, NULL, 'ace', '1--::

  1c+3c (leading) dance down, cast up round 4c, dance up and cast into exchanged positions (3,2,1,4)

9--::

  3W+2M & 1W+4M set and change places RH ; 3M+2W & 1M+4W repeat (2x,3x,4x,1x)

17--::

  4c+1c ½ R&L ; 3c+1c repeat  (2x,1x,3,4)

25--::

  2c+1c repeat ; 1c dance down the middle (2c+3c+4c up) and cast up into 4pl (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9285, '2016-08-28 16:53:35.479759+00', '2016-08-29 12:48:29.435391+00', 13623, 1, NULL, 'ace', '*Start (1,2,3x,4x)*

1--::

  1c+4c turn P BH ½ as 2c+3c step to end | in facing lines across all set ; and A&R(1+1) twice

9--::

  1W+4W dance as for ¾ Reel4 on midline, passing Lsh to start _while{6}_ 1M facing 4M set, dance Lsh round each other, and return to own end, passing the other W Rsh twice | 1c+4c turn P RH 1¼ into lines across (1c+2c & 4c+3c), all M facing W 

17--::

  1c+2c & 4c+3c Reels4 across, finishing (2,1x,4,3x)

25--::

  1c+4c S&Link ; Circle4 L (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (9449, '2016-10-29 15:34:11.19471+00', '2016-11-04 23:43:38.083737+00', 6738, 1, NULL, 'ace', '1--::

  1c cross RH | Cast (2c up) ; Turn RH to face 2W in promhold

9--24::

  1c  ½ Reel3 across with 2c, Rsh to 2W ; full Reel3 across with 3c, Rsh to 3M ; ½ Reel3 across with 2c, Lsh to 2W 

25--::

  1c lead out on W side cross and cast (W up. M down) and in the ends, pass Lsh in the middle, and cast Lsh round 3cnr to (2,1,3)









', 3);
INSERT INTO 'dancecrib' VALUES (14252, '2021-08-20 13:53:45.506367+00', '2021-08-20 14:59:38.133806+00', 20444, 1, 202, 'ace', '1--::
  2C S&Link. 2M & 1W face in, 2W & 1M face out ; ½ Parallel Reels3 on sides, 1c LSh to 3c (3,1,2)
9--::
  All set | dance BtoB | set (3,1,2)
17--::
  1c ½ Fig8 L round 2cnrs[pos] ; turn P RH 1½ (3,1,2)
25--::
  3C Chain Progression (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14698, '2022-03-11 00:06:57.364483+00', '2022-11-13 19:28:56.236926+00', 20718, 1, 1645, 'ace', '1--::
  1c+2c Mixed Chain: 1W+2M turn &frac34; RH as 1M/2W dance down/up sides | &frac12; turn LH on sides ; repeat from new places (1,2,3)
9--::
  All S&Link for 3 couples twice (3x,2x,1x)
17--::
  All dance BtoB ; 3c cast off 2 | &frac12; turn BH _while{4}_ 2c & 1c turn P 1&frac12; BH moving up (2,1,3)
25--::
  All circle6 & back (2,1,3)
', 5);
INSERT INTO 'dancecrib' VALUES (3273, '2012-01-22 19:30:18.481054+00', '2019-12-18 09:28:16.377183+00', 6133, 1, NULL, 'ace', '1–::

  1c+3c set, cast off one (2c+4c up), ½ Fig8 up (2,1x,4,3,x5)

9–::

  1c+3c set, cast off one (4c+5c up), ½ Fig8 up (to 2,4,1,5,3)

17–::

  1c dance Teapots R ; and L (1M+5c & 1W+4c RHA ; 1M+4c & 1W+5c LHA)

25–::

  4c+1c & 5c+3c R&L  (2,4,1,5,3)



{{explanation}}

This is a 5C variant on Lamb Skinnet', 2);
INSERT INTO 'dancecrib' VALUES (1892, '2012-01-22 19:29:08.414249+00', '2016-01-01 11:42:15.651808+00', 14392, 1, NULL, 'ace', '1–::

  1c cross RH | cast off to 2pl (2c up) ; 1c, NHJ, dance between 3c and cast up to (2,1,3)

9–::

  All Circle6 and back

17–::

  1c turn RH 1½ _while_{4} 2c+3c chase clw ½ round ; All set twice (3x,1,2x)

25–::

  Diagonal R&L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1838, '2012-01-22 19:29:05.118498+00', '2014-05-05 15:00:49.523588+00', 10595, 1, NULL, 'ace', '{{explanation}}

On 2nd chord 3c+4c cross (1,2,3x,4x)



1–::

  1c+4c set | cast in (2c+3c step out) (2,1,4x,3x) ; 1c+4c RHA, at end pivot R to face cnr (2,1,4x,3x)

9–::

  Half Schiehallion Reel (centre and cnr pass Rsh | in the centre move to next cnr to the R, passing Lsh, repeat.  Finish in diagonally opposite position (3,4,1x,2x)

17–::

  4c+1c LHA ; 3c+4c & 1c+2c ½ RHA to sidelines (4x,3x,2,1) | All turn P RH ½ , finishing 4c+1c in allemande hold facing out the end and 3c+2c in Poussette hold

25–::

  Interlocking Allepousse: 3c & 2c Poussette »singly« (W starts backwards) to own end of the set _while_{8} 4c+1c Allemande »singly« (phrase as a 3c allemande, 1c starts down), passing each other before dancing in | on [31-32] cross LH to other side (to 3,1,4x,2x)', 3);
INSERT INTO 'dancecrib' VALUES (10369, '2017-12-29 20:49:43.922336+00', '2017-12-29 21:00:05.966425+00', 14900, 1, 202, 'ace', '1--::

  1c & 3c turn RH ½ | 1c & 3c (M leading) cast off ; dance up the middle M pivoting R to face P (2W & 4W up) | 1c & 3c turn P RH to finish into parallel lines of 4 across for

9--::

  1c+2c & 3c+4c parallel Reels4 in 2diag, on [16] 1c & 3c turn P RH ½ to opposite sides (to 1W,2M,3W,4M on M side and 2W,1M,4W,3M on W side)

17--::

  All cross to opposite sides as follows: 1c & 3c straight no hands, 2c & 4c turn P RH ¾ | repeat [17-18]: 1c & 3c turn P RH ¾, 2c & 4c straight no hands ; 1c+2c & 3c+4c Circle4 L ending 1c & 3c in the midline, 2c & 4c on own sides

25--::

  1c+3c ½ Reel4 (2c up to 1pl, 4c up to 3pl) ; 1c & 3c turn BH 1 ¾ (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (1919, '2012-01-22 19:29:09.793401+00', '2021-03-27 21:40:52.594039+00', 1087, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; ½Fig8 up (2,1x,3)

9–::

  1c set twice, on [11-12] 1W swivels R to face out ; 1W (1M following) casts R round 2M and down middle to finish 1W between 3c facing 3M, and 1M between 2c facing 2M.

17–::

  1M+2c & 1W+3c Rsh reels3 across

25–::

  1W (1M following) casts R round 3M and cross to 2pl ; 1c turn RH  (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (14927, '2022-06-27 23:40:52.653989+00', '2022-06-27 23:46:08.701918+00', 20923, 1, 202, 'ace', '1--::

  All W advance and clap | retire ; all M advance and clap | pivot R and turn P RH ¾. All face in and join hands

9--::

  All Circle L {3}, cross R foot over and pivot L ; chase cclw

17--::

  All M dance RSh round P ; all W cast off and dance RSh round P. All face P

25--::

  All turn P RH ¼ {1} into promhold facing cclw, promenade {5}. On [31-32] All release LH. All M bring W to their L and meet a new P ready to dance in', 2);
INSERT INTO 'dancecrib' VALUES (14697, '2022-03-10 21:21:56.654852+00', '2022-03-10 21:23:06.037426+00', 18305, 1, 1645, 'ace', '1--::

  All set | cross RH ; S&Link for 3

9--::

  1W+2W+3W & 1M+2M+3M RHA ending in lines3 across (2W between 3c at top, 2M between 1c) ; S&Link for 3 ending in promhold with P facing up (3,2,1)

17--::

  3c+2c+1c promenade, 3c cast off & 2c dance up (2,3,1)

25--::

  Grand chain (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (13939, '2021-04-06 23:08:31.804573+00', '2021-04-07 08:01:12.579543+00', 20304, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; ½ Fig8 R round 3cnrs and face 1cnrs
9--::
  ½ Reel4 on 1diag. On [12] 1c turn LH to face 4cnrs ; ½ Reel4 on 2diag. On [16] 1c turn LH to face 3cnrs[pos]
17--::
  3c+1M & 1W+2c RHA. 1c face 3cnrs[pos] ; ½ Reel4 on 1diag. On [24] 1c turn LH to face 2cnrs[pos]
25--::
  ½ Reel4 on 2diag. On [28] 1c turn LH to face 1cnrs ; 2c+1W & 1M+3c RHA to sides (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (1610, '2012-01-22 19:28:50.788186+00', '2014-04-30 23:23:36.903286+00', 11543, 1, NULL, 'ace', '1–::
  1c cross down RH behind 3c (2c up) and dance up to 2plx ; Mirror ½ Reels3 on the sides (1c out and up) (to 3,1x,2)
9–::
  G-Chain (3c cross to begin)
17–::
  S&Link3 ; 1c turn RH 1¾ to face 1cnr pos. _while_{4} 3c+2c chase ½ clw
25–::
  1c+1cnrs diag. ½Reel4 (1c pass Rsh) ; ½Reel4 with 2cnrs (pass Rsh to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9455, '2016-11-02 07:56:30.443806+00', '2016-11-02 08:00:23.862158+00', 17460, 1, NULL, 'ace', '1--::

  1c+2c S&Link ; Circle4 L (2,1,3)

9--::

  1c cast clw round 3cnr, pass Lsh up/down, cast Lsh round 1cnr and turn P LH to midline, M below W

17--::

  2c+1W & 1M+3c RHA ; (Snake) 1W+2W+2M & 1M+3M+3W unwind, pass the other dancers Lsh and loop L to (3,1,2)

25--::

  3c+1M & 1W+2C LHA ; (Snake) 1W+2W+2M & 1M+3M+3W unwind, pass the other dancers Rsh and loop R to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9453, '2016-11-01 22:57:52.463614+00', '2016-11-03 06:21:56.604653+00', 17458, 1, NULL, 'ace', '1--::

  Parallel Reels4 on both sides

9--::

  1c lead down | cross, W passing above, under joined arms ; lead to between 2c | Turn RH to face down as 2c face up, join NH in line of 4

17--::

  1c+2c BiL | 1c turn 2c EH, finish 2c in 1pl and 1c between 3c ; 1c+3c repeat 

25--::

  1c+4c repeat ; 1c turn RH 1½ (or Birl) to (2,3,4,1)

 

', 5);
INSERT INTO 'dancecrib' VALUES (2230, '2012-01-22 19:29:26.919752+00', '2020-02-10 11:37:18.991407+00', 9634, 1, NULL, 'ace', '1–::

  1c lead down the middle and up, 2c+3c step in for

9–::

  1c+2c+3c Allemande (to 3,2,1)

17–::

  1c long cast to 1pl (3c+2c down) ; 2c repeat (1c+3c down) (2,1,3)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (10850, '2018-06-14 08:47:08.403831+00', '2019-02-04 11:01:05.131777+00', 10498, 1, 202, 'ace', '1--::

  1c set | cross RH ; 1c+2c set | turn RH ¾

9--::

  1W+2W turn LH ¾ _while{2}_ 1M & 2M chase clw ¼ | 1c & 2c turn RH ; repeat [9-10] | 1c & 2c turn RH ¾ to sidelines (2,1x)

17--::

  Circle4 L ; 1c ½ Fig8 up round 2c (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11009, '2018-08-18 11:16:36.378588+00', '2020-04-13 12:05:16.383528+00', 18508, 1, 202, 'ace', '1--::

  1c & 3c turn opposite person RH ½, retain hands | set, W pivoting R ½ to face out ; 1W(3W) followed by 3M(1M) dance out and chase clw ½ to original places with 3M(1M) on their R, both M facing clw

9--::

  1W+3W turn RH _while{4}_ 3M&1M chase clw ½ ; 1c & 3c turn opposite person RH (1,2,3,4)

17-32::

  2c & 4c repeat [1-16] (1,2,3,4)

33--::

  All W RHA ; all cpls turn P LH, W BtoB face P

41--::

  All cpls turn P RH ½ into promhold facing cclw | Promenade cclw ¾ (4,1,2,3)

49--::

  All M LHA ; all cpls turn P RH ¾

57--::

  Circle8 and back (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (9450, '2016-11-01 13:23:55.96031+00', '2021-01-15 20:56:21.044629+00', 12108, 2, 160, 'ace', '1-8::

  All set twice (pull Rsh back) ; chase 1pl CW, set.

9-16::

  Head cpls (4&2) RHA ; Side cpls (1&3) LHA.

17-24::

  Reels of Four - end in square set.

25-32::

  8 Hands round and back.', 0);
INSERT INTO 'dancecrib' VALUES (9971, '2017-06-20 00:24:43.895484+00', '2017-06-28 16:59:44.106439+00', 17801, 1, 202, 'ace', '1--::

 1c dance between 2c, divide, behind 3c, dance between 4c, cast up and dance between 3c, divide, behind 2c to 1pl

9--::

 1c+2c & 3c+4c Parallel Reels4 across, to start: 1M+2W & 3M+4W pass Lsh, 1W & 3W cast down, 2M & 4 M cast up (1,2,3,4)

17--::

 1c in promhold Reel3 across, 1c Rsh to 2M to start, ending in 2pl centre (3c step in on [24])

25--::

 1c+3c Poussette (2,3,1,4)

33--::

 1c in promhold Reel3 across, 1c Rsh to 4M to start (2,3,4,1)

41--::

 Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (1852, '2012-01-22 19:29:06.066286+00', '2014-09-27 22:54:26.244969+00', 9768, 1, NULL, 'ace', '1–::

  1c+2c S&Link ; 2c+1c+3c set, advancing on 2nd step | Turn P BH into

9–::

  3C Allemande, 1c finish facing 1cnr (3,1,2)

17–::

  1c set to and turn 1cnr BH ; repeat with 2cnr, 1c finish Lsh touching in middle facing own side

25–::

  All (1c merging in) chase ½ clw ; all C turn BH 1½ (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9131, '2016-04-08 01:47:42.962538+00', '2016-04-08 01:47:42.962538+00', 16908, 2, NULL, 'ace', '1- 8::

      All dance ½ Grand Chain, set and turn partners 2H. (3)(2)(1) 

9-16::

     All dance Reflection reels of 3 (1s in and up to start) ending with 1s dancing up to face 1st corners pstns as 2s continue to 3rd place 

17-24::

    1s dance ½ diag reel with 1st corners and pass RSh to face 2nd corner pstns, 1s dance ½ reel with 2nd corners and curve to right to 1M between 2s, 1L between 3s 

25-32::

    All Set+Link for 3 to (2)(1)(3) (all on opposite sides), all chase clockwise ½ way to 312 ', 2);
INSERT INTO 'dancecrib' VALUES (1849, '2012-01-22 19:29:05.827533+00', '2021-03-27 19:28:41.177983+00', 7355, 1, NULL, 'ace', '1–::

  1c (2c following) lead between 4c, cross and cast up to places (1x,2x,3,4)

9–::

  4c (3c following) repeat upwards (1x,2x,3x,4x)

17–::

  Reels of 4 on the sides

25–::

  1c lead to 4pl (2c+3c+4c up) ; all set and cross RH

', 2);
INSERT INTO 'dancecrib' VALUES (13938, '2021-04-06 12:57:41.940485+00', '2021-04-07 09:50:25.027461+00', 20305, 1, 202, 'ace', '1--::
  1c & 3c cross RH | cast off (2c & 4c up) ; ½ Fig8 up round 2c-or-4c (2,1,4,3,5)
9--::
  3c (+1c following) dance down between 5c and cast up behind own lines to exchanged places (2,3,4,1,5)
17--::
  4c+1c+5c Corners Pass and Turn. On [20] 1c pivot R to face 4cnrs and repeat [17-20] on 2diag to 4pl (2,3,4,1,5)
25--::
  2c+3c+4c Circle6 and back _while{8}_ 1c+5c ½ R&L ; set | cross RH (2,3,4,5,1)', 4);
INSERT INTO 'dancecrib' VALUES (3703, '2013-02-07 04:05:35.531435+00', '2014-04-30 23:23:42.521705+00', 849, 1, NULL, 'ace', '1–::
  RHA ; W cross RH | set _while_{4} M set | cross RH
9–::
  W cross LH | set _while_{4} M set | cross LH ; LHA
17–::
  R&L
25–::
  Turn person opposite 1¼ into line across ; BiL | both couples dance on to meet new cpl.', 2);
INSERT INTO 'dancecrib' VALUES (1907, '2012-01-22 19:29:09.205236+00', '2014-04-30 23:23:43.577841+00', 1024, 1, NULL, 'ace', '1–::
  1c+2c A&R ; half circle4 L
9–::
  Repeat, to places
17–::
  1M+2W turn RH ; 1W+2M turn RH
25–::
  Poussette', 3);
INSERT INTO 'dancecrib' VALUES (14151, '2021-07-17 08:48:11.30793+00', '2021-07-18 04:34:14.495558+00', 20363, 1, 202, 'ace', '1--::

  1c & 3c lead down {3}, lead up to original place {3} | cast off and face 1cnrs (2c & 4c up) (2,1,4,3,5)

9--::

  ½ Parallel Reels4 on 1diag ; ½ Parallel Reels4 on 2diag and face 3cnrs[pos]

17--::

  ½ Parallel Reels4 on 1diag. 1c in 2plx centre & 3c in 4plx centre, RSh to P, 1M & 3M face down, 1W & 3W face up) ; 5c+4c+2c chase clw ½ _while{4}_ 1c & 3c turn RH (2x,1x,4x,3x,5x)

25--::

  1c & 3c (1M & 3M leading) cast off one place to own sides (4c & 5c up) ; 2c & 4c & 5c turn P RH 1½ (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (1842, '2012-01-22 19:29:05.363573+00', '2019-03-19 10:32:30.823783+00', 820, 1, NULL, 'ace', '1–::

  1c+2c dance RHA for 3 bars and back for 3, 1c casts one place and 2c dance up to top _while_{8} 3c+4c dance RHA for 4 bars ; and LHA back(2,1,3,4)

9–::

  1W Fig8 round 2c and 1M Fig8 round 3c

17–::

  1c set and cast off one place (3c up) ; turn RH for 4 bars to finish in promhold in the middle of the dance facing down

25–::

  1c Reel3 across with 4c, to (2,3,4,1).', 2);
INSERT INTO 'dancecrib' VALUES (1848, '2012-01-22 19:29:05.761041+00', '2016-05-10 20:10:09.695809+00', 8199, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; All turn P RH (2,1,3)

9–::

  1c set adv. to 2cnrs | turn them RH to end between cnrs ; cross down LH between 3c and cast up to (2,1,3)

17–::

  1c set adv. to 1cnrs | turn them LH to end between cnrs ; cross up RH between 2c and cast off to (2,1,3)

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (3862, '2013-07-21 09:13:21.167709+00', '2018-01-06 22:48:20.677387+00', 14983, 1, NULL, 'ace', '1–::

  1c+2c S&Rotate (set to P | cast 1 place clw ; change place RH with P | chase 1 place clw) (2,1,3)

9–::

  1c+3c RHA ; 2c+1c LHA, finish facing 1cnr

17–::

  set to and turn 1cnrs BH ; open (cnr leading) into circle 4L, finish facing 2cnr

25–::

  set to and turn 2cnrs BH ; open (cnr leading) into circle 4L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9973, '2017-06-20 08:24:18.161821+00', '2017-06-28 16:58:15.911403+00', 6858, 1, 202, 'ace', '1--::

 1c Fig8 on opp sides, 1c cross down to start (2c up on [1-2]), ending between 2c facing down

9--::

 1c Fig8 on own sides, ending NHJ in 2pl centre facing down

17--::

 1c turn 3c EH, ending NHJ in 2pl centre facing up ; 1c turn 2c EH (2,1,3)

25--::

 1c+3c S&Rotate (2,3,1)



*Deviser''s note: this dance is a 6x32 jig. On second time through*



- 1-8: Reels3 on opp side

- 9-16: Reels3 on own side

- 17-32: No change', 2);
INSERT INTO 'dancecrib' VALUES (10468, '2018-02-27 16:43:56.357865+00', '2018-02-27 16:51:45.958442+00', 4304, 1, 202, 'ace', '1--::
  1M+2W dance round each other Rsh to respectively 2Mpl & 1Wpl _while{4}_ 1W+2M set diagonally and cast respectively to 2Wpl & 1Mpl ; 2c+1c dance BtoB on sidelines (2,1)
9--::
  2c & 1c dance BtoB across ; turn P RH
17--::
  2c+1c chase clw 1 place | 1W+2M set ; cross RH _while{4}_ 1M+2W cross RH ; set | all chase clw 1 place (2,1)
25--::
  Poussette (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (1851, '2012-01-22 19:29:05.990682+00', '2019-01-27 20:02:22.552567+00', 845, 1, NULL, 'ace', '1–::

  1c+2c circle4 and back

9–::

  1c fig8 around 2c

17–::

  1c lead down | turn RH ; lead up and cast to 2pl

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (9774, '2017-04-06 16:55:13.394818+00', '2020-10-26 18:40:56.17799+00', 17312, 1, 202, 'ace', '1--::

 1c long cast to 2pl _while{4}_ 4c long cast to 3pl, all touching NH briefly (2c&3c step out) ; 1W+4W & 1M+4M Rsh Gypsy turn on sidelines, finishing 1W+4W facing down, 1M+4M facing up (2,1,4,3)

9--::

 1W+4W in tandem with 2W & 3W Rsh lead-change Reel3 _while{8}_ 3M+1M in tandem with 2M & 4M Rsh lead-change Reel3 (2,1,4,3)

17--::

 2c+1c & 4c+3c S&Link ; 1c+2c & 3c+4c change places RH | set (2,1,4,3)

25--::

 1c+4c chase cclw ½ (to 2,4x,1x,3) ; 4c&1c turn LH ½ | pulling Lsh back, cast to own sides (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8195, '2014-02-13 22:57:36.009617+00', '2020-10-27 09:44:09.268511+00', 13983, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; 1c set | 1W cast up as 1M cast down (2W down & 3M up) (Men 2,3,1. W 1,2,3)

9–::

  3C Knot (not own partner) (M 1,3,2. W 3,2,1)

17–::

  1M+3M & 2W+1W S&Link ; All dance BtoB (3,1,2)

25–::

  All turn BH and face up NHJ ; 3c followed by 1c & 2c split and cast off to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14152, '2021-07-18 04:52:20.899323+00', '2021-07-18 05:04:56.02825+00', 20365, 1, 202, 'ace', '_Reel_

1--::

  1c+2c S&Link ; 1c turn P BH and face 1cnrs

9--::

  ½ Reel4 on 1diag ; ½ Reel4 on 2diag (3x,1x,2x)

17--::

  Diagonal R&L (2,1x,3)

25--::

  1c dance BtoB ; turn P RH 1½ (2,1,3)



_Strathspey_



33-64:: Repeat [1-32] in strathspey time', 2);
INSERT INTO 'dancecrib' VALUES (11420, '2018-12-22 12:09:20.627821+00', '2020-07-04 22:37:28.163235+00', 17937, 1, 202, 'ace', '*Seven dancers organised as follows:*  

. . . . . 1 . 2  

Top  3 . 4 . 5  

. . . . . 6 . 7

1--::

  »Upper four dancers«  set | Petronella Turn ; Circle L. New Middle dancer (in 4[pos]) faces down (4,2,1,6,5,3,7)

9--::

  »Lower four dancers«  set | Petronella Turn ; Circle L. New Middle dancer (in 4[pos]) faces up (4,5,1,2,7,3,6)

17--::

  Reel3 on midline, Middle dancer (in 4[pos]) RSh to Top dancer (in 3[pos])

25--::

  Sides (= 1[pos]+2[pos]+6[pos]+7[pos]) R&L _while{8}_ Middle dancer + Top dancer set | turn RH ; Middle dancer + Bottom dancer (in 5[pos]) set | turn LH  (4,5,1,2,7,3,6)



*Deviser''s note:  

R&L on [25-32] may be omitted*  



Finishing position  

. . . . . 4 . 5  

Top  1 . 2 . 7  

. . . . . 3 . 6', 4);
INSERT INTO 'dancecrib' VALUES (3711, '2013-02-13 18:22:00.604352+00', '2015-02-28 21:11:52.957006+00', 14425, 1, NULL, 'ace', '1–::

  1c+2c set | 2c with 1c following dance between 3c and cast to top (2,1,3) | 1c (passing outside) turn 2c ½ EH (1,2,3)

9–::

  Mirror reels3 on opposite sides, 1c cross down and 2c out and up, at end 1c cross down to finish (2,1,3)

17–::

  All set | 2c+3c cross RH _while_{2} 1c set advancing to midline and face own side for ; All set as in DTr | 1c sets to finish (2x,1x,3x)

25–::

  All set PdB R {1} Circle6 L once clw | All cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1860, '2012-01-22 19:29:06.598854+00', '2019-03-19 00:30:41.100819+00', 877, 1, NULL, 'ace', '1–::

  1W casts off behind all W _while_{4} 1M dances down the middle ; 1c lead up to places

9–::

  On [9] all M swivel L to face out with arms folded as in hornpipe, on [16] they swivel L to face in _while_{8} 1W dances Lsh round her P, behind (=inside) 2M, Lsh round 3M and cross to 3W''s pl. (2W+3W up), M swivel L to face in

17–::

  1M repeats [9-16] round the W (who face in) to 3M''s pl., (2M+3M up) (2,3,1,4)

25–::

  1c+4c Poussette (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (13653, '2021-02-08 12:34:31.277275+00', '2021-02-08 12:40:42.095506+00', 17969, 1, 202, 'ace', '1--::

  1c dance down, out between 3c & 4c, meet and dance back out between 4c & 3c to 2pl (2c up on [3-4]) (2,1,3,4)

9--::

  Mirror Reels3 in tandem on sides, 1c in and up, 2c out and down, 3c+4c in tandem on sides (3M+4M, 3W+4W no lead change) out and up. 3c & 4c loop to places where appropriate (2,1,4,3)

17--::

  2c+1c & 4c+3c RHA ; LHA (2,1,4,3)

25--::

  1W (4W following) & 4M (1M following) chase outside cclw ½ to exchanged places (to 2,4x,1x,3) | 4c & 1c cross LH (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8895, '2015-09-07 13:13:27.828928+00', '2015-09-07 13:18:30.785708+00', 2585, 2, NULL, 'ace', '1–::

  1c+2c ½ turn RH | set retaining hands (M facing down, W up) ; 1c+2c 1½ turn RH to places (finish W facing down, M up)

9–12::

  1M+2M dance up and across just above 1pl to face down NH joined _while_ 2W+1W dance down and across just below 2pl

  to face up NH joined | 1c+2c set to partners

13–16::

  1c+2c change places w/partners RH and chase to own sides (2,1)

17–::

  1c turn RH 1¼ | 1M+2c, 1W+3c LH across (2,1x,3)

25–::

  1c turn LH 1¼ | 1M+3c, 1W+2c RH across (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3585, '2012-07-21 11:45:16.500397+00', '2014-04-30 23:23:42.641625+00', 13686, 1, NULL, 'ace', '1–::
  1c+3c cross RH | cast off (2c+4c up) ; dance between couple below and cast up, touch NH and stand BtoB facing out for
9–::
  DoubleDTr, finishing as started (2,1x,4,3x,5)
17–::
  1c+3c turn 1cnr RH | pass P Rsh ; turn 2cnr RH | All set (2,1x,4,3x,5)
25–::
  All A&R ; 1c+3c cross RH and cast off (4c+5c up) (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (8247, '2014-04-24 10:07:35.566099+00', '2014-04-30 23:23:36.918647+00', 14980, 1, NULL, 'ace', '{{title}}
Strathspey

1–::
  1c+2c & 3c+4c S&Rotate (2,1,4,3), 1M+3W face out
9–::
  1c+4c ½ LHA | 1M & 4W cast off _while_{2} 1W & 4M dance out the end and face out on opposite side ; 1c (1W leading) & 4c (4M leading) cast inwards to (2,4,1,3)

{{title}}
Reel

17–::
  Rsh Reels4 on the sides
25–::
  2c+4c & 1c+3c RHA ; 4c+1c LHA (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1607, '2012-01-22 19:28:50.609293+00', '2016-11-21 10:49:54.783155+00', 9106, 1, NULL, 'ace', '1–::

  All 4 couples set, cross RH ; repeat

9–::

  1c & 4c dance NHJ to meet in centre, with person opposite dance NHJ out sides, and cast to own places ; 1c lead down to 4pl (2c+3c+4c up on 15-16))

17–::

  3c+4c (middle couples) R&L

25–::

  2c+3c & 4c+1c RHA ; LHA', 3);
INSERT INTO 'dancecrib' VALUES (8248, '2014-04-24 10:07:51.397264+00', '2015-04-24 20:56:33.736506+00', 8998, 1, NULL, 'ace', '1–::

  1c lead down | turn RH ½ ; lead up, cross and cast off (2c up) (2,1,3)

9–::

  2c+1W & 1M+3c ½ Lsh Reel3 across ; ½ Reels3 on the sides, 1c Rsh to 2cnr (3x,1x,2x)

17–::

  3c+2c A&R up/down _while_{4} 1c cast clw into lines across ; All change places RH and set up/down

25–::

  2c+3c A&R _while_{4} 1c cast clw to opposite side ; All cross RH and set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11508, '2019-01-12 20:29:50.134373+00', '2022-02-15 15:39:43.879014+00', 14448, 1, 1645, 'ace', '1-::

  1c & 3c turn RH | cast off to be LSh to P (2c & 4c up) ; 1M+4c+3W RHA _while{4}_ 2c+1W & 3M+5c &frac12; LSh Reels3 across

9-::

  1c & 3c (1M & 3W leading) &frac12; alternating tandem diag Reels3, RSh to leaders 1cnrs ; repeat with 2cnrs

17-::

  Repeat with 3cnrs, end 1W & 3M leading, facing their 3cnrs ; 1c+4c+3c chase clw to (5x,3x,4x,1x,2x)

25-::

  All &frac12; turn P RH | balance in line down centre ; turn P RH to sides | set (5,3,4,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (9861, '2017-05-16 09:42:19.533583+00', '2022-02-10 07:40:24.223414+00', 10659, 1, 202, 'ace', '1--::
 1c set | cast two places ; cross RH | cast to 2plx _while_ 2c dance up and face out (2,1x,3)
9--::
 Mirror Reels3 on sides {6}, 1c in and up, all joining NH when possible | 1c cross to 2pl (2,1,3)
17--::
 1c+3c Knot (2,3,1)
25--::
 Circle6 and back (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (1859, '2012-01-22 19:29:06.535155+00', '2019-09-20 19:42:59.920787+00', 8348, 1, NULL, 'ace', '{{explanation}}

3c & 4c start on opposite side



1–::

  1c+2c & 3c+4c circle4 left ; S&Link (to 2,1,4,3)

9–::

  Parallel Reels4 on the sides

17–::

  1c+4c L-Chain, ending in promhold with non-partner, facing in

25–::

  1c+4c Dance to opposite side (Lsh to opposite pair), veering left to face in and join NH with P ; dance out through the end couple and cast in to 3plx and 2pl (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (10469, '2018-02-27 17:42:31.40037+00', '2018-02-27 17:50:11.305599+00', 2038, 1, 202, 'ace', '1--::

  1c & 2c cross Rsh | cast off, dance in round 3c, up to sidelines (2x,1x,3)

9--::

  1c, 2c following NHJ, lead down, on [12] 1c turn inwards to face up ; 2c making arch, 1c dance up under the arch and cross to 1pl _while{4}_ 2c turn inwards and dance to 2plx (1,2x,3)

17--::

  1c cast | cross down to 3plx ; set | cast _while{8}_ 2c cross up to 1pl | set ; cast | cross down to 3plx _while{8}_ 3c set | cast ; cross up to 1plx | set (3x,1x,2x)

25--::

  All chase clw ½ to own sides ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8896, '2015-09-07 14:34:36.576513+00', '2015-09-07 14:34:36.576513+00', 1957, 1, NULL, 'ace', '1--::  All set | dance Rsh round P and face P on midline, M below W | set to P

9--::  Partial Reel6 on midline, finish facing P on midline in order (3,2,1)

17--::  All turn P BH 1¼ to (3,2,1) ; 4 hands of Gr-Chain (3c cross to start) (2x,1x,3)

25--::  2c+1c ½ R&L ; 1c+2c turn P RH | 1c lead down as 2c cast up (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1881, '2012-01-22 19:29:07.893062+00', '2023-02-21 13:05:33.344226+00', 954, 1, NULL, 'ace', '1–::

  1W, 1M following, Fig8 round 3M+2M (Lsh to 3M), to own places

9–::

  1c+2c RHA ; LHA

17–::

  1M, 1W following, Fig8 round 3W+2W (Rsh to 3W), to own places

25–::

  1c+2c Set&Rotate (= set diagonally | cast 1 place clw ; change place RH with P | chase 1 place clw) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14253, '2021-08-20 14:21:46.008953+00', '2021-08-20 15:00:08.400435+00', 20447, 1, 202, 'ace', '1--::
  Mirror Reels3 on sides, 1c in (2,1,3)
9--::
  1c set | cast off (2c up) ; turn P RH and face out (2,1,3)
17--::
  3C Chain Progression (3,1,2)
25--::
  3C Knot (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (1872, '2012-01-22 19:29:07.320653+00', '2017-07-07 12:48:32.55122+00', 909, 1, NULL, 'ace', '1–::

  1c Rsh Reels3 on opposite sides, 1M starts across top (Rsh to 2W), 1W crosses down (Lsh to 3M) (to 1x,2,3)

9–::

  1c Rsh Reels3 on own sides, 1W starts across top, 1M crosses down, end in 1pos NHJ (1,2,3)

17–::

  1c NHJ set to 2W | move round in PdB to face 2M ; set to 2M | retire in PdB to 1pl

25–::

  1c+2c set | ½ RHA ; set | ½ LHA to places

33–::

  1c cross RH | cast off one (2c up) ; 1c turn LH 1½ (to 2,1,3)

41–::

  2c+1c R&L.



{{explanation}}

Alternative for [1-8]: 1c ends on own side.  See 101 SCD and Manual', 3);
INSERT INTO 'dancecrib' VALUES (14254, '2021-08-20 15:31:47.666493+00', '2021-08-20 15:34:48.735179+00', 20448, 1, 202, 'ace', '_Strathspey_
1--::
  1c+2c+3c Petronella turn | set ; repeat [1-4] (1x,2x,3x)
9--::
  1c long cast (2c up) ; turn P RH and face out (2x,1x,3x)
17--::
  3C Chain Progression (3x,1x,2x)
25--::
  3C S&Link twice (2,1,3)

_Reel_
33-64::
  Repeat [1-32] in Reel time', 2);
INSERT INTO 'dancecrib' VALUES (1639, '2012-01-22 19:28:52.441185+00', '2021-03-27 12:34:31.400569+00', 7337, 1, NULL, 'ace', '1–::

  1c+2c Circle4 and back

9–::

  1c (crossing down) Fig8 round 2c

17–::

  1W+2M Turn RH ; 1M+2W repeat

25–::

  1c lead down the middle (2c up) ; and up (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (12124, '2019-09-01 21:17:17.220473+00', '2019-09-01 21:18:19.090826+00', 19588, 2, 160, 'ace', '1-4::  All set, 1s half turn RH & face down - 2s 3s full turn RH + face up; (1x 2 3)
5-12::  Promenade reel 3. 1s 2s pass Rshoulder.
13-16::  1s followed by 2s dance up, cast on own side. 2s finish  in top place as 1s finish in 2pl. center of dance facing 2W.
17-24:: Montgomeries'' Rant setting - end 1C facing 2M.
25-28:: 3s dance in + cast up 1 place as 1C turn toward partner and follow 3s, 1s casting up into 3pl.
29-32::  2s3s1s turn BH once round.', 2);
INSERT INTO 'dancecrib' VALUES (1868, '2012-01-22 19:29:07.081684+00', '2016-01-14 16:46:24.696179+00', 900, 1, NULL, 'ace', '1–::

  1c+2c R&L

9–::

  1c lead down the middle {3} and up {3}, and cast off to sidelines (2c up) (2,1,3)

17–::

  Turn 1cnr RH, to sidelines ; Turn 2cnr LH, to sidelines 

25–::

  2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA, (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1637, '2012-01-22 19:28:52.300377+00', '2017-07-07 14:08:26.475822+00', 76, 1, NULL, 'ace', '1–::

  1c cast off | turn RH and face out ; cast up | turn LH

9–::

  1c+2c set | ½RHA ; set | ½LHA (1,2)

17–::

  1M+2W set advancing, turn RH, 1M finishes in 2M place (2M up) ; 1W+2M repeat LH, 1W finishing in 2W place (2W up) (2,1)

25–::

  1M+2W cross RH | 1W+2M repeat ; 1c+2c ½R&L', 3);
INSERT INTO 'dancecrib' VALUES (11725, '2019-03-22 22:15:25.508764+00', '2019-03-22 23:00:04.399364+00', 8574, 1, NULL, 'ace', '1--::

  1c turn LH moving to 2pl (2c up) | 1c cast L round 4cnr into DTr pos facing opp. side | All set

9--::

  1c+1cnrs turn RH ¾ _while{2}_ 2cnrs loop L single ¾ | set in "Inverted DTr" (1c outside) ; 1c+4cnr person turn LH ¾ _while{2}_ 1cnrs loop R single ¼ | set as in DTr (2cnr persons are in the middle)

17--::

  Repeat figure [9-16] (both 2cnrs  & 1c have exchanged places)

25--::

  1c+1cnrs ½ diag. Reel4, at end 1c fast LH turn to face out in 2plx ; 1c chase cclw half round _while_ 2cnrs change places LH on [29-30] and 1cnrs LH on [31-32] (2,1,3)  



*note:  "Loop single" means to dance a loop as if you were turning another dancer.*

', 3);
INSERT INTO 'dancecrib' VALUES (1862, '2012-01-22 19:29:06.675667+00', '2018-11-13 23:42:44.947637+00', 887, 1, NULL, 'ace', '1–::

  1c set, ½RH turn to promhold facing down ; ½ Rsh Reel3 across with 2c, 2c finish in 1plx

9–::

  ½ Lsh Reel3 across with 3c, 3c finish in 2plx ; repeat Rsh with 4c to (2x,3x,4x,1x)

17–::

  1c leading, all cast up outside sidelines to the top, cross Lsh to P and dance down on own sidelines (2,3,4,1)

25–::

  All set and turn partners BH ; 2c+3c & 4c+1c Circle4 L.', 3);
INSERT INTO 'dancecrib' VALUES (14746, '2022-04-05 21:23:11.159794+00', '2022-04-05 21:27:42.642133+00', 16051, 1, 1645, 'ace', '*3c & 4c start on opposite side (1,2,3x,4x)*
1--::
  1c & 4c cast inwards | cross LH out the ends ; cast inwards | 1M+4W & 1W+4M &frac12; turn RH on sides into promhold
  _while{8}_ 2c & 3c &frac34; Fig8: cross RH out the ends | cast in ; cross out RH | set
9--::
  1M+4W & 1W+4M &frac12; Reels3 on sides starting RSh to 2W/3W ; &frac12; LSh Reels3 across
17--::
  Repeat &frac12; RSh Reels3 on sides ; &frac12; LSh Reels3 across (2,4,1x,3x)
25--::
  2c+4c & 1c+3c Poussette (2,4,1x,3x)
', 2);
INSERT INTO 'dancecrib' VALUES (3733, '2013-04-19 10:15:41.091555+00', '2014-04-30 23:23:43.199793+00', 4847, 1, NULL, 'ace', '1–::
  1c+2c & 3c+4c S&Rotate (2,1,4,3)
9–::
  1c+4c set | ½ RHA ; 2c+4c & 1c+3c set | ½ LHA (4,2x,3x,1)
17–::
  2c+3c set | ½ RHA ; 4c+3c+2c ½ Reel3 on side, 3c Rsh to 2c (2,3,4,1)
25–::
  2c+3c & 4c+1c Poussette (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (1887, '2012-01-22 19:29:08.2097+00', '2015-07-03 05:30:18.530325+00', 977, 1, NULL, 'ace', '1–::

  1c set | cross RH ; 1c+2c set | 1W cast down as 2W cast up as both M cross (1c now on M side)

9–::

  L-Chain

17–::

  1c+2c set to P (up/dn) twice ; Turn RH 1½

25–::

  1c followed by 2c (curve in from sideline) slip down the middle ; and back to (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (1866, '2012-01-22 19:29:06.944905+00', '2022-08-31 09:18:49.993673+00', 895, 1, NULL, 'ace', '1–::

  1W casts off one (2W up) | set to 2M ; repeat with 3M (3W up)

9–::

  1W (1M) cast up (down) to 2pl (3W & 2M step down/up), 1c set ; 1W (1M) casts up (down) to midline in 1pl (3pl) facing P | 1c set  (2c & 3c step towards each other on sidelines

17–::

  1W+2c & 1M+3c circle3 & back, 2c & 3c finish BtoB facing ends, NHJ

25–::

  All set | 2c+3c dance to ends making arches as 1W & 1M dance under arches to 2pl ; 2c+1c+3c turn RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10171, '2017-10-12 17:51:43.17498+00', '2020-10-26 18:45:58.330515+00', 17313, 1, 202, 'ace', '1--::

  1c+2c progressive Espagnole up/dn [1c cross RH to 2plx _while{2}_  2c dance up to top place, etc. on [5-8], 1M(1W) turn 2M(2W) LH(RH) 1 ½] (2x,1x,3)

9--::

  1M+3W(1W+3M) change places RH(LH) | 6 bars of DblFig8, 3c cast up to begin, finish 1c facing 1cnr pos

17--::

  Corners pass and turn (2x,1x,3x)

25--::

  All W set | A&R{2+2} _while{6}_ All M A&R{2+2} ; set | All cross RH (2,1,3)



Repeat from new positions in reel time', 2);
INSERT INTO 'dancecrib' VALUES (13654, '2021-02-08 12:48:54.855976+00', '2021-02-08 13:13:25.938457+00', 17967, 1, 202, 'ace', '1--::

  1c lead down (2c up) ; lead up and face 1cnrs

9--::

  Reel4 on 1diag, pass LSh

17--::

  Reel4 on 2diag to midline, LSh to P facing opposite sides

25--::

  1c dance LSh round P to 2pl | cast off (3c up) ; all turn P RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (1870, '2012-01-22 19:29:07.183806+00', '2021-03-27 21:42:33.42588+00', 904, 1, NULL, 'ace', '1–::

  1c long cast to 3pl (2c+3c up) ; 2c repeat (3c+1c up) (3,1,2)

9–::

  All set | cross RH ; set | turn RH ½  into middle for

17–::

  All Allemande

25–::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1874, '2012-01-22 19:29:07.444314+00', '2021-03-27 21:52:53.754112+00', 13449, 1, NULL, 'ace', '1–::

  1c+2c circle4 L and face down NHJ ; dance between 3c and cast up to (2,1,3)

9–::

  Diagonal R&L (1M down, 1W up) (3x,1,2x)

17–::

  1c ½ Fig8 round 1cnr (to 3x,1x,2x) ; All set | All Turn RH ½ and face up for

25–::

  3c+1c+2c Allemande, at end 1c cast off and 3c dance up to (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (1882, '2012-01-22 19:29:07.93562+00', '2021-06-25 22:41:56.158376+00', 958, 1, NULL, 'ace', '1–::

  1c+2c ½ R&L ; 1c followed by 2c lead down the middle

9–::

  2c+1c ½ R&L ; 1c followed by 2c lead up  the middle

17–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (1879, '2012-01-22 19:29:07.790064+00', '2021-11-09 21:04:39.60331+00', 929, 1, NULL, 'ace', '1–::

  1c set | cross down (2c up) ; cast R and in to meet, turn RH ½ into

9–::

  2c+1M & 1W+3c LHA ; Rsh Snake Pass (unwind the LHA, 1c leading, pass other snake Rsh through 2plx and chase clw) (3,1,2)

17–::

  All circle6 L {3}, cross R foot over and pivot L ; chase cclw to (3,1,2)

25–::

  All turn P LH ½ | set LHJ ; All cast R and chase ½ way clw to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14313, '2021-09-15 20:46:36.277352+00', '2021-09-16 09:23:41.633519+00', 20485, 1, 202, 'ace', '1--::

  1M+2W set advancing | turn RH to places ; 1c+2c S&Link (2,1,3)

9--::

  2M+1W set advancing | turn RH to places ; 2c+1c S&Link (1,2,3)

17--::

  1c dance down (2c up on [19-20]) ; and up to 2pl (2,1,3)

25--::

  1c+3c Poussette (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (11973, '2019-07-23 10:50:26.389683+00', '2021-02-08 12:55:39.905056+00', 10506, 2, 26003, 'ace', '1-8:: 1s 4s Set, Cast off/up 1 place and chase clockwise round (2nd and 3rd positions)

9-16:: 2s with 1s, 4s with 3s set and dance right hands across 1/2 way, set and dance left hands across 1/2 way

17-24:: All 4 couples dance reel of 4 on own sides

25-32:: 1s 4s dance 1/2 rights and lefts lead up or down through ends, cross over and cast off or up. 2413

', 4);
INSERT INTO 'dancecrib' VALUES (3701, '2013-02-07 02:49:13.907896+00', '2014-04-30 23:23:37.954823+00', 12801, 1, NULL, 'ace', '1–::
  Snowball Chain, 1c cross RH to start (3,2x,4,1x)
9–::
  2c+3c & 4c+1c L-Chain
17–::
  2c & 1c ½ Fig8 up ; 2c+4c S&Link(3,4,2,1)
25–::
  3c+4c & 2c+1c Demi-Tournee (4 bars of Tournee, finish all on midline facing P, W in the middle ; set to P | turn P ¾ with »own side« hand to exchanged places (4,3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (1888, '2012-01-22 19:29:08.218161+00', '2015-12-20 16:54:59.296727+00', 13269, 1, NULL, 'ace', '1–::

  Circle4 and back

9–::

  RHA, LHA

17–::

  Dance BtoB with dancer opposite ; dance through arches to face next couple (clw form arches)', 3);
INSERT INTO 'dancecrib' VALUES (1890, '2012-01-22 19:29:08.331394+00', '2014-04-30 23:23:43.295+00', 981, 1, NULL, 'ace', '1–::
  1c+4c set | cast in (2c+3c to ends) ; 2c+1c & 4c+3c RHA
9–::
  1c+4c LHA ; set | cast to ends (2c+3c to middle) (1,2,3,4)
17–::
  1c lead to 4pl and make arch _while_ from [19] 4c followed by 3c+2c dance down the sides, curve in to meet and dance up under the arch, finishing in promhold with P (4,3,2,1)
25–::
  4c+3c+2c Allemande (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (1886, '2012-01-22 19:29:08.160909+00', '2016-04-11 22:34:50.569703+00', 976, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  1c+2c S&Link ; 1c+3c RHA

9–::

  2c+1c S&Link ; 1c+2c Circle L (1,2,3)



{{title}}

Reel



17–::

  1c cross down (2c up) into DTr position | All set ; 1c cast R into lines across (M down. W up) | All Set

25–::

  All A&R ; All turn person opposite RH, 1c turning 1¼ (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9135, '2016-04-15 16:28:49.690388+00', '2016-04-15 16:28:49.690388+00', 15915, 1, NULL, 'ace', '1--::

  1c+2c ½ R&L ; Set | pass P Rsh to (2,1)

9--::

  All turn P RH ; Circle4 L (2,1)

17--::

  All A&R ; All dance BtoB (2,1)

25--::

  All turn P LH ; Circle4 R (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10370, '2018-01-01 11:57:44.050106+00', '2018-01-01 11:57:44.050106+00', 18203, 2, NULL, 'ace', '{{explanation}}

 2s and 4s cross to opp. side on 2nd chord 



1–::

      2s and 4s turn  RH to face 1st crnrs, turn 1st crnrs LH, 2nd crnrs RH, partner LH to face 1st crnrs.

9–::  

      Diag. reels of 4, finish on opp sides facing out.

17–::  

     1s and 2s, 4s and 5s (end couples) dance double figs of 8. ( 1s cross down, 2s cast up and 4s cast down 5s cross up to begin)

25--::

     1M and 5L zigzag up/down set:

     1M and 2M,  5L and 4L cross diagonally RH. 1M and 3M, 5L and 3L cross LH. 1M and 4M, 5L and 2L cross RH. 1M and 5M, 5L and 1Lcross LH.   All finish with new partner

', 2);
INSERT INTO 'dancecrib' VALUES (1889, '2012-01-22 19:29:08.269304+00', '2017-07-07 13:23:52.836216+00', 980, 1, NULL, 'ace', '1–::

  1c+2c set | RHA | 1c cast off and 2c dance to top (2,1,3)

9–::

  1c+3c set | LHA | 1c cast to 3pl and 3c dance up (2,3,1)

17–::

  1c set | lead to top (3c down) | cast to 2pl

25–::

  2c+1c+3c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (1885, '2012-01-22 19:29:08.120668+00', '2017-07-07 13:24:20.094082+00', 972, 1, NULL, 'ace', '1–::

  1c turn RH ; 1M+2W LH turn to finish in middle in 2pl (2M dances up to meet 1W)

9–::

  2M+1W & 1M+2W Allemande

17–::

  1c followed by 2c (2M starts upwards) lead down the middle ; and up (2c leading) ;

25–::

  2c+1c R&L', 4);
INSERT INTO 'dancecrib' VALUES (1878, '2012-01-22 19:29:07.739307+00', '2017-07-13 02:36:15.41498+00', 924, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c cross RH | ½ circle4 left ; 1c+4c & 3c+5c cross LH | ½ circle4 right (to 2,4,1,5,3)

9–::

  Half G-Chain (2c cross, 4c face 1c, 5c face 3c) for 5 hands and face across (to 3x,5x,1x,4x,2x) {6} | 3c+1c turn ¾ BH to midline _while_{2} other C turn BH ½ to own sides

17–::

  3c+1c ½Reel4 on midline ; flowing (1W & 3M leading) into ½ circle4 left dividing into 3c+1c cross RH to own side (3,5,1,4,2)

25–::

  All C half circle10 L ; all C turn RH | change to Turn BH (1½ in all) to own sides (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (1894, '2012-01-22 19:29:08.516591+00', '2014-04-30 23:23:43.354675+00', 7553, 1, NULL, 'ace', '1-4::
  move forwards with 3 runs (outer foot starting) and a hop | repeat backwards
5-8::
  move away from partner with the same step and clap on the hop | and back into ballroom hold
9-12::
  Slip- in-slip-hop in line of dance (RR cclw) | same back
13-16::
  progress RR cclw with half turns in step-hop and open out to begin again', 2);
INSERT INTO 'dancecrib' VALUES (3587, '2012-07-21 11:45:17.776657+00', '2014-07-01 08:31:20.733392+00', 988, 1, NULL, 'ace', '1–::

  1c followed by 2c cast off behind own lines ; turn inwards and dance up (2c leading) to places

9–::

  1c+2c DblFig8 (1c cross down)

17–::

  1c+2c dance down (2c leading) the middle and up (1c leading)

25–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (1906, '2012-01-22 19:29:09.147191+00', '2017-06-09 11:22:36.358784+00', 1022, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; ½ Fig8 up (2,1x)

9–::

  2c+1c R&L, 1c finish RHJ with P and LHJ with 1cnr

17–::

  BiL | 1c turn RH ¾ to join LH with 2cnr ; BiL | turn RH to face W side NHJ, 1W above 1M

25–::

  1c dance out, split and cast (1W up, 1M down) and meet in middle NHJ facing M side ; repeat to finish (2,1,3)



{{explanation}}

on 2nd turn 1c lead to the bottom (3c up)', 2);
INSERT INTO 'dancecrib' VALUES (1909, '2012-01-22 19:29:09.314496+00', '2021-06-23 12:06:37.073345+00', 1034, 1, NULL, 'ace', '1–::

  1c+2c+3c circle6 and back, all finishing in the middle for

9–::

  1c+2c+3c Promenade

17–::

  1c+2c Poussette, 1c finish BtoB facing own side for

25–::

  DTr (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3662, '2012-12-11 04:35:09.529955+00', '2014-04-30 23:23:43.399291+00', 7629, 1, NULL, 'ace', '1–::
  1c+2c Set and Rotate (2,1,3,4)
9–::
  Reels of 4 on the sides (2,1,3,4)
17–::
  On own side 1c dance Rsh round 2c and likewise 3c round 4c : 1c turn 3c LH 1½ on the sides (2,3,1,4)
25–::
  2c+3c RHA ; LHA  _while_{8}   1c+4c RHA into diagonal line ; Half Poussette (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (1655, '2012-01-22 19:28:53.287367+00', '2021-07-04 11:09:43.05517+00', 140, 1, NULL, 'ace', '1–::

  Mirror Reels3 on the sides, 1c crossing down to start

9–::

  Repeat, 1c crossing back to own sides

17–::

  1c lead down the middle (2c up) ; and up to 2pl

25–::

  1c cross up for ½Fig8 round 2c ; repeat down round 3c', 3);
INSERT INTO 'dancecrib' VALUES (14312, '2021-09-15 20:34:22.210346+00', '2021-09-16 12:20:02.258885+00', 20484, 1, 202, 'ace', '1--::

  1c set | cross down (2c up) ; cast behind 3c, meet | dance up to 2pl centre (2,1,3)

9--::

  Mirror Reels3 on sides, 1c out and up. 1c face opposite sides as for DblTr

17--::

  6 bars of DblTr | 1c Petronella turn to 2pl (2,1,3)

25--::

  Circle6 and back (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (10401, '2018-01-25 19:56:06.303453+00', '2018-01-25 19:56:06.303453+00', 15013, 2, 963, 'ace', '1-8::
  1c cross down thru 2nd pl opp side, dance behind 3c, cross up thru 2nd place own side and cast up behind 2c to orig place 2c step up 1&2 and step down 7&8  
9-12::
  1M+2W set|1M casts off one pl as 2M steps up   
13-16::
  1W+2M set| 1W casts off one pl as 2W steps up  
17-24::
  2c,1c,3c turn partner RH; circle 6 hands to the left half way  
25-28::
  3c,1c,2c set| pass partn Rsh to own sides and face up  
29-32::
  3c, followed by 1c+2c cast off to 2,1,3  
Note: 29-32 are the last 4 bars of Miss Hadden''s Reel (which the 2012 candidates class at TAC called a ''flype'')
   ', 5);
INSERT INTO 'dancecrib' VALUES (9136, '2016-04-17 02:49:07.796953+00', '2016-04-17 14:34:54.629739+00', 16034, 1, NULL, 'ace', '1--::

  1c+3c S & Rotate while[8] 2c set | turn RH ¾ ; set to P up/down | turn RH to face 1cnr

9--::

  2c+1cnrs Pass & Turn, pass Rsh ; 2c+2cnrs repeat (3,2,1)

17--::

  All set | 3c+2c ½ RHA while[2] 1c cross RH ; All set | 2c cross RH while[2] 3c+1c ½ RHA (2,1,3)

25--::

  Circle6 and back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (1912, '2012-01-22 19:29:09.492434+00', '2021-06-23 11:58:35.620864+00', 1066, 1, NULL, 'ace', '1–::

  1c long cast (2c up on 3-4) to NHJ in centre facing 2W ; set to 2W veering L | set to 2M, finish facing M side

9–::

  2c+1W RHA and 1M+3c LHA, 1c twirl on singly ¾ to face P up/down ; 1c set, turn ¾ BH and open out to NHJ (W on right) facing 3M

17–::

  Set to 3M | set to 3W, finish facing W side ; 2c+1M LHA and 1W+3c RHA, twirl on ¾ as before to face P on midline

25–::

  1c set | petronella to 2pl own side ; All turn BH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2591, '2012-01-22 19:29:48.927109+00', '2020-07-05 09:08:57.96235+00', 3562, 1, NULL, 'ace', '{{explanation}}

1c with 2c on their L, facing 3c with 4c on their R, each M has W on the R



1–::

  1c+4c RHA ; LHA

9–::

  2c+3c RHA ; LHA

17–::

  All set twice to P ; turn P BH

25–::

  All C BHJ slip across (M pass BtoB) ; and back (W pass BtoB)

33–::

  2c+4c & 1c+3c circle4 to L ; LHA

41–::

  All A{2}&R{1}, (All 3 claps) ; 2c+1c progress under arches made by 4c+3c to meet next 2 couples



{{explanation}}

Reaching the end of the room, couples face about, M on left of W', 3);
INSERT INTO 'dancecrib' VALUES (9858, '2017-05-15 23:13:42.824407+00', '2017-08-26 07:17:20.412106+00', 10652, 1, 202, 'ace', '1--::

 1c+2c & 3c+4c RHA, 2c & 4c finishing in middle RHJ ; 2c & 4c turn RH ½ to opp side | all 4Cs set (1,2x,3,4x)

9--::

 1c+2c & 3c+4c ½ M-Chain ; ½ parallel Reels4 (to 3M,3W,1M,1W on W side & 4W,4M,2W,2M on M side)

17--::

 Top 2Cs & bottom 2Cs ½ S&Rotate (to 4,3x,2,1x) ; 4c+3c & 2c+1c RHA finishing 4c facing out, 3c facing in and up, 2c facing out and up

25--::

 4c+3c+2c ½ parallel Lsh Reels3 (to 2,3x,4,1x) ; 3c & 1c ½ Fig8 up (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (1893, '2012-01-22 19:29:08.463574+00', '2017-05-03 14:18:25.834901+00', 985, 1, NULL, 'ace', '{{explanation}}

On 2nd chord, 1W+2M+2W & 3W+4M+4W move one place cclw, to starting position 1c+3c (on M side) facing 2c+4c (on W side)



1–::

  All A&R ; All cross RH | turn P LH (¾ or 1¼) to facing lines across, all M on the left of P

9–::

  Repeat [1-8] (A&R up/down ; cross RH | turn P LH) to sidelines (4c+2c face 3c+1c, all M on the left of P)

17–::

  3c+4c & 1c+2c RHA ; LHA

25–::

  3c+2c Lsh Reel4 starting Lsh to P (along 2diag of set)

33–::

  1c+4c L-Chain (along 1diag)

41–::

  3c+4c & 1c+2c ½ R&L ; 2c+3c ½ R&L (along 1diag), finish 2c+1c facing 4c+3c



{{title}}

;', 3);
INSERT INTO 'dancecrib' VALUES (1904, '2012-01-22 19:29:09.052838+00', '2017-07-07 12:39:47.73557+00', 1018, 1, NULL, 'ace', '1–::

  1c lead down the middle and up

9–::

  2c lead down the middle and up

17–::

  1c+2c RHA {3}, LHA(3) | 1c cast to face 1cnr _while_{2} 2c dance to 1pl

25–::

  Turn CPCP (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9782, '2017-04-08 10:00:16.225345+00', '2017-08-26 11:59:26.539004+00', 15283, 1, 202, 'ace', '1--::

 1c set | cast _while{4}_ 2c set | dance up to top NHJ facing up _and_ 3c set | cross RH to face out ; 2c+1c+3c ½ Mirror Reels3, 1c starting in and down (3,1,2)

9--::

 1c set | dance down to bottom and face out _while{4}_ 2c set | cast up _and_ 3c set | cross RH to face out ; 3c+2c+1c ½ Mirror Reels3, 1c starting out and up (1,2,3)

17--::

 1c set | lead down and up, 2c step in on [24]

25--::

 1c+2c Allemande (2,1,3)

33--::

 Circle6 and back



*Alternative*

25-32 :: Poussette', 2);
INSERT INTO 'dancecrib' VALUES (1903, '2012-01-22 19:29:08.998165+00', '2017-07-07 14:13:45.103058+00', 1020, 1, NULL, 'ace', '1–::

  1W (passing in front) sets to and turns 2M RH _while_{4} 1M sets to and turns 2W LH ; 1W sets to and turns 3M LH _while_{4} 1M sets to and turns 3W RH

9–::

  1c lead up and cross to 1pl, 1W with loop, 1M no loop ; set and cast off one place (2c up)

17–::

  1c+3c Circle4 and back

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (1910, '2012-01-22 19:29:09.368974+00', '2014-04-30 23:23:43.654875+00', 1060, 1, NULL, 'ace', '1–::
  1c turn RH | cast off 2 (2c+3c up) ; cross LH | cast up to 2pl (3c down) (2,1x,3)
9–::
  1c turn P RH, 1cnr LH ; 2cnr RH, P LH to face 1cnrs
17–::
  ½Reel4 on 1diag and pass Rsh ; ½Reel4 on 2diag ; ending (3x,1x,2x)
25–::
  (»Chain«:) Middle couple change places RH with person diag. to R | new middles repeat LH and L ; repeat R, all C cross LH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13291, '2020-10-25 08:30:20.14297+00', '2020-10-28 09:33:34.596015+00', 20095, 1, 202, 'ace', '1--::
  1c & 4c A&R diagonally ; cast inwards (2c & 3c step out) | set (2,1,4,3)
9--::
  2c & 3c A&R diagonally ; cast inwards (1c & 4c step out) | all set (1,2,3,4)
17--::
  1c & 4c cross RSh | cast inwards (2c & 3c step out) ; ½ Fig8 out round nearest ends. On [24] pass LSh on sides into Reel4 position (2,4,1,3)
25--::
  Reels4 (2,4,1,3)
33--::
  4c+1c+3c S&Link ; all set | 1c Petronella turn to 3pl (2,3,1,4)
41--::
  1c+4c Espagnole (2,3,4,1)', 5);
INSERT INTO 'dancecrib' VALUES (3588, '2012-07-21 11:45:18.37687+00', '2015-06-28 23:49:18.185455+00', 1039, 1, NULL, 'ace', '1–::

  1M+2c ½ Lsh Reel across, 1M takes 1W on R in promhold ; with 2c ½ Rsh Reel3 across and face down (2,1x*mid*,3)

9–::

  1c cast down behind 3c and up to stand BtoB between 3c facing opp. side ; set | 1c turn 3c EH (1c starts upwards)

17–::

  1c dance up and cast up behind 2c and down to stand BtoB between 2c facing opp. side | set ; 1c turn 2c EH (1c starts downwards) to finish (1x,2,3)

25–::

  1c+2c 5/4 of DblFig8 (1c cross down) finish (2,1,3)

33–::

  Grand Chain (2,1,3)







', 4);
INSERT INTO 'dancecrib' VALUES (15170, '2022-10-13 07:51:44.853666+00', '2022-10-13 19:53:59.717045+00', 21118, 1, 202, 'ace', '1--::
  1c+2c The Espagnole (2,1,3)
9--::
  All set | turn BH ; chase clw ½ (3x,1x,2x)
17--::
  1c Fig8 on own sides, RSh to 4cnrs[pos] (3x,1,2x)
25--::
  ½ diagonal R&L with 1cnrs[pos]. On [28] 1c dance in, BtoB with P facing 4cnrs[pos] ; ½ LSh Reel4 on 2diag (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (15440, '2023-02-09 03:16:05.812954+00', '2023-02-09 10:05:31.299269+00', 1877, 2, 963, 'ace', '1-8::  

  1C set, turn RH, cast (2s up), turn LH to face out 2nd place own side  

9-12::  

  1C dance RH mixed chain on 2nd diag with 2nd crns - 9/10 1W dance up 1 plc, 1M dance down 1 plc AS 2nd crns turn RH to 2nd place opp sides and face out  11/12 1C half turn 2nd crns LH, 1C face out 2nd place

13-16::  

 1C dance LH mixed chain on 1st diag with 1st crns - 13/14 1M dance up 1 plc, 1W dance down one place AS 1st crns turn LH to 2nd place opp sides and face out 15/16 1C half turn 1st crns RH, 1C do a polite turn into 2nd plc  3x,1,2x  

17-24::  

  All set.  1C pet into lines across, All set, 1C pet into 2nd plc opp side

25-28::   

  All adv for one, retire for one and turn partner RH to face clw  

29-32::  

  All chase clw halfway to 2,1,3 

    

  

  

  ', 2);
INSERT INTO 'dancecrib' VALUES (14155, '2021-07-19 21:36:27.492252+00', '2021-07-19 21:36:35.490391+00', 20394, 1, 1645, 'ace', '1-::

  1c set | 1W casts off _while_ 1M dances down & faces out in 2pl (2c up) ; 1M followed by 1W cast R round 2M & down to end 1M/1W between 3c/2c facing M side

9-::

  1W+2c & 1M+3c RSh Reels3 across, 1c end facing down, 1W behind 1M

17-::

  1c dance down (1M leading) | dance up (1W leading) ; cast L round 2M & 1W crosses to own side (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11359, '2018-12-02 20:24:38.051032+00', '2020-10-28 22:51:24.738957+00', 17453, 1, 202, 'ace', '1--::

  1c+2c A&R ; 1c set | cast to face 1cnrs (2c up on [7-8])

9--::

  Reel4 on 1diag _while{8}_ 2cnrs set | A&R | set. 1c pass LSh to face 2cnrs

17--::

  Reel4 on 2diag _while{8}_ 1cnrs set | A&R | set. 1c into 2pl (2,1,3)

25--::

  1c cross RH | all set ; repeat [25-28] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3773, '2013-07-13 15:56:00.719896+00', '2014-04-30 23:23:43.817549+00', 8041, 1, NULL, 'ace', '1–::
  1c+2c & 3c+4c Circle4 and back (1,2,3,4)
9–::
  Rsh Reels4 on the sidelines
17–::
  1c lead down the middle and up
25–::
  1c cast to4pl (2c+3c+4c up) ; 1c turn RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (1920, '2012-01-22 19:29:09.863556+00', '2018-07-28 17:30:38.484269+00', 9148, 1, NULL, 'ace', '1–::

  1c turn BH | cast off (2c up) ; 1½  turn BH to face 1cnr

9–::

  ½Reel4 with 1cnrs ; turn 1cnr (in 3cnr pos) RH and face 4cnr

17–::

  ½Reel4 with 4cnrs ; turn 4cnr (in 2cnr pos) RH, 1c finish BtoB M facing up, W down

25–::

  3c+1M & 1W+2c circle3 L ; open into ½ circle6 L (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8122, '2013-11-26 20:47:17.418164+00', '2014-04-30 23:23:48.866546+00', 12107, 1, NULL, 'ace', '1–::
  1c+2c RHA ; Parallel ½ Reels3 on the sides, 1c Rsh to 2c (3,2,1)
9–::
  2c+1c LHA ; Parallel ½ Reels3 on the sides, 1c Lsh to 2c (1,2,3)
17–::
  1c cross RH | cast (2c up) ; ½ Fig8 L (2,1,3)
25–::
  Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1911, '2012-01-22 19:29:09.424655+00', '2017-01-07 22:02:59.030142+00', 9341, 1, NULL, 'ace', '1–::

  1M+2W Fig8: pass LH, cast left around P, pass RH, cast R around neighbours to (1,2)

9–::

  1c+2c set, 1W casts off and 2M casts up _while{2}_ 1M+2W cross into P''s place ; All set, 1c facing 2c across | 1M casts off one and 2W casts up one _while{2}_ 2M+1W turn ¾ RH to face P

17–::

  1c+2c Reel4 on 1diag., Rsh to P. 2M+1W end with a Lsh pass. Finish facing P on the diagonal, M facing up and W facing down.

25–::

  2c+1c Poussette: to enter both C turn BH ½ to position', 3);
INSERT INTO 'dancecrib' VALUES (8236, '2014-04-06 17:20:13.131737+00', '2021-02-08 15:14:21.168+00', 10475, 2, 160, 'ace', '1–8::

 1C 3C set, turn RH 1.1/4, petronella turn back to place.

9–16::

 1C 2C 3C reel of three on sides. 2M out&up, 2L out&down to begin.

17–24::

 2C turn RH 1.1/4, set, petronella turn back to place.

25-32::

 1C 2C dance the Knot.

', 2);
INSERT INTO 'dancecrib' VALUES (1702, '2012-01-22 19:28:57.466196+00', '2019-01-27 00:07:55.687749+00', 8111, 1, NULL, 'ace', '1–::

  1c+2c Circle4 L ; 1W+2W loop Rsh round P to own places

9–::

  1c+2c the Knot (2,1)

17–::

  2c+1c Circle4 R ; 1M+2M loop Lsh round P to starting places

25–::

  1c dance up and cast round 2c ; turn BH (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (1908, '2012-01-22 19:29:09.252401+00', '2019-08-29 18:32:32.241907+00', 1030, 1, NULL, 'ace', '1–::

  Mirror Reels3{6} on own sides (1c start in) | 1c+2c continue to put 1c in DT position and 2c at top

9–::

  1c dance DT, finish in 2plx facing P, _while_{8} 2c+3c set in DT | petronella cclw one place ; repeat (3x,1x,2x)

17–::

  1c, start Rsh into Fig8{6} round own cnr positions | All C set advancing and face up

25–::

  All lead up, cross and cast to (2,1,3) ; all C turn RH', 3);
INSERT INTO 'dancecrib' VALUES (13656, '2021-02-08 19:03:19.349946+00', '2021-02-08 19:09:15.07132+00', 17963, 1, 202, 'ace', '1--::

  1c ½ Fig8 down round 2c ; 1c dance down between 3c and cast up looping to 3pl (2c+3c up on [7-8]) (2,3,1x)

9--::

  1c ½ Fig8 up round 3c ; 1c dance up between 2c (3c down) ; cast off passing LSh BtoB in centre, 1M facing down

17--::

  All set as in DTr | 1c turn 1cnrs LH into 1diag RH with P ; BiL | 1c turn P RH finishing BtoB, 1M facing up

25--::

  All set as in DTr | 1c turn 2cnrs RH into 2diag LH with P ; BiL | 1c turn P LH to 2plx and face out

33--::

  Reels3 on sides, 1c LSh to 2cnrs. On [39-40], 1c pass P RSh to 2pl (2,1,3)

41--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3590, '2012-07-21 11:45:19.370796+00', '2014-07-26 23:08:54.62624+00', 1158, 1, NULL, 'ace', '1–::

  1c set, cross RH, cast off 2, lead up middle and cross to own place (1,2,3)

9–::

  1c lead down {3}, up {3} | cast to face 1cnr (2c up)

17–::

  Turn CPCP to (2,1,3)

25–::

  All A&R{1+1}| repeat ; Turn P BH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1930, '2012-01-22 19:29:10.447188+00', '2021-02-21 18:23:32.438822+00', 9632, 1, NULL, 'ace', '1–::

  1M+3W pass Lsh to face 3M / 1W resp. | ½Reel4 on 2diag. | 3M+1W cast clw 2 places _while_{2} 1M+3W loop in, all to P''s place (1x ,2, 3x)

9–::

  1c+2c RHA, 1M ends facing out ; 1M casts 2 behind W line, in round 3M and up to 2W place, facing down _while_{4} 1W follows parallel path down the middle, round 3W and to 2M place (2c up on 15-16)  (2,1x,3x)

17–::

  G-Chain (2c cross)

25–::

  2c+1c LHA ; 1c+3c lead up between top couple, cross and cast off to order 2,3,1

', 3);
INSERT INTO 'dancecrib' VALUES (1706, '2012-01-22 19:28:57.643201+00', '2014-10-16 21:58:19.360526+00', 13499, 1, NULL, 'ace', '1–::

  All set | 1c+4c cross RH _while{2}_ 2c+3c turn BH and face nearest end ; 2c+3c dance out, cross and cast in (1x,2x,3x,4x)

9–::

  2c+3c ½ R&L ; ½ Reels4 on the sides, 2c&3c omit last Lsh to finish in the middle facing last corner passed (4x,3mid,2mid,1x)

17–::

  2c+3c set H&G, finish 2M&3W on opp. sidelines, 2W at top, 3M at bottom

25–::

  2c+3c Circle4 L 7/8  to (4x,2x,3x,1x) ; All set | All Turn P RH ½, 4c facing 2c & 3c facing 1c for

33–::

  4c+2c & 3c+1c Rondel (middle cpls start the arches)

41–::

  Circle8 and back (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3762, '2013-06-13 07:48:11.754322+00', '2014-04-30 23:23:43.982687+00', 13757, 1, NULL, 'ace', '1–::
  1c+2c set | 1c cast as 2c dance up and loop into 1pl ; 1c dance between 3c and cast up to face 1cnr
9–::
  1c set to 1cnr | dance clw round P to face 2cnr ; repeat with 2cnr, finishing facing out (2,1,3)
17–::
  1c cast R, meet, turn RH ½ fast, ; twirl R and cast R to 2pl _while_{8} corners A&R diagonally twice
25–::
  Circle6 and back

{{explanation}}
Note: [1-4] is a "mirrored" Set and Link.', 3);
INSERT INTO 'dancecrib' VALUES (1922, '2012-01-22 19:29:09.96616+00', '2020-02-20 21:29:06.282883+00', 8042, 1, NULL, 'ace', '1–::

  1W+2W+3W chase cclw around the men, to places

9–::

  1M+2M+3M repeat clw round the W

17–::

  1c slip down | and back ; cast to the bottom (others step up)

25–::

  All Circle8 and back.', 4);
INSERT INTO 'dancecrib' VALUES (12439, '2019-12-17 18:34:15.918506+00', '2020-06-24 10:40:50.364621+00', 13306, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 1c+4c S&Link _while{4}_ 2c & 3 set | cross RH (2x,4,1x,3)

9--::

  4c+1c RHA ; 2c+4c & 1c+3c turn LH on sides (2x,4,1x,3)

17--::

  4c+1c M-Chain

25--::

  2c & 3c ½ Fig8 inwards  ; all turn P BH (2,4,1x,3x)



*Deviser''s note:*  

On [5-6] all set in line in fours', 2);
INSERT INTO 'dancecrib' VALUES (8898, '2015-09-07 16:26:17.010909+00', '2022-12-19 11:30:03.860425+00', 16732, 2, NULL, 'ace', '1-8::

  1M 2L cross RH, set ; 1L 2M cross LH , set.

9-16::

  2C 1C half R&L ; 1C 2C turn RH into Allemande hold.

17-24::

  1C 2C Allemande - 1C end facing 1crnr.

25-32::

  Turn CPCP - end 1M btwn 3C, 1L btwn 2C.

33-40::

  Reel3 across the set -  Lsh to 1crnr to begin (8 bars)', 2);
INSERT INTO 'dancecrib' VALUES (14156, '2021-07-19 21:36:57.59831+00', '2021-07-19 21:36:57.59831+00', 20394, 2, 10819, 'ace', '1-4:: 1C set, 1L cast down _while_ 1M dance down into second plc, facing out (2C step up on bars 3+4)
5-8:: 1M leads 1L around 2M; 1M to finish between 3C, 1L between 2C, both facing men''s side.
9-16:: 2 parallel RS reels of 3 across, 1M & 1L finish between couples, facing down
17-20:: 1C dance down the middle (1M in the lead) and up (1L in the lead) to finish 1L between 2C & 1M between 3C, both facing up.
21-24:: 1L leads 1M around 2M into second plc own side.', 5);
INSERT INTO 'dancecrib' VALUES (1918, '2012-01-22 19:29:09.749893+00', '2015-09-08 06:03:47.125742+00', 1085, 1, NULL, 'ace', '1–::

  1c+2c circle4 and back

9–::

  1c+2c RHA ; LHA

17–::

  1c down the middle and up

25–::

  1c cast to the bottom (other C up) ; 1c turn RH', 2);
INSERT INTO 'dancecrib' VALUES (3865, '2013-07-21 13:16:08.257432+00', '2015-10-15 22:39:40.880815+00', 14984, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c diag Reels4 (start Rsh to P, finish facing P

9–::

  1c+2c & 3c+4c Chain Progression (turn P RH ¾ | »middles turn LH 1½ _while_ Ps chase ½ clw | turn RH to own side) finishing for

17–::

  1c+4c Allemande (2,4,1,3)

25–::

  2c+4c & 1c+3c circle L ; 4c+1c Circle R', 4);
INSERT INTO 'dancecrib' VALUES (1943, '2012-01-22 19:29:11.13321+00', '2020-09-19 11:32:30.769504+00', 13584, 1, NULL, 'ace', '1–::

  1c set adv. and join RH | lead down (2c up) , cross below 3c, cast up and turn LH to face 1cnr

9–::

  1c+1cnrs ½ Reel4 ; turn 3cnr (pstn) RH | turn P LH to face 2cnr

17–::

  1c+2cnrs ½ Reel4 ; turn 4cnr (pstn) RH | turn P LH into

25–::

  3c+1M & 1W+2c RHA ; 2c+3c chase clw ½ round _while_{4} 1c turn LH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1925, '2012-01-22 19:29:10.150926+00', '2016-03-28 21:57:59.265235+00', 1128, 1, NULL, 'ace', '1–::

  All W RHA _while{4}_ all M dance cclw half round ; W keep RHJ and give LH to new M, All set | all turn LH ½  to put M in middle

9–::

  All M RHA _while{4}_ all W dance cclw half round ; M keep RHJ and give LH to P, all set | turn LH ¼ to new places (3,4,1,2)

17–::

  1c+3c A&R ; ½ R&L to places

25–::

  2c+4c repeat

33–::

  All set to P | turn RH to face cnrs ; set to and turn cnr RH to promhold, M inside

41–::

  All Promenade cclw, M finish in own places, with the cnr as new P



{{explanation}}

Repeat 3 times, each time with a new partner', 3);
INSERT INTO 'dancecrib' VALUES (1717, '2012-01-22 19:28:58.167674+00', '2016-12-06 20:10:37.847697+00', 364, 1, NULL, 'ace', '1–::

  1c lead down the middle and up, 2c step in for

9–::

  1c+2c allemande

17–::

  1c+2c R&L

25–::

  1c Fig8 up around 2c.', 2);
INSERT INTO 'dancecrib' VALUES (1704, '2012-01-22 19:28:57.55929+00', '2016-12-07 14:24:38.56034+00', 11583, 1, NULL, 'ace', '1–::

  1c+2c S&L, 2W finish facing out ; 1c turn RH 1½ _while{4}_ 2c+3c chase ½ clw (3x,1x,2x)

9-14::

  Men advance | retire ; set | _while{6}_ Women set | advance ; retire |

15-16::

  All turn P RH ½, into

17–::

  3c+1c+2c Allemande, on [23-24] 1c set advancing to face 1cnr

25–::

  Corners pass & turn (cnrs make BH turns), 1c passing Rsh (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3589, '2012-07-21 11:45:18.902087+00', '2019-02-05 16:23:24.383193+00', 13721, 1, NULL, 'ace', '1–::

  1c+4c lead down {3} up {3} | cast off (2c+5c up)

9–::

  1c & 4c RHA with 1cnr+4cnr (2c+1W & 1M+3c & 5c+4W & 4M+6c RHA),; repeat as LHA with 2cnr+3cr, finish facing 4cnr

17–::

  2c+1c+3c & 5c+4c+6c Reels3 on own sides, Rsh to 4cnr (2,1,3,5,4,6,7)

25–::

  1c+4c cross RH | cast off (3c+6c up) ; 1c+4c cross LH and cast off (5c+7c up) (2,3,5,1,6,7,4)



{{explanation}}

Note: may be danced in a 4c set.', 3);
INSERT INTO 'dancecrib' VALUES (1933, '2012-01-22 19:29:10.587697+00', '2019-02-22 17:23:43.462108+00', 9633, 1, NULL, 'ace', '1–::

  1c cross RH | 1c cast to 3pl _while_{2} 3c cross to top ; 3c cast to 2pl _while_{2} 2c cross to top | 2c cast to 3pl _while_{2} 1c cross to top and face out (1,3x,2x)

9–::

  1c turn 3c EH 1½ ; 1c cross down into ½ Fig8 (3x,1x,2x)

17–::

  All set advancing to join P facing down | bars [3-8] of a 3c Knot (2,1,3), 1c finish facing 1cnr

25–::

  1c set to 1cnr | to 2cnr and swivel R ; 1c cross RH and cast off (3c up) (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2225, '2012-01-22 19:29:26.684508+00', '2023-02-09 11:29:52.843986+00', 2158, 1, NULL, 'ace', '1–::

  1c ½ RH turn to promhold, dance between 3c ; cross LH (2c up) and cast up to (2,1,3)

9–::

  2M+1W+3M set advancing to form triangle NHJ {2}, set retiring, advancing, retiring _while_{8} 2W+1M+3W stand {2}, set advancing likewise, retiring, advancing

17–::

  1c in promhold +2W+3W Lsh ½Reel3 in centre of set ; 1c+(2W+3M)+(3W+2M) all in promhold ½Reel3

25–::

  1c+2M+3M ½Reel3 (finish 2x,1x,3x) ; all set and cross RH', 3);
INSERT INTO 'dancecrib' VALUES (14154, '2021-07-19 17:08:14.120112+00', '2021-07-19 22:53:37.921229+00', 18096, 1, 1645, 'ace', '1-::
  1c & 3c lead down 2 places, cross & cast up (2c & 4c up on [1-2]) ; turn LH to face 1cnrs
9-::
  1c & 3c corner chain with 1cnrs, end facing 2cnrs
17-::
  1c & 3c repeat corner chain with 2cnrs, end in centre, W above M, facing 1cnrs
25-::
  1W+2c & 3M+5c LSh Reels3 across _while{8}_ 1M+3W dance Fig8 round standing 4c, starting LSh to 1cnrs & passing RSh in centre, all ending on own side (2,1,4,3,5)
33-::
  1c+4c & 3c+5c turn 1&frac12; on sides, M RH, W LH | all set (2,4,1,5,3)
', 2);
INSERT INTO 'dancecrib' VALUES (3708, '2013-02-09 16:41:14.588168+00', '2014-04-30 23:23:44.173888+00', 1167, 1, NULL, 'ace', '1–::
  1c+4c cross RH | cast to centre (2c+3c to ends) | ½ Fig8 round end cpls (2,1,4,3)
9–::
  All set | 1c+4c ¾ R&L to face »corner«
17–::
  1c+4c set to and turn cnr RH ; set to and turn LH on the sides (2,4,1,3)
25–::
  Reels4 on the sides (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1934, '2012-01-22 19:29:10.6399+00', '2021-06-22 17:35:48.589097+00', 1154, 1, NULL, 'ace', '1–::

  All set | Circle6 L

9–::

  All set, Circle6 R, finishing for

17–::

  1c+2c+3c promenade, at the end 1c cast and 2c dance up (2,1,3)

25–::

  1c+3c RHA ; 2c+1c LHA', 3);
INSERT INTO 'dancecrib' VALUES (12763, '2020-04-13 19:16:21.770407+00', '2020-04-13 19:16:47.05606+00', 19955, 1, 1645, 'ace', '1-::

  1c cross RH | cast off (2c up) ; &frac12; Fig8 round 3c & end facing 1cnrs

9-::

  1c+1cnrs Corner Chain, 1c end facing 2cnrs

17-::

  1c+2cnrs Corner Chain ending on the sides

25-::

  M stand while all W dance RSh round P & face them RHJ ; set turning under R arm (allemande turn) & dance back to place (2,1,3)  

  *On 2nd turn, M dance RSh round W, set RHJ & cast away to place.*

', 2);
INSERT INTO 'dancecrib' VALUES (1944, '2012-01-22 19:29:11.174218+00', '2020-11-30 11:18:01.840981+00', 13075, 1, NULL, 'ace', '1–::

  2c (= dancing C) turn RH ½ | twirl R to sideline facing out ; cast Rsh round 1cnr, meet and turn LH to face 1cnr

9–::

  ½ Diag Reel4 with 1cnrs ; turn 3cnrs (1cnr person) RH | turn P LH ¾ to face 2cnr

17–::

  ½ Diag Reel4 with 2cnrs ; turn 4cnrs (2cnr person) RH | turn P LH ½ to between end cpl (M up, W dn) facing 3cnr

25–::

  ½ Lsh Reels3 across, finish NHJ at 2pl own side facing down ; 2W+1W & 2M+1M turn EH 1½ to (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (1932, '2012-01-22 19:29:10.537049+00', '2021-03-27 19:05:10.210155+00', 9835, 1, NULL, 'ace', '1–::

  All C Reel3 on the sides, 1c cross to begin (to 1x,2,3)

9–::

  1M+2W turn LH 1½ _while_{4} 1W+2M turn RH 1½ ; 1M+3W turn RH 1½ _while_{4} 1W+3M turn LH 1½ (to 2,3,1x).

17–::

  All C Reel3 on the sides, 1c crossing up, 1c end in 3pos NHJ facing up

25–::

  1c set to 3c who reply | 3c step down as 1c set advancing to 2c who reply ; 1c dance to top & cast to 2pl (2,1,3).

', 3);
INSERT INTO 'dancecrib' VALUES (12669, '2020-03-17 02:36:36.80238+00', '2021-07-20 09:12:07.852841+00', 17396, 1, NULL, 'ace', '1--::

  Circle8 L ½ ; All A&R (3,4,1,2)

9--::

  1c+3c chase clw ¼ inside set, M leading, and pivot R to face side cpl | pass opposite Rsh ; chase clw to original place | set _while{8}_ 2c+4c set | A&R | set (1,4,3,2)

17--::

  1c+3c ½ L-Chain ; 2c+4c ½ M-Chain (all M are now in original place, all W ½ way round)  

25--::

  New pairs face each other & set | all move 1/8 round clw (M cast away to W place of the next position behind them & face clw, W dance to M place of the same position & face cclw) ; repeat from new places.  All are in new pairs, with original P across the set (M: 4,1,2,3; W: 2,3,4,1).  

::

  *Each time through all M move 1 position clw, all W 1 position cclw*  

', 0);
INSERT INTO 'dancecrib' VALUES (8144, '2014-01-05 12:46:02.440786+00', '2014-01-05 12:49:46.414235+00', 11949, 2, NULL, 'ace', '1- 8::

  1s turn RH and cast 1 place, 1s turn LH to face 1st corners

9-16::

  1s+1st corners dance ½ Celtic reel on the diagonal:-

17-24::

  Repeat with 2nd corners:- 1s+2nd corners dance ½ Celtic reel on the diagonal, (but 1s do not dance round each other at the end, instead turning RH to end in 2nd place), while 1st corners set and dance 1 place clockwise, set and dance 1 place clockwise

25-32::

  All circle 6h round and back



{{explanation}}



Description of The Celtic Reel

     

      9-12::

   1s+1st corners pass RSh as for reel of 4 then 1s dance clockwise ¼ way as 1st corners dance ¾ LSh round each other to face 1’s on the 2nd corner diagonal, at the same time 2nd corners set and dance clockwise to 1st corner position. 

      

      13-16::

  1st corners and 1s pass RSh to as for reel of 4 then 1st corners dance clockwise ¼ way while 1s dance ¾  LSh right round each other to face 2nd corner people who are in 4th corner position having again set and danced ¼ way round clockwise.



', 5);
INSERT INTO 'dancecrib' VALUES (1935, '2012-01-22 19:29:10.685263+00', '2019-03-18 23:48:25.214867+00', 1161, 1, NULL, 'ace', '{{explanation}}

A square set with in the middle 5M facing up, 5W down



1-4::

  1c+2c+3c+4c set, turn RH _while_{4} 5c set | set passing

5-12::

  1c (promhold)+5M+5W+3c (promhold) reel4

13-20::

  5M+2c & 5W+4c RHA, pass Rsh ; 5M+4c+ 5W+2c LHA, finish 5c facing P across (Teapots)

21-24::

  5c set, turn LH to face 1c in promhold

25–::

  5c+1c change places Lsh | 1c+2c repeat ; 2c+3c repeat | 3c+4c repeat



{{explanation}}

The set is now formed by (5,1,2,3, and 4c in the middle', 2);
INSERT INTO 'dancecrib' VALUES (1938, '2012-01-22 19:29:10.830555+00', '2014-10-16 21:25:06.393807+00', 10787, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; ½ Fig8 across to the R (1M up, 1W down) to face 1cnr

9–::

  1c+1cnrs pass and turn, at end 1c swivels R to be BtoB facing 4cnr ; 1c+4cnrs pass and turn, 1c swivels R to finish BtoB facing own side for

17–::

  DTr, 1c finish between end couple facing own side

25–::

  Reels3{6} across (Rsh to 4cnr) | 1c cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1942, '2012-01-22 19:29:11.034927+00', '2014-11-10 23:46:56.111853+00', 9985, 1, NULL, 'ace', '1–::

  1c cast off | turn ¾ RH ; dance out through ends, cast R round 4cnr to face end cpl (1cnr+4cnr)

9–::

  2c+1W & 1M+3c circle3 L, at end 1c swivel R to face P ; 1c set to P | set passing P to face other end couple

17–::

  2c+1M & 1W+3c circle3 L, at end 1c swivel R to face P ; 1c set to P | turn LH to face 1cnr

25–::

  1c+1cnrs pass and turn, 1c pass Rsh ; 1c+2cnrs pass and turn, 1c passing Rsh to  (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1949, '2012-01-22 19:29:11.463666+00', '2021-06-21 08:49:00.779893+00', 1215, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; set advancing & turn BH ¼ [?]

9–::

  1W+2c & 1M+3c circle3 L ½ round | set in facing lines across ; 1c set advancing | turn BH ½

17–::

  1M+2c & 1W+3c circle3 L ½ round | set in facing lines across ; 1c turn RH (stay in the middle)

25–::

  1c dance Rsh round 1cnr, pass P Rsh ; Rsh round 2cnr

33–::

  1c Reels3{6} on opposite sides (Lsh to 1cnr) | 1c cross (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11726, '2019-03-22 23:09:19.194998+00', '2019-03-22 23:32:55.654853+00', 16514, 1, NULL, 'ace', '1--::

  1c+3c set | cross RH ; Chase L ½ round 2c (3,2,1,4)| 

9--::

  3c+2c & 1c+4c Circle4 L ; all advance passing Rsh and face P | retire (3x,2x,1x,4x)

17--::

  2c+1c dance out nearest end and cast back round cnr ; 2c+1c RHA (3x,2x,1x,4x)

25--::

  3c+2c & 1c+4c "The Spiral":  3M+2W turn RH ¾ | 3c+2c BiL, the end dancers turning in to face clw : in line rotate ¼ clw | end dancers dance one place clw as middle dancers turn RH to own side opposite P (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (1719, '2012-01-22 19:28:58.268359+00', '2017-07-07 14:26:16.115279+00', 373, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c R&L

9–::

  1c+2c & 3c+4c set | ½ RHA ; all set | cross RH (to 2,1,4,3)

17–::

  Reels4 on the sides, 2c finish in 1pl, the others dance in on [24] for

25–::

  1c+4c+3c Allemande (to 2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (9463, '2016-11-07 09:08:21.611097+00', '2018-07-13 06:39:28.434585+00', 17479, 1, 202, 'ace', '1--::

 Reels3 on opposite sides (1x,2,3)

9--::

 Reels3 on own sides (1,2,3)

17--::

 1c+2c ¾ R&L |All set (2,1,3)

25--::

 1c+3c ¾ R&L |All set (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (1959, '2012-01-22 19:29:12.096565+00', '2017-04-21 22:51:02.991777+00', 1261, 1, NULL, 'ace', '1–::

  1W+2M turn RH 1¼ and face out _while_{4} 1M+2W set and cast one place cclw (to 2,1) ; 2c+1c turn on sides LH (2,1)

9–::

  Repeat from new positions (1,2)

17–::

  1c+2c Circle 4 and back

25–::

  1c cross RH | cast ; cross up and cast _while_{8} 2c turn RH ½ | dance up ; cast off | cross up (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (13785, '2021-03-04 00:10:42.080879+00', '2021-03-04 00:23:41.5779+00', 20241, 1, 202, 'ace', '1--::
  1c+2c »Non Progressive Set&Rotate« [: same as 2C Set&Rotate except [5-6] RHA ½] (1,2,3)
9--::
  3C Knot (3,2,1)
17--::
  2M+1W cross RH _while{2}_ 2W+1M set diagonally | 2M+1W set diagonally _while{2}_ 2W+1M cross RH ; 1c+2c chase 1 place clw | 2W+1M cross RH _while{2}_ 1W+2M set (3,1,2)
25--::
  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (1960, '2012-01-22 19:29:12.140119+00', '2015-02-18 21:31:46.952912+00', 11771, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; dance between 3c and cast up to (2,1,3)

9–::

  2c+1W & 1M+3c ½ Reel3 across ; ½ Reels3 on opposite sides (Rsh to 2cnr pos.) to (3x,1x,2x)

17–::

  3c+1M & 1W+2c RHA, and 1c faces 3cnr pos ; ½ Reel4 on 1st diag., 1c pass Rsh to face 4cnr pos.

25–::

  ½ Reel4 on 2nd diag., 2c+1W & 1M+3c RHA (2,1,3)

33–::

  All circle 6 L on [36] cross R foot over and face cclw ; All chase back to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3575, '2012-05-08 20:38:38.386403+00', '2014-04-30 23:23:44.433106+00', 1244, 1, NULL, 'ace', '1–::
  1W+3M turn RH | dance Rsh round P {4} | turn RH again, finishing RHJ and LHJ with P for
9–::
  1c+3c BiL | turn P ½ LH ; BiL | turn P LH to original places (¼ or ¾ turn)
17–::
  1c+3c R&L
25–::
  1c+3c L-Chain (M no polite turn at the end)
33–::
  All turn corner RH | give P LH to form circle (M face out) and set ; turn P LH into promhold facing cclw
41–::
  All dance cclw to original positions

{{explanation}}
repeat 3 times with 2W, 3W and 4W leading in turn', 3);
INSERT INTO 'dancecrib' VALUES (1958, '2012-01-22 19:29:12.045228+00', '2014-04-30 23:23:44.497565+00', 7650, 1, NULL, 'ace', '1–::
  1c lead down the middle (2c up) ; and up to face 1cnrs
9–::
  SetH&G , finish BtoB in middle, 1M facing up, 1W down
17–::
  DTr up/down, to end in same position
25–::
  Reels3{6} on the sidelines, Rsh to 2cnr | 1c cross', 3);
INSERT INTO 'dancecrib' VALUES (14029, '2021-05-13 09:23:41.987068+00', '2021-05-13 09:27:07.442067+00', 2980, 1, 202, 'ace', '1--::
  1c turn P RH (2c up) ; lead down | turn P RH and face 1cnrs
9--::
  1c+1cnrs set | turn RH ; 1c set to P | turn P RH and face 2cnrs
17--::
  1c+2cnrs set | turn RH ; 1c set to P | turn P RH to 2pl (2,1,3)
25--::
  1c+2c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1957, '2012-01-22 19:29:11.994845+00', '2021-01-29 22:31:13.403159+00', 11187, 1, NULL, 'ace', '1–::

  1c long cast to 3pl (2c+3c up) ; 2c+3c+1c set & turn RH ½ to face down for

9–::

  2c+3c+1c Allemande (start down) (to 1x,3x,2x)

17–::

  All M (1M leading) chase ½ cclw _while_{4} all W (1W leading) chase ½ clw inside the men ; 1c dance to top and cast off one (3c down) (2,1,3)

25–::

  Teapots R ; and L (1M+3c & 1W+2c RHA ; 1M+2c & 1W+3c LHA)', 2);
INSERT INTO 'dancecrib' VALUES (1972, '2012-01-22 19:29:12.673363+00', '2020-12-31 11:52:01.531522+00', 14338, 1, NULL, 'ace', '1–::

  1c+2c R&L

9–::

  1c+3c double Fig8 (1c cross down to begin)

17–::

  1c+2c+3c promenade

25–::

  1c cast off one (2c up) | All set ; 2c+1c+3c dance BtoB', 2);
INSERT INTO 'dancecrib' VALUES (1962, '2012-01-22 19:29:12.220391+00', '2015-02-28 21:05:58.156951+00', 1280, 1, NULL, 'ace', '1–::

  1c+2c+3c circle6 and back, finishing in couples for

9–::

  1c+2c+3c Promenade

17–::

  1c cross RH, cast off one {3} cross LH, cast off one | lead up to face 1cnrs (2c up on [19-20]

25–::

  1c SetH&G with clap on [31] and Petronella Turn to own sideline', 3);
INSERT INTO 'dancecrib' VALUES (3672, '2013-01-01 14:23:01.718364+00', '2014-04-30 23:23:44.557235+00', 14637, 1, NULL, 'ace', '1–::
  1c cross | cast (2c up) ; 1c petronella R and set  _while_{4}  2c facing 3c set and change places RH
9–::
  Reels3{6} across, 1c Lsh to 2cnr | 1c Petronella to the R (3,1,2)
17–::
  1c turn RH ¾ to between ends ; 1c petronella R and set  _while_{4}   2c+3c set and cross RH and face out(3x,1x,2x)
25–::
  Reels3{6} on the sides, 1c Lsh to 1cnr | All cross RH (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (1951, '2012-01-22 19:29:11.556212+00', '2015-05-11 21:50:05.263641+00', 1218, 1, NULL, 'ace', '1--::

  1c set | cast off one (2c up) ; turn RH 1½ to end in the middle facing up in promhold

9--::

  Mirror Reels3 on own sides, 1c crossing up, 2c start down, 3c out and up (2,1,3)

17--::

  1c A&R ; 2c+1c+3c dance (touch hands) BtoB, 1c pivoting R at end into 

25--::

  2c+1c+3c DTr

', 3);
INSERT INTO 'dancecrib' VALUES (8897, '2015-09-07 15:25:21.132792+00', '2015-09-07 15:25:21.132792+00', 7436, 1, NULL, 'ace', '1-:: 1c+2c Espagnole, finish in tandem 1W facing 1cnr, 1M behind 1W

9-:: 1W leading, 1c+1cnrs 1/2 diag. Reel3 (Rsh to 2M), finish in tandem with 1M leading facing 3M ; 1M leading, 1c+2cnrs 1/2 diag. Reel3 (Rsh to 3M), finish in tandem with 1W leading facing 2M

17-:: 1W leading, 1/2 Reel3 across with 2c (Lsh to 2M) ; 1W leading, 1/2 Reel3 across with 3c (Lsh to 3W) to 2pl (3,1,2)

25-:: All set | cross RH ; chase clw 1/2 to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (14387, '2021-10-14 03:30:02.717901+00', '2021-10-20 06:54:12.509953+00', 19776, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 R round 3cnrs (2,1,3)

9--::

  All A&R ; 1c turn 1cnrs RH into facing lines3 across, 1M between 3c, 1W between 2c

17--::

  All A&R ; 1c turn 2cnrs RH to 2plx (2,1x,3)

25--::

  Reels3 on sides {6}, 1c LSh to 1cnrs | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1952, '2012-01-22 19:29:11.606439+00', '2019-02-04 18:20:39.916387+00', 1223, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; 2c+1c ½ RHA | set to P (1,2x)

9–::

  1c+2c R&L, finish with ¾ LH turn into line across, the W in the centre:

17–::

  The Targe (1W+2W turn ¾ RH _while_{2} 1M+2M chase ¼ round cclw | 1M+2W & 1W+2M Turn LH ; repeat) finishing on sides (2,1x)

25–::

  2c facing 1c set | all set to P ; 1c lead up, cross and cast to 2pl (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (3591, '2012-07-21 11:45:20.121982+00', '2019-03-06 23:52:19.032247+00', 8250, 1, NULL, 'ace', '1–::

  1W cross down, cast down round 3M, cross down, cast up round 4W to place.

9–::

  1c lead down the middle, (2c+3c up on [11-12] ; 1c cast up round 4c (2,3,1,4) | 2c+1c petronella into the midline.

17–::

  2c+1c Reel4 on midline

25–::

  2c+1c turn RH 1¼, finishing (2,3,4,1) (4c up [25-26] ; 2c+3c & 4c+1c Circle4 L (2,3,4,1).', 3);
INSERT INTO 'dancecrib' VALUES (1964, '2012-01-22 19:29:12.323752+00', '2020-09-30 14:48:17.332908+00', 1283, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; dance between 3c and cast up to 2pl (2,1,3)

9–::

  2c+1c R&L

17–::

  1M+3c & 1W+2c Reels3 across (Lsh to 1cnr), 1c finish in the middle facing W side NHJ, 1W below 1M,

25–::

  1c dance out and cast round nearest W (1M up, 1W down) to meet in the middle ; dance out and, cast again round nearest M (1M up, 1W down) into 2pl own side.', 2);
INSERT INTO 'dancecrib' VALUES (1973, '2012-01-22 19:29:12.714348+00', '2014-04-30 23:23:44.727567+00', 1299, 1, NULL, 'ace', '1–::
  All circle6 & back.
9–::
  All set | cross RH ; set | turn RH into promhold for
17–::
  1c+2c+3c Promenade, at end 2c to 1pl and 1c casts (to 2,1,3)
25–::
  2c+1c DblFig8 (2c cast to start)
33–::
  1c+3c R&L', 2);
INSERT INTO 'dancecrib' VALUES (1971, '2012-01-22 19:29:12.626072+00', '2021-06-20 10:01:36.928581+00', 1296, 1, NULL, 'ace', '{{explanation}}

On 2nd chord, 1c change sides. In top or bottom place couples change sides on [31-32]of the next turn. This dance can be done round the room.



1–::

  1c facing 2c R&L starting up/down

9–::

  1c+2c (NHJ on sidelines) set twice to P ; turn P BH

17–::

  1c+2c RHA, LHA

25–::

  1c facing 2c NHJ set twice ; turn person opposite 1½ BH,  (TACnotes: RH and skip change may be used)', 3);
INSERT INTO 'dancecrib' VALUES (2034, '2012-01-22 19:29:16.229259+00', '2014-11-06 08:37:47.720033+00', 10693, 1, NULL, 'ace', '1–::

  1c+2c dance BtoB, face down NHJ ; dance down | set to P and face up

9–::

  1c+2c dance up | 1c cast and 2c to 1pl ; 2c+1c dance BtoB (2,1)

17–::

  2c+1c lead down {3}, and back, 2c leading | 2c cast off and 1c to 1pl, in middle for

25–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (1975, '2012-01-22 19:29:12.821302+00', '2020-05-18 16:02:09.25329+00', 1304, 1, NULL, 'ace', '1–::

  All turn person opposite RH ; all turn P LH ¾ into promhold, next to other couple (M inside), facing cclw

9–::

  Both C promenade once cclw to original places

17–::

  L-Chain (along line of dance)

25–::

  All A&R ; All advance [3] passing opposite person Rsh, retire [1] to face new couple', 2);
INSERT INTO 'dancecrib' VALUES (1966, '2012-01-22 19:29:12.413121+00', '2021-02-06 13:08:44.121306+00', 10600, 1, NULL, 'ace', '1–::

  RHA ; LHA

9–::

  All turn opposite person RH ; turn partner LH,

17–::

  Circle4 and back

25–::

  All A&R ; cross Rsh to face next couple

', 3);
INSERT INTO 'dancecrib' VALUES (14257, '2021-08-21 13:41:24.306575+00', '2021-08-21 13:45:48.023163+00', 20396, 1, 202, 'ace', '1--::

  1c & 4c set | cross RH ; cast inwards (2c & 3c steop out | Petronella turn to midline

9--::

  2c+1c & 4c+3c RHA ; 1c+4c ½ Reel4 on midline

17--::

  2c+4c & 1c+3c RHA ; 4c+1c ½ Reel4 on midline. 1c face up, 4c face down

25--::

  1c (1M leading) dance RSh round 2W to 3pl _while{4} 4c (4W leading) dance RSh round 3M to 2pl ; all turn P RH (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2029, '2012-01-22 19:29:15.86104+00', '2021-01-17 00:28:26.419666+00', 9103, 1, NULL, 'ace', '1–::

  1c cast off behind own lines (2c up) ; cast up to 2pl

9–::

  2c+1c RHA ; LHA

17–::

  1c turn RH to face 1cnr, turn 1cnr LH ; turn 2cnr RH, cross LH to (2,1,3)

25–::

  All A&R ; all turn RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1965, '2012-01-22 19:29:12.372496+00', '2023-02-17 12:35:06.695477+00', 1285, 1, NULL, 'ace', '1–::

  1c+2c A&R ; turn RH into

9–::

  1c+2c Allemande

17–::

  1c Fig8 up round 2c

25–::

  2c+1c RHA ; LHA', 3);
INSERT INTO 'dancecrib' VALUES (14157, '2021-07-20 22:44:02.055373+00', '2021-07-20 22:47:43.426148+00', 8452, 1, 202, 'ace', '1--::

  1c turn RH ½ into promhold | promenade between 3c ; cross LH and cast round 3c to 2pl, 1W facing up, 1M facing down (2,1,3)

9--::

  Reels3 on sides, 1c RSh to 4cnrs (2,1,3)

17--::

  All set | cross RH ; Circle6 R

25--::

  All set | cross LH ; Circle 6 L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14158, '2021-07-21 08:59:42.16648+00', '2021-07-21 09:01:43.933723+00', 13739, 1, 202, 'ace', '1--::

  Reels3 on sides, 1c in and down (1,2,3)

9--::

  1c set | cross down to 2plx (2c up) ; set | cross down to 3plx (3c up) (2,3,1)

17--::

  Circle6 and back (2,3,1)

25--::

  1c set | dance to top (3c down) ; cast off | all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14033, '2021-05-13 15:18:53.961495+00', '2021-05-13 15:22:31.786435+00', 5300, 1, 202, 'ace', '1--::

  1c lead down ; and up (1,2,3)

9--::

  1c+2c RHA ; LHA (1,2,3)

17--::

  1c cross RH | cast off (2c up) ; ½ Fig8 L round 4cnrs (2,1,3)

25--::

  1c+2c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14159, '2021-07-21 10:09:57.858154+00', '2021-07-21 10:09:57.858154+00', 19727, 2, 10819, 'ace', '1-4:: 1s cast, pass LS to face 1st crnr, back to back with partner
5-16:: "TickTock" (4 bar pattern, to be danced three times): center dancers change places RH with crnrs on the diagonal & set, with new center dancers (back to back) move on one crnr CLW; _while_ free crnrs 1/2 chase CLW to change places. (Positions on bar 16: 2L+3L in top places, 2M+3M in bottom places, all moved 1 plc CCLW, 1s back to back in the center, face 2nd crnr positions)
17-20:: 1s+3L+2M 1/2 reel on 2nd diagonal (to 2x 1x 3x).
21-24:: All set and XR. 
25-32:: All circle for 4 slip steps, then set turning on the spot pulling RS back to face CLW, chase (to 2 1 3).', 5);
INSERT INTO 'dancecrib' VALUES (12015, '2019-08-12 19:09:59.444427+00', '2021-04-07 12:32:52.748456+00', 19496, 1, 1645, 'ace', '1-::

  1c dance down | cast up round 3c (2c up) ; all turn BH ending in promhold

9-::

  2c+1c+3c Promenade (2,1,3)

17-::

  2c+1W & 1M+3c RHA, 1c pass RSh ; LHA

25-::

  Circle6 & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (9785, '2017-04-08 12:53:27.619889+00', '2019-10-14 22:54:46.109525+00', 15286, 1, 202, 'ace', '1--:: 

 1c+2c RHA ; ½ LHA | 2c+1c change places LH on sidelines (1x,2x,3)

9--:: 

 Parallel Reels3, 1c Lsh to 2c, ending with loops

17--:: 

 1W+2W & 1M+2M set | Petronella in tandem ; repeat (2,1,3)

25--::

 All A&R{4} ; all turn RH', 2);
INSERT INTO 'dancecrib' VALUES (8217, '2014-03-21 20:37:28.661001+00', '2014-04-30 23:23:44.925409+00', 15398, 1, NULL, 'ace', '{{explanation}}
Cpl facing Cpl round the room, 1c facing cclw

1–::
  Circle4 and back
9–::
  1W+2W turn RH ; 1M+2M Turn LH, finish with P in promhold, cpl facing cpl
17–::
  Pass other cpl Rsh | pass next cpl Lsh ; repeat Rsh | and Lsh and change to NHJ
25–::
  Pass next couple (2c makes arch, 1c under) | repeat (1c arch) ; repeat (2c arch) | repeat (1c arch) and face next cpl.', 2);
INSERT INTO 'dancecrib' VALUES (9976, '2017-06-23 15:18:35.191479+00', '2017-06-23 21:11:34.226475+00', 17788, 2, 116, 'ace', '1-8:: 1C set, cross RH and cast off 2 places (2C + 3C step up on bars 5 + 6), then 2C + 3C + 1C set, 2C + 3C advancing on 2nd setting step and joining promenade hold with partners, 2C facing up, 3C facing down (finishing order: 2, 3, 1x)

9-16:: 2C + 1C dance slow centrosymmetrical allemandes (phrasing like 2C in a 2 couple allemande) while 3C dance la baratte and set (finishing order: 2, 3x, 1x)

17-24:: 2C set, cross RH and cast off 2 places (3C + 1C step up on bars 21 + 22), then 3C + 1C + 2C set (finishing order: 3x, 1x, 2x)

25-32:: 3C + 1C + 2C dance clockwise halfway round, then 1C + 3C, facing each other on the sides, turn BH one and a half times (finishing order: 2, 3, 1)', 5);
INSERT INTO 'dancecrib' VALUES (5260, '2013-08-21 08:31:03.676281+00', '2023-02-09 11:29:52.846795+00', 2158, 3, NULL, 'ace', '1-8::

    1s 1/2 turn RH into prom hold & dance down, cross LH & cast up

    behind 3s on own sides to 2nd place

9-16::

    1L & 2M+3M set advancing to form triangle, 1L & 2M+3M retire as 1M &

    2L+3L set advancing to form triangle, repeat this Fig (bars 9-12)

17-24::

    1s in prom hold dance 1/2 LSh reel of 3 with 2L+3L (in centre of

    set), 2L & 3L pick up each others partner & complete reel

25-32::

    1s (prom hold) continue with 1/2 reel of 3 with 2M+3M (Men leave

    Ladies on Men''s side in 1st & 3rd place) all end opp side 2 1 3, all

    set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (1976, '2012-01-22 19:29:12.865047+00', '2019-06-01 23:26:12.415402+00', 8569, 1, NULL, 'ace', '1–::

  1M+2c ½Reel3 across (Lsh to 2W) ; 1W+2c & 1M+3c ½ Rsh Reel3 across

9–::

  1W+3c ½ Lsh Reel3 across _while_{4} 1M casts up W side to above 1pl and 1W finishes below 3pl ; 1M+1W cross to M side, cast in (2c up) between 2M and 3M, and finish BtoB facing 1Mup / 1Wdown ready for

17–::

  2c+1c+3c DTr up / dn, at end petronella to (2,1,3)

25–::

  2c+1c+3c circle6 and back

33–::

  1c dance between 3c and cast up ; dance between 2c and cast off to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1970, '2012-01-22 19:29:12.615071+00', '2019-07-24 11:55:46.42898+00', 1295, 1, NULL, 'ace', '1–::

  1c cast behind own lines and back

9–::

  1c+2c A&R{1+1} twice ; All Turn P RH ½ and cast R to (1x,2x)

17–::

  All set | Circle4 L | Turn P RH ½ for

25–::

  1c+2c Allemande (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (1977, '2012-01-22 19:29:12.948374+00', '2019-12-12 08:38:36.540411+00', 1315, 1, NULL, 'ace', '1–::

  1c+2c Poussette

9–::

  1W+2W dance between P, split and dance round P to places ; All turn P EH 1½ (1c use RH, 2c LH) (1x,2x)

17–::

  1M+2M dance between P, split and dance round P to places ; All turn P EH 1½, finish 1c facing 2c, NHJ  

25–::

  1c set to 2c | Circle4 L ½ ; turn P BH 1½ (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (1981, '2012-01-22 19:29:13.221398+00', '2014-04-30 23:23:44.95566+00', 10365, 1, NULL, 'ace', '1–::
  Circle6 and back
9–::
  Reel3 with persons on right and right opposite
17–::
  Same 3 people 3 RHA ; and LHA, to places
25–::
  A&R and pass through Rsh to new set of 3 people.', 2);
INSERT INTO 'dancecrib' VALUES (1984, '2012-01-22 19:29:13.537119+00', '2014-04-30 23:23:45.017276+00', 11374, 1, NULL, 'ace', '1–::
  1M+2W turn RH 1½ _while_{4} partners chase round them cclw ½ (to 2x,1x,3) ; 1c ½ Fig8 down round 3c (2x,1,3)
9–::
  1W+3M turn LH 1½ _while_{4} partners chase round them clw ½ (to 2x,3x,1x) ; 3c ½ Fig8 up round 2c (2x,3,1x)
17–::
  All set | 3c petronella into facing lines across (3W with 2c, 3M with 1c) ; S&Link3 (2,3,1), 3c dancing into the middle for
25–::
  Teapots R (2c+3W & 3M+1c RHA) ; Teapots L  (2c+3M & 3W+1c LHA) (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (1985, '2012-01-22 19:29:13.595326+00', '2014-04-30 23:23:45.032086+00', 1348, 1, NULL, 'ace', '1–::
  1c cast off behind own lines ; turn inwards and dance up to places
9–::
  1c Fig8 round 2c
17–::
  1c lead down the middle and up
25–::
  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (2436, '2012-01-22 19:29:38.687686+00', '2020-01-09 11:08:56.00833+00', 2947, 1, NULL, 'ace', '1–::

  1c+2c+3c set | cross RH ; chase ½ clw (3,2,1)

9–::

  1c+2c+3c set | cross LH ; chase ½ cclw (1,2,3)

17–::

  1M & 3W change places RH | 3M+1W repeat ; 2c cross RH | all set (3x,2x,1x)

25–::

  Modified Snowball chain from bottom:   

1c cross LH {1} as 3c+2c start dancing down, 2c+1c pass RH on the sides {1} |   

2c cross LH  _as_ 3c+1c pass LH on the sides (1,3x,2) ;   

1c turn RH moving down {4} _while{4}_ 3c+2c pass RH on the sides | 2c dance to top _as_ 3c cross LH  (2,1,3)







', 3);
INSERT INTO 'dancecrib' VALUES (1986, '2012-01-22 19:29:13.644564+00', '2020-03-27 19:16:01.947816+00', 8490, 1, NULL, 'ace', '1–::

  1c+2c cross (no hands) into ½ RHA ; flowing into 2c turn RH (to 1pl own side) _while_{4} 1c turn RH 1½ to face 1cnrs

9–::

  SetH&G , finish facing 3cnrs

17–::

  ½Reel4 on 1diag, pass Rsh, ½Reel4 on 2diag

25–::

  Diagonal R&L (1c start to the right)', 2);
INSERT INTO 'dancecrib' VALUES (1983, '2012-01-22 19:29:13.372834+00', '2021-03-27 21:38:36.82841+00', 1331, 1, NULL, 'ace', '1–::

  Reels4 on the side

9–::

  1c+2c & 3c+4c RHA ; LHA

17–::

  1c set, cast off ; 1c+3c circle4 to the left

25–::

  1c set, lead up to 1pl ; cast off to 4pl (3c+4c up on 31-32)

33–::

  2c+3c & 4c+1c R&L

', 2);
INSERT INTO 'dancecrib' VALUES (13105, '2020-08-12 22:29:33.93731+00', '2021-04-07 17:04:33.544837+00', 3805, 1, 202, 'ace', '1--::

  Circle8 and back. Only 1M and 2W release hands

9--::

  All chase cclw, 2W leading under 1c''s Arch

17--::

  1c+3c R&L

25--::

  2c+4c R&L

33-48::

  Gr-Chain, 2 bars/hand



*Note:*  

Repeat three times with 2nd, 3rd then 4th couple.', 4);
INSERT INTO 'dancecrib' VALUES (14255, '2021-08-20 15:55:04.995385+00', '2021-08-20 15:58:39.133554+00', 20449, 1, 1645, 'ace', '1-::

  1c turn BH | dance down below 3c ; cast up (2c up) | turn LH to centre line, W above M

9-::

  2c+1W & 1M+3c circle3 to L & 1c twirl to face P, 2c/3c face down/up NHJ ; all set | 1c petronella to opp side _while_ 2c & 3c turn inwards & cast to sides (2,1x,3)

17-::

  All set | 1c "gypsy" turn RSh ; 1M followed by 1W cast off, dance across & face up (3c up)

25-::

  Modified Grand Chain, 2c start by crossing. On [3-4] all &frac12; turn RH & twirl away then continue the chain as usual (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (14314, '2021-09-15 21:03:17.231014+00', '2021-09-16 09:29:02.731571+00', 20486, 1, 202, 'ace', '1--::

  All W Circle4 and back _while{8}_ all M chase clw ¾

9--::

  All M Circle4 and back _while{8}_ all W chase clw ¾ (2,3,4,1)

17--::

  3c+1c turn opposite person RH ½, face that person | cast R to exchanged places ; 1c & 3c S&Link (2,1,4,3)

25--::

  2c+4c repeat [17-24] (4,1,2,3)', 5);
INSERT INTO 'dancecrib' VALUES (1982, '2012-01-22 19:29:13.317303+00', '2016-03-06 22:17:28.81798+00', 1330, 1, NULL, 'ace', '1-10::

  1c cast off one | full Fig8 around 2c & face 1cnrs (2c up [9-10]

11-20::

  1c+1cnr turn RH ½ | 1c dance ½ way clw round the set _while{4}_ 1cnr turn LH 1½ | 1c+1cnr turn RH ½ | 1c turn LH ¾ to face 2cnrs. (Corners'' Chain)

21-30::

  1c & 2cnrs repeat 11-20. 1c face 3cnr position.

31-40::

  1c ½Reel4 with 1cnrs & pass Lsh to face 4cnr pos ; 1c ½Reel4 with 2cnrs | 1c turn LH to 2pl, facing out to repeat (2,1,3)



*After 2nd turn the old 1c casts to 4pl on the new [1-2]*', 4);
INSERT INTO 'dancecrib' VALUES (3641, '2012-08-21 17:20:44.0017+00', '2014-09-24 22:27:23.453275+00', 13405, 1, NULL, 'ace', '1–::

  1c+3c long cast (touch hands, heart shape) (2c+4c up); dance NHJ between 3c/5c and cast up into the centre facing W''s 4cnr, M behind W

9–::

  1c+3c Rsh ½ Lead-change reel3 on 2diag., finish NHJ (M on L) facing W''s 1cnr ; set and turn inwards to face M''s 1cnr | set and face M''s 4cnr, W behind M

17–::

  1c+3c Rsh ½ Lead-change reel3 on 2diag (the same), finish NHJ (1W on L) facing M''s 1cnr ; set and turn inwards to face W''s 1cnr | set and face up NHJ on own side (2,1,4,3,5)

25–::

  1c with 4c following dance up and cast round 2c _while_{4} 3c with 5c do the same round (empty) 3pl  (2,4,1,5,3) ; all turn P BH.', 3);
INSERT INTO 'dancecrib' VALUES (1794, '2012-01-22 19:29:02.656755+00', '2014-04-30 23:23:41.072192+00', 8978, 1, NULL, 'ace', '1–::
  1M, 2M+3M following, cast behind W line, 1M dancing in front of 2W to let 2M+3M overtake, cast up on M side (to 2M,3M,1M,4M)
9–::
  The W repeat the figure (2,3,1,4)
17–::
  1c cast off into Fig8{6} round 4c | 1c+4c change place EH (2,3,4,1)
25–::
  Circle8 and back.', 3);
INSERT INTO 'dancecrib' VALUES (2026, '2012-01-22 19:29:15.666312+00', '2014-04-30 23:23:45.97233+00', 1478, 1, NULL, 'ace', '1–::
  1c+2c RHA ; LHA
9–::
  1c lead down the middle and up
17-28::
  1c casts off behind own lines, the other couples following {6} and lead up {6}, 1c finish facing down, 2c+3c+4c forming arches
29-32::
  1c dance down, the others step back on [32] (to 2,3,4,1)

{{explanation}}
(An unofficial variant is for 3c+4c to also dance RHA, LHA on [1-8]', 3);
INSERT INTO 'dancecrib' VALUES (9460, '2016-11-04 23:12:37.956832+00', '2016-11-04 23:12:37.956832+00', 8314, 2, NULL, 'ace', '1-4::

  HALF FIGURE OF 8: 1st couple dance a half figure of 8 around 2nd couple; 

5-8::

  TURN: 1st man turns 2nd woman left hand AS 1st woman turns 2nd man right hand, once round ending with 1st couple in promenade hold facing down between 2nd couple; 

9-16::

  PROMENADE REEL OF 3: 1st couple dance a promenade reel of 3 with 2nd couple starting by passing right shoulder with 2nd man (2nd couple dance half reel of 3, then on bars 13-16, they turn once around with right hands to end in the middle in promenade hold facing down) (1st couple end behind 2nd couple); 

17-24::

  DOWN MIDDLE AND UP: 2nd couple followed by 1st couples dance down middle, on bar 20 drop left hands, raise right hands for the women to dance under the arch as men dance below partner to lead back up on own side to original places; 

25-32::

  ROULETTE: 1st and 2nd couples dance into centre with petronella turn (2 bars), turn partner halfway round with both hands opening out with 1st couple facing woman''s side and 2nd couple facing men''s side (2 bars), 1st woman and 2nd man join right hands and start to dance a double wheel (1 bar), then dropping partner''s hands, 1st man and 2nd woman dance round outside to progressed places AS 1st women and 2nd man turn right hands just over once round to progressed places. 



Repeat having passed a couple. 



(Dance Crib compiled by the devisers, Maggie and Duncan Keppie) 

', 5);
INSERT INTO 'dancecrib' VALUES (1997, '2012-01-22 19:29:14.175791+00', '2017-04-24 00:15:11.738826+00', 1382, 1, NULL, 'ace', '1–::

  1c+2c petronella to midline | set ; turn RH ¾ into 1c+2c ½ RHA, 2W faces out (2,1,3)

9-12::

  2c+3c chase ½ clw (3x,1,2x) ;

13-16::

  1c turn LH & 2c+3c turn RH, 1c joining NH on the R _while_ dancing in and out together

17-20::

  Repeat 13-16 with the other hands, 1c finish facing out keeping NHJ on the L ;

21-24::

  3c+2c chase ½ clw _while_ 1c set, helping the dancer on the L to cast | 1c set to P (small steps)

25–::

  2c+1c+3c set | circle6 L {3} and all dance into centre {4} | swivel R and spiral out clw to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3757, '2013-06-08 21:03:52.159026+00', '2014-04-30 23:23:45.264772+00', 14610, 1, NULL, 'ace', '1–::
  1c cross | cast (2c up) ; ½ Fig8 round 2c (2,1,3)
9–::
  2c+1c+3c The Knot , at end 1c turn LH to midline, W above M
17–::
  3C+1W & 1M+2c RHA ; (snake) break circle with 1c leading, going down opposite side, and crossing to finish (2,1,3)
25–::
  1c cross RH | cast (3c up) ; turn RH 1½ (or birl) (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (1992, '2012-01-22 19:29:13.931911+00', '2014-04-30 23:23:45.348061+00', 1375, 1, NULL, 'ace', '1–::
  1c cross RH, cast off (2c up) ; lead between 3c and cast up to face 1cnr
9–::
  SetH&G , finishing in the middle facing opposite side
17–::
  1c fig8 round corners, start Lsh to 2cnr, finish facing 2cnr _while_{8} 2c+3c R&L
25–::
  Reels3{6} with corners (Rsh to 2cnr) | 1c cross RH to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8450, '2014-11-18 17:37:00.692595+00', '2016-04-18 23:09:08.1925+00', 10477, 2, 160, 'ace', '1–::

 Chase - 1L followed by 1M - cast behind 2L, cross up btwn 2C ; cast behind 2M and cross to 2pl own side. (2C up on 7-8) (2,1)

9–::

 2M1C half Reel3 across - 2M1L pass Lsh to begin ; 2L1C half Reel3 across - 2L1L pass Rsh to begin. (2x, 1)

17–::

 Chase - 2M followed by 2L cast behind 1L, cross up btwn 1C ; cast behind 1M , cross to end in 2pl opp. sides. (1, 2x)

25–::

 1C2C dance LH Across once round ; 1C cast as 2C cross up, 1C set.', 0);
INSERT INTO 'dancecrib' VALUES (2775, '2012-01-22 19:29:56.905598+00', '2021-05-08 20:59:38.894349+00', 4318, 1, NULL, 'ace', '1–::

  1c (NHJ) set twice to 2W ; repeat with 2M

9–::

  1c lead down the middle and up, staying in the middle

17–::

  1c cross and cast on opp. side (2c up), cross LH, cast off round 3c and lead up to face 1cnrs

25–::

  1c set to and turn corners

33–::

  Reels3{6} on the sides (Lsh to 1cnrs), 1c cross RH to 2pl', 2);
INSERT INTO 'dancecrib' VALUES (13941, '2021-04-08 08:39:46.485401+00', '2021-04-13 09:37:39.635581+00', 20297, 1, 202, 'ace', '1--::
  1c & 4c set | 1c (1W leading) & 4c (4M leading) chase clw ½ to exchanged places (to 4x,2,3,1x) | 1W cast up _as_ 1M dance up the middle to 3plx (3c down) _while{2}_ 4M cast off _as_ 4W dance down the middle to 2plx (2c up) (2,4x,1x,3)
9--::
  4c+1c *Mixed L-Chain* : same as L-Chain except that 4M+1W change places RH twice (2,4x,1x,3)
17--::
  Reels4 on sides (2,4x,1x,3)
25--::
  2c+4c & 1c+3c RHA ; 4c+1c LHA (2,4x,1x,3)', 4);
INSERT INTO 'dancecrib' VALUES (1791, '2012-01-22 19:29:02.513016+00', '2021-07-01 09:18:18.524113+00', 629, 1, NULL, 'ace', '1–::

  1c+2c circle4 L ; set | 1c cast off and face in _while_{2} 2c (NHJ) dance to top and face out (2,1,3)

9–::

  2c+1c+3c mirror Reels3 (take NH when possible), corners end with loop and 1c faces 1cnrs

17–::

  1c SetH&G , finishing BtoB in centre, 1M facing up, 1W down

25–::

  2c+1M & 1W+3c RHA (2,1x,3) ; All spin turn (R. elbow hold), 1c 1½ and 2c+3c twice', 2);
INSERT INTO 'dancecrib' VALUES (14318, '2021-09-16 07:26:21.547027+00', '2021-09-16 11:27:27.825549+00', 20487, 1, 202, 'ace', '1--::
  1c dance down (2c up) ; turn BH | dance up to 2pl centre. 2c & 3c step in on [8] (2,1,3)
9--::
  3C Allemande (3,1,2)
17--::
  3C S&Link twice (2x,1x,3x)
25--::
  ½ Reels3 across, 1c RSh to 4cnrs[pos] ; all turn BH (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (2013, '2012-01-22 19:29:14.972153+00', '2014-04-30 23:23:45.759668+00', 12023, 1, NULL, 'ace', '1–::
  1M+3W pass Rsh, face, and cast to exchanged places ; chase clw ½ way round the set to own places _while_{8} 1W+3M cast clw and chase ½ way round the set ; pass Rsh, face, and cast to own places (1,2,3)
9–::
  2c Set Adv | Turn RH and face down ; Dance between 3c and cast up to (1,2,3).
17–::
  Mirror Reels3 on own sides (2c starts in and up), 1c ends facing out (1,2,3)
25–::
  1c+2c ½ turn EH on side | 1c turn RH and face down ; Dance between 3c and cast up to (2,1,3).

{{explanation}}
Notes: On the 2nd turn, 4c steps up on [31-32] as 1c loops into 4pl.  
»Pass, face and cast away«: After passing face each other, cast R and dance out to exchanged places.', 3);
INSERT INTO 'dancecrib' VALUES (5231, '2013-08-21 08:31:02.976311+00', '2023-02-09 11:38:56.327022+00', 2103, 3, NULL, 'ace', '1-8::

    1s set, turn RH, cast 1 place _while_ 2s lead up, 1s+3s dance RH

    across 1/2 way

9-16::

    2s set, turn RH, cast 1 place _while_ 3s lead up, 2s+1s dance RH

    across 1/2 way

17-24::

    3M+2L change places RH, 3L+2M change places RH, 1s 1/2 turn LH to

    face 1st corners & turn corners RH into prom hold facing in

25-32::

    1s with 1st corner persons dance LSh round 3rd corners into centre &

    dance RH across to end on own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9464, '2016-11-08 01:07:06.612471+00', '2016-11-08 01:11:24.377721+00', 1729, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; 1c set and start turning | cast Lsh round 4cnr to face 1cnr

9--::

  1c+1cnrs diag. Reel4{6} | 1M (above) sets to 1W (below) and face 2cnr

17--::

  1c+2cnrs Lsh diag. Reel4{6}, 1c start Lsh to 2cnr | 1W (above) sets to 1M (below), and finish facing 1cnr

25--::

  1c+1cnrs turn BH, 1c finish in 2plx | 1c set and face 2cnr ; 1c+2cnrs turn BH, 1c finish between end cpls | 1c turn RH to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1998, '2012-01-22 19:29:14.21685+00', '2017-07-13 02:40:48.228468+00', 1388, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c cross Rsh (W making arches) | cross back Rsh (M making arches) ; 1c & 4c lead out of ends & back _while_{4} 2c+3c RHA and change places, 3c making arch (1,3,2,4).

9–::

  1c+3c & 2c+4c circle4 R, at end couples change places (3c & 4c making arches) ; 3c+2c lead out of ends & back as 1c+4c RHA and change places, 4c making arch (3,4,1,2).

17–::

  All ½ G-Chain (start along the sides) ; all A{1}&R{1} and turn BH (2x,1x,4x,3x)

25–::

  2c+1c & 4c+3c circle4 L ½ | 1c cast off one (2c up) ; cross RH & cast off one (3c up) | cross LH & cast (4c up) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10036, '2017-08-02 14:01:00.862424+00', '2017-08-27 04:23:58.719865+00', 17904, 1, 202, 'ace', '1--::

 1M+2W & 3M+4W set | cross RH ; 1W+2M & 3W+4M set | cross LH (2x,1x,4x,3x)

9--::

 All set | all A&R | 2c & 1c turn RH ½ into allemande hold facing up _while{2}_ 4c & 3c turn RH into allemande hold facing down

17--::

 2c+1c & 4c+3c Allemande, on [22] *3c+4c* drop hands and pass P Rsh (1,2,3,4)

25--::

 1c ½Fig8 round 2c ; 1c+2c change places EH | 1c+3c change places EH (2,3,1x,4)

33--::

 1c ½Fig8 round 4c ; 1c dance to 4pl with a loop (4c up on [37-38]) _while{4}_ 2c dance round 3c to 1pl (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (8651, '2015-02-13 12:48:25.871971+00', '2023-02-04 01:23:10.457565+00', 7065, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast, cross to 2nd place own sides (2s step up
    5-6)
9-16::
    1s+2s dance circle 4H round to Left, 1s+2s dance LH across back to
    places
17-24::
    1s+2s+3s set, cross RH, set, cross RH back to places
25-32::
    1s+2s+3s dance 3/4 circle 6H round to left (4 bars), drop hands,
    2s+3s dance on to 2nd/3rd places own sides _while_ 1s turn Left
    about, dance anticlockwise round them to 2nd place opp. sides &
    cross RH to own sides  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12762, '2020-04-13 16:05:44.230438+00', '2020-04-15 09:21:56.475202+00', 19943, 1, 1645, 'ace', '1-::
  1c+2W RHA, 1M ends in 2pl (2M up on [3-4]) ; 1c+2M LHA, 1W ends in 2pl facing out (2W up on [7-8])
9-::
  Reel3 on sides, 1c start LSh to 2c, corners add loops, 1c end NHJ facing 2W, 1M with 1W on his R
17-::
  1c set to 2W, turn in | set to 3M ; set to 3W, turn in | set to 2M & face up
25-::
  2M+1M+3M LHA & 2W+1W+3W RHA on sides ; 1c dance up | cast off (2,1,3)
', 5);
INSERT INTO 'dancecrib' VALUES (3676, '2013-01-08 13:39:36.578073+00', '2014-04-30 23:23:45.591781+00', 10463, 1, NULL, 'ace', '1–::
  1W+1M following cast off 2 (2c+3c up) and cross  ; 3c+1c RHA (1W face out)
9–::
  1W+1M following cast up to1pl (2c+3c down) ; 1c+2c RHA (1,2,3)
17–::
  Parallel Reels3 on own side, 1c Rsh to 2c (1,2,3)
25–::
  1W with 1M following cast off 1, cross up between 2c, cast Lsh round 2M (2c up) to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2005, '2012-01-22 19:29:14.586417+00', '2014-04-30 23:23:45.606961+00', 1410, 1, NULL, 'ace', '1–::
  1c+2c Poussette
9–::
  1c+2c S&Link ; Circle4 L (2,1,3)
17–::
  Reels3 on own side (1c Rsh to 2c), at end 2W loops R into
25–::
  2c+1c RHA (1M face out for) ; 1c+3c LHA', 3);
INSERT INTO 'dancecrib' VALUES (2280, '2012-01-22 19:29:29.504974+00', '2017-08-28 14:17:03.366946+00', 2344, 1, NULL, 'ace', '1--::

  1c set | cross down RH between 2c (2c up) ; cast Rsh round 1cnr | turn ¾ RH and face out between corners

9--::

  2c+3c R&L (no polite turns) _while{8}_ 1c Fig8 round 1cnr+4cnr positions, at end pass Lsh to face 1cnrs

17--::

  1c ½ diagonal Reel4 with 1cnrs, pass Rsh, repeat with 2cnrs, finish ready for

25--::

  1M+3c (above) & 1W+2c (below) RHA to (3x,1x,2x) ; all chase clw to (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (2769, '2012-01-22 19:29:56.673854+00', '2021-05-08 21:26:26.246745+00', 4300, 1, NULL, 'ace', '1–::

  1c ½ Fig8 round 2c who set twice meanwhile pivoting (W L, M R) to face person dancing round them ; All set and cross RH (1,2x)

9–::

  »The Swirl«: 1c+2c turn P RH to face other C in allemande hold | change places Lsh ; LHA, to (2x,1)

17–::

  All set to P | cross RH ; RHA (2,1x)

25–::

  1c ½ Fig8 round 2c ; turn RH (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (12488, '2020-01-10 00:12:09.883304+00', '2020-01-10 00:15:46.966698+00', 19730, 1, 202, 'ace', '1--::

  1W+2M set | cross RH ; 1M+2W repeat (2x,1x,3)

9--::

  1c ½ Fig8 up round 2c ; 1c lead down {2}, lead up {2} and face 1cnrs. On [13-14] 2c cross LH (2,*1*,3)

17--::

  Corner Chain on 1diag

25--::

  Corner Chain on 2diag

33--::

  Reels3 on sides, 1c LSh to 4cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12759, '2020-04-12 22:59:27.927192+00', '2020-04-12 23:14:51.024642+00', 19939, 1, 202, 'ace', '1--::
  1c set | 1W (1M following) casts round 3W, 1W dances up round 3M and 1M dances up the middle (2c up on [7-8]) (2,1x,3)
9--::
  M-Chain into line4 across, ending the 2nd RH turn with M BtoB in centre
17--::
  Reel4 across. On [23-24] 1M+2M pass RSh to sides (2,1x,3)
25--::
  1c set | 1M (1W following) casts round 3W, 1M dances up round 3M and 1W dances up the middle (2,1,3) ', 2);
INSERT INTO 'dancecrib' VALUES (2001, '2012-01-22 19:29:14.390783+00', '2021-03-06 22:23:02.715698+00', 9003, 1, NULL, 'ace', '1–::

  1c cross down (no hands) to 2plx facing out and R _while_{2} 2c dance up and face in | Reels3{6} on the sides (Rsh to 1cnr), 1c finish BtB facing 1cnr

9–::

  1c set to and turn 1cnr BH ¾ to finish between end couples, retaining NH with 1cnr ; All cross up/dn, 3M & 2W dancing under the arch they meet | 1c turn 1cnr person BH ¾ to finish (3,1x,2)

17–::

  Teapots R (1M up, 1W down) to sidelines ; 1c ½ Fig8 L (1W up, 1M down) to 2pl. On [24] 2c+3c step in for

25–::

  3c+1c+2c Allemande. on [31-32] 1c casts to 3pl and 3c dance to 2pl (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2673, '2012-01-22 19:29:52.547748+00', '2014-04-30 23:23:59.356982+00', 3802, 1, NULL, 'ace', '1–::
  1c set | cast off two (2c+3c up) ; 1c set | cast up two (2c+3c down)
9–::
  1c lead down the middle and up (1,2,3)
17–::
  1c+2c Allemande, to finish 1c facing 1cnrs
25–::
  Turn CPCP to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2000, '2012-01-22 19:29:14.320985+00', '2023-02-17 12:08:02.52478+00', 1405, 1, NULL, 'ace', '1–::

  1c cross RH, cast (2c up) ; cross LH, cast 1W up, 1M down and dance in to meet facing 2M

9–::

  1c in promhold dance half diagonal Rsh Reel3 with 2M+3W ; repeat with 3M+2W, 1c finish in middle facing women'' side

17–::

  1c lead out on W side and cross, casting round 2W and 3W positions (1M down, 1W up) to meet in middle ; 1c turn RH 1¼ times _while_{4} 3c+2c ½ R&L around them

25–::

  1c lead up between top couple and cast off ; 2c+1c+3c Turn RH', 2);
INSERT INTO 'dancecrib' VALUES (14929, '2022-06-28 22:19:01.915232+00', '2022-06-28 22:21:59.429275+00', 2854, 1, 202, 'ace', '1--::

  1c Fig8 down round 2c (1,2,3)

9--::

  All set | cross RH ; set | turn P RH ½ into promhold 

17--::

  3C Promenade (1,2,3)

25--::

  1c+2c RHA{3}, LHA{3} | 1c cast to 2pl, 2c dance to top (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3702, '2013-02-07 03:44:42.652831+00', '2016-04-19 12:59:53.304244+00', 7662, 1, NULL, 'ace', '1–::

  1c set | dance down ; 1W+2W+3W LHA _while_{4} 1M+2M+3M RHA, finish (1,2,3)

9–::

  1c dance down and cast up behind 2c, dance below 3c and cast up to 2pl (2c up) (2,1,3)

17–::

  All turn R ½ and twirl to (2x,1x,3x) ; repeat (2,1,3)

25–::

  1c+3c turn RH ¾ to midline | ½ Reel4 on midline | turn RH ¾ to (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2014, '2012-01-22 19:29:15.020806+00', '2014-04-30 23:23:45.775029+00', 14395, 1, NULL, 'ace', '1–::
  1c lead down the middle (2c up) ; and up to 2pl RHJ
9–::
  1c turn RH to 2pl and face 3cnr | All W, 3W leading cast up and down along 2diag _while_{6} all M, 2M leading, cast off and up 2diag, passing the others Rsh, finishing on ends and middle of 2diag as two facing diagonal lines
17–::
  All set to P | turn P BH ; Set to P | Turn P BH to (2,1,3)
25–::
  2c+1c Poussette (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2015, '2012-01-22 19:29:15.062422+00', '2014-04-30 23:23:45.790108+00', 10771, 1, NULL, 'ace', '1–::
  1c cross RH | cast (2c up) ; 1c ½ Fig8 to R (W down, M up) (2,1,3)
9–::
  Opposing ½ Reels3 on sides (1c starts in & R, i.e. Rsh to 4cnr), 2c+3c finish with loop ; opposing ½ Reels3 across (1c Lsh to 1cnr position) (3x,1x,2x)
17–::
  S&Link3 ; repeat (2,1,3)
25–::
  All circle6 and back.', 3);
INSERT INTO 'dancecrib' VALUES (9466, '2016-11-08 14:09:55.82455+00', '2016-11-08 14:09:55.82455+00', 17404, 1, NULL, 'ace', '1--::

  1c+2c+3c Inveran Reels (1,2,3)

9--::

  1c cross RH | cast off to face 2cnr (2c up) ; 1c+2cnrs Pass & Gypsy Turn (cnrs dance Rsh round each other, no hands)

17--::

  1c Rsh Gypsy Turn to face 1cnrs | 1c+1cnrs Pass & Gypsy Turn | 1c turn RH into promhold facing 1M place

25--::

  2M+1c+3M ½ Rsh Reel3 ; 2W+1c+3W ½ Reel3 (Rsh to 3W), all finish facing up RHJ (3,1,2) 

33--::

  3C Allemande (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2002, '2012-01-22 19:29:14.445366+00', '2019-03-07 22:58:06.192587+00', 9157, 1, NULL, 'ace', '1-16::

  *Fugue*:  1M set | cast (2M up) ; set | petronella to between 3c ;; set with 3c | advance with 3c ; retire with 3c | advance alone _while{16}_ 1W waits {2} and then repeats 1M’s [1-14], dancing with 2c, on [16] 1W pivots R to give Rsh to 2W 

17–::

  1W with 1M following Reel3 across with 2c, finish (2,1,3)

25–::

  Parallel Reels3 on own sides, 1c Rsh to 3c (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14699, '2022-03-13 20:01:43.807348+00', '2022-03-13 20:08:52.928657+00', 6545, 1, 202, 'ace', '1--::

  1W & 4M ½ Reels3 with nearest couples ; pick-up P on Left in promhold and continue Reels3. 1c in 1W place face Mside _as_ 4c in 4M place face Wside

9--::

  1c & 4c lead to centre facing each other | set ; RHA and face out

17--::

  1c & 4c lead out and cast inwards (to 2,1x,4x,3) ; 1c & 4c turn RH on sides and face in

25--::

  1c+4c set | ½ R&L | set (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3873, '2013-08-07 21:35:44.673874+00', '2014-04-30 23:23:45.882659+00', 13364, 1, NULL, 'ace', '1–::
  1c turn RH 1½ and face out ; cast (2c up) | turn LH ¾
9–::
  2c+1W & 1M+3c RHA ; ½ Reel4 wih 1cnrs, pass Lsh into
17–::
  1M+ the W above & 1W+the M below RHA, and face 2cnr ; ½ Reel4 with 2cnrs (3x,1x,2x)
25–::
  1c turn LH _while_{2} 2c+3c cross RH | 1c dance out ends (M up, W down) and cast L _while_{4} 2c+3c set and change places LH on side | All set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3438, '2012-01-22 19:30:25.521694+00', '2021-01-11 23:03:59.510562+00', 12637, 1, NULL, 'ace', '1–::

  1c cross down (2c up) | set as in DTr ; 1c cast R round 1cnr to face 1cnr on diagonal

9–::

  Reel4 with 1cnrs, at end 1c make fast LH turn to face 2cnr

17–::

  Reel4 with 2cnrs, finish (2,1,3).

25–::

  All Circle L {3}, put R foot ahead and swivel L ; all chase cclw. to places in Skip-change. (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13372, '2020-11-12 00:57:42.546232+00', '2020-11-12 01:05:45.539421+00', 19795, 1, 202, 'ace', '1--::
  1c+2c ½ DblFig8, 1c crossing down. 2c face out ; 1c+2c turn EH on sides 1½. 1c face out (2,1,3)
9--::
  1c+3c ½ DblFig8, 1c casting. 1c face out ; 1c+3c turn EH on sides 1½. 3c face out (2,3,1)
17--::
  1c dance up through 2c, cast off to 2plcentre, dance down through 3pl[pos] and cast up to 2plcentre, BtoB facing own sides _while{8}_ 3c follow 1c then loop to 3pl into DTr position, all dancing NHJ when possible (2,1,3)
25--::
  »Inverted DTr« [: all set as in DTr | all set advancing and right about into inverted DTr (2c+3c are BtoB) ; all set as in DTr | all set to finish on sides, 1c pivoting R to 2pl] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13292, '2020-10-30 20:39:55.709702+00', '2020-10-30 20:50:39.509444+00', 14218, 1, 1645, 'ace', '1-::
  1c+2c+3c dance down (3c leading) & back (1c leading), 2c to top, 1c casting off (2,1,3)
9-::
  1c cross up _while{2}_ 2c dance down sides | 1c+2c change pl EH (2,1x,3) ;
  1c cross down _while{2}_ 3c dance up sides | 3c+1c change pl EH (2,1,3)
17-::
  All A&R {1+1} | 1c advance, quickly turn BH & retire to opp side (2,1x,3) ;
  repeat [17-20] but 1c end facing down NHJ
25-::
  Mirror Reels3 on own sides, 1c starting in & down (2,1,3)
::
  *On the last bar of their 2nd repeat, 1c change pl EH with 4c to end in 4pl*

*Note: this crib follows the published instructions.*
*But in the video, for bars 17-20 1c advance{1} & dance down round 3c (or up round 2c in 21-24) back to 2pl own side.*
', 2);
INSERT INTO 'dancecrib' VALUES (14160, '2021-07-21 10:11:13.211688+00', '2021-07-21 10:11:13.211688+00', 19546, 2, 10819, 'ace', '1-4:: 1s+3s set, then 1/2 RA, _while_ 2s XR and cast to their right to end between cpls (2L facing down, 2M between facing up)
5-8:: Half circle to the left
9-12:: From lines across, set & link for three to sidelines
13-16:: All chase halfway round clw
17-24:: 2s TR 1/2, stay facing one another in the middle. Both set, with 2M turning on the spot to face ladies‘ side, 2L firmly putting fists on her hips while setting. 2M leading a chase around his 1st crnr pos, 2s to end on own side in 3rd place (cpl in 3rd plc step up on 23+24).
25-28:: 2L+3M XR to change places and set, _while_ 3L+2M chase half way round the set clw _while_ 1s set and cross right hand
29-32:: Half circle to the left (3 1 2)

On bars 1, 9 and 25, everyone shouts „six“.
On bars 5, 13 and 29, everyone shouts „oh“.
On bars 19, 19 1/2 and 20, the corners stomp 3x with the right foot and hands in their hips, shouting „Walk the dog“.', 5);
INSERT INTO 'dancecrib' VALUES (2073, '2012-01-22 19:29:18.350092+00', '2021-03-27 19:09:24.295184+00', 9336, 1, NULL, 'ace', '1–::

  1c cross RH, cast off to 2pl (2c up) ; 2c+1c turn RH, men finish facing out

9–::

  L-Chain, men finish facing out

17–::

  1M+2M dance cclw ½ way round outside _while_{4} 1W+2W turn LH 1½, women finish LHJ and men dance in front of partner into ; LHA

25–::

  1c+2c chase cclw ½ way round set ; 2c+1c set | 1c cross RH to own side

', 2);
INSERT INTO 'dancecrib' VALUES (2022, '2012-01-22 19:29:15.387045+00', '2021-06-18 21:03:36.210371+00', 1467, 1, NULL, 'ace', '1–::

  1c+2c+3c reels3 on sides, 1c begins inwards

9–::

  1c lead down | lead up ; cast off (2c up) | turn ¾ RH and join LH with 1cnrs

17–::

  BiL | 1c turn ¾ RH to join LH to 2cnrs ; BiL | 1c turn RH to 2pl

25–::

  2c+1c+3c set | cross RH ; repeat (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2024, '2012-01-22 19:29:15.538394+00', '2014-04-30 23:23:45.94262+00', 1473, 1, NULL, 'ace', '1–::
  1c+3c turn RH ½ with person opposite, face that person | twirl R and into opposite place ; 2c+4c repeat this and face in _while_{4} 1c+3c (W leading) chase ¼ clw | curve into centre and swivel R to face out (1c facing 4pl and 3c facing 2pl)
9–::
  Parallel Reels4 across
17–::
  2c+1c & 3c+4c circle4 L ; face other couple and set | ½ RHA, flowing into
25–::
  2c+4c LHA in the middle ; dance out passing same sex standing dancer on the side Rsh, and chase R (M leading) to 1pl/3pl (to 2,3,4,1).', 3);
INSERT INTO 'dancecrib' VALUES (2028, '2012-01-22 19:29:15.798679+00', '2016-11-23 09:50:18.302254+00', 1486, 1, NULL, 'ace', '1–::

  1c cross RH, cast off one (2c up) ; ½Fig8 up round 2c (2,1,3)

9–::

 1c (start inwards) turn 3C EH ; 1c turn 2C EH (2,1,3)

17–::

  1c+3c RHA ; 1c+2c LHA

25–::

  2c+1c+3c Reels3 on the sides, 1c giving Rsh to 3c (2,1,3)



*After the second turn the dancing couple continues the reel with bottom couple to change places.*', 4);
INSERT INTO 'dancecrib' VALUES (2132, '2012-01-22 19:29:21.78621+00', '2023-02-10 13:42:25.031631+00', 1843, 1, NULL, 'ace', '{{explanation}}

intended for a 3c set



1–::

  1c lead down, cross and cast to top (1x,2) ; 1M+2W lead between Ps, cross and cast back to W side

9–::

  1W+2M lead between Ps, cross and cast back to M side ; 2c lead down, cross and cast up (2x,1x)

17–::

  1M+2W pass Rsh and curve to face each other | pull back Rsh and dance to original places ; 1W+2M repeat (1,2)

25–::

  Tournée (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (2027, '2012-01-22 19:29:15.736631+00', '2014-04-30 23:23:46.002254+00', 1480, 1, NULL, 'ace', '1–::
  1c+2c half R&L ; 2c cross RH to own side _while_{4} 1c dance up to between 2c, all facing up NHJ | set in line across and pivot R the second PdB to face down
9–::
  In line of 4 dance down the middle (turn R about) ; and up, finishing with 1c BtoB between 2c
17–::
  1c+2c Reel4 across the dance, 1c finishing facing corners
25–::
  1c turn corner, P, corner, cross over to own sides (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2030, '2012-01-22 19:29:15.926519+00', '2014-10-26 14:16:10.694846+00', 1492, 1, NULL, 'ace', '1–::

  1c dance down 2 places and cast up to 2pl (2c up) ; 2c+1c+3c set and cross RH (2x,1x,3x)

9–::

  1c dance up and cast off one ; 2c+1c+3c set | 2c+3c cross LH _while_{2} 1c turn LH to face 1cnr:

17–::

  1c set R to 1cnr {1} and L to P {1} | turn ¾ RH ; set R to 2cnr and L up/down to P | turn ¾ RH to 2pl

25–::

  2c+1c+3c circle6 and back. (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2040, '2012-01-22 19:29:16.565148+00', '2021-04-25 13:12:27.187944+00', 5171, 1, NULL, 'ace', '1–::

  1c dance down the middle, cast up round 3c (2c up) , cross up and cast off to (2,1x,3)

9–::

  Mirror Reels3 on the sides, 1c start down & in (2,1x,3)

17–::

  1c ½Fig8 round 3c, 1c turn LH 1¼ to face 1cnr in lines across.

25–::

  2c+1W & 1M+3c Lsh Reels3 across (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10430, '2018-02-13 19:34:26.907185+00', '2020-10-31 11:56:01.21613+00', 17476, 1, 202, 'ace', '1--::

  Mirror Reels3 on sidelines, 1c (then all cpls in 1pl) crossing down to start (1x,2x,3x)

9--::

  Mirror Reels3 on sidelines, 1c down and in to start (1x,2x,3x)

17--::

  1c+2c ½ DblFig8, 1c crossing down to start (to 1,2,3x) ; 1c dance down between 3c (2c dance up to 1pl), cast up to 2 pl (2,1,3x)

25--::

  1c+3c ½ DblFig8, 1c crossing down to start (to 2,1x,3) ; 1c lead up between 2c, cast off to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3759, '2013-06-08 22:24:09.443312+00', '2018-01-27 14:23:38.436816+00', 10166, 1, NULL, 'ace', '1–::

  1c+2c+3c Inveran Reels (1,2,3)

9–::

  1c cross RH | cast (2c up) ; Turn RH to face 1cnr

17–::

  1c+1cnrs pass Rsh | cnrs turn RH ½ and cast away as 1c meet and pass Rsh to face 2cnrs ; repeat with 2cnrs (3x,1x,2x)

25–::

  ½ Reels3 across, 1c Lsh to 3cnr ; ½ Reels3 on the sides, 1c Rsh to 4cnr (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2043, '2012-01-22 19:29:16.703302+00', '2023-02-12 16:26:11.203041+00', 1535, 1, NULL, 'ace', '1–::

  1c lead down the middle (2c up) ; turn inward and lead up to face 2W in promhold

9–::

  1c in promhold Rsh Reel3 across with 2c

17–::

  1c Reel3 across with 3c (Lsh to 3W), finish on midline facing P, M above W

25–::

  1c set, petronella to 2pl ; All C turn RH', 3);
INSERT INTO 'dancecrib' VALUES (10652, '2018-04-18 18:25:13.205708+00', '2020-04-15 09:29:39.805734+00', 13914, 1, 202, 'ace', '1–-::

  1M+2W cross and dance ¾ Lsh round P, pass down/up Lsh, cast R round standing M/W to places (1,2)

9–-::

  1W+2M repeat (other shoulders) (1,2)

17--::

  1M followed by 1W cast | cross to 2plx (2c up) ; 2c+1c LHA, 2c(1c) facing dn(up) at end (2,1x)

25--::

  2c+1c set | turn EH, 1c start in and up | 1c cross LH (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (14161, '2021-07-21 10:12:09.858079+00', '2021-07-21 10:12:09.858079+00', 19547, 2, 10819, 'ace', '1-4:: 1s set & cast (2s step up on bars 3+4)
5-8:: 1L+3L & 1M+2M set & link, finishing with 3L+2M stay facing out
9-16:: 1/2 LS reels of 3 on sidelines (3L up, 2M down), then 1s set _while_ 2M+3M and 2L+3L TB once round and open up, all circle on to lines across with 1s in the middle (1M facing down, 1L up, 2C+3C on opp. sides)
17-24:: All set and XR, then corners XR with partner to own sides _while_ 1s cast to their right into 2nd place own side, all set
25-32:: Circle round and back to 312', 5);
INSERT INTO 'dancecrib' VALUES (2033, '2012-01-22 19:29:16.164854+00', '2019-01-11 00:30:09.785496+00', 1501, 1, NULL, 'ace', '1–::

  1c (NHJ) set to 2W | 1c+2W circle3 L ; 1c set to 2M | 1c+2M circle3 L, 1c finish in the middle facing down 

9–::

  1c lead down (2c up) ; and up to between 2c, 1M facing 2W and 1W facing 2M

17–::

  1c+2c Reel4 across, 1c finish facing 1cnrs

25–::

  Turn CPCP (2,1,3) (1st time through finish NHJ facing new 2W)', 3);
INSERT INTO 'dancecrib' VALUES (11249, '2018-10-05 00:35:17.461703+00', '2018-10-05 00:41:22.591981+00', 18755, 1, 202, 'ace', '1--::

  All turn P RH ½, face P | cast R to exchanged places ; 1W set | cast to 3pl (2W+3W up)

9--::

  All repeat [1-4] with opposite person ; 2W+2M set | cast (3W & 3M up) (1,3,2 on M side, 3,2,1 on W side)

17--::

  3C Bourrel, 1c face out  (2,1,3)

25--::

  Reels3 on sidelines, 1c RSh to 3cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2041, '2012-01-22 19:29:16.606115+00', '2014-09-25 14:06:44.456288+00', 9559, 1, NULL, 'ace', '1–::

  1c turn RH ½ | set to P with RHJ (2c up) ; 1c lead down, cross below 3c and cast up to (2,1,3)

9–::

  All A&R ; ½ Reels3 across (Lsh to 1cnr) (2x,1x,3x)

17–::

  All A&R ; ½ Reels3 across (Lsh to 3cnr pos), 1c finish LHJ with P and RHJ with 4cnr

25–::

  the Spoke: BiL{1}, advance LHJ cclw to next cnr {1} | repeat 3 times, on [31-32] 1c petronella turn to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1618, '2012-01-22 19:28:51.301798+00', '2019-12-18 16:40:20.253771+00', 22, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; dance down between 3c and cast up to face 1cnr

9–::

  1c ½ Reel4 with 1cnrs, at end pass LH into ; BiL with 3cnrs (1cnr persons) | turn P LH ¾ to face 2cnrs

17–::

  Repeat with 2cnrs, finish BtoB facing own side (3x,1,2x)

25–::

  1c cast R round 3cnr pos, pass up/dn RH and cast R _while{8}_ 3c+2c cross RH | set across {1} and up/dn {1} ; cross up/dn | set up/dn {1} and across {1} (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10847, '2018-06-14 06:02:44.206865+00', '2019-03-24 11:13:38.084321+00', 18384, 1, 202, 'ace', '1--::

  1M followed by 1W dance down the middle {2} and pivot R to face P (2c up) | 1c change places RH up/dn, retaining RH ; set | on [7], release RH, PdB R facing P. On [8] PdB L and pivot R to face 3cnrs (2,*1*,3)

9--::

  »Weasel Reel« on 1diag [½ Reel4 on diagonal, on reaching the end each dancer chases clockwise to the other end and is replaced in the reel4 by a dancer finishing that chase]. Finish as started. On [16] 1c pass Lsh to face 2cnrs

17--::

  »Weasel Reel« on 2diag. On [24] 1c pass Lsh to face 1cnrs

25--::

  Corners Pass and Turn (2,1,3)

33--::

  Circle6 and back ', 5);
INSERT INTO 'dancecrib' VALUES (8021, '2013-08-29 21:25:59.513967+00', '2018-11-26 00:22:21.365456+00', 1499, 1, NULL, 'ace', '1--::

  1c cross RH | cast off 2 (2c+3c up) ; turn 3c 1½ EH (1c move inwards), to finish in 2pl facing our, hands joined with cnrs

9--::

  All set | set to 1cnr ; turn 1cnrs RH and pass Rsh to join hands, 1M with 2c, 1W with 3c

17--::

  All set | set to 2cnr ; turn 2cnr RH and pass Rsh to 2pl own side

25--::

  All chase clw half round ; All set to P | All turn P RH ½ into

33--::

  3C Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12025, '2019-08-18 16:57:17.400665+00', '2019-08-18 17:04:11.002309+00', 8068, 1, 202, 'ace', '1--::

  All set | cross RH ; all set | turn P RH ½ ready for

9--::

  3C promenade (1,2,3)

17--::

  1c cross RH | cast to 3plx (2c+3c up) ; 1c ½ Fig8 up round 3c (2,3,1)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (9465, '2016-11-08 12:13:32.891928+00', '2016-11-08 12:13:32.891928+00', 17404, 2, NULL, 'ace', '1- 8::

  1s+2s+3s dance Inveran reels  

9-12::

  1s cross RH & cast off to face 2nd corners 

13-16::

  1s+2nd corners dance Pass & Gypsy Turn: `1s dance RSh around the corner positions into the centre whilst  corners dance around each other with a RSh Gypsy Turn & return to places   

17-24::

  1s dance around each other with a RSh Gypsy Turn to face 1st corners, 1s+1st corners dance Pass & Gypsy Turn, 1s turn RH into promenade hold facing 1M’s position 

25-32::

  2M+1s+3M dance ½ reel of 3 on side (3M & 1s pass RSh to start), 2L+1s+3L dance ½ reel of 3 on side (1s & 3L pass RSh to start), finishing with 1s in 2nd place in centre 

33-40::

  3s+1s+2s Allemande 

', 5);
INSERT INTO 'dancecrib' VALUES (1857, '2012-01-22 19:29:06.393545+00', '2014-10-22 06:34:25.660105+00', 873, 1, NULL, 'ace', '1–::

  1c set, cast (2c up) ; turn LH 1½ and face out (2,1x,3)

9–::

  Reels3 on the sides (Lsh to 2cnr), at end 1c turn RH to face 1cnrs

17-32::

  »Dance to Each Corner and Set« (»Free« cnrs set diagonally _while{2}_ centre dancers change place Rsh with the facing cnr, who in the centre pass Rsh to face next cnr on R. Repeat this five times, on alternating diagonals) ; 1c turn RH 1½ to 2pl _while{4}_ 3c+2c ½ R&L starting along the sides.(2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3681, '2013-01-14 00:46:28.882379+00', '2014-06-13 08:21:08.0209+00', 14553, 1, NULL, 'ace', '1–::

  1c set | lead down, cross below 3c and cast up to (1x,2,3)

9–::

  1c+2c Bourel: 1M+2M cross and dance cclw to midline _while_{4} 1W+2W set adv. | turn ¾ RH and pivot R, and all face P ; set to P | turn RH ¾ , finish (2,1x,3) with 1c NHJ facing down and 2c facing out

17–::

  Mirror Reels3 on the sides, 1c pass between 3c, 1c finish in centre facing down

25–::

  1c cross below 3c and cast to 2pl ; All turn P RH', 3);
INSERT INTO 'dancecrib' VALUES (1861, '2012-01-22 19:29:06.634488+00', '2014-04-30 23:23:42.626614+00', 9169, 1, NULL, 'ace', '1–::
  1M+2W cross RH | 1W+2M cross RH ; 2c+1c S&Link (to 1x,2x)
9–::
  1W+2M cross RH | 1M+2W cross RH ; 2c+1c S&Link (to 1,2)
17–::
  1c+2c half RH turn and take hands crossed (LH below) | slip down ; up | half turn in PdB and face up, passing hands into Allemande hold
25–::
  1c+2c Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11728, '2019-03-24 00:53:57.665682+00', '2019-03-24 21:40:25.485421+00', 8203, 1, NULL, 'ace', '*Can be danced in a 3C, 4C or 5C set*  

1--::

    1c Fig8 on own sides (start in & down) 

9--::

    Bottom couple Fig8 on own sides (start in & up)

17--::

    All turn P RH ; LH

25--::

    1c slip down | and up to top ; 1c long cast to bottom (other couples up)  

', 3);
INSERT INTO 'dancecrib' VALUES (10052, '2017-08-28 19:27:42.439318+00', '2017-08-28 19:27:42.439318+00', 1298, 1, NULL, 'ace', '1--::

  1c+2c ½ R&L finish 1W facing 2M ; “Set & Shuttle”: 1W+2M set, pivoting ¼ L | change place in slip-step, passing BtoB {1}, PdB L and face P up/down {1}

9--::

  1c+2c ½ R&L starting along sides, finish 1M facing 2W ; 1M+2W “Set and Shuttle” to (2x,1x)

17--::

  2c+1c set | cross RH ; turn P RH 

25--::

  Circle4 and back (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2048, '2012-01-22 19:29:16.952635+00', '2021-01-11 11:32:55.27867+00', 12675, 1, NULL, 'ace', '1–::

  1c+2c set | 1c turn RH and 2c turn LH into a diagonal line for ; 1c+2c ½Poussette but end with a slow ½ BH turn to face down NHJ, M on the R

9–::

  1c (leading)+2c dance down the middle and (2c leading) up, finish in the middle

17–::

  2c+1c+3c Mirror Reels3 in own sidelines (2c cast, 1c up), 1c finish facing 1cnr.

25–::

  1c set to 1cnr | then spiral R to face 2cnr ; set to 2cnr | spiral R to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2221, '2012-01-22 19:29:26.49343+00', '2014-04-30 23:23:49.332817+00', 2136, 1, NULL, 'ace', '1–::
  1c+2c set, ½R&L ; repeat
9–::
  1c down the middle and up to 2pl (2c up)
17–::
  1c+3W circle3 to the L, flowing into ; 1c+3M repeat
25–::
  2c+1c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (2042, '2012-01-22 19:29:16.659297+00', '2016-06-03 13:37:45.776459+00', 9500, 1, NULL, 'ace', '1–::

  1c set | cast off two and lead up to the top, 2c dance in on [8] for

9–::

  1c+2c allemande, on [15-16] 1c turn LH ¾ into

17–::

  1M+2c & 1W+3c RHA ; 1M+3c & 1W+2c Circle3 R, at the end 1c pull Lsh back to face P up / down

25–::

  1c set | petronella turn into 2plx ; All turn partner BH, 1c turning 1½ times (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (2049, '2012-01-22 19:29:17.009167+00', '2019-04-02 20:45:47.795763+00', 11872, 1, NULL, 'ace', '1-4::

  1c lead down two and cast up to 2pl (2c up)

5-16::

  R&L for 3 couples (2,1,3)

17–::

  1c turn RH ¾ _while_{2} cnrs chase ¼ cclw | 1c turn 4cnr (pos.) LH _while_{2} 1cnrs set diag. ; 1c turn RH ¾ _while_{2} cnrs chase ¼ cclw | 1c turn 1cnrs LH _while_{2} 2cnrs set diag. (3x,1x,2x)

25–::

  All S&Link3 ; repeat (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2050, '2012-01-22 19:29:17.07102+00', '2021-02-05 12:30:36.134943+00', 10788, 1, NULL, 'ace', '1–::

  1c+3c turn P RH ¾ | ½ Reel4 on midline | turn P RH ¾ (3,2,1,4)

9–::

  3c+2c & 1c+4c RHA ; LHA, stay facing cclw

17–::

  All chase cclw half round the set into ; Half Circle8 R, finish for

25–::

  3c+2c & 1c+4c Poussette (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (14389, '2021-10-14 15:11:01.9108+00', '2021-10-14 15:17:10.453054+00', 20508, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; ½ Fig8 R round 1cnrs (2,1x,3)

9--::

  All set | 1c turn P RH ¾ _while{2}_ 2c+3c link into two lines3 across, 1M between 3c in 1pl, 1W between 2c in 3pl. 3W & 2M face out ; ½ Reels3 across, 1c RSh to 2cnrs[pos], 3W & 2M in 2cnrs[pos] pulling RSh back to enter the reel

17--::

  All set in lines3 across | 1c turn P RH ¾ to 2pl _while{2}_ 3c & 2c link across to sides. 3M & 2W face out ; ½ Reels3 on sides, 1c RSh to 3cnrs[pos], 3M & 2W in 3cnrs[pos] pulling RSh back to enter the reel (2,1,3)

25--::

  1c turn 1cnrs LH ; turn P RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14598, '2022-02-05 02:22:06.281462+00', '2023-02-04 01:23:04.039972+00', 18512, 3, NULL, 'ace', '1-8::
    1s set to 2s & change places RH; 1M+2M set & change places RH
    _while_ 1L+3L set & change places RH (Men''s side 1 2 3, Ladies'' side
    2 3 1)
9-16::
    All dance 3 couple Bourrel:
::
    _9-12_  1M+3L also 2M+1L set advcg & 3/4 turn 2H to line up/down
    middle & twirl to end BtoB (Lady facing up, Man down)  _while_ 3M &
    2L chase anticl''wise to face them
::
    _13-16_ All set & turn 2H to own sides.  3 1 2
17-24::
    3s+1s+2s set & circle 6H round to left
25-28::
    1s cross RH & cast right into lines of 3 across _while_ corners
    dance 1/2 R&L (no polite turns)
29-32::
    1s pass RSh (1 bar), Retire passing LSh (1 bar), pull back RSh to
    face opp side _while_ corners pass partner RSh into centre & face,
    2s+1s+3s Retire to own side. 2 1 3

{{explanation}}
Note: Bars 29-32 easier: 1s face partner (bar 29), turn 1/4 (bar 30) still facing partner & then Retire with 2s & 3s to own side', 0);
INSERT INTO 'dancecrib' VALUES (2066, '2012-01-22 19:29:17.952121+00', '2017-02-13 01:01:55.703414+00', 1586, 1, NULL, 'ace', '1–::

  1c+2c with NHJ set and dance half R&L ; repeat

9–::

  1c lead down for two steps, set to each other ; lead up to the top and cast to corners

17–::

  1c set to corners ; set to each other on 2nd diagonal, turn BH to finish 2pl opposite side

25–::

  2c+1c+3c advance {1}, retire {1}, repeat ; 1c turn BH 1½ to finish in 2pl on own side.', 2);
INSERT INTO 'dancecrib' VALUES (13655, '2021-02-08 16:14:27.123803+00', '2021-02-08 16:19:50.493867+00', 17966, 1, 202, 'ace', '1--::

  All set | 1c (2c & 3c following) cast down behind own lines, turn inwards on 3 pl and dance up back to places (1,2,3)

9--::

  1M+2W set | cross RH ; repeat _while{8}_ 1W+2M cross RH | set ; repeat (1,2,3)

17--::

  1W (1M following) casts off to 2plx (2c up) ; 1M (1W following) casts off to 3pl (3c up) (2,3,1)

25--::

  Circle4 L ; all NHJ advance in {2}, shout "Hoi" and retire to sides (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (1876, '2012-01-22 19:29:07.60311+00', '2019-01-22 15:19:57.466221+00', 916, 1, NULL, 'ace', '{{explanation}}

Music in 3+3-bar sections. One Sk-ch step per bar, i.e. start even-numbered 3-bar sections with L foot.



1-6::

  1c cast off (2c up) [3] ; 1M+3c & 1W+2c circle3 L

7-12::

  1M+3c & 1W+2c circle3 R ; 1c cast L and dance Lsh round 4cnr to face 1cnr

13-24::

  Turn CPCP (3 steps per turn)', 3);
INSERT INTO 'dancecrib' VALUES (11498, '2019-01-05 11:57:17.828426+00', '2022-02-15 15:40:46.645917+00', 14449, 1, 1645, 'ace', '1-::

  1c cross RH | cast (2c up) ; lead down LH, cross & cast up (2,1,3)

9-::

  2c+1c+3c &frac12; Gr-Chain, 3c cross to start ; all set | cross RH (3,1,2)

17-::

  3c+1c S&Link (1,3,2) ; all advance & retire

25-::

  1c+3c+2c Knot (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (2065, '2012-01-22 19:29:17.906176+00', '2014-04-30 23:23:46.756314+00', 8514, 1, NULL, 'ace', '1–::
  1c set, 1M advancing to behind 1W who swivels R | cast into 2plx (2c up) ; 2c+1c RHA
9–::
  1c (1W leading) +2M+3M Reel3,Lsh to 3M, 1c finish between 2c,
17–::
  1c (1W leading)+2W+3W Reel3, Rsh to 3W, 1c finish between 2c, facing down, 1M on L of P
25–::
  1c cross out through 2pl, cast behind 3c and up to between 3c facing own side ; set to 3c | 1M+3M & 1W+3W turn EH ¾ (start downwards) to (2,1,3)  (On second turn, start upwards, turning with the other hand, to (2,3,1))', 3);
INSERT INTO 'dancecrib' VALUES (9865, '2017-05-19 08:08:03.534101+00', '2017-08-26 13:39:30.276218+00', 10662, 1, 202, 'ace', '1--::

 1c/4c cast to 2pl/3pl as 2c/3c dance in to 1pl/4pl | all turn P BH ; 2c+1c & 4c+3c Circle4 and back (2,1,4,3)

9--::

 all repeat [1-2] to original places | all turn P BH ; 2c+3c Circle4 and back (1,2,3,4)

17--::

 1c+2c Knot finishing 1c facing 3c (2,1,3,4)

25--::

 1c & 3c set | 1c & 3c set adv passing Lsh to BtoB, 1c facing 4c ; 1c & 4c repeat [25-28] (2,3,4,1)

33--::

 2c+3c & 4c+1c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (9138, '2016-04-19 05:14:14.17668+00', '2016-04-19 05:40:13.498967+00', 12754, 1, NULL, 'ace', '1--::

  1c long cast (touch hands) to 3pl (2c+3c up) ; 1c turn RH (2,3,1) 

9--::

  3c followed by 2c dance down, cast up round 1c, dance to top NHJ and 3c+2c cast off to (2,3,1)

17--::

  All advance up NHJ | retire ; All turn P RH (231) 



*Danced 6 times through*

', 3);
INSERT INTO 'dancecrib' VALUES (2064, '2012-01-22 19:29:17.845548+00', '2019-03-07 00:33:15.722511+00', 8235, 1, NULL, 'ace', '1–::

  All M set H.Schottische _while_{4} all W LHA, finish facing P ; all W dance Lsh round P and finish in middle facing P

9–::

  All set to P | all C La Baratte, finish in promhold facing cclw

17–::

  All promenade once round cclw. to places

25–::

  All C petronella in tandem one place R and set ; turn P RH', 4);
INSERT INTO 'dancecrib' VALUES (1818, '2012-01-22 19:29:04.023072+00', '2021-06-28 15:16:52.392224+00', 722, 1, NULL, 'ace', '1–::

  1c+2c set | 2c cast up _while_{2} 1c cross down touching hands ; 1M+2W & 1W+3M turn LH, then pass wide Lsh to face 1cnrs.

9–::

  1c dance to corner position, face in & set _while{4}_ 1cnrs dance in and turn RH 1½ ; 1cnrs continue to opposite sides and set _while{4}_ 1c dance in and turn RH 1½ to face 2cnrs.

17–::

  1c repeat with 2cnrs, finish facing 3cnr

25–::

  1c+1cnrs ½ diag Reel4 ; pass Rsh and repeat with 2cnrs, finish with crossing Lsh to opposite sides, into

33–::

  1c+cnrs RHA on side, then M up, W down for ; 1M+2c & 1W+3c LHA, finish (2,1,3).

', 2);
INSERT INTO 'dancecrib' VALUES (2068, '2012-01-22 19:29:18.071446+00', '2014-04-30 23:23:46.801247+00', 1588, 1, NULL, 'ace', '1–::
  1c+2c S&Link ; 1c+3c S&Link. (to 2,3,1)
9–::
  2c+3c+1c advance {1}and retire {1} | turn BH ½ and remain in the middle: All set to P | All swivel R to dance out to opposite sides (2x,3x,1x), ready for
17–::
  Two hands of G-Chain (2c cross to start) to (1x,2,3) ; 1c+2c S&Link, 1c finish BtoB in the middle facing opposite side as for DTr (no hands).
25–::
  All advance (1c to sideline, 2c+3c meet P) {1}, retire {1} | all advance and swivel R (1c to 2plx, 2c+3c into BtoB in the middle) ; All A{1} & R{1} again | 1c cross RH _while_{2} 2c+3c advance to sideline and swivel R (2,1,3).

{{explanation}}
note: For [25-28] the original texts say no hands, and pass; in the Book 23 version hands are often held, steps are very small', 3);
INSERT INTO 'dancecrib' VALUES (2069, '2012-01-22 19:29:18.12245+00', '2017-03-24 14:58:01.101088+00', 11724, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; ½ Fig8 L (M up, W down) (2,1x,3)

9–::

  All A&R [1+1] | cross RH ; repeat, but 1c turn RH so 1M faces up, 1W down

17–::

  Reels3{6} across, 1c Rsh to 2cnr | 1c turn LH to face 1cnr

25–::

  Corners pass and turn (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13657, '2021-02-09 10:30:16.956973+00', '2021-02-09 11:57:37.42742+00', 17950, 1, 202, 'ace', '1--::

  All turn P RH ; chase clw ½ (3x,2x,1x)

9--::

  Mirror Reels3 on sides, 3c in and down, 2c out and up (3x,2x,1x)

17--::

  3c (+2c+1c who dance up to follow) dance down ; on [21] all change sides and face up [: M dance below W who dance under P''s arm] and dance up to places. 1c & 2c stay in the middle ready for (1,2,3)

25--::

  2C Poussette (2,1,3)



*Deviser''s notes:  

- On the second time through, 4th couple stay in the middle and 1 st, 3rd, and 4th couples dance a three couple poussette to take first couple to the bottom,  

- For a three couple set dance: 1st, 2nd and 3rd couples stay in the middle on bar 24 and dance a three couple poussette to finish 2,3,1; repeat with a new top couple.*', 2);
INSERT INTO 'dancecrib' VALUES (2076, '2012-01-22 19:29:18.524408+00', '2020-02-08 20:24:18.946465+00', 1625, 1, NULL, 'ace', '{{explanation}}

on 2nd chord 3c+4c change sides (1,2,3x,4x)



1–::

  1c+4c dance in for mirror Fig8 on own side around middle persons (W pass in front)

9–::

  2c & 3c Fig8 around 1c & 4c respectively, meeting in a circle NHJ

17–::

  2c+3c set in circle | set swivelling 1¼ R ; LHA to own places

25–::

  Reels4 on the sides, at end the middle pairs pass with ½LH turn into:

33–::

  Join RH with end person and BiL twice ; end pairs on sidelines turn RH ½ ; new middle couples ½LHA to new places (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (2904, '2012-01-22 19:30:02.298659+00', '2016-09-04 20:44:54.80854+00', 4875, 1, NULL, 'ace', '1–::

  1c starting inwards Mirror Figs8 on own side

9–::

  Mirror crossover Reels3 on the sides (1x,2,3)

17–::

  1c cross RH | cast (2c up) ; lead between 3c, cross and cast up (2,1x,3)

25–::

  All A&R ; 1c turn RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (5014, '2013-08-21 08:30:58.844585+00', '2023-02-10 14:54:40.479159+00', 1678, 3, NULL, 'ace', '1-8::

    1s pass RSh & lead down LH for 2 bars, lead up to top & turn LH to

    end between 3s

9-16::

    1s dance reel of 4 across with 3s & end facing 1st corners

17-32::

    1s dance Corner Chain with 1st & 2nd corners :

::

    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return

    to places giving RH to 1s who turn LH in centre to face 2nd crnrs

::

    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &

    return to places giving RH to 1s & 1s end turning LH back to places.

    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14162, '2021-07-21 10:13:08.719109+00', '2021-07-21 10:13:08.719109+00', 19725, 2, 10819, 'ace', '1-4:: 1M set, cast down (2M step up on bars 3+4)
5-8:: 1L set, cast down (2L step up on bars 7+8) _while_ 1M+3L TR back to sidelines
9-12:: 1L+3M TL back to sidelines _while_ 1M+2L TL back to sidelines
13-16:: 1L+2M TR back to sidelines _while_ 1M dance round 3M passing LS to finish side by side with 1L on ladies'' side, NHJ
17-20:: 1s dance over to men''s side and cast (1L up, 1M down) to finish between couples
21-24:: 1s set advancing, TB 1/2 (PdB), pull RS back to finish back to back, 1L facing down, 1M facing up _while_ crnrs face diagonally in and set twice.
25-32:: 1s dance 1/2 reels of 3 across (RS to 2nd crnr), passing RS in the middle; 1s dance another 1/2 reel of three across (RS to 4th corner) into 2nd place own side', 5);
INSERT INTO 'dancecrib' VALUES (14747, '2022-04-06 02:12:31.827942+00', '2022-04-06 02:17:43.571337+00', 16049, 1, 202, 'ace', '1--::

  Reels3 on sides, 2c RSh to 4cnrs (1,2,3)

9--::

  1c+2W & 2M+3c RHA ; 2c dance up to top and cast off (1,2,3)

17--::

  1c+2M & 2W+3c LHA ; 2c dance down and cast up (1,2,3)

25--::

  3c dance up to top and cast off to 2pl  _while{4}_ 2c set | dance up looping to 1pl _while{4}_ 1c dance in and cast off to 3pl ; all turn P BH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (15169, '2022-10-13 06:54:04.128293+00', '2022-10-13 20:04:43.916399+00', 21122, 1, 202, 'ace', '1--::
  1c+3c R&L
9--::
  Circle8 and back
17--::
  1c+3c M-Chain. 1W & 3W face out
25-40::
  Schiehallion Reels. 1M & 3M face clw
41--::
  1c & 3c (M leading) chase clw ¼ | curve into centre RSh round dancer same sex and face that dancer ; 2c+1c & 3c+4c Circle4 L
49--::
  Parallel Reels4
57--::
  1c & 3c dance out passing same sex standing dancer RSh | chase clw ¼ (M leading) to exchanged places ; 3c+1c ½ R&L (1,2,3,4)

*Deviser''s note* :  2c & 4c repeat [1-64]', 4);
INSERT INTO 'dancecrib' VALUES (2080, '2012-01-22 19:29:18.727283+00', '2014-04-30 23:23:46.995169+00', 1641, 1, NULL, 'ace', '1–::
  With NHJ on the sides 4 slip steps R | and back ; all turn partner RH
9–::
  With NHJ on the side 4 slip steps L | and back ; all turn partner LH
17–::
  1c cast off one, meet and dance NHJ to top ; cast off to bottom (2c+3c+4c up on [23-24] (2,3,4,1)
25–::
  All Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (13293, '2020-11-01 01:54:48.383298+00', '2021-03-20 19:41:25.813833+00', 8313, 2, 35787, 'ace', '1-8 :: 1c set, cast off  (2c up); and LH 1½ to facing 1st corners

9-16 :: 1c dance ½ reel-4 with 1st corners, 1c pass RSh ; dance ½ reel-4 with 2d corners, pass RS to 2d place own side (312)

17-24 :: 3c+1c+2c set twice;  BtoB w partner

25-32 :: 3c+1c+2c diag R&L (213)

', 0);
INSERT INTO 'dancecrib' VALUES (1745, '2012-01-22 19:29:00.077134+00', '2016-09-04 21:20:49.826962+00', 475, 1, NULL, 'ace', '1–::

  1c+2c+3c A&R ; dance BtoB (M making arches), finish 2c+3c making BH arches for

9–::

  1c dances under 2c arch and under 3c arch, 2c following | all dance down ; all dance back up, first 3c and then 2c forming arches, and the others passing under, all C finish in promhold on midline

17–::

  Promenade to the Right (on W side), 3c finish in 3pl, 1c+2c in middle for

25–::

  1c+2c Allemande (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2072, '2012-01-22 19:29:18.279102+00', '2016-10-30 13:39:30.088889+00', 1582, 1, NULL, 'ace', '1–::

  1c+2c set, ½ RHA ; set, ½ LHA

9–::

  1c lead down the middle and up, 2c step in for

17–::

  1c+2c Allemande

25–::

  2c+1c+3c circle6 and back.', 3);
INSERT INTO 'dancecrib' VALUES (10406, '2018-01-29 13:37:09.32754+00', '2018-01-29 13:41:58.187291+00', 18232, 1, NULL, 'ace', '1--::

  2c cross down RH and cast up to 2plx ; cross up RH and cast off to face 1cnrs

9--::

  2c set to and turn corners, to (1,2x,3)

17--::

  Reels3 on own sides, giving hands, to start 2c cross down (1,2,3) 

25--::

  Slipknot: 6 bars of a 3C knot, (to 3x,2x,1x) | 3c+2c ½ LHA as 1c turn LH ½ (2,3,1)

 

', 3);
INSERT INTO 'dancecrib' VALUES (2081, '2012-01-22 19:29:18.758835+00', '2019-02-19 15:57:30.3848+00', 14396, 1, NULL, 'ace', '1–::

  1c+2c+3c Inveran Reels, 2c start out and up, all C cross from top and from bottom  (1,2,3,4)

9–::

  1c dance to 4pl _while_{2} 2c+3c+4c set | dance up one place ; 2c+3c & 4c+1c Circle4 L

17–::

  2c+3c+4c dance Inveran Reels as in [1-8]

25–::

  2c+3c & 4c+1c Mirror DblFigs8, to start 2c&1c cross inwards and 3c+4c dance to the ends

33–::

  Circle8 and back (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2085, '2012-01-22 19:29:18.972693+00', '2014-04-30 23:23:47.070192+00', 11278, 1, NULL, 'ace', '1–::
  1c+2c progressive DblFig8 (1c cross, cast ; cross up, cast _while_{8} 2c set, cross up, cast, cross up) (2,1,3)
9–::
  Mirror Reels3 on sides, 1c start in and down, and finish facing 1cnr
17–::
  1c set »Hello&Goodbye«, finish facing 3cnr
25–::
  1cnrs pass & turn ; 2cnrs pass & turn (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1914, '2012-01-22 19:29:09.578163+00', '2019-02-07 12:04:19.85229+00', 8040, 1, NULL, 'ace', '1–::

  All A&R ; cross to opposite side, the M making arches

9–::

  Repeat, to own side, the W making arches

17–::

  1c slip down | slip up ; cast behind 2c, between 3c and behind 4c (2c+3c+4c up) (2,3,4,1)

25–::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (2114, '2012-01-22 19:29:20.849522+00', '2023-02-10 14:28:38.14271+00', 1776, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; 1c+3c set | 1c turn ½ RH and 3c turn RH into

9–::

  1c+3c Allemande (2,3,1)

17–::

  1c cast up (3c down), cross LH and cast up (2c down) to (1,2,3) ; 1c+2c set | 1c turn ½ RH and 2c turn RH into

25–::

  1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2094, '2012-01-22 19:29:19.432833+00', '2017-07-07 13:59:47.047946+00', 1677, 1, NULL, 'ace', '1–::

  Mirror reels on own sides, 1c starting in and down

9–::

  1c+2c RHA {3} 1c cast as 2c dance up ; 1c+3c LHA (2,1,3)

17–::

  All circle6 and back, 1c finish facing corners

25–::

  1c set to 1cnr, to P, to 2cnr, petronella to 2pl', 2);
INSERT INTO 'dancecrib' VALUES (12489, '2020-01-10 01:22:04.780338+00', '2020-02-10 00:45:50.451849+00', 16876, 1, NULL, 'ace', '*C face C RR (1c face cclw, 2c clw)*

1--::

  1c+2c RHA ; LHA

9--::

  1c Fig8 round 2c

17--::

  2c Fig8 round 1c

25--::

  1c facing 2c A&R ; 1c makes arch, 2c pass under, and both face next cpl | the two W change place RH to join new P.  



*Repeat with new partner.*



', 3);
INSERT INTO 'dancecrib' VALUES (2086, '2012-01-22 19:29:19.030399+00', '2020-09-19 21:01:15.761941+00', 13722, 1, NULL, 'ace', '1–::

  S&Link ; 2M+1W cross and cast Rsh round P to exchanged places

9–::

  R&L

17–::

  S&Link ; 1M+2W cross, pass person opposite Rsh to exchanged places (2x,1x)

25–::

  RHA, to sidelines ; All set and cross RH (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (2096, '2012-01-22 19:29:19.525999+00', '2023-02-10 14:35:26.587798+00', 1697, 1, NULL, 'ace', '1–::

  1c+2c+3c mirror Reels3 on own sides (1c start in and down, 2c out and up), touch NH when meeting P

9–::

  1M+3W turn RH ½, remain close, swivel R and dance into each others place ; 1W+3M repeat and face out (3x,2,1x)

17–::

  1c+3c chase ½ clw to own places _while_{4} 2c turn BH ; 1c+2c ½ RHA _while_{2} 3c cross RH, 2c+1c+3c cross over RH (2,1,3)

25–::

  1c lead down between 3c, cross and cast up to 2pl ; lead up between 2c, cross and cast off to 2pl _while_{8} 2c+3c set | cross RH ; repeat back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8206, '2014-03-04 00:01:47.166405+00', '2021-04-02 21:23:41.636523+00', 15358, 1, NULL, 'ace', '1–::

  1c lead down and up | cast to 2pl (2c up) (2,1,3,4)

9–::

  All turn P RH ; All dance BtoB

17–::

  2c+1c & 3c+4c RHA ; LHA (2,1,3,4)

25–::

  End cpls chase 3/4 round cclw _while_{6} middles RHA 1 1/4, forming a set at right angles | All set to P



{{explanation}}

The set has now rotated 1/4 clockwise.  The bottom couple (2c) becomes the next dancing couple', 3);
INSERT INTO 'dancecrib' VALUES (3695, '2013-02-01 00:02:36.321597+00', '2016-11-27 11:01:58.515717+00', 12662, 1, NULL, 'ace', '{{explanation}}

2c+4c cross to opposite side (1,2x,3,4x)



1–::

  1M&4M ½ fig8 round neighbour couple (Lsh to the M), finish beyond P and face her ; take P on L in promhold and dance to meet in the middle (2c+3c step to end) | ½ LHA (2x,4,1x,3)

9–::

  On sidelines, middles pass ends Rsh to change places | 2c+3c ½ LHA _while_{2} 4c+1c set diagonally (4,3x,2,1x); On sidelines, middles pass ends Rsh to change places | 4c+1c ½ LHA _while_{2} 2c+3c set diagonally (3x,1,4x,2)

17–::

  1c&4c dance NHJ out the end and cast back to same place ; All half turn RH and twirl (3,1x,4,2x)

25–::

  Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (2087, '2012-01-22 19:29:19.074681+00', '2015-03-05 23:42:17.28697+00', 8741, 1, NULL, 'ace', '1–::

  1c long cast (2c up) ; dance between 3c and cast up to (2,1,3)

9–::

  All c dance Rsh round P to finish (2,1,3) facing clw ; all chase ½ clw (3x,1x,2x)

17–::

  All circle6 L and back

25–::

  All c dance Lsh round P to finish (3x,1x,2x) facing cclw ; all chase ½ cclw (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11531, '2019-01-20 19:39:51.04755+00', '2021-11-08 19:07:35.723515+00', 19166, 2, 12064, 'ace', '1-4:: 1s, 2s and 3s dance half turn (RH) and twirl.

5-8:: 1s, 2s and 3s dance a half chase clockwise, to go back to original lines (3, 2, 1).

9-16:: 1s and 2s dance the Tourbillon

17-24:: 1s dance the figure of love

25-32:: 1s dance a reel of three accross with 2s and 3s, 1st man down, 1st lady up, to 3, 1, 2.', 5);
INSERT INTO 'dancecrib' VALUES (10546, '2018-03-24 00:15:36.283575+00', '2018-03-24 00:17:24.737023+00', 7611, 1, 202, 'ace', '1--::

  1c & 4c long cast into 2p/3p  (2c & 3c step out) ; 1c & 4c ½ Fig8 round ends (2,1x,4x,3)

9--::

  1c+4c ½ R&L (no polite turn) ; 2c+4c & 1c+3c RHA (2,4,1,3)

17--::

  4c+1c LHA ; 2c+4c & 1c+3c turn RH on sidelines

25--::

  Parallel Reels4

33--::

  4c+1c DblFig8, 1c cast up to start (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9796, '2017-04-15 22:38:45.563507+00', '2023-02-10 15:04:30.034825+00', 1668, 1, 202, 'ace', '1--::

 1c BHJ slip down ; and up

9--::

 2c repeat

17--::

 1M+2W cross RH | 1W+2M cross RH ; 2c+1c set | 2c cross RH _while{2}_ 1c turn LH to face 1cnrs

25--::

 Turn CPCP (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2323, '2012-01-22 19:29:31.513799+00', '2020-12-25 10:57:24.580142+00', 11299, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c Poussette.

9–::

  1c+2c & 3c+4c set | Petronella in tandem to face P up/down ; parallel ½Reels4 on sides, finish facing P up/dn

17–::

  All Set | petronella in tandem to sidelines, Parallel ½Reels4 on the sides (1,2,3,4).

25–::

  1c+2c cross RH | ½ RHA ; 1c+3c cross RH | ½ RHA (2,3,1,4)

33–::

  1c+4c Espagnole (2,3,4,1).



{{explanation}}

Espagnole: both W lead RHJ to M side, cross and cast back to exchanged places while{4} Men cross to W side, lead RHJ back to M side and cross to exchanged places ; all turn P EH (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (3668, '2012-12-19 11:34:25.665454+00', '2014-04-30 23:23:47.265141+00', 14612, 1, NULL, 'ace', '1–::
  1c cross RH | cast off (2c up) ; turn RH to (2,1x,3)
9–::
  Reels3 across, 1c giving Rsh to 4cnr (2,1x,3)
17–::
  Reels3 on the sides, 1c giving Rsh to 2cnr (2,1x,3)
25–::
  1c cross RH | cast off (3c up) ; 1c turn RH (2,3,1)
33–::
  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (2105, '2012-01-22 19:29:20.373703+00', '2016-11-08 11:03:24.591555+00', 10433, 1, NULL, 'ace', '{{explanation}}

Part 1



1–::

  All Circle8 and back

9–::

  The Swirl: 1c+3c turn RH into Allemande hold facing in | dance Lsh round other C half way ; 1c+3c LHA, on [16] let go and swivel L to face side couples, BtoB with P, 1c below 3c

17–::

  Parallel Rsh Reels4 across, finish as at start

25–::

  All set | 1M+3W & 3M+1W NHJ dance out between side couple, cross and cast to own places, change place with P RH



{{explanation}}

Part 2



1–::

  All set | advance to middle and form circle ; retire with cnr | set

9–::

  1W+4M & 3W+2M R&L, starting across the set

17–::

  1M+2W & 3M+4W R&L, starting across the set

25–::

  All set | advance to middle and form circle ; retire with P | set



{{explanation}}

Part 3



1-24::

  2c+4c starting, repeat part 1, 9-32 in the other orientation (The Swirl, Reels4 up/dn, return to places)

25–::

  All Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (2333, '2012-01-22 19:29:31.913542+00', '2023-01-27 11:39:02.220503+00', 2504, 1, NULL, 'ace', '1–::

  1c advance to face 2M NHJ | set to 2M ; turn P RH to face 2W, NHJ with P and 1M on the R | set to 2W

9–::

  1c turn RH to places ; repeat LH

17–::

  1c down the middle and up

25–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (12492, '2020-01-11 01:29:07.915416+00', '2020-01-11 01:31:55.065791+00', 8388, 1, NULL, 'ace', '1--::

  1c dance down and cast up _as_ 2c dance up the sides and dance down NHJ to 2pl facing out and down ; ½ Reels3 on the sides (3,2,1)

9--::

  Repeat [1-8] (1,2,3) 

17--::

  3C Promenade (1,2,3)

25--::

  1c+2c "The Monument" [1c+2c set adv and join RH with P | set turning ¼ RH ; chase clw ½] (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (13658, '2021-02-09 17:03:00.878706+00', '2021-02-09 17:22:30.474319+00', 17951, 1, 202, 'ace', '1--::

  1c pass P RSh to midline BtoB 1M facing down (2c up) | Crown Triangles (last 6 bars). On [8] 1M pivot R to finish behind 1W. 1c face 3M

9--::

  1c+3c ½ Reel3 across in tandem (with lead change), 1W RSh to 3M ; 1c+2c ½ Reel3 across in tandem (with lead change), 1M LSh to 2M

17--::

  ½ Reel3 in tandem (with lead change) on 1diag, 1W RSh to 3M ; ½ Reel3 in tandem (with lead change) on 2diag, 1M LSh to 2M. 1c LSh to P on midline face own sides (3,1,2)

25--::

  3c+1W & 1M+2c RHA ; LHA (3,1,2)



*Deviser''s note:  

Bars 9-24: 1st couple are dancing two figures of eight in tandem: first on the men''s side, then on the women''s side, changing lead at each loop.*', 2);
INSERT INTO 'dancecrib' VALUES (2101, '2012-01-22 19:29:20.139774+00', '2021-02-13 15:36:48.493387+00', 10014, 1, NULL, 'ace', '1–::

  1c dance down 2 places and face out (2c+3c up) | 3c+1c turn ½ EH on the side ; 2c+1c turn once EH on the side (2,1,3)

9–::

  Mirror Reels3 on the side, with hands (1c start down and in, and finish facing 1cnr)

17–::

  ½ Reel4 with 1cnr, pass Lsh ; ½ Reel4 with 2cnr (3x,1x,2x)

25–::

  Holding hands in circle6 all set | All petronella to the R in circle (cclw, ¼ round) ; All set | All petronella to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2818, '2012-01-22 19:29:58.659739+00', '2021-05-08 23:16:13.033944+00', 4517, 1, NULL, 'ace', '*Strathspey*   

1–::

  1c+4c set | cast to middle (2c+3c step to end) ; 1c+4c RHA

9–::

  1c+4c set and cast back (2c+3c step back) ; 1c+2c & 3c+4c Circle4 L (1,2,3,4)

17–::

  Top three men (1M+2M+3M) change places RH with the next W below | set _while{4}_ 1W+4M cast clw to exchanged places ; Top three men (4M+1M+2M)  change places RH with the next W below (3W+4W+1W) | set _while{4}_ top W and bottom M (2W+3M) cast cclw to exchanged places  (3,4,1,2)

25–::

  Repeat 17-24 (to 1,2,3,4)



*Reel*  

33–::

  All dance 4 Petronella turns (no setting in between) (1,2,3,4)

41-52::

  1c turn RH | cast (2c up) ; cross Lsh | cast L round 2cnr ;; cross up/dn Lsh | cast left round 1cnr (to 2,1x,3,4)

53-56::

  All C turn RH (1c turns 1½) and stay in middle for

57–::

  Double Poussette: 2c+1c dance as top C, 3c+4c as bottom C. All dance out and turn on bar 1, progress on bars 2+3, continue as usual on 4-8  (to 3,4,2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2095, '2012-01-22 19:29:19.479794+00', '2021-03-16 18:21:13.209807+00', 8562, 1, NULL, 'ace', '1–::

  1c+2c Espagnole, 1c finish facing 1cnr

9–::

  1c+1cnrs ½ Reel4, pass Lsh ; ½ Reel4 with 2cnrs, finish (3x,1x,2x)

17–::

  All A{1}&R{1} | Link for 3 ; repeat (2,1,3)

25–::

  1c ½ Fig8 R ; turn BH



{{explanation}}

Espagnole: both W lead RHJ to M side, cross and cast back to exchanged places while Men cross to W side, lead RHJ back to M side and cross to exchanged places ; all turn P EH (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2107, '2012-01-22 19:29:20.483341+00', '2015-02-21 00:23:53.431094+00', 1758, 1, NULL, 'ace', '1–::

  All 4 couples cross over RH | 1c+2c & 3c+4c ½ RHA ; repeat LH (1,2,3,4)

9–::

  All set | ½ circle8 L | all set keeping hands in circle, finish in square set 

17–::

  4c+1c ½ R&L (up and down), to sidelines ; 3c+2c ½ R&L across (to 1,2,3,4, longwise set)

25–::

  All C turn RH ; 1c lead to 4pl _while{4}_ 2c+3c+4c set and dance up one place on the side (2,3,4,1).', 3);
INSERT INTO 'dancecrib' VALUES (15439, '2023-02-05 18:26:26.992217+00', '2023-02-05 18:32:28.704432+00', 21135, 1, 1645, 'ace', '{{explanation}}

Strathspey



1--::

  1c+2c & 3c+4c 6 bars of Poussette | on [7] 1c, 2c & 4c &frac12; turn BH _while{1}_ 3c &frac14; turn & all curve into square set (1,2,4,3)

9--::

  Circle8 &frac12; way to L (4,3,1,2) ; all S&Link & W face out

17-32::

  Schiehallion reel, W end facing out



{{explanation}}

Reel



33-36::

  4c & 1c &frac12; turn RH to 1pl & 4pl _while{2}_ 2c & 3c chase &frac14; clw to longwise set (4,2x,3,1x) | all set

37-40::

  2c Pass & Turn with 4cnrs (3M & 4W) to own side (4,2,3,1x)

41--::

  Mirror Reels4 on sides, 2c start in & down

49-52::

  All set | 2c lead to 4pl _while{2}_ 1c cast up (4,1x,2,3)

53-56::

  1c &frac12; Fig8 LSh round 3cnr pos _while{4}_ 3cnrs (4M+3W) turn LH _while{4}_ 2c set RHJ | &frac12; turn RH (4,1,3,2)

57--::

  1c+3c+2c set | 1c dance down & loop onto 4pl _while_ 3c+2c cast up; all turn P RH (4,3,2,1). *Repeat (once) from new places*

', 2);
INSERT INTO 'dancecrib' VALUES (1927, '2012-01-22 19:29:10.313812+00', '2014-04-30 23:23:43.967724+00', 11619, 1, NULL, 'ace', '1–::
  1c+3c dance down 2 (2c+4c up) and cast round 4c/5c to (2,1,4,3,5) ; 1c+3c RHA with Couple on their R (wheels of 3 at the ends, wheel of 4 in the middle)
9–::
  1c+3c ½diag Reel4 with 1cnrs ; with 2cnrs, at end turn ¾ LH into
17–::
  Lsh Reels3 across at the ends, Rsh Reel4 across in the middle (1c/3c finish in 2pl/4pl)
25–::
  1c+3c ½diag R&L (to 5,1x,4,3x,2) ; 1c+3c cross RH | 1c+4c change LH on the side (5,4,1,3,2)', 2);
INSERT INTO 'dancecrib' VALUES (11500, '2019-01-05 12:51:32.742889+00', '2022-02-15 15:43:12.773371+00', 14451, 1, 1645, 'ace', '*On 2nd chord, 3c & 4c cross over (1,2,3x,4x)*

1-::

  1c+2c & 3c+4c set | &frac12; RHA ; 1c+4c set | &frac12; LHA (2x,4x,1,3)

9-::

  2c+4c & 1c+3c set | &frac12; RHA (4,2,3x,1x) ; 4c+2c & 3c+1c each &frac12; chase clw into lines of 4 across with 2M+4W & 1M+3W BtoB in centre

17-::

  2c+4c & 1c+3c Reels4 across

25-::

  All set | petronella to face down/up on sides (2x,4x,1,3) ; all set turning to face P | cross RH (2,4,1x,3x)

33-::

  Circle8 & back (2,4,1x,3x)

', 2);
INSERT INTO 'dancecrib' VALUES (11502, '2019-01-08 10:37:29.329053+00', '2022-02-15 15:44:04.404892+00', 14452, 1, 1645, 'ace', '1-::

  1c+2c+3c set to P | 1c cast off _while_ 2c dance up NHJ & face down _while_ 3c dance in, touch NH & loop down to face up (2,1,3,4) ; 1W+2c & 1M+3c &frac12; LSh Reels3 across (2x,1x,3x,4)

9-::

  1c+3c+4c repeat [1-8] to (2x,3,1,4x)

17-::

  1c followed by 3c dance below 4c & cast up (2x,1,3,4x) ; 1c & 3c cross RH | 2c+1c change LH on sides (1x,2x,3x,4x)

25-::

  1c+2c set | &frac12; RHA ; 1c+3c &frac12; LHA | 1c+4c &frac12; RHA (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (2097, '2012-01-22 19:29:19.880791+00', '2016-12-06 21:34:55.395051+00', 11393, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c Poussette 

9–::

  1W+2M & 3W+4M change places Rsh, curving in ; 1M+2W & 3M+4W repeat (Rsh) (2x,1x,4x,3x)

17–::

  1c+3c ½Fig8 up ; 2c+4c ½Fig8 down (2,1,4,3)

25–::

  1c+4c+3c the Knot (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2103, '2012-01-22 19:29:20.258599+00', '2017-02-14 16:23:51.844034+00', 8665, 1, NULL, 'ace', '1–::

  1c+2c+3c circle6 and back

9–::

  1c set and cast off one place _while_{4} 2c set and lead up one place ; repeat

17–::

  1c followed by 2c and 3c cast off two places and lead up to own places

25–::

  1c+2c Allemande.', 2);
INSERT INTO 'dancecrib' VALUES (2110, '2012-01-22 19:29:20.626463+00', '2020-10-18 20:47:03.891712+00', 1768, 1, NULL, 'ace', '1–::

  1c+2c+3c promenade, 1c cross and cast to finish (2,1x,3)

9–::

  All set , but on second step [10] 1c turn R into lines across | repeat, 1c turning to own sideline ; repeat, into the other line across | repeat, 1c finish facing 1cnr

17–::

  1c+1cnrs ½Reel4 and pass Lsh ; ½Reel4 with 2cnrs  (to 3x,1x,2x)

25–::

  All circle6 L to own side ; 2c+1c+3c turn RH', 2);
INSERT INTO 'dancecrib' VALUES (10407, '2018-01-30 01:40:24.052083+00', '2018-01-30 01:55:33.201262+00', 18235, 1, NULL, 'ace', '1--::

  1c cross | cast off (2c up) ; turn LH 1¾ and join RH with 1cnr

9--::

  6 bars of "The Spoke" | turn LH to 2pl facing out (cnrs dance 8 bars) (2,1,3)

17--::

  All dance Chaperoned Chain Progression (3,1,2)

25--::

  All chase clw 1/2 ; Cross RH and set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9139, '2016-04-19 22:09:57.015631+00', '2016-04-19 22:09:57.015631+00', 11436, 1, NULL, 'ace', '1--::

  1c turn RH | cast (2c up) ; turn LH to face 1cnr

9--::

  1c+1cnrs diagonal Reel4, at end 1c pass Lsh to face 2cnr

17--::

  1c+2cnrs diagonal Reel4, to (2,1x,3)

25--::

  1c cross LH | cast off (3c up) ; turn RH (2,3,1)



', 3);
INSERT INTO 'dancecrib' VALUES (1928, '2012-01-22 19:29:10.354625+00', '2020-08-29 15:43:04.072405+00', 1143, 1, NULL, 'ace', '1–::

  Circle4 and back

9–::

  1W+2W dance NHJ between their P, cast round P to own place, change places RH

17–::

  1M+2M repeat

25–::

  R&L', 2);
INSERT INTO 'dancecrib' VALUES (1974, '2012-01-22 19:29:12.773318+00', '2021-02-10 11:04:00.38584+00', 10308, 1, NULL, 'ace', '1–::

  1c cross | cast ; ½ Fig 8 Rsh round 4cnr to face 1cnr

9–::

  »Corners pass and Turn« with 1cnr and pass Rsh ; repeat with 2cnr, finish BtoB in centre, M facing up, W down

17–::

  DTr, but on [19-20] and [23-24] the cnrs dance to next place clw, 1c finish in centre facing own side

25–::

  1c+1cnrs ½ DiagReel4 ; Repeat on 2diag (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14316, '2021-09-15 21:52:32.98184+00', '2021-09-16 19:48:21.846852+00', 20490, 1, 202, 'ace', '1--::
  1c set | cast off (2c up) ; ½ Fig8 up round 2c (2,1x,3)
9--::
  Circle6 and back (2,1x,3)
17--::
  1c+3c Set&Rotate (2,3,1x)
25--::
  All set | 1c (+3c who dance down to follow) lead up to top ; 1c cross and cast to 3pl _while{4}_ 3c following 1c cast to 2pl (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (9870, '2017-05-20 01:32:32.742918+00', '2018-02-03 18:40:08.967637+00', 16476, 1, 202, 'ace', '1--::

 1c+2c S&Rotate (2,1,3)

9--::

 Parallel Reels3, 1c Rsh to 2c, finishing in 1diag, LHJ to P, RHJ to 1cnrs

17--::

 BiL | 1c turn LH 1 ¼ finishing in 2diag, RHJ to 2cnrs | BiL

25--::

 Reels3{6} across, 1c Lsh to 3cnrs | 1c cross to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2124, '2012-01-22 19:29:21.370546+00', '2014-04-30 23:23:47.686008+00', 1799, 1, NULL, 'ace', '1–::
  Rsh Reels3 on the sides
9–::
  1c lead down the middle and up (1,2,3)
17–::
  1c+2c Allemande, finishing in lines across, 1W between 2c facing 1M between 3c
25–::
  All set | All set, 1c moving to 2pl ; all set twice (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (2121, '2012-01-22 19:29:21.228781+00', '2020-12-06 10:58:52.071535+00', 1790, 1, NULL, 'ace', '1–::

  1M+2W & 1W+2M turn RH 1½ to finish (2,1x,3) ; 2c turn LH to 1pl _while{4}_ 1c turn LH 1½, to face up NHJ in middle

9–::

  1c dance up to the top (2c down) | set ; cast off (2c up) | turn BH to face 1cnrs

17–::

  1c set to and turn cnrs, (to 2,1x,3)

25–::

  All A&R ; 1c Turn BH 1½ to 2pl.', 3);
INSERT INTO 'dancecrib' VALUES (10929, '2018-07-29 04:48:12.592204+00', '2021-05-09 13:32:44.850314+00', 18487, 1, 202, 'ace', '1--::
  1c+2c & 3c+4c S&Link ; RHA (2,1,4,3)
9--::
  Reels4 on sides (2,1,4,3)
17--::
  All set | 1c & 3c turn P RH ¾ into midline, M(W) facing up(dn) | set to P ; turn P LH ½ into tandem facing up 
25--::
  Parallel Reels3 in tandem across ( (with lead change), 1c(3c) LSh to 2M(4M) (2,1,4,3)
33--::
  1c+4c+3c 3C Knot (2,3,4,1)', 5);
INSERT INTO 'dancecrib' VALUES (14390, '2021-10-14 15:33:15.007572+00', '2021-10-14 15:37:38.321924+00', 20509, 1, 202, 'ace', '1--::

  1c lead down (2c up) | face P and set ; turn P RH 1½ to 2plx and face out (2,1x,3)

9--::

  All chase clw ½ (to 3x,1,2x) ; ½ Reels3 on sides, 1c RSh to 3cnrs[pos] (2x,1,3x)

17--::

  3C diagonal R&L (3,1,2)

25--::

  3c+1W & 1M+2c RHA ; ½ Reels3 on sides, 1c RSh to 4cnrs[pos] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11532, '2019-01-20 23:38:58.492431+00', '2021-11-08 19:07:35.727668+00', 19166, 1, 202, 'ace', '1--::

  All Turn Halfway and Cast ; chase clw ½ (3,2,1)

9--::

  2c+1c Tourbillon (3,1,2)

17--::

  1c »Figure of Love« [1c loop LSh round 1cnrs[pos] to centre, touch P BH, pull LSh

back to face opp sides, loop LSh round 2cnrs[pos] to original places] (3,1,2)

25--::

  Reels3 across, 1c LSh to 1cnrs[pos] (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (2115, '2012-01-22 19:29:20.912152+00', '2016-11-21 17:01:03.755671+00', 1777, 1, NULL, 'ace', '1–::

  Mirror Reels3 on the sides (1c cast off, 2c cross up LH, 3c join NH facing down and cast up), all c touch hands when possible, at end 1c&3c dance to own place NHJ and turn inwards so 1c faces 3c NHJ (12x,3)

9–::

  All set | all circle6 L ; all M turn W on their right BH | continue circle6 (to 1,2x,3)

17–::

  1c+2c RHA ; 1c cast off one and lead up to 1pl _while_{4} 2c lead up, cross, cast off and meet P, ready for

25–::

  1c+2c Allemande (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (2126, '2012-01-22 19:29:21.47948+00', '2019-08-07 17:20:48.585285+00', 1816, 1, NULL, 'ace', '1–::

  1c+2c turn RH ; set, 1c cast off one _while_{2} 2c dance up

9–::

  2c+1c+3c Reels3 in sideline (1c crossing down RH) (to 2,1x,3)

17–::

  1c cross RH and cast R round 3cnr to meet partner up/down the set _while_{4} 2c & 3c set diagonally and ½ RHA (to opposite corner) ; 1c 1½ LH turn _while_{4} 3c & 2c chase ½ round clw

25–::

  1c+1cnrs ½ diagonal Rsh Reels4, 1c pass Rsh ; repeat with 2cnr

33–::

  3c+1c+2c turn RH ; chase ½ clw.', 2);
INSERT INTO 'dancecrib' VALUES (9505, '2016-11-30 03:00:58.577536+00', '2017-04-24 13:59:12.188633+00', 17483, 1, NULL, 'ace', '1--::  1c+2c Espagnole, 1c finish facing 1cnr

9--::  1c+1cnrs pass, cnrs turn BH ½, and cast away as 1c meet and pass Rsh ; repeat with 2cnrs (3x,1x,2x)

17-- ::  All set | All C turn BH ½ ; All twirl R to sidelines | All set (3,1,2)

25--::  3c Turn BH _while{4}_ 1c+2c S&Link ; 3c+2c S&Link _while{4}_ 1c Turn BH (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (11484, '2019-01-01 01:58:09.461098+00', '2023-02-04 01:23:10.479859+00', 18965, 3, NULL, 'ace', '1-8::
    1s make arch & 2s lead up under arch & cast back to place; 2s & 3s
    dance RH across
9-16::
    4s make arch & 3s dance down under  & cast back to place; 2s & 3s
    dance LH across
17-24::
    1s cast off to bottom (4 bars); 2s+3s+4s make arches, 1s dance up to
    top under the arches
25-32::
    1s followed by 2s+3s+4s cast to bottom; 1s make arch & 2s+3s+4s
    dance under to new places 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14820, '2022-05-09 06:55:58.567359+00', '2022-08-31 07:10:51.479071+00', 20807, 1, 202, 'ace', '_Strathspey_
1--::
  1c cast off (2c up) | cross RH ; dance RSh round 1cnrs | turn P RH to face 1cnrs
9--::
  1c set to and turn 1cnrs RH, 1c finishing facing P on 1diag  ; 1c & 1cnrs set | 1c turn P RH to face 2cnrs
17--::
  1c+2cnrs set | 1c turn 2cnrs RH to 2plx ; 1c ½ Fig8 R round 3cnrs (2,1,3)
25--::
   1c+3c Poussette (2,3,1)

_Reel_
33-64::
  Repeat [1-32]. 1c will finish straight to 4pl having danced a Poussette in reel time.  

Repeat S32+R32 three more times.', 5);
INSERT INTO 'dancecrib' VALUES (9859, '2017-05-16 08:38:32.568965+00', '2019-12-19 00:19:37.644915+00', 10654, 1, 202, 'ace', '1--::
 1M+2W set | cross RH ; 1W+2M repeat (2x,1x,3,4)
9--::
 2c+1c S&Rotate (1x,2x,3,4)
17--::
 1c&4c cross | cast (2c&3c step out) | 1c+4c ½ RHA | 1c+4c set
25--::
 Parallel Reels4 (2x,4,1x,3)
33--::
 2c & 1c ½ Fig8 down RH (to 2,4,1,3) ; 4c+1c+3c ½ mirror Reels3, 1c start in and up, on [39] 4c touch NH briefly, on [40] 4c turn toward each other and face 1c both C in middle NHJ ready for
41--::
 1c+4c »Half Rondel« [: 3 bars of Rondel in {4} ; all set to P | cross RH] (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (9979, '2017-06-25 23:59:02.806086+00', '2017-06-26 00:02:08.284159+00', 17880, 2, NULL, 'ace', '1-8::

  1L + 2M set and change places RH, while 1M + 2L change places RH and set. Then 1L + 3L set and change  places LH while 1M + 3M change places LH and set, 1L stays facing out. 



9-16::

  1C (lady I front) casts behind 3M into 2nd place, 3C stepping down on 11, 12. 2C, 1C and 3C then dance a half reel of three in the sidelines, 1C giving Rsh to 2C to begin. All finish on opp. sides. 



17-24::

  3C, 1C and 2C adv 1 step, ret 1 step, then 3C and 2C set while 1C with two setting steps pass each other by the left shoulder, to finish back to back in the center facing their 2nd corner (person). They then dance a diagonal half reel of 4, finishing in lines across, the men at the top facing down, the ladies at the bottom facing up. 



25-32::

  Bars 17 - 24 are repeated all finishing in the sidelines in the order 2, 1, 3. 

', 5);
INSERT INTO 'dancecrib' VALUES (14163, '2021-07-21 10:14:03.373373+00', '2021-07-21 10:14:03.373373+00', 19545, 2, 10819, 'ace', '1-4:: 1s cast into 2nd place (2s step up on bars 3+4).
5-8:: 1s TR to face out _while_ 4s set, then cross up left hand to finish with 4M behind 1L and 4L behind 1M, facing out.
9-16:: RS tandem reels of three on the side lines with 1M+4L and 1L+4M; 4s shorten their reels to end between couples, 4M facing down, 4L facing up 
17-24:: 2s+3s: set and rotate reverse (chase 1 place clockwise, XR with partner on sidelines, chase 1 place clockwise, set turning on the spot)
	_while_ 1s cast around third corner and tulloch turn 1 3/4 to sidelines own side _while_ 4s tulloch turn 1 3/4 to own sidelines, cast around third corner pos.
25-28:: 1s+4s half RA, 1s cast into 4th place _while_ 4s keep hands and TR 3/4 to sidelines. At the the end of bar 28, all clap.
29-32:: 1s+4s XR to own sides, all join hands on the sideline and set.', 5);
INSERT INTO 'dancecrib' VALUES (2136, '2012-01-22 19:29:21.983016+00', '2019-03-19 09:38:05.45712+00', 1854, 1, NULL, 'ace', '1–::

  1c+3c Reel4, the W pass Lsh to start and loop at the ends

9–::

  2c+4c repeat

17–::

  1c+4c & 2c+3c RHA ; LHA

25–::

  1c+3c R&L

33–::

  2c+4c L-Chain

41–::

  All W RHA, to places ; all M RHA finish with twirl in middle facing P

49–::

  All C set twice ; turn 1¾ BH opening into

57–::

  Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (8158, '2014-01-15 14:52:31.116988+00', '2014-11-12 14:07:52.127762+00', 13740, 1, NULL, 'ace', '1--::

  1c+2c ½ RHA | 1c+3c ½ LHA _while{2}_ 2c cross RH ; 1c+4c ½ RHA _while{2}_ 3c cross RH | 1c+4c cross RH

9--::

  1c cross up | cast up behind 3c ; cross up and cast off (3c+4c down) (2,1,3,4)

17--::

  2c+1c & 3c+4c DblFig8, 1c&3c cross to begin

25--::

  1c+3c R&L

33--::

  1c dance between 3c and cast to 4pl (3c+4c up) ; All turn P RH twice (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2137, '2012-01-22 19:29:22.029464+00', '2017-02-14 16:25:36.543012+00', 8981, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; cross RH between 3c and cast up to 2plx

9–::

  1c set | turn LH ¾ ; 1W+2c & 1M+3c RHA, finish facing 1cnr

17–::

  1c set to and turn cnrs, finish (2,1x,3)

25–::

  All circle6 L {6} | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2125, '2012-01-22 19:29:21.42398+00', '2021-06-13 08:58:33.841038+00', 1804, 1, NULL, 'ace', '1–::

  1c+2c half Espagnole: both W RHJ lead across to M side, cross and cast back _while{4}_ Men cross to W side, cast in, lead RHJ back to M side and cross (to 2,1) ; 1c turn LH 1¼ to face 1cnr

9–::

  1c set to 1cnr | to 2cnr | to 3cnr | to 4cnr, finish facing opp. side

17–::

  2c+1W & 1M+3c RHA (1c to own sideline) ; 2c+1M & 1W+3c LHA

25–::

  1c set | cast off (3c up) ; 2c+3c+1c turn P BH', 3);
INSERT INTO 'dancecrib' VALUES (2135, '2012-01-22 19:29:21.938082+00', '2014-04-30 23:23:47.883221+00', 7694, 1, NULL, 'ace', '1–::
  All S&Link3 ; S&Link3 (to 3x,2x,1x)
9–::
  2c followed by 1c progressive Fig8 up through 3c (cross up, cast, cross up, cast to exchanged places) (3x,1x,2x)
17-28::
  3c+1c+2c 3-couple R&L (all cross RH | 1M+2M & 3W+1W (on sidelines) & 3M+2W (2nd diag.) change places LH ; repeat twice to places)
29-32::
  All Set and Cross RH. (to 3.1.2)', 2);
INSERT INTO 'dancecrib' VALUES (2138, '2012-01-22 19:29:22.107512+00', '2017-04-23 22:57:09.394776+00', 1857, 1, NULL, 'ace', '1–::

  2c, with 1c following, cross between 3c, cast up, cross down between 3c again, and cast up to (2,1,3)

9–::

  2c+1W & 1M+3c RHA, 1c pass Lsh to face 2cnr ; ½ Reel4 with 2cnrs, 1c finish in centre, Lsh joined, M facing down, W up

17–::

  1M+2c (on M side) & 1W+3c (on W side) RHA ; 1c+1cnrs ½ Reel4, at end 1c swivel R to finish BtoB, M facing down, W up

25–::

  3c+1W & 1M+2c Circle3 L {3}, opening (1c leading) into Circle6 L {3} | 1c cross RH (2,1,3)



{{explanation}}

On second turn, 1c cross to 4pl on [31-32] as 4c cast up to 3pl.', 3);
INSERT INTO 'dancecrib' VALUES (3779, '2013-07-13 15:56:04.30878+00', '2016-07-15 12:52:33.946172+00', 14560, 1, NULL, 'ace', '{{explanation}}

For children, any number of C in circle, #1 on the L, #2 on the R, all face centre



1–::

  All Circle L and back

9–::

  All A&R

17–::

  All spring points R R L L R R L L ; face P and clap 4 times | change places with P RH

25–::

  All clap 8 times ; All chase clw', 3);
INSERT INTO 'dancecrib' VALUES (12834, '2020-05-16 17:48:10.199513+00', '2021-05-08 22:27:43.893905+00', 19976, 2, 1645, 'ace', '1-4:: First couple dance Covid Turn: half turn with both hands, a loop to the left releasing hands, half turn with both hands, a loop to the left releasing hands.

5-8:: First and second couples dance half Covid Circle: circle to the left, a loop to the left releasing hands, circle to the left, a loop to the left releasing hands.

9-10:: First and second couples set: first man and second woman on the side, first woman and second man across the dance.

11-12:: First and second couples set: first man across the dance facing down, second woman across the dance facing up, first woman and second man on the side facing out. All finish facing in, turning to the left.

13-14:: First and second couples one step forward and one step backward: first man and second woman on the lines, first woman and second man across the dance.

15-16:: First and second couples one step forward and one step backward: first man and second woman across the dance, first woman and second man on the lines.

17-20:: First and second couples half Schiehallion Reel: all the four dancers start the Schiehallion as usually done by men. All finish in the original place.

21-24:: First and second couples set on the diagonal, one step forward and cast to place by the right.

25-32:: First and second couples half circle to the left (2 bar), half right hand across (2 bar), change place with the partner with right hand (2 bar) and half circle to the left (2 bar) to progress.

:: *Instructions from the youtube video*', 2);
INSERT INTO 'dancecrib' VALUES (10542, '2018-03-21 12:36:08.234197+00', '2019-02-09 16:14:27.834953+00', 12345, 1, 202, 'ace', '1--::

  All set twice ; all M RHA, M in centre facing P at end

9--::

  All turn P BH twice, M in centre again ; all M LHA, to places facing P

17--::

  Gr-Chain

25--::

  Circle8 L{2} | A&R{1+1} ; all Pivot R and chase clw ½ (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (8123, '2013-11-27 02:44:25.096391+00', '2017-08-28 23:02:58.919344+00', 2531, 1, NULL, 'ace', '{{explanation}}

Start (1,2,3x,4x) 



1–::

  1c & 4c cross (quick RH) towards centre, dance out between 2c and 3c (give quick LH), and cast to opposite end (4,2,3x,1x) ; repeat to (1,2,3x,4x)

9–::

  2c+3c pass RH on sides, cast behind end couple and cross LH ; cast inwards | ½ RHA and face out (1,2,3x,4x)

17–::

  2c+3c cast to own end and stand _while_{8} 1c+4 turn RH moving inwards to meet ; ½  RHA | turn P RH ¾ to line of 4 on midline (the M BtoB in the middle)

25–::

  4c+1c ½ Reel4 on midline : continue into chase clw inside the set to (2,4,1x,3x)

33–::

  All set | set adv. ; set, the W turning under the M''s arm | turn P RH into

41–::

  Circle8{3}, swivel R foot over L ; Circle8 back (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (2134, '2012-01-22 19:29:21.883781+00', '2019-03-11 11:10:52.37815+00', 5693, 1, NULL, 'ace', '1–::

  1W followed by all W cross at top, cast behind opposite line, cross back at bottom and up to places

9–::

  Men repeat

17–::

  All Circle8 and back

25–::

  All C (NHJ) A&R ; 1c lead to 4pl (2c+3c+4c up)', 3);
INSERT INTO 'dancecrib' VALUES (2128, '2012-01-22 19:29:21.584974+00', '2019-05-01 20:45:29.03725+00', 1834, 1, NULL, 'ace', '1–::

  1c+2c+3c Rsh reel3 on the sides

9–::

  1c+2c+3c RHA (6H !) ; LHA

17–::

  1c lead down the middle (2c up on 19-20) ; and up to face 1cnrs

25–::

  1c set to and turn corners (2,1x,3)

33–::

  2c+1c+3c A&R ; 1c turn RH 1½.', 3);
INSERT INTO 'dancecrib' VALUES (12490, '2020-01-10 09:27:11.831197+00', '2020-01-10 09:30:38.910582+00', 19731, 1, 202, 'ace', '1--::

  1c set | turn BH and face down NHJ ; 1c dance down between 3c | cast up to 2pl (2c up) (2,1,3)

9--::

  1c set advancing and pass LSh to face 1cnrs | 1c turn 1cnrs BH ¾ into facing lines3 across ; all set. Cnrs face P | 1c Petronella turn to 2plx _while{2}_ 2c & 3c cross RH (2x,1x,3x)

17--::

  1c set advancing and pass LSh to face 3cnrs[pos] | 1c turn 3cnrs[pos] into lines3 across and face own sides ; ½ Reels3 across, 1c RSh to 3cnrs[pos]. All face clw

25--::

  All chase clw ½ into facing lines3 across, 1W between 3c in 1pl facing 1M between 2c in 3pl ; 3C S&Link (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (2148, '2012-01-22 19:29:22.602883+00', '2015-02-26 16:13:14.995327+00', 1884, 1, NULL, 'ace', '1–::

  1c+2c circle4 and back

9–::

  1c face 2c & 3c face 4c, all set | change places RH ; all set | change back RH (2M+4M face out and up) (1,2,3,4)

17–::

  1M+2c & 3M+4c Lsh Reels3 across, the M taking P in promhold on [20] ; 1c+3c finish on M side in promhold facing in and down

25–::

  3c with 1c following dance between 4c, divide & cast up ; 3c cross up between 2c and cast to 3pl (2c up) _while_{4} 1c dance on up and turn LH to face 1cnr

33–::

  1c turn 1cnrs RH, pass Rsh (cnrs dance 4 bars) ; 1c turn 2cnrs LH, to 2pl facing up NHJ (2,1,3,4)

41–::

  1M+2M+3M LHA _while{4}_ 1W+2W+3W RHA ; 1c breaks to dance down NHJ and 3c follows into ; 1M+3M+4M RHA _while{4}_ 1W+3W+4W LHA (to 2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12951, '2020-07-03 16:59:34.577678+00', '2020-07-07 08:44:24.893927+00', 2002, 1, 202, 'ace', '1--::
  1W  &  2M  set  |  cross  RH  ; 1M & 2W set | turn LH ¾ (a bit more) _while{4}_  1W  &  2M  chase clw ¾ outside into line4 across, 1M & 2W BtoB in centre facing person same sex
9--::
  Reel4 across. On [15-16] 1M & 2W pass RSh to sides (2,1,3)
17--::
  2c+1c RHA ; LHA (2,1,3)
25--::
  1c+3c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2143, '2012-01-22 19:29:22.339881+00', '2016-11-15 15:35:15.015148+00', 1866, 1, NULL, 'ace', '1–::

  1c set | cast off two ; lead to the top, cross and cast off (2c up) to (2,1x,3)

9–::

  2c+1c+3c Circle6 and back, 1c finish facing 1cnr

17–::

  1c set to and turn corners

25–::

  Opposing Lsh Reels3{6} on the sides | 1c cross to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8899, '2015-09-09 13:54:11.603526+00', '2015-09-09 13:54:11.603526+00', 16733, 2, NULL, 'ace', '1-8::

  1C2C set, 1C cast as 2C cross up to face out ;

  Half double fig. 8 - 1C cross up, 2C cast off to begin.

 ( 2 1x 3)

9-16::

  Mirror Reel3 on sides. 1C in & down to begin.

 13-14 :- 1C cross up and complete the reel on own sides.

17-24::

  Half Lsh Reel3 across - 1L2C and 1M3C ;

  1C turn LH.

25-32::

  Half Rsh Reel3 across - 1L2C and 1M3C ;

  1C turn RH.', 2);
INSERT INTO 'dancecrib' VALUES (2152, '2012-01-22 19:29:22.807345+00', '2014-04-30 23:23:48.15111+00', 12940, 1, NULL, 'ace', '1–::
  1c+2c turn RH ; Turn LH
9–::
  1c+2c RHA, finish holding P with RH ; 2c+ 1c following lead down the middle
17–::
  1c+2c RHA, finish holding P with RH ; 1c+2c following lead up the middle
25–::
  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (14164, '2021-07-21 10:14:49.535651+00', '2021-07-21 10:14:49.535651+00', 19726, 2, 10819, 'ace', '1-4:: 1s TR
5-8:: 1s cast down (2s step up on bars 5+6), then TL 3/4 to face 2nd crnrs
9-16:: "Reverse" CPCP: TR with 2nd crnrs, 1s TL 3/4, TR with 1st crnrs, 1s TL 3/4 to face 4th crnrs
17-20:: 1/2 reels of 3 across (RS to 4th corner), finishing on own side 2nd place, 1L facing down, 1M up
21-24:: 1/2 reels of 3 on own sides (LS to 3rd crnr), finishing in 2nd place on own side
25-32:: Diagonal RL', 5);
INSERT INTO 'dancecrib' VALUES (2142, '2012-01-22 19:29:22.28933+00', '2021-03-23 21:36:55.271937+00', 7696, 1, NULL, 'ace', '1–::

  1c+4c set | dance to middle (2c+3c step to end) ; 1c+4c Circle4 L, finish (swivel R) BtoB in the centre facing the person in his/her starting position (2,1,4,3)

9–::

  All set | change places RH ; Intersecting ½ Diag Reels4 (to 4x,3x,2x,1x), with 3c+2c in the middle facing diag out

17–::

  Repeat from new places (2,1,4,3)

25–::

  1c+4c dance out between 2c & 3c, cast round them and meet ; 1c dances under arch by 4c, 1c dance between 3c and 4c between 2c, and cast round that couple to (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2144, '2012-01-22 19:29:22.391936+00', '2020-12-19 14:12:57.678336+00', 8116, 1, NULL, 'ace', '1–::

  1c set, cast (2c up) ; 2c+1c+3c set, 1c turn ¾ RH to 1cnrs _while{2}_ 2c+3c cross LH

9–::

  Lsh ½ Reel4 on 1diag, 1c pass Lsh ; Rsh ½ Reel4 on 2diag (to (3,1x,2)

17–::

  1c ½ Petronella, on [23-24] All set {1} all set advancing {1} into

25–::

  3c+1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2157, '2012-01-22 19:29:23.035765+00', '2021-06-12 18:25:11.896266+00', 1908, 1, NULL, 'ace', '1–::

  1c cast off behind own lines ; cast back to places

9–::

  1c lead down {3}, up {3} | cast off and cross to 1cnrs (2c up)

17–::

  Turn CPCP, finish 1M below 1W in the middle facing W side

25–::

  1c dance out NHJ between 2W & 3W, cast round them to meet in the middle ; dance out on M side, cast as before to 2pl', 2);
INSERT INTO 'dancecrib' VALUES (2151, '2012-01-22 19:29:22.745419+00', '2016-06-23 20:28:47.559264+00', 8113, 1, NULL, 'ace', '1--::

  1c+3c set | cross down RH (2c+4c up) for ; All set in Double DTr | 1c+3c turn 1cnr RH, finish on midline facing P, cnrs in places

9--::

  Reel4 on midline, finish 1c (W above M) facing W side and 3c (W above M) facing M side 

17--::

  2c+1W & 3M+5c Rsh reels3 across at the ends and 1M+4c+3W Reel4 across in the middle, finish with 1M behind 1W facing W side and 3W behind 3M facing M side (2,1,4,3,5)

25--::

  1W (1M follows) + 3M (3W follows) cast off (4c+5c up) and cross ; turn P 1½ (1c RH, 3c LH) to (2,4,1,5,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10541, '2018-03-21 11:53:38.543398+00', '2018-03-21 12:12:38.373137+00', 12157, 1, 202, 'ace', '1--::

  2W+1c & 2M+3c RHA, 2c ending in centre Lsh to P facing opposite sides ; Lsh »Snake Pass« [unwind the RHA, 2c leading, pass other snake Lsh through 2plx and chase cclw], 2c ending in centre BtoB, 1M(1W) facing up(dn) (3,2,1)

9--::

  All set as in DTr | 2c 6 bars of Reels3 across, 2c start Rsh to 2cnrs (3,2,1)

17--::

  2c turn P RH ¾, cast R and chase chase clw to 2plx _while{8}_ 3c+1c set | change places RH ; set to P | cross RH (1x,2x,3x)

25--::

  All set | 1c+2c ½ RHA _while{2}_ 3c cross RH (to 2,1,3) ; 1c+3c S&Link (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3778, '2013-07-13 15:56:04.113339+00', '2019-04-20 22:09:56.499456+00', 14561, 1, NULL, 'ace', '{{explanation}}

For children, any number of C in circle, #1 on the L, #2 on the R, all face centre



1–::

  All Circle L ; and back

9–::

  All 1s A&R ; All 2s A&R

17–::

  All spring points R R L L R R L L ; face P and clap 4 times | change places with P RH



{{explanation}}

Repeat with new partner', 3);
INSERT INTO 'dancecrib' VALUES (2166, '2012-01-22 19:29:23.495979+00', '2015-12-12 23:19:26.892352+00', 12793, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; cross down LH between 3c and cast up (2,1,3)

9–::

  2c+3c petronella to midline and set ; 1c petronella to midline, 1W finishing between 2c facing down and 1M between 3c facing up | all set

17–::

  2W+1W, 2M, 3W, 1M+3M dance Reel4 on midline, the tandem pairs changing lead at the ends, 2M & 3W don''t pass last Lsh but curve in to finish BtoB, all W facing up, M down

25–::

  All chase clw to own side (3,1,2) ; All turn P RH', 3);
INSERT INTO 'dancecrib' VALUES (2154, '2012-01-22 19:29:22.907686+00', '2014-11-05 23:23:41.8224+00', 12848, 1, NULL, 'ace', '1–::

  1c Fig8 on own side (start in and down ; take NH where possible).

9–::

  1c+2c+3c Mirror Reels3 on own sides (2c start out & up)

17–::

  1c dance down middle {3}, up {3}, and cast off (2c up)

25–::

  Teapots R ; and L (1M+3c & 1W+2c RHA, 1c pass Rsh ; 1M+2c & 1W+3c LHA)  (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2159, '2012-01-22 19:29:23.12735+00', '2014-07-16 11:11:37.880004+00', 1916, 1, NULL, 'ace', '1–::

  2M+1W Turn RH ; 1c Turn RH ¾ (2c up), into facing lines of 3 across, 1W(1M) between 2c(3c)

9–::

  Set in lines across, 1c petronella R on second step, to between corners | set on sidelines ; 1c set to P | turn BH ½

17–::

  2c+1c+3c circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2163, '2012-01-22 19:29:23.366561+00', '2016-04-18 23:47:53.665334+00', 1927, 1, NULL, 'ace', '{{explanation}}

The original is a 16 bar dance, two steps per bar ; the music has been rewritten to 32 bars, so the dance is now a normal 32 bar reel



1–::

  All four C set twice ; cross Rsh

9–::

  Repeat

17–::

  All C, facing the top, A&R, turn partners RH

25–::

  1c set, cast off one (2c up), and turn P RH



{{explanation}}

All 4 couples dance the first 24 bars on each turn of the dance, though the progression is the normal one for a 3c set', 2);
INSERT INTO 'dancecrib' VALUES (2162, '2012-01-22 19:29:23.325208+00', '2014-04-30 23:23:48.330732+00', 14269, 1, NULL, 'ace', '1–::
  1c cross RH | cast off (2c up) ; cross RH | cast R into facing lines across (1M above, 1W below)
9–::
  All A&R {1+1 step} | cross up/down RH ; repeat, at end all face P
17–::
  1C cross up/down RH | cast R to 2pl ; turn RH
25–::
  All circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10543, '2018-03-21 14:17:12.532594+00', '2018-03-21 14:23:07.929892+00', 12346, 1, 202, 'ace', '1--::

  1c+3c DblFig8 round 2c, 1c cross down to start (1,2,3)

9--::

  2c Fig8 R, Lsh to 1cnrs to start (1,2,3)

17--::

  1c+2c S&Link ; 1c+3c S&Link (2,3,1)

25--::

  Gr-Chain, 1c cross to start', 2);
INSERT INTO 'dancecrib' VALUES (10250, '2017-11-11 20:17:18.433008+00', '2017-11-11 20:17:18.433008+00', 8151, 2, 2847, 'ace', '1-8:: Each couple in waltz hold dance a small square in their own space as follows: Man 2 steps to the Left (Lady to the Right)  ; Man 2 steps Back (Lady Forward)  ; Man 2 steps Right (Lady to the Left)  ; Man 2 steps Forward (Lady Back) 
9-12:: Couple half turn to end back to back touching hands; half turn again to face each other and touch hands 
13-14:: Couple take both hands and step in towards each other with Man stepping more to the Right so that Lady moves slightly more to his Left side 
15-16:: Couple step away from each other then Man turns Lady under his Left arm to exchange places (Lady ends with her back to centre of the circle) 
17-20:: Repeat bars 13-16 to end in original places (i.e. with Man''s back to the centre) 
21-24:: Man steps to Left (Lady to Right) , crosses Right foot (Lady Left), points Left foot (Lady Right), and closes Left foot to the Right (Lady closes Right foot to Left) 
25-28:: Man and Lady repeat bars 21-24 in opposite direction 
29-32:: Each couple do 2 waltz turns, or 3 if they are up to it, progressing anticlockwise as they waltz.', 0);
INSERT INTO 'dancecrib' VALUES (2554, '2012-01-22 19:29:47.436651+00', '2016-12-03 08:19:25.948852+00', 3418, 1, NULL, 'ace', '1–::

  1c set | cast to 2pl (2c up) ; 1c set to 1cnrs | change places with them RH and face along side (with polite turn).

9–::

  1W+3W & 2M+1M set to each other | change places LH ; 1c turn RH 1½ to 2pl.

17–::

  1c set to 2cnrs | change places with them RH ; 1M+3M & 2W+1W set to each other | change places LH (3x,1x,2x).

25–::

  3c+1c+2c A&R, ½ circle6 L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2147, '2012-01-22 19:29:22.56072+00', '2016-06-15 10:38:07.428085+00', 1883, 1, NULL, 'ace', '1–::

  All set and cross Rsh ; repeat (all four cpls dance at each repetition)

9–::

  1c lead down the middle (2c up) and up to 2pl in middle

17–::

  1c (alone) allemande inside the set, to face 1cnr (2c up) ; set to 1cnr | set to 2cnr

25–::

  Reels3{6} on the sides Rsh to 2cnr | 1c cross to 2pl.   (2,1,3,4)



{{explanation}}

Repeat from 2pl, finish (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2160, '2012-01-22 19:29:23.205516+00', '2021-03-15 22:23:59.129091+00', 8668, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; turn 1¼ LH | cast Lsh round 1cnr to 2plx (2,1x,3)

9–::

  Reels3 on the sides, 1c Rsh to 2cnr, and finish on diagonal facing 1cnr

17–::

  1c SetH&G (to 2,1,3)

25-28::

  2c+1c+3c turn RH

29-40::

  2c+1c+3c R&L for 3 couples.

', 2);
INSERT INTO 'dancecrib' VALUES (8868, '2015-08-26 20:33:49.223043+00', '2021-11-09 23:38:33.778243+00', 13892, 2, NULL, 'ace', '1 - 8::  1s set to 2s & 1M+2M turn RH as 1L+2L turn LH, 1s dance down & turn 3s (M RH & L LH) _while_ 2s dance up & set
9-16::  2s+1s+3s dance reels of 3 on sides, crossing to opposite sides as they dance up to 1st pl (1s on 9, 3s on 11, 2s on 14/15) (2)(1)(3)
17-24::  All set, petronella turn into centre, set & turn RH to finish ready for
25-32::  2s+1s+3s dance Allemande 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (11750, '2019-03-31 12:48:58.419565+00', '2019-03-31 16:21:34.583221+00', 19063, 1, NULL, 'ace', '1--::

  1c turn RH | cast off (2c up) ; 2c+1W & 1M+3c RHA

9--::

  2c+1M & 1W+3c LHA ; Rsh Snake Pass [wheels unwind, 1c leading the other two through 2plx, and all chase clw, crossing in 1pl and 3pl] to finish (3,1,2,4)

17--::

  1c+2c ½ RHA (3,2x,1x,4); 3c & (2M+1M) & (2W+1W) & 4c turn BH into a square set, facing in NHJ

25--::

  All set to corners | all La Baratte with corners (to positions 2x,3,4,1x if described as a longwise set)

33--::

  All set | 2c & 1c Turn P 1½ _while{4}_ 3c+4c RHA into longwise set |All set (2,3,4,1)



', 3);
INSERT INTO 'dancecrib' VALUES (9980, '2017-06-27 17:53:12.73512+00', '2017-06-28 16:52:46.402054+00', 17793, 1, 202, 'ace', '1--::

 1c Fig8 on sidelines, 1c dance down between *2c & 3c* to start, to 2pl (2c up on [7-8]) (2,1,3,4)

9--::

 All A&R twice

17--::

 1c+3c S&Link ; 1c+4c S&Link (2,3,4,1)

25--::

 2c+3c & 4c+1c RHA ; LHA

33--::

 1c dance up, cast off round 4c to 4pl ; 1c turn RH', 2);
INSERT INTO 'dancecrib' VALUES (2178, '2012-01-22 19:29:24.082415+00', '2020-08-30 09:40:16.136411+00', 1972, 1, NULL, 'ace', '1–::

  1c+2c+3c circle 6 and back, finish 1c facing down NHJ

9–::

  1c set, dance between 3c and cast up to 1pl in the middle

17–::

  1c (2c dance up and follow) lead down the middle and up (to 2,1,3)

25–::

  1c fig8 up round 2c', 2);
INSERT INTO 'dancecrib' VALUES (2172, '2012-01-22 19:29:23.800508+00', '2019-03-05 20:57:14.054691+00', 9004, 1, NULL, 'ace', '1–::

  1c+2c Poussette (1,2,3)

9–::

  1W+3M set advancing to face P on 1diag. | 1c+3c ½Reel4 | all continue to exchanged places on own sides (3,2,1)

17–::

  2c+1c RHA, finish facing down/up ; half G-Chain (3c cross to start) (1x,2x,3x)

25–::

  All set | 1c cast to 2plx _while_{2} 2c cross up _while_{2} 3c cross RH ; 1c cross RH and cast off (3c up) (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2180, '2012-01-22 19:29:24.176152+00', '2023-02-09 12:13:35.130427+00', 1983, 1, NULL, 'ace', '1–::

  1W+2M cast (Rsh back) to meet in middle ; turn RH 1½ to exchanged places

9–::

  1M+2W repeat (Lsh and LH) (to 2x,1x)

17–::

  All C cross RH to own side (loops) ; turn LH

25–::

  Circle4 and back', 3);
INSERT INTO 'dancecrib' VALUES (9080, '2016-01-21 20:04:52.734605+00', '2021-04-07 20:29:22.731552+00', 2632, 2, 1007, 'ace', '1-8::

  All Grand Chain (RH to partner to begin)

9-12::

  1s lead down middle through 3rd place, while the other 3 couples dance up on the sides (3s dividing to their nearer side) to follow 1s. Side couples meet the person standing opposite them to begin, i.e 4M meets 2L and 2M meets 4L.

13-16::

  Each pair in turn divide at bottom and dance up on nearer side to finish in 2 lines of 4 facing inwards.

17-24::

  All set (joining nearer in lines) and cross with RH with opposite person

  1/2 reel of 4 (the 2 in the inside of each line turn to their R to face nearer end, all pass R to begin reel)

25-30::

  Allemande in 2 group of 2 pairs, (To begin the Order of pairs from top to bottom, 3M + 3L facing diagonally down, 2M + 4L facing diagonally, 4M + 2L facing diagonally down, 1M + 1L facing diagonally up. The 2 pairs facing up and the 2 pairs facing down dance together) each pair dances diagonally R and travel round the set in an anti-clockwise direction for 4 places, all turning to L on 5th step to finish in 2 lines up and down set, all facing middle, all move into middle M bring L across in front to face him on 6 (order 2L + 4M, 1M + 1L, 3L + 3M, 2M + 4L)

31-32::

  Criss-cross to place (each M releasing RHs, passes the L he is holding by L on bar 31, the passes the next L he meets by R, all travelling into original places, on the last step the ladies travelling CW on the outside of circle)



Repeat with each couple in turn leading through the opposite place on bar 9 and following the same routine but from a different alignment.', 0);
INSERT INTO 'dancecrib' VALUES (14444, '2021-11-09 09:25:29.011012+00', '2021-11-09 09:25:39.753151+00', 11585, 1, 1645, 'ace', '1-::

  1c & 3c cross down into mirror Reels4 on opposite sides, 2c & 4c start up & out (1x,2,3x,4)

9-::

  1c & 3c cross down again into mirror Reels4 on own sides (1,2,3,4)

17-::

  1c & 3c cross RH | cast off (2c & 4c up) ; &frac12; Fig8 round 2c & 4c (2,1,4,3)

25-::

  1c+4c &frac12; R&L (omitting polite turn) ; turn P 1&frac12; RH (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (8086, '2013-10-14 23:48:04.615028+00', '2014-04-30 23:23:48.54917+00', 15182, 1, NULL, 'ace', '1–::
  Circle8 and back
9–::
  All turn P RH ; turn P LH
17–::
  1c+2c RHA ; LHA
25–::
  1c lead down and up
33–::
  1c cast off to 4pl (2c+3c+4c up) ; 1c turn RH', 3);
INSERT INTO 'dancecrib' VALUES (1993, '2012-01-22 19:29:13.978994+00', '2014-11-04 00:06:44.195461+00', 1376, 1, NULL, 'ace', '1–::

  1c+2c+3c Circle6 and back

9–::

  1c set advancing, join RH | 1M sets, 1W turning under her own R arm ; 1c set, join LH | 1W sets, 1M turning under his own L arm

17–::

  1c NHJ dance down {1}, up {1} | cast off (2c up) ; lead down between 3c cross and cast up to 2plx

25–::

  Mirror Reels3{6} on the sides, 1c starting in and up | 1c cross to 2pl (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8900, '2015-09-09 14:29:33.938227+00', '2015-09-09 14:29:33.938227+00', 6066, 1, NULL, 'ace', '*2c+4c cross to opposite side (1,2x,3,4x)*

1--::  1c+4c cross RH | cast to middle (2c+3c to end) ; ½ Fig8 round end cpl (2x,1,4x,3)

9--::  Snowball chain (8 hands), 1c+4c start passing RH on the side, (2,1,4x,3x)

17--::  1c+4c RHA and face nearest cnr ; Set “H&G” (set to cnr, to P, to next cnr and face that cnr) 

25--::  4c+1cnr turn cnr EH (1c+4c out the ends and in the sides) ; 4c+1c ½ La-Chain (2,4x,1,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (2177, '2012-01-22 19:29:24.020326+00', '2016-05-04 10:08:32.464385+00', 10102, 1, NULL, 'ace', '1–::

  1W dances Rsh round P into the centre ; 1c (W beckoning and leading)+2c ½ Lsh Reel3, 2c finish in 1pl, 1c face down, M on L

9–::

   1c  dance down the middle NHJ ; change sides to face up, 1W crossing above 1M and under joined arms | 1c dance up to between 3c

17–::

  1c (W leading)+3c ½ Rsh Reel3, 3c finish in 3pl ; 1c (M on R) dance up and cast off (2x,1x,3x)

25–::

  S&Link3 twice (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (9981, '2017-06-27 18:26:02.820968+00', '2017-07-06 19:05:14.560196+00', 17794, 1, 202, 'ace', '1--::

 All Circle6 L, on bar [4), pull back Rsh, spiral out ; chase clw ½ (1,2,3)

9--::

 All dance 6 bars of 3C Knot (3x,2x,1x)

17--::

 S&Link3 ; repeat (1,2,3)

25--::

 1c cross RH | cast (2c up) ; 1c cross LH | cast (3c up) (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (8136, '2013-12-18 13:31:54.469263+00', '2017-10-22 20:25:39.414996+00', 10469, 1, NULL, 'ace', '1–::

  1c cross down, cast behind 3c, meet and lead up one, cast up behind 2c, cross down into promhold, 1M on the R, between 3c (2c up)

9–::

  Reel3{6} across with 3c, Rsh to 3M, at end face down | 1M+3M & 1W+3W turn EH to (2,1,3)

17–::

  1c dance down {3} and up {3} | 1M+2M & 1W+2W turn EH to put 1c in promhold (own side) facing up

25–::

  Reel3{6} across with 2c, Rsh to 2W, finish on own side in middle still holding hands | 1c retire (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14317, '2021-09-16 03:59:07.807675+00', '2021-09-18 08:10:59.767168+00', 20489, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; dance down between 3c, meet | dance up to 2pl (2,1,3)

9--::

  All turn P RH ½, face P | cast R to exchanged places (to 2x,1x,3x) ; 2c & 3c repeat [9-12] back to places _while{4}_ 1c turn P RH twice to face 1cnrs

17--::

  Corners Pass and Turn, cnrs turning with BH (2,1,3)

25--::

  Circle6 and back (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (11509, '2019-01-14 00:03:01.262264+00', '2021-01-04 12:15:10.04631+00', 14194, 1, 202, 'ace', '1--::

  1c cross RH | cast off below 2c ; cross no hands to 2pl | 1c+2c change places EH. 1c face in, 2c out (2,1,3)

9--::

  Mirror Reels3 on sides, 1c in and down, 2c & 3c ending with loop. 1c pass LSh and face 1cnrs (2,1,3)

17--::

  ½ Reel4 on 1diag, pass LSh ; ½ Reel4 on 2diag (3x,1x,2x)

25--::

  3C S&Link ; repeat (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10121, '2017-09-15 07:18:07.093403+00', '2017-09-16 10:53:01.134471+00', 1551, 2, NULL, 'ace', '1-8::

  1L casts to below 2L, crosses up diagonally to above 1M, then 1s in prom. hold cast behind 2M and cross up to 1L place facing out

9-16::

  1s in prom. hold cast below 2L and with NHJ cross up to 1M place making an arch WHILE 2M casts up to 1M place and crosses down diagonally under 1s arch to below 2L; then 1s NHJ cast tightly while 2s NHJ cast up tightly and all cross set, 1s under arch of 2s, & turn inward to face across  (1s on L side, 2s opposite)

17-24::

  1s & 2s 4H ½ round to L and set to partners, M NHJ facing up, Ls NHJ facing down; repeat 4H ½ round to L and set facing across dance, partners NHJ

25-32::

  1M & 2L turn ½ RH, 1L & 2M  join for ½ RH across, ½ LH across to own sides, set facing across NHJ

', 3);
INSERT INTO 'dancecrib' VALUES (11510, '2019-01-14 02:27:59.835293+00', '2019-01-14 02:32:47.981715+00', 14187, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; turn P LH 1¼

9--::

  1W+2c & 1M+3c RHA, pass RSh ; 1W+3c & 1M+2c LHA, pass LSh into BiL[pos] on 1diag, LH to P

17--::

  The Spoke. 1c face 1cnrs

25--::

  Reel4 on 1diag. Pass LSh to face 2cnrs

33--::

  Reel4 on 2diag (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2223, '2012-01-22 19:29:26.588389+00', '2020-05-27 06:06:56.343846+00', 2153, 1, NULL, 'ace', '1–::

  1M facing 2M & 1W facing 2W set, change places RH ; repeat LH, finish (3c steps in) for

9–::

  1c+2c+3c Promenade (1,2,3)

17–::

  1c+2c Poussette, 1c finishing for

25–::

  DTr (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14742, '2022-04-03 09:35:18.663968+00', '2022-04-08 14:13:55.697695+00', 20673, 1, 1645, 'ace', '1--::

  1c+2c circle4 to L ; 1M & 2W chase &frac12; way clw

9--::

  1c+2c LHA ; 2M & 1W chase &frac12; way cclw (2x,1x)

17--::

  2c+1c RSh Reel4 on 1st diagonal, starting from & ending on opp sides (2x,1x)

25--::

  2c+1c set | petronella to centre line ; set facing P | turn P &frac34; RH (2,1)

', 5);
INSERT INTO 'dancecrib' VALUES (13777, '2021-03-02 01:22:24.546747+00', '2023-02-04 01:23:09.146835+00', 13706, 3, NULL, 'ace', '1-8::
    All circle 8H round to the left & back
9-16::
    All turn partner RH; all dance DoSiDo
17-24::
    1s lead down & back to finish in the middle in top place
25-32::
    1s join 2H & set twice; 2s+3s+4s make arches & 1s dance down under
    to 4th place (2s+3s+4s step up 31-32).  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (2129, '2012-01-22 19:29:21.635729+00', '2022-10-14 20:06:36.517851+00', 8133, 1, NULL, 'ace', '1–::

  1c dance Reels3 on opposite sides with 2c+3c (to 1x,2,3)

9–::

  1W, followed by 1M casts off one and crosses to own side (2c up)  (to 2,1,3) ; 1c turn LH once round to finish side by side in the centre, facing up

17–::

  1c set to 2c (who face down), set turning towards each other and face down ; 1c set to 3c (who face up), set passing Lsh to finish facing 1cnrs

25–::

  1c turn 1cnrs RH, pass P Rsh in the middle, turn 2cnrs RH, and pass P Rsh to 2pl own sides (corners dance for 4 bars!)', 2);
INSERT INTO 'dancecrib' VALUES (2006, '2012-01-22 19:29:14.632572+00', '2014-07-08 07:38:49.718562+00', 10007, 1, NULL, 'ace', '{{explanation}}

Four trios WMW in a square set



1–::

  Each trio Reel3, M starts Rsh

9–::

  All M set | ½ RHA | dance out between opposite W and cast R to next M place

17–::

  1trio+3trio advance NHJ , the W make a quick BH turn | retire in new trios ; side trios repeat

25–::

  Circle 12 and back



{{explanation}}

Progression. Each turn the M move one place cclw, the W cross to opposite side.', 3);
INSERT INTO 'dancecrib' VALUES (3754, '2013-06-06 22:29:12.771245+00', '2014-04-30 23:23:45.637003+00', 14611, 1, NULL, 'ace', '1–::
  1c+5c set | cast inwards (2c+4c to end) ; turn LH to face 1cnr
9–::
  Diag Reels4 with 1cnrs, at end pass Lsh and face out (2,1x,3,5x,4)
17–::
  1c+5c cast R (round 1cnr), 1M&5W pass Lsh in middle to face P ; 1c+5c ½ Reel4 on midline, finish facing nearest end
25–::
  5c+2W & 1c+4M RHA to sidelines (2,5,3,1,4) ; 5c+3c set | 5c cast as 3c dance up (2,3,5,1,4)', 2);
INSERT INTO 'dancecrib' VALUES (2188, '2012-01-22 19:29:24.729758+00', '2015-03-05 22:06:20.955925+00', 2010, 1, NULL, 'ace', '1–::

  1M+2W set | turn RH ; 1c set | cast off (2c up)

9–::

  1W+2M set | turn RH ; 2c set | cast off (1c up) (1,2)

17–::

  1c+2c dance BtoB ; 1M+2M & 1W+2W dance BtoB (1,2)

25–::

  Full DblFig8{6}, 1c crossing down (to 1,2) | 1c dance down as 2c cast up (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (2184, '2012-01-22 19:29:24.503073+00', '2017-11-11 13:44:03.214811+00', 13804, 1, NULL, 'ace', '1–::

  1c Turn RH | cast off (2c up) ; 1c turn LH and cast L round 4cnr to face 1cnr

9–::

  Opposing Reels3 across, Rsh to 1cnr, on [16] 1c turn LH ½ to face 3cnr

17–::

  Opposing Reels3 across, RSh to 3cnr, on [24] 1c turn LH ½ to face 1cnr

25–::

  1c turn 1cnr RH and pass Rsh, Turn 2cnr RH and pass Rsh to (2,1,3) (cnrs dance for {4})', 3);
INSERT INTO 'dancecrib' VALUES (2191, '2012-01-22 19:29:24.897325+00', '2017-04-27 20:22:27.326967+00', 8351, 1, NULL, 'ace', '1--::

  1c+3c set | 1c cast off and cross up _while{4}_ 3c cross up and cast off | 1c+2c change places EH on the sides _while{2}_ 3c turn RH ½ into (2,1x,3)

9--::

  All Circle6 and back

17--::

  All set and cross RH and 1c face out ; 2c+3c change places LH on sides (no polite turn) and set facing diagonally  _while{4}_ 1c cast L round 4cnr (pos) into middle facing 1cnr

25--::

  1c dance Rsh round 1cnr, meet & twirl to face 4cnr _while{4}_ 1cnrs turn RH ½ and cast away to diag opp pl ; 1c dance Rsh round 4cnr _while{4}_ 4cnrs turn RH ½ and cast away (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2179, '2012-01-22 19:29:24.132272+00', '2021-06-11 20:40:33.743645+00', 1982, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; pass Lsh and cast Rsh round 1cnr to finish Lsh to Lsh facing opposite side

9–::

  1W+2c & 1M+3c RHA, to sidelines ; 1M+2c & 1W+3c LHA (to 2,1,3)

17–::

  All set | turn BH ½ ; cast R to opposite side | cross back RH

25–::

  All circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (10540, '2018-03-21 09:01:54.31378+00', '2018-03-22 14:01:49.033308+00', 12148, 1, 202, 'ace', '1--::

  1c set | cross RH _while{2}_ 2c set ; 1c & 2c change places LH _while{2}_ 3c set | 1c & 3c change places RH _while{2}_ 2c cross RH as 4c set (2x,3,1x,4)

9--::

  2c+3c & 1c+4c changes places LH (to 3,2x,4,1x) | 3c & 1c cross RH _while{2}_ 2c+4c change places RH (to 3x,4,2x,1) ; 3c+4c & 2c+1c change places LH | all set (4,3x,1,2x)

17--::

  ½ Parallel Reels4 on sidelines (to 2x,1,3x,4) ; 1c+3c+4c ½ Parallel Reels3 on sidelines (2x,4,3x,1)

25--::

  4c & 1c ½ Fig8 up round 2c/3c (to 2x,4x,3x,1x) ; 2c & 1c cross RH _while{2}_ 4c+3c ½ RHA | all set (2,3,4,1)

33--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (9142, '2016-05-03 20:20:05.580863+00', '2016-05-03 20:38:37.172072+00', 5957, 1, NULL, 'ace', '1--::

  1W+4M cast clw behind own line, round the end and meet in the middle ; 1W+4M turn RH ¾ _while{4}_ 1M+4W cast cclw behind own line, round the ends and meet in the middle

9--::

  1c+4c LHA {2} | 4c+1c dance to opposite end (4,2,3,1) ; All turn P LH

17-32::

  4c+1c repeat [1-12] to places ; All turn P LH to promhold facing up 

33--::

  1c+2c & 3c+4c Promenade | 1c+3c cast off as 2c+4c dance up (2,1,4,3)

41--::

  1c+4c+3c Reels3{6} on own side, 4c start out and up | 1c+4c change place EH on sidelines (4c out and up) (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2190, '2012-01-22 19:29:24.857818+00', '2017-04-05 09:30:19.960265+00', 8855, 1, NULL, 'ace', '1–::

  2c, 1c following, lead down {3}, and up, 1c leading {3} | 1c cast (to 2,1,3)

9–::

  G-Chain (2c cross to start)

17–::

  1c ½ Fig8 down (cross RH) , repeat up

25–::

  Teapots R and L', 3);
INSERT INTO 'dancecrib' VALUES (2183, '2012-01-22 19:29:24.45229+00', '2019-02-21 21:34:58.523386+00', 9005, 1, NULL, 'ace', '1–::

  1c+3c long cast down (2c+4c up) ; cross RH | cast up to the middle, forming lines of 4 facing down

9–::

  All dance down the middle, turn R about and dance up 1c+3c finish facing up.

17–::

  1c with 3c following cast off to (2,3x,4,1x), end couples facing middle couples ; All set up/down | all set to P

25–::

  2c+3c & 4c+1c RHA ; 3c+1c lead up, cross and cast off to (2,3,4,1).', 3);
INSERT INTO 'dancecrib' VALUES (2203, '2012-01-22 19:29:25.625279+00', '2016-03-05 17:11:57.386722+00', 2063, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; cross RH | cast R (M up, W down)

9–::

  ½ Reels3 across (Lsh to 2cnr) ; set in lines across | all cross up/down RH

17–::

  Corners chase once clw _while{8}_ 1c chase half way clw and turn RH 1¼ to face 1cnr positions

25–::

  ½ diag. Reel4 with 1cnrs, 1c pass Rsh ; ½ diag. Reel4 with 2cnrs, 1c passing Rsh to 2pl.', 2);
INSERT INTO 'dancecrib' VALUES (2018, '2012-01-22 19:29:15.198086+00', '2014-04-30 23:23:45.839153+00', 11277, 1, NULL, 'ace', '1–::
  1c ½ Fig8 round 2c ; cross RH | cast off (2c up) to face 1cnr
9–::
  Set to and turn corners, finishing (2,1x,3)
17–::
  All A&R ; 1c petronella  _while_{2}   2c+3c set pivoting ¾ L or R (start outwards) | set in facing lines across
25–::
  All A&R up/down ; repeat figure to lines on own side | All set', 2);
INSERT INTO 'dancecrib' VALUES (3788, '2013-07-13 15:56:06.583545+00', '2018-01-04 00:23:14.142164+00', 14598, 1, NULL, 'ace', '{{explanation}}

On 2nd chord 3c+4c cross over (1,2,3x,4x)



1–::

  1c+2c [& 3c+4c] ½ Reels4 across, to start 1c [& 4c] cross fast, and pass Rsh with 2W/2M [3W/3M] (who first hold back), 2c [& 3c] then pass P Lsh to end in 1plx [4pl] as 1c [& 4c] dance into centre of set and pass P LH (2x,*1,4x*,3) ; 1c+4c ½ LHA | 1c facing 4c turn opposite dancer LH moving to the sidelines and all middles face ends (2x,4,1x,3)

9–::

  Reels4 on the sides, finish in St. Andrews cross all facing clw NHJ (2x,*4,1x*,3)

17–::

  ½ RHA, finish again in cross, middles facing ends ; All set | All turn opposite RH ½ (1,*3x,2*,4x), 3c & 2c finish M close behind W, facing 1cnr positions

25–::

  Rsh Lead-Change Reels3 on the sides, at end 2c pass 3c Rsh

33–::

  3c&2c lead to the ends, W faces P and turns P BH (4c+1c step to middle) to (3,1,4x,2x) ; Circle8 L half round  (2,4,1x,3x)



Note: In brackets like (2x,*1,4x*,3) the italics mean "standing inside sidelines".', 4);
INSERT INTO 'dancecrib' VALUES (2194, '2012-01-22 19:29:25.097371+00', '2014-04-30 23:23:48.911416+00', 2034, 1, NULL, 'ace', '1–::
  1c set | cast off one (2c up) ; set | turn RH ½ to face 1cnrs
9–::
  Turn 1cnr LH | P RH ; 2cnr LH | P RH to 2pl facing out.
17–::
  Reels3 on own sides, 1c Rsh to 3cnr, ending BtoB in the centre for
25–::
  2c+1c+3c DTr.', 2);
INSERT INTO 'dancecrib' VALUES (14749, '2022-04-08 08:31:06.742498+00', '2022-04-08 15:14:16.289569+00', 20672, 1, 202, 'ace', '1--::
  1M dances to P | 1c lead down {3} and up {3}to 2pl centre into promhold facing 2W (2c up on [5-6])
9--::
  Reel3 on 2diag, RSh to 2W. 1c face 2M
17--::
  Reels on 1diag, LSh to 2M. 1c in 2pl midline face Mside
25--::
  1c in promhold dance out, chase clw ½ to 2pl on Wside | 1W sets _as_ 1M dances to 2pl _while{8}_ cnrs advance diagonally | set ; retire | set (2,1,3) ', 5);
INSERT INTO 'dancecrib' VALUES (2195, '2012-01-22 19:29:25.152116+00', '2014-04-30 23:23:48.926618+00', 11280, 1, NULL, 'ace', '1–::
  1c lead down the middle and up
9–::
  1c+2c Poussette, on [15-16] 1c add ¼ turn extra and swivel R to finish BtoB on midline
17–::
  2c+1M & 1W+3c Reels3 across, Rsh to 2cnr, at end 1c turn RH ½ to face 1cnr
25–::
  1c turn 1cnr LH | P RH ; 2cnr LH | P RH, staying in centre to repeat or to lead to 4pl', 3);
INSERT INTO 'dancecrib' VALUES (2202, '2012-01-22 19:29:25.585333+00', '2014-04-30 23:23:49.031295+00', 2053, 1, NULL, 'ace', '1–::
  1c pass Rsh to face 1cnrs (2c up) | set to 1cnr, 2cnr (one PdB each) and pull Rsh back to end between corners ; 2c+1c+3c A&R
9–::
  2W+1M+3W & 2M+1W+3M circle3 to the left ; 1c Turn BH moving up to 1pl, 2c joining them for
17–::
  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (2262, '2012-01-22 19:29:28.444+00', '2017-08-29 22:53:40.796666+00', 2267, 1, NULL, 'ace', '1–::

  1c set | cross RH ; cast off (2c up) | turn ¾ LH

9–::

  BiL with 1cnrs | ½ turn 1cnrs RH ; 1c followed by 1cnrs chase clw round 4cnrs to leave 1cnrs in exchanged places, and join LH to 2cnr, RH to P

17–::

  BiL with 2cnrs | ½ turn 2cnrs LH ; 1c followed by 2cnrs chase cclw, 1c crossing Lsh to 2plx facing out (3x,1x,2x)

25–::

  ½ Lsh Reels3 on the sidelines ; All set and cross (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2017, '2012-01-22 19:29:15.150792+00', '2021-02-09 12:40:50.104596+00', 10356, 1, NULL, 'ace', '1–::

  2W+3M turn RH 1½ to exchanged places _while_{4} 1M+4W cross in through 2W/3M place and cast R to exchanged places ; 2M+3W turn RH 1½ to exchanged places _while_{4} 1W+4M cross through 2M/3W place and cast L to exchanged places (4x,3x,2x,1x)

9–::

  4c+3c & 2c+1c circle4 L (2c+3c pulling Lsh back into) ; 3c+2c circle4 R (4x,3x,2x,1x)

17–::

  ½Reels4 on the sides ; 1c+2c+3c+4c set | turn BH ½ into

25–::

  1c+2c & 3c+4c ½ Poussette, 1c+4c stay in middle for ; 1c+4c ½ Poussette (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (9143, '2016-05-04 21:42:35.870415+00', '2016-05-04 21:42:35.870415+00', 10575, 1, NULL, 'ace', '1--::

  1c+3c+5c set | cross RH ; set | cross RH  while{8}  2c+4c Fig8 round couple to their R and finish LHJ, and RHJ with 1cnr 

9--::

  2c+4c The Spoke, finish facing 1cnr

17--::

  2c+4c+ their 1cnrs diag. Reels4 (1,2,3,4,5)

25--::

  1c dance to 5pl as 2c+3c+4c+5c set (no hands) and cast up ; all turn P RH (2,3,4,5,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8031, '2013-09-10 08:44:22.92634+00', '2016-05-20 09:38:57.098361+00', 15098, 1, NULL, 'ace', '1–::

  All W RHA ; join LH with P and BiL | turn P LH ½ putting M in middle.

9–::

  All M RHA ; join LH with P and BiL | turn P LH ½ putting W in centre facing P

17-32::

  Double Celtic Reel, [pass P Rsh | ''outsides'' chase ¼ clw _while_{2} ''insides'' dance Lsh cclw ¾ and face P ; repeat 3 times] straight into

33-48::

  Schiehallion Reel

49–::

  1c+3c slip across BHJ, M passing BtoB | turn P BH ; slip back, W passing BtoB | Turn BH to place

57–::

  2c+4c repeat

65–::

  ½ G-Chain{6} | set to P

73–::

  repeat

81–::

  Circle8 and back.', 3);
INSERT INTO 'dancecrib' VALUES (2140, '2012-01-22 19:29:22.197476+00', '2021-04-08 10:06:54.6105+00', 1862, 1, NULL, 'ace', '{{title}}

Strathspey



1-4::

  All M advance one, set one left, _while_{4} all W set one to the right, advance one, all turn person opposite 1½ BH, finish facing in

5-16::

  Repeat [1-4] 3 more times, but on the last 2 bars, turn P once round to finish in P''s place facing P

17–::

  Interlocking Reels4 on the circle: starting Rsh to P, finish in same places, M facing out, W facing in

25–::

  Double Reels4 across: W begin in and LHA _while_ M first loop into P''s place. The M finish BtoB in the centre facing diagonally out between partner and woman who was originally one place to the right



{{title}}

Reel



33–::

  All set, joining hands as in DTr, then all Petronella Turn forward, men to the diagonal points facing in, women to the middle BtoB facing out ; repeat to return to places

41–::

  All set as in DTr, and in PdB change places RH with P ; Repeat, changing places with person held by LH

49–::

  Repeat, again with the person held by LH ; All set and turn P to original places, using skip change of step

57–::

  All circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (2074, '2012-01-22 19:29:18.392327+00', '2019-01-15 08:42:34.288524+00', 1615, 1, NULL, 'ace', '1–::

  1c+2c set | cross Rsh (no hands) ; repeat

9–::

  1c down the middle and up, 2c step in

17–::

  1c+2c Allemande, finish facing 1cnr

25–::

  1c turn 1cnr BH, pass Rsh, turn 2cnr BH, cross Rsh to (2,1,3)



{{explanation}}

Note: older instructions tell 1c to turn once LH on 23-24; the current (revised) instructions leave that unspecified.', 3);
INSERT INTO 'dancecrib' VALUES (2371, '2012-01-22 19:29:33.967711+00', '2017-07-07 13:15:35.787679+00', 2645, 1, NULL, 'ace', '1–::

  1M+2W set advancing slightly | turn BH ; 1W+2M repeat

9–::

  1c lead down the middle and up

17–::

  1c set, cast one place (2c up), 1c dance BtoB

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (2200, '2012-01-22 19:29:25.490242+00', '2021-06-21 10:49:41.094135+00', 2044, 1, NULL, 'ace', '1–::

  1W+2W+3W Circle3 L on the W side ; 1M+2M+3M repeat on M side

9–::

  1c lead down the middle (2c up) ; and up to face 1cnrs

17–::

  1c set to and turn corners, finish between corners

25–::

  1c set twice ; turn RH 1½ to own sides', 2);
INSERT INTO 'dancecrib' VALUES (2206, '2012-01-22 19:29:25.777048+00', '2020-12-06 11:13:37.19598+00', 2084, 1, NULL, 'ace', '1–::

  1c+2c set | ½ RHA ; 2c+1c+3c ½ Rsh Reels3 (1c start up) (3,1x,2x,4)

9–::

  1c+2c LHA _while{4}_ 3c+4c chase clw halfway around (4M & 3W cast, P follows) ; 4c+1c and 2c+3c turn RH in sideline (4x,1x,2x,3x)

17–::

  Rsh Reels4 in sideline

25–::

  All set and 4c+2c cast off 1 place (1c+3c up) ; ½ circle8 to L (to 2,3,4,1).', 3);
INSERT INTO 'dancecrib' VALUES (14391, '2021-10-14 16:10:09.937762+00', '2021-10-14 16:12:41.399517+00', 6013, 1, 202, 'ace', '1--::

  1c & 4c set | turn P BH openning to face to centre (2c & 3c step out) ; all NHJ across set, 1c & 4c turning Bto with P and face own sides

9--::

  Reels4 across. 1c & 4c face to centre

17--::

  1c & 4c lead in | ½ RHA ; turn P RH ½ moving through nearest ends | cast inwards (2,4,1,3)

25--::

  4c+1c RHA. Retain RH with P ; 4c & 1c turn P RH (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2208, '2012-01-22 19:29:25.862738+00', '2016-07-13 23:37:06.462178+00', 9811, 1, NULL, 'ace', '1–::

  All set | cross RH ; chase clw half round (4,3,2,1)

9–::

  4c+3c & 2c+1c RHA ; ½Reel4 on the sidelines

17–::

  1M+2W cross RH and set _while{4}_ 1W+2M set and cross RH ; 1M+3M cross RH and set _while{4}_ 1W+3W set and cross RH

25–::

  1M+4W cross RH and set _while{4}_ 1W+4M set and cross RH ; 2c+3c+4c+1c turn BH 1½  (2,3,4,1)



{{explanation}}

Note: the crossings [17-28] all start with 1M crossing, 1W setting', 2);
INSERT INTO 'dancecrib' VALUES (10544, '2018-03-22 14:27:45.000122+00', '2018-03-22 14:35:06.890247+00', 12349, 1, 202, 'ace', '1--::

  All circle8 L {3}, cross R foot over and pivot L ; chase cclw to places

9--::

  All M RHA, on [12] M pivot R BtoB in centre facing P ; all set | all turn P RH ¾, W(M) facing out(in)

17--::

  8 bars of Schiehallion reels (3,4,1,2)

25--::

  All turn P RH ; all dance BtoB with P

33--::

  All W repeat [9-16], W(M) facing in(out)

41--::

  8 bars of Schiehallion reels to places, W on M''s L (1,2,3,4)

49--::

  All turn P RH 1 ½ ; all dance BtoB with P

57--::

  Repeat [1-8]', 2);
INSERT INTO 'dancecrib' VALUES (2216, '2012-01-22 19:29:26.259333+00', '2014-04-30 23:23:49.259894+00', 2126, 1, NULL, 'ace', '1–::
  1c+2c+3c chase clw once round to places
9–::
  1c+2c RHA, LHA
17–::
  1c cast down 2, dance up 2, cast to 2pl (2c up)
25–::
  2c+1c+3c A&R, all turn RH', 2);
INSERT INTO 'dancecrib' VALUES (11511, '2019-01-14 15:33:54.741838+00', '2022-11-01 19:30:16.223937+00', 6455, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; cross LH | loop LSh round 4cnrs

9--::

  1c pass RSh up/down, 2c+1M & 1W+3c RHA (to 2,1x,3) ; 1c pass RSh, 2c+1W & 1M+3c LHA. 1c finish BtoB in DTr[pos] facing own side

17--::

  DTr. 1c finish BtoB in DTr[pos] facing own side

25--::

  1c turn 3cnrs RH, pass RSh ; turn 4cnrs LH to 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2038, '2012-01-22 19:29:16.464606+00', '2021-02-09 12:28:08.413569+00', 10366, 1, NULL, 'ace', '{{explanation}}

On 2nd chord 3c+4c cross (to 1,2,3x,4x)



1–::

  1c+4c set and cast (2c+3c up/dn) ; 1c+4c RHA, at end swivel R to face »corners«

9–::

  All SetH&G , finish facing opposite cnrs (2,4,1x,3x)

17–::

  All turn corner (W with RH, M with LH) to sidelines ; pairs 1M+4W & 4M+1W in promhold ½ Rsh Reels3 across with end couple on their L

25–::

  Same pairs in promhold ½ Lsh Reel3 on sidelines ; 1c+4c RHA (3,1,4x,2x)



{{explanation}}

The first two turns are in Strathspey time, the second two are in Reel time.', 3);
INSERT INTO 'dancecrib' VALUES (2207, '2012-01-22 19:29:25.822236+00', '2017-02-14 23:24:33.533586+00', 2097, 1, NULL, 'ace', '1–::

  1c+2c+3c circle6 and back, finishing for

9–::

  All Promenade, finish in middle RHJ facing down for

17–::

  All lead down the middle and up to (1,2,3)

25–::

  1c+2c »Chain Progression« (1c+2c turn BH ¾ | ½ Reel4 on midline | turn BH ¾) to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2211, '2012-01-22 19:29:26.004791+00', '2018-11-28 15:50:31.661096+00', 10824, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c set | ½ RHA ; 1c+4c set | turn BH ½ into 

9--::

  1c+4c ½ Poussette ; 2c+4c & 1c+3c circle4 L (2x,4,1,3x) 

17--::

  4M+1W dance on casting R round end dancer to midline _while{2}_  4W+1M turn LH ½  | 4M+1M & 4W+1W turn RH ; ½ reel4  (1W,4W,1M,4M) 

25--::

  1W (4W follows) & 4M (1M follows) cast R through the end, behind own line, and cross Rsh to opposite side (2x,4x,1x,3x) ; all Turn BH 1½  (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10685, '2018-04-23 19:08:27.388099+00', '2018-10-05 08:05:48.993498+00', 9482, 1, 202, 'ace', '1--::

  1c set | cross down to 2pl (2c up) ; cast round 3c | dance up to 2pl facing out (2,1x,3)

9--::

  Mirror Reels3 on sidelines, 1c out and up to start, cpls touching hands when possible, 1c ending BtoB in centre facing opposite sides

17--::

  2c+1c+3c set as in DTr | all set advancing and swivel R to form "inverted" DTr (2c+3c are BtoB in centre) ; repeat [17-20] into DTr position

25--::

  1c cast R round 1cnrs, pass Rsh up/dn, cast R round 2cnrs, cross LH to 2pl _while{8}_ 1cnrs cross RH | set ; 2cnrs cross RH | set (3x,1,2x)

33--::

  Diagonal R&L (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3597, '2012-07-21 11:45:30.591332+00', '2014-04-30 23:23:49.362852+00', 11281, 1, NULL, 'ace', '1–::
  1c set and cross ; 1c+2c set | 1M casts down  _while_{2}   2M casts up  _while_{2}   1W+2W turn LH ½ to face P on 1diag
9–::
  Reel4 on 1diag, the W curve R to finish (2,1x)
17–::
  L-Chain
25–::
  1c cross up RH and cast off ; turn RH (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (2213, '2012-01-22 19:29:26.128015+00', '2020-12-24 18:16:49.063746+00', 10854, 1, NULL, 'ace', '1–::

  1W, 1M following, casts behind W line and up between 3c, 1W casts up behind 2W and 1M behind 2M, to (1,2,3)

9–::

  1M+3W change places RH | 1W+3M repeat ; 2c+1c ½ R&L, 1c finish facing 3cnr position (3x,1,2x)

17–::

  2cnrs A&R diagonally _while{4}_ 1c with 1cnr person on R in promhold chase cclw behind them into lines across (2M+1W+3M facing 2W+1M+3W) ; set | 1c turn LH to face 4cnr position

25–::

  Repeat [17-20], 1c with 2cnr persons, finish (2,1x,3) ; set | 1c cross LH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2233, '2012-01-22 19:29:27.078147+00', '2020-12-19 15:16:03.111855+00', 8726, 1, NULL, 'ace', '{{explanation}}

4c+5c+6c start on opposite sides (1,2,3,4x,5x,6x)



1–::

  1c+2c+3c & 4c+5c+6c each circle6 and back

9–::

  ½ G-Chain (6 hands), starting across at the ends (to 6,5,4,3x,2x,1x)

17–::

  Top, middle and bottom pairs of couples set, ½RHA ; end couples wait _while{4}_ 6c+3c & 4c+1c set, ½LHA (to 5x,3x,6,1x,4,2)

25–::

  Middle-most couples (1c+6c) face each other, set and change places RH ; all C set and cross RH (to 5,3,1,6x,4x,2x)', 2);
INSERT INTO 'dancecrib' VALUES (1649, '2012-01-22 19:28:52.952793+00', '2021-11-10 10:15:25.48329+00', 107, 1, 202, 'ace', '1–::

  1c cross RH | cast off ; cross LH | cast to 1pl (1,2,3)

9–::

  Mirror Reels3 on sides, 1c in and down (1,2,3)

17–::

  1c dance down (2c up) ; set | dance up in 2pl  centre facing up

25–::

  All W RHA _while{4}_  all M LHA ; 1c dance to top and cast off to 2pl (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9904, '2017-06-04 17:51:58.178967+00', '2021-06-28 00:46:06.303405+00', 867, 2, 160, 'ace', '1-8::

  1C 2C dance RHA; 1M 2W retain RH, turn halfway [1] then cast L around partner and cross to own places [3].

9-16::

  1C 2C dance LHA; 1W 2M dance around partner by L and pass by the L - - 1W to face 2W, 2M to face 1M.

17-24::

  Diagonal Reel4 - 1W 2M on reaching partner''s place cross to own sides.

25-32::

  1C 2C Tourbillon.', 3);
INSERT INTO 'dancecrib' VALUES (13553, '2021-01-13 00:52:47.417903+00', '2021-01-13 20:39:13.503847+00', 9017, 1, 202, 'ace', '1--::

  All 3 W dance RSh round P to places | all set (1,2,3)

9--::

  All 3 M repeat [1-8] (1,2,3)

17--::

  1c cross RH | cast off to 3pl (2c+3c up) ; 1c cross RH | cast up to 2pl (3c down) (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (14266, '2021-08-26 08:42:44.734254+00', '2021-09-16 16:28:58.062724+00', 20450, 1, 202, 'ace', '1--::

  1c turn P BH ; 1c+2c set | 1c dance down to 2pl _while_ 2c cast up (2,1,3,4)

9--::

  Mirror Reels3 on sides, 1c out and down, all giving hands when possible (2,1,3,4)

17--::

  1c turn P BH moving down to 3pl centre {3} _while{3}_ 3c cast up to 2pl centre. 3c+1c retire to sides {1} ; all NHJ set advancing, face P and cast R to original places (2,3,1,4)

25--::

  2c & 1c dance down between nearest couples and cast up to original places (to 2,3,1,4) ; 2c+3c Circle4 L to centre {3} _while{3}_ 1c turn P BH moving down to 4pl centre _while{3}_ 4c cast up to 3pl centre. All NHJ retire {1} (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (9144, '2016-05-07 11:07:17.343054+00', '2016-05-07 12:20:52.425647+00', 5473, 1, NULL, 'ace', '1--::

  1c turn RH ½ moving down to 2plx in the middle (2c up) | 1c set to P ; 1c cast clw round 1cnr to meet Lsh to Lsh in 2plx

9--::

  1c+1cnr+2cnr RHA ; 1c+3cnr+4cnr LHA, 1c finish facing 2cnr

17--::

  1c+2cnr set | change places RH ; cnr persons turn LH to face own cnr while{2} 1c set to P diagonally | change back Rsh (no H), cnrs to own place and 1c into the middle, pivoting R to face 1cnr

25--::

  1c+1cnr set | change places RH ; cnr persons turn LH to face own cnr while{2} 1c set to P diagonally | change back Rsh (no H), cnrs to own place and 1c to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9988, '2017-06-30 11:22:37.934529+00', '2018-10-05 13:01:24.88093+00', 17883, 1, 202, 'ace', '1--::

 1c+2c Poussette (1,2,3)

9--::

 1M+2W cross RH | set _while{4}_ 1W+2M set | cross LH (to 2x,1x,3) ; 1M+3M cross LH _while{4}_ 1W+3W set | cross RH (2x,3x,1)

17--::

 2c+3c RHA ½ | cross RH _while{4}_ 1c set | cross RH (to 3x,2x,1x) ; all chase clw ½ (1,2,3)

25--::

 1c+2c Knot (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2228, '2012-01-22 19:29:26.815802+00', '2014-04-30 23:23:49.454101+00', 2166, 1, NULL, 'ace', '1–::
  1c lead down the middle (2c up) ; and up, to face 1cnrs
9–::
  1W+2c and 1M+3c Reel3 across, Rsh to 1cnr, finish facing 1cnr
17–::
  1c set to and turn corners, finish in sideline between corners
25–::
  1c set twice to P ; turn RH 1½ to (2,1,3) (alternative: turn BH ½ in PdB)', 3);
INSERT INTO 'dancecrib' VALUES (7879, '2013-08-21 08:31:50.361801+00', '2023-02-04 01:23:09.206356+00', 1566, 3, NULL, 'ace', '1-8::
    1L+2M also 3L+4M cross RH, cast behind partner & round to face
    partner, 1s+2s also 3s+4s dance 1/2 Poussette
9-16::
    1s+4s+3s (bottom 3 couples) dance the Knot
17-24::
    2s+3s also 4s+1s dance LH across & RH back
25-32::
    All RSh reels of 4 on sides.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8114, '2013-11-17 12:47:04.368348+00', '2014-11-11 01:29:00.622335+00', 2168, 1, NULL, 'ace', '1–::

  1c lead down {3}, up {3} and cast (2c up)

9–::

  Grand Chain, 2c cross to begin (2,1,3)

17–::

  1c set adv to 1cnr | turn 1cnr BH into lines across ; repeat with 2cnrs (2,1x,3)

25–::

  repeat with 3cns ; repeat with 4cnrs (2,1,3)

33–::

  1c cross up LH | cast to 2plx ; cross RH | cast off (3c up) (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2109, '2012-01-22 19:29:20.586374+00', '2018-04-17 21:09:13.52349+00', 1763, 1, NULL, 'ace', '1–::

  1c cross RH, cast off (2c up) ; 2c+1M & 1W+3c RHA (to 2,1x,3)

9–::

  »The Fiddich«: 2M&3W chase clw half round _while{4}_ 1c+corner on the R set advancing, ½RHA (to 3x,1,2x) ; 2W&3M chase cclw back to own places _while{4}_ 1c+person on the L set advancing, ½LHA to diagonally opposite places (2,1x,3)

17–::

  Reels3{6} on the sides, Rsh to 2cnr | 1c cross RH (2,1,3)

25–::

  2c+1c+3c »Wheelie Chain« (2c+1M & 1W+3c ½ RHA | all M & all W ½ LHA (to 3x,1x,2x) ; repeat to (2,1,3)) 



*The Wheelie Chain {8 bars}:  Every 2 bars [2M with 1M following] & [3W with 1W following] move ¼ clw round the set, while 2W & 3M move round ¼ cclw.  To begin 2M+1M+2W & 1W+3W+3M dance ½RHA. Then on each passing the groups of 3 dance ½LHA ; ½RHA | ½LHA.  Finish (213)*', 3);
INSERT INTO 'dancecrib' VALUES (2053, '2012-01-22 19:29:17.239294+00', '2017-04-21 07:59:55.92108+00', 8349, 1, NULL, 'ace', '1-16::

  1c set | cross RH ; cast below 3c | cross up between them ;; cast off again | slip to the top ; cast into 2pl | cross LH and face out.

::

  2c does the same, starting 2 bars later, finish in 1st place and face down and in (2,1x,3)

17–::

  Reels3 on the sides, 1c Lsh to 2cnr, at end cross to own side (2,1,3)

25–::

  2c+1c+3c circle6 left ; swivel L , chase back cclw (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10055, '2017-08-31 10:25:34.262057+00', '2017-08-31 10:25:34.262057+00', 17924, 2, NULL, 'ace', '1-8::

  1s cross RH, cast to 2nd place (2s step up bars 3-4), 1s dance 1/2 Fig of 8 down

9-16::

  1s set advancing, passing L to end B to B facing out | Taking hands as triangles, 1s,2s,3s set ; invert triangles | set

17-24::

  1s dance reels of 3 on sides giving RSh to person on their Right

25-32::

  2s+1s+3s circle 6H round to L for 6 bars.  1s pass R to cross on 7-8  

', 3);
INSERT INTO 'dancecrib' VALUES (2222, '2012-01-22 19:29:26.536443+00', '2017-07-07 12:59:01.01502+00', 2140, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; 1c set | cast Lsh back (W up, M down), (2W step down, 3M up) (to positions 1W,2W,3W and 2M,3M,1M respectively)

9–::

  1M+2W+3W & 1W+3M+2M Lsh Reels3, to enter 1M+2W & 1W+3M pass Lsh, and 3W & 2M cross the set passing Rsh to 1M/1W, all finish in starting places, 1c+2M+3W facing out for

17–::

  Opposing Reels3 on own sides, 1M+3M & 1W+2W enter Rsh, at end they again pass Rsh, 2c & 3c to end positions and 1c to face 1cnr

25–::

  Turn CPCP (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2059, '2012-01-22 19:29:17.554412+00', '2021-06-17 21:14:09.647977+00', 1558, 1, NULL, 'ace', '1–::

  1c+2c S&Link ; S&Link , 1W & 2M finish facing out (1,2)

9–::

  Reel4 across (1M pass 2W Lsh) , at end 1W+2M cross Rsh (1,2)

17–::

  1c+2c advance to P [1], spiral R to place [1] | cross Rsh to opposite side ; advance diagonally [1], spiral R back [1] | chase half round to (2,1)

25–::

  R&L', 2);
INSERT INTO 'dancecrib' VALUES (2054, '2012-01-22 19:29:17.278277+00', '2021-02-19 14:39:09.150532+00', 9830, 1, NULL, 'ace', '1–::

  Reels4 on the sides, M with Rsh, W with Lsh

9–::

  1c+3c & 2c+4c interlocking DblFig8 (cross down and cast up, moving 2 places each time)

17–::

  All set | All ½ circle8 left (to 4x,3x,2x,1x) | All C ½ RH turn, 1c to sidelines and the others into

25–::

  4c+3c+2c Allemande (to 2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3783, '2013-07-13 15:56:05.462519+00', '2016-03-28 20:29:52.254874+00', 14599, 1, NULL, 'ace', '1–::

  The Bourrel: [1M+2W set advancing | turn BH ¾ and twirl R, finish BtoB on midline to face P up/down _while_{4} 1W+2M chase cclw ¾ round ; 2c+1c set to P | turn BH, 2c to 1pl and 1c finish on 2diag, 1M followed by 1W facing 3M]

9–::

  ½ Rsh lead change Reel3 on 2diag, and 1W followed by 1M face 3W ; ½ Rsh lead change Reel3 on 1diag, to (3x,1x,2x) 1c facing out

17–::

  3c+2c ½ R&L  _while_{4}  1c cast L, cross to own side and cast L (to 2,1,3) ; All A(1)&R(1) | All set

25–::

  2c+1c Poussette (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2640, '2012-01-22 19:29:51.124298+00', '2021-09-17 11:13:31.422621+00', 3700, 1, NULL, 'ace', '1–::

  1M leading +2M+3M dance across the top and down to behind the Women ; all M cross to own side (1M below 3W, 2M below 2W. 3M below 1W) | All set

9–::

  Teapots R ; and L (2c RHA with pair to the R ; LHA to the L)

17–::

  1W leading +2W+3W dance across the top and down behind the M to join own P (who swivels ¾ L on [20] into promhold facing down ; half 3C Promenade to finish 1c in the middle facing up, 2c & 3c on sides (1,2,3)

25–::

  1c cast off as 2c dance to top | 1c turn BH ; cast off to 3pl (3c up) | 1c turn BH. (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (14392, '2021-10-14 17:58:46.194425+00', '2021-10-14 18:01:08.714714+00', 935, 1, 202, 'ace', '1--::
  1c lead down {3}, turn P RH {2}, lead up to 1pl centre {3}. 2c step in on [8]
9--::
  2C Allemande. On [8] 1c turn P RH to face 1cnrs
17--::
  SetH&G. On [23-24] 1c set advancing pulling RSh back into BtoB position. 1M faces up, 1W faces down
25--::
  2c+1M & 1W+3c LHA, pass LSh ; 2c+1W & 1M+3c RHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8252, '2014-04-24 11:29:03.613824+00', '2014-04-30 23:23:49.558794+00', 10649, 1, NULL, 'ace', '1–::
  1c+2c turn EH 1½ on sides, 1c starting inwards ; 1c+3c repeat, 1c starting outwards (2,3,1)
9–::
  1c dance up 2 and cast off one (3c down) ; All dance BtoB (2,1,3)
17–::
  Teapots R and L [2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA)
25–::
  1c ½ Fig8 down ; ½ Fig8 up (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2239, '2012-01-22 19:29:27.35907+00', '2021-03-01 01:48:16.253632+00', 2203, 1, NULL, 'ace', '{{explanation}}

Square set plus 5M / 5W in middle face P with backs to 4c / 2c



1–::

  1c+2c+3c+4c circle8 and back _while_{8} 5c turn RH ; turn LH 1½

9–::

  5M+2c & 5W+4c RHA ; 5M+1c & 5W+3c LHA

17–::

  1c+5M+2c & 3c+5W+4c (couples in promhold) Reels3 Rsh to side couple, 5c meets (5M swivels L) and takes promhold facing 1c

25–::

  (all C promhold) 5c+1c change places Rsh | 1c+4c repeat ; 4c+3c repeat | 3c+2c repeat, 2c is the new centre couple.', 3);
INSERT INTO 'dancecrib' VALUES (2508, '2012-01-22 19:29:45.578421+00', '2020-09-16 22:12:10.777434+00', 13131, 1, NULL, 'ace', '1–::

  Mirror Reels3 on own side, 2c starts out and up, finish 1c facing 3c in the middle

9–::

  1c+3c R&L up/down, finish (1,2,3) with 1c facing out

17–::

  1c cast (2c up) | ½ Fig8 up | cross RH (2,1,3)

25–::

  Circle6 and back



{{explanation}}

When a new top couple starts, the bottom c starts from 4pl as the previous 1c steps down.', 3);
INSERT INTO 'dancecrib' VALUES (8040, '2013-09-18 06:12:33.10374+00', '2014-04-30 23:23:49.698853+00', 8515, 1, NULL, 'ace', '1–::
  1c+2c & 3c+4c S&Link (2,1,4,3,5) ; 1c+3c turn P LH 1½ to face 1cnr
9–::
  1c+3c Pass & Turn with 1cnrs ; with 2cnr, finish (2.1.4.3.5)
17–::
  2c+1W & 3M+5c Lsh Reels3 across _while_{8} 1M+4c+3W Lsh Reel4 across, start with 1M Lsh to 4W & 4M Lsh to 3W. Finish 2c in 1pl ready for
25–::
  1c+4c & 3c+5c Rondel (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (1646, '2012-01-22 19:28:52.805669+00', '2016-05-07 12:56:18.0637+00', 9223, 1, NULL, 'ace', '1–::

  1c+2c set | RHA | 1c cross down as 2c cast up (2,1x,3)

9–::

  1c casts R round 1cnr ; 1W+2M+3M &1M+2W+3W circle3 left, 1c end facing 1cnr.

17–::

  1c ½Reel4 with 1cnrs and pass Rsh, _while_{4}  2cnrs chase ½ clw round the set ; 1c ½Reel4 with 2cnrs, end passing Rsh, _while_{4}  1cnrs chase clw ½ round to own places

25–::

  (Cnrs Pass and Turn) 1c+3cnr pass Rsh, 3cnrs turn RH | pass back and 1c pass Rsh ; repeat with 4cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2248, '2012-01-22 19:29:27.766178+00', '2019-06-02 23:35:49.916894+00', 2236, 1, NULL, 'ace', '1–::

  1c+3c+5c set advancing to line of six NHJ with P on the right | BiL ; 1c turn ¾ RH and cast to 5pl _while{4}_ 3c+5c turn ¾ RH and lead up to 1pl / 3pl (3,2,5,4,1)

9–::

  3c+5c+1c repeat bars 1-8 from new places (5,2,1,4,3)

17–::

  1c followed by 5c lead down the middle ; and up to 2pl/4pl (2c+4c up) (2,5,4,1,3)

25–::

  2c+5c & 1c+3c R&L.

', 3);
INSERT INTO 'dancecrib' VALUES (10126, '2017-09-15 07:32:41.703794+00', '2017-09-16 10:55:04.713053+00', 4401, 2, NULL, 'ace', '1-8::

  1s turn once BH (2 bars), cross RH WHILE 2s turn once BH; then as 3s & 4s repeat Bars 1-4, 1s & 2s 4H once round to L (ends 1x, 2, 3x, 4)

9-16::

  All pass 3 people in Grand Chain RH, LH, RH (1s & 4s at ends start crossing with partners), all M make polite turns to face in after the 3rd (RH) pass and dance 8H ½ round to L (stay in circle formation)

17-24::

  All Ls change places LH with M on their L with polite turns to face in, all 8H ¼ round to R (NB) - 2 places - and repeat these 4 bars (Ls passing again to L and circling ¼ round - ends 4, 2x, 3, 1x)

25-32::

  4s & 3s, 2s &1s dance quick half Rights & Lefts (2 bars only), then 2s & 1s turn BH once while 4s & 3s cross RH, all to own sides; 2s stand at top while 4s 1s & 3s 6H hands ½ round to L (2 bars), 1s & 4s continue 4H ½ round to L while 3s cross RH (ends 2, 3, 4, 1)

', 3);
INSERT INTO 'dancecrib' VALUES (3598, '2012-07-21 11:45:31.031514+00', '2017-02-13 14:40:58.595183+00', 485, 1, NULL, 'ace', '1–::

  1c+2c Tournee (2,1,3)

9–::

  Teapots R [2c+1W & 1M+3c RHA] ; 2c+3c chase clw ½  _while_{4}   1c turn LH 1½ to face 3cnr

17–::

  1c+1cnrs ½ Reel4 at end 1c fast turn LH to face 4cnr ; ½ Reel4 with 2cnrs, finish (2,1,3)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (2236, '2012-01-22 19:29:27.209985+00', '2017-02-13 14:41:34.129029+00', 2196, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; 1c turn 1cnr RH, finish between end couple facing 1cnr

9–::

  1W+2c & 1M+3c Rsh Reels3 across, finish in lines across

17–::

  A&R (up/down) ; 1c turn RH 1¼ to 2pl (2,1,3)

25–::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2240, '2012-01-22 19:29:27.406048+00', '2018-05-17 21:56:31.964425+00', 2222, 1, NULL, 'ace', '1–::

  1c set and cast off one (2c up), 1¼ turn LH so 1M (with 1W behind) faces 3W

9–::

  1c lead-change diagonal Reel3 with 1cnrs (Rsh to 3W) (1M & 1W switch lead at each end of the reel), end facing 3M

17–::

  Repeat with 2cnrs (start Rsh to 3M), finish facing 1cnrs

25–::

  Turn 1cnr RH, pass P Rsh, repeat with 2cnr, cross to (2,1,3) (cnrs turn for 4 bars)', 3);
INSERT INTO 'dancecrib' VALUES (2238, '2012-01-22 19:29:27.303608+00', '2019-03-07 09:37:16.902787+00', 8048, 1, NULL, 'ace', '1–::

  1c+2c A&R ; Circle4 L

9–::

  1c+2c A&R ; Circle4 R

17–::

  1c down the middle and up

25–::

  1c, other Cs following, cast to 4pl, 1c form arch and 2c+3c+4c dance up (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2237, '2012-01-22 19:29:27.253056+00', '2020-12-25 12:35:23.913866+00', 12502, 1, NULL, 'ace', '1–::

  1c+2c+3c mirror Reels3 on own side, 1c starting in

9–::

  1c cross RH, cast (2c up) : cross LH between 3c and cast up to face 1cnr

17–::

  Turn CPCP, 1c finish facing out (2,1,3)

25–::

  1c cast up, dance down to 2pl ; 1M+3M turn LH 1½ _while{4}_ 1W+3W turn RH 1½ (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3599, '2012-07-21 11:45:31.352439+00', '2014-11-12 22:33:49.214768+00', 2223, 1, NULL, 'ace', '{{explanation}}

On the second chord 1c change sides (1x,2,3).



1–::

  1W+2W dance BtoB, moving one place to the R _while{4}_ 1M+2M set and cast one place to the L (2,1x,3) ; 1M+2M dance BtoB (2,1x,3)

9–::

  2c+1c R&L

17–::

  2W+1W+3W Lsh Reel3{6} (1W through and up) | all turn P RH

25–::

  2M+1M+3M Reel3{6} (1M through and down) | All turn P RH, finishing in triangular formation with Men with backs to the centre

33-44::

  Schiehallion Reel

45-48::

  All cpls turn BH to finish (2x,3,1) 



{{explanation}}

In an alternative version, [9-16] and [17-24] are interchanged, and 1W starts through and down on bar 9.  There is also a version for a 3C/4L set (8x48).', 3);
INSERT INTO 'dancecrib' VALUES (3654, '2012-11-25 00:10:01.883599+00', '2021-04-18 18:37:55.62143+00', 1533, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c Circle4 L ; S&Link (2,1,4,3)

9–::

  2c+1c & 4c+3c RHA ; 1c+4c LHA

17–::

  Reels4 on the sides, at end the middles take LH and start to turn

25–::

  1c+4c turn LH ½ on the sides and set to P ; All turn RH (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9295, '2016-09-17 20:45:18.711904+00', '2016-09-17 20:45:18.711904+00', 6728, 1, NULL, 'ace', '1--::

  1c+2c set | cross with a petronella turn ; repeat to own side

9--::

  1c cross RH | cast off ; cross LH | cast to place

17-26::

  1M+2W change place RH | 1W+2M repeat ; 2c+1c Circle4 L ½ | 1c set and cast off (2,1)   

', 3);
INSERT INTO 'dancecrib' VALUES (2244, '2012-01-22 19:29:27.588747+00', '2016-01-17 02:31:25.525988+00', 9382, 1, NULL, 'ace', '1–::

  1c+3c set, turn ¾ RH into ; ½Reel4 on mid-line

9–::

  1c (W leading) & 3c (M leading) chase clw to own places _while{4}_ 2c Turn RH ; all chase clw ½ to (3x,2x,1x)

17–::

  3c+2c half R&L (no polite turn) ; 3c+1c half R&L (to 2,1,3x)

25–::

  1c ½ Fig8 down (round 3c) ; 1c+3c set and cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2250, '2012-01-22 19:29:27.861496+00', '2015-09-05 21:16:08.337772+00', 14387, 1, NULL, 'ace', '1–::

  1c lead down the middle and back

9–::

  1c cast off into figures of 8 on their own sides

17–::

  1c, other cs following, cast behind own lines to the bottom and 1c make arch ; other couples dance up under arch

25–::

  All Circle and back



{{explanation}}

This can also be danced in a 3C or 5C set`', 3);
INSERT INTO 'dancecrib' VALUES (10056, '2017-08-31 10:36:09.351481+00', '2017-08-31 10:36:09.351481+00', 17924, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 down (2,1,3)

9--::

  1c set adv. passing Lsh into DTr position | set as in DTr ; All set inverting the Triangles | All set (2,1x,3)

17--::

  Reels3 on the sides, 1c Rsh to 2cnr

25--::

  Circle6 L{6} | 1c cross Rsh (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9864, '2017-05-17 15:29:01.414904+00', '2021-01-13 20:24:31.257224+00', 12587, 2, 160, 'ace', '1-4::

  1L 2M adv [1] & ret [1] , 1M 2L the same ;

5-8::

  1C 2C turn BH 1_1/4 to line of 4.

9-16::

  Reel4

17-24::

  1C 2C turn BH 3/4, 4hands round to left [4], set.

25-32::

 1C 2C Knot.', 3);
INSERT INTO 'dancecrib' VALUES (11753, '2019-03-31 18:50:45.751318+00', '2019-03-31 18:50:45.751318+00', 15095, 1, NULL, 'ace', '1--::

  1c lead down the middle and up, 2c step in

9--::

  1c+2c Allemande, 1c face 1cnrs

17--::

  Turn CPCP (2,1x,3)

25--::

  All set twice ; 1c turn P 1½ (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2247, '2012-01-22 19:29:27.724663+00', '2019-10-16 10:23:43.183936+00', 2235, 1, NULL, 'ace', '1–::

  1c+2c set | petronella to midline facing P (M below W) ; set | turn BH

9–::

  Reel4 on midline, finish in same positions

17–::

  H.Schottische Poussette, 1c finish with BH turn to face 2cnr, 2c finish with BH turn to 1pl

25–::

  2cnr pass&turn, 1c fast RH turn to face 1cnr ; 1cnr pass&turn, 1c to 2pl. (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2245, '2012-01-22 19:29:27.635895+00', '2021-02-25 20:12:21.540426+00', 9338, 1, NULL, 'ace', '1–::

  1W (2M following) cast into Fig8 round 2W and 1M, to original places, - at the end both dancers swivel R and 2M faces out.

9–::

  2M (1W following) Fig8 round 1M and 2W, to original places (2M swivel R at the end)

17–::

  1c set advancing | turn BH ; dance NHJ between 2c and cast up to finish (2c steps in) for

25–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (14930, '2022-06-29 03:56:12.84523+00', '2022-06-29 13:22:14.347563+00', 20924, 1, 202, 'ace', '1--::
  All set | cross RSh ; chase clw ½. 3c face down and 1c face up (3,2,1)
9--::
  Reels3 on sides, 2c LSh to 3cnrs[pos] (3,2,1)
17--::
  3c+2W & 2M+1c RHA, pass P RSh ; 3c+2M & 2W+1c LHA (3,2,1)
25--::
  2c+3c dance down between 1c | cast up (to 2,3,1) ; all turn P RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (14261, '2021-08-22 07:38:15.832218+00', '2022-04-17 16:37:03.292394+00', 20401, 1, 202, 'ace', '1--::

  1c dance down | set NHJ and face P (2c up) ; change sides, 1W passing under joined arms and 1M crossing below 1W | dance up as for DTr position

9--::

  4 bars of DTr. On [11-12] 1c dance to the right (2 PdB) BtoB with 1W facing up and 1M facing down ; ½ Reels3 across, 1c RSh to 4cnrs. 1c finish as on [12]

17--::

  4 bars of DTr up/down. On [19-20] 1c dance to the right (2 PdB) BtoB facing own sides ; ½ Reels3 on sides, 1c RSh to 3cnrs[pos]. 1c in 2pl face out (3x,1,2x)

25--::

  3C Chain Progression (2x,1,3x)

33--::

  1c ½ Fig8 L round 2cnrs[pos] ; all set | cross RH (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (14197, '2021-08-10 12:09:50.861008+00', '2022-10-14 21:14:08.654763+00', 8076, 1, 202, 'ace', '1--::

  All NHJ on sides slip L ; slip R

9--::

  All W (1W leading) chase cclw round Mline to places

17--::

  All M (1M leading) repeat same pattern clw

25--::

  1c lead down ; lead up to 1pl and face out

33--::

  1c cast off to the bottom (all others step up on [35-36]) ; all turn P RH', 2);
INSERT INTO 'dancecrib' VALUES (8041, '2013-09-18 08:21:06.954805+00', '2015-09-09 22:44:51.889011+00', 15128, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c set | turn P BH ; Circle4 L, finish on diagonal for

9–::

  1c+2c & 3c+4c ½ Poussette ; 1c+4c half Poussette, finish (2,4,1,3) with 4c facing 1c, 2c & 3c facing P

17–::

  (Interlocking Lsh Reels4 round the set, 2c+3c dancing across, 4c+1c on own side) All pass person opposite Rsh | dance Lsh round next person at the corner ; pass Rsh again | dance Lsh round next person at the corner, to (2,4,1,3) with 1c+4c facing out and L

25–::

  Lsh Reels3 on the sides, 4c+1c dancing as one and changing lead (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10845, '2018-06-11 20:44:25.996355+00', '2018-06-12 16:18:28.362661+00', 18380, 1, NULL, 'ace', '1-::

  1c (also 3c) cross NH into &frac12; Fig8 on opposite sides round 4L/2M (2L/4M) &amp; end facing them | all set

9-::

  3M+1W (also 1M+3W) with NHJ change pl with 2c (4c) who make arches | 2c+4c cross RH with small steps _while{2}_ 1W+3M &amp; 3W+1M change pl, W dancing under M arm ; repeat [9-12] from new places

17-::

  4c+1M+3W (also 2c+3M+1W) Circle4 to L, 1M+3W (3M+1W) drop NH &amp; open out ; all &frac12; Circle8 to L (3,2,1,4)

25-48::

  2c &amp; 4c repeat [1-24] to (3,4,1,2)

49-::

  3c+1c &frac12; R&amp;L ; 4c+2c &frac12; R&amp;L (1,2,3,4)

57-::

  All NHJ with P set adv slightly to form a wide circle | set ; 4 spring points | set turning to face P

65-::

  All birl with P, end back in square set with M facing in, W facing P

73-::

  Double M-Chain, end with M facing in, W facing out

81-96::

  Full Schiehallion reel, end facing P

', 5);
INSERT INTO 'dancecrib' VALUES (9294, '2016-09-17 20:11:01.209093+00', '2020-09-27 09:24:01.363456+00', 14371, 1, NULL, 'ace', '1--::

  1c+2c ¾ R&L | set to P (2,1,3)

9--::

  1c turn 1cnr RH | pass Rsh ; turn 2cnr RH | pass Rsh and face out (cnrs dance 4 bars)

17--::

  Rsh Reels3 on the sides (2,1,3)

25--::

  1c+3c ¾ R&L | set to P (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8165, '2014-02-04 01:34:17.18814+00', '2014-11-15 00:40:58.872101+00', 15041, 1, NULL, 'ace', '1-10::

  Snowball Gr-Ch (5 hands), 1c cross to start (3x,1,2x), 1W no polite turn

11-20::

  1c turn LH to face 3cnr (pos!) | turn cnr RH (cnrs dance {4}) | pass Rsh | turn 4cnr RH | pass Rsh into

21-30::

  3c+1W & 1M+2c RHA {4} | 1c turn LH ½ | 3c+1M & 1W+2c RHA {4} (to 3x,1x,2x)

31-38::

  2c+3c set to P | cross RH | set up/down | change RH | _while{8}_ 1c cross RH | cast clw to midline | change RH up/down | cast clw to 2pl

39-40::

  All Set  (2,1,3)



*Note: In an earlier version, for [19-20], 1c turn P LH to finish M below W. In another variant, 1c turn LH 1½ for [25-26]*', 3);
INSERT INTO 'dancecrib' VALUES (2256, '2012-01-22 19:29:28.158224+00', '2020-12-06 11:18:03.578988+00', 2250, 1, NULL, 'ace', '1–::

  1W followed by 1M casts off 2, 1W crosses below 3c and casts up M side _while_ 1M dances up the middle, both to P''s place {6} | 1c set

9–::

  1c repeat with 1M casting, finishing in original places

17–::

  1c lead down the middle and up

25–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (2258, '2012-01-22 19:29:28.246821+00', '2020-12-06 11:22:51.358122+00', 2259, 1, NULL, 'ace', '1–::

  Bottom-Crossing U-Chain (as G-Chain, 2 steps/hand, 3c crosses to begin, but each couple sets at the top instead of crossing) (to 3x,1x,2)

9–::

  1c+2c set and cross RH, 2c ending in 3plx, _while_ 1c remain in middle facing up and change to LH ; 1c lead up LH, cross at top, cast off to face 3cnr position (1cnr person)

17–::

  ½Reel4 on 1diag, pass Rsh ; ½Reel4 on 2diag, 1c cross through 2plx into

25–::

  8-bar Rsh Reels3 with corners on the sidelines, 1c crossing to 2pl on the last bars', 2);
INSERT INTO 'dancecrib' VALUES (2255, '2012-01-22 19:29:28.108133+00', '2020-12-24 18:20:00.695563+00', 10859, 1, NULL, 'ace', '1–::

  1c+3c turn RH | cast off (2c+4c up) ; 1c+3c ½Fig8 up (2,1x,4,3x)

9–::

  1c+3c set | 2c facing 1c & 4c facing 3c set ; turn person opposite RH ¾ to lines of 4 across (men at the ends) facing down | All set

17–::

  In lines of 4 dance down ; swivel R and dance up | drop hands and dance to sidelines, men to 1st & 3rd pos, women follow to 2nd & 4th pos (order on M side 2M,1W,4M,3W , on W side 1M,2W,3M,4W)

25–::

  All set | 1M+1W following & 3W+3M following cast clw to exchanged places | All M set _while{2}_ 3W+2W & 1W+4W change places LH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2746, '2012-01-22 19:29:55.733817+00', '2021-05-09 18:55:01.673763+00', 4155, 1, NULL, 'ace', '1–::

  1c lead down crossing between 2c, cast off round 3c and NHJ up the middle ; 1W LHA (and 1M RHA) with 1cnr+2cnr, 1c finish in 1plx facing out (1x,2,3)

9–::

  1c+2c change places on sides EH | 1c turn BH ¾ to finish facing down, 1M just above 2c and 1W (swivel R) just above 3c ; 1M+2c & 1W+3c Circle3 left, into lines across facing down

17–::

  Lines of 3 dance down the middle, swivel R, dance up, finish line facing line

25–::

  Lines set | cross RH ; set, 2c+3c cross back RH _while_{2} 1c cast to own side (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8168, '2014-02-05 23:05:24.498156+00', '2014-04-30 23:23:50.123295+00', 11518, 1, NULL, 'ace', '1–::
  1c cross | cast (2c up) ; 1c (start inwards) turn 3c EH to (2,1x,3)
9–::
  All set | 1c turn LH ¾ ; 2c+1W + 1M+3c RHA (2,1,3)
17–::
  All set | 1c turn LH ¾ ; 2c+1M & 1W+3c RHA (2,1x,3)
25–::
  1c ½ Fig8 up ; dance down and cast into 4pl (3c+4c up)', 3);
INSERT INTO 'dancecrib' VALUES (2254, '2012-01-22 19:29:28.048255+00', '2016-03-17 23:10:04.346177+00', 9504, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  1c+3c set | »La Baratte« with person opposite, (3x,2,1x,4)

9–::

  1c&3c NHJ set to person opposite | turn that person BH ½ ; 1c+3c Circle4 L to places (1,2,3,4)

17-32::

  2c+4c repeat



{{title}}

Reel



1–::

  All set to P | Turn RH ¾ (W into centre facing P) ; Intersecting ½ Reels4, the M giving brief LH in the centre, at the end the W pass Lsh (no hands) to face M in next position cclw.

9–::

  All set | Turn RH ½ (M in middle) ; repeat [5-8] , the M finish facing P in next place cclw

17–::

  All set to P | turn RH ¾ to face in ; All advance to centre and retire (2,3,4,1)

25–::

  All Circle8 {3} and pass R foot over L ; chase cclw to (2,3,4,1)



{{explanation}}

Repeat once from new places.', 3);
INSERT INTO 'dancecrib' VALUES (10545, '2018-03-23 19:57:38.198107+00', '2018-03-23 20:00:07.673243+00', 11320, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; cross RH | cast R round 3cnrs into facing lines of 3 across

9--::

  1c cross RH | cast R to 2pl _while{4}_ 2c+3c chase clw ¼ | ½ RHA (to 2x,1,3x) ; 1c cross RH | cast R to face 1 cnrs position _while{4}_ 2c+3c chase clw ¼ | ½ RHA (3x,1,2x)

17--::

  ½ Reel4 on 1diag, pass Rsh ; ½ Reel4 on 2diag, 1c ending in centre RHJ facing up, 1W on 1M''s L (2,1,3)

25--::

  1c cross RH between 2c, cast to 2pl ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2261, '2012-01-22 19:29:28.390102+00', '2016-11-02 23:44:51.694471+00', 9802, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; dance between 3c and cast to (2,1,3)

9–::

  Reels3 across, 1c giving Lsh to 1cnr

17–::

  1c turn RH to face 1cnr | turn 1cnr LH ; turn 2cnr RH (to 2,1x,3) | All set

25–::

  1c turn RH to face 3cnr | turn 3cnr LH ; turn 4cnr RH (to 2,1,3) | All set

33–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (2257, '2012-01-22 19:29:28.206428+00', '2014-09-22 12:50:53.747787+00', 2254, 1, NULL, 'ace', '{{explanation}}

This is a centro-symmetrical dance. 3c & 4c start on opposite sides



1--::

  1c+4c Turn RH | cast in to middle places (2c+3c step to ends) ; 1c+4c ½ R&L (to 2,4,1x,3x)

9--::

  4c+1c the Targe: 1W+4W turn ¾ RH _while{2}_ 1M+4M chase ¼ cclw to line up/dn | 1M/4M turn 4W/1W LH ; 1W+4W turn ¾ RH _while{2}_ 1M+4M chase on ¼ cclw | repeat the ¾ RH turns and finish (2,1,4x,3x)

17--::

  Parallel Reels4 on the sidelines

25--::

  End couples with middle couples ½ RH turn on sidelines | middle couples LHA _while{4}_ end couples chase clw ½ round the set | repeat ½ RH turns on sidelines (2,4,1x,3x)

33--::

  All set, turn partner BH ; flowing into 2c+4c & 1c+3c circle4 left (2,4,1x,3x)









', 2);
INSERT INTO 'dancecrib' VALUES (10471, '2018-02-28 09:13:31.242545+00', '2018-02-28 09:40:39.457349+00', 6567, 1, 202, 'ace', '1--::

  All set | turn P RH ¾ ; all W LHA

9--::

  All turn P RH ½ into promhold, dance 1 place cclw, release LH & cross RH ; turn P RH | M leading, all cpls chase clw into circle ready for

17--::

  Circle6 L (to 1,2,3) ; all set to P | turn P RH, M facing in & W facing out ready for

25--::

  8 bars of Schiehallion reels (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (8082, '2013-10-10 22:45:03.248801+00', '2017-08-18 14:29:26.952635+00', 10390, 1, NULL, 'ace', '1–::

  1c set | turn BH ; dance down between 3c (2c up) and cast up (2,1,3)

9–::

  Mirror Reels3 on own sides, 1c start in and up, and finish facing 1cnr, 2c+3c finish with loops

17–::

  Set »H&G«, but 1c stays in the middle, not dancing out to the sidelines or the ends , at end 1c petronella to (2,1,3)

25–::

  1c+3c The Knot _while{8}_ 2c wait{4} ; turn LH (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2259, '2012-01-22 19:29:28.298144+00', '2018-07-14 05:03:12.820967+00', 2260, 1, NULL, 'ace', '1–::

  1W followed by 2W+3W cross, dance behind 1M, in front of 2M, behind 3M, cross and dance up to own places (Ladies'' Train)

9–::

  Men repeat (Men''s Train)

17–::

  1c BHJ slip down the middle (2c up) ; and up to 2pl (2,1,3)

25–::

  2c+1c+3c (NHJ on sidelines) slip down and back', 2);
INSERT INTO 'dancecrib' VALUES (2609, '2012-01-22 19:29:49.802446+00', '2020-12-08 22:44:47.636272+00', 3611, 1, NULL, 'ace', '1–::

  1M casts off _while{4}_ 2W casts up ; they turn BH 1½ to exchanged places

9–::

  1W casts off _while{4}_ 2M casts up ; they turn BH 1½ to exchanged places

17–::

  2c+1c RHA ; LHA

25–::

  2c+1c set twice ; cross RH', 2);
INSERT INTO 'dancecrib' VALUES (1586, '2012-01-20 13:06:12.784296+00', '2021-05-09 23:08:41.492223+00', 4142, 2, 1, 'ace', '1-8::

  1C+2C circle round and back

9-16::

  1C cross R | cast off ; dance ½Fig8 round 2C | pass L to 1crnr (2C up)

17-24::

  1C set to 1crnrs then 2crnrs

25-30::

  1C dance Fig8 round crnrs (RS to 2crnr to start)

31-32::

  1C cross L to 2nd pl own sides



*When the dance is not used to introduce corners, »reels of three with corners«

may be substituted for the figures of eight in bars 25-30.*', 3);
INSERT INTO 'dancecrib' VALUES (3600, '2012-07-21 11:45:32.153692+00', '2014-04-30 23:23:50.216922+00', 2268, 1, NULL, 'ace', '1–::
  1W, 1M following, cast round 2W _while_{4}   4M, 4W following cast round 3M (2c&3c step to end) (to 2,1x,4x,3) ;        1c+4c LHA
9–::
  repeat [1-8] (1x,2x,3x,4x)
17–::
  Reels4 on the sides
25–::
  1c+2c ½ R&L ; 1c+3c ½ R&L
33–::
  1c+4c ½ R&L ; All turn P RH (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2991, '2012-01-22 19:30:05.892403+00', '2022-10-14 21:40:04.372432+00', 8071, 1, NULL, 'ace', '1–::

  2M+1W advance and join RH, 1W dances (clw) under 2M''s R arm, and out to sideline as 2M retires ; 1W+2M turn RH (= Allemande R)

9–::

  1M+2W repeat (RH again)

17–::

  1c cross RH | cast off (2c up) ; cross LH | cast off (3c up)

25–::

  2c+3c+1c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (2265, '2012-01-22 19:29:28.606165+00', '2014-04-30 23:23:50.259901+00', 2277, 1, NULL, 'ace', '1–::
  1c+2c R&L
9–::
  1W+2W dance between the men, cross and cast (1W down, 2W up) to exchanged places ; 2W+1W turn RH
17–::
  1M+2M dance between the women, cross and cast to exchanged places ; 2M+1M turn RH
25–::
  2c+1c Circle4 and back', 2);
INSERT INTO 'dancecrib' VALUES (9145, '2016-05-08 20:49:44.731477+00', '2016-05-08 20:49:44.731477+00', 10956, 1, NULL, 'ace', '1--::

  1M, 1W following, cast off | cross the set to 2plx (2c up) ; All set to P | All change places RH, 1M facing out (2x,1,3x)

9--::

  1M, 1W following cast R round 2M pos and down, into facing lines of 3 across (1W above, 1M below) ; All set up/down | all change places RH into facing lines across again

17--::

  In lines of 3 advance{1}, retire{1} | set ; 2c+3c ½ R&L starting along the sides while{4} 1M, 1W following, cast R around 1W pos and cross to 2pl (2,1,3)

25--::

  All advance {1}, retire {1} | set ; all turn P BH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11755, '2019-03-31 19:50:14.887722+00', '2019-03-31 19:50:14.887722+00', 19250, 2, NULL, 'ace', '1-8::

  Circle round and back.

9-16::

  Set to partner and turn right once round. Set to corner and turn left once round.

17-24::

  Dance around partner right shoulder and left shoulder around corner.

25-32::

  Advance 2 steps and retire. Men pull back right shoulder and cast one position ready to start again.', 0);
INSERT INTO 'dancecrib' VALUES (11754, '2019-03-31 19:20:27.851361+00', '2021-07-20 08:54:13.52147+00', 4758, 1, NULL, 'ace', '1--::

  1W+2M set {4} ; turn BH 

9--::

  1M+2W set {4} ; turn BH

17--::

  1c dance down and up (1,2)

25--::

  1c+2c Allemande  (2,1)   



*The instructions give no details for bars [1-4] and [9-12]*', 3);
INSERT INTO 'dancecrib' VALUES (14445, '2021-11-11 15:22:40.563016+00', '2021-11-11 15:29:09.878229+00', 6718, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides (1,2,3)

9--::

  3C G-Chain, 1c crossing (1,2,3)

17--::

  1c in tandem, 1M leading, cast off | dance up between 2c ; cast off | cross to 2pl (2c up) (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2102, '2012-01-22 19:29:20.180385+00', '2016-07-15 12:49:22.251954+00', 1713, 1, NULL, 'ace', '1–::

  1c+3c set adv | Turn opposite RH to places ; 2c+4c repeat

9–::

  Circle8 and back

17–::

  1c+3c RHA ; 2c+4c LHA

25–::

  All set adv into 8-hand RHA ½ round (long arms!) ; set casting Rsh out and dance to next place clw (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (7904, '2013-08-21 08:31:51.154166+00', '2023-02-04 01:23:10.773391+00', 7068, 3, NULL, 'ace', '1-8::
    1M followed by 2M+3M dance up & down behind Ladies, cross & up own
    side _while_ 1L+2L+3L set twice & circle 3H round to left
9-16::
    Repeat this Fig with Ladies dancing round as Men set & circle 3H
    round
17-24::
    1s+2s dance Poussette.  2 1 3
25-32::
    1s+3s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (3785, '2013-07-13 15:56:05.97252+00', '2014-04-30 23:23:50.42626+00', 14559, 1, NULL, 'ace', '1–::
  All set | cross RH ; Set, cross RH
9–::
  1c lead down the middle (2c up) ; and up to DTr  position facing own side
17–::
  All set | 1c turn 3c EH ½ to DTr pos ; All set | 3c turn 1c back EH (2,1,3)
25–::
  Mirror Reels3{6} on sides, 1c start out and up | 1c cast to 3pl (3c up) (2,3,1)

{{explanation}}
Note: this dance can easily be modified into a 3C/4L dance', 3);
INSERT INTO 'dancecrib' VALUES (2117, '2012-01-22 19:29:21.00685+00', '2015-06-06 01:32:30.41111+00', 1782, 1, NULL, 'ace', '1–::

  1c+2c+3c A&R ; all turn P BH (in SkCh) to own places, (1c finish facing out)

9–::

  1c cast off, dance (NHJ where possible) between 3c, cast up, dance between 2c, cast off (2c up) to put 1M below 1W for

17–::

  1W+2c & 1M+3c RHA, 1c pass Rsh ; 1M+2c & 1W+3c LHA, 1c pass Lsh to face 1cnrs

25–::

  Turn cnr, P, cnr, cross LH (On 2nd time through 1c cross LH to 4pl (3c up), ready for next start)

33–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (11250, '2018-10-05 15:45:47.09617+00', '2019-02-03 21:08:20.173411+00', 18801, 1, 202, 'ace', '1--::

  All turn P RH, 1W & 3M face out ; 1c+3c chase clw ½ _while{4}_ 2c turn LH 1½ (3x,2x,1x)

9--::

  3C S&Link twice (1,2,3)

17-20::

  1c set | cast (2c up)

21-32::

  3C R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2287, '2012-01-22 19:29:29.89082+00', '2019-02-22 22:43:10.285582+00', 2354, 1, NULL, 'ace', '1–::

  1W+2M & 3W+4M cross RH, cast R round P to pl ; 1c+2c & 3c+4c circle4 L

9–::

  1M+2W & 3M+4W cross LH, cast L round P to pl ; 1c+2c & 3c+4c circle4 R

17–::

  1c down the middle ; 1c up the middle, as 4c+3c+2c dance down and fall in behind)

25–::

  1c+4c+3c+2c Allemande (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (9506, '2016-12-04 00:19:01.92278+00', '2016-12-04 00:19:01.92278+00', 12365, 1, NULL, 'ace', '1--::

  1c lead down {3}, set L ; set R , lead to top facing up and 2c step in {3}

9--::

  1c+2c Allemande, on [15-16] 1c turn RH into reverse promhold (M on R), facing 3M

17--::

  1c+2cnrs Rsh Reel3, but at the ends of the reel 1c do not loop but pivot inwards (M now on L) and back to finish in reverse promhold facing 3W 

25--::

  1c+1cnrs Lsh Reel3 in same style, at end drop LH to continue



*Note: 1c keep RHJ throughout both turns the dance, finishing in 4pl of the set.  The final couple finish RHJ in centre and bow to P.*

', 3);
INSERT INTO 'dancecrib' VALUES (14931, '2022-06-29 15:08:52.374015+00', '2022-06-29 15:12:48.455403+00', 20925, 1, 202, 'ace', '1--::

  1c+2c set | cross RSh ; chase clw ½. 2c+1c face each other (2,1,3)

9--::

  Parallel Reels3 on sides, 1c RSh to 2c (2,1,3)

17--::

  All cross RH | 1c dance RSh round 1cnrs[pos] into facing lines3 across _while{4}_ 2c & 3c set ; all change places LH | 1c dance LSh round 3cnrs[pos] to 2pl _while{4}_ 3c & 2c set (3x,1,2x)

25--::

Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10372, '2018-01-06 10:14:04.664036+00', '2019-02-26 17:28:41.717907+00', 14819, 1, 202, 'ace', '1--::

  All set | 1M & 3W Petronella turn _while{2}_ 1W+2W & 2M+3M Petronella turn in tandem, ending 1W+2W in 1pl, 2M+3M in 3pl ; 1M+1W+2W & 3W+3M+2M LHA, 1M & 3W ending Lsh facing opposite sides

9--::

  All W & all M ½ RHA | 3W followed by 2W+1W & 1M followed by 2M+3M chase clw on own sides (to 1,2,3) | all set advancing for

17--::

  3C Poussette (2,3,1)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2270, '2012-01-22 19:29:28.9055+00', '2020-12-21 16:58:32.527267+00', 9989, 1, NULL, 'ace', '1–::

  1c+4c dance in and towards each other | with dancer opposite dance NHJ through the sides and cast to places ; 2c +3c ½ Fig8 round nearst end couple, to finish (1,2x,3x,4) 1c facing 2c and 3c facing 4c

9–::

  Reels4 on the sides, to finish in a St Andrew''s Cross, 1c+4c diagonally facing 2c+3c in the centre

17–::

  All set and change places RH ; 1c+4c (in centre) LHA _while{4}_ 2c+3c (end couples) change places RH along the sides and cross LH (to 3,1,4,2)

25–::

  Four couple Knot: [1] turn RH ½, on [2-5] dance up the ladies'' side, on [6-8] turn LH to own sides (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10619, '2018-04-16 08:49:30.782368+00', '2022-10-14 21:42:54.330924+00', 8054, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; turn LH (2,1,3)

9--::

  2c turn RH | cast (1c up) ; turn LH (1,2,3)

17--::

  1c cross RH | cast (2c up) ; cross LH | cast (3c up) (2,3,1)

25--::

  3c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (8203, '2014-02-16 15:52:59.997535+00', '2014-04-30 23:23:50.54819+00', 13685, 1, NULL, 'ace', '1–::
  1c cross | cast (2c up) ; Turn RH to (2,1x,3)
9–::
  Reels3 across (1c Rsh to 4cnr), 1c finish RHJ and LHJ with 1cnr
17–::
  »The Spoke« (clw), (BiL{1}, move to next cnr{1}, repeat 3 times) finish (2,1x,3)
25–::
  1c ½ Fig8 L (Rsh to 4cnr) ; All turn P RH', 2);
INSERT INTO 'dancecrib' VALUES (12497, '2020-01-12 00:18:08.485851+00', '2020-01-12 00:24:28.93051+00', 19738, 1, 202, 'ace', '1--::

  Inveran Reels (1,2,3)

9-12::

  1c lead down between 3c | cross and cast up to 2plx (2c up) (2,1x,3)

13-24::

  3C R&L (2,1x,3)

25--::

  1c ½ Fig8 L round 4cnrs ; all turn P BH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13198, '2020-09-17 00:35:48.590403+00', '2020-09-17 00:41:12.007353+00', 13152, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 up round 2c and face 1cnrs

9--::

  1c turn 1cnrs RH ¾ into »inverted Crown triangles«, 1c outside facing in | joining hands, all set ; all set advancing into Crown Triangles, 1c BtoB in centre facing out | 1c turn 1cnrs LH to 2plx (2,1x,3)

17--::

  ½ Reels3 on sides, 1c RSb to 2cnrs (to 3,1x,2) ; ½ Reels3 across, 1c LSh to 3cnrs[pos]. 1c face 1cnrs[pos] (3x,1,2x)

25--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag, pass RSh to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2271, '2012-01-22 19:29:28.954556+00', '2021-06-06 12:48:48.232421+00', 2308, 1, NULL, 'ace', '1–::

  1c dance between 2c, cast up, ½ Fig8 round 2c (1x,2)

9–::

  2c repeat between 1c (1x,2x)

17–::

  1c+2c cross RH, set in the sidelines ; dance BtoB with P

25–::

  1c cross RH, cast (2c up) ; ½ Fig8 round 2c (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (2283, '2012-01-22 19:29:29.694819+00', '2021-06-06 12:37:21.447636+00', 2350, 1, NULL, 'ace', '1–::

  1c cast off behind own lines ; cast back to places

9–::

  1c turn RH | cast off (2c up) ; turn LH 1¼ into lines across, 1W up, 1M down

17–::

  All set twice, 1c petronella L (swiveling L) to own side on [19-20] (2,1,3) ; all set twice, 1c finishing BtoB facing own side for

25–::

  DTr (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14262, '2021-08-22 11:43:25.008585+00', '2021-08-22 11:48:59.933237+00', 20400, 1, 202, 'ace', '1--::

  2C S&link ; 2c+1c RHA (2,1,3)

9--::

  2c+1c S&Link ; 1c+2c RHA. 1W faces out (1,2,3)

17--::

  1c (1W leading) cast off | ½ Fig8 round 2c | cross to 2pl (2c up) (2,1,3)

25--::

  Parallel Reels3 on sides {6}, 1c RSh to 3c. 1W & 3M face out | 1c+3c change places RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2274, '2012-01-22 19:29:29.118356+00', '2014-07-14 20:51:12.866257+00', 2317, 1, NULL, 'ace', '{{explanation}}

Set of 2 couples, who start the dance facing each other



{{title}}

Strathspey



{{explanation}}

Part (can be repeated)



1–::

  1c+2c Reel4 across (W cross Lsh first), to finish on a line 2W, 1M, 2M, 1W across

9–::

  All set

17–::

  Repeat Reel4, again finish in a line, with W in same place and men now facing P

25–::

  All set



{{title}}

Reel



{{explanation}}

Part (is repeated the same number of times)  

Dance the same figures in Reel time  

Can be repeated, usually 2 times through  

Often combined with reel of Tulloch', 2);
INSERT INTO 'dancecrib' VALUES (2284, '2012-01-22 19:29:29.76687+00', '2014-09-08 20:51:42.460249+00', 10494, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; cross RH and cast R round 3cnr to face 1cnr

9–::

  SetH&G , to finish 1M between 2c facing 1W between 3c

17–::

  »Diagonal R&L« up/down, finish 1M between 3c in 1pl and 1W between 2c in 3pl, both facing out the end

25–::

  1c+2cnrs ½ Reel4 on 2diag, 1c giving Rsh to 2cnr pos., pass Rsh to face 3cnr ; 1c+1cnrs ½ Reel4 on 1diag, finish (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2290, '2012-01-22 19:29:30.04279+00', '2014-06-30 16:14:25.665505+00', 2360, 1, NULL, 'ace', '{{explanation}}

This dance is a fugue; the M copy the W 8 bars later.  

1W+2W+3W dance:



1–::

  Across the top and behind the men to own places

9–::

  Set | cross ; set | cross

17–::

  Set | cross RH ; chase clw round top to places (3,2,1)

25-40::

  1½Reel3 on own side (2W starts out and down) {12 bars} ; 1W+2W turn LH 1½ (to 2,1,3)

41–::

  stand



{{title}}

while{48}



1–::

  1M+2M+3M stand

9-48::

  the M repeat the W''s movements in mirror image 8 bars later, giving RH on [19-20].-On [28] the M pass just below their P who is 4 bars into the reel, and face up .', 3);
INSERT INTO 'dancecrib' VALUES (2292, '2012-01-22 19:29:30.126862+00', '2020-12-21 16:33:56.847893+00', 9820, 1, NULL, 'ace', '1–::

  1c+2c+3c+4c set | 1c+3c cast to midline Lsh to Lsh _while{2}_ 2c+4c dance up ; 2c+1W & 1M+4c+3W & 3M+5c RHA, finish (2,1,4,3,5), with 1c+4c in the middle facing up, and 3c+5c in the middle facing down

9–::

  Dbl Allemande: 1c+4c »Normal Allemande, 3c+5c (leading) »Reverse Allemande« (LHJ over W''s shoulder, all moves mirrored), finish (2,4,1,5,3) with 4c & 5c facing 1cnr

17–::

  Turn CPCP:  4c & 5c turn 1cnr RH | P LH ; 2cnr RH | P LH to midline facing opp side

25–::

  2c+4W & 4M+1c+5W & 5M+3c RHA to sidelines ;  4c+5c turn LH (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (10136, '2017-09-17 15:50:43.527262+00', '2020-08-29 15:51:10.462825+00', 1183, 2, 111, 'ace', '1-8::

 1c turn RH, cast 1 pl (2s up); 1c turn LH

9-16::

 2c turn RH, cast 1 pl (1s up); 2c turn LH

17-24::

  1c cross RH, cast 1 pl (2s up); 1s turn RH 1-1/2 to own side

25-32::

  Circle 6 hands around and back', 4);
INSERT INTO 'dancecrib' VALUES (2285, '2012-01-22 19:29:29.808314+00', '2019-02-22 22:30:32.822005+00', 2352, 1, NULL, 'ace', '1–::

  1M+2M+3M set, 1W+2W+3W set ; 1W+2W+3W cross and dance Rsh round P to places

9–::

  1c+2c+3c the Knot for 3 couples  (3,2,1)

17–::

  All the M dance Lsh round P to places ; 3c+2c+1c (1c leading) lead down the middle, 3c divides

25–::

  2c+1c turn in and lead up, 3c following, 2c dances to top, 1c+3c finish for ; 1c+3c ½ Poussette (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11752, '2019-03-31 18:50:45.750673+00', '2019-03-31 22:02:57.532973+00', 15095, 2, NULL, 'ace', '1-8::

  1s lead down the middle and up. Finish in centre with 2nd couple stepping in on #8

9-16::

  1s & 2s: allemande: 1s finish facing 1st corners.

17-24::

  1s turn 1st corner RH: partner LH: 2nd corner RH & partner LH to finish in second place on opposite sides.

25-32::

  2s, 1s, 3s NH joined set twice,  1s turn 2H 1&1/2 to finish in second place on own sides. ', 0);
INSERT INTO 'dancecrib' VALUES (9983, '2017-06-28 00:43:34.804247+00', '2019-02-09 17:44:42.500411+00', 17796, 1, 202, 'ace', '1--::

 1c+2c & 3c+4c RHA ; 1c cast off to 4pl _while{4}_ 4c dance up to 1pl (4,2,3,1)

9--::

 2c+3c Poussette

17--::

 4c cast off to 4pl _while{4}_ 1c dance up to 1pl ; 1c+2c NHJ & 3c+4c NHJ set advancing to finish BtoB | 1c+4c repeat [21-22] _while{2}_ 2c & 3c turn inwards to 1pl/4pl, on [24] all finish in Reel4 pos

25--::

 Reels4 (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13659, '2021-02-10 15:47:18.617661+00', '2021-02-10 16:10:21.533543+00', 17952, 1, 202, 'ace', '1--::

  1c+2c The Tourbillon. On [7-8], 2c turn P RH ¾ to midline. 1c face clw _while{8}_ 3c stand still | set in line in three ; turn P BH ½ | turn P RH ¾ to midline (on midline, 2M,2W,3M,3W in Reel4 position)

9--::

  »Weasel Reel« [: All continuously dance ½ Reel4 on midline, dancers who reach the end cast clw on own side and rejoin the reel at the other end. All finish as on [9]. Dancers entering and leaving the reel pass RSh.]

17--::

  2c & 3c Petronella Turn to sides _while{2}_ 1c A&R {1+1} | all set ; ½ Reels3 on sides, 1c RSh to 4cnrs. Cnrs loop to places where appropriate (3,1,2)

25--::

  3c+1M & 1W+2c LHA, pass LSh ; 3c+1W & 1M+2c RHA (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (2286, '2012-01-22 19:29:29.849469+00', '2021-05-01 21:58:41.416169+00', 2353, 1, NULL, 'ace', '1–::

  1c turn RH | cast off one (2c up) ; 1c turn RH ¾ and dance Rsh round 4cnr to (2,1,3)

9–::

  1c passing Lsh turn 1cnr RH | pass P Rsh ; turn 2cnr RH | cross Rsh to 2pl facing out and up (2,1,3) into

17–::

  Mirror Reels3{6} on own sides | 1c+2c dance an extra loop to finish (1,2,3)

25–::

  1c+2c Tournée', 3);
INSERT INTO 'dancecrib' VALUES (2295, '2012-01-22 19:29:30.354557+00', '2021-03-13 15:38:01.738571+00', 2367, 1, NULL, 'ace', '1–::

  1W+2W (NHJ) cross and cast round P to own places | 1c+2c set

9–::

  All chase clw once round (3W & 1M leading) to (1,2,3) ready for

17–::

  1c+2c+3c Allemande (3,2,1)+

25–::

  1c dance to top and cast off on own side to face 1cnrs _while{4}_ 3c cast off to own places (2c up) ; 1c set to 1cnr | set to 2cnr

33–::

  1c Reels3{6} with cnrs (Rsh to 2cnr) | cross RH', 3);
INSERT INTO 'dancecrib' VALUES (13942, '2021-04-08 11:25:25.093075+00', '2021-04-08 11:29:05.907564+00', 3067, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; ½ Fig8 up round 2c (2,1x,3)

9--::

  Mirror Reels3 on sides, 1c dancing NHJ in and down, 2c & 3c touching NH before casting into reels (2,1x,3)

17--::

  1c lead down ; turn P RH under joined arms, lead up to 2pl (2,1,3)

25--::

  1c+3c set | ½ RHA (to 2,3x,1x) ; 2c turn BH _while{4}_ 3c & 1c turn BH 1½ (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2288, '2012-01-22 19:29:29.932318+00', '2021-06-06 10:10:24.808402+00', 2357, 1, NULL, 'ace', '1–::

  1c turn RH, cast off one place ; turn LH and cast up to top place.

9–::

  1c+2c A&R ; cross RH.

17–::

  1M+2W set & change places RH ; 1W+2M repeat.

25–::

  2c+1c R&L.', 2);
INSERT INTO 'dancecrib' VALUES (14320, '2021-09-16 23:05:06.105719+00', '2021-09-16 23:06:28.504195+00', 20456, 1, 1645, 'ace', '*3c & 4c start on opposite side (1,2,3x,4x)*
1--::
  1c & 4c &frac12; Fig8 through 2c/3c ; cross RH | cast inwards (2c & 3c out) to (2,1,4x,3x)
9--::
  1W & 4W cross over _while_ 1M & 4M dance down/up side | all turn corner RH, retain RH & join LH in centre | BiL
17--::
  1c & 4c dance to next corner cclw | repeat [11-16]
25--40::
  Repeat with next two corners (2,1,4x,3x)
41--::
  1c & 4c cross LH out nearest end | cast in ; change pl RH on sides | all set (2,4,1x,3x)
', 2);
INSERT INTO 'dancecrib' VALUES (2299, '2012-01-22 19:29:30.512203+00', '2014-04-30 23:23:50.821791+00', 2388, 1, NULL, 'ace', '1–::
  1c+2c & 3c+4c RHA ; 1W & 4M (partners following) chase clw behind sidelines to other end (4x,2,3,1x)
9–::
  Repeat from new positions, to own places
17–::
  1c facing 2c & 3c facing 4c set | change places RH ; 1c+4c repeat LH (2,4,1,3)
25–::
  1c & 4c dance out between nearest end couple and cast back ; all C turn RH (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3786, '2013-07-13 15:56:06.325354+00', '2017-09-16 00:35:19.119991+00', 14642, 1, NULL, 'ace', '1–::

  1c petronella to midline | Set moving down (2c up) ; pass RH and cast Rsh round 2cnr to (2,1x,3)

9–::

  1c (on R)+1cnr, with NHJ and facing diagonally, S&Link ; Circle4 L into lines across (1W betw. 2c above, 1M betw. 3c below)

17–::

  All S&Link3 to sidelines (2x,1,3x) ; 1c dance clw round 2cnr (position) who Turn RH (to 2x,1x,3x)

25–::

  1c cast L round 1cnr (position) who Turn LH ; All set and cross RH (2,1,3)



{{explanation}}

(may also be danced as a strathspey; then [1-8] should read  

1c petronella to midline | Set moving down ; 1c+2c ½RHA | 1c cast Rsh round 2cnr as 2c turn RH ½ to (2,1x,3))', 3);
INSERT INTO 'dancecrib' VALUES (2294, '2012-01-22 19:29:30.314163+00', '2018-04-07 22:47:21.343106+00', 2365, 1, NULL, 'ace', '1–::

  1W+2W cross down below P, cast down and in, dance up the middle and cast to own place

9–::

  1M+2M repeat

17–::

  1c+2c RHA ; lead down RHJ

25–::

  1c+2c RHA ; lead up and out to places (1,2,3)

33–::

  Espagnole [both W lead RHJ to M side, cross & cast back to exchanged places _while{4}_ both M cross to W side, lead RHJ back to M side and cross to exchanged places ; all turn P EH] (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10548, '2018-03-25 19:03:03.632962+00', '2018-03-25 19:05:58.643217+00', 12312, 1, 202, 'ace', '1--::

  1c+3c R&L finishing in promhold _while{8}_ 2c+4c set | cross RH ; set | cross RH finishing facing out

9--::

  1c+4c & 3c+2c ½ Reel3, Lsh to 4W/2W ; 1c+2c & 3c+4c repeat [9-12], Lsh to 2M/4M (1,2,3,4)

17--::

  ½ Double La-Chain ; all S&Link, ending M facing clw, W facing cclw

25--::

  All set | change places RH {1}, change places LH {1} with next person ; all turn P RH 1 ½ (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11756, '2019-03-31 22:34:23.566877+00', '2019-04-05 00:54:59.032969+00', 19251, 2, NULL, 'ace', '1-8::

  1s and 2s dance half rights and lefts; 1s and 2s set and cross right hand (2s stay facing out).

9-16::

  2s and 3s dance double figure of eight round 1s (2s cast, 3s cross up)

17-24::

   2s,  1s and 3s allemande.

25-32::

   3s,  1s and 2s six hands round and back.', 5);
INSERT INTO 'dancecrib' VALUES (9985, '2017-06-28 23:51:51.124943+00', '2021-01-04 11:59:08.69463+00', 9483, 1, 202, 'ace', '1--::

 1c+2c & 3c+4c RHA ½ | 1c+4c LHA ½ _while{2}_ 2c & 3c cross RH ; 2c+4c & 1c+3c RHA ½ | 2c+3c LHA ½ _while{2}_ 4c & 1c cross RH (4,3,2,1)

9--::

 All set | cross RH ; repeat [9-12] (4,3,2,1)

17--::

 Repeat [1-8] (1,2,3,4)

25--::

 1c cross down RH (2c up) | cast to 3plx (3c up) ; 1c cross down LH (4c up) | all turn P BH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2297, '2012-01-22 19:29:30.434085+00', '2023-01-27 12:09:14.294378+00', 2380, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1M+2W turn BH 1½ to change places ; 1W+2M repeat

17–::

  1c face 2c and set H.Schottische ; 2c+1c half circle4 left {2}, 1c cast off one and 2c dance up to top (NHJ)

25–::

  2c+1c set and cross Rsh ; repeat', 2);
INSERT INTO 'dancecrib' VALUES (2309, '2012-01-22 19:29:30.934236+00', '2014-04-30 23:23:50.998358+00', 7546, 1, NULL, 'ace', '{{explanation}}
Circle, all C face cclw.

1–::
  March 4 steps in Allemande hold (L.R.L.R). swiveling R on 4th step, to face clw | March 4 steps backward (L.R.L.R.) ; repeat
9–::
  M marches (or dances) 8 steps forward, _while_{4} P advances swiveling R under his up-raised right arm ; Take ballroom hold and polka (or waltz), finishing in original position, ready to repeat', 2);
INSERT INTO 'dancecrib' VALUES (2312, '2012-01-22 19:29:31.08567+00', '2016-04-30 12:52:01.893576+00', 2436, 1, NULL, 'ace', '1–::

  1c cross down, set to 3c ; 1M+3W lead up behind 2W to face down between 2c _while_{4} 1W+3M lead down behind 4M to face up between 4c

9–::

  1M+3W and 1W+3M advance down/up | lead partners (3c use LH) back to (1,2,3,4) ; 1c+2c+3c turn LH into promhold facing up

17–::

  1c+2c+3c Promenade

25–::

  1c cast off two, lead up to the top and cast to the bottom (2c+3c+4c up)', 3);
INSERT INTO 'dancecrib' VALUES (2335, '2012-01-22 19:29:31.993407+00', '2022-07-01 13:43:52.768064+00', 2518, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1c+2c Turn P RH ; LH

17–::

  1c lead down the middle (2c up) ; and up to 2pl

25–::

  2c+1c Circle4 and back.', 2);
INSERT INTO 'dancecrib' VALUES (13787, '2021-03-04 10:06:02.020602+00', '2021-03-04 19:09:17.739293+00', 17322, 1, 202, 'ace', '_Strathspey_

1-::

  1c+2c »Half Rondel« [: 3 bars of Rondel in {4} ; all set to P | cross RH]. On [7-8] 1c turn RH to face 3cnrs[pos] (2,1,3)

9--::

  »Set to Corners and Cast Away« [:1c set to 3cnr[pos] | 1c cast RSh round P to 1cnr[pos] _while{2}_ cnrs on 1diag dance into centre and swivel R BtoB to face own cnr[pos] ; repeat, cnrs on 1diag finishing in exchanged places and 1c facing 4cnrs[pos]]

17--::

  Repeat [9-16] with 4cnrs[pos]. On [31-32] 1c dance to centre ready to join RH

25--::

  2c+3c chase 1 place clw and set diagonally _while{4}_ 1c turn RH into lines3 across, 1W between 2W & 3W on top ; all chase 1 place clw | set (2,1,3)



_Reel_

33-64::

  Repeat [1-32] in reel time



*Note:  

»Set to Corners and Cast Away« is also called "Best Set in the Hall Figure".*

', 2);
INSERT INTO 'dancecrib' VALUES (2300, '2012-01-22 19:29:30.552136+00', '2021-06-05 11:50:47.373644+00', 2389, 1, NULL, 'ace', '1–::

  1c cast off behind own lines, turn out and back to place

9–::

  1c+2c circle4 and back

17–::

  1c turn RH | cast off (2c up) ; turn LH

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (3320, '2012-01-22 19:30:20.416752+00', '2020-09-17 22:32:30.379611+00', 13463, 1, NULL, 'ace', '1–::

  1c cross RH | Cast off 2 (2c+3c up) ; 1M+3c & 1W+4c RHA, finish (2,3,1x,4,5)

9–::

  1c ½ Fig8 L (1W up, 1M down) ; 3c+1M & 1W+4c LHA (to 2,3,1,4,5)

17–::

  2M+1W & 1M+5W turn RH, pass Rsh ; 2W+1M & 1W+5M turn LH (2,3,1,4,5)

25–::

  1c long cast off 2 (4c&5c up) ; All turn P BH in skip-change', 3);
INSERT INTO 'dancecrib' VALUES (2298, '2012-01-22 19:29:30.472372+00', '2021-06-07 11:03:45.686736+00', 2226, 1, NULL, 'ace', '1–::

  1c cast off two, lead up between 3c to top, cast off on own sides to face first corners (2c up on 7‑8)

9–::

  1c turn 1cnrs RH, pass Rsh ; turn 2cnrs RH, pass Rsh (corners 4 bar turns)

17–::

  Repeat with 3cnrs and 4cnrs, finishing on own sides in 2pl

25–::

  2c+1c+3c circle6 and back.', 2);
INSERT INTO 'dancecrib' VALUES (2145, '2012-01-22 19:29:22.435045+00', '2021-06-08 10:18:27.087666+00', 9817, 1, NULL, 'ace', '1–::

  2c+3c RHA _while{4}_ 1c+4c set and turn RH ½ (all keep handhold with P) ; 1c+2c & 3c+4c RHA (1x,2,3,4x)

9–::

  ½ Reel4 on sideline ; 2c Turn 3c ½ LH on sideline | 2c+3c cross Lsh and face out (4x,2x,3x,1x)

17–::

  2c+3c turn corner EH, and finish facing out on the sides, 2W leading 2M on M side, 3M leading 3W on W side ; Opposing ½ Reels3 across, 2c & 3c dancing in tandem, giving Rsh to 1cnr, finish (2,4,1,3), with 2c+3c a bit inside the sidelines

25–::

  Circle8 and back (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14319, '2021-09-16 08:11:18.94742+00', '2021-09-16 11:49:55.092834+00', 20488, 1, 202, 'ace', '1--::
  1c & 3c set | ½ Fig8 down round nearest couples | all set (no hands), all W pivoting R on PdB L to face out (1x,2,3x,4)
9--::
  1c+2c & 3c+4c *Lady-boy Chain* : like La-Chain except all have opposite sex role ; repeat [9-12]. All W face out (1x,2,3x,4)
17--::
  All W *The Kissing Gate* : all W dance LSh round next M, meet in centre and pass giving RH, dance RSh round P to exchanged places
25--::
  All M *The Kissing Gate* : All M cast behind P, meet in centre and pass giving LH, dance LSh round W on Mside to exchanged places. On [32] 1W & 3M face out (2x,1,4x,3)
33--::
  1c (1W leading) & 3c (3M leading) chase clw to exchanged places (to 2x,3x,4x,1x) ; all set | cross RH (2,3,4,1)
41--::
  2c+3c & 4c+1c Circle4 and back (2,3,4,1)

*Deviser''s note* : Last time through  
41-48:: Circle8 and back', 4);
INSERT INTO 'dancecrib' VALUES (14321, '2021-09-17 21:12:28.381041+00', '2021-09-17 21:16:01.210545+00', 10480, 1, 1645, 'ace', '1--::
  1c+2c set | cross RH ; set | &frac12; turn RH ready for
9--::
  1c+2c Allemande, on [15-16] 1c turn slightly LH & join RH with 1cnrs *(the "fudge")*
17--::
  1c+1cnrs BiL | 1c turn 1cnrs RH ; BiL | 1c turn P 1&frac14; LH to join RH with 2cnrs
25--::
  Repeat with 2cnrs, 1c end in 2pl own side (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2089, '2012-01-22 19:29:19.162518+00', '2021-02-11 15:05:58.953287+00', 10114, 1, NULL, 'ace', '1–::

  1c+3c set diagonally in their square | cast clw one place in square ; 1M+3M+2c RHA _while_{4} 1W+3W+4c LHA

9–::

  1c+3c set and cast clw again as in [1-4] (3x,2,1x,4) ; 2c+3c Circle4 L _while_{4} 1c+4c Circle4 R

17–::

  1M makes a free choice Reel3 with either 2W+1W (Lsh) or with 3W+4W (Rsh)

25–::

  1M Reel3 with the other two women

33–::

  All set to P ; turn LH ; Half G-Chain, all starting up/dn on sideline (4x,1,2x,3)

41–::

  Facing up/dn in pairs on sidelines, set | turn RH ; 4c+2c set and cross (4,1,2,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9953, '2017-06-11 22:53:38.680423+00', '2017-09-05 13:53:24.976201+00', 7866, 1, NULL, 'ace', '*Set: 3 trios WMW form a square, all face the top.  The M are 1M, 2M, 3M.  Each M has a LW on his L and a RW on his R*



*2 chords: M honour W on R ; honour W on L*



1--::

  All M NHJ with RW promenade cclw round line of LW, to places

9--::

  All M NHJ with LW promenade clw round line of RW, to places

17--::

  1M+2LW+2RW+3M Circle4 L and back

25--::

  1LW+1RW+3LW+3RW Circle4 L and back

33--::

  1M+1RW+2M+2RW LHA ; 1M+1LW+2M+2LW RHA, to places

41--::

  2M+2LW+3M+3LW LHA ; 2M+2RW+3M+3RW RHA, to places

49--::

  All lines across: Reels3 across, each M starts Rsh to his RW

57--::

  1LW followed by 1M+1RW cast off below 2LW, dance across the set, cast off round 3RW, and across.



*Cribwriter''s note: Standing lines step up during [57-64], otherwise the set will move down one place each time.*', 3);
INSERT INTO 'dancecrib' VALUES (10138, '2017-09-18 20:20:00.412276+00', '2017-09-18 20:20:00.412276+00', 1025, 1, NULL, 'ace', '1--::

  1c turn RH | cast off (2c up) ; 1c turn RH to face P as 2c+3c step in and all form circle NHJ | all set

9--::

  All petronella one place R in the circle | Set in circle NHJ ; repeat

17--::

  1c face cclw and dance round set to 2pl _while{4}_ 2c+3c RHA (to 3x,1,2x) ; 1c turn LH 1½ and face out (3x,1x,2x)

25--::

  1c Fig8 on side (Lsh to 2cnr ; Rsh to 1cnr and cross to own side) _while{8}_ 2c+3c ½ R&L ; wait{4} (2,1,3) 

', 3);
INSERT INTO 'dancecrib' VALUES (2318, '2012-01-22 19:29:31.323093+00', '2020-12-20 23:36:58.998106+00', 9115, 1, NULL, 'ace', '1–::

  All A&R | 1c+2c & 3c+4c ½ RHA ; All C turn RH ½  to face P in the middle | twirl out to sides (as Argyll Strathspey)

9–::

  1c+4c circle4 L, finish 1c facing 4c NHJ ; 1c dances down under arch and cast up round 3c _while{4}_ 4c dance up (arch) and cast off round 2c

17–::

  2c+4c & 1c+3c Poussette (2,4,1,3)

25–::

  3c dance up 2 places (4c+1c down) | 2c+3c+4c Reels3{6} on the sides (3c start out and up)', 2);
INSERT INTO 'dancecrib' VALUES (12952, '2020-07-07 10:49:18.481319+00', '2020-07-07 11:00:13.360527+00', 3251, 1, 202, 'ace', '1--::

  1c & 2c Petronella turn all facing own sides | BiL NHJ ; 1M+2W turn LH ¾ _while{2}_ P chase clw ¼ into line4 across | BiL NHJ

9--::

  1c & 2c turn RH ½ | 1M (1W following) & 2W (2M following) chase clw to own sides (to 2,1,3) ; 2c+1c Circle4 L (2,1,3)

17--::

  Mirror Reels3 on sides, 1c in and up. 1c face 1cnrs

25--::

  1c turn 1cnrs RH | pass P RSh ; turn 2cnrs LH | dance to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3696, '2013-02-01 16:09:11.928035+00', '2017-09-26 00:56:56.724663+00', 14700, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c ½ DblFig8 (1c & 3c cross down) ; 3c & 1c following dance out the bottom and cast up to (3x,2x,1x,4x)

9–::

  3c+2c & 1c+4c S&Link, finish in centre ; 2c facing 3c & 4c facing 1c S&Link across (2,3,4,1)

17–::

  2c+3c & 4c+1c RHA ; All turn (or birl) to (2,3,4,1)

25–::

  All Circle6 L, pivot L and chase cclw to (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2321, '2012-01-22 19:29:31.440688+00', '2021-06-05 09:56:53.434179+00', 2464, 1, NULL, 'ace', '1–::

  1c+4c long cast to middle (2c & 3c step to ends) ; LHA

9–::

  2c+1c & 4c+3c DblFig8 (end couples cross to begin) (2,1,4,3)

17–::

  All set, 1c+4c ½ RHA ; all set, 4c+1c cross RH (2,4,1,3)

25–::

  2c+4c & 1c+3c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (10550, '2018-03-26 01:13:16.382565+00', '2018-03-26 01:22:55.92347+00', 12226, 1, 202, 'ace', '1--::

  1c Reels3 on opposite sides (1x,2,3)

9--::

  1c turn RH | cast (2c up) ; 1c cast R round 2cnrs (2,1x,3)

17--::

  1c Reels3 across, start Lsh to 3cnrs (2,1x,3)

25--::

  1c turn RH | cast ; 1c cross LH | cast up (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2443, '2012-01-22 19:29:39.126551+00', '2016-01-07 23:46:23.51672+00', 2979, 1, NULL, 'ace', '1–::

  All clap, 1c cross Rsh and cast off one (2c up) ; 1c+3c RHA

9–::

  All clap, 1c cross back Rsh, cast up to own place (2c down) ; 1c+2c LHA

17–::

  1M+3W change places RH | 1W+3M change RH, _while{2}_ 1M+3W dance a Rsh loop ; 1M+3W cross back RH _while{2}_ 1W+3M loop | 1W+3M cross back LH, 1W to 2pl _while{2}_ 1M casts to 2pl (2c up)

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (3766, '2013-06-25 20:31:23.396366+00', '2022-10-14 22:18:59.092305+00', 7941, 2, 1058, 'ace', ' 1- 8::

  1s+2s+3s dance reels of 3 on the sides (1s in & down to start)

 9-16::

  1s dance down between 2s+3s & cast up to 2nd place, 1L+3L turn LH 1.1/2 times while 1M+3M turn RH 1.1/2 times

17-24::

  1s+4s+5s dance reels of 3 on sides (1s out & down to start)

25-32::

  1s cast below 5s & dance up middle to 4th place, 1L+5L turn RH 1.1/2 times while 1M+5M turn LH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (9288, '2016-09-10 22:54:06.484752+00', '2016-09-11 23:25:41.589646+00', 15136, 1, NULL, 'ace', '1--::

  1c+2c ½ R&L ; turn P RH 1¼ onto midline, all facing P

9--::

  All set to P | ½ Reel4 on midline | 1W+2M (= “middles”) turn LH 1¼ as 2W+1M (“outers”) dance clw ¼ , into line across, all facing P

17--::

  All set to P | ½ Reel4 in line across | ”middles” turn LH 1¼ as “outers” dance ¼ clw, to midline

25--::

  1c+2c ½ Reel4 on midline ; All turn P RH 1¼ (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (13786, '2021-03-04 00:59:37.075178+00', '2021-03-04 17:47:11.447036+00', 19600, 1, 202, 'ace', '1--::
  1c lead down between 3c | cross and cast up to 2plx (2c up) ; 1c lead up to top | cross and cast off to 2pl (2,1,3)
9--::
  Mirror Reels3 on sides taking hands where possible, 1c in and down, 3c out and up (2,1,3)
17--::
  1c turn 1cnrs RH | pass P RSh ; turn 2cnrs RH | pass P RSh to 2pl. Cnrs dance 4 bars each time (2,1,3)
25--::
   Circle6 L {3}, cross R foot over and pivot L ; chase cclw (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (3626, '2012-07-21 11:46:10.370714+00', '2021-02-12 18:26:13.268998+00', 10083, 1, NULL, 'ace', '1–::

  All turn P BH ; 2c ½ Fig 8 to the L (1,2x,3)

9–::

  All set to P | Circle6 L {2}, M turn W behind BH and circle6 on to (1,2x,3)

17–::

  2c turn BH ½ and twirl to own sideline facing out ; cast L and cross to opposite side and face out (1,2x,3)

25–::

  Opposing Reels3 on the sides, 2c starts Lsh to 2cnr (1W & 3M), from [31] 2c cross to own side as 1c+3c finish the reels.(1,2,3)

33–::

  1c ½ Fig8 round 2c ; cross down (2c up) | cast behind 3c (3c up) (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (14315, '2021-09-15 21:29:02.10529+00', '2021-09-16 12:24:33.144117+00', 20491, 1, 202, 'ace', '1--::

  1c+2c set | turn P BH opening into ; Circle4 L (1,2,3)

9--::

  1c ½ Fig8 down round 2c ; ½ Fig8 down round 3c (2c up) to face 1cnrs

17--::

  *Corners Pass and Twirl* : Like Corners Pass and Turn except on [19-20] & [23-24] where cnrs cast away to exchanged places (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (2307, '2012-01-22 19:29:30.855208+00', '2021-06-05 11:34:38.393852+00', 2419, 1, NULL, 'ace', '1–::

  1c cross RH, cast to 2pl (2c up) ; 2c+1c+3c circle6 L (2,1x,3)

9–::

  All set to P | cross RH ; repeat, 1c finish facing 1cnrs

17–::

  Set to and turn corners, finish between corners

25–::

  Reels3{6} with the corners, start Lsh to 1cnr | 1c cross to own side (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11986, '2019-07-27 12:50:25.211245+00', '2021-07-25 20:11:49.151075+00', 12375, 1, 1645, 'ace', '1-::

  5c set | &frac12; turn RH ; 5W+1c & 5M+3c LHA

9-::

  5c turn 1&frac34; turn RH ; 5M+2c & 5W+4c LHA

17-::

  1W+5W+3M & 1M+5M+3W Reels3, 5M/5W start RSh to 3W/1W & end facing down/up

25-::

  5c set | La Barratte & retain LH

33-::

  5c set LHJ | turn &frac34; LH ; 5W+2c & 5M+4c RHA

41-::

  5c turn 1&frac34; turn LH ; 5M+1c & 5W+3c RHA

49-::

  2W+5M+4M & 2M+5W+4W Reels3, 5M/5W start RSh to 4M/2M & end facing 5c, all take allemande hold

57-::

  5c+1c change places LSh ; 1c+2c repeat ; 2c+3c repeat ; 3c+4c repeat, 4M turning 4W under his R arm to end 4M facing 2pl above 4W facing 4pl (5,1,2,3,4)

', 2);
INSERT INTO 'dancecrib' VALUES (2319, '2012-01-22 19:29:31.361581+00', '2015-11-02 13:07:02.017965+00', 9813, 1, NULL, 'ace', '1–::

  1c dance down the middle and up to 2pl _while{8}_ on [3] 2c (ghosts) dance down two places and cast up to 1pl (before 1c can see them) (2,1,3,4)

9–::

  1c dance BtoB (suspicious) ; All turn RH

17–::

  1c+2c(ghosts, following)+3c+4c Reels3 on sidelines, 1c starts in and down, at the end 2c slip quickly to 1pl (2,1,3,4)

25–::

  1c dance in and face opposite side BtoB (suspicious) | join BH backwards and ½ Turn R to face own sides ; cast down (no extra turn) to 4pl (3c+4c up)



{{explanation}}

on [24] 2c may sneak a little on bar 25 but not more. ', 4);
INSERT INTO 'dancecrib' VALUES (2327, '2012-01-22 19:29:31.673543+00', '2017-02-14 16:20:05.037294+00', 9819, 1, NULL, 'ace', '1–::

  2c set | Turn ½ RH and face up ; lead between 1c cross and cast to (1,2,3)

9–::

  2c, with 1c following, Fig8 round 3c, finish (2,1,3)

17–::

  2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA (Teapots R ; L), 2W and 3M face out

25–::

  Opposing Reels3 across, Lsh to 1cnr, to (2,1,3)

33–::

  All Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (10472, '2018-02-28 16:59:26.114452+00', '2018-02-28 17:03:50.159832+00', 13680, 1, 202, 'ace', '*3c & 4c start on opposite sides (1,2,3x,4x)*

1--::

  1c & 4c set | cast inwards (2c & 3c step out) (to 2,1,4x,3x) ; 1c & 4c ½ Fig8 round nearest ends (2,1x,4,3x)

9--::

  1c+4c S&Link ; Circle4 L (2,4,1x,3x)

17--::

  2c+4c & 1c+3c Reverse S&Link ; 4c+2c & 3c+1c Circle4 R (4,2,3x,1x)

25--::

  4c+2c & 3c+1c »The Helix« [Both cpls set passing Lsh | cast R to own place ; turn P RH ½ | ½ RHA] (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (2330, '2012-01-22 19:29:31.793138+00', '2021-06-03 19:43:46.98666+00', 2495, 1, NULL, 'ace', '1–::

  1c+2c RHA, LHA

9–::

  1c+2c+3c RHA, LHA (6 hands)

17–::

  1c lead down the middle (2c up on [19-20]) ; and up to 2pl (2,1,3)

25–::

  2c lead down the middle, followed by 1c+3c ; all cast up to places', 3);
INSERT INTO 'dancecrib' VALUES (2332, '2012-01-22 19:29:31.874068+00', '2020-12-06 18:28:11.008374+00', 2501, 1, NULL, 'ace', '1–::

  1M+2W set | cast (2M steps up, 1W down) ; turn BH (to 2,1)

9–::

  1W+2M repeat [1-8] (1M steps up, 2W down) (1,2)

17–::

  1c+2c set | 1c cross RH ; cast off into line of 4 between 2c | 1c+2c dance to top NHJ, finish 1c BtoB between 2c

25–::

  1c+2c set | 2c set _while{2}_ 1c Petronella (M down, W up) to face P on midline ; 1c dance to meet, join RH (1W now faces up) dance to top and cast off (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (2334, '2012-01-22 19:29:31.954084+00', '2015-12-30 14:31:12.954248+00', 2506, 1, NULL, 'ace', '1–::

  1c+2c ½ DblFig8 (1c cross down to begin) ; 1c turn 2c easy hand on side (1c inwards) (1x,2x)

9–::

  Repeat from new positions (1,2)

17–::

  1c+2c RHA and dance to centre and pull Rsh back ; dance out to places | all set (facing in)

25–::

  1c+2c Espagnole.



{{explanation}}

Espagnole: both W lead RHJ to M side, cross and cast back to exchanged places while{4} Men cross to W side, lead RHJ back to M side and cross to exchanged places ; all turn P EH (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (2342, '2012-01-22 19:29:32.262175+00', '2015-02-18 22:59:26.009138+00', 250, 1, NULL, 'ace', '1--::

  Crossover Reels3 on the sides, 1c crosses down, to (1x,2,3) with 1c +3c slightly in from sidelines

9--::

  1c+3c L-Chain, down/up, at end M with P behind face out (1x,2,3)

17--::

  1c+3c, M leading, cast R into each a full Fig8 round 2c, passing Lsh first time, Rsh second time (“hug your turning post”), into

25--::

  Circle6 and back (to 1x, 2, 3)

33--::

  1c+2c set | ¾ DblFig8, (2c cross up to start) 



{{explanation}}

(1c continues into the new reel, on second turn 1c casts to 4pl and 3c (in 2pl) dances on into the new reel)

', 3);
INSERT INTO 'dancecrib' VALUES (8125, '2013-11-27 20:02:09.775977+00', '2015-02-24 14:40:41.126673+00', 15270, 1, NULL, 'ace', '1–::

  All turn RH ½, face P and cast to other side ; repeat to (1,2,3,4)

9–::

  All Circle8 L half round ; Set | cross RH, mid couples facing en couples (4,3,2,1)

17–::

  4c+3c & 2c+1c R&L, starting up/down, with polite turns when possible , 3c+2c finishing on the diagonal for

25–::

  3c+2c ½ Poussette ; 4c+2c & 3c+1c ½ Poussette (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11924, '2019-06-28 22:07:38.96069+00', '2020-04-16 09:41:36.526404+00', 19430, 1, 1645, 'ace', '1-::
  1c+2c circle4 & back _while{8}_ 3c+4c+5c set with highland arms | cross RH ; set with highland arms | cross LH
9-::
  2M & 4W change places by crossing over | casting RSh round 3c _while{4}_ 1M+5W change places passing RSh between 3c ; 5W+1W+4W+2W (top) & 4M+2M+5M+1M (bottom) RHA _while{4}_ 3c turn 1&frac14; LH
17-::
  *Extended snake pass:* 3M,4M,5M,1M,2M dance up W side, across and down M side _while{8}_ 3W,2W,1W,5W,4W dance down M side, across and up W side (M: 2,1,5,4,3; W: 3,2,1,5,4)
25-::
  All set | all dance up NHJ with opposite person (not P) and cast down (M: 3,4,5,1,2; W: 4,5,1,2,3)
33-::
  All set | all stand ; 3W (in 5pl) dances up alone to 1pl (other W down on [39-40]) to (3,4,5,1,2)
', 5);
INSERT INTO 'dancecrib' VALUES (10387, '2018-01-19 01:13:24.558315+00', '2021-02-12 20:13:13.18696+00', 17953, 2, 963, 'ace', '1-8::

  2s following 1s, W leading M, fig 8 around 4s+2c position (Rsh to 4s) back to place – pull back Lsh to face clw  

9-16::

  1s following 2s, M leading W, fig 8 around 3s+1c position (Lsh to 3s) back to place  

17-24::

  1s+3s RHA 2-1/2 times (M lead in, 2 RHA, M lead out) to change places  

25-32::

  All set and petronella in tandem one place right; all chase cw ½ (4,3,2,1)  

Repeat once in Strathspey Time (to 1,2,3,4)   

Repeat twice in Reel Time, but now making only 1½ RHA on [17-24]  

*Notes:  Not a standard progression – (1,2,3,4) to (4,3,2,1) and back.*

', 5);
INSERT INTO 'dancecrib' VALUES (2325, '2012-01-22 19:29:31.594221+00', '2021-06-04 10:30:15.738191+00', 2471, 1, NULL, 'ace', '1–::

  1c set | cast 1 place (2c up) ; set | W cast up, M down

9–::

  1c dance Rsh round 1cnr, pass Rsh, dance Lsh round 2cnr, pass Lsh to 2pl (2,1,3)

17–::

  1c set advancing, turn 1cnr BH to finish 3 and 3 across ; 1c set advancing, turn 2cnr BH to finish 2pl opposite side

25–::

  1c pass Rsh, dance Rsh round 3cnr, pass Rsh, dance Lsh round 4cnr, pass Lsh to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2324, '2012-01-22 19:29:31.554097+00', '2021-06-05 09:44:50.602674+00', 2469, 1, NULL, 'ace', '1–::

  1c+2c Set&Rotate (set | cast 1 place clw in square ; change place RH with P | chase 1 place clw) (2,1,3)

9–::

  Parallel Reels3 on own sides (1c Lsh to 3c), 2W & 1M face out into

17–::

  2c+1c RHA (to sidelines) ; 1c+3c LHA

25–::

  All set advancing into a small circle (no hands) | set swiveling R ¾ ; ½ RHA (6 hands) into chase to (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (14448, '2021-11-14 21:30:32.032523+00', '2021-11-14 21:33:18.353863+00', 20556, 1, 1645, 'ace', '1--::

  1W dances down centre & casts up round 3W _while_ 1M dances behind own line & round 3M, 1c end between 2c & 3c, 1M facing out ;

  1M followed by P casts up round 2M & crosses to opp side facing out (1x,2,3)

9--::

  1c+2c RSh Reel4 across, 1W+2W pass LSh & 1M/2M dance down/up to start (1x,2,3)

17--::

  1c+3c set | 1c cast to 3pl (2c up) _while_ 3c cross up, no hands (2,3x,1x) ; 3c+1c set | &frac12; RHA (2,1,3)

25--::

  Circle6 & back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3716, '2013-03-16 17:28:32.681798+00', '2014-04-30 23:23:51.529957+00', 2508, 1, NULL, 'ace', '1–::
  1c+2c & 3c+4c ½ R&L ; ½ RHA | All set, to finish  2c facing 3c and 1c+4c facing P (1,2,3,4)
9–::
  »Borrowing« Lsh Reels4, simultaneously on sidelines and across:.  All pass facing person Rsh | loop L with other dancer in the corner ; pass Rsh again | loop L with another dancer, finish as started.
17–::
  1c+2c ½ DblFig8 (1c cross down) ; 2c cast up and cross as 1c+3c ½ DblFig8 (1c cross down) (2,1,3x,4)
25–::
  1c+4c ½ DblFig8 (1c cross down) as 3c cast up and cross ; 1c turn LH 1½ to 4pl as 4c cast up and cross (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2336, '2012-01-22 19:29:32.026116+00', '2020-12-06 18:29:25.739659+00', 2507, 1, NULL, 'ace', '1–::

  1W+2M+3W+4M petronella to centre line _while{2}_ the others step ½ place R to form diamonds, all set ; both diamonds circle4 left

9–::

  Reel4 on centre line

17–::

  Both diamonds RHA to sidelines (a bit more than once round) ; 1c+2c+3c ½ Rsh Reels3 on sidelines 2c starting up (to 3,2,1,4)

25–::

  3c+2c & 1c+4c Tournée (to 2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2338, '2012-01-22 19:29:32.106021+00', '2014-04-30 23:23:51.575266+00', 2532, 1, NULL, 'ace', '1–::
  1c+2c R&L
9–::
  1c with 2c following lead down ; lead up (2c leading) into line across, 1c BtoB in middle between 2c, facing opp side
17–::
  1c+2c Reel4 across, 1c finish facing 1cnr
25–::
  Turn CPCP', 2);
INSERT INTO 'dancecrib' VALUES (13079, '2020-08-10 00:19:29.717623+00', '2023-02-09 12:20:58.722859+00', 1955, 3, NULL, 'ace', '1-8::

    1s+2s+3s dance mirror reels of 3 on sides (1s in/down, 2s out/up to

    start), 2s & 3s cross to opp side from top place to reel on opp

    side.  1 (2) (3)

9-16::

    1s lead down, cross below 2s, 1M cast down, 1L casts up, dance

    towards each other in middle & turn LH to face 1st corners (pstn)

::

    _while_ 2s+3s set, cross RH, face on sides, set & change places LH.

    3 1 2

17-32::

    »Moving Corners«:

::

    _17-20_   1s set to & 1/2 turn corners 2H (1M+2L, 1L+3M). 1s end in

    corner place _while_ corners face 2nd corner pstn (3s & 2s facing

    partners)

::

    _21-24_   Repeat 17-20. End 3L & 2M in centre on 1st corner

    diagonal, 3L facing 1M (3rd place Ladies'' side), 2M facing 1L (1st

    place Men''s side)

::

    _25-28_   Repeat 17-20. End 1s in centre on 2nd corner diagonal, 1M

    facing 2L (3rd place Men''s side), 1L facing 3M (1st place Ladies''

    side)

::

    _29-32_   Repeat 17-20. End 3M facing 2L in centre on 1st corner

    diagonal

33-36::

    2L+3M set twice _while_ 1s (1L in top place, 1M in 3rd place) set

    advancing & join hands with 2L+3M & all set

37-40::

    1s+2L+3M dance RH across 1.1/4 round to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11252, '2018-10-06 05:50:09.641676+00', '2018-10-06 05:53:23.303666+00', 18815, 1, 202, 'ace', '1--::

  1c set | cross RH ; cast (2c up) | cross LH (2,1,3)

9--::

  2c+1c Reel4 across, 1W+2M passing LSh (2,1,3)

17--::

  1c+3c Reel4 across, 1W+3M passing RSh (2,1,3)

25--::

  1W+2c & 1M+3c RHA ; 1c turn LH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9880, '2017-05-24 21:51:05.997852+00', '2017-05-24 21:51:05.997852+00', 17760, 2, NULL, 'ace', '1-8::

  1st and 2nd couples dance the Knot.  First couple end facing first corners.

9-12::

  1st couple dance Back to Back with first corners.  At the end of bar 11, 1st couple pull right shoulder back to face each other and pass partner’s right shoulder

13-16::

  1st couple repeat 9-12 with second corners, finish passing partner by right shoulder and facing each other to flow into...

17-24::

  1st couple turn with both hands, then dance up and cast off two places on own sides. 3rd couple step up on 23 & 24. 

25-32::

  1st and 3rd couples dance Poussette.', 5);
INSERT INTO 'dancecrib' VALUES (9289, '2016-09-11 23:23:37.498348+00', '2016-09-12 19:45:56.417271+00', 14879, 1, NULL, 'ace', '1--::

  1c set | cross down (2c up) ; 2c+1c RHA (2,1x,3,4,5)

9--::

  1c+3c+4c parallel Rsh Reels3{6} | 1c+3c change place LH (2,3,1x,4,5)

17--::

  3c+1c+4c+5c Gr-Ch, no polite turn at end

25--::

  2c+3c+4c+5c Circle8 and back _while{8}_ 1c free turns or steps in the centre  (2,3,1x,4,5)

33--::

  1c up through 3c, cast off on opp. side, cross down and cast below 5c (4c+5c up) (2,3,4,5,1)

', 3);
INSERT INTO 'dancecrib' VALUES (14934, '2022-07-02 09:15:04.383114+00', '2022-09-06 21:22:27.09457+00', 1932, 2, 1, 'ace', '1–4::

  All S | ½Circle6 to L

5–8::

  2M+3c & 2W+1c RH across [pass R at end]

9–::

  2M+1c & 2W+3c LH across, ½Chase acw [to own sides] | all pull RS back to cast [1c dance in to join BH, 2c&3c out to sides]

17–::

  1c set w/Highland Schottische [1M on LF] ; 1c set [pivot towards bottom at end of 21, continue travelling down] | 1c set [pivot towards top at end of 23, continue travelling up]

25–::

  1c+2c dance ½Poussette ; 1c+3c dance ½Poussette', 3);
INSERT INTO 'dancecrib' VALUES (2742, '2012-01-22 19:29:55.548395+00', '2020-04-16 09:51:27.313652+00', 4133, 1, NULL, 'ace', '1--::

  1c+2c DblFig8, 2c casting up (to 1,2,3, 2c face out)

9--::

  1c+2c+3c BiL on sidelines | 1c turn 2c EH ½ (1c face out) _while{2}_ 3c set ; 2c+1c+3c BiL | 2c set _while{2}_ 1c turn 3c EH ½ (2,3,1, with 3c facing out)

17--::

  2c+3c+1c mirror Reels3 on own sides (3c begin down), finish with 2c at top and 1c (facing up) between 3c (facing down) in line of 4 across NHJ 

25--::

  1c+3c BiL | 1c turn 3c EH ¾ (to 2,3,1, 3c facing out) ; 3c+1c set, on 2nd step pivot ½ about towards each other changing hand (2,3,1, 1c facing out) | 1c turn 3c EH ½ (2,1,3, 3c facing out ready to continue (on 2nd time through make full turn to (2,3,1))

', 3);
INSERT INTO 'dancecrib' VALUES (12128, '2019-09-01 22:19:34.594078+00', '2019-09-01 22:19:45.05837+00', 19582, 1, 1645, 'ace', '1-::

  All set to P | turn cnr LH & face P | &frac12; turn P RH, 1c & 3c end facing out in promhold

9-::

  1c+2M+4W & 3c+4M+2W RSh Reels3 across, 2c & 4c end taking promhold as 1c & 3c separate

17-::

  2c+1W+3M & 4c+3W+1M RSh Reels3 up/down, 2c & 4c end in centre, 1c & 3c curve away from P to plx

25-::

  2c+4c &frac12; RHA | 2M+4W & 4M+2W chase{4} LSh round 3W/1W, in through 3c/1c to face P in centre | set retiring _while{2}_ 1c & 3c set adv

33-::

  1c+3c &frac12; RHA | 1M+3W & 3M+1W chase{4} LSh round 4W/2W, in through sides to face P in centre | set retiring _while{2}_ 2M+4W & 4M+2W set

41-::

  All turn cnr 1&frac12; BH (2,3,4,1) ; circle8 &frac12; way to L (4,1,2,3)

', 5);
INSERT INTO 'dancecrib' VALUES (2345, '2012-01-22 19:29:32.382096+00', '2016-02-22 12:34:36.467108+00', 12634, 1, NULL, 'ace', '1–::

  1c+2c ½ DblFig8 (1c cross down) ; 2c cast up to 1plx {2} _while_{4} 1c+3c ½ DblFig8

9–::

  3c cast up to 2plx {2} _while_{4} 1c+4c ½ DblFig8 ; 4c cast up to 3plx {2} _while_ 1c dance down | turn RH to (2x,3x,4x,1x)

17–::

  4c+1c ½ RHA | Set ; 3c+1c repeat LH ;

25–::

  2c+1c repeat RH ; 1c cast to 4pl (2c+3c+4c up on [31-32]) (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (8120, '2013-11-26 01:56:09.366498+00', '2017-11-23 00:19:31.193753+00', 15266, 1, NULL, 'ace', '1--::

	1c+2c Chain Progression [Turn P RH 3/4 | "outers" chase 1/2 clw _while{4}_ "middles" turn LH 1 1/2 | Turn P RH 3/4] (2,1,3) 

9--::

	2c+1c+3c the Knot (3,1,2), 1c finish facing 1cnr  

17--::

	Set "H&G", 1c face out (3,1,2)  

25--::

	Half Reels3 on own sides, 1c Rsh to 3cnr ; 2c+3c stand as 1c continues path of the reel to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2346, '2012-01-22 19:29:32.422542+00', '2014-04-30 23:23:51.769488+00', 2562, 1, NULL, 'ace', '1–::
  1c (passing inside)+2c & 3c(passing inside)+4c change places EH on the side | BiL on sidelines ; change places back same hand | BiL again (1,2,3,4)
9–::
  Mirror Reels4 on the sides, the M Rsh, W Lsh, on [11-12] 1c cross down into opposite reel.  At end 1c dances through 1plx to finish between 2c in 2pl facing opposite side (for the last pass in middle Rsh is allowed), 3c & 4c finish in places
17-32::
  The Spurtle (½Reel4 across, 2c to 1plx, and 1c makes fast RH turn to between 3c ; repeat with 3c ;; repeat with 4c ; All set and cross RH) (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2197, '2012-01-22 19:29:25.244495+00', '2015-06-27 22:08:32.450635+00', 10883, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1c dance between and casts round 2c ; turn RH

17–::

  2c dance between and casts round 1c ; turn RH

25–::

  1c advances with arch and 2c dances under, both meet next couple | repeat, 2c making arches ; repeat twice more »over and under«', 2);
INSERT INTO 'dancecrib' VALUES (8173, '2014-02-08 23:34:03.425009+00', '2014-06-01 09:37:36.009405+00', 1559, 1, NULL, 'ace', '1–::

  1c+2c Tourbillon (2,1,3)

9–::

  All lead down, 3c leading ; and up in promhold, 2c leading (2,1,3)

17–::

  All in promhold, 2c goes L, 1c goes R, 3c goes L into Lsh Reel3 across, at end 2c to 1pl, 1c to M side, 3c to W side (both M on L of P)

25–::

  1c+3c turn person opposite BH ½ and lead on clw one place | All set [this is ½ Tourbillon] (2,3,1x) ; 2c+3c Circle4 L _while_ 1c turn BH 1½ (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (8121, '2013-11-26 19:11:17.482285+00', '2015-02-24 14:45:55.465525+00', 15267, 1, NULL, 'ace', '1–::

  1W+2W+3W+4W Fig8 round P and M below, start Lsh round M below P

9–::

  All set | turn P RH ½ ; continue turn BH ½, face P close by and cast away to (1,2,3,4,5)

17–::

  1M+2M+3M+4M Fig8 round P and M below, start Rsh round M below P

25–::

  1c+2c & 3c+4c S&Link ; 1c+4c & 3c+5c S&Link (all set on [25-26] and [29-30]) (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (2355, '2012-01-22 19:29:32.907322+00', '2021-02-06 11:19:10.196332+00', 10672, 1, NULL, 'ace', '1–::

  1M with 2c Lsh Reel3 across

9–::

  1W with 2c and 1M with 3c Rsh reels3 across, 2c finishing in 1pl and 1W/1M finishing between the end Cpl, facing down

17–::

  1c cast R round standing M to face 1cnr ; turn 1cnr RH

25–::

  1c SetH&G, to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8113, '2013-11-17 11:41:42.010631+00', '2015-04-01 23:23:12.509773+00', 10923, 1, NULL, 'ace', '{{explanation}}

Couple face couple RR



1–::

  All dance BtoB with opposite ; turn opposite BH

9–::

  Repeat with P

17–::

  Circle4 and back, keep hands joined

25–::

  All advance and Heugh | retire ; pass opposite Rsh and meet next couple', 3);
INSERT INTO 'dancecrib' VALUES (8743, '2015-03-25 00:12:39.714795+00', '2015-06-07 22:51:29.150918+00', 5122, 1, NULL, 'ace', '*Start (1,2,3x,4x)*



1--::

  1c+4c set | turn BH to finish W facing out ; 1c+4c (M following W) cast inwards (2c+3c step to end), and pass Lsh round the other couple into 

9--::

  4c+2W & 1c+3W RHA ; 4c+2M & 1c+3M LHA, finish 4c+1c NHJ facing closest end and 2M & 3M facing out (2,4,1x,3x)

17--::

  4c+1c dance NHJ to end and cast back while{4} 2c+3c dance in one place and return NHJ to end (2,4,1x,3x) ; 4c+1c Circle4 L

25--::

  All Circle8 L {2} | Set with HJ ; chase L {1} and cast cclw to starting places (2,4,1x,3x)

', 4);
INSERT INTO 'dancecrib' VALUES (3659, '2012-12-09 21:15:15.096859+00', '2015-09-12 12:59:14.449646+00', 14604, 2, 1, 'ace', '1-::

  1c figure8 round 2c (crossing down to start)

9–12::

  1c dance down between 2c and 3c | cast up to 2pl

13–16::

  2c+1c+3c set | 1c set advancing, pivot R to face out _while_ 2W&3M petronella into diamond formation

  [2W in centre at top, 3M in centre at bottom] _while_ 2M&3W cast into 2pl to finish 1M facing 2M, 1L

  facing 3L in a line across

17–28::

  Dance to each point and set {12}. On [27-28], 2M&3W set to face clockwise, 2W&3M dance out

  from centre to face clockwise

29–32::

  1c turn R 1¼ to 2pl own sides _while_ 2c&3c chase clockwise [finish 213]

33–::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (9290, '2016-09-13 15:32:09.21726+00', '2016-09-13 15:33:34.399916+00', 17306, 1, NULL, 'ace', '1--::

  1c+2c Circle4 L ; RHA

9--::

  1c set | cast (2c up) ; set to P | set advancing and pivot R to DTr position

17--::

  2c+1c+3c DTr (2,1,3)

25--::

  1c+3c LHA ; Circle 4 R

*On first time through, 1c+3c hold on to hands on [32] to enter Circle4 L.*

*When new top starts, the bottom couples may dance [1-12] to change places.*

', 4);
INSERT INTO 'dancecrib' VALUES (9881, '2017-05-25 23:05:07.483496+00', '2017-08-26 13:42:46.795435+00', 15972, 1, 202, 'ace', '1--::

 1c dance towards P to midline, 1M pulling Lsh back, 1c in promhold facing M side (2M up on [1-2]), 1c dance out through 2M pl, cast L round 3M, cross to W side, cast L round 3W (2W up on [5-6]), dance in through 2W pl, finishing in centre facing 3M

9--::

 1c NHJ set to 3M  (swivel ½ inwards) | set to 2W (veer R together) ; set to 3W (swivel ½ inwards) | set to 2M finishing in centre facing up

17--::

 2W+1W+3W RHA _while_ 2M+1M+3M LHA ; 1c dance up and cast to 2pl

25--::

 Circle6 and back', 5);
INSERT INTO 'dancecrib' VALUES (9508, '2016-12-05 05:51:21.816562+00', '2017-08-25 06:04:38.875236+00', 16893, 1, 202, 'ace', '1-::

 1c & 4c set | 1c & 4c dance NHJ to meet in centre (2c & 3c step out) ; 1c+4c Circle4 L to sidelines (2,1,4,3)

9-::

 All set | All C turn BH ½ ; All twirl R to sidelines | All set (2x,1x,4x,3x)

17-::

 1c & 4c dance out, cast to places ; 1c+4c S&Link (2x,4x,1x,3x)

25-::

 All set | All C turn BH ½ to face up NHJ ; All set | All curve out to sidelines (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2431, '2012-01-22 19:29:38.392769+00', '2016-09-26 10:06:00.259267+00', 2931, 1, NULL, 'ace', '1–::

  Couples circle4 and back

9–::

  RHA ; LHA

17–::

  Turn person opposite LH ; turn P RH and face the other C

25–::

  A&R ; All advance, couples facing clw make arch & others passing under.', 2);
INSERT INTO 'dancecrib' VALUES (8035, '2013-09-15 20:52:36.419776+00', '2014-04-30 23:23:51.876322+00', 15125, 1, NULL, 'ace', '1–::
  1W+2M followed by 1M lead down ; 1c followed by 2M lead up and others dance in for
9–::
  1c+2c+3c Allemande, at end 2c curve R to face out on own side (3,2,1)
17–::
  3c+1c turn RH ¾ _while_{2} 2c cast R | 2c pick up 3W&1M and promenade clw ½ _while_{4} 3M+1W turn LH 1½ | 1c+3c turn ¾ RH _while_{2}  2c dance to 2pl (1,2,3)
25–::
  1c turn RH ½ and cast away to 1plx ; set to P and cross down (2c+3c up) to (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2354, '2012-01-22 19:29:32.864901+00', '2020-09-19 21:03:53.456238+00', 13723, 1, NULL, 'ace', '{{explanation}}

2c+4c cross to start (1,2x,3,4x)



1–::

  Parallel Reels4 on the sides, 1W+4W face out

9–::

  1W+4W, Partners following, chase clw ½ round ; 4c+2c & 3c+1c RHA

17–::

  1W+4W, Partners following, chase clw ½ round ; 1c+2c & 3c+4c RHA

25–::

  1c+2c & 3c+4c ½ R&L ; 1c+4c ½ R&L (2,4x,1,3x)', 3);
INSERT INTO 'dancecrib' VALUES (2351, '2012-01-22 19:29:32.776017+00', '2015-03-10 10:12:50.118739+00', 7406, 1, NULL, 'ace', '1–::

  1W+2W & 3M+4M pass P Lsh, cast 2 places to the L ; repeat back to places

9–::

  1M+2M & 3W+4W repeat, using Rsh

17–::

  1c slip down the middle and up, finish in centre facing up

25–::

  1c cast to bottom (2c+3c+4c up) ; all C turn LH', 3);
INSERT INTO 'dancecrib' VALUES (2372, '2012-01-22 19:29:34.009862+00', '2014-07-08 07:21:52.493098+00', 13621, 1, NULL, 'ace', '1–::

  1c+2c RHA, LHA

9–::

  1c cross RH | cast (2c up) ; ½ Fig8 up to face 1cnr

17–::

  1c turn 1cnr RH | pass Rsh ; turn 2cnr RH | pass Rsh to (2,1,3)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (2353, '2012-01-22 19:29:32.806027+00', '2016-11-15 15:44:23.986889+00', 14339, 1, NULL, 'ace', '1–::

  1c slip down (2c up) ; lead up RHJ and face 1cnr

9–::

  Set twice to 1cnr ; set twice to 2cnr

17–::

  Reels3{6} on the sides, Rsh to 2cnr | 1c cross RH

25–::

  All Circle6 and back



{{explanation}}

Note: There is a 24-bar version of this dance where bars 25-32 are omitted.', 2);
INSERT INTO 'dancecrib' VALUES (3824, '2013-07-13 15:56:15.858071+00', '2015-03-27 14:46:32.647931+00', 7874, 1, NULL, 'ace', '1–::

  All M RHA ; All W RHA

9-24	::

  Lead-change Schiehallion Reel: All couples, M with W close behind, dance to next W place to the right {2}| both loop R singly to face in at that M’s place, W in front {2} ; repeat with W leading {4} ;; repeat with M leading ; repeat with W leading to finish in P’s place, facing clw

25--	::

  All chase clw one place. (W leading) | All cpls set ; 1c+3c cross RH | 2c+4c cross RH (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2369, '2012-01-22 19:29:33.824222+00', '2016-11-15 15:45:24.597198+00', 2644, 1, NULL, 'ace', '1–::

  1M (on the L) leads P behind 2M, across (2c up) ; behind 3W, and up to (2,1,3)

9–::

  2c repeat (1,2,3)

17–::

  1c cross RH | cast (2c up) ; dance between 3c and cast up (2,1x,3)

25–::

  All Circle6 and back (2,1x,3)

33–::

  1c set | lead to top, cross and cast off (2,1,3)

41–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (13943, '2021-04-08 11:34:39.207099+00', '2021-04-08 11:35:24.727588+00', 20307, 1, 1645, 'ace', '*3c & 4c start on opposite side (1,2,3x,4x)*

1-::

  1c & 4c set | change places{4}, 1W & 4W casting as 1M & 4M pass RSh in the middle | 4c+2c & 3c+1c &frac12; turn RH (2,4x,1,3x)

9-24::

  *Parallel Celtic Reels:* All pass RSh, 4c & 1c chase &frac14; clw outside _while_ 2c+3c &frac34; LHA to lines across ;

  repeat three times changing orientation each 4 bars. End in St Andrew''s cross: 4c+1c retain LHJ in centre & take RH with 2c & 3c

25-::

  All set | 4c & 1c turn corners RH to sides (2,4x,1,3x) | all set

33-::

  4c & 1c &frac12; Fig8 out nearest end ; turn P RH (2,4,1x,3x)

', 2);
INSERT INTO 'dancecrib' VALUES (1850, '2012-01-22 19:29:05.910374+00', '2015-09-13 13:23:35.991652+00', 11188, 1, NULL, 'ace', '1–::

  1c+2c circle4 L and face down NHJ ; dance between 3c and cast up to (2,1,3)

9–::

  Diagonal R&L (1M down, 1W up) (3x,1,2x)

17–::

  1c ½ Fig8 round 1cnr (to 3x,1x,2x) ; All set | All Turn RH ½ and face up for

25–::

  3c+1c+2c Allemande, at end 1c cast off and 3c dance up to (2,3,1)



{{explanation}}

This dance is identical to the dance Caerlaverock Castle (Graded&Social 3)', 3);
INSERT INTO 'dancecrib' VALUES (2358, '2012-01-22 19:29:33.118887+00', '2015-03-30 00:23:48.106311+00', 9114, 1, NULL, 'ace', '1–::

  1c+2c+3c mirror Reels3 on sides ; 2c dancing out and up.

9–::

  1c+2c DblFig8. 1c cross down to begin ; 2c dance out and up (1,2,3)

17–::

  1c+2c Petronella turn in parallel (both W above face the M below, NHJ, 1c on W side) | set ; Petronella turn in parallel | 2c+1c cross RH  (2,1,3)

25–::

  2c+1c+3c set | turn BH {4} | set.', 3);
INSERT INTO 'dancecrib' VALUES (5147, '2013-08-21 08:31:01.378707+00', '2023-02-09 12:31:23.741627+00', 1924, 3, NULL, 'ace', '1-8::

    1s+2s set, 1s cross RH _while_ 2s 3/4 turn RH, 1M set diag to 3M

    _while_ 2s continue to turn RH (end 2L facing up, 2M down), 1M+2L

    also 2M+3M change places passing RSh with 1M+3M ending BtoB facing

    own partners

9-16::

    1s+3s set advancing to join RH, 1M+3M set _while_ 1L & 3L turn under

    partners'' arms, 1s & 3s turn partners RH back into diagonal line

17-24::

    1s+3s dance diagonal reel of 4

25-32::

    1s+2L also 3s+2M dance RH across to end 1 2(3), 1s+2s turn RH

    _while_ 3s turn RH 1.1/2 times

33-40::

    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (2348, '2012-01-22 19:29:32.611144+00', '2017-07-20 13:16:46.218809+00', 11707, 1, NULL, 'ace', '1–::

  1W (1M follows) casts off and crosses to 2plx ; Turn P LH 1½   (2,1,3)

9–::

  Teapots R ; and L (2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA)  (2,1,3)

17–::

  1c+1cnrs ½ diag Reel4, 1M passes P Rsh and follows her into ; 1c (Rsh to 3M)+2cnrs ½ diag Reel3

25–::

  1c (Rsh to 2M in 3W''s pl)+1cnrs ½ diag Reel3 ; 1W veering R, 1c face 2cnr pos, 1c+2cnrs ½ diag Reel4



{{explanation}}

In this variant on »The Gloomy Winter« the difficult bars [9-16] have been simplified.', 3);
INSERT INTO 'dancecrib' VALUES (2360, '2012-01-22 19:29:33.222255+00', '2018-02-21 00:20:20.594044+00', 2600, 1, NULL, 'ace', '1–::

  1c, followed by 2c, 3c & 4c cast off to 4pl and dance up NHJ, all making polite turn to places

9–::

  1c+2c & 3c+4c S&Link ; 2c+1c & 4c+3c circle4 L

17–::

  2c+1c & 3c+4c »the Knot«, 1c finish between 2c, facing the other P

25-40::

  »Spurtle« progression (1c+2c ½Reel4 across, 2c finish in 1plx _while_{4} 1c Turn RH to face 3c in same way ; 1c+3c repeat ; 1c+4c repeat (to 2x,3x,4x,1x) ; All set and cross RH', 2);
INSERT INTO 'dancecrib' VALUES (11757, '2019-04-01 10:27:38.839923+00', '2019-04-01 10:46:05.419987+00', 214, 1, NULL, 'ace', '*Crib uncertain - see notes.  This is the editor''s best guess*

1--::

  1M+2W set and change places RH ; 1W+2M repeat (2x,1x)

9--::

  2c+1c A&R ; ½ RHA | cast back to own side (1,2)

17--::

  Circle4 and back (1,2)

25--::

  1c+2c RHA {3}, LHA{3} | 1c cast off as 2c dance up (2,1)

', 1);
INSERT INTO 'dancecrib' VALUES (11758, '2019-04-01 10:38:33.138734+00', '2019-04-01 10:46:05.420705+00', 214, 2, NULL, 'ace', '*The "original description" available to the database editors reads as below.  This must be in error.  The progression is complete on [16], and then [31-32] is impossible*

1-4::

  1st man & 2nd lady set & giving R hand change places  

5-8::

  1st lady & 2nd man set & giving R hand change places   

9-12::

  1st & 2nd couples advance and retire  

13-16::

  1st & 2nd couples advance again, turn and dance back to own side 

17-24::

  1st & 2nd couples 4 hands round & back

25-32::

  1st & 2nd couples 4 hands (r) across for 3 beats 4 hands (1) back for 3 beats   

  1st couple cast into 2nd place and 2nd couple lead up', 1);
INSERT INTO 'dancecrib' VALUES (2364, '2012-01-22 19:29:33.538067+00', '2019-04-30 21:15:16.473097+00', 2616, 1, NULL, 'ace', '1-4::

  1c cast off one place (2c up) | 1c set advancing to face 1cnrs

5-16::

  Dance to each corner and set (»Free« cnrs set diagonally _while_{2} centre dancers change place Rsh with the facing cnr, who in the centre pass Rsh to face next cnr on R | repeat five times, on alternating diagonals), 1c finish facing 3cnr position)

17–::

  1c ½Reel4 on 1diag, pass Rsh ; ½Reel4 on 2diag (2,1,3)

25–::

  2c+1W & 1M+3c RHA ; 2c+1c+3c turn RH.', 3);
INSERT INTO 'dancecrib' VALUES (7795, '2013-08-21 08:31:48.510434+00', '2023-02-04 01:23:01.821417+00', 9571, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All advance for 2 steps & retire, all dance DoSiDo
17-24::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L
25-32::
    1s+4s dance 1/2 R&L, All turn partners RH 1.1/2 times back to own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (9882, '2017-05-26 08:10:22.984092+00', '2017-08-26 07:48:03.314476+00', 10468, 1, 202, 'ace', '1--::

 1c+2c set | 1c cross RH to 2plx as 2c cast to 1pl ; ½ mirror Reels3, 1c start out and down, touching NH briefly, end facing 1cnrs pos

9--::

 1c set to 1cnr pos | turn BH to face 2cnrs pos ; 1c set to 2 cnr pos | turn BH to 2plx (3,1x,2)

17--::

 S&Link3 ; 1c passing Lsh cast R round 2cnr to 2plx (2,1x,3)

25--::

 Reels3{6}, 1c start Lsh to 1 cnr | 1c cross RH to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15171, '2022-10-15 13:56:07.395956+00', '2022-10-15 14:14:24.439243+00', 17697, 1, 202, 'ace', '1--::

  3C Set&Rotate (3,2,1)

9--::

  2c+1c Chain and Turn (3,1,2)

17--::

  1c ½ Fig8 down round 2c ; all turn RH into promhold 1c facing down and 3c & 2c facing up (3,1x,2)

25--::

  3C Circulating Allemande (2,1x,3)

33--::

  1c ½ Fig8 up round 2c ; all turn P LH (2,1,3)



*Note* : On second time through [33-36], 1c dance ½ Fig8 to 4pl (4c step up).', 2);
INSERT INTO 'dancecrib' VALUES (2373, '2012-01-22 19:29:34.068354+00', '2014-04-30 23:23:52.23795+00', 13580, 1, NULL, 'ace', '{{explanation}}
Trio face Trio RR

1–::
  All Circle6 and back
9–::
  Middle dancers RHA with dancers on their R ; repeat to the L
17–::
  the four corner dancers A&R diagonally ; the middle dancers dance BtoB
25–::
  All cross RH to opposite, to meet new trio | repeat LH : turn next opposite RH', 3);
INSERT INTO 'dancecrib' VALUES (10249, '2017-11-11 16:44:12.929856+00', '2021-07-26 09:06:47.655416+00', 18046, 2, 9560, 'ace', '1-8::

 1s+3s Figs of 8 round 2s. To start, 1s cross down, 3s dance up.

9-16::

  1s+2s Chain Progression, 1s finishing facing out.

17-24::

  1s cast to the right, ½ RH & twirl up and down the dance, cast to the right, finishing in 2nd place.

25-28::

  1s+3s dance mirror S&Link (1s casting).

29-32::

  1s turn BH, long cast to sidelines, stay facing out.

', 0);
INSERT INTO 'dancecrib' VALUES (8209, '2014-03-13 23:41:40.313953+00', '2014-04-30 23:23:52.267937+00', 13133, 1, NULL, 'ace', '1–::
  1c cross RH | 1c cast _while_{2} 2c dance up and face out ; Mirror ½ Reels3 on the sides, 1c dancing down and crossing (3,1,2),
9–::
  Reels3 across, 1M Lsh to 2W & 1W Lsh to 3M, 2c+3c enter with loops (3,1,2)
17–::
  All set | cross RH ; set | all turn RH ½ and stay in middle, for
25–::
  Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2375, '2012-01-22 19:29:34.178962+00', '2016-10-10 16:05:07.893838+00', 2661, 1, NULL, 'ace', '1–::

  1c+2c+3c Rsh Parallel Reels3 on own side

9–::

  1c set | turn BH, finish facing 2c ; with person opposite set and turn BH 1½ (2,1,3)

17–::

  1M+3c Circle3 L, break early and finish (2,1,3x) ; 1W+3c repeat R (to 2,1,3)

25–::

  1c set, dance to the top ; cast off, turn RH (2,1,3)



*note: on [17-20], 1M may finish turning 3W BH ½, likewise for [21-24]*', 3);
INSERT INTO 'dancecrib' VALUES (2362, '2012-01-22 19:29:33.450023+00', '2014-07-14 21:03:26.100356+00', 2604, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; turn LH 1¼

9–::

  Teapots R ; and L (2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA)

17–::

  1c lead down the middle and up into 2pl

25–::

  All circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (14693, '2022-03-09 01:05:40.692557+00', '2022-03-10 00:41:01.135954+00', 19617, 1, 202, 'ace', '1--::
  All set | 1c+2c & 3c+4c ¾ DblFig8, 2c & 3c crossing to ends, 1c & 4c casting inwards. 2c & 3c (cnrs) face out (2,1x,4x,3)
9--::
  1M+4M & 1W+4W cross NHJ, M making arch _while{2}_ cnrs cast inwards and change places RSh on sides (to 3,1,4,2) | 1c+3c & 4c+2c turn EH ¾ on sides into lines4 across ; 1c & 4c change places NHJ, 4c who dance up making arch _while{2}_ cnrs cross RSh | 4c+3c & 1c+2c turn EH ¾ to sidelines. 3c & 2c face out (3x,4,1,2x)
17--::
  Repeat [9-16] from new places. 2c & 3c face out  (2,1x,4x,3)
25--::
  2c & 3c pivot turning inwards (4 PdB) to face in _while{4}_   1c+4c ½ R&L ; all turn P RH (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2092, '2012-01-22 19:29:19.350629+00', '2016-12-11 20:09:13.15237+00', 13275, 1, NULL, 'ace', '1–::

  1c+3c turn RH and cast off (2c+4c up) ; 1c+3c turn LH 1¼ to face 1cnrs

9–::

  1c+3c Cnr-Chain with 1cnrs (change pl. RH with cnrs | corners turn LH ; change back RH | turn LH to face 2cnr)

17–::

  Repeat Cnr-Chain with 2cnrs, at end ½ LH turn to finish M facing down, W up

25–::

  2c+1W & 1M+4c+3W & 3M+5c RHA ; 1c+3c turn ¾ LH and cast off (4c+5c up) (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (13660, '2021-02-12 19:59:30.854688+00', '2021-02-12 20:13:13.187996+00', 17953, 1, 202, 'ace', '_Strathspey_

1--::

  2c followed by 1c, both in tanden with 1W leading Fig8 round 4c & 2c[pos], 1W RSh to 4c. Back to original places

9--::

  1c followed by 2c, both in tandem with 1M leading Fig8 round 3c & 1c[pos], 1M LSh to 3c. Back to original places

17--::

  1c+3c RHA 2½ to exchanged places (3,2,1,4)

25--::

  All set | Petronella in tandem R (to 2,1,4,3) ; chase clw ½ (4,3,2,1)

33-64::

  Repeat same pattern in Strathspey time (1,2,3,4)



_Reel_

1-64::

  Repeat [1-64] in Reel time but now making only RHA 1½ on [17-24] and [49-56]', 2);
INSERT INTO 'dancecrib' VALUES (9984, '2017-06-28 15:18:44.070752+00', '2017-11-12 04:10:57.41077+00', 14360, 2, 160, 'ace', '1-6::

  1C 2C dance first 6 bars of Poussette Right Round.

7-8::

  1C 2C turn BH once round and face down LH joined with partner. (1x 2x 3)

9-12::

  2C leading, dance down crossing between 3C, and cast up to progressed place; (2 1 3)

13-16::

  1C dance RHA - 1st woman with 2C, 1st man with 3C - 1C end in the middle facing 2nd corner (Rsh to Rsh with prtnr).

17-24::

  2nd corners Pass&Turn as 1C dance round 2nd corner positions + pass Rsh to face 3rd corners ; 1st corners Pass&Turn as 1C dance round 3rd corner positions and cross to 2nd place opp. sides + face out.

25-32::

  8 bar Reel3 on sides - 1C pass 1st corner Rsh to begin - 1C cross to 2nd place own sides on bars 31-32.', 0);
INSERT INTO 'dancecrib' VALUES (9291, '2016-09-14 04:37:11.950076+00', '2017-08-26 09:53:04.541713+00', 17335, 1, 202, 'ace', '1--::

 1c dance between 2c and cast up to middle 1pl NHJ ; dance between 3c and cast up to 2pl own side (2c up on 7-8)

9--::

 Teapots R (2c+1W & 1M+3c RHA) ; Teapots L (2c+1M & 1W+3c LHA), finish Rsh to Rsh facing opposite side for

17--::

 Rsh Snake Pass (unwind the LHA, 1c leading pass other snake Rsh through opposite side and chase clw to) ; 3c,1c,2c Turn P RH 

25--::

 Circle6 and back (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (2389, '2012-01-22 19:29:35.099213+00', '2021-06-01 20:55:42.197274+00', 2717, 1, NULL, 'ace', '1–::

  1c set | cross to 2pl in middle facing 3c (2c up) ; set to 3c and face 2c | set to 2c and face out (2,1x,3)

9–::

  1c dance Rsh round 1cnr, pass P Rsh ; dance Rsh round 2cnr into (2,1x,3)

17–::

  Opposing Reels3{6} across (1c Rsh to 4cnr), at the end 1c cross RH to own side (2,1,3)

25–::

  All Circle6 and back.', 3);
INSERT INTO 'dancecrib' VALUES (2382, '2012-01-22 19:29:34.603379+00', '2015-07-01 12:32:39.073877+00', 2700, 1, NULL, 'ace', '1–::

  1c dance down one and cast up ; 1M+2M dance between the W and cast back

9–::

  1W+2W dance between M and cast back ; 2c dance up one and cast back

17–::

  1M+2W set advancing | twirl R and set back to place ; 1W+2M repeat

25–::

  1c+2c half circle4 L in skip change ; 2c+1c set | cross RH.', 2);
INSERT INTO 'dancecrib' VALUES (2379, '2012-01-22 19:29:34.454523+00', '2014-04-30 23:23:52.343634+00', 2682, 1, NULL, 'ace', '1–::
  1c turn ¾ RH moving down, turn LH (2c up) to 1M(1W) between 3c(2c) ; set twice in lines across
9–::
  1c turn 1¾ BH to 2plx ; 2c+1c+3c set twice, 1c finish facing 1cnrs
17–::
  Set to and turn corners
25–::
  Reels3{6} on opposite sides (Lsh to 1cnrs), 1c cross', 3);
INSERT INTO 'dancecrib' VALUES (14263, '2021-08-22 19:58:47.710933+00', '2021-08-22 20:17:56.938935+00', 20403, 1, 202, 'ace', '1--::
  Parallel Reels4 on 1diag, 2c & 4c passing P LSh. On[8] 2c & 4c turn P LH ½ and face 2cnrs
9--::
  Parallel Reels4 on 2diag (1,2,3,4,5)
17--::
  1c set advancing | turn P BH opening to face down NHJ ; 1c dance down to 5pl (2c+3c+4c+5c up) (2,3,4,5,1)
25--::
  *Centenary formation* : 2c turn BH ½ opening to face down NHJ | set ; S&Link to 1pl _while{8}_ 3c+4c & 5c+1c Circle4 and back (2,3,4,5,1)', 2);
INSERT INTO 'dancecrib' VALUES (2403, '2012-01-22 19:29:35.934559+00', '2015-12-15 16:37:30.285105+00', 2777, 1, NULL, 'ace', '1–::

  1M+2W cross and dance ¾ Lsh round P, pass down/up Rsh, cast R round standing M/W to places

9–::

  1W+2M repeat (other shoulders)

17–::

  1c slip down the middle | set (1M starts L foot) ; slip to top | cast off (2c up)

25–::

  2c+1c A&R (all clap) ; turn P RH', 3);
INSERT INTO 'dancecrib' VALUES (11514, '2019-01-17 20:09:02.044207+00', '2019-01-17 20:09:16.611609+00', 19167, 1, 1645, 'ace', '1-::

  1c & 5c set | cast inwards (2c & 4c to ends) ; &frac12; fig8 round ends to centre line M above W

9-::

  2c+1M, 1W+3c+5M & 5W+4c RHA, pass RSh to change ends ; LHA back, 1c & 5c face 1cnrs

17-::

  1c & 5c &frac12; diag RSh Reels4 with 1cnrs, pass RSh ; repeat with 2cnrs & face 3cnr pos

25-::

  1c & 5c set to 3cnrs | dance RSh round P to face 4cnr pos _while_ all cnrs chase 1 cnr pos clw ; repeat with 4cnrs, 1c face out in 2plx, 5c face up NHJ in 4pl (2,1x,3,5x,4)

33-::

  1c cast to 5plx _while{4}_ 5c dance up & follow 1c path to 4plx (4c up on [33-34], 3c+4c up on [35-36]) ; 1c & 5c turn P 1&frac12; RH (2,3,4,5,1)

:: *Crib derived from the video*

', 1);
INSERT INTO 'dancecrib' VALUES (2412, '2012-01-22 19:29:36.435587+00', '2020-06-01 17:59:20.918934+00', 2812, 1, NULL, 'ace', '1–::

  1M+2W turn RH ½ | 1W+2M join in for RHA ; 1c+2c LHA, to finish 1c(2c) on M(W) side, M above and BHJ with W

9–::

  1c+2c BHJ (one H.Schottische step) cross to other side, 1c passing below 2c, (on the 2 hops travel without turning, 1c down, 2c up) ; repeat back, on [12] turn BH ½ into diagonal line (M facing UP, W DN, 1c above 2c) ; 1c+2c ½Poussette to (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (13661, '2021-02-13 01:48:41.637967+00', '2021-02-13 01:53:53.882503+00', 17955, 1, 202, 'ace', '_Strathspey_
1--::
  All  dance double M-Chain. On [7-8] all M turn P RH to finish in centre
9--::
  All M LHA ¾ _while{2}_ all W chase clw 1 place | all turn P RH ; repeat [9-12] to places (3,4,1,2)
17--::
  All set | Petronella in tandem R ; set to P | turn P RH. All W face out (4,1,2,3)
25--::
  ½ Schiehallion Reels (2,3,4,1)
33-64::
  Repeat [1-32]

_Reel_
1-64::
  Repeat in Reel time', 2);
INSERT INTO 'dancecrib' VALUES (12953, '2020-07-08 11:32:11.047552+00', '2020-07-08 11:34:21.551316+00', 19675, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c The Tourbillon (2,1,4,3)

9--::

  2c+1c & 4c+3c RHA ; 1c+4c LHA (2,1,4,3)

17--::

  Reels4 on sides (2,1,4,3)

25--::

  1c & 3c turn P BH ¾ | ½ Reel4 on midline | turn P BH ¾ to sides (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2387, '2012-01-22 19:29:34.943749+00', '2021-06-01 20:59:09.629892+00', 2713, 1, NULL, 'ace', '1–::

  1W+2W advance | 1c+2c Set ; 1W+2W retire | 1c+2c Set (1,2)

9–::

  Repeat, the M advancing and retiring

17–::

  1c lead down the middle and up

25–::

  1c+2c Poussette (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (14169, '2021-07-26 09:06:19.56608+00', '2021-07-26 10:18:03.607915+00', 18046, 1, 202, 'ace', '1--::
  1c+3c DblFig8, 1c crossing down (1,2,3)
9--::
  1c+2c Chain Progression. 1c face out (2,1,3)
17--::
  1c dance RSh round 3cnrs to centre, turn P Rh ½, face P and cast RSh round 4cnrs to 2pl (2,1,3)
25--::
  1c+3c Mirror Set&Link, 1c casting off (to 2,3,1) ; 1c turn BH opening to face down and cast outwards to 3pl facing up (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2434, '2012-01-22 19:29:38.528446+00', '2022-01-13 10:21:29.669538+00', 2935, 1, NULL, 'ace', '1–::

  All C in promhold A&R ; all W cast behind P and dance one place clw.

9–::

  All new pairs in promhold A&R ; all M men cast behind P and dance one place cclw.

17–::

  All set to new partner, 1M+3M cross LH ; 2M+4M cross LH, all set to own P.

25–::

  All circle8 and back.', 2);
INSERT INTO 'dancecrib' VALUES (14323, '2021-09-18 08:10:20.229869+00', '2021-09-18 15:36:29.099044+00', 20493, 1, 202, 'ace', '1--::
  1c+2c The Tourbillon. On [7-8] 1c turn P RH and pivot R facing opposite sides as for DTr position
9--::
  DTr, 1c starting on [9] & [13]  with L foot and moving with traveling steps. 1c face 1cnrs
17--::
  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag (3x,1x,2x)
25--::
  3C S&Link twice (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (2937, '2012-01-22 19:30:03.67995+00', '2015-03-25 12:13:36.818158+00', 4965, 1, NULL, 'ace', '1–::

  1c lead down the middle and up

9–::

  1c set _while{2}_ 2c cross RH | 1c+2c set facing down/up ; 1c+2c RHA, Women finish facing out (1,2x)

17–::

  1c+2c Reel4 across, M start Lsh, on [7-8] women dance straight across and face in (1,2x)

25–::

  1c+2c set | R&L for 4 bars (2c) and 6 bars (1c) (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (9987, '2017-06-29 19:11:26.239146+00', '2017-07-01 00:59:15.878075+00', 17882, 1, NULL, 'ace', '1--:: 

  1c+2c S&Rotate (2,1,3,4)

9--::

  2c+1c+3c Reels3 on the sides, 1c Rsh to 2c (2,1,3,4)

17--::

  2c+1c RHA ; 1c+3c LHA

25--::

  1c+3c+4c A&R ; turn P RH (2,1,3,4)

33--::

  1c+3c+4c Circle6 and back

41--::

  1c+3c+4c 3C Poussette (2,3,4,1)', 5);
INSERT INTO 'dancecrib' VALUES (2388, '2012-01-22 19:29:35.025995+00', '2019-01-22 13:16:09.532631+00', 2716, 1, NULL, 'ace', '1–::

  1c lead down 2 | cast up round 3c ; lead to top | cast to 2pl (2c up) to end NHJ facing 2W

9–::

  Set to 2W and turn inwards | set to 3M ; lead RHJ between 2M and 3M and cast L round 3M and lead up to face 2M NHJ

17–::

  Set to 2M and turn inwards | set to 3W ; lead RHJ between 2W and 3W and cast L round 2W to 2plx in the middle facing down

25–::

  Reels3 with cnrs, 1c starting down and out and 3c in , 1c cross from top to 2pl at end. (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2397, '2012-01-22 19:29:35.599225+00', '2016-04-18 23:14:19.781118+00', 2746, 1, NULL, 'ace', '1–::

  1c+2c set, cross RH ; circle4 to the left (1x,2x)

9–::

  1W+2M ½ RH turn | 1M+2W join to make ½RHA ; ½LHA, 1W+2M returning to own side | 1M+2W continue LH turn to (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2391, '2012-01-22 19:29:35.209406+00', '2014-04-30 23:23:52.557846+00', 5100, 1, NULL, 'ace', '1–::
  1c+3c set | cast off (2c+4c up) ; ½ Fig8 up and pass Lsh to finish BtoB facing own side for
9–::
  1c+3c dance as in DTr to finish BtoB facing own side, _while_{8} the corners join in, but petronella one place cclw round the set on 11-12 and 15-16
17–::
  Half diagonal Reel4, with 3cnr ; 1c+3c 1½ LH turn (5,1,4,3,2)
25–::
  CPCP
33–::
  2c lead to top _while_{4} 5c cast to bottom ; 1c+3c set and cast off (4c+5c up) (to 2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (2392, '2012-01-22 19:29:35.248522+00', '2014-04-30 23:23:52.572838+00', 13223, 1, NULL, 'ace', '1–::
  1c cross RH | cast off (2c up) ; ½Fig8 round 2c (2,1,3,4)
9–::
  1c+3c+4c  Reels3 on the side, 1c crossing down to start (2,1x,3,4)
17–::
  1c lead to top, cross and cast ; 2c+1c RHA
25–::
  1c+3c+4c 3-couple Poussette (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (1680, '2012-01-22 19:28:56.254085+00', '2016-09-16 14:45:36.786713+00', 224, 1, NULL, 'ace', '1–::

  1M+2W & 2M+3W & 3M+4W turn RH ; all C turn P LH

9–::

  1c+2c+3c slip BHJ down the middle | half turn BH ; slip up | half turn BH (1,2,3,4)

17–::

  1c+2c R&L, at end 1M faces out

25–::

  1M followed by 1W cast off (2c up) and cross ; 1c+3c RHA (2,1x,3,4)

33–::

  1M followed by 1W cast off (W side) to 4pl (3c+4c up) ; 4c+1c RHA (to 2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2395, '2012-01-22 19:29:35.478535+00', '2016-10-16 14:43:55.30785+00', 9564, 1, NULL, 'ace', '1–::

  1c cross RH | cast off 2 (2c+3c up) ; 1c cross down into 1c+4c+5c half mirror Reels3, (to 2,3,5,4,1)

9–::

  1c cross LH | cast up 2 (5c+4c down) ; 1c cross up into 2c+3c+1c half mirror Reels3 (to 1,3,2,5,4)

17–::

  1c+2c set and ½ RH turn ; chase clw round 3c to change places (to 2,3,1,5,4)

25–::

  1c+4c set and ½ LH turn ; chase cclw round 5c to change places (to 2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (3504, '2012-01-22 19:30:28.205996+00', '2016-09-16 14:58:08.216149+00', 7035, 1, NULL, 'ace', '{{explanation}}

C facing C RR



1–::

  1c+2c circle4 L and back

9–::

  1c+2c RHA ; LHA,

17–::

  1M+2W & 1W+2M (= person opposite) turn RH, turn LH

25–::

  1c to 2c A&R ; pass dancer opposite Rsh to meet next couple', 2);
INSERT INTO 'dancecrib' VALUES (8372, '2014-07-29 12:59:37.063082+00', '2023-02-04 01:23:04.050028+00', 15228, 3, NULL, 'ace', '{{title}}
Strathspey

1-16::
    1L (setting) Adv+Ret; then 2L, then 3L, then 4L repeats bars 1-4
17-24::
    All circle 8H round and back
25-32::
    1s facing 3s, 2s+4s facing partner to start, dance interlocking R&L
    (1s with 3s & 2s with 4s)

{{title}}
Chorus

33-40::
    All set, turn partner 3/4 RH; Ladies dance LH across 1/2 way, turn
    opposite Man RH
41-48::
    Ladies dance LH across 1/2 way, ladies turn partner RH, ladies dance
    round partner RSh
49-56::
    Ladies dance anticlockwise round inside of set, take next Man in
    prom. hold; promenade 1 place, leave Man in new place, dance on &
    take next Man in prom. hold, promenade 1 place.  Finish Men opposite
    original places, Ladies in centre facing original place
57-64::
    All turn new partners RH, Ladies dance 1/2 LH across, turn original
    partner RH 1.1/4 times, finish facing partners on sides

{{title}}
Jig

65-96::
    Repeat Chorus (bars 33-64), ending with birl', 0);
INSERT INTO 'dancecrib' VALUES (1948, '2012-01-22 19:29:11.406377+00', '2017-11-12 05:58:25.376894+00', 13679, 1, NULL, 'ace', '{{explanation}}

3c+4c start on opposite sides (no double chord)  (1,2,3x,4x)



1–::

  1c+4c petronella to midline | set to P (2c+3c step to end) ; dance full Rsh loop round standing dancer on R, to same place on midline

9–::

  1c+4c ½ Rsh Reel4 ; All petronella 1 place to the right and set, putting 2c+3c on midline (with the M BtoB) and 4c/1c in 1plx/4pl

17–::

  2c+3c turn RH | 2W+3W dance Rsh round 1Wpl/4Mpl _while_{2} 2M+3M turn LH ½ and face out in 3Wpl/2Mpl ; 2c+3c ½ L-Chain (4x,3,2x,1)

25–::

  4c+1c cross RH | cast to middle (2c+3c step to ends) ; ½ RHA | All set (3,1,4x,2x)



{{explanation}}

Repeat in Strathspey time, and twice in Reel Time', 3);
INSERT INTO 'dancecrib' VALUES (2164, '2012-01-22 19:29:23.41623+00', '2020-12-06 11:04:22.392803+00', 1931, 1, NULL, 'ace', '{{explanation}}

Part A



1–::

  All C circle8 and back

9–::

  1W+2W+3W+4W RHA, holding P LH ; all C veer right NHJ to bring M to the middle for LHA back to places, M holding P RH.

17–::

  All C set to partners twice ; turn partners once BH, to finish facing partners in original places

25-40::

  All C G-Chain (2 skip change par hand) to own places, finishing facing the centre (no polite turn)



{{explanation}}

Part B



1–::

  1W moves to centre, and dances alone (any suitable reel steps) _while{8}_ 1M+2c+3c+4c circle7 and back

9–::

  1W sets to and turns P BH ; sets to and turns opposite M (3M) BH

17–::

  1W+1M+3M Reel3, 1W starts with Lsh to 1M, 1W stays in the centre at the end

25–::

  Repeat bars 1-8

33–::

  1W sets to and turns M on right (4M) BH ; sets to and turns opposite M (2M) BH

41–::

  1W+4M+2M Reel3, 1W starts with Lsh to 4M, at the end 1W resumes her original place, and 2W moves into the centre



{{explanation}}

Repeat part B 7 times, with 2W, 3W, 4W, 1M, ... 4M each in turn in the centre. On bars 9- the W/M in the centre first sets to the P, then to the opposite M/W. In bars 33- the W/M first sets to the M/W on the L (seen from inside) of her/his original position, then the M/W opposite.  

repeat part A', 3);
INSERT INTO 'dancecrib' VALUES (13199, '2020-09-17 23:56:24.446859+00', '2022-11-06 21:52:01.965731+00', 5220, 2, 35787, 'ace', '1- 8::

  1M cross below 1W, dance around her CCW, cast off behind 2W to pick her up in prom hold.

9-16::

  1M & 2W dance reel-3 with 1W & 2M giving R-Sh to 1W.

17-24::

  1W cross below 1M, dance around him CW, cast off behind 2M to pick him up in prom hold.

25-32::

  1W & 2M dance reel-3 with 1M & 2W giving L-Sh to 1M, end 1s end facing out.

33-40::

  1s cast off to 2d pl (2s up), 1s & 2s RHA ½way; 1s & 2s ½ RL.', 2);
INSERT INTO 'dancecrib' VALUES (2400, '2012-01-22 19:29:35.762821+00', '2016-06-04 20:31:35.824354+00', 11770, 1, NULL, 'ace', '1–::

  1c long cast to 2pl (2c up), dance between 3c and cast up (2,1,3)

9–::

  1c turn 1cnr RH | pass Rsh ; turn 2cnr RH | pass Rsh to 2pl facing out (cnrs dance for 4-bars) (2,1,3)

17-20::

  1c cast R (M up, W dn) to face P on midline, and set _while{4}_ 2c+3c advance joining hands in circle, and set swiveling R on the second step

21-24::

  1c dance Rsh round each other to same place and face R _while{4}_ 2c/3c dance out to 1pl/3pl and face in diagonally, and set

25–::

  Opposing Reels3 across, 1c Rsh to 2cnr, on [27-28] 1c makes full RH turn into the other reel (1M down, 1W up, Rsh to 4cnr position) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2399, '2012-01-22 19:29:35.714714+00', '2016-10-16 15:29:09.195533+00', 9565, 1, NULL, 'ace', '1–::

  1c+3c+5c Mirror Reels3 on sides (2c+4c stand still), 3c starts up and out, all C cross down from the top (to 1x,2,3x,4,5x)

9–::

  Repeat from new positions (to 1,2,3,4,5)

17–::

  1c+2c RHA ; 1c cross RH, cast off 2 (2c+3c up)

25–::

  1c+4c LHA ; 1c cross LH and cast off 2 (4c+5c up) (to 2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (2393, '2012-01-22 19:29:35.293191+00', '2020-08-06 14:54:44.503135+00', 2727, 1, NULL, 'ace', '1–::

  1M+2W set | cross RH ; 1W+2M repeat

9–::

  2c+1c set | cross RH ; RHA

17–::

  1c dance down between 3c | cast up ; dance up between 2c, cast off to 1cnrs (all on own side)

25–::

  Turn CPCP', 2);
INSERT INTO 'dancecrib' VALUES (9296, '2016-09-17 21:34:06.731694+00', '2016-09-17 21:34:06.731694+00', 9413, 1, NULL, 'ace', '1--::

  1c+2c S&Link ; Circle4 L (2,1,3)

9--::

  1c+3c S&Link ; Circle4 L (2,3,1)

17--::

  3c+1c Turn BH | dance up, 3c leading, and cast off to (2,1,3) | 1c turn BH ¾ and face M side

25--::

  Reels3 across, 1W Rsh to 2M and 1M Lsh to 3M, finish (2,1,3) 

', 2);
INSERT INTO 'dancecrib' VALUES (2409, '2012-01-22 19:29:36.281858+00', '2021-10-11 22:46:15.63227+00', 2807, 1, NULL, 'ace', '1–::

  1c turn RH ½  | lead down ; turn RH ½  | lead up to place

9–::

  2c repeat

17–::

  1c+2c set | ½ RHA ; set | ½ LHA into

25–::

  1c+2c Poussette (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (14021, '2021-05-10 17:17:28.795293+00', '2021-05-10 17:20:50.587205+00', 19995, 1, 202, 'ace', '1--::

  1c+3c DblFig8, 1c casting, 3c crossing up. On [7-8] 1c pass P RSh to face 1cnrs (2c up)

9--::

  *Set to Corners and Cast Away* : 1c set to 1cnr | 1c cast RSh round P to 3cnr[pos] _while{2}_ cnrs on 1diag dance into centre and swivel R BtoB to face own cnr[pos] ; repeat, cnrs on 1diag finishing in exchanged places, and 1c facing 2cnrs

17--::

  Repeat [9-16] with 2cnrs. On [23-24] 1c pass P RSh to 2plx (3x,1x,2x)

25--::

  3C S&Link twice (2,1,3)

33--::

  Circle6 and back



*Note* : Set to Corners and Cast Away is also known as "Best Set in the Hall Figure".', 2);
INSERT INTO 'dancecrib' VALUES (8119, '2013-11-26 01:18:35.067057+00', '2014-04-30 23:23:52.963719+00', 15265, 1, NULL, 'ace', '1–::
  1c set | cast (2c up) ; All set | 1c cross RH _while{2}_ 2c+3c Petronella to midline
9–::
  All dance Weasel Reel [Reel4 on midline, on reaching the end each dancer chases clockwise to the other end, and is replaced in the reel4 by a dancer finishing that chase]. Finish as started. 1c facing P in 2plx
17–::
  All set | 2c+3c Petronella to opposite side as 1c set (2x,1x,3x) ; All chase clw ½ round and take P in promhold facing up for
25–::
  3c+1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3602, '2012-07-21 11:45:37.565841+00', '2014-10-26 14:14:19.283863+00', 11282, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; dance between 3c and cast up into

9-12::

  2c+1W & 1M+3c RHA, finish facing 1cnr

13-16::

  1c+1cnrs turn ½ RH _while_{2} 2cnrs set | centre dancers turn ½ LH _while_{2} the others chase clw one position

17–::

  repeat [13-16] twice from new positions, 1c finish facing 1cnr

25–::

  Set R to 1cnr {1} and L to P {1} | turn ¾ RH ; set R to 2cnr and L up/down to P | turn ¾ RH to 2pl



{{explanation}}

Note: In the »Quarries''Jig« figure [13-16], the movements on 1diagonal flow best as half turns, but are called »change places« in the original', 3);
INSERT INTO 'dancecrib' VALUES (2406, '2012-01-22 19:29:36.112522+00', '2014-04-30 23:23:53.005626+00', 13747, 1, NULL, 'ace', '1–::
  1M+2M & 1W+2W (1c starts inwards) Turn 1½ EH to change places ; 1M+3M & 1W+3W repeat with other hand (to 2,3,1), 3c facing out
9–::
  1c dance NHJ to top, cast off one ; turn twice RH (or birl) to face 3cnr, 3c cast to 3pl on [9-10]
17–::
  Diag Reel4 with 3cnrs (twiddles allowed), at end pass Lsh to face 2cnr
25–::
  Diag Reel4 with 2cnrs , finish (2,1,3)  (on 2nd time through, top W may finish facing out, for the next LH turn)', 3);
INSERT INTO 'dancecrib' VALUES (1916, '2012-01-22 19:29:09.664925+00', '2015-03-25 16:29:28.789593+00', 1077, 1, NULL, 'ace', '1–::

  All set | ½ Circle6 L ; set | ½ Circle6 L (1,2,3)

9–::

  1c turn RH | cast to face 1cnr (2c up) ; set to 1cnr | set to 2cnr, swiveling R to between cnrs (2,1x,3)

17–::

  2c+1c R&L and continue into

25–::

  2c+1c+3c Half G-Chain, 2c cross to start ; ½ Circle6 L | 1c cross RH (2,1,3)



{{explanation}}

on 2nd time through 1c cross to 4pl, 4c step up', 2);
INSERT INTO 'dancecrib' VALUES (2402, '2012-01-22 19:29:35.884438+00', '2016-07-05 06:58:08.746856+00', 2770, 1, NULL, 'ace', '{{explanation}}

Note: all corners refer to positions, not persons



1–::

  1c long cast to 2pl (2c up) ; ½Reels3 across, Lsh to 1cnr, 1c finish facing 4cnr

9–::

  1c turn cnr RH into DTr position, M facing down, W up ; All set | turn 1cnr LH to face 2cnr

17–::

  1c turn 2cnr RH into DTr position, W facing down, M up ; All set | turn 3cnr LH to face 2cnr

25–::

  ½Reels3 across, Rsh to 2cnr, ; 1c turn RH 1½ to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9297, '2016-09-17 23:07:52.070206+00', '2016-09-17 23:11:01.190037+00', 16474, 1, NULL, 'ace', '1--::

  1c+3c set and turn P RH ; all turn corner LH and all W face out

9-24::

  Full Schiehallion Reel

25--::

  All turn P RH into Allemande hold facing clw | promenade ¾ clw (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10551, '2018-03-26 02:01:40.312322+00', '2018-03-26 02:15:19.49016+00', 12230, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up), finish facing 2c on sidelines ; 1c turn 2c LH, M facing out at end (2,1x,3)

9--::

  2c+1c La-Chain, 1c facing 1cnrs at end

17--::

  1c ½ Reel4 on 1diag, start *Lsh* to 1cnrs, pass P Lsh to face 4cnrs ; ½ Reel4 on 2diag, start *Lsh* to 4cnrs, to 2pl facing 3cnrs (3x,1,2x)

25--::

  1c ½ Fig8 L, Rsh to 2cnrs position (to 3x,1x,2x) ; chase clw ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2411, '2012-01-22 19:29:36.378253+00', '2019-03-07 09:29:45.321892+00', 8103, 1, NULL, 'ace', '1–::

  1W+2W+3W set adv to 2M+3M+4M | dance Rsh round that M to own place {4} | All C cross RH (1x,2x,3x,4x)

9–::

  1M+2M+3M set adv to 2W+3W+4W | dance Rsh round that W to own place {4} | 4c cross RH _while_{2} 1c+2c+3c Turn RH ½ into the middle for

17–::

  1c+2c+3c Allemande (to 3,2,1,4)

25–::

  3c+2c & 1c+4c  set to P | ½ RHA ; set to P | cross RH (to 2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2405, '2012-01-22 19:29:36.023253+00', '2019-03-16 15:49:53.169563+00', 2782, 1, NULL, 'ace', '1–::

  All W A&R ; All C dance BtoB

9–::

  All M A&R ; All C dance BtoB

17–::

  1c cross RH | cast (2c up) ; cross LH | cast off (3c up)

25–::

  1c Fig8 round 3c', 2);
INSERT INTO 'dancecrib' VALUES (2401, '2012-01-22 19:29:35.844266+00', '2016-11-15 02:31:09.83872+00', 8861, 1, NULL, 'ace', '1–::

  1c dance between 3c and cast (1W leading) round 3W to the middle (2c up) ; 1W+2c RHA _while_{4} 1M+3c LHA

9–::

  Three couples dance Reel3 on midline, 1c Rsh to 2c (2c & 3c stay on own side NHJ, changing hands at top & bottom, 1M follows 1W to start, change lead at top and bottom)

17–::

  1W+2c RHA _while_{4} 1M+3c LHA ; 1W casts up & 1M casts down (both on M-side) and meet in 2pl BtoB facing own sides

25–::

  DTr (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13782, '2021-03-02 14:48:46.000177+00', '2021-03-04 14:11:14.36905+00', 20238, 1, 202, 'ace', '1--::
  1c long cast to 2pl, touching hands briefly (2c up) ; 1c turn RH to centre, RSh to P facing 2cnrs
9--::
  1c+2cnrs dance BtoB ; 2c+1M & 1W+3c LHA. 1c in centre, LSh to P, face 1cnrs
17--::
  1c+1cnrs dance LSh BtoB ; 2c+1W & 1M+3c RHA. 1c finish BtoB on midline, 1M facing down
25--::
  2c+1c+3c chase clw ½, 1W dancing up between 2c & 1M dancing down between 3c into facing lines3 across (1M between 3c on top, 1W between 2c on bottom) ; 1c set | Petronella Turn to 2pl _while{4}_ 3c+2c ½ R&L up/down (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (2279, '2012-01-22 19:29:29.415627+00', '2021-06-06 12:43:25.493354+00', 2333, 1, NULL, 'ace', '1–::

  1c cross down RH to 2pos BtoB (2c up) | six bars of DTr

9–::

  1c cast below 3c | tulloch turn (or spin) once to finish own side BHJ ; slip up the middle to top | cast off to 2pl

17–::

  1W+2c & 1M+3c Reels3 across, Lsh to 1cnr

25–::

  2c+1c+3c set advancing | All tulloch turn (or spin) once round ; turn RH (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (4987, '2013-08-21 08:30:58.521957+00', '2023-02-10 15:12:15.107441+00', 1643, 3, NULL, 'ace', '1-8::

    1s set & cast 1 place, 1s dance 1/2 Fig of 8 (1L round 2s, 1M round

    3s) & end BtoB (1M facing up & 1L facing down as for Crown

    Triangles)

9-12::

    All set & 1s dance up/down to 1st & 3rd pstns & turn about _while_

    2s+3s dance towards each other & meet on sides to form a diamond

13-16::

    All set & as 1s set advancing & pass LSh to end BtoB the 2s & 3s

    retire to places

17-24::

    1s dance Figs of 8 (1L dancing round 2s, 1M round 3s) ending 2nd

    place own side _while_ 2s+3s dance R&L (starting on sides)

25-32::

    All petronella turn twice to opposite sides, all set & cross RH to

    own sides', 0);
INSERT INTO 'dancecrib' VALUES (2418, '2012-01-22 19:29:37.2895+00', '2020-12-23 10:58:26.790945+00', 10231, 1, NULL, 'ace', '1–::

  1c set | cross RH ; 1M + 1W following cast off 2 (2c+3c up), 1M crossing (2,3,1)

9–::

  Rsh Reels3 on the sides, 3c starting down

17–::

  2c+1c turn RH ; 2c cast off 2 _while{2}_ 1c lead up 2 | All set (1,3,2)

25–::

  2c+3c set up/dn | change places EH (2c pass inside) ; 1c+2c repeat (2c pass outside) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11273, '2018-10-17 20:10:30.59693+00', '2021-07-26 14:49:24.226126+00', 16857, 1, 1645, 'ace', '{{explanation}}

Strathspey



1-::

  1c dance down between 3c | 1c+3c turn &frac34; EH (2c up) ; 1c dance up between 2c | 1c+2c turn &frac34; EH (2,1,3,4)

9-::

  2c+1c+3c Circle6 to L & pivot ; chase back, 1c end facing 1cnrs

17-::

  Interrupted H&G setting: 1c H&G set to 1cnr | turn P &frac34; RH to 2cnr ; H&G set to 2cnr | turn P &frac34; RH to (2,1,3,4)

25-::

  1c+3c diamond poussette (2,1,3,4)



{{explanation}}

Reel



1-24::

  1c repeat [1-24] from 2pl to (2,3,1,4) but 1c end in centre as 4c step in

25-::

  1c+4c poussette (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (9866, '2017-05-19 12:49:52.007278+00', '2017-08-26 10:25:52.888637+00', 10660, 1, 202, 'ace', '1--::

 1c turn RH 1 ½ to 1plx facing out ; 1c+2c turn EH 1 ½, 1c facing down (2,1x,3)

9--::

 Reels3{6}, 1c start in and down | 1c pass Rsh to DTr pos

17--::

 DTr, 1c in DTr pos again

25--::

 1c cast R to midline facing each other ; cross RH up/dn | cast R to 2pl _while{8}_ 2M+3W cross RH as 2W+3M set diag | 2M+3W set diag *facing out* as 2W+3M cross RH ; 3c & 2c set pulling Rsh back to face P | 3c & 2c cross RH (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (3860, '2013-07-13 19:59:42.735826+00', '2014-04-30 23:23:53.253176+00', 14978, 1, NULL, 'ace', '1–::
  1c long cast (2c up), between 3c and cast up (2,1,3)
9–::
  1c lead down | Turn BH ; Lead up | turn BH ½ and pivot R to face 1cnr
17–::
  Cnrs pass and turn, to finish (2,1,3)
25–::
  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (3639, '2012-08-20 21:09:53.272986+00', '2014-07-08 07:20:53.061495+00', 13619, 1, NULL, 'ace', '1–::

  1c Rsh Fig8 on own side round 2c&3c (1,2,3)

9–::

  1c turn RH | cast (2c up) ; turn LH to (2,1,3)

17–::

  G-Chain, 2c cross to start

25–::

  All A&R ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8196, '2014-02-13 23:36:26.296802+00', '2014-04-30 23:23:53.277298+00', 9948, 1, NULL, 'ace', '1–::
  1c+4c set | cross EH to middle (2c+3c step to end), cast on opposite side to own end and lead to meet in the middle
9–::
  1c+4c RHA ; join with cnrs NH and in big wheel ½ RHA, finish facing cnr
17–::
  Centres set to cnr | turn cnr ½ LH putting 2c&3c in centre (2c face M side and 3c W side) ; 2c & 3c chase clw to other end as 1c+4c step to middle (2,4,1,3)
25–::
  2c+4c & 1c+3c Circle4 and back (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2413, '2012-01-22 19:29:36.521863+00', '2016-08-30 22:20:28.662768+00', 2820, 1, NULL, 'ace', '{{explanation}}

Running step is used throughout



1–::

  1W+4M dance towards the centre, turn RH and return to places ; 1M+4W repeat

9–::

  Repeat, using left hand turns

17–::

  Repeat, using BH turns ;

25–::

  1W+4M dance BtoB ; 1M+4W repeat

33–::

  1W+4M advance {1}, curtsey/bow {1}, and retire to places {2} ; 1M+4W repeat

41–::

  1c followed by the other C cast off to 4pl, 1c forms arch ; 2c+3c+4c dance up under the arch (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2432, '2012-01-22 19:29:38.457381+00', '2014-04-30 23:23:53.742939+00', 12603, 1, NULL, 'ace', '1–::
  1c set | cast (2c up) ; cross Lsh | cast R round 1cnr to face up/dn between end Cs
9–::
  1c set advancing | Highland style Tulloch Turn (L arms raised) and pivot R to face opp. side
17–::
  2c+1W & 1M+3c RHA, 1c pass Rsh into ; 2c+1M & 1W+3c LHA, and 1c face 1cnr
25–::
  Cnrs Pass and Turn (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2419, '2012-01-22 19:29:37.334528+00', '2014-04-30 23:23:53.404761+00', 2853, 1, NULL, 'ace', '1–::
  1c cross RH and cast off (2c up) ; 1M+2c & 1W+3c RHA (Teapots), finish in lines of 3 across facing down (1M swivels R)
9–::
  All dance down the middle and back, finishing 2c & 3c facing P and 1c facing 2cnr
17–::
  Reels3 across, 1c Lsh to 2cnr, finish all facing P
25–::
  1c turn BH ½ | set to P ; turn BH 1¼ _while_{8} 2c+3c ½ R&L and face up/down ; ½ R&L back starting along sidelines (2,1,3)

{{explanation}}
On second time through, 4c finish the R&L in 3pl and 1c turn to 4pl', 3);
INSERT INTO 'dancecrib' VALUES (13495, '2020-12-31 22:58:25.887036+00', '2023-02-12 15:58:15.380704+00', 1634, 2, 202, 'ace', '1--::

  1c set | turn RH ; cast off (2c up) | turn LH ¾ into midline

9--::

  2c+1M & 1W+3c RHA ; LSh Snake pass ready for

17--::

  3c+1W & 1M+2c LHA ; RSh Snake pass to sides (2,1x,3)

25--::

  All set | 1c Petronella turn into facing lines3 across ; all set | 1c Petronella turn (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9299, '2016-09-18 12:31:34.486473+00', '2016-09-18 12:31:34.486473+00', 2346, 1, NULL, 'ace', '1--::

  1c long cast (2c up) ; 2c long cast (1c up) (1,2)

9--::

  Reel4 on 1diag, to start 1W&2M pass Lsh (1,2)

17--::

  All turn P BH 1½ ; 1W+2M change place RH as 1M sets to 2W | 1M+2W change place RH as 1W sets to 2M (2,1)

25--::

  1c+2c Poussette (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2408, '2012-01-22 19:29:36.207093+00', '2018-03-26 10:00:20.932952+00', 2805, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; 1c ½ Fig8 to the R _while{4}_ 2c+3c set and cross RH (2x,1,3x)

9–::

  1c cross RH | cast R ; cross between end couple | cast R to meet P in 2pl _while{8}_ 2c+3c Set | Petronella to midline ; set to P | Turn RH ¾, all finish facing up in allemande hold

17–::

  2c+1c+3c Allemande (3,1,2)

25–::

  All Set | cross RH ; All chase clw ½ (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10552, '2018-03-26 07:19:03.324925+00', '2018-03-26 07:29:42.444042+00', 12254, 1, 202, 'ace', '1--::

  1c+2c set | cross RH ; S&Link (2x,1x)

9--::

  1M & 2W chase clw ½ to exchanged places ; 1M+2W dance BtoB, back to next place cclw _while{4}_ 1W & 2M set diagonally | cast to next place clw

17--::

  Repeat [9-16] from new places (1,2)

25--::

  The Knot (2,1) ', 2);
INSERT INTO 'dancecrib' VALUES (8677, '2015-02-18 17:02:35.647313+00', '2019-12-20 13:51:29.4394+00', 16072, 2, 1, 'ace', '1–::

  1c set | cast off (2c up) ; 1c lead down crossing RH | cast up

  [fin 21x3 in middle, 2c&3c facing up, 1c facing down]

9–::

  Circulating allemande for 3 couples [on 15–16, 1c turn ¾ RH to fin facing

  2nd corner places]

17–::

  Corners pass and turn on 2nd corner diagonal (corners turn BH)

  – at end, 1c dance round partners LS to fin facing 1st corner places ;

  corners pass and turn on 1st corner diagonal (corners turn BH)

  – 1c fin in 2nd place own sides.

25–::

  Circle6 and back', 5);
INSERT INTO 'dancecrib' VALUES (2487, '2012-01-22 19:29:44.075622+00', '2020-09-18 08:07:42.324062+00', 13465, 1, NULL, 'ace', '1–::

  1c+2c+3c A&R ; Turn P RH into promhold for

9–::

  1c+2c+3c Promenade

17–::

  1c lead down the middle and up, and face out

25–::

  1c cast behind 2c | dance between 3c ; cast behind 4c (2c+3c+4c up) | 1c turn RH (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (10253, '2017-11-12 23:12:16.901521+00', '2021-01-03 12:50:43.505844+00', 13307, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c RHA ; 2c+3c LHA

9--::

  1c+2c & 3c+4c DblFig8, 1c+4c cross to start

17--::

  1c & 4c lead down/up{2} _while{2}_ 2c & 3c cast out to end places | 1c+4c ½ RHA ; 1c & 4c turn P RH ½ and cast R to (2,4,1,3)

25--::

  2c+4c & 1c+3c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (12445, '2019-12-22 19:01:20.652503+00', '2019-12-22 20:13:25.29009+00', 11351, 1, 202, 'ace', '1--::

  1c+2c+3c Reels3 on opposite side, all crossing from the top, 2c starts out and up (1x,2x,3x)

9--::

  1c+2c+3c Reels3 on own sides, all crossing back from the top (1,2,3)

17--::

  1W+2M set | cross RH ; 1M+2W set | cross RH (2x,1x,3)

25--::

  2c & 1c set to P (no hands) | turn P RH ½ and stay in centre RHJ ; 2c+1c RHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2415, '2012-01-22 19:29:36.650646+00', '2019-03-16 13:01:56.360709+00', 2825, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; ½ Fig8 round 3c (to 2,1x,3)

9–::

  3c set | cast up (1c down) ; ½ Fig8 round 2c (to 2, 3x, 1x)

17–::

  2c lead down, cross below 3c cast behind 1c ; lead up, cross below 3c and cast up (to 2,3x,1x).

25–::

  Crossover reels on the sides ; all C crossing down from the top, 2c also crossing at the bottom (2,3,1). (for 2c this repeats bars 17-24)', 2);
INSERT INTO 'dancecrib' VALUES (2293, '2012-01-22 19:29:30.166845+00', '2019-05-14 01:14:19.469814+00', 2364, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; dance between 3c and cast up, 2c+3c step in on [8]

9–::

  2c+1c+3c Allemande (3,1,2)

17–::

  In lines Advance {1}, Retire {1) | Cross RH to sides ; Half Circle6 L (2,1,3)

25–::

  1c+3c turn RH ¾ | Half Reel4 on midline| 3c+1c turn RH ¾ (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (8022, '2013-08-31 21:04:44.8148+00', '2016-04-18 23:03:02.516168+00', 7415, 1, NULL, 'ace', '1–::

  1c cast (2c up) | cross Rsh, cast R round 1cnr to meet and turn BH to face 1cnr

9–::

  Set to 1cnr | dance BtoB with 1cnr | set to 1cnr and face 2cnr

17–::

  Repeat with 2cnr, finish 1M between 2c facing 1W between 3c

25–::

  Reels3 across, Rsh to 3cnr, finish in 2pl facing out to begin again', 3);
INSERT INTO 'dancecrib' VALUES (9621, '2017-02-26 14:42:57.701906+00', '2021-01-14 20:13:42.751317+00', 12437, 2, 3155, 'ace', '1-4::

   1s lead down the middle, 2s step up on bars 3–4

5-8::

   On bar 5, 1M turns his partner under his right

  arm, they lead up to 2nd place and finish in the

  centre of the set, back to back, facing opposite

  sides.

9-16::

   2s, 1s & 3s dance “Angus MacKinnon Triangles”

17-24::

  1s turn 1st corner RH, pass each other right

  shoulders, turn 2nd corner RH and pass each

  other right shoulder to finish in 2nd place own

  sides. (Corners dance for 4 bars.)

25-28::

  2s, 1s & 3s dance six hands round to the left for

  SIX steps and then on bar 28, cross right foot

  over left and, keeping the weight on both feet

  and releasing hands, pivot round to face out

  pulling left shoulder back.

29-32::

   2s, 1s & 3s dance around in a chase (anticlockwise)

  back to own sides.', 2);
INSERT INTO 'dancecrib' VALUES (2433, '2012-01-22 19:29:38.47807+00', '2021-10-11 22:49:52.243236+00', 2934, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; turn LH 1½ to face 1cnrs

9–::

  1c set to and turn corners, finish facing 1cnrs

17–::

  Reels3{6} with corners, Lsh to 1cnr | 1c cross RH to own side (2,1,3)

25–::

  2c+1c+3c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (2425, '2012-01-22 19:29:38.015924+00', '2016-11-02 23:10:21.101432+00', 13587, 1, NULL, 'ace', '{{explanation}}

On 2nd chord, 2c+4c cross (1,2x,3,4x)



1–::

  Parallel Reels4 on the sides, on [8] mid Cs do not pass but pivot R to face end Cs (1,3,2x,4x)

9–::

  1c+3c & 2c+4c R&L start on sides, 3c+2c finish in middle BHJ

17–::

  3c+2c Poussette (1,2x,3,4x)

25–::

  2c & 3c ½ Fig8 round end C (1,2,3x,4x) ; All turn P RH and face end (1c+2c face up, 3c+4c down)

33–::

  1c+2c & 3c+4c Interlocking Allemandes: the mid couples pass each other to finish (2,4x,1,3x)', 3);
INSERT INTO 'dancecrib' VALUES (2430, '2012-01-22 19:29:38.322547+00', '2016-07-15 22:36:12.970818+00', 2925, 1, NULL, 'ace', '1–::

  In trios A&R twice

9–::

  Men Lsh Reels3 with W on R and W opposite

17–::

  Same 3 dancers Circle3 and back, to places

25–::

  In trios A&R ; pass person opposite Rsh to face next trio.', 3);
INSERT INTO 'dancecrib' VALUES (2427, '2012-01-22 19:29:38.125111+00', '2014-04-30 23:23:53.624257+00', 2916, 1, NULL, 'ace', '1–::
  1c set | cast off to 3pl (2c+3c up) ; 2c+3c cross RH
9–::
  1c lead up to the top (2c+3c down) ; 1c set | cast off (2c up) to face 3cnr position (2cnr persons)
17–::
  1c set to and turn corners (3cnr, 4cnr positions), finish facing out between them (2x,1,3x)
25–::
  2c+1c+3c BiL twice, 1c tunr R about on [28] to 2pl facing in ; 2c+1c+3c turn P RH to own side (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10252, '2017-11-12 16:09:17.191656+00', '2017-11-12 21:33:43.977882+00', 3448, 2, 2929, 'ace', '1-4::

  1M set advancing to 2W, turn 1W LH

5-8::

  1W set advancing to 2M, turn 1M RH

9-12::

  1C set advancing to 3W [2C step up], circle L with 3W

13-16::

  1C set to 2M, circle L with 2M

17-20::

  Set to corners, finish between corners on sidelines

21-24::

  1C turn BH twice around

25-28::

  2C + 1C circle left all the way

29-32::

  1C lead up, cross, and cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (2826, '2012-01-22 19:29:59.006534+00', '2017-09-19 16:40:51.278738+00', 4558, 1, NULL, 'ace', '1–::

  1c+2c Non-progressive Allemande (2c starts in and up as 1c casts behind) (1,2,3)

9–::

  1c+3c Non-progressive Allemande (3c starts in and up as 1c casts behind) (2c up) (2,1,3)

17–::

  1c set | dance to top ; cast off (2,1,3) | 1W dances up and 2W casts off into

25–::

  2M+1W & 1M+2W Allemande, 1M+2M change places LH on [31-32]', 3);
INSERT INTO 'dancecrib' VALUES (3071, '2012-01-22 19:30:09.292759+00', '2020-09-18 08:23:10.604915+00', 13471, 1, NULL, 'ace', '1–::

  1c cross | cast two (2c+3c up) ; 1c+4c RHA, into

9–::

  3c+1c L-Chain

17–::

  1M, P following, cast up 2 and cross to own places (2c+3c down) ; 1c+2c LHA

25–::

  1c turn 2c LH 1½ on sidelines ; 1c+3c change places RH | 1c+4c change places LH (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (12447, '2019-12-24 02:32:47.056106+00', '2019-12-24 02:37:45.932879+00', 11359, 1, 202, 'ace', '1--::

  1c lead down {3}, lead up {3} | cast to 2pl (2c up) (2,1,3)

9--::

  1c ½ Fig8 up round 2c ; ½ Fig8 down round 3c (2,1,3)

17--::

  Reels3 on sides, 1c RSh to 4cnrs (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (12448, '2019-12-26 00:27:44.165955+00', '2019-12-26 00:29:44.712941+00', 17402, 1, NULL, 'ace', '1--::

  1W+2M dance BtoB ; loop in to pass close Lsh and cast R to next place clw (1M+2W step down/up) (2,1)

9--::

  2W+1M repeat (1,2)

17--::

  1c+2W Circle3 L ; 1c+2c Circle4 R, finish for (1,2)

25--::

  Poussette (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (14023, '2021-05-13 02:06:27.517538+00', '2021-05-13 02:08:30.903297+00', 2456, 1, 202, 'ace', '1--::

  1c+2c RHA ; LHA (1,2)

9--::

  1c Fig8 down round 2c (2,1)

17--::

  1c (+2c who dance up to follow) lead down ; 1c (2c following) lead up ready for

25--::

  2C Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2426, '2012-01-22 19:29:38.075189+00', '2021-05-28 12:44:22.840896+00', 2910, 1, NULL, 'ace', '1–::

  1c cast off behind own lines ; cast back

9–::

  1c+2c Turn RH ; repeat LH

17–::

  1c followed by 2c lead down the middle ; and up, 2c leading (to 2,1)

25–::

  2c+1c R&L.', 3);
INSERT INTO 'dancecrib' VALUES (2424, '2012-01-22 19:29:37.95107+00', '2021-05-28 12:53:12.134876+00', 2903, 1, NULL, 'ace', '1–::

  1c+2c cross, M NHJ between W ; cross back, W NHJ between M

9–::

  RHA ; LHA

17–::

  1c lead down the middle and up

25–::

  Poussette', 3);
INSERT INTO 'dancecrib' VALUES (2422, '2012-01-22 19:29:37.858219+00', '2017-02-14 16:30:16.016851+00', 2886, 1, NULL, 'ace', '1–::

  1c+2c set | 1W, 1M following, cast behind 2W, cross up between 2c, and cast off, crossing (2c up) to (2,1,3)

9–::

  1c+3c set | 1M, 1W following, casts off behind 3M, crosses up, casts behind 3W, crosses (3c up) to (2,3,1)

17–::

  1c (1M leading) + 2c (1W leading) cast clw to change places (1x,3,2x) ; All Circle6 L

25–::

  Repeat [17-24] in the opposite direction (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (9989, '2017-07-01 03:51:41.877005+00', '2017-07-02 19:48:04.826376+00', 7274, 1, 202, 'ace', '1-- ::

 1c set | cast (2c up) ; 1c+3c ½ R&L (2,3x,1x)

9-- ::

 2c set | cast (3c up) ; 2c+1c ½ R&L (3x,1,2x)

17-- ::

 1c cross RH | cast R into facing lines across ; all A&R

25-- ::

 1c cross RH | cast R to 2plx _while{4}_ 2c+3c set diag | ½ RHA (to 2,1x,3) ; all set | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2444, '2012-01-22 19:29:39.174986+00', '2015-10-04 07:03:17.178544+00', 11538, 1, NULL, 'ace', '1–::

  All clap as 1c+4c cross Rsh | cast in (2c+3c step to end) ; 1c+4c RHA (2,1x,4x,3)

9–::

  All clap as 1c+4c cross Rsh | cast out (2c+3c step to middle) ; 1c+2c & 3c+4c LHA (1,2,3,4)

17-22::

  1M+2M change places RH with 3W+4W | 3M+4M repeat RH with 1W+2W ; 3W+4W repeat RH with 1M+2M

23-24::

  4M+1W change places LH _while{2}_ the other 6 dancers cast cclw to the next place of the 6 (1M+4W cast in one , 2M+3W cast 2 to the other end, 3M+2W cross to own side and swivel L to face in) (3,1,4,2)

25–::

  3c+1c & 4c+2c R&L



{{explanation}}

note: the »loops« traditionally danced between the diagonal crossings are allowed as an option, but not preferred by the author', 3);
INSERT INTO 'dancecrib' VALUES (3794, '2013-07-13 15:56:08.333772+00', '2014-04-30 23:23:53.785406+00', 14390, 1, NULL, 'ace', '1–::
  1c cross RH | cast (2c up) ; 1c+3c ½R&L (2,3x,1)
9–::
  1c cross RH | cast up (3c down) ; 2c+1c ½R&L (1,2x,3x)
17–::
  1c set | cross down RH through 2c (2c up) cast round 3c and lead up to face 1cnr pos.
25–::
  1c ½Reel4 with 1cnrs, pass RSH ; ½Reel4 with 2cnrs, pass Rsh to (3,1,2)
33–::
  All chase clw to opposite sides ; set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9300, '2016-09-18 13:11:22.897807+00', '2016-09-18 13:12:45.613462+00', 15399, 1, NULL, 'ace', '1--::

  Gr-Chain, 1c cross to start, at end 1M faces out

9--::

  1c, 1M leading, cast off 2 and cross (2c up); 1M cast up as 1W dances up | 2c+1c ½ RHA (1,2x,3), 

17--::

  1c, 1W leading, cast off 2 and cross (2c up); 1W cast up as 1M dances up | 2c+1c ½ LHA (1,2,3), 

25--::

  1c+2c Poussette (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (7989, '2013-08-21 08:31:54.143578+00', '2023-02-04 01:23:15.090317+00', 10171, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place _while_ 2s set & dance up, 1s turn 2s on
    sides with nearer hand
9-16::
    1s cross RH & cast down 1 place _while_ 3s set & dance up 1 place,
    1s turn 3s on sides with nearer hands
17-24::
    1s cross up to dance reels of 3 on opposite sides & end 2 3 (1)
25-32::
    1s dance 1/2 Fig of 8 round 3s & all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (12954, '2020-07-10 22:17:16.480752+00', '2020-07-10 22:20:04.752772+00', 19673, 1, 202, 'ace', '1--::

  1c followed by 2c,3c & 4c (who dance up) cast off behind own lines ; meet below 4pl and lead up in the middle

9--::

  All promenade (1,2,3,4)

17--::

  All set | 1c+2c & 3c+4c ½ RHA (to 2x,1x,4x,3x) ; 2c & 3c set _while{2}_ 1c+4c ½ LHA | all set (2,4,1,3)

25--::

  Reels4 on sides (2,4,1,3)

33--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (2442, '2012-01-22 19:29:39.077931+00', '2014-04-30 23:23:53.932645+00', 2972, 1, NULL, 'ace', '1–::
  1c cast off behind own lines ; cast up to places
9–::
  1c+2c RHA ; LHA
17–::
  1c cross RH and cast off one (2c up) {3}, cross LH and cast off one {3} | dance up the middle to 2pl
25–::
  2c+1c+3c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (8157, '2014-01-15 14:16:05.753778+00', '2014-04-30 23:23:53.938526+00', 2975, 1, NULL, 'ace', '1–::
  1c+2c Adv{1}&Ret{1} | 1c cast as 2c dance up ; 1c turn LH to face 2cnr | turn 2cnr RH into promhold and face 3cnr
9–::
  ½ Reel4 on 1diag, but at the end the cnrs turn LH ¾ to finish at 2cnr (across from their starting position) ; 1c turn LH to face 2cnr _while_{2} guiding their cnr RH to 1cnr | turn 2cnr (=3rd cnr person) RH into promhold and face 3cnr (all cnr persons have moved one place clw)
17–::
  Repeat [9-16] with the new corners, but at the end 1c turn to own side (3x,1,2x)
25–::
  Diag R&L (2,1,3)

{{explanation}}
On 3rd time through, new 3c+4c copy [1-4] to progress.  
Note: numbered cnrs refer to positions', 2);
INSERT INTO 'dancecrib' VALUES (2168, '2012-01-22 19:29:23.581558+00', '2020-12-06 11:07:43.273254+00', 1937, 1, NULL, 'ace', '1–::

  1c set | cross RH and hold ; set | cross to 2pl in promhold facing up (2c up)

9–::

  1c Rsh Reel3 with 2c

17–::

  1c lead to top, cross and cast to 2pl (2,1,3) ; Mirror ½ Reels3 on the sides, 1c starting in and down (3,1,2)

25–::

  1W+3c ½ Reel3 across _while{4}_ 1M+2c RHA ; 3c+1M LHA _while{4}_ 1W+2c ½ Reel3 across (3x,1,2x)

33–::

  Diagonal R&L (first to R, then to L) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8110, '2013-11-16 23:29:43.317674+00', '2014-04-30 23:23:54.049325+00', 15263, 1, NULL, 'ace', '{{explanation}}
A. For 1st time through:

1–::
  1W with 1M following cast to 2plx (2c up) ; 2c+1c RHA
9–::
  1W with 1M following cast to 3pl (3c up) ; 3c+1c LHA (2,3,1)
17–::
  1c set | turn RH {4} | lead to top (3c down)
25–::
  1c cast off | ½ Fig8 up | cross RH (2,1,3)

{{explanation}}
B. For 2nd time through:

1–::
  1M with 1W following cast to 2plx (2c up) ; 2c+1c LHA
9–::
  1M with 1W following cast to 3pl (3c up) ; 2c+1c RHA (2,3,1)
17–::
  1c set | turn RH {4} | lead to top (3c down)
25–::
  1c cast off | ½ Fig8 up | cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9885, '2017-05-27 23:30:11.636658+00', '2017-08-26 10:35:12.036366+00', 10094, 1, 202, 'ace', '1-4::

 1M+3W turn RH ¾ | dance out through 3M/1W pl to original places _while{4}_ 1W & 3M cast dn/up 2 pl | 1W+3M turn RH ¾ to original places facing out

5-8::

 1c+2c RHA _while_ 3c+4c LHA, 1W & 3M facing out

9--::

 1c+3c repeat [1-4] ; 1M+2W & 3W+4M cross RH | 1W+2M & 3M+4W cross RH (2x,1x,4x,3x)

17--::

 2c+1c & 4c+3c Circle4 and back

25--::

 All set |  2c & 3c cross RH _while_ 1c+4c ½ RHA ; all turn P RH  (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2445, '2012-01-22 19:29:39.251444+00', '2017-02-13 14:49:34.459228+00', 7420, 1, NULL, 'ace', '1–::

  1c+2c RHA 1W faces out ; 1W (1M following) cast behind W line to 3pl opposite side, facing 3c(2c+3c up)

9–::

  2c+3c+1c G-Chain (2c cross)

17–::

  1c set, turn BH ½ and face up ; dance to top and cast off to 3pl

25–::

  2c+3c+1c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (11167, '2018-09-26 22:33:10.286923+00', '2021-02-13 02:03:37.680141+00', 17957, 1, 202, 'ace', '1--::
  ½ Mirror Reels3 on opposite sides, 1c crossing down (to 3,2,1x) ; 1c turn 2c EH 1½ on sides, finish 2c in 3pl, 1c face 1cnrs[pos] (3,1,2)
9--::
  »Set to Corners and Cast Away« [1c set to 1cnrs[pos] | 1c cast RSh round P to 3cnrs[pos] _while{2}_ cnrs on 1diag dance into centre, and swivel R BtoB to face own cnrs[pos] ; repeat, cnrs on 1diag finishing in exchanged places, and 1c facing 2cnrs[pos]]
17--::
  Repeat [9-16] with 2cnrs[pos]. On [32] 1c finish in centre RSh to P facing opposite sides (2x,1,3x)
25--::
  1M+2M+3M & 1W+2W+3W LHA ; 2cnrs[pos] (2M & 3W) leading, all chase cclw to own sides (1,3,2 on Mside, 3,2,1 on Wside)
33--::
  3C Bourrel. On [39-40] all Petronella Turn to sides (2,1,3)

*Note:  
»Set to Corners and Cast Away« is also called "Best Set in the Hall Figure".*', 2);
INSERT INTO 'dancecrib' VALUES (3795, '2013-07-13 15:56:08.360484+00', '2021-01-08 18:06:48.545461+00', 12835, 1, NULL, 'ace', '1–::

  1c ½ Fig8 round 2c ; 1c+3c turn LH

9–::

  1c+3c L-Chain up/down (1,2,3)

17–::

  Mirror Reels3 on sides (2c start in and up)

25–::

  1c cast below 3c, lead to top, cross and cast (2c up) (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2435, '2012-01-22 19:29:38.586472+00', '2019-03-15 20:45:12.198876+00', 2944, 1, NULL, 'ace', '1–::

  1c+3c Petronella Turn | Set H.Schottische {4} | Petronella Turn to (1x,2,3x)

9–::

  All set | turn P BH ; Circle L {2} | all M turn W on the L BH (to 3,2x,1)

17–::

  2c+1c set | ½RHA ; 1c set | turn LH to face 1cnr

25–::

  1c diag Reel4 with 1cnrs, at end turn RH ¾ to finish (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (9301, '2016-09-18 19:07:33.122779+00', '2016-09-18 19:07:33.122779+00', 17265, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; ½ Fig8 R (2,1x,3)

9--::

  1c+cnrs to the R ½ diag. R&L ; S&Link3 into lines across (all face P)

17--::

  1c+cnrs to the L ½ diag. R&L ; S&Link3 (2,1,3)

25--::

  Circle6 and back

', 3);
INSERT INTO 'dancecrib' VALUES (12498, '2020-01-12 01:54:59.342828+00', '2020-01-12 02:03:57.262251+00', 7582, 1, NULL, 'ace', '1--::

  1c+3c chase cclw ½ round standing 2c to (3x,2,1x) ; 2c+1c chase cclw ½ (3x,1,2x)

9--::

  3c+1W & 1M+2c ½ Reels3 across, 1c Lsh to 1cnr ; ½ Reels3 on the sides, 1c Rsh to 2cnr (2,1x,3)

17--::

  1c turn 1cnr LH and dance Rsh round 4cnr to (2,1,3)

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3796, '2013-07-13 15:56:08.430166+00', '2014-11-12 01:17:56.763885+00', 14678, 1, NULL, 'ace', '1–::

  1c set | dance NHJ between 2c ; cast back to place | cross LH (1x,2)

9–::

  1W+2M set to each other | dance out NHJ on W side ; cast round P to M side | change places LH

17–::

  1c change place diagonally RH | chase, 1W leading, clockwise round 2W to finish 1W in own place and 1M in 2Mpl

25–::

  1W+2W set to each other | dance out NHJ between the Men ; cast round nearest M to W side | change places LH (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (3722, '2013-04-07 19:17:07.869675+00', '2014-04-30 23:23:54.116502+00', 7745, 1, NULL, 'ace', '{{title}}
Strathspey

1–::
  1c+3c cast down behind own side ; turn outwards and dance up to places, face down and in
9–::
  Mirror Reels4 on the sides, Lsh on W side
17–::
  1c+3c ½ Fig8 down ; All turn P RH (1x,2,3x,4)
25–::
  1c+2c & 3c+4C RHA ; wheels unwind (1M+4M leading) into clw chase, finishing in square set (4,2,1,3)

{{title}}
Reel

33–::
  All Circle8 and back
41–::
  All turn P RH 1½ and face P ; All dance ½ interlocking Reels4 as if an end person: pass P Rsh, pass Lsh, pass Rsh and face that person
49–::
  Turn that person 1½ RH ; All dance ½ interlocking Reels4 as if an end person: pass Rsh, pass Lsh, pass P Rsh and face cnr
57–::
  Turn cnr RH | P LH ; cnr RH | P LH (1,3,4,2)', 3);
INSERT INTO 'dancecrib' VALUES (2448, '2012-01-22 19:29:39.406145+00', '2014-04-30 23:23:54.146863+00', 3027, 1, NULL, 'ace', '1–::
  1c cast off (2c up), cross RH ; cast off | dance up to DTr position facing opposite sides,
9–::
  2c+1c+3c DTr, 1c finishes facing 2cnrs
17–::
  Reel4 with 2cnrs, at end pass Lsh and face 1cnrs
25–::
  Reel4 with 1cnrs to finish in 2pl (facing out to continue) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2830, '2012-01-22 19:29:59.177749+00', '2018-10-06 10:42:02.11033+00', 13197, 1, NULL, 'ace', '1–::

  1c lead down, cross below 3c, cast up to 1plx and turn LH ½ to face down NHJ, on [8] 2c step in to face 1c NHJ

9–::

  1c set to 2c | Circle4 L | 1c set advancing to 2c, passing person opposite Lsh (interleaving), to (2,1,3), 1c facing 3c all NHJ (3c step in on [16].

17–::

  1c+3c repeat [9-16], finish (2,3,1)

25–::

  Mirror reels3 on the sides, 3c dancing out and up. (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3693, '2013-01-29 23:49:17.010225+00', '2014-04-30 23:23:54.231282+00', 9930, 1, NULL, 'ace', '1–::
  1c+4c turn RH and cast to centre (2c+3c out) ; 1c+4c turn LH 1½ to finish BtoB between the end couples
9–::
  1c+2c & 3c+4c reels4 across, at end 1c+4c pass RH to help P, into line across facing line across
17–::
  All set | change place with opposite RH ; 1c+4c dance out casting in as 2c+3c set to P | All change place LH with P (3x,4,1,2x)
25–::
  All chase cclw half round ; 1c+4c ½ LHA | All set (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2196, '2012-01-22 19:29:25.196454+00', '2020-12-06 11:11:33.305784+00', 2039, 1, NULL, 'ace', '1–::

  2c petronella to midline | set ; All petronella | all set (2c now in 2plx)

9–::

  1c+3c Reel4 on midline, at end 3W+1M turn RH to face opp side (1W stays facing 3M on midline)

17–::

  3W+2c+1M set, 2c advancing on [18] | RHA, 2c to 2plx (1M+3W retain RHJ) | 1M+3W turn RH ½ to face own side _while{2}_ 2c set

25–::

  3W+2c+1M Reel4 across, at end 1M+3W finish BtoB facing P

33–::

  1c+3c set to P | turn RH ¾, 1c finish in centre facing up, 3c in 3plx, 2c step up ; 1c lead to top, and cast off to finish BtoB on midline, M above W

41–::

  2c+1M & 1W+3c Circle3 L, break (1c leading) into Circle6 L ½ | All set to P (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (11515, '2019-01-17 21:36:27.484345+00', '2021-04-08 14:43:57.609119+00', 6551, 1, 1645, 'ace', '1-::

  1c cross down | cast off _while{4}_ 2c cast up | cross RH _while{4}_ 3c &frac12; turn RH | lead up (2x,3x,1x) ; repeat from new places

9-::

  Repeat [1-8] from new places, but on [15-16] 3c cross up to face out opp side in DTr position (2,3x,1)

17-::

  Set as DTr | 3c &frac12; turn 1cnrs RH who face 4cnr pos ; &frac12; diag RSh Reel4 to crown triangle pos (1W up, 2M down)

25-::

  Set as crown triangles | 1W & 2M &frac12; turn 4cnrs RH who face 3cnr pos ; &frac12; diag RSh Reel4 to 1M & 2W facing 4cnr pos on sides (M 3,1,2; W 1,2,3)

33-::

  1M+2M & 2W+1W &frac12; turn LH | 2M+3M & 2W+3W &frac12; turn RH ; all turn P LH (2,3,1)

:: *Crib derived from the video*

', 1);
INSERT INTO 'dancecrib' VALUES (9303, '2016-09-19 00:20:39.080111+00', '2016-09-19 00:20:39.080111+00', 17385, 2, 1, 'ace', '1–::
  1c+2c, 3c+4c set to ptr | cross RH ; circle to L (fin 1c facing 2c, 3c facing 4c)
9–::
  1c+2c, 3c+4c set and “reverse link” to own sides ; circle to R (fin on sides)
17–::
  1c+2c, 3c+4c dance Helix [S adv to ptr passing LS to fin back-to-back ;
  cast to R round ptr back to own sides ; ½turn RH ;  ½ RH across] (to 2143)
25–::
  1c+4c dance Rose progression [1W+4M cross RH and cast to R _while_
  1M+4W set and ½ turn BH ; 1M+4W cast away from each other and
  dance across to 3M''s/2W''s places _while_ 1W+4M ½ turn BH and cast away
  from each other to 3W''s/2M''s places] (to 2413)', 3);
INSERT INTO 'dancecrib' VALUES (3677, '2013-01-08 13:43:25.665312+00', '2016-12-14 22:50:51.265069+00', 13577, 1, NULL, 'ace', '1–::

  1c set | dance between 3c (2c up) and cast up to finish side by side LHJ facing 1cnr

9–::

  Set to 1cnr and turn inwards and join RH | set to 3cnr ; turn 3cnr LH to face 2cnr RHJ

17–::

  Set to 2cnr and turn inwards and join LH | set to 4cnr ; turn 4cnr RH to (2,1,3)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (2447, '2012-01-22 19:29:39.349856+00', '2018-03-03 23:36:25.377688+00', 3021, 1, NULL, 'ace', '{{explanation}}

3c+4c start on opp. side



1–::

  2c+3c set and ''La Baratte'' and face out (2M+3W & 2W+3M in promhold)

9–::

  ½ Lsh Reel3 in sideline ; in promhold with P ½ Rsh Reel3 in sideline to meet in centre

17–::

  3c+2c RHA to face up/down RHJ ; lead out the end, cross and cast to (1,3,2x,4x)

25–::

  1c+3c and 2c+4c S&Link ; all ½ chase clw around (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (2624, '2012-01-22 19:29:50.487692+00', '2017-07-07 12:32:48.12689+00', 3637, 1, NULL, 'ace', '1–::

  1c set | cast off 2, meet below 3c ; dance to the top and cast off to face 1cnr (2c up)

9–::

  SetH&G , at end 1c set advancing to face 1cnr

17–::

  Turn CPCP, finish in the middle facing down NHJ on own side

25–::

  1c dance down | cast up round 3c ; dance up between 2c | cast off to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2305, '2012-01-22 19:29:30.775138+00', '2021-01-14 20:20:41.974422+00', 12427, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; ½ Fig8 L (M dn, W up), finish facing 1cnrs

9–::

  ½ Diag Reel4 with 1cnrs, pass Lsh ; ½ Diag Reel4 with 2cnrs, swivel R to face opp side BtoB for

17–::

  3c+1c+2c Double Triangles, finish (3x,1x,2x)

25–::

  All set | turn RH ; chase clw to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3373, '2012-01-22 19:30:22.542508+00', '2020-04-02 23:53:18.296488+00', 8166, 1, NULL, 'ace', '1–::

  1c A&R [bars 1-4] | 2c A&R [3-6] ; 3c A&R [5-8] | 4c A&R [7-10] (1,2,3,4)

9–::

  1c cross into Snowball G-Chain (3,2x,4,1x)

17–::

  3c+2c & 4c+1c La-Chain (3,2x,4,1x)

25–::

  3c cross RH [25-26] | 3c+2c ½RHA [27-28]  _while_ 4c turn RH [27-30] _and_ 1c turn 1½ RH [29-32] (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (10254, '2017-11-13 00:08:33.146442+00', '2017-11-13 00:08:33.146442+00', 18054, 2, 1, 'ace', '1–::
  1c starts Snowball Grand Chain by crossing over RH ; picks up 2c LH |
  1c picks up 3c RH _while_ 2c cross RH at top ; 1c crosses LH at bottom
  _while_ 2c and 3c change pl LH on sides [to 3,2x,1]
9–::
  All set ; 3c (at top) cross RH _while_ 2c (in 2nd pl) cast off
  _while_ 1c cross up LH [to 3x,1x,2x] | all set ; all ½ turn RH
  [fin facing up in Allemande hold]
17–::
  3-couple Allemande
25–:: Circle6{8} _or_ all set {2} ; Circle6 to L {3} | dance in towards center {1},
  pull RS back and cast out to pl {2}.', 3);
INSERT INTO 'dancecrib' VALUES (2457, '2012-01-22 19:29:39.908551+00', '2020-08-30 21:12:15.363192+00', 3042, 1, NULL, 'ace', '1–::

  1W followed by 2W Fig8 round 2M+1M (Lsh to 2M) and cross to exchanged places

9–::

  1M+2W & 2M+1W (leading) down the middle ; and up, 2W casts off and 1W speeds up to join P, finish RHJ facing up (1,2)

17–::

  1c+2c 6 bars of Allemande | all cross RH to (2x,1x)

25–::

  2c+1c circle4 L ; all set and cross (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (13200, '2020-09-18 01:38:24.679316+00', '2020-09-18 01:44:36.66874+00', 11759, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 R round 3cnrs and face 1cnrs

9--::

  ½ Reel4 on 1diag, 1c continue the reel to face 3cnrs[pos] ; 1c set pivoting R to face P | turn P BH 1¼ and face 2cnrs

17--::

  Repeat on 2diag to 2plx (3x,1x,2x)

25--::

  All chase clw ½ ; turn P BH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14322, '2021-09-17 22:53:16.549676+00', '2021-09-17 23:01:22.847076+00', 8850, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

  All clap on [1] as 1c & 4c cross RH | cast inwards (2c & 3c step out) ; 1c+4c set | ½ RHA (2,4x,1,3x)

9--::

  All clap on [9] as 1c & 4c cross and cast outwards (2c & 3c step in) (to 4,2,3x,1x) ; 4c+2c & 3c+1c set | ½ RHA. 2c & 1c face down, 4c & 3c face up (2x,4x,1,3)

17--::

  All set | Petronella turn into two lines4 across, all facing same sex person ; ½ Reels4 across

25--::

  All set | turn RH ¾ to sides (to 2,4,1x,3x) ; chase clw ½ (3,1,4x,2x)', 2);
INSERT INTO 'dancecrib' VALUES (12499, '2020-01-12 02:40:19.521759+00', '2020-01-12 02:40:19.521759+00', 5252, 1, NULL, 'ace', '1--::

  All M A&R ; All M dance Rsh round P, to places (1,2,3,4)

9--::

  All W chase cclw round the set, to places (1,2,3,4), 

17--::

  1M+2W & 2M+3W & 3M+4W turn RH ; 1W+2M & 2W+3M & 3W+4M turn LH (1,2,3,4)

25--::

  1c dance BtoB ; 1c change places with 2c RH, with 3c LH, with 4c RH (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (3571, '2012-01-22 19:30:31.66858+00', '2020-09-18 08:25:55.907418+00', 13472, 1, NULL, 'ace', '1–::

  1c+3c, W leading, dance ½ cclw inside set, and face out ; with M leading return to place clw outside side couples

9–::

  1c+3c RHA ; LHA

17-32::

  2c+4c repeat [1-16]

33–::

  1W & 3W dance Rsh round cnr ; NHJ with cnr A&R into the centre

41–::

  1W+3W+their cnrs dance R&L on the diagonal

49-64::

  2W+4W repeat [33-48] with their cnrs, finish in place facing P

65–::

  All M pass in front of P | behind next W ; in front of next W | behind cnr, to place

73–::

  All W repeat, finish to R of P ready for

81–::

  All promenade clw round the set, at end the M move ahead for

89–::

  Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (9302, '2016-09-18 22:54:33.738523+00', '2016-09-18 22:58:28.452452+00', 17384, 1, NULL, 'ace', '*Start (1,2,3x,4x)*



*Strathspey*



1--::

  1c+2c & 3c+4c The Knot, but on [7-8] 1c+4c ½ LHA (2,4x,1,3x)

9--::

  4c+1c set to P | turn P BH ½ ; Circle4 L, finish in middle facing cnrs (2,4,1x,3x)



*Reel*



17--::

  4c+1c set Double H&G, finish in promhold, 1c facing up and 4c down

25--::

  2c+1c & 4c+3c ½ Reels3 across, Rsh to the W, at end switch P ; (1W+4M in promhold with 2c) & (1M+4W in promhold with 3c) ½ Reels3 across, Lsh to the W (to 2,4,1x,3x) 

', 3);
INSERT INTO 'dancecrib' VALUES (8903, '2015-09-14 21:57:12.206297+00', '2015-09-14 21:57:12.206297+00', 16735, 2, NULL, 'ace', '1 - 8::  1C set and cast off 1 pl. (2C step up), then 2C + 1C + 3C adv & ret while 1C changes sides RH (as in Trip to Bavaria)

9 -16::  1C set and cast (L up, M down) to between 2C and 3C, then all adv & ret up and down while 1C changes sides.

17-24::  Reels of three in the sidelines, 1C passing partner’s 2nd corner with LSh to start.1C finish in the middle facing each other up and down.

25-28::  1C joining RH set twice and on bars 27, 28 1L, pulling back RSh, turns under her partner’s arm.

29-32::  1C cross RH and cast (M up, L down) to 2nd pl. on own side.', 3);
INSERT INTO 'dancecrib' VALUES (2455, '2012-01-22 19:29:39.794143+00', '2015-09-18 00:47:48.013017+00', 3038, 1, NULL, 'ace', '1–::

  1c followed by 2c cast off behind own lines ; 2c (leading)+1c cast up to top, casting off (to 1,2)

9–::

  1c cross down | dance round 3c ; lead up the middle | cross at the top and cast to 2pl (2c up) (2,1,3)

17–::

  1c+3c circle4 L ; 2c+1c circle4 L (again) 

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (9304, '2016-09-19 00:37:18.112335+00', '2016-09-19 18:45:10.487812+00', 16894, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 2c+1c ½ M-Chain

9--::

  1c+2c+3c ½ Reels3 on the sides, 1c+2c start Rsh to P ; 1c facing 2c set | Circle4 L ½ (3, 2c facing 1c, 4)

17--::

  2c (W leading)+3c & 1c (W leading)+4c tandem (no lead change) Reels3 across, finish 1c on W side facing 2c on M side, both in promhold

25--::

  Tournee: to enter 1c+2c dance in and M meet Lsh to Lsh (3,2,1,4)

33--::

  3c+1c dance in and cast 1 place (2c & 4c up) ; All turn BH (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9461, '2016-11-04 23:29:55.140287+00', '2016-12-12 20:51:39.98975+00', 16041, 2, NULL, 'ace', '1-8::

  All set to partner & Petronella turn (Ladies back to centre), all set & change RH

9-12::

  Men LH across in centre

13-28::

  Double celtic reels:

::

  13-14  Pass partner RSh

::

  15-16  Ladies ¾ LH across while Men dance one place clockwise

::

  17-18  Pass partner RSh

::

  19-20   Men ¾ LH across while Ladies dance one place clockwise

::

  21-28   Repeat 13-20 finishing with Men in centre facing partner

29-32::

   Men dance out through their position & behind their corner to position beside (their new partner) – Men move round clockwise, Ladies stay in place

33-40::

   All circle 8H round & back



 



', 3);
INSERT INTO 'dancecrib' VALUES (12446, '2019-12-22 23:17:07.375361+00', '2019-12-22 23:21:56.812204+00', 11364, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 R round 3cnrs to 2pl (2,1,3,4)

9--::

  Reels3 on sides, 1c RSh to 4cnrs. 2c & 3c loop to places (2,1,3,4)

17--::

  1c & 4c turn P RH ¾ into middline | 1c+4c ½ Reel4 | 4c & 1c turn P RH ¾ to sides (2,4,3,1)

25--::

  2c & 3c repeat [17-24] (3,4,2,1)', 2);
INSERT INTO 'dancecrib' VALUES (13663, '2021-02-13 10:27:58.240652+00', '2021-02-13 10:33:10.341732+00', 15886, 1, 202, 'ace', '1--::

  1c+2c set | 1c turn 2c on sides EH ½ into DTr position ; all set | 1c turn 3c on sides EH ½ (2,3,1)

9--::

  Mirror Reels3 on sides, 1c in and up, 3c out and down, taking hands when possible (2,3,1)

17--::

  1c cross up to 2plx (no hands) _while{2}_ 3c dance to 3pl (to 2,1x,3) | 1c dance out and up ; meet and cross down to 2pl | all set (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2456, '2012-01-22 19:29:39.843252+00', '2020-12-23 11:06:04.901393+00', 10295, 1, NULL, 'ace', '1–::

  4c set | cross LH (3c down) to face 3c in line across ; ½ Reel4 across, 3c ends in 4plx _while_ 4c turn ½ LH into the middle own side facing up NHJ

9–::

  4c dance up two places and turn 2c EH (to 1,2,4,3x) ; 2c+4c ½ R&L (1,4x,2x,3x)

17–::

  1c+4c+2c Mirror Reels3 on the sides, 4c start in and up, and cross down to own side on bar 20 (1,4,2x,3x)

25–::

  1c+4c set | ½ RHA ; all set | cross RH (4,1,2,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14170, '2021-07-28 07:23:59.505772+00', '2021-07-28 08:16:02.646418+00', 2649, 1, 202, 'ace', '1--::

  1c set | cross RH to 2plx (2c up) ; dance RSh round 1cnrs through ends to midline | turn RH ¾. 1M faces down, 1W faces up

9--::

  Reels3 across, 1c RSh to 4cnrs | 1c turn P LH 1¼ and face 2cnrs (cnrs dance 8-bar Reels3)

17--::

  ½ Reel4 on 1diag, pass P RSh to face 3cnrs ; ½ Reel4 on 2diag, pass P LSh to 2pl (3x,1,2x)

25--::

  1c set | cross RH _while{4}_ 3c & 2c A&R {1+1} diagonally | set (to 3x,1x,2x) ; all chase clw ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2473, '2012-01-22 19:29:40.863092+00', '2016-09-01 23:58:20.192544+00', 3104, 1, NULL, 'ace', '1--::

  1c+3c DblFig8 round 2c (to start, 1c cross down, 3c casts up) (1,2,3)

9--::

  1c turn RH, cast (2c up) ; 1c 1¼ turn LH, finishing 1W(1M) between 2c(3c)

17--::

  All in lines across A&R (1+1) | repeat ; All turn dancer opposite BH, finishing 3c in 3pl and 1c+2c ready for 

25--::

  1c+2c Allemande (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2464, '2012-01-22 19:29:40.4013+00', '2014-04-30 23:23:54.802245+00', 13461, 1, NULL, 'ace', '1–::
  1c dance down NHJ | turn TR ; dance up and cast off (2c up) (2,1,3)
9–::
  All Circle6 and back, 1c finish facing 1cnr
17–::
  1c SetH&G , finish facing 2cnr
25–::
  Opposing Rsh Reels3{6} on the sides | 1c cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2465, '2012-01-22 19:29:40.456586+00', '2014-04-30 23:23:54.847146+00', 3083, 1, NULL, 'ace', '1–::
  1c+2c set | 1c cast off _while_ 2c dance up and face out ; 2c+1c half DblFig8 (2x,1x,3)
9–::
  1c+3c repeat (2x,3x,1)
17–::
  1c lead up to top crossing to opposite side (2c+3c down) ; set, cast off one (2c up) (2x,1x,3x)
25–::
  All set | cross RH ; All Turn RH', 3);
INSERT INTO 'dancecrib' VALUES (12443, '2019-12-22 01:28:48.563174+00', '2019-12-22 01:36:27.273086+00', 11588, 1, NULL, 'ace', '1--::

  Parallel Reels3 on the sides, 1c Rsh to 2c (1,2,3)

9--::

  1M+2W turn RH to places ; 1W+2M turn LH 1¼ into diag. line and face P

17--::

  Pass P Rsh | "outers" (1W+2M) cast 1 place clw in square _while{2}_ "inners" dance Lsh round each other, to form a line on 2diag, all facing P ; Pass P Rsh | new "outers" and "inners" repeat [19-20], finishing (2x,1x,3)

25--::

  1c+3c set | ½ RHA and face down RHJ ; 1c cross and cast up as 3c lead down and cast up, finish (2x,1x,3x)  



*The set is now inverted, and 3c is the dancing couple from the former bottom.*  

*Repeat, each couple leads once from each end.*

', 3);
INSERT INTO 'dancecrib' VALUES (10255, '2017-11-13 01:06:48.325186+00', '2017-11-13 01:06:48.325186+00', 18055, 2, 1, 'ace', '1–::
  1c long cast to 2nd pl (2c step up) |  1c dance down between 3c and cast up
9–12::
  1c passing LS dance across to opp side ; 1M+2L, 1L+3M turn LH to fin
  1M between 2c, 1L between 3c
13–16::
  1c passing LS cross up/down ; 1L+2M, 1M+3L turn LH to fin (2, 1x, 3).
17–::
  1c+2L+3M dance half diag R/L (1c polite turn at end)
  | 1c+2M+3L dance half diag R/L
25–::
  All petronella to centre ; set to ptrs | turn BH to own sides ; set to ptrs', 3);
INSERT INTO 'dancecrib' VALUES (3800, '2013-07-13 15:56:08.932011+00', '2014-04-30 23:23:55.035972+00', 14650, 1, NULL, 'ace', '1–::
  Mirror Reels3 on opp. side (1c cross down) (1x,2,3)
9–::
  1c+2c set to P | Turn P RH ½ ; the M, with P following, dance R crossing the set again and chase on clw to (2x,1,3)
17–::
  1c+3c ½ Dbl Fig8, 1c crossing down ; All turn P RH 1½ (2,1,3)
25–::
  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (8097, '2013-10-18 18:41:56.363465+00', '2014-04-30 23:23:55.071857+00', 14465, 1, NULL, 'ace', '1–::
  1c pass Rsh and 1W pivots R to follow P | 1c cast (2c up) to 2pl W above M facing M side ; 2c+1W RHA & 1M+3c LHA. 1c finish in promhold facing M side
9–::
  Diag. Reel3 with 1cnrs, start Rsh to 2M, finish as before
17–::
  Diag. Reel3 with 2cnrs, start Lsh to 3M, finish dancing down
25–::
  1c dance between 3c, cross and cast up to 2pl ; All turn P RH', 3);
INSERT INTO 'dancecrib' VALUES (15175, '2022-10-17 23:11:59.211241+00', '2022-10-17 23:18:20.393406+00', 20824, 1, 1645, 'ace', '1--::

  1c set | dance down between 2c ; cast behind 3c | dance up to end BtoB facing own side (2c up)

9--::

  2c+1c+3c Crown Triangles, 1c end BtoB on centre line, W facing up, M down

17--::

  1W+2c & 1M+3c Reels3 across, 1c start LSh to 1cnrs & end on own sides (2,1,3)

25--::

  1c turn 1&frac14; RH ; 2c+1M & 1W+3c LHA (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (9306, '2016-09-19 12:41:36.249823+00', '2016-09-19 12:41:36.249823+00', 13872, 1, NULL, 'ace', '1--::

  All set | cross RH ; set | cross RH

9--::

  1c turn RH | cast off (2c up) ; ½ Fig8 R (2,1x,3)

17--::

  ½ Reels3 on the sides, Rsh to 2cnr ; ½ Reels3 across, Lsh to 3cnr (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (9305, '2016-09-19 10:34:21.783989+00', '2016-09-19 11:06:26.518686+00', 2179, 1, NULL, 'ace', '1--::

  1c+2c RHA ; LHA

9--::

  Circle4 and back

17--::

  1W+2W turn RH ; 1M+2M turn LH

25--::

  All dance BtoB with opposite ; with NHJ slip L 3 steps/close to advance and pass | slip R to face next cpl.

', 3);
INSERT INTO 'dancecrib' VALUES (9307, '2016-09-19 19:57:22.513517+00', '2016-09-19 19:59:01.360869+00', 13870, 1, NULL, 'ace', '1--::

  1c+4c NHJ dance in and pass, 4c making arch, dance out other end and cast to middle (2c+3c step to end) | All set to P (2,4,1,3)

9--::

  2c+4c & 1c+3c R&L 

17--::

  Reels4 on the sides

25--::

  Circle8 and back (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9308, '2016-09-19 20:14:55.028146+00', '2016-09-19 20:14:55.028146+00', 13871, 1, NULL, 'ace', '1--::

  1c+3c (casting) DblFig8 round 2c (1,2,3)

9--::

  1c+2W & 2M+3c RHA ; 1c+2M & 1W+3c LHA (“Teapots R and L”)

17--::

  1c facing 2c set | 1c cross down as 2c dance up ; 1c+3c repeat (2,3,1)

25--::

  Circle6 and back (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8210, '2014-03-14 08:19:22.059921+00', '2016-01-01 22:56:07.708652+00', 13134, 1, NULL, 'ace', '1–::

  1c+4c set | cross RH ; cast to middle (2c+3c to end) | turn P LH ½ into middle for

9–::

  1c+4c Poussette (2,4,1,3)

17–::

  All set advancing slightly | turn P RH, flow into ; 2c+4c & 1c+3c RHA, finish on sides, middles facing ends for

25–::

  Parallel Reels4 on the sides (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3803, '2013-07-13 15:56:09.121823+00', '2014-04-30 23:23:55.339853+00', 14654, 1, NULL, 'ace', '1–::
  1c+2c Poussette
9–::
  1c+2c S&Link ; 2c+1c Circle4 L (2,1,3)
17–::
  1c set to P and cnr (1c set to P and face 4cnr, set to 4cnr and face P up/dn) ; set to P (no adv.) | turn BH to face 1cnr
25–::
  Corners Pass and Turn. (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3603, '2012-07-21 11:45:40.594597+00', '2020-12-07 21:40:59.429138+00', 3111, 1, NULL, 'ace', '1–::

  1c turn RH 1½ ; 1M+2W turn LH 1¼ _while{4}_ 1W+2M turn RH 1¼

9–::

  In line across dance down the middle and turn R about ; and up to own places, 1M putting 1W across on [16]

17–::

  1c+2c RHA ; LHA

25–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (2463, '2012-01-22 19:29:40.356068+00', '2020-12-18 20:31:26.435592+00', 7285, 1, NULL, 'ace', '1–::

  1c+2c turn RH 1½ ; 1c+2c RHA _while{4}_ 3c+4c turn RH 1½

9–::

  1c+2c ½ R&L _while{4}_ 3c+4c RHA ; 1c+3c ½ R&L (2,3,1x,4x)

17–::

  3c+1c L-Chain

25–::

  1c+4c lead up {3}, change sides (M loop above _while_ W under M''s arm) ; lead down | 4c casts up _while_ 1c dances straight into 4pl (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2349, '2012-01-22 19:29:32.663652+00', '2020-12-24 17:59:09.693076+00', 10695, 1, NULL, 'ace', '1–::

  1c lead down the middle {3} and up {3} | cast off (2c up) (2,1)

9–::

  1c ½ Fig8 round 2c ; 1M+2M turn LH and face out (2,1x)

17–::

  L-Chain, at end 1c face W side

25–::

  1W casts once round 2M and crosses to W side _while{6}_ 1M casts up, crosses, casts off  | 2c+1c set (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (14024, '2021-05-13 07:03:56.621359+00', '2021-05-13 07:34:19.049376+00', 59, 1, 202, 'ace', '1--::

  1c lead down ; and up (1,2)

9--::

  1c set | cross RH ; set | cross down LH (2c up) (1,2)

17--::

  1c Fig8 up round 2c (2,1)

25--::

  R&L (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2474, '2012-01-22 19:29:40.904699+00', '2021-05-26 09:26:54.296546+00', 3105, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; cross down between 3c and cast up to 2plx

9–::

  2c+1c R&L, 1c finish facing 1cnr

17–::

  1c set to and turn corners, finish between cnrs

25–::

  Reels3{6} on the sides (Lsh to 1cnrs) | 1c cross (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13664, '2021-02-13 10:37:38.426681+00', '2021-02-13 10:41:24.825733+00', 17959, 1, 202, 'ace', '1--::

  1c+2c 6 bars of R&L | 1c turn 2c on sides LH (2,1,3)

9--::

  Mirror Reels3, 1c RSh to 3c (2,1,3)

17--::

  All A&R ; Circle6 L ½ (2,1,3)

25--::

  All A&R ; Circle6 R ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2466, '2012-01-22 19:29:40.515006+00', '2021-05-26 09:47:50.848574+00', 3084, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1c lead to 3pl (2c+3c up on [11-12] ; 3c+1c Circle4 L (2,3,1)

17–::

  1c set | cast up to face 1cnr (3c down) ; 1c set to 1cnr | to 2cnr

25–::

  Rsh Reels3{6} on the sides | 1c cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12765, '2020-04-15 18:53:41.431722+00', '2021-04-07 15:51:06.781237+00', 19938, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; ½ Reels3 across, 1c LSh to 1cnrs (2x,1x,3x)

9--::

  3C Set&Rotate (3x,1x,2x)

17--::

  3c set | cast off to 3plx _while{4}_ 2c dance up NHJ and cast to 1plx (to 2x,1x,3x) ; all turn P RH ½, face P and cast R to exchanged places (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3802, '2013-07-13 15:56:09.002632+00', '2019-04-20 10:49:06.390934+00', 10797, 1, NULL, 'ace', '1–::

  1c with 2c following dance down the middle {3} and (2c split) up {3} | 2c to 1pl as 1c cast off to 2pl and 3c step in, for

9–::

  1c+3c+4c Poussette (2,3,4,1)

17–::

  2c & 1c dance in and meet (3c+4c step to end) | ½ LHA (3,1x,2x,4) ; 1c & 2c cast out round the end and crosses to (3,1,2,4)

25–::

  All PdB/Coupé ; 1c+2c »Link«  _while_{2}   3c+4c set turning to face up/down | 3c+2c & 1c+4c change place LH (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2478, '2012-01-22 19:29:41.842+00', '2014-04-30 23:23:55.162381+00', 3137, 1, NULL, 'ace', '1–::
  1c A&R{1+1} | cross RH ; cast off 1 (2c up)  | 2c+1c+3c A&R{1+1} (2,1x,3)
9–::
  All circle6 left {6} | still in circle advance to centre {1}& retire to places {1} (2,1x,3)
17–::
  G-Chain (2c cross), one bar per step ; finish in circle | A&R{1+1} as before
25–::
  1M+2c & 1W+3c Reels3{6} across (Lsh to 2cnr, i.e. round the outside | 1c meet and turn ¾RH to 2pl', 2);
INSERT INTO 'dancecrib' VALUES (3875, '2013-08-09 06:55:05.220878+00', '2014-05-03 20:18:30.757861+00', 14685, 1, NULL, 'ace', '{{explanation}}

3c+4c cross on second chord (1,2,3x,4x)



1–::

  1c+4c cross RH, cast (2c+3c step to end) ; ½ Fig8 round end cpl (2,1,4x,3x)

9–::

  Modified Half Grand Chain: 2c & 3c turn P RH 1½ _while_ on sideline 1c+4c turn RH 1½ {3}, all turn next dancer LH ½ {1} (4x,2x,3,1) ; repeat (3,4,1x,2x)

17–::

  Reels4 on the sidelines (3,4,1x,2x)

25–::

  3c+2c chase ½ clw _while_{4} 4c+1c LHA ; 2c+4c & 1c+3c RHA (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (9309, '2016-09-19 20:36:18.296671+00', '2016-09-19 20:36:18.296671+00', 13873, 1, NULL, 'ace', '*Cpl face Cpl RR*

1--::

  Circle4 and back

9--::

  La-Chain

17--::

  R&L

25--::

  Set twice to other cpl ; pass opposite Rsh, dance on 3 steps and retire 1

', 3);
INSERT INTO 'dancecrib' VALUES (10389, '2018-01-19 01:35:28.273175+00', '2021-02-13 10:41:24.823552+00', 17959, 2, 963, 'ace', '

1-6::

  1c+2c ¾ R&Ls  

7-8::

  2M+1M, 2W+1W turn LH  

9-16::

  2c+1c+3c R3, 1c Rsh to 3c  

17-24::

  2c+1c+3c adv/ret; circle ½ left    

25-32::

  2c+1c+3c adv/ret; circle ½ right

', 5);
INSERT INTO 'dancecrib' VALUES (2366, '2012-01-22 19:29:33.639808+00', '2017-10-12 15:38:00.801004+00', 2635, 1, NULL, 'ace', '1–::

  1c+2c+3c Circle6 and back

9–::

  1c+2c+3c G-Chain (1c cross to start)

17–::

  2c+3c+4c inverted G-Chain (4c cross to start)

25–::

  1c lead down the middle and up, on [32] all finish on the midline for

33–::

  1c Allemande to 4pl _while{8}_ 2c+3c+4c Poussette, all dancing as 2nd cpl. (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2481, '2012-01-22 19:29:41.986103+00', '2020-09-11 20:19:25.41297+00', 3154, 1, NULL, 'ace', '1–::

  1c+2c+3c Rsh Reels3 on the sides

9–::

  1c cast off (2c up), dance between 3c, cast up and cross to face 1cnrs

17–::

  1c set to 1cnr | to 2cnr, finish in 2plx ; turn RH 1½  (2,1,3)

25–::

  2c+1c R&L.', 3);
INSERT INTO 'dancecrib' VALUES (2253, '2012-01-22 19:29:28.000319+00', '2020-12-06 11:15:33.890288+00', 2244, 1, NULL, 'ace', '1–::

  2c (= dancing Cpl) ½Reel4 with 1cnrs ; 2c pass Rsh into (2M+ two W above) & (2W+ two M below) RHA, 2c pass Lsh into

9–::

  2c ½Reel4 with 2cnrs ; 2c pass Rsh into Teapots on the sides (2M+ two W & 2W+ two M RHA), 2c curve into 2pl own sides. (3x,2,1x)

17-28::

  R&L for 3 couples (3x,2,1x)

29-32::

  2c turn RH and cast to 3pl, _while{4}_ 3c set and cross, _while{4}_ 1c set and cross up to 2pl (3,1,2).', 3);
INSERT INTO 'dancecrib' VALUES (2502, '2012-01-22 19:29:45.344871+00', '2023-01-10 19:57:24.01567+00', 3235, 1, NULL, 'ace', '1–::

  1M+2W turn RH 1½ to exchanged places ; 1W+2M repeat (2x,1x)

9–::

  Repeat [1-8] to own places

17–::

  1c down the middle (2c up) ; 1c up the middle, turn LH to 2pl

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (2521, '2012-01-22 19:29:46.097727+00', '2020-12-07 21:48:25.512296+00', 3299, 1, NULL, 'ace', '{{explanation}}

On 2nd chord 2c+4c change sides (1,2x,3,4x)



1–::

  1W+2W & 3W+4W set to the other | change places RH ; Men repeat (2,1x,4,3x)

9–::

  2c+1c & 4c+3c RHA ; 1c+4c LHA, _while{4}_ 2c+3c chase clw ½ round the set, at end all W face out (3,1x,4,2x)

17–::

  3c+1c & 4c+2c M-Chain

25–::

  Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (3791, '2013-07-13 15:56:07.342558+00', '2020-12-26 10:31:37.753667+00', 14549, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; 1c turn LH | cast up (2c down)

9–::

  1c+2c RHA ; 1c NHJ dance to bottom and turn inwards (2c+3c+4c up), 2c+4c face down and 3c+1c face up (2,3,4,1)

17-32::

  Up and down the mountain ‑ a series of changing places: 2c+4c make arches and 3c+1c dance under | 1c makes arch _while{2}_ 3c+2c turn inwards to face down/up (3,1,4,2) ; repeat three times to (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (14399, '2021-10-26 07:25:02.407353+00', '2021-10-26 07:25:33.155854+00', 726, 1, 202, 'ace', '1-::

  1c+2c ½ R&L ; set | cross RH (2,1,3)

9--::

 Mirror ½ Reels3 on sides, 1c out and down (to 3,1,2) ; 3c+1c Circle4L _while{4}_ 2c set | cross RH (3,1,2x)

17--::

  Mirror ½ Reels3 on sides, 1c in and down, 3c casting off (to 2x,1,3) ; 1c+3c Circle4L _while{4}_ 2c set | cross RH (2,1,3)

25--::

  1c Petronella turn into facing lines3 across | all set ; 1c turn RH _while{2}_ 2c & 3c change places RH on sides | 1c dance RSh round 4cnrs[pos] (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (7826, '2013-08-21 08:31:49.196568+00', '2023-02-04 01:23:04.125967+00', 6915, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All set to person opposite, change places passing RSh (Lady making
    waltz turn to right, Men moving straight forward), set to partners &
    change places as before
9-16::
    Repeat above Fig back to original places
17-32::
    All join hands & balance forward & backward, Men pass Lady on left
    over to the right (2H). Repeat 3 times, finishing in ballroom hold
    with partner
33-40::
    Couples waltz around each other (Men pass by left), moving
    anticlockwise, to meet next couple
::
    Variation bars 33-40:  Couples Poussette passing to meet next couple', 0);
INSERT INTO 'dancecrib' VALUES (7827, '2013-08-21 08:31:49.204439+00', '2023-02-04 01:23:04.136863+00', 6916, 3, NULL, 'ace', '1-8::
    All circle 6H round & back
9-16::
    1s dance Fig of 8 on own sides (between 2s to start)
17-24::
    1s slip step down & back, cast to 3rd place
25-32::
    3s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (2483, '2012-01-22 19:29:43.040053+00', '2021-05-26 09:11:32.279902+00', 3152, 1, NULL, 'ace', '1–::

  All C set twice ; cross Rsh, M making arches

9–::

  Repeat back to places, M making arches

17–::

  1c lead down the middle and up to top, finishing in the middle facing 2c who step in

25–::

  1c set twice to 2c ; turn person opposite BH 1½ (may also be done RH with skip-change) (2,1,3).



{{explanation}}

Could be done as a 2c dance in a longways set for as many as will', 2);
INSERT INTO 'dancecrib' VALUES (14025, '2021-05-13 07:24:26.255016+00', '2021-05-13 07:33:53.423596+00', 5962, 1, 202, 'ace', '1--::

  1c Parallel Fig8 on sides, RSh to 2c (1,2)

9--::

  1c set | cross RH ; cast off (2c up) | cross RH (2,1)

17--::

  RHA ; LHA (2,1)

25--::

  R&L (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2480, '2012-01-22 19:29:41.942348+00', '2021-05-26 09:14:19.961489+00', 3145, 1, NULL, 'ace', '1–::

  1c down the middle and up

9–::

  1c+2c Allemande, 1c ends in middle facing 1cnr

17–::

  Turn CPCP (2,1,3)

25–::

  All advance {1}, retire {1}, advance {1}, retire {1} ; all C turn BH.', 2);
INSERT INTO 'dancecrib' VALUES (2485, '2012-01-22 19:29:43.939517+00', '2014-04-30 23:23:55.370138+00', 3165, 1, NULL, 'ace', '1–::
  1c cross RH | cast off (2c up) ; ½Fig8 round 3cnr, pass Lsh to face 1cnr
9–::
  ½Reel4 with 1cnrs, pass Lsh ; Teapots R (1M+2W+3W (at top) & 1W+2M+3M RHA) finish facing 2cnrs
17–::
  ½Reel4 with 2cnrs, pass Lsh ; Teapots R on own sides (1M+2W+3W & 1W+2M+3M RHA)
25–::
  1c turn LH ½ (1M faces up, 1W down) _while_{2}   all cnrs change places RH on sides (polite turn) | 1c dances out the end and L to 2pl _while_{4}   2c+3c set to P and cross RH | All set (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (2486, '2012-01-22 19:29:43.986986+00', '2014-04-30 23:23:55.385084+00', 9087, 1, NULL, 'ace', '1–::
  1c+2c set, 1W+2W cross, passing P Rsh ; 1W (leading) + 2W chase clw to exchanged places
9–::
  1c+2c RHA ; LHA
17–::
  1c+2c set, 1M+2M cross, passing W opposite Rsh ; 2M (leading) +1M chase clw to (2,1)
25–::
  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (9310, '2016-09-19 23:40:56.158257+00', '2016-09-19 23:40:56.158257+00', 17386, 1, NULL, 'ace', '1--::

  Reels3 on the sides, 1c Rsh to 2c (1,2,3)

9--::

  All set | 1c cast as 2c leads up as 3c set ; All turn P RH into Allemande hold 

17--::

  2c+1c+3c Allemande (3,1,2)

25--::

  1c+2c turn RH ½ | ½ RHA ; 3c+2c repeat (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10142, '2017-09-22 21:55:26.002938+00', '2018-02-19 00:43:39.894717+00', 2643, 2, 160, 'ace', '1-8::

  1M 2W set, change places RH; 1W 2M set, change places RH.

9-16::

  2s+1s join NH, set on sides, turn BH 1_1/2 to own sides [4], set on the sides.

17-24::

  2s+1s Rights&Lefts.', 3);
INSERT INTO 'dancecrib' VALUES (9311, '2016-09-20 11:53:38.179776+00', '2016-09-20 11:53:38.179776+00', 15186, 2, NULL, 'ace', '1-:: 1c+4c chase clw while 2c+3c RHA ; LHA

9-:: 1c followed by 2c+3c+4c cast off behind own sides, 1c in 4pl make arch ; the others dance up under it, all retire (to 2,3,4,1)

17-:: All circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (2489, '2012-01-22 19:29:44.61943+00', '2014-07-11 16:52:42.326444+00', 3176, 1, NULL, 'ace', '1–::

  All dance ½ G-Chain (1c+4c cross, 2 steps per hand) (4x,3x,2x,1x)

9–::

  1c followed by 2c,3c,4c lead up, 1c+3c crossing back to own sides ; 1c cast (2c up) and cross to finish BtoB between 3c, (M facing W). Choose timing freely, e.g. 1c cross [11‑12] and [15-16], 3c cross [13‑14] |.

17–::

  1c+3c set, 1c set swiveling ¾ L to finish 1M facing dn and 1W up ; 2c+1W & 1M+4c ½ circle3 RIGHT into facing lines across | set in lines

25–::

  2c+1W & 1M+4c ½ Rsh Reels3 ; 1c pass Rsh into ½ Lsh Reel4 across with 3c, passing Rsh into

33–::

  2c+1M & 1W+4c ½ Rsh Reels3 ; 1c pass Lsh into ½ Rsh Reel4 with 3c, at end 1c pass Rsh to finish BtoB facing 3c (M facing W) (3c on own side)

41–::

  1c+3c set, 1c turning to face up NHJ | 1c+2c set, 1c turning inwards (change hands) to face down ; 1c+4c set | 1c cross down to 4pl (2c,3c,4c up). (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (9147, '2016-05-24 08:13:41.499435+00', '2016-05-24 08:13:41.499435+00', 16954, 2, 1, 'ace', '{{title}}
Strathspey
1–4::
  1c long cast to face 1st corners (2c up on 3–4)
5–16::
  Dance to corners and set (to face 3rd corner pos)
17–24::
  1st corners pass & twirl (1c pass RS) ; 2nd corners pass & twirl
  (1c pass RS to face 1st corner pos)
25–32::
  1c set to 1st corners | dance round RS to face 2nd corners ;
  1c set to 2nd corners | dance round RS to (2, 1, 3)

{{title}}
Reel
1–32::
  R bars 1–32 of Strathspey.

Each couple dance their first turn in Strathspey time and their second turn in Reel time.', 3);
INSERT INTO 'dancecrib' VALUES (3804, '2013-07-13 15:56:09.135343+00', '2017-07-07 09:14:09.865009+00', 12428, 1, NULL, 'ace', '1–::

  All set and cross RH ; chase ½ clw (3,2,1)

9–::

  Repeat (1,2,3)

17–::

  1c down the middle and up

25–::

  1c set | cross RH ; cast off (2c up) | cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2386, '2012-01-22 19:29:34.893404+00', '2017-02-13 14:47:28.869076+00', 2711, 1, NULL, 'ace', '{{explanation}}

The title means: »Happiness is SCD«



1–::

  1c turn RH ending BtoB in 2pos, 1W facing up and 1M down (2c up) | all set up/dn in DTr ; 1c turn 4cnr RH, and pass Rsh to face 1cnr

9–::

  SetH&G , at end set advancing to P

17–::

  1c turn RH once ending BtoB, 1M facing up and 1W down | All Set up&dn in DTr ; 1c turn 2cnr RH and pass Rsh to 2pl (2,1,3)

25–::

  All Circle6 and Back', 2);
INSERT INTO 'dancecrib' VALUES (2503, '2012-01-22 19:29:45.38377+00', '2017-03-14 08:35:00.292626+00', 3236, 1, NULL, 'ace', '1–::

  All set, ½ R&L (1 bar per hand) ; repeat

9–::

  1c lead down the middle and up (1,2)

17–::

  1c+2c Allemande', 3);
INSERT INTO 'dancecrib' VALUES (10553, '2018-03-26 09:11:07.82721+00', '2018-03-26 09:27:22.29853+00', 12347, 1, 202, 'ace', '*Strathspey*

1--::

  1c set | cast (2c up) ; turn LH, 1M with 1W behind ends facing 1cnr,

9--::

  Corners pass and turn in tandem with lead change, 1W with 1M behind ends facing 4cnr ; repeat [9-12] to 2pl, 1M & 2W facing out (2,1,3)

17--::

  2c+1c RHA ; 1c+3c LHA

25--::

  1c ½ Fig8 R, Lsh to 1cnrs ; turn P LH (2,1x,3)

33--::

  1M+2c & 1W+3c RHA ; 1M+3c & 1W+2c LHA

41--::

  1c ½ Fig R, Lsh to 3cnrs ; all turn P RH (2,1,3)



*Repeat in Reel Time*', 2);
INSERT INTO 'dancecrib' VALUES (2492, '2012-01-22 19:29:44.809117+00', '2019-01-09 23:11:07.439253+00', 10794, 1, NULL, 'ace', '{{explanation}}

On 2nd chord, 3c+4c change sides (to 1,2,3x,4x)



1–::

  1c+4c cross RH | cast to middle (2c+3c step to ends) ; 1c+4c ½ Fig8 round nearest end couple (2,1,4x,3x)

9–::

  1c+4c R&L, finish facing end couple (no polite turns) (2,1,4x,3x)

17–::

  Parallel Rsh reels4 on the sides, but 1c+4c finish in line across, 1M+4M in the middle RHJ, the W outside

25–::

  1M+4M turn RH ¾ _while{4}_ 1W+4W chase ¼ cclw inside the set | 1M+4W & 4M+1W turn LH ½ ; 1W+4W turn RH ¾ _while{4}_ 1M+4M chase ¼ cclw | 1M+4W & 4M+1W turn LH ¾ (to 2,4,1x,3x)', 4);
INSERT INTO 'dancecrib' VALUES (11221, '2018-09-30 22:20:42.796019+00', '2023-02-04 01:23:04.283212+00', 18574, 3, NULL, 'ace', '1-8::
    1L crosses down to dance a reel of 3 on opposite side (LSh to 3M)
    _while_ 1M crosses over & dances down behind 2L into RH across with
    2L+3L
9-16::
    1L crosses down to dance a reel of 3 on own side (RSh to 3L) _while_
    1M dances behind 3L & crosses over to dance up behind 3M then dances
    RH across with 2M+3M & 1s end in original places
17-24::
    1s lead down middle & up to 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (10390, '2018-01-19 01:44:10.802534+00', '2021-02-13 12:36:55.803552+00', 17960, 2, 963, 'ace', '1-8::

  1c passing Rsh, cross to opp side, face out|1-1/2 turn 2c (1M RH, 1W LH)|1c passing Rsh, cross to own side  

9-12::

  1c 1-1/2 turn 3c (1M LH, 1W RH)  

13-16::

  3c+1c set + mirror link (1c cast up)  

17-24::

  2c+1c dance all round poussette  

25-32::

  1c+3c tourbillon   2,3,1

', 3);
INSERT INTO 'dancecrib' VALUES (3690, '2013-01-27 12:56:39.469437+00', '2014-04-30 23:23:55.537945+00', 13323, 1, NULL, 'ace', '1–::
  1c+2c & 3c+4c S&Link and face the other cpl ; 3 hands of G-Chain (3,1x,4x,2)
9–::
  Repeat (4x,3x,2x,1x)
17–::
  ½ Circle8 L  breaking into ; 1c+2c & 3c+4c Circle4 L, finishing on the diagonals for
25–::
  1c+2c & 3c+4c Half Poussette ; 1c+4c Half Poussette (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3264, '2012-01-22 19:30:18.122429+00', '2020-07-12 22:15:30.947507+00', 6091, 1, NULL, 'ace', '1–::

  1c+2c+3c cross RH | set ; repeat

9–::

  1c+3c DblFig8 round 2c (1c cross down, 3c cast up)

17–::

  1c followed by 2c+3c dance down the middle (2c & 3c divide) ; 1c (leading) +2c+3c dance up

25–::

  1c+2c Rondel (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (14397, '2021-10-23 01:07:23.638147+00', '2021-10-23 01:08:32.51791+00', 20534, 1, 202, 'ace', '1--::

  1c cast behind own sides ; turn outwards and dance up to places (1,2,3)

9--::

  Mirror Reels3 on sides, 1c in and down (1,2,3)

17--::

  1c cross RH | cast off (2c up) ; turn LH to 2plx (2,1x,3)

25--::

  Reels3 on sides, 1c LSh to 2cnrs (2,1x,3)

33--::

  1c cross RH | cast off (3c up) ; turn LH to 3pl (2,3,1)

41--::

  Mirror Reels3 on sides, 1c in and up, 2c out and down (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2558, '2012-01-22 19:29:47.593719+00', '2014-04-30 23:23:56.717486+00', 3435, 1, NULL, 'ace', '1–::
  1c+2c R&L
9–::
  1c Lead down the middle {3} and up {3}, cross and cast off (2c up) (to 2, 1x)
17–::
  2c+1c L-Chain (2,1x)
25–::
  1c+2c A&R ; 1c turn RH 1½ (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (14022, '2021-05-12 00:35:19.960189+00', '2021-05-12 00:40:28.60382+00', 18082, 1, 202, 'ace', '1--::
  1c+2c change places on sides, 1c in and down | 1c+3c change places EH (to 2,3,1) ; 1c set | lead up to 2pl centre facing up (3c down)
9--::
  ½ Reel3 across, 1c in promhold RSh to 2W ; ½ Reel3 across, 1c in promhold, RSh to 3M
17--::
  1c pivot turn to 2pl facing clw _while{4}_ 2c & 3c set | cross RH and face clw ; all chase clw ½ (3x,1x,2x)
25--::
  3c lead down to 3pl _while{4}_ 2c cross RH and cast up to 1pl (to 2,1x,3) ; 1c cross RH | all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10648, '2018-04-18 09:05:56.910074+00', '2018-04-18 11:59:38.736552+00', 13918, 1, 202, 'ace', '1--::

  1c followed by 2c dance down. On [4] 1c change side and face up, W passing under joined arms, 2c divide ; 1c followed by 2c dance up. On [8], 1c cross over to 1pl and face down, W passing under joined arms, 2c dancing out to 2pl

9--::

  1c+2c facing dn/up turn EH 1½, 1c start in and down, NHJ briefly to finish in centre facing P, back to own side ; 1c set | turn P ¾ to finish  facing 4cnrs

17--::

  Reels3 on sidelines, 1c start Rsh to 4cnrs. On [20], 1c change places to continue the reel on opposite sides Lsh to 1cnrs position, 1c finish in centre facing 2cnrs

25--::

  Reels3 across, 1c start Rsh to 2cnrs (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (1856, '2012-01-22 19:29:06.31902+00', '2020-03-04 09:52:21.726321+00', 862, 1, NULL, 'ace', '{{explanation}}

6 Women and 3 Men in 3 Trios WMW form a square set of 9 dancers, the M are on the midline.  For this crib, we name the men 1M, 2M and 3M by their positions; 2M is »the King«, and wears a cocked hat. We name the W on the »Men''s side« 1W, 2W and 3W, and the W on the Women''s side 1w, 2w and 3w.  

FIG is short for this 16b figure:  Each M sets to and turns a first Woman {4} ; then a second Woman {4} ;; Reel3 with these women, Lsh to the first, to places.



1–::

  All trios WMw dance up NHJ and pivot R ; dance down to places

9-24::

  1M+1W+2W & 2M+1w+3W & 3M+3w+2w dance FIG (2M on 2diag + triangles)

25-40::

  1M+1w+2w & 2M+1W+3w & 3M+3w+2w dance FIG (2M on 1diag + triangles)

41-56::

  1M+1W+1w & 2M+2w+2W & 3M+3W+3w dance FIG (All in lines across)

57-72::

  2w+3w+1w & 2M+1M+3M & 2W+3W+1W dance FIG (All longwise lines).  At the end, 3Trio and 2Trio change places, and 3M becomes »King«.

73-144::

  Repeat [1-72], at the end top two trios change places, and 1M becomes »King« (3,1,2)

145-216::

  Repeat [-72]

217-224::

  The »1M King« dances Reel steps _while_{8} the others Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (2504, '2012-01-22 19:29:45.421436+00', '2021-01-14 00:37:36.208943+00', 12566, 1, NULL, 'ace', '1–::

  1W+2M change places RH | all set to P on sideline ; all turn P EH, M starting inwards, W finish facing out

9–::

  Both W cast up (M step down) | set ; turn LH to finish between the M, facing P

17–::

  Reel4 across, on [23-24] all dance to the same positions as on [4], facing in

25–::

  All dance BtoB with person opposite ; chase one place cclw | set to P

', 2);
INSERT INTO 'dancecrib' VALUES (2498, '2012-01-22 19:29:45.185766+00', '2019-02-12 22:00:09.05532+00', 10435, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; turn RH 1¼ moving to finish on midline between 3c, 1M above 1W

9–::

  1c+3c RHA into ; 1c turn RH ½, 1W turning under arm to face up, 1M behind | dance up to between 2c

17–::

  1c+2c RHA into ; 1c turn RH ½, 1W turning under arm to face down, 1M behind | 1c dance to 2pl (2,1,3)

25–::

  1c+3c the Knot (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3144, '2012-01-22 19:30:13.206424+00', '2019-03-11 11:09:10.896043+00', 5703, 1, NULL, 'ace', '1–::

  All C ½ RH turn and set in circle, ½ LH turn with corner and set, W face in at end

9–::

  1c+3c ½ L-Chain, ½ R&L

17–::

  2c+4c repeat

25–::

  All circle8 and back.', 2);
INSERT INTO 'dancecrib' VALUES (8437, '2014-11-10 20:43:07.899395+00', '2019-07-21 17:36:19.781142+00', 15698, 2, 160, 'ace', '1-8::
 1C half fig8 round 2C (1C face down, 2C up); set and change places LH
9-16::
 1C 2C ladies chain. (1C face down)
17-24::
 Reel of 3 on sides - 1C pass 3C by R-shoulder to begin. (1C face down-3C face up).
25-32::
 1C set to 3C, change with HH - 1C out & down (i.e. 1M 3L RH, 1L 3M LH);
 1C half fig8 round 3C.
33-40::
 3C 1C poussette right round.', 2);
INSERT INTO 'dancecrib' VALUES (2268, '2012-01-22 19:29:28.783404+00', '2020-12-06 11:25:55.749839+00', 2302, 1, NULL, 'ace', '{{explanation}}

Running step used throughout, 2 steps per bar



1–::

  1c lead down the middle and up

9--::

  1c turn RH | 1M+2W & 1W+2M turn LH ; 1c turn RH | 1M+3W & 1W+3M turn LH

17--::

  Repeat 4 bars with 4c ; 1c cast to top behind own line

25--::

  2c+3c+4c kneel down and clap _while_ 1c (NHJ) dance down one on each side of W line, and up one on each side of M line

33-48::

  All C joining BH with partners, 1c dance out to M side and back to centre, weaving down one place each time between 2c+3c+4c till 4pl, _while_ 2c+3c+4c dance out to W side and back, weaving up, (choose phrasing freely) (2,3,4,1).  



*this dance can be adapted to be danced in 40 bars.*', 2);
INSERT INTO 'dancecrib' VALUES (9149, '2016-05-24 22:25:09.594291+00', '2016-05-24 22:25:09.594291+00', 14789, 1, NULL, 'ace', '1--::

  1c cross down into Mirror Reels3 on opposite side (1x,2,3)

9--::

  1c cross back into Mirror Reels3 on own side (1,2,3)

17--::

  1c followed by 2c+3c lead down, cross in 3pl and dance up opposite side to (1x,2x,3x)

25--::

  2c+3c ¾ R&L {6} | all set (1x,3x,2x)



*The set is now inverted, the bottom is the new top. 2c is the new dancing couple.*

', 3);
INSERT INTO 'dancecrib' VALUES (9150, '2016-05-24 22:38:12.050357+00', '2016-05-24 22:38:12.050357+00', 6653, 1, NULL, 'ace', '1--::

  1c cast off behind own lines and cast back

9--::

  1c cross RH | cast (2c up) ; cross down LH between 3c and cast up (2,1,3)

17--::

  All A&R ; all dance BtoB

25--::

  All Circle6 and back

', 4);
INSERT INTO 'dancecrib' VALUES (2506, '2012-01-22 19:29:45.499651+00', '2021-07-20 18:35:08.472193+00', 3246, 1, NULL, 'ace', '1–::

  1c (start Rsh) parallel Figs8 on own sides round 2c+3c

9–::

  1c lead down the middle and up, finish 1c NHJ facing 2c NHJ

17–::

  2c make an arch and dance up, 1c dance down under, all swivel inwards to face back | return same way, 1c making the arch ; repeat, bottom couple making each arch

25–::

  1c+2c Poussette

', 3);
INSERT INTO 'dancecrib' VALUES (2306, '2012-01-22 19:29:30.815766+00', '2020-12-06 18:24:31.848344+00', 2415, 1, NULL, 'ace', '1–::

  1c+2c+3c mirror Reels3 on opposite side (with hands), 1c cross down to begin

9–::

  1c+2c+3c mirror Reels3 on own side ; finish 1W/1M between 2c/3c

17–::

  Set twice in lines of 3 across ; 2W+3W & 2M+3M turn BH _while{4}_ 1c BH 1¼ turn (2,1,3)

25–::

  All set twice ; turn RH', 3);
INSERT INTO 'dancecrib' VALUES (9148, '2016-05-24 13:06:53.493023+00', '2020-10-02 17:51:52.31886+00', 2572, 1, NULL, 'ace', '1--::

  1c cross down as 2c cast up , 2c+1c on side turn EH ½ (1x.2.3){3}, 1c cross down as 2c cast up, 2c+1c on side turn EH ½ (1,2,3){3} | 1c cross to face 1cnr as 2c cast up 

9--::

  CPCP, finish 1c facing out (2,1x,3)

17--::

  Reels3 on the sides, Lsh to 2cnr, finish 1c facing out (2,1x,3)

25--::

  1c cast Lsh round 2cnr, meet in middle, pull Lsh back and cast Lsh round 3cnr to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12444, '2019-12-22 03:53:43.478648+00', '2019-12-22 03:57:52.775662+00', 17624, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; ½ Fig8 R and face 1cnrs
9--::
  ½ Reel4 on 1 diag, pass LSh ; ½ Reel4 on 2 diag to 2pl centre, LSh to P (3x,1x,2x)
17--::
  3c+1M & 1W+2c RHA ; all turn P RH ½, face P | cast R to exchanged places (3,1,2)
25--::
  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (14171, '2021-07-28 08:07:35.546161+00', '2021-07-28 08:13:10.070447+00', 4800, 1, 202, 'ace', '1--::

  *Modified Chain Progression* : 1c & 2c set | turn P RH ¾ to midline ; 1M+2W turn LH ½ _while{2}_ 1W & 2M chase clw ½ to exchanged places | 2c & 1c turn P RH ¾ to centre facing down RHJ

9--::

  1c (2c following) lead down ; and up to sides (2,1,3)

17--::

  2c+3c DblFig8, 3c crossing up (2,1,3)

25--::

  1c+3c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14026, '2021-05-13 07:31:28.834194+00', '2021-05-13 07:33:14.474432+00', 5399, 1, 202, 'ace', '1--::

  1c turn RH ½ | lead down ; turn RH ½ | lead up (1,2)

9--::

  1c set | cast off (2c up) ; set | cast up (2c down) (1,2)

17--::

  RHA ; LHA (1,2)

25--::

  Poussette (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2404, '2012-01-22 19:29:35.976689+00', '2021-05-31 10:21:00.488579+00', 2781, 1, NULL, 'ace', '1–::

  1c+2c+3c Mirror Reels3 in sideline, 1c crossing

9–::

  Repeat, 1c crossing back to own side

17–::

  1c lead down middle {3} and up, cast to 2pl (2c up)

25–::

  1c+3c RHA flowing into ; 2c+1c LHA', 3);
INSERT INTO 'dancecrib' VALUES (2514, '2012-01-22 19:29:45.813925+00', '2021-01-16 19:59:50.432034+00', 12079, 1, NULL, 'ace', '1–::

  1c turn RH | cast off  (2c up) ; 1c turn BH ¾ (4 PdB) and finish BtB W facing up, M down

9–::

  Teapots R ; and L (2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA) (to 2,1,3)

17–::

  2c+1c+3c  (3c leading) lead down the middle ; on [20] the M turn P under R arm and lead up, all stay in the middle of the set, 2c facing out (2x,1x,3x) , ready for

25–::

  Mirror Reels3{6} on opposite sides, touching hands, 1c start in and up |  all cross RH

33–::

  2c+1c+3c circle6 and back.', 2);
INSERT INTO 'dancecrib' VALUES (3609, '2012-07-21 11:45:47.378752+00', '2017-07-07 12:40:47.332056+00', 3730, 1, NULL, 'ace', '1–::

  1c cast off two ; 1c cast back to places

9–::

  1c cross RH, cast off one (2c up) {3}, cross LH, cast off {3} and lead up to face 1cnr

17–::

  Set to and turn cnrs, finish on midline, 1W above 1M, facing M side NHJ

25–::

  1c lead out between 2M & 3M, split and cast round them into middle, repeat with 2W & 3W (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14396, '2021-10-22 07:24:27.397662+00', '2023-01-10 19:03:22.593159+00', 20535, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; turn BH to face 1cnrs

9--::

  *Modified Corners Pass and Turn* : same as Corners Pass and Turn except that cnrs turn RH ½, face each other and cast away to exchanged places. 1c in 2pl face out (3x,1,2x)

17--::

  1c dance RSh round 3cnrs[pos] to between nearest ends _while{4}_ 3c+2c ½ R&L ; 1c turn P BH to face 3cnrs

25--::

  ½ Reel4 on 1diag, pass P RSh to face 4cnrs ; ½ Reel4 on 2diag, pass P RSh to face 1cnrs[pos]

33--::

  Repeat same pattern [25-32] (2,1x,3)

41--::

  1c cross RH | cast off (3c up) ; turn P BH (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (2505, '2012-01-22 19:29:45.460367+00', '2019-01-30 11:40:44.14774+00', 13508, 1, NULL, 'ace', '1–::

  Mirror Reels3{6} on sidelines, 2c starting out and down | 2c+3c change places by continuing the reel (1,3,2)

9-24::

  R&L for 3 couples ; All turn P RH, into

25–::

  1c+3c+2c Allemande (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2515, '2012-01-22 19:29:45.852984+00', '2019-06-05 19:41:07.161077+00', 13618, 1, NULL, 'ace', '1–::

  1c+2c+3c A&R ; dance BtoB

9–::

  1c+2c+3c Turn RH ; turn LH

17–::

  1c slip down | up ; cast off two (2c+3c up on [23-24])

25–::

  2c+3c+1c Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (11899, '2019-06-18 10:38:22.420421+00', '2021-11-08 19:09:31.809508+00', 19409, 1, 202, 'ace', '1--::

  1c+2c The Tourbillon. On [7-8] 1c turn BH and face 1cnrs (2,1x,3)

9--::

  »Modified Corners Pass and Turn« on 1diag [: same as Corners Pass and Turn except that cnrs turn BH ½, face each other and cast away to exchanged places. 1c pass P RSh in centre and pivot R to face 2cnrs] ; repeat [9-12] on 2diag. On [15-16] 1c meet P in centre and pivot R to 2plx (3x,1x,2x)

17--::

  All set | all »RSh Turn« 1½ [: dance RSh round P to own sides] (3,1,2)

25--::

  1c »Figure of Love« L [: 1c ½ Fig8 L, meet P in centre, touch BH and pivot RSh back ½ ; dance RSh round 1cnr[pos] to 2pl] (3,1,2)

33--::

  Circle6 and back (3,1,2)



*Note:  

»RSh Turn« (Right Shoulder Turn) is also known as Gypsy Turn, a term now considered offensive by some.*', 5);
INSERT INTO 'dancecrib' VALUES (2513, '2012-01-22 19:29:45.774396+00', '2021-01-29 22:32:43.448516+00', 11164, 1, NULL, 'ace', '1–::

  1c set | cross RH ; 1c+2c set | cross RH (1,2x,3)

9–::

  1c+2c+3c set | cross RH ; All ½Circle6 L (3,2x,1)

17–::

  Mirror Reels3 on the sides, 1c crossing up, 2c out and down (3,2x,1x)

25–::

  2/3 of a G-Chain (3c cross to start, 2bars/hand, 4 changes) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2527, '2012-01-22 19:29:46.337147+00', '2016-01-21 15:51:11.511505+00', 3336, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  Circle8 and back

9–::

  Set to and turn corners RH ; set to and turn P LH

17–::

  1c+3c advance & meet opposite person {1}, lead out between side couple, cross and dance to opposite place ; turn P 1½ RH (3,2,1,4)

25–::

  2c+4c repeat (to 3,4,1,2)

33–::

  All W Petronella Turn into next W place to the R | All set ; repeat to W in original places

41–::

  All M repeat Petronella Turns and setting back to original places

49–::

  G-Chain (one step per hand)

57–::

  Promenade (Allemande hold) cclw round the set, to places



{{title}}

Jig



65-128::

  Repeat all, end with women in the centre facing P for bow/curtsey.', 3);
INSERT INTO 'dancecrib' VALUES (2510, '2012-01-22 19:29:45.65769+00', '2020-09-18 16:13:56.526584+00', 13511, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; cross RH | cast R (M up, W dn) to between end cpl

9–::

  Reels3 across, Lsh to 2cnr, 1c finish in middle LHJ facing 1cnr

17–::

  Set to 1cnr, turning inwards into RHJ | set to 3cnr, moving clw ; set to 2cnr, turning inwards into LHJ | set to 4cnr, moving cclw into

25–::

  Teapots R ; and L (2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2356, '2012-01-22 19:29:32.96139+00', '2020-12-06 18:32:13.123841+00', 2589, 1, NULL, 'ace', '1–::

  All turn BH ½ to face up NHJ | set ; 1c cast through 3plx and dance up to face 1cnr _while{4}_ 2c/3c dance up, cross, and cast into 3pl/1pl respectively

9–::

  1c SetH&G , finish Lsh to Lsh facing own side (3,1 in middle,2)

17–::

  3c+1M & 1W+2c RHA ; Lsh Snake Pass (unwind the RHA, 1c leading, pass other snake Lsh through 2pl and chase cclw) to 2,1x,3, 1c facing 2cnr

25–::

  2c+1M & 1W+3c LHA ; Rsh Snake Pass (unwind the LHA, 1c leading, pass other snake Rsh through 2plx and chase clw) (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (2517, '2012-01-22 19:29:45.93106+00', '2021-03-21 20:04:15.84608+00', 8138, 1, NULL, 'ace', '1–::

  1c+2c set | Petronella in tandem ; ½circle4 L | turn P BH into first diagonal (2c above 1c) for

9–::

  2c+1c ½ Poussette, 2c remaining in middle and 3c dancing in for ; 2c+3c ½ Poussette (to 1,3,2)

17–::

  Diagonal R&L (to 2x,3,1x)

25–::

  2c+1c Petronella turn | set ; turn LH 1¼ to (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (13665, '2021-02-13 12:36:38.364284+00', '2021-02-13 12:44:43.914958+00', 17960, 1, 202, 'ace', '1--::
  1c cross RSh | turn 2c on sides EH 1½ | 1c cross RSh and face out (2,1,3)
9--::
  1c turn 3c on sides EH 1½ (to 2,3,1) ; 3c+1c Set & MirrorLink, 1c out and up (2,1,3)
17--::
  2c+1c All Round Poussette (2,1,3)
25--::
  1c+3c The Tourbillon (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2511, '2012-01-22 19:29:45.69646+00', '2021-03-16 18:53:43.07229+00', 8556, 1, NULL, 'ace', '1–::

  1c set, cast off one (2c up) ; 2c+1c+3c half G-Chain (2c crossing)  (3x,1x,2x)

9–::

  3c+1c+2c set | Opposing Reels3{6} across (Rsh to 4cnr position ; 1W up, 1M down)  (3x,1x,2x)

17–::

  S&Link3 twice (2,1,3)

25–::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (7828, '2013-08-21 08:31:49.321754+00', '2023-02-04 01:23:04.310095+00', 7533, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1L+2M turn LH, 1M+2L turn RH
17-24::
    1s slip step down the middle for 4 steps, back to top & cast to 4th
    place
25-32::
    4s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (9423, '2016-10-06 07:19:05.06319+00', '2023-02-04 01:23:04.35117+00', 17139, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All dance reel of 4 on own sides
17-24::
    1s followed by 2s+3s+4s cast behind own lines (4 bars), meet
    partners & dance up NHJ  remaining in middle
25-32::
    1s NHJ set twice & cast to 4th place _while_ 2s+3s+4s dance
    promenade dancing up 1 place extra at end.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (2522, '2012-01-22 19:29:46.131288+00', '2021-05-23 20:46:32.892596+00', 3309, 1, NULL, 'ace', '1–::

  2c Petronella turn | set in lines across ; 2c Petronella turn | Set on sides

9–::

  Opposing Reels3{6}, 2c starting Rsh to 2cnr | 2c cross to (1,2,3)

17–::

  1c lead down and up staying in centre as 3c dance in on [23-24] (2c down)

25–::

  1c+3c Allemande (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (2512, '2012-01-22 19:29:45.735501+00', '2021-05-25 12:08:00.210895+00', 3256, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; 1c cross Lsh | cast R round 1cnr to face 4cnr

9–::

  Reels3 across, start Lsh to 4cnr, 1c finish between their end couple, facing P

17–::

  1c change places Lsh | cast R round 2cnr ; pass Rsh to finish BtoB facing 1cnr ; set to 1cnr | to 2cnr

25–::

  Reels3{6} on the side, (1c Rsh to 2cnr) | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2529, '2012-01-22 19:29:46.415612+00', '2016-11-15 15:50:18.236709+00', 3339, 1, NULL, 'ace', '1–::

  1c (BHJ) slip down the middle and back ; cast off one (2c up) and join BH

9–::

  1c repeat with 3c, finish in 3pl

17–::

  2c+3c+1c circle6 and back

25–::

  1c lead up to top ; set | cast off to 2pl (3c down)



{{explanation}}

Note: against tradition and the original text the 2006 Manual tells 2c+3c to step down on [27-28], and 2c to step up on [30-31]. Serious protest has been voiced.', 3);
INSERT INTO 'dancecrib' VALUES (2540, '2012-01-22 19:29:46.846946+00', '2020-12-07 21:53:50.578274+00', 3373, 1, NULL, 'ace', '1–::

  1c cross RH and cast (2c up) ; 2c+1c+3c set and cross RH (2x,1,3x)

9–::

  1c cross RH and cast R (M down, W up) to lines across ; All set | 2c+3c change places on side RH _while{2}_ 1c turn RH ¾ to face 1cnr position

17–::

  1c+1cnrs ½ diag Reel4, pass Lsh ; 1c+2cnrs ½ Diag Reel4 (2,1x,3)

25–::

  2c+3c dance BtoB _while{4}_ 1c advance passing Rsh and swivel to face P, and retire ; all C turn RH', 3);
INSERT INTO 'dancecrib' VALUES (2531, '2012-01-22 19:29:46.494304+00', '2014-04-30 23:23:56.130555+00', 3343, 1, NULL, 'ace', '1–::
  1c+2c RHA ; LHA
9–::
  1c lead down the middle {3} and up | cast to 2pl (2c up) (2,1)
17–::
  1c Fig8 round 2c
25–::
  Circle4 and back', 3);
INSERT INTO 'dancecrib' VALUES (10532, '2018-03-20 09:37:40.903009+00', '2018-03-26 13:31:45.70607+00', 7751, 1, 202, 'ace', '1--::
  1c cross RH | cast two _while{4}_ 2c+3c set | cross up (no hands) ; 2c+3c+1c set | cross RH (2,3,1)
9--::
  2c & 1c Petronella turn into midline | 2W & 1M set _while{2}_ 2M+1W dance round by the R to exchanged places ; 2c & 1c Petronella turn | set (2W,3W,2M on M side, 1W,3M,1M on W side)
17--::
  3c ½ Reel4 with 1cnrs position into line of 3 across ; 3c turn P RH 1 ¼ to 2pl (1,3,2)
25--::
  1c+2c turn P RH ¾ _while{2}_ 3c cross RH and face out | 1W+3M+2M+3W chase clw ½ _while{4}_ 1M+2W turn LH 1 ½ | 2c & 1c turn P RH ¾ _while{2}_ 3c turn RH (to 2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (2533, '2012-01-22 19:29:46.57462+00', '2019-09-26 10:43:47.46965+00', 7283, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; dance between 3c and cast up to (2,1,3)

9–::

  All turn P RH to sidelines ; all chase clw half round (to 3x,1x,2x)

17–::

  All dance BtoB ; all set | all ½ RH turn into

25–::

  3c+1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2523, '2012-01-22 19:29:46.171034+00', '2019-10-20 22:55:28.467907+00', 3310, 1, NULL, 'ace', '1–::

  All A&R ; turn P RH, finish with 1c facing 4c, both NHJ

9–::

  1c+4c A&R up/down, finish as before ; On the sides, all Ends turn Middles EH (1c+4c start inwards), to sidelines (1,2,3,4)

17–::

  1c lead down the centre, cross below 3c, cast behind 4c ; ½ Fig8 up round 4c (2c+3c+4c up) (2,3,4,1)

25–::

  All Circle8 and back (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (3749, '2013-05-24 17:45:01.720708+00', '2014-10-28 12:23:26.755936+00', 7433, 1, NULL, 'ace', '1–::

  1c+2c Espagnole (2,1,3)

9–::

  1c+3c mirrored Espagnole, the M dancing between the W to start (2,3,1)

17–::

  1c cross RH | cast up (3c down) ; turn LH 1¼ to face 3cnr

25–::

  Opposing Reels3 on own side Lsh to 3cnr (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2112, '2012-01-22 19:29:20.756041+00', '2017-07-07 12:43:48.514783+00', 1773, 1, NULL, 'ace', '1–::

  1c+2M Reel3 on M side, 1W starts Lsh to 2M, end in places

9–::

  1c+2W Reel3 on W side, 1W starts Lsh to 2W as 1M crosses at the top, both W finish with loops (to 1,2),

17–::

  1c set and turn BH ; dance down between 2c, cast up to top, 2c join in on [24] for

25–::

  1c+2c Allemande (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (2562, '2012-01-22 19:29:47.750798+00', '2020-12-08 09:50:09.369376+00', 3444, 1, NULL, 'ace', '1–::

  1c+2c circle4 L for {3}, then 1c cast off _while{1}_ 2c dance up ; 1c+3c repeat to the R (to 2,3,1)

9–::

  3c+1c set | ½R&L | cross to own side

17–::

  2c+1c+3c circle6 and back

25–::

  2c+1c+3c turn RH ; turn LH', 2);
INSERT INTO 'dancecrib' VALUES (2532, '2012-01-22 19:29:46.535047+00', '2020-12-24 10:31:41.624998+00', 10675, 1, NULL, 'ace', '1–::

  1c lead down one (2c up) | cast behind 3c ; lead up to 2pl | turn 3cnr RH and face that corner (2,1,3)

9–::

  Opposing Reels3{6} on sides, Rsh to 3cnr | 1c set adv. & twirl R to face 2cnr

17–::

  1c+2cnrs ½ diag Reel4, pass Rsh and face 3cnr ; 1c+3cnrs ½ Diag. Reel4, finish BtoB 1M facing up, 1W down for

25–::

  1c dance as DTr, with final petronella to 2pl _while{8}_ cnrs join in DTr but chase clw 1 place on [27-28] and on [31-32] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2535, '2012-01-22 19:29:46.652106+00', '2020-12-25 21:34:42.918131+00', 13227, 1, NULL, 'ace', '1–::

  1c+4c set | cross RH ; set, cross LH _while{8}_ 2c+3c RHA ; LHA

9–::

  1c cast behind own lines and lead up to places

17–::

  2c+3c dance BtoB with P ; dance BtoB on sideline with 1c / 4c respectively (1,2,3,4)

25–::

  With same person set advancing and passing | turn next person ½BH, at top/bottom face next couple, on the sides face P and then twirl R to face the end couple ; repeat 4 bars (to 4x,3x,2x,1x)

33–::

  4c+3c+2c ½ Lsh Reel3 on the sides (3c start up and R ; 2c cast into reel) ; all C turn RH 1½.', 2);
INSERT INTO 'dancecrib' VALUES (2541, '2012-01-22 19:29:46.884425+00', '2021-03-01 16:49:07.620416+00', 9123, 1, NULL, 'ace', '1–::

  1c+2c ½RHA, cross RH ; repeat

9–::

  1c cross RH, cast (2c up) ; turn LH to join RH with 1cnr

17–::

  BiL, 1c turn 1¼ LH to join RH with 2cnr ; BiL, 1c turn LH into 2pl in middle and 3c step in

25–::

  1c+3c Poussette.', 2);
INSERT INTO 'dancecrib' VALUES (14173, '2021-07-28 16:30:19.313129+00', '2021-07-28 16:34:17.429972+00', 13604, 1, 202, 'ace', '1-12::

  3C R&L (1,2,3)

13-16::

  1c BHJ set, starting to the bottom, opening to cast off (2,1,3)

17--::

  Poussette

25--::

  1c lead up to top LHJ | cast off ; lead up to top RHJ | cast to 3pl (3c up) (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (14030, '2021-05-13 11:14:23.515346+00', '2021-05-13 11:17:30.04866+00', 5106, 1, 202, 'ace', '1--::
  1W+2c in line3 across dance down ; and up to places
9--::
  1M+2c repeat [1-8]
17--::
  1c lead down ; and back to 2pl (2c up on [19-20]) (2,1)
25--::
  Circle4 and back (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2542, '2012-01-22 19:29:46.923129+00', '2023-01-10 13:10:19.70073+00', 3381, 1, NULL, 'ace', '1–::

  1W+2M set to each other | change place RH ; cast behind P and cross to (1,2)

9–::

  1M+2W repeat LH

17–::

  1c+2c DblFig8, 1c cross down to start, finish for

25–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (2537, '2012-01-22 19:29:46.731067+00', '2023-01-10 13:16:29.767903+00', 3365, 1, NULL, 'ace', '1–::

  1M casts off one (2M up) | 1M+3W set (not advancing) ; turn RH to own side

9–::

  1W casts off one (2W up) | 1W+3M set ; turn LH (to 2,1,3)

17–::

  2c+1W & 1M+3c RHA, 1c finish in centre LHJ, facing opposite sides ; 1c set | dance out to opposite side (2,1x,3)

25–::

  1M+2c & 1W+3c RHA, 1c finish in centre LHJ facing own sides ; 1c set | dance out (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (7829, '2013-08-21 08:31:49.329952+00', '2023-02-04 01:23:04.383752+00', 6919, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1M+4L also 1L+4M dance figs of 8 on sides round 2s+3s (dancing
    between 2s/3s to start)
9-16::
    1s & 4s turn partners RH 1.1/2 times, cast in 1 place & dance 1/2 RH
    across to end in prom hold with other partner facing 2M/3M
17-24::
    1M+4L also 1L+4M dance RSh reels of 3 on sides & end in centre
    facing out sides
25-32::
    1s+4s 1/2 turn corners with nearer hand, cross down/up 1 place
    _while_ corners cast to ends & turn ''new'' corners once round to end
    2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (2536, '2012-01-22 19:29:46.691533+00', '2021-06-16 16:40:25.800816+00', 3364, 1, NULL, 'ace', '1–::

  1c turn BH ½ and stay close | set ; cross RH | cast off to face 1cnrs (2c up)

9–::

  1c+1cnrs turn BH ¾ and open up (cnr on the R) to face diagonally NHJ | set ; advance diagonally (keep NHJ for 1 bar), pass dancer opposite Lsh into ½LHA (cnrs to place and 1c finish facing 2cnrs)

17–::

  Repeat with 2cnrs (1c finish facing 3cnr)

25–::

  1M+2c & 1W+3c Reels3 across (Rsh to 3cnr) (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10673, '2018-04-21 23:27:58.673318+00', '2021-07-30 03:31:57.96091+00', 4741, 1, 202, 'ace', '1--::

  1c & 2c set | cross RH, facing dn/up at end ; 1c+2c set | change places LH (2x,1x,3,4)

9--::

  1c+3c ½ RHA |1c+4c LHA | 3c+1c ½ RHA (2x,1x,3,4)

17--::

  2c+1c+3c Mirror Reels3, 1c out and up to start

25--::

  1c(2c following) lead down, cross and cast round 4c(3c) to 2pl(1pl) | all set (2,1,3,4)

33--::

  1c lead down, cross between 3c, cast behind 4c to 4pl (3c+4c up) ; 1c ½ Fig8 up round 4c (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (8112, '2013-11-17 00:33:38.459896+00', '2014-04-30 23:23:56.462093+00', 10926, 1, NULL, 'ace', '{{explanation}}
Couples in single circle, W to the R of P.  Waltz step all through.

1–::
  All M advance to centre and retire ; W repeat
9–::
  M repeat ; W repeat, returning to next W position clw and face out
17–::
  Turn this P RH ½ | Balance ; Turn P RH ½ | balance, and face P
25–::
  BtoB with P ; Turn BH and face in, W on R of M', 3);
INSERT INTO 'dancecrib' VALUES (14027, '2021-05-13 08:02:02.917411+00', '2021-05-13 08:03:49.625751+00', 4688, 1, 202, 'ace', '1--::

  1c set | cross down RH (2c up). 1c+2c face on sides ; 1c+2c set on sides | change places RH and face on sides (1x,2,3)

9--::

  Parallel Reels3 on sides, 1c RSh to 2c (1x,2,3)

17--::

  1c set | cast off (2c up) ; ½ Fig8 up round 2c (2,1,3)

25--::

  1c+2c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2437, '2012-01-22 19:29:38.728892+00', '2015-02-18 21:34:37.690695+00', 2956, 1, NULL, 'ace', '1–::

  1c+2c A&R ; Turn RH ½ into | ½ RHA (2,1)

9–::

  2c+1c A&R ; Turn LH ½ into | ½ LHA (1,2)

17–::

  1c (BHJ) slip down the middle and up

25–::

  1c set | cast off (2c up) ; 2c+1c turn RH', 3);
INSERT INTO 'dancecrib' VALUES (15089, '2022-09-07 23:25:07.525449+00', '2022-09-07 23:30:37.780516+00', 17538, 1, 202, 'ace', '1--::

  All chase clw ½ in a rectangular shape ; set | 3c & 1c turn RH ¾ into midline

9--::

  ½ Reel4 on midline. On [12] 1M+3W pass LSh to face 2c across ; ½ Reel4 across. On [16] 1M+3W pass LSh to face P on midline

17--::

  ½ Reel4 on midline ; 3c & 1c set | Petronella turn to sides (3,2,1)

25--::

  2c (+1c following) dance up to top | cast off (to 3,1,2) ; all turn P BH (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (10650, '2018-04-18 12:20:38.139506+00', '2020-04-13 08:47:10.287585+00', 13916, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; 1c turn LH 1¾

9--::

  1M+2c & 1W+3c RHA, 1c finish in centre LHJ facing own side ; 1c set | cross LH to 2pl and face out (2,1,3)

17--::

   Reels3 on sidelines, 1c start Lsh to 4cnrs. On [24], 1c, 3M & 1W pull Rsh back into

25--::

  Circle6 and back (2,1,3)



*Deviser''s note:*  

*This is the Jubilee* _challenge_ *but if dancers find the ending of the reels. bars 23-24, too confusing or too difficult they can finish the normal way instead*', 4);
INSERT INTO 'dancecrib' VALUES (3647, '2012-09-12 23:17:59.929817+00', '2016-06-01 08:03:55.415254+00', 14241, 1, NULL, 'ace', '1–::

  1c set | turn BH ½ and face 2c ; 1c set to 2c and turn BH on the side (1x,2,3,4,5)

9–::

  Snowball G-Chain, start 1c RH to 2c, on [4] 1c (in 4plx) + 2c (in 2plx) take »L-Tulloch«hold (Lsh to Lsh, L arms linked, holding P''s R hand behind his back) make 2 turns, finish facing up (order 3c,2x in middle,4, 1x in middle,5)

17–::

  3c+2c & 4c+1c RHA 1½  ; 3c+1c LHA 1½

25–::

  2c+1c & 3c+4c RHA 1½ (1,2x,4,3x,5) ; all set ; 1c+4c cast off as 2c+3c cross up (2,1,3,4,5)



{{explanation}}

For next time through, 2c starts anew from 1pl and 1c dance to 5pl (3c+4c+5c up on [3-4]  

(This version is closer to RSCDS style.  Alternatives are 1½ turn on [3-4], going to sidelines on [16], making 1½ turn moving up on [31-32]', 3);
INSERT INTO 'dancecrib' VALUES (14265, '2021-08-24 07:17:55.438568+00', '2021-08-24 07:22:55.500239+00', 11095, 1, 202, 'ace', '1--::

  1c turn RH to 1pl centre and face down | Fig8 on opposite sides, 1c crossing down (1x,2,3)

9--::

  Mirror Reels3 on sides {6}, 1c in, giving hands where possible | 1c&2c&3c cross RH. 1c in 1pl centre face down (1,2x,3x)

17--::

  1c lead down to 3pl centre and turn inwards to face up _while{2}_ 2c & 3c cast up (to 2x,3x,1) | 3c+1c ½ RHA _while{2}_ 2c turn LH and face down (to 2x,1x,3) ; 2c+1c ½ LHA _while{2}_ 3c turn RH and face up (to 1,2,3) | 3c lead up to 1pl _while{2}_ 1c & 2c cast off (3,1,2)

25--::

  3C Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1921, '2012-01-22 19:29:09.907988+00', '2017-07-07 12:49:23.303519+00', 1100, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  1c+2c RHA ; LHA

9–::

  1c set | 1c cast (2c up) ; 2c+1c R&L (1 step per hand) (2,1,3)



{{title}}

Reel



17–::

  1W+1M each Fig8 round 1cnr+2cnr (Rsh to 1cnr) and finish facing 1cnr

25–::

  1c SetH&G (1c clap on [31] and petronella to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12955, '2020-07-11 06:13:12.718463+00', '2020-07-11 06:18:08.129352+00', 18242, 1, 202, 'ace', '1--::

  1c Fig8 down round 2c (1,2,3,4)

9--::

  1c+2c Circle4 and back _while{8}_ 3c Fig8 down round 4c (1,2,3,4)

17--::

  1c+2c S&Link twice _while{8}_ 3c+4c Circle4 and back (1,2,3,4)

25--::

  1c turn 2c RH ½ on sides | turn 3c LH ½ ; turn 4c RH ½ | all set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (4966, '2013-08-21 08:30:58.069588+00', '2023-02-12 16:06:11.167185+00', 1608, 3, NULL, 'ace', '1-8::

    1M 1/2 turn 3L into prom hold face in as 3M casts & turns 1L into

    prom hold face out, 1M+3L dance up & face 2L as 3M+1L go behind 2L &

    face 2M

9-16::

    1M+3L+2L dance RH across & 1/2 way back as 1L+3M+2M dance likewise,

    3L followed by 1M dance round passing other couple RSh to 3rd place

    facing up as 1L followed by 3M dance round to 1st place facing down

17-24::

    1s+3s dance 1/2 Ladies'' Chain (3s end in original places & 1s in 1st

    place opp sides), 1s+2s change pl RH on sides & 1s cross LH to own

    sides

25-32::

    2s+1s+3s set, turn partners RH (long turn) & set', 0);
INSERT INTO 'dancecrib' VALUES (2556, '2012-01-22 19:29:47.515047+00', '2020-07-25 22:20:14.991864+00', 3424, 1, NULL, 'ace', '1–::

  1M+2W A&R ; dance BtoB

9–::

  1W+2M repeat

17–::

  1c long cast (2c up), dance through 3c and cast up into 2pl

25–::

  2c+1c+3c in a wide circle A&R ; all C turn P RH to places', 3);
INSERT INTO 'dancecrib' VALUES (2446, '2012-01-22 19:29:39.300929+00', '2020-08-05 14:25:40.709864+00', 3019, 1, NULL, 'ace', '1–::

  1c lead down, cross and cast up ; 1M+2W lead out on M side, cross and cast to W side

9–::

  All facing diagonally set, petronella 1 place to R ; set, ½RHA end facing down with »wrong« P

17–::

  All lead down the middle, in the turn 2M passes down outside 1M ; 1c+2c dance up, staying in middle for

25–::

  1c+2c Allemande', 2);
INSERT INTO 'dancecrib' VALUES (2539, '2012-01-22 19:29:46.807462+00', '2020-12-26 10:23:23.103451+00', 14386, 1, NULL, 'ace', '1–::

  1c set | dance down the middle and cast up round 3c to 1pl

9–::

  1c+2c+3c mirror Reels3 on the sides, each couple crossing down from the top, at end 2c face out (1x,2x,3x)

17–::

  1c+2c ¾ of DblFig8 _while_ 3c cross RH on [21-22] | All set (2,1x,3)

25–::

  2c+3c dance BtoB _while{4}_ 1c pass P Rsh, swivel R to face P, and retire ; 2c+1c+3c turn RH', 3);
INSERT INTO 'dancecrib' VALUES (11254, '2018-10-06 12:19:40.354963+00', '2021-01-04 12:36:30.228708+00', 18837, 1, 202, 'ace', '1--::

  1W+2W turn RH 1½ ; 1W +3W turn LH 1½ _while{8}_ Reel3 on M side, 1M & 2M passing RSh (2,3,1 on W side, 1,2,3 on M side)

9--::

  3C Bourrel. On [15-16] all turn P BH into promhold facing up (3,1,2)

17--::

  3C Allemande. 1c face 1cnrs (2,1,3)

25--::

  CPCP (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3022, '2012-01-22 19:30:07.246995+00', '2021-03-22 01:00:52.920134+00', 8117, 1, NULL, 'ace', '1–::

  1c set, cast off (2c up) ; 1c turn 1¼ RH to finish in the middle

9–::

  1M+2c & 1W+3c LHA ; 1M+3c & 1W+2c RHA

17–::

  1c in promhold ½Reel3 with 2W+3W (Rsh to 2W) ; ½Reel3 on M side (Lsh to 3M), on [24] 2W+3W step in for

25–::

  3c+1c+2c Allemande', 2);
INSERT INTO 'dancecrib' VALUES (10851, '2018-06-18 08:25:11.791763+00', '2021-03-21 12:00:52.548452+00', 14750, 2, 202, 'ace', '1-8::

  all set. 1,2; 3,4 3/4 R & L

9-10::

  active couples dance just past partner RS, and turn to the Right (so ladies face up and men down)

11-12::

  1M dances down to opposite 3M place, 4M dances down to below 4M place; ladies up similarly.

13-14::

  1M, 4M dance out to the sidelines and face up pulling back RS; ladies similarly down, also RS back.

15-16::

  in a line of 3 1M, 3M and 4M dance up into respectively 2M, 3M and 4M place; ladies similarly

17-24::

  repeat 9-16 but with 2L opposite 1M and 3M opposite 4L as active center couples to begin, taking the roles of 1C and 4C of 9-16. Finish in order 2C, 1C, 4C, 3C

25-32::

  1C, 4C, 3C dance a 3 couple set and rotate.', 2);
INSERT INTO 'dancecrib' VALUES (14032, '2021-05-13 14:01:54.249009+00', '2021-05-13 14:04:36.545847+00', 2666, 1, 202, 'ace', '1--::

  1c lead down {3} and face P, slip up {3} to 1pl | cast off (2c up) (2,1,3)

9--::

  1c ½ Fig8 RHJ down round 3c ; ½ Fig8 RHJ up round 2c (2,1,3)

17--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10676, '2018-04-22 08:52:42.082842+00', '2021-07-30 07:48:07.797391+00', 3566, 1, 202, 'ace', '1--::

  All set | Circle6 {2} L ; set in circle | Circle6 {2} R, back to original places

9--::

  Reels3 on sidelines, M start Rsh to W on their right, back to original places

17--::

  ½ Reel4 on 1diag, M passing Lsh to start ; ½ Reel4 on 2diag, M passing Rsh to start, to sidelines

25--::

  M turn RH ¾ | set ; turn RH ¾ _while{6}_ W ¾ R&L | all set

33--::

  M Petronella turn into facing lines of 3 across | all set ; all A&R  ', 2);
INSERT INTO 'dancecrib' VALUES (2547, '2012-01-22 19:29:47.159274+00', '2015-03-19 10:28:42.796731+00', 12669, 1, NULL, 'ace', '1–::

  1c cross | cast (2c up) ; 1c ½ Fig8 L (M down, W up) _while{4}_ 2c+3c set | cross LH (2x,1,3x)

9–::

  Diagonal R&L (first R, then L) (3,1,2)

17–::

  Set&Rotate for 3 (All set | cast clw to lines of 3 across ; change places with P RH | chase clw to (2,1,3)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (14701, '2022-03-14 23:52:19.496628+00', '2022-03-14 23:57:26.363971+00', 19254, 1, 1645, 'ace', '1--::
  1c & 3c petronella to centre line | set with 1W & 3M turning &frac34; on the spot to face own side ; 1W & 3M, followed by P, chase &frac12; way clw _while{4}_ 2c petronella twice to opp side (3x,2x,1x)
9--::
  All chase &frac12; way clw to original places (1,2,3) ; all turn RH & face down RHJ
17--::
  3c followed by 2c & 1c lead down & up, 1c end facing out (1,2,3)
25--::
  1c+2c turn 1&frac12; on sides, M LH, W RH ; 1c+3c turn once, M RH, W LH (2,1,3)
::
  *On their 2nd turn, or in a 3 couple set, 1c turn 1&frac12; to the bottom in bars 29-32*
', 0);
INSERT INTO 'dancecrib' VALUES (2575, '2012-01-22 19:29:48.261915+00', '2023-01-10 11:29:22.742757+00', 3511, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; turn RH to face 1cnr

9–::

  Opposing Reels3 on the sides, Rsh to 1cnr, finish facing 1cnr

17–::

  1c with 2cnrs closely following dance Reel4 on 1diag with 1cnrs, as 1c pass in the middle they turn left to follow the other cnr person, finish with 2cnrs in own cnr place, and 1W between 2c facing 1M between 3c

25–::

  1c set adv as 2c+3c set to P | 1c turn ¾ RH as 2c+3c cross RH ; All set and cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2007, '2012-01-22 19:29:14.684607+00', '2017-07-07 12:52:40.034238+00', 1415, 1, NULL, 'ace', '1–::

  1c+2c set and cross RH ; repeat (1,2,3)

9–::

  1c lead down (2c up on [11-12]) ; 1c lead up (RHJ), at end 1W dances once R about under her arm and 1c face 1cnr

17–::

  1c set to 1cnr | to 2cnr ; set to P across the dance | cross RH to (2,1,3)



{{explanation}}

Note on [15-16]: older text versions say 1W turns L about under M''s arm, and some specify PdB. The Technique committee (has chosen for R about and Sk-Change.', 3);
INSERT INTO 'dancecrib' VALUES (2530, '2012-01-22 19:29:46.455239+00', '2017-07-07 12:55:43.717382+00', 3342, 1, NULL, 'ace', '1–::

  1W (longish) cast off, 1M following (2c up), 1W crosses (swivel R) to finish 1c in 2plx {6} | 1c set

9–::

  1c repeat (1M casting up, & swivel L on [14] to original places

17–::

  1c+2c RHA, LHA

25–::

  1c+2c set and cross RH ; repeat

33–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (14028, '2021-05-13 08:13:56.57861+00', '2021-05-13 09:29:05.034891+00', 237, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; set | turn P LH and face 1cnrs

9--::

  1c turn 1cnrs RH ; turn P LH and face 2cnrs

17--::

  1c turn 2cnrs RH ; turn P LH to 2plx centre facing up

25--::

  1c dance up | cast off to 2plx ; set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10119, '2017-09-12 19:54:21.993853+00', '2017-11-14 01:07:06.523084+00', 14361, 1, 202, 'ace', '1--::

 2c followed by 1c lead down ; and up

9--::

 1c+2c S&Link ; 1c set advancing | 1c turn BH (2,1,3)

17--::

 1c+3c Knot (2,3,1)

25--::

 1c dance up | turn BH twice | dance back to 3pl (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (14031, '2021-05-13 11:33:05.751403+00', '2021-05-13 11:35:36.9107+00', 6301, 1, 202, 'ace', '1--::

  1c cast off behind own lines ; turn outwards and dance up to places (1,2,3)

9--::

  1c lead down (2c up) ; lead up to 2pl centre

17--::

  1c dance to top | cast off ; dance down between 3c | cast up (2,1,3)

25--::

  2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10555, '2018-03-28 06:38:55.359941+00', '2018-03-28 19:31:43.485312+00', 3897, 1, 202, 'ace', '1--::
  All set | 1c+2c & 3c+4c ½ R&L (one step per bar) ; repeat (1,2,3,4)
9--::
  1c lead down, cross and cast behind 4c, meet, lead up and cross to 1pl
17--::
  4c repeat [9-16] to top
25--::
  1c turn BH | lead down | turn BH to 4pl (2c+3c+4c up on [31-32])', 2);
INSERT INTO 'dancecrib' VALUES (12956, '2020-07-11 06:42:16.091582+00', '2020-07-11 06:47:19.986439+00', 20044, 1, 202, 'ace', '1--::

  Circle6 and back (1,2,3)

9--::

  1c+2c RHA ; 2c+3c LHA ½ retaining LH | 3c+2c cross LH (1,3,2)

17--::

  All set | 1c followed by 3c & 2c (who dance up) lead down, cross to 3pl and dance up. All face up (1x,3x,2x)

25--::

  Mirror ½ Reels3 on sides, 1c out and down, 2c in and up ( to 2x,3x,1x) ; all set | cross RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12957, '2020-07-11 11:17:00.976082+00', '2020-07-11 11:19:56.284119+00', 16002, 1, 202, 'ace', '1--::

  1c+2c ½ RHA | set (to 2x,1x,3) ; 1c+3c ½ LHA | set (2x,3x,1)

9--::

  Reels3 on sides, 1c in and up, 3c out and down. 1c in 3pl centre NHJ face up (2x,3x,1)

17--::

  1c dance up, cast up behind 2c ; cross down RH, cast behind 3c to 3plx (2x,3x,1x)

25--::

  All turn P RH ¾ to midline | set to P ; turn P RH ¾ to sides | all set (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2699, '2012-01-22 19:29:53.595391+00', '2021-05-13 16:05:59.156195+00', 3932, 1, NULL, 'ace', '1–::

  1M+2W set | turn BH ; 1W+2M repeat

9–::

  1c lead down, cross below 2c, cast behind 3c ; lead to the top, cross and cast off to face 1cnrs (2c up)

17–::

  1c turn 1cnr RH | pass P Rsh ; turn 2cnr LH | pass P Lsh to finish 1W / 1M between 2c /3c facing down / up

25–::

  In lines across A{1}&R{1}, repeat {2} ; 1c turn 1¼ BH to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2572, '2012-01-22 19:29:48.143605+00', '2021-05-18 20:49:13.406676+00', 3502, 1, NULL, 'ace', '1–::

  1c&2c set | ½RHA ; set | ½LHA

9–::

  1c cross RH, cast off 2 ; dance up to BtB between 2c facing opposite side | 1c+2c set

17–::

  1c+2c spurtle ; 1c+3c spurtle (to 2x, 3x, 1x)

25–::

  Mirror Reels3 on sides, all C crossing from bottom (2c&3c face down, 1c cross up to start) (to 231)



{{explanation}}

The spurtle: ½Reel4 across, outer couple finish 1 place up, inner couple fast LH turn to next position', 2);
INSERT INTO 'dancecrib' VALUES (2570, '2012-01-22 19:29:48.064781+00', '2023-01-10 11:31:23.699647+00', 3490, 1, NULL, 'ace', '1–::

  1c set advancing | turn BH ; cast off (2c up) | turn BH ½ and face down NHJ

9–::

  1c (NHJ) set to 3c (in places) | change places no hands, 1c passing between 3c ; 3c NHJ set to 1c (in sidelines) | change back, 1c finish NHJ facing up

17–::

  2c+1c repeat the formation, 2c finish facing out and 1c in and down (2,1x,3)

25–::

  Mirror Reels3{6} on the sides | 1c cross RH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (7831, '2013-08-21 08:31:49.346185+00', '2023-02-04 01:23:04.608889+00', 12897, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross LH, Lady casts up & Man down
9-16::
    1s dance 1/2 reels of 3 across (Lady with 2s & Man with 3s) into 1/2
    reels of 3 on own sides (RSh to 3rd corner (pstn) & end 2nd pl own
    sides
17-24::
    3s & 2s 1/2 turn RH _while_ 1s rotate, 3s+1s+2s chase cl''wise 2
    steps to lines across facing prtnr up/dn, 1/2 turn prtnr RH & chase
    to own sides
25-32::
    2s+1s+3s circle 6H round to left for 6 steps, pivot left & chase
    back to places', 0);
INSERT INTO 'dancecrib' VALUES (2571, '2012-01-22 19:29:48.10409+00', '2021-05-19 10:38:44.757506+00', 3499, 1, NULL, 'ace', '1–::

  1c+2W Circle3 L (2M up) ; 1c+2M (who is on L of 1M) Circle3 R (2W up) (2,1,3)

9–::

  1c cross RH into Fig8 round own cnrs, starting Rsh to 1cnr , finish facing 1cnr

17–::

  Set to and turn 1cnr ; repeat with 2cnr, finish (2,1mid,3) with 1c on midline RHJ, M below W, facing W side

25–::

  1c+(the two W)+(the two M) Interlocking Reels3 across: each pair on reaching a sideline cross RH up/down (and cross back on second sideline), 1c finish on own side (2,1,3).', 2);
INSERT INTO 'dancecrib' VALUES (9152, '2016-05-31 22:33:24.480819+00', '2016-05-31 22:33:24.480819+00', 16964, 1, NULL, 'ace', '1--::

  Reels3 on the sides, 1c Rsh to 2c (1,2,3)

9--::

  “La Spirale”: 1c+2c turn BH ¾ to midline | 1W+2M (“ends”) cast clw outside the set to own side while{2} 1M+2W (“middles”) cast clw round each other to own side, couples finish in exchanged positions (2,1,3) ; 2c+1c turn P RH

17--::

  2c+1M & 1W+3c Reels3 across, 1c Rsh to 2cnr, and finish facing 1cnr

25--::

  CPCP using elbow grip, except for crossing LH on [31-32] (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2566, '2012-01-22 19:29:47.90398+00', '2017-07-15 01:36:03.375776+00', 3474, 1, NULL, 'ace', '1–::

  1M+2W & 3M+4W change places RH | 1M+4W change places LH ; 1W+2M & 3W+4M change places RH | 1W+4M change places LH (2x,4,1,3x)

9–::

  2c+4c & 1c+3c set | ½ RHA ; 2c+3c set | ½ LHA (4x,3x,2x,1x)

17–::

  1c lead to 1plx (others step down) ; 4W+3W & 4M+3M facing up/dn set | turn LH to finish BtoB facing the ends

25–::

  ½ Reels4 on the sides ; All cross RH {4bars!} (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2573, '2012-01-22 19:29:48.183451+00', '2019-03-15 10:24:32.296252+00', 3503, 1, NULL, 'ace', '1–::

  1W, followed by 2W, 3W, and 4W dances across the set, behind the men, across the set at the bottom and up own side back to place

9–::

  men repeat

17–::

  1c lead down the middle and up

25–::

  1c cast off to bottom (2c+3c+4c step up on bars 27-28) ; 1c turn RH', 2);
INSERT INTO 'dancecrib' VALUES (2133, '2012-01-22 19:29:21.830694+00', '2020-06-19 22:35:19.663038+00', 1848, 1, NULL, 'ace', '1–::

  1c+2c+3c Reels3 on the sides, 1c crossing down (to 1x,2,3) 2c facing out

9–::

  1c turn 2c 1½ Easy H, and 1c dance down crossing ; 1W+3W turn LH _while_{4} 1M+3M turn RH, 1c finish facing 1cnr

17–::

  1c set to 1cnr | dance (Sk-Ch) Rsh round each other to face 2cnr ; set to 2cnr |  dance (Sk-Ch) Rsh round each other to the midline, 1M/W facing up/dn

25–::

  1M(1W) dances through 2c/3c and cast R to (2,1,3) ; 1W+2c & 1M+3c RHA (teapot R)', 3);
INSERT INTO 'dancecrib' VALUES (2587, '2012-01-22 19:29:48.73832+00', '2015-02-18 21:35:11.375505+00', 9787, 1, NULL, 'ace', '1–::

  1c+2c S&Link, but 2c cast up & 1c dance down & face out ; 1c joining EH with 3c set and change places (2,3,1)

9–::

  2c+3c+1c mirror Reels3 on the sides, 3c starts down and out (2,3,1)

17–::

  1c set | cross RH ; cast up (3c down) | turn LH to face 1cnr

25–::

  1c+1cnrs ½ Reel4, 1c pass Rsh ; ½ Reel4 with 2cnrs (to 3x,1x,2x)

33–::

  All C turn RH and chase clw to own sides (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3876, '2013-08-09 12:28:49.718794+00', '2014-06-01 02:46:58.07365+00', 14977, 1, NULL, 'ace', '1–::

  1c cast behind own lines and cast back

9–::

  1c cross down into Mirror Reels3 on opposite sides (1x,2,3)

17–::

  1c lead down, cross (M below W, who passes under M''s arm) ; and up, 2c steps in for

25–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (9529, '2016-12-15 08:47:45.025739+00', '2016-12-16 00:31:52.506647+00', 17485, 1, NULL, 'ace', '1--::

  All set | 1c (crossing) ½ Fig8 round 2c (and 4c likewise round 3c), finishing between them in facing lines across NHJ | All set to opposite 

9--::

  2W+1M+4M+3W LHA _while{4}_ 2M+1W+4W+3M RHA ; 4c with 1c following lead down LH, cross between 3c and cast up (2c up and 3c down) to (2,4,1,3)

17--::

  All set | All turn P BH ½ and twirl to opposite side All cross RH (2,4,1,3)

25--::

  2c+4c & 1c+3c Poussette

', 4);
INSERT INTO 'dancecrib' VALUES (2583, '2012-01-22 19:29:48.578343+00', '2017-07-07 12:55:09.191215+00', 3541, 1, NULL, 'ace', '1–::

  1W+2M A&R ; turn BH (skip change of step)

9–::

  1M+2W repeat

17–::

  1c followed by 2c (dancing up to begin) lead down the middle ; up the middle (2c leading) to exchanged places

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (2582, '2012-01-22 19:29:48.539211+00', '2022-12-20 12:15:33.155736+00', 3537, 1, NULL, 'ace', '1–::

  1c set twice ; turn RH | cast (2c up) (2,1,3)

9–::

  1c lead down the middle {3}, lead to top {3}, cast to 1cnrs

17–::

  1c set to and turn corners (to 2,1x,3)

25–::

  1c lead between 3c, cross ; cast up, lead between 2c, cast to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12767, '2020-04-17 00:25:11.317315+00', '2021-04-06 11:27:37.151263+00', 19495, 1, 202, 'ace', '1--::

  1c+2c set | 1c followed by 2c (dancing up to begin) lead down {3}, up (2c leading) {3} to exchanged places (2,1,3)

9--::

  All set | 1c Petronella Turn into facing lines3 across ; all set | 1c Petronella Turn to face 1cnrs

17--::

  Turn CPCP crossing RH on [23-24]

25--::

  2c+1c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10143, '2017-09-24 15:11:10.447697+00', '2017-09-24 15:14:38.504184+00', 3817, 2, 160, 'ace', '1-8::

  1s+2s set, RHA, set.

9-16::

  1s cross RH, cast (2s up); cross LH, cast Left - woman up, man down to lines of 3 across.

17-24::

  1s turn 1cor RH end facing out btwn corners; 1s turn 2cor LH.

25-32::

  All advance & retire; 1s turn RH 1_1/2 to own sides.', 3);
INSERT INTO 'dancecrib' VALUES (2581, '2012-01-22 19:29:48.499891+00', '2020-12-24 10:28:16.955154+00', 10632, 1, NULL, 'ace', '1–::

  1c set | 1c touch NH into long cast to 2pl (2c up on [5-6] | 1c set advancing to DT position

9–::

  Set as in DTr | All set advancing and right about to inverted DTr (2c+3c are BtoB) ; All set as in DTr | All set to finish in sideline, 1c facing 3cnr

17–::

  3cnrs turn RH ½ and twirl R to change places _while{4}_ 1c cast to R round 3cnr position to meet in middle and swivel R to face 2cnr ; repeat with 2cnrs, finish facing 1cnr

25–::

  1c+1cnrs ½ diag Reel4 and pass Rsh ; repeat with 2cnrs to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14175, '2021-07-31 04:48:44.576793+00', '2021-10-05 11:00:43.181408+00', 20421, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; set | pass P RSh to 2plx and face out (2,1x,3)

9--::

  Reels3 on sides, 1c RSh to 1cnrs. 1c face in (2,1x,3)

17--::

  1c ½ Fig8 down round 3c ; 1c dance to top | cast off (2,1,3)

25--::

  2c+1c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13591, '2021-01-27 17:41:24.417818+00', '2021-05-15 09:29:10.296026+00', 6416, 1, 202, 'ace', '1--::

  1c cast off (2c up) | 1c ½ Fig8 L round 2cnrs | 1c turn LH to face 1cnrs

9--::

  Reels3 across, 1c LSh to 1cnrs. On [15-16] 1c pass P LSh to face 2cnrs

17--::

  Reel4 on 2diag (2,1x,3)

25--::

  Reels3 on sides {6}, RSh to 2cnrs | 1c cross RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2584, '2012-01-22 19:29:48.617105+00', '2021-03-13 16:19:29.348529+00', 3542, 1, NULL, 'ace', '1–::

  1c+4c set | lead in to meet (2c+3c step to own end) ; 1c+4c RHA

9–::

  2c+3c repeat [1-8] (1c+4c stepping) to (1,2,3,4)

17–::

  1c+4c set | ½ Fig8 round nearest couple ; 2c+3c step out _while_ 1c+4c dance in NHJ to face nearest corner.

25–::

  Double H&G setting (6 bars) | 1M+4W set advancing in and L _while_ 1W+4M turn LH ½ to meet P for

33–::

  1c+4c Poussette. (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2606, '2012-01-22 19:29:49.687213+00', '2017-07-07 13:33:35.886088+00', 3608, 1, NULL, 'ace', '1–::

  1c+2c+3c set | ½Circle6 L ; repeat

9–::

  1c+2c Reel4 across ; to start 1W & 2M pass Lsh, finish (2,1,3)

17–::

  1c lead down {3} and up {3}, to 2plx facing 2c | 2c to 1c Set

25–::

  Opposing Reels3{6} on sidelines (1c Rsh to 2cnr), at end 1c cross to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12430, '2019-12-05 01:32:31.015102+00', '2023-02-04 01:23:04.639262+00', 17527, 3, NULL, 'ace', '1-8::
    1s lead down & back to face 1st corners (2s step up 3-4)
9-16::
    1s dance "Hello-Goodbye" setting ending with petronella turn to 2nd
    place own side
17-28::
    2s+1s+3s dance R&L for 3 couples
29-32::
    1s turn RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7997, '2013-08-21 08:31:54.212288+00', '2023-02-04 01:23:15.548505+00', 9908, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 2s & 4s cross to  opp sides

1-8::
    All Ladies set advancing & Bal-in-Line (like Wild Geese) then dance
    RSh round partners & back to places
9-16::
    All dance reels of 4 on sides
17-24::
    1s turn RH (4 bars), 1s+2s dance 1/2 R&L
25-32::
    1s+3s dance 1/2 R&L then 1s+4s dance 1/2 R&L.  2 (3) 4 (1)', 0);
INSERT INTO 'dancecrib' VALUES (2470, '2012-01-22 19:29:40.722885+00', '2021-05-26 09:44:43.969405+00', 3093, 1, NULL, 'ace', '1–::

  All C circle6 and back (1,2,3)

9–::

  2c (=dancing couple) turn 1cnr LH ; turn 4cnr RH and finish in middle facing up, (1W & 3M face out)

17–::

  1c+2c+3c mirror Reels3 on the sides, 2c in & up to start, at end 2c dance to top and 1c cast to 2pl, all C facing up in middle for

25–::

  2c+1c+3c Allemande (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (1835, '2012-01-22 19:29:04.961067+00', '2017-07-07 13:10:47.608613+00', 794, 1, NULL, 'ace', '1–::

  1c cast off 2 places, lead up to the top ; cross over and cast off one place (2c up), meet NHJ facing 2W

9–::

  1c set to 2W, turn inwards, set to 3M ; veer left and set to 3W, turn inwards, set to 2M, finish facing 1cnrs (1M pulls back Rsh).

17–::

  1c turn corner, P ; corner, P finishing (2,1x,3)

25–::

  All A&R ; 1c turn BH 1½ times (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2377, '2012-01-22 19:29:34.28933+00', '2020-12-06 18:36:05.962629+00', 2674, 1, NULL, 'ace', '1–::

  Crossover Mirror Reels3 (1x,2,3), 2c facing out

9–::

  1c turn RH ½ | 1c lead down _while_ 2c cast up ; 1W+1M following cast R round 3M and cross to own side

17–::

  1c+3W RHA, 1c pivot R ; 1c (1M leading)+3M RHA, 1c takes promhold

25–::

  1c+3M+2W Reel3 (Lsh to 3M), but on [30] 1M casts off round 2M as 1W continues the reel to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1690, '2012-01-22 19:28:56.808331+00', '2017-11-14 00:56:30.08265+00', 14356, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; ½ Fig8 R, Lsh to 1cnr  _while_{4}   2c+3c set and cross RH (2x,1x,3x)

9–::

  1c turn LH 1¾ to face 4cnr (1cnrpers) ; turn cnr RH ½ | these cnrs turn LH 1¼ to face P on 1diag

17–::

  2c+3c turn P RH ½ | 2W+3M turn LH 1¼ to face 1c (on 2diag) ; centres turn cnr ½ RH | 1c turn LH to finish in lines across, 2M+1W+3M in 1pl facing 2W+1M+3W in 3pl

25–::

  All set | opposing Reels3{6} across, 1c Rsh to 1cnr (1cnrpers), 2c+3c finish with loops

33–::

  Opposing Reels3{6} on the sides, 1c Lsh to 2cnr, finish in the same lines across

41–::

  All Circle6 L ¾ ; 1c turn RH 1½ (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (8130, '2013-12-04 10:53:07.525058+00', '2018-10-06 13:01:48.19773+00', 13153, 1, NULL, 'ace', '1–::

  1c+5c Parallel Figs8 on own side, start Rsh to next person

9–::

  1c+5c set to P | cast inwards (2c+4c to end) ; 1c+5c ½ Fig8 through end couple (2,1x,3,5x,4)

17–::

  All M dance across to P | turn P BH 1½ | dance back to starting place (2,1x,3,5x,4)

25–::

  1c cross RH | change place LH with 3c on side ; change place RH on side with 5c | 5c cross RH (2,3,5,1,4)', 3);
INSERT INTO 'dancecrib' VALUES (2593, '2012-01-22 19:29:49.03803+00', '2020-12-08 22:26:37.622078+00', 3570, 1, NULL, 'ace', '1–::

  1c lead down {3} and up, cross and cast off (2c up) (2,1x,3)

9–::

  2c lead down the middle and up

17–::

  2c+1c Reel4 across, the W pass Lsh in the middle _while_ M stand still, the M cross back on [23-24] (2,1x,3)

25–::

  2c+1c R&L, 1c finish facing 1cnr

33–::

  1c set to and turn corners

41–::

  Opposing Reels3{6} on the sides | 1c cross (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14174, '2021-07-30 03:57:47.933047+00', '2021-07-30 04:15:09.82428+00', 17571, 1, 202, 'ace', '1--::
  1c & 3c lead down (2c & 4c up) ; lead up. 1c BtoB between 2c & 3c between 4c BtoB face own sides
9--::
  Parallel Reels4 across. On [15-16] 1c & 3c turn P LH to finish as on [9] facing up (2,1,4,3)
17--::
  1c cast to 4pl _while{6}_ 3c dance to top and cast to 2pl (to 2,3,4,1) | all set (2,3,4,1)
25--::
  All turn P RH ; all set twice (2,3,4,1)

*Deviser''s note* : Although this is a 4 couple dance, it could be danced in a 3 couple set with just the 1st couple dancing down the middle, and the 1st and 2nd couples dancing the reel. 1st couple would cast to 3rd place and a new 1st couple would start the next time through.', 2);
INSERT INTO 'dancecrib' VALUES (10139, '2017-09-22 18:56:43.843835+00', '2017-11-13 23:58:34.208933+00', 17948, 1, NULL, 'ace', '1--::

  All Circle8 and back

9--::

  All S&Link with P ; turn P RH 1½ and W face out

17--::

  All Schiehallion {2} | Turn new P RH ½ ; repeat (each time M dance through the middle, the W do not progress) 

25--::

  All M LHA as all W chase outside clw ½ to meet P ; Turn P ¾ RH | set to P (3,4,1,2)

33--::

  All ½ Reel4 around the circle (M cclw,W clw) ; turn last person passed RH (M face out, W in); 

41--::

  Repeat 17-24, with W going through the middle, finish in P’s place facing P

49--::

  Set to P | change places with Baratte (start RH), finish in promhold facing cclw

57--::

  All promenade once cclw (4,1,2,3) (last time through W finish in middle for curtsey)

', 5);
INSERT INTO 'dancecrib' VALUES (2596, '2012-01-22 19:29:49.158433+00', '2014-04-30 23:23:57.610161+00', 3577, 1, NULL, 'ace', '1–::
  1c lead down the middle and up {6}, cast off (2c up)
9–::
  2c repeat (1,2,3)
17–::
  2c (1c following) cross down into a Fig8 round 3c, to finish (2,1,3)
25–::
  1c+3c R&L, finish facing 1cnrs (1M has no polite turn)
33–::
  1c set to 1cnr, to 2cnr, pulling Rsh back to sideline facing P ; turn RH 1½ to (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (2598, '2012-01-22 19:29:49.238994+00', '2014-04-30 23:23:57.640531+00', 3585, 1, NULL, 'ace', '1–::
  1c+2W (1c Rsh) diagonal Reel3
9–::
  1c+2M (1c Lsh) diagonal Reel3
17–::
  1c lead down {3}, up {3}| cast off (2c up)
25–::
  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (2601, '2012-01-22 19:29:49.396976+00', '2015-09-29 06:12:54.160315+00', 3594, 1, NULL, 'ace', '1–::

  1c lead down the middle and up, 2c step in on bar 8 for

9–::

  1c+2c Allemande (2,1)

17–::

  1c Fig8 round 2c

25–::

  2c+1c circle4 and back', 3);
INSERT INTO 'dancecrib' VALUES (2597, '2012-01-22 19:29:49.199265+00', '2020-12-08 22:32:36.676175+00', 3584, 1, NULL, 'ace', '1–::

  1c cross RH, cast off (2c up) ; ½fig8 between 3c (2,1,3)

9–::

  1c set adv to 1cnrs | turn 1cnr BH (in SkipChange), finish 1W between 2c facing 1M between 3c ; Repeat with 2cnrs, finish 1W between 3c all facing down and 1M between 2c all facing up.

17–::

  In lines across 1M+2c lead up _while{2}_ 1W+3c lead down, and all turn about | advance in threes to meet ; All turn dancer opp BH (PdB ; but SkCh is allowed), 1c turning 1¼ (2,1x,3)

25–::

  2c+1c+3c A&R ; 1c turn BH 1½ (in skip change) to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1915, '2012-01-22 19:29:09.63157+00', '2015-03-26 00:21:18.977191+00', 1075, 1, NULL, 'ace', '{{explanation}}

On 2nd chord 1c change sides (1x,2).



1–::

  1M+2M turn RH ¾ to P''s place and face out _while_{2} 1W casts down, 2W up | 1c (on M side) + 2c (W side) turn P LH {4} | 1W+2W turn RH _while_{2} 1M cast down and 2M up to (2x,1)

9–::

  2c+1c ½ R&L (to 1x,2) ; 1c+2c turn P RH 1½ to finish RHJ, 1c facing up, 2c down

17–::

  1c+2c singly dance Allemande for {6} to (2x,1) retaining RHJ | 1c+2c ¾ RHA, both W pivot inwards

25–::

  2M+1W (start up) & 1M+2W (start down) singly dance Allemande for {6}, retaining RHJ | All ¼ RHA, W turning inwards, to (2,1x)



{{explanation}}

Couples reaching top or bottom change sides while waiting.  

When all 4 couples are dancing, the middle allemandes interlink', 3);
INSERT INTO 'dancecrib' VALUES (10738, '2018-05-03 15:40:53.849587+00', '2021-05-15 11:30:10.476437+00', 3787, 1, 202, 'ace', '1--::

  1c+2c RHA ; 1c ½ Fig8 on sidelines, start Rsh to 2c (2c+3c up on [7-8]) (2,3,1)

9--::

  3c+1c LHA ; 1c ½ Fig8 on sidelines, start Lsh to 3c (2c+3c down on [15-16]) (1,2,3)

17--::

  1W followed by 1M Fig8 round 2c, start behind 2W. On [23-24] 1c dance to top for

25--::

  1c+2c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3607, '2012-07-21 11:45:45.123165+00', '2020-09-08 17:06:51.19679+00', 9294, 1, NULL, 'ace', '1–::

  1c cross RH and face out, set swiveling R to face in ; repeat _while_ 2c wait{2} cross, set swiveling R, cross _while_ 3c wait {4}, cross, set swiveling R (1,2,3x)

9–::

  Rsh Reels3 on the sides, 2c start out and R, 1c cross down and 3c cross up,   2c finish facing out (1x,2,3)

17–::

  1M+2W & 1W+2M turn 1½ EH, 1c crossing to 2pl ; 1M+3M & 1W+3W turn EH (same hand for 1c) to (2,1,3)

25–::

  Circle6 and back



{{explanation}}

Can be danced in a 3c set by making 1½ turn on bars 21-24 for the progression', 2);
INSERT INTO 'dancecrib' VALUES (13856, '2021-03-28 23:53:50.092178+00', '2021-08-24 18:38:17.361433+00', 20286, 1, 202, 'ace', '1--::
  1c+2c set | cross RH and face up/down (to 1x,2x) ; all set | change places RH on Wside, LH on Mside (2x,1x)
9--::
  1c ½ Fig8 up round 2c ; 2c ½ Fig8 down round 1c (2,1)
17--::
  2c (+1c who dance up to follow) lead down ; 1c lead up | cast off to 2pl centre _while{4}_ 2c following 1c lead up to 1pl centre (2,1)
25--::
  2C Promenade (2,1)', 5);
INSERT INTO 'dancecrib' VALUES (10257, '2017-11-14 08:51:20.32916+00', '2017-11-14 08:51:20.32916+00', 18073, 2, 1, 'ace', '1–::
  1M dances RS round 2M and crosses down to 2L''s place (2L up on 5–6)
  _while{6}_ 1L sets and dances ½ Fig8 round 2M to 1M''s place ; 
  1c set adv to fin facing 2M in prom hold
9–12::
  1c (in prom hold)+2c dance ½ diag Reel3 (RS to 2M)
  [1c fin in centre facing each other]
13–16::
  1c turn RH to places _while{2}_  2M dances to 2L''s place ; 1c set
17–::
  Ladies'' Chain
25–::
  1L+2L change places RH ; 1M+2M change places RH ; 1c cross RH ; all set', 3);
INSERT INTO 'dancecrib' VALUES (2602, '2012-01-22 19:29:49.438605+00', '2016-11-15 15:52:29.405532+00', 3595, 1, NULL, 'ace', '1–::

  1c+2c+3c advance {1} and retire {1} | repeat ; ½ G-Chain, 1c starting across

9–::

  Repeat [1-8], continuing the G-Chain (L,R,L)  (1,2,3)

17–::

  1c lead down {3}, up {3}, and cast off own side

25–::

  2c+1c+3c circle6 and back.', 3);
INSERT INTO 'dancecrib' VALUES (2604, '2012-01-22 19:29:49.517268+00', '2016-11-15 15:53:22.35915+00', 3607, 1, NULL, 'ace', '1–::

  1c+2c+3c set, cross RH ; set, turn RH ½ to

9–::

  1c+2c+3c Promenade

17–::

  1c set, cast off one (2c up) ; 1c dance BtoB

25–::

  2c+1c+3c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (9530, '2016-12-16 20:46:35.051448+00', '2016-12-17 15:36:47.80103+00', 17484, 1, NULL, 'ace', '1--::

  1c set | lead down (2c up) ; 1W dance under joined arms to finish on midline facing up, 1M behind 1W | dance up to between 2c

9--::

  1c+2c Bow Tie Reel (Mascherl Reel): 1c+2c (1W & 1M start towards opposite sides, 2c start down) follow fig8 track round 1pl positions, finish 2c in 1pl and 1c facing 1cnr

17--::

  1c+1cnrs turn RH | 1c pass Rsh (corners dance for 4 bars) ; repeat with 2cnrs to (2,1,3)

25--::

  All (including the non-dancing couple) Circle8 and back (2,1,3)

 

', 3);
INSERT INTO 'dancecrib' VALUES (2052, '2012-01-22 19:29:17.198166+00', '2016-06-03 12:49:47.928699+00', 1544, 1, NULL, 'ace', '1–::

  1c set to 3c | both cast ¼ clw into the middle and face across ; 1c+3c cross RH | chase clw to P''s place facing clw

9–::

  1c+2W & 3c+4W RHA (1c+3c, W leading, pass through own place into) ; 1c+4M & 3c+2M LHA , finish again in P''s place

17–::

  1c & 3c (W leading M) Rsh Reels3 with the same two corners (1c+2W+4M, 3c+4W+2M), 1c+3c face out in P''s place, 2c+4c face in and all take promhold

25–::

  1c+3c chase clw half round, _while_{4} 2c+4c A&R ; 1c & 3c pass Rsh to own place

33-64::

  2c+4c repeat [1-32]

65–::

  All set to P | change places RH (M face out) ; all W ½RHA and dance out to W place ¾ clw from the start _while_{4}   all M dance one place clw, to meet »opposite partner«

73–::

  Repeat [65-72] with new partner (to 3,4,1,2)

81–::

  Half Schiehallion Reel (to own places)

89–::

  All circle8 and back.



{{explanation}}

Note by Drewry: On [65-68] and [69-72] the W use RH twice.  This can be avoided by substituting: [65-68] »All set to P | change places passing Rsh, (M face out)«', 3);
INSERT INTO 'dancecrib' VALUES (12768, '2020-04-17 00:45:07.548419+00', '2020-04-17 00:45:24.770299+00', 19489, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; 1c Petronella Turn into lines3 across ; 1c set

9--::

  1c cross RH | dance RSh round 2cnrs (to 2,1x,3) ; ½ Reels3 on sides, 1c LSh to 3cnrs (3,1x,2)

17--::

  1c cross RH | dance RSh round 3cnrs[pos] into lines3 across ; ½ Reels3 across, 1c LSh to 2cnrs[pos]. 1c face 3cnrs[pos]

25--::

  ½ Reel4 on 1diag, pass LSh to face 4cnrs[pos] ; ½ Reel4 on 2diag (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2616, '2012-01-22 19:29:50.131775+00', '2017-07-07 12:39:09.654904+00', 3623, 1, NULL, 'ace', '1–::

  1c+2c RHA {3}, LHA back {3}| 1c cast off as 2c dance up (2,1,3)

9–::

  1c lead up, crossing to finish BtoB facing 2c | 1c+2c set ; 1c dance down to between 3c, 1c+3c set, 1c finish facing 1 cnr

17–::

  1c turn 1cnrs RH, finish between end cpls | 1c set , advancing towards 2cnr ; 1c turn 2cnr RH to sideline, 1c set across

25–::

  Reels3{6} on the sides (Lsh to 1cnrs) | 1c cross RH.', 3);
INSERT INTO 'dancecrib' VALUES (9250, '2016-06-16 22:42:29.085072+00', '2023-02-04 01:23:04.656866+00', 16854, 3, NULL, 'ace', '1-8::
    1s set, cross down RH, dance down behind 3s, cross back to 2nd place
    own sides (2s step up 5-6)
9-16::
    2s+1s+3s dance mirror (reflection) reels of 3 on sides (1s out/up to
    start).  1s NHJ stay in middle for ...
17-24::
    2s+1s dance RH across, 1s+3s dance LH across.  1s end in middle, 1L
    facing up, 1M facing down
25-32::
    1s dance out of ends, cast to Right into 2nd place own sides.  All
    turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (11759, '2019-04-01 21:56:41.803999+00', '2019-04-01 23:21:45.089422+00', 14474, 1, NULL, 'ace', '*start (1,2,3x,4x)*  

*This dance is centro-symmetric.  The four corner positions are in 1pl and 4pl.     

During [9-24] the repeating 4-bar figure is : "2 dancers arrive in tandem at a corner, dance RHA 3 with the corner, the leading arriving dancer stays in the corner, and the other two dance on to the next corner cclw in the set."  This occurs simultaneously at both ends of alternately 2nd and 1st diagonal, 4 times in all.*    

1--::

  All set | 1c/4c (each in tandem, W leading) cast clw 3 places and up/down the middle to finish between top/bottom couple (2c+3c step to end on [7-8])

9--::

  Figure on 2diag. ; Figure on 1diag.

17--::

  Figure on 2diag. ; Figure on 1diag. Now 1c/4c, W leading, are in the middle on M/W side dancing down/up and 2c/3c are in 4plx/1pl.

25--::

  1c+4c ½ LHA | 1c/4c (W leading) cast Lsh round 1cnr and cross to 2pl/3plx | All set (3,1,4x,2x)

', 3);
INSERT INTO 'dancecrib' VALUES (2553, '2012-01-22 19:29:47.397204+00', '2017-07-07 13:18:10.912998+00', 3412, 1, NULL, 'ace', '1–::

  1c set | cast off 2 (2c+3c up) ; set | cast up 2 (2c+3c down)

9–::

  1c lead down between 2c, cross and cast behind 3c ; dance to top, cast off to face 1cnr (2c up)

17–::

  1c set to and turn cnrs, end with long swivel to face 1cnr

25–::

  1W+2c & 1M+3c Rsh Reels3 across

33–::

  Reels3 on own side, Rsh to 3cnr (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2618, '2012-01-22 19:29:50.203687+00', '2016-08-14 21:33:08.988116+00', 10563, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; ½ Fig8 L (Rsh round 4cnr) to face 1cnr

9–::

  ½ diag Reel4 with 1cnrs, 1c on meeting swivel ½R to face 4cnr ; repeat with 4cnrs, end facing 3cnr pos

17–::

  Repeat with 3cnrs, end facing 2cnr pos ; repeat with 2cnrs, 1c turn RH ½ flowing into

25–::

  2c+3c chase clw once round _while{8}_ 1c turn RH 1½ to 2plx ; and join the chase (2,1,3)

33–::

  Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2622, '2012-01-22 19:29:50.408701+00', '2014-08-24 19:54:55.191438+00', 3636, 1, NULL, 'ace', '{{explanation}}

On 2nd chord 3c+4c cross to (1,2,3x,4x)



1–::

  2c+3c RHA ; 2W & 3W with P following cast L round 1W & 4W »=2cnrs«

9–::

  1M+2c & 3c+4M RHA ; 1W+2c & 3c+4W LHA

17–::

  2c (on M side) & 3c (on W side) (still in tandem, W leading) opposing Reels3 on sidelines, Lsh to 4W/1W “=4cnr”, to 2,1,4x,3x, middle Cs facing each other up/dn

25–::

  1c+4c set | cross RH on side ; set to P | cross RH (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (2607, '2012-01-22 19:29:49.729286+00', '2016-11-15 15:54:01.732823+00', 3609, 1, NULL, 'ace', '1–::

  1c+2c+3c circle6 and back

9–::

  1c+2c+3c G-Chain (1,2,3)

17–::

  1c cross RH, cast off one (2c up) ; cross LH, cast off and lead up to 1cnrs

25–::

  1c turn corner, P, corner, P to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2605, '2012-01-22 19:29:49.557851+00', '2017-02-13 17:27:06.424442+00', 10089, 1, NULL, 'ace', '1–::

  1c+2c+3c Inveran reels (1c cross from top and from bottom) (1,2,3)

9–::

  1c+3c set | turn BH just less than once and open NHJ forming arch, 1c facing 2W and 3c facing 2M ; arches advance as 2c pass under, all now form an approximate circle | all swivel ¼ R and chase clw round circle (2c to just outside 2pl)

17–::

  3c+2c+1c circle6 and back (to 3,2,1)

25–::

  3M (3W follows whole way) cast off | cross up (2M up) ; cast off round 2W | cross to 2pl (2W up) (2,3,1)



{{explanation}}

Also called Emma''s Delight', 2);
INSERT INTO 'dancecrib' VALUES (13944, '2021-04-09 07:18:42.763293+00', '2021-04-09 07:33:04.46122+00', 15673, 1, 202, 'ace', '1--::

  Interlocking Reels4. All face P (1,2,3,4)

9--::

  All M LHA ¾ _while{4}_ all W chase 1pl clw  (to 4,1,2,3) | all turn P RH ; All W RHA ¾ _while{4}_ all M chase 1pl clw  (to 3,4,1,2) | all turn P RH 1¼. All W face out (3,4,1,2)

17--::

  8 bars of Schiehallion Reels (1,2,3,4)

25--::

  Double M-Chain. All W face out

33--::

  All W Fig8 round P and cnr, starting behind P

41--::

  All M Fig8 round P and cnr, starting in front of P

49--::

  Double M-Chain. All W face out

57--::

  8 bars of Schiehallion Reels (3,4,1,2)

65--::

  Repeat [9-16] (1,2,3,4)

73--::

  Repeat [1-8] (1,2,3,4)', 2);
INSERT INTO 'dancecrib' VALUES (2509, '2012-01-22 19:29:45.617831+00', '2021-02-21 19:38:19.873053+00', 9580, 1, NULL, 'ace', '1–::

  1c (2c dance up and follows) lead down ; 2c followed by 1c lead up (2,1)

9–::

  1c (cross up) Fig8 round 2c

17–::

  2c (cross down) Fig8 round 1c

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (2626, '2012-01-22 19:29:50.566529+00', '2014-04-30 23:23:58.281972+00', 7441, 1, NULL, 'ace', '1–::
  1c long cast (2c up) ; all turn RH and face up for
9–::
  2c+1c+3c promenade (2,1,3)
17–::
  1c Fig8 on own side, starting to the R
25–::
  Teapots R and L (RHA with end couple on the R ; LHA with end couple on the L)', 3);
INSERT INTO 'dancecrib' VALUES (2627, '2012-01-22 19:29:50.606844+00', '2014-04-30 23:23:58.296948+00', 13850, 1, NULL, 'ace', '1–::
  Mirror Reels4 on sides (M Rsh, W Lsh)
9–::
  1c+3c lead down the middle ; and up under arches by 2c+4c (make arches a bit below 2pl/4pl, on [16] all dance out diagonally)
17–::
  All set | set advancing ; set twice
25–::
  4c Poussette (2,3,4,1)
33–::
  2c+3c & 4c+1c R&L
41–::
  Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (8254, '2014-04-24 11:29:12.155638+00', '2014-04-30 23:23:58.31205+00', 8571, 1, NULL, 'ace', '1–::
  1c Turn RH ½ and hold RH | lead down (2c up), cross between 3c and cast up | set to P (2,1,3)
9–::
  1c+1cnr A&R {1+1} | 1c+2cnr repeat ; All dance BtoB (2,1,3)
17–::
  1c cross up as 2c cast off | 1c turn 2c EH ½ ; 1c cross down as 3c cast up| 1c turn 3c EH ½ (2,1,3)
25–::
  Reels3{6} across, Lsh to 1cnr | 1c turn 3c EH ½ (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2494, '2012-01-22 19:29:44.992371+00', '2014-08-25 07:00:35.445051+00', 3197, 1, NULL, 'ace', '1–::

  1c+2c set | 1c cast to 2pl, 2c dance up to top ; 1c+3c repeat (2,3,1)

9–::

  1c turn RH, spirally slightly upwards ; lead to top | cast off to face 1cnr (3c down)

17-28::

  Dance to each corner and set (centre and cnr change place Rsh and these cnrs pass Rsh in the middle to face cnr to the R _while{12}_ other cnrs set | repeat 5 times) at the end the cnrs have crossed diagonally and in the middle 1M (above) faces 1W (below)

29-32::

  1c pass Rsh and dance out the end (W up, M down) and cast R to 2pl _while{4}_ 2c+3c set advancing | ½ RHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1585, '2012-01-20 13:06:12.779354+00', '2016-06-03 13:34:52.597674+00', 13626, 2, 1, 'ace', ' 1-8:: 1C set | 1C ½ turn RH to face down in prom hold ; 1C dance down and cast up

     around 3C to 2pl 

 9-16:: Mirror reels of 3 on opposite sides, 1C up/in, 2C down/out, 3C up/out, 1C end facing

     1st corners

17-20:: 1C set to 1st corners _while_ 2nd corners set | 1C set turning right about

     _while_ corners chase ¼ clockwise ; R from new places

21-24:: 1C ½ diag reels of 4 w/1st corners (RS to 3rd corner person to begin) and

     pass RS

25-32:: 1C ½ diag reels of 4 w/2nd corners (RS to 4th corner person to begin) and

     pass RS to 2nd place on own sides', 5);
INSERT INTO 'dancecrib' VALUES (2629, '2012-01-22 19:29:50.687136+00', '2017-07-07 12:58:33.3386+00', 3656, 1, NULL, 'ace', '1–::

  1c+2c ½ Circle4 L | set ; repeat R

9–::

  1c, 2c+3c following, cast off to 3pl, cross, the W passing above the M, and dance up to (1x,2x,3x)

17–::

  Repeat [9-16] to places, (again W cross above M)

25–::

  1c+2c Poussette

33–::

  2c+1c R&L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2625, '2012-01-22 19:29:50.527024+00', '2016-11-15 15:56:29.2655+00', 3638, 1, NULL, 'ace', '1–::

  1c cast off behind own lines ; and cast back

9–::

  1c lead down {3}, up {3} | and cast (2c up) (2,1,3)

17–::

  All Circle6 and back, 1c face 1cnr

25–::

  Set 6 bars of »H&G« | 1c clap and Petronella to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2631, '2012-01-22 19:29:50.766684+00', '2020-08-31 14:32:58.358759+00', 3669, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; ½Fig8 round 2c (2,1,3)

9–::

  All lead down the middle and up, finish in centre

17–::

  2c+1c+3c promenade (2,1,3)

25–::

  Teapots R and L (2c+1W & 1M+3c RHA ; LHA at other end)', 3);
INSERT INTO 'dancecrib' VALUES (10408, '2018-01-30 13:20:16.203996+00', '2018-01-30 13:40:38.794224+00', 8923, 1, NULL, 'ace', ' 

 

1--::

  1c cross RH | cast off (2c up) ; 1c turn RH as 2c+3c ½ R&L (3x,1x,2x)

9--::

  “Snowball chase”: 3M crosses above P, chases cclw round to starting place _while{8}_ 1M waits{2} and does the same _while{8}_ 2M waits{4} and does the same (3x,1x,2x)

17--::

  2W crosses below P, chases cclw round to starting place _while{8}_ 1W waits{2} and does the same _while{8}_ 3W waits{4} and does the same (3x,1x,2x)

25--::

  1c Petronella turn | set ; repeat _while{8}_ 3c+2c set | Petronella turn ; repeat (3,1,2)

 

 

', 3);
INSERT INTO 'dancecrib' VALUES (10644, '2018-04-17 14:09:05.141246+00', '2018-04-18 15:41:16.789828+00', 13922, 1, 202, 'ace', '1--::

  2c cross down RH between 3c, cast to 2plx ; cross up RH to 1pl (1c down), and face out | 2c+1c turn EH, 2c face out at end (2,1,3)

9--::

  Mirror Reels3 on sidelines, 1c start crossing down RH to 3plx, on [13-14], 1c cross up RH to 1pl (2,1,3)

17--::

  2c+1c+3c set | 3C Petronella turn into facing lines of 3 across ; repeat [17-20] (3x,1x,2x)

25--::

  All turn P RH | chase clw ½ | set (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (10642, '2018-04-17 10:12:25.880225+00', '2018-04-18 15:41:47.618501+00', 13925, 1, 202, 'ace', '1--::

  1c turn P BH and face down NHJ | dance down {2} (2c up). On [4] change side and face up, W passing under joined arms ; 1c dance up {2} to between 2c BtoB facing opposite sides | all set

9--::

  Reel4 across, finishing as before

17--::

  All set, 1c finish facing up | 1c touching NH briefly cast to 2plx ; 1c ½ Fig8 up round 2c (2,1,3)

25--::

  2c+1c set | turn P RH, retaining RH ; RHA', 4);
INSERT INTO 'dancecrib' VALUES (14395, '2021-10-18 22:53:48.765227+00', '2021-10-26 15:03:49.909453+00', 13796, 1, 1645, 'ace', '1--::

  1c cross down into mirror Reels3 on opposite sides (1x,2,3)

9--::

  1c cross down into mirror Reels3 on own sides, but at the end 1c cross down again & face out as 2c dance up (2,1x,3)

17--::

  1c cast RSh round 1cnr & loop 1W/1M through 2c/3c to be LSh to P on centre line ; continue loop back out through 2c/3c & cast RSh round 4cnr (2,1,3)

25--::

  1c dance BtoB ; dance up through 2c | cast off (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2620, '2012-01-22 19:29:50.328999+00', '2020-09-06 10:05:29.8166+00', 8131, 1, NULL, 'ace', '1–::

  1c solo 6 bars of Allemande, dancing in on [1] (2c up on [3-4], 1c turn ¾ LH to finish facing 3cnr

9–::

  1c ½diag Reel4 with 3cnrs, at end 1c meet and swivel R to face 2cnr ; repeat with 2cnrs, and pass Rsh (to 3x,1,2x)

17–::

  1c set, turn ¾ RH ; 1M+2c & 1W+3c LHA to (3x,1x,2x)

25–::

  All set | all advance {1} swivel R and return to sideline {1} ; all chase clw to own sides (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2414, '2012-01-22 19:29:36.570095+00', '2020-12-06 18:40:10.266538+00', 2822, 1, NULL, 'ace', '1–::

  1c+2c Espagnole, 1c finishing facing 1cnr

9–::

  1c turn 1cnr RH, pass Rsh ; turn 3cnr LH, pass Lsh (cnrs dance for {4})

17–::

  Turn 2cnr RH, pass Rsh ; turn 4cnr LH, pass Lsh to 2plx side by side facing down

25–::

  Lead LHJ between 3c, cross and cast to 2pl ; All C turn RH



{{explanation}}

Espagnole: both W lead RHJ to M side, cross and cast back to exchanged places _while{4}_ Men cross to W side, lead RHJ back to M side and cross to exchanged places ; all turn P EH (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (14703, '2022-03-16 04:24:09.588343+00', '2022-03-16 04:24:46.767051+00', 16734, 1, 202, 'ace', '1--::

  1c+2c ½ RHA | set ; 1c cross RH | 2W+1M & 2M+1W turn ¾ LH into line4 across

9--::

  The Targe (2,1x)

17--::

  2c+1c chase ½ ; 1c ½ Fig8 down round 2c (1x,2x)

25--::

  1c+2c ½ R&L ; 2c & 1c turn P RH (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2032, '2012-01-22 19:29:16.098916+00', '2016-06-03 13:37:23.413624+00', 1495, 1, NULL, 'ace', '1–::

  All C Petronella Turn and set ; turn ¾ RH and set (to 1x,2x,3x)

9–::

  Mirror-cross-over Reels3 on the sides (all C''s cross down from top, 1c begins) (to 1,2,3)

17–::

  1c mirror Fig8 round 2c&3c, starting in (join NH when meeting) (to 1,2,3)

25–::

  Progressive (non-crossing) G-Chain: top C full turn RH _while_{2} sides change RH | bottom C full turn LH _while_{2} sides change LH ; repeat (finish: 2-3-1)', 3);
INSERT INTO 'dancecrib' VALUES (2643, '2012-01-22 19:29:51.245003+00', '2020-12-08 22:59:03.244937+00', 3710, 1, NULL, 'ace', '{{explanation}}

On 2nd chord step into »Glasgow Highlanders« position :(1c+3c on M side facing 2c+4c on L side, all M on L of W)



1–::

  All turn P RH ¼ {1} into Reels4 across (finishing W at ends facing P in middle)

9–::

  All set to P | W set again _while{2}_ M petronella R to form diamond ; 1c+2c & 3c+4c Circle4 L, to orig. places

17–::

  2c+3c cross over passing opp. Lsh. and cast left (M leading) to other C''s place, turn P ½ LH into Promenade diagonally across back to place passing other C Lsh

25–::

  1c+4c repeat in mirror pattern (cross Rsh, W leading, ½ RH turn, pass Rsh.)

33–::

  Circle8 to L (turning P BH on {5-6}) finish facing P up/dn

41–::

  All set to P and turn RH ½ ; ½ Rsh Reels4 in sideline. (couples have changed places on sideline)', 2);
INSERT INTO 'dancecrib' VALUES (2652, '2012-01-22 19:29:51.648589+00', '2021-02-21 11:18:31.015277+00', 9667, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; turn LH into

9–::

  Teapots R ; and L (2c+1W & 1M+3c RHA ; switch Rsh into LHA, finish BtoB, 1W/1M facing 2c/3c

17–::

  DTr starting »up/down«, finish as on [16]

25–::

  2c+1W & 1M+3c Rsh Reels3{6} across | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12135, '2019-09-02 02:08:04.226399+00', '2019-09-02 14:46:24.738545+00', 19590, 1, 202, 'ace', '1--::
  1c & 3c set | cast off (2c & 4c up) (to 2,1,4,3,5) ; 2c+1W & 1M+4c+3W & 3M+5c RHA. 1c & 3c face 1cnrs
9--::
  1c & 3c set to 1cnrs | dance RSh round P and face 2cnrs ; set to 2cnrs | dance RSh round P. 1c(3c) finish in 2pl(4pl) centre facing down(up)
17--::
  1c+3c R&L up/down _while{8}_ 4c set | cross RH ; repeat. All finish on sides (2,1,4,3,5)
25--::
  1c & 3c set | cast off (4c & 5c up) ; all turn P BH (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (4959, '2013-08-21 08:30:57.953062+00', '2023-02-12 16:12:09.005732+00', 1595, 3, NULL, 'ace', '1-8::

    1s+2s dance 1/2 Diamond Poussette, 1s turn 2H once round _while_ 2s

    turn 2H 1/2 way, 2s+1s wheel round each other 1/2 way

9-16::

    1s+2s dance Ladies'' Chain 1s ending on Men''s side & 2s on Ladies''

    side both with Ladies on Men''s right

17-24::

    1s followed 2s lead down, Men 1/2 turn Lady under right arm & lead

    back up (2s leading)

25-32::

    1s dance 1/2 reels of 3 across (1L+2s & 1M+3s) & 1/2 reel of 3

    across with other couple', 0);
INSERT INTO 'dancecrib' VALUES (2648, '2012-01-22 19:29:51.443162+00', '2014-04-30 23:23:58.724174+00', 3725, 1, NULL, 'ace', '1–::
  1c set | turn BH ; cast off one (2c up), cross RH and face out (2,1x,3)
9–::
  Reels3 on the sides (Rsh to 1cnr), 1c finish facing 1cnrs
17–::
  1c set to and turn corners
25–::
  2c+1c+3c Reels3{6} across (Lsh to 3cnr, i.e. 1M up, 1W down) | 1c cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9889, '2017-05-28 19:37:10.636177+00', '2017-05-31 22:04:56.788346+00', 16728, 1, NULL, 'ace', '1--::

  1c set | long cast to to 2pl (2c up) | set adv to 1cnr

9--::

  1c+1cnrs “Corners pass & twirl”: 1c dance Rsh round 1cnr as 1cnrs turn RH ½ and cast R to exchanged places, 1c pass Rsh ; repeat with 2cnrs, finish in DTr position (3x,1x,2x) 

17--::

  DTr, finish between end cpl facing 2cnr

25--::

  ½ Rsh Reels3 across ; 1c turn RH 1½ (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (10144, '2017-09-24 15:26:34.82728+00', '2017-09-24 15:29:31.887172+00', 4349, 2, 160, 'ace', '1-8::  1s dance down btwn 2s, and cast up to place; 1s+2s RHA.

9-16::  1M 2W change RH, 1W 2M change RH; 2s+1s set, 1/2 turn RH.

17-24::  2s followed by 1s lead down the middle & up - end 2s at top 1s facing up in 2place RHJ.

25-32::  1s lead up crossing, cast to 2pl opposite sides; 1s cross Rh, 2s+1s set.', 3);
INSERT INTO 'dancecrib' VALUES (2653, '2012-01-22 19:29:51.68908+00', '2019-01-10 00:25:49.607307+00', 3743, 1, NULL, 'ace', '1--::

  1c+2c+3c Reels3 on opposite side, all crossing from the top, 2c starts out and up (1x,2x,3x)  

9--::

  1c+2c+3c Reels3 on own sides, all crossing back from the top (1,2,3)

17--::

  1c set, cross RH, cast off (2c up) ; cross down LH between 3c and cast up (2,1,3)

25--::

 1c dance to top and cast off ; all turn P RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3518, '2012-01-22 19:30:28.854704+00', '2020-12-18 20:23:07.125685+00', 7068, 1, NULL, 'ace', '1–::

  1W+2W+3W set twice, circle3 L _while{8}_ the 1M followed by 2M+3M chase round them clw, all to places

9–::

  Repeat bars 1 - 8 the M set and circle3 L _while{8}_ the W dance cclw round the men (1W leading), 1c+2c finish ready for

17–::

  1c+2c Poussette

25–::

  1c+3c R&L



{{explanation}}

Note: for [9-16] neither the instructions nor any notes say that 1W leads cclw, 3W leading clw is also possible', 3);
INSERT INTO 'dancecrib' VALUES (3706, '2013-02-07 23:21:26.843941+00', '2021-05-13 21:08:29.910355+00', 3918, 2, 1, 'ace', '1–::

  1c followed by 2c+3c lead down {3}, lead up through 2c+3c, cross, cast to 2pl {5} _while_ 2c meet,

  lead up through 3c to 1pl _while_ 3c meet and lead up to 3pl

9–::

  Reels3 on sides [1c in/down, 2c cast off, 3c dance out/up; NH where possible] (to 21x3)

17–20::

  2c+1c ½ double fig 8 [1c cross up, 2c cast off]

21–24::

  1c+3c ½ double fig 8 [1c cross down, 3c cast up]

25–28::

  2c+1c+3c cross R (to 213) | 2c+1c+3c set

29–32::

  1m+3c & 1w+2c RH across', 3);
INSERT INTO 'dancecrib' VALUES (2646, '2012-01-22 19:29:51.364472+00', '2021-05-15 20:42:12.238432+00', 3723, 1, NULL, 'ace', '1–::

  1c+2c+3c cross RH {4 bars!} ; cross back (pass through places on [7], into Promenade position on [8]

9–::

  1c+2c+3c Promenade, 1c+2c finishing on the diagonal for

17–::

  1c+2c ½Poussette, 1c finish facing 1cnr ; set to 1cnr & 2cnr, finish facing 1cnr

25–::

  Turn CPCP, finish (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2645, '2012-01-22 19:29:51.32443+00', '2021-05-16 08:51:10.053561+00', 3722, 1, NULL, 'ace', '1–::

  1M+2W turn RH, to places ; 1W+2M repeat

9–::

  1c lead down the middle and up

17–::

  1c+2c Poussette

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (2636, '2012-01-22 19:29:50.964561+00', '2021-05-16 17:35:12.070825+00', 3691, 1, NULL, 'ace', '1–::

  1c+2c RHA, finish 1c facing 2c ; change places on the side RH | 1c+3c change places on the side LH, finish 1c facing 3c (2,3,1)

9–::

  2c+3c+1c Reels3 on the side (1c Lsh to 3c)

17–::

  1c+3c LHA, finish 1c facing 3c ; change places on the side LH | 2c+1c+3c set

25–::

  2c+1c+3c circle6 L for 6 steps, cross R foot over L turning L about ; circle6 R to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2672, '2012-01-22 19:29:52.504883+00', '2021-02-14 12:20:14.020291+00', 9999, 1, NULL, 'ace', '1–::

  1c+4c petronella to midline and set ; All petronella and set repeat (2c+3c to midline, 1c+4c to opp. side)

9–::

  2c+3c turn P RH ¼ into ½ RHA ; 2c+3c cross LH | ½ LHA (1x,2x,3x,4x)

17–::

  Reels4 on the sides, 2c+3c pass Rsh to finish

25–::

  1c cast off on opp. side to 4plx (other Cs up) ; All C set and cross', 3);
INSERT INTO 'dancecrib' VALUES (15441, '2023-02-12 20:48:45.220747+00', '2023-02-12 20:54:58.714638+00', 6286, 1, 1645, 'ace', '1--::
  1c followed by 2c+3c+4 cast off to 4pl, cross LH with P & dance up opp side (1x,2x,3x,4x)
9--::
  1c & 3c &frac12; Fig8 round 2c & 4c ; 2c & 4c &frac12; Fig8 round 1c & 3c (1,2,3,4)
17--::
  1c dance down{1}, separate & slip down{3} closely facing own side _while{4}_ 4M dances up midline ;
  1c curve to meet, join NH & slip up to 1pl facing out _while{4}_ 4M casts to 4pl
25--::
  1c+2c change pl EH | 1c+3c change pl EH ; 1c+4c turn 1&frac12; EH (2,3,4,1)
', 2);
INSERT INTO 'dancecrib' VALUES (2359, '2012-01-22 19:29:33.177224+00', '2016-06-03 13:42:47.801845+00', 13300, 1, NULL, 'ace', '1–::

  1c cast (2c up) | ½Fig8 round 2c | dance round P Lsh to face 1cnr

9–::

  1c+1cnrs ½ diag Reel4, 1c pass Lsh to face 2cnr ; repeat with 2cnrs, finish facing 3cnr position (1cnr person)

17-20::

  1c loop Rsh round 3cnr, meet and pivot R to face M up, W down _while_{4} 1cnrs pass 1c Rsh, turn RH ¾ and dance to 4cnr position _while_{4} 2cnrs set and chase one corner place clw

21-24::

  1c loop Rsh round 2cnr pos to finish in 2plx _while_{4} 1cnr persons (the same as before) pass 1c Rsh, turn RH ¾ and dance to original corner position _while_{4} 2cnrs set and chase one place clw to original corner position (2,1x,3)

25–::

  1c Reels3{6} on the sides, Lsh to 1cnr ; 1c cross RH', 3);
INSERT INTO 'dancecrib' VALUES (2642, '2012-01-22 19:29:51.205256+00', '2014-09-24 21:26:32.823373+00', 3705, 1, NULL, 'ace', '1--::

  1c+2c+3c set | cross RH ; all set| ½ LH turn into promhold facing up

9--::

  1c+2c+3c Promenade, at end 1c casts off to 2pl, finish (2,1,3), 2c and 3c facing out

17--::

  Mirror Reels3 on opposite sides (1c cross down RH to start), at the end 2c+3c make loops and 1c faces 2cnr 

25--::

  1c+2cnrs “Pass & Turn”, 1c make fast RH turn ; 1c+1cnrs “Pass&Turn”, finish (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2796, '2012-01-22 19:29:57.743473+00', '2017-07-07 14:14:37.256127+00', 4431, 1, NULL, 'ace', '1–::

  1W+2W dance NHJ between their P, cast round P to near own side facing P ; 1c+2c turn BH

9–::

  1M+2M repeat

17–::

  1c cross RH | cast ; cross LH | cast off

25–::

  1c lead to top | set ; cast off (2c up) | turn P RH.', 3);
INSERT INTO 'dancecrib' VALUES (2661, '2012-01-22 19:29:52.008868+00', '2017-07-07 14:21:16.593007+00', 3759, 1, NULL, 'ace', '1-16::

  1c+2c full Petronella (2c step up on [1-2] and join in, one place behind 1c. On [15-16] 2c petronella to 2pl).

17–::

  1c lead down the middle and up

25–::

  1c+2c RHA, end on diagonal ; ½Poussette.', 3);
INSERT INTO 'dancecrib' VALUES (2420, '2012-01-22 19:29:37.434191+00', '2020-12-06 18:42:29.405371+00', 2868, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  All A&R {2} twice ; 1c cross RH and cast off _while{4}_ 2c turn RH ½ and lead up crossing to 1pl _while{4}_ 3c+4c turn RH ½ | turn LH ½  (to 2,1x,3,4)

9–::

  G-Chain, crossing at top and bottom to begin

17–::

  1c+3c RHA, LHA

25–::

  2c+1c R&L, 1c finish facing 1cnr



{{title}}

Reel



33–::

  SetH&G

41–::

  Reels3{6} with the corners. 1c cross to 2pl

49–::

  1c+3c advance | join NH with P and retire (1c up, 3c down ; advance | 3c divide and dance to 2pl _while{2}_ 1c dance to 3pl

57–::

  1c+4c repeat (to 2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2651, '2012-01-22 19:29:51.608553+00', '2015-03-13 22:39:32.210618+00', 3735, 1, NULL, 'ace', '1–::

  1M casts off _while{4}_ 2W casts up ; turn RH 1¼ to own places

9–::

  1W casts off _while{4}_ 2M casts up ; turn LH 1¼ to own places

17–::

  1c dance to 3pl (2c+3c up) | set ; ½ Fig8 up around 3c (2,3,1x)

25–::

  1c dance up to 2pl (3c down) and set ; dance ½ Fig8 up around 2c (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2660, '2012-01-22 19:29:51.969109+00', '2015-04-03 18:03:02.939056+00', 14399, 1, NULL, 'ace', '1–::

  1c+2c A&R ; ½RHA | cross RH (2,1,3)

9–::

  2c+1c Set&Rotate finish 1c facing 2c (1,2,3)

17–::

  Grand Chain, 3c crossing to start. (1,2,3)

25–::

  1c+2c Tournee (2,1,3)



{{explanation}}

Repeat from new positions in reel time', 3);
INSERT INTO 'dancecrib' VALUES (1991, '2012-01-22 19:29:13.873882+00', '2015-09-14 22:59:42.671253+00', 13211, 1, NULL, 'ace', '1–::

  1c long cast to meet just above 3c (2c up) (heart shape, touch hands briefly) ; dance NHJ between 3c and cast up through 2pl into the centre

9–::

  Rsh ½ Lead-change reel3 with 2W+3M (1W leading, 1M leads from [11]) ; with NHJ face 2M and set, turning inwards to face 3W and set

17–::

  Rsh ½ Lead-change reel3 with 3W+2M (1W leading, 1M leads from [19]) ; NHJ face 3M (in 1W place) and set, turning inwards to face 2W (in 3M place) and set

25–::

  All couples, dancing as one person with W leading, ½ Rsh Reel3 on the midline ; All turn P BH (1c once, 2c+3c 1½) (to 2,1,3)



{{explanation}}

1c use flirting glances all through.', 2);
INSERT INTO 'dancecrib' VALUES (2650, '2012-01-22 19:29:51.568917+00', '2019-03-15 10:18:06.623579+00', 3732, 1, NULL, 'ace', '{{explanation}}

On 2nd chord, 1W+2M+2W & 3W+4M+4W move one place cclw, to starting position 1c+3c (on M side) facing 2c+4c (on W side)



{{title}}

Strathspey



1–::

  All W diag Rsh Reel4,

9–::

  1W+2W & 3W+4W L-Chain {the M are not mentioned}



{{title}}

Reel



17–::

  1W+4W change places RH | 1W+3M+2M+4W Circle L | all change places RH on side (to M side 4W, 1M, 3W, 3M and W side 2M, 2W, 4M, 1W)

25–::

  1M+4M change places RH | 1M+2W+3W+4M Circle R | All cross RH (to 2c+1c on M side facing 4c+3c on W side)', 3);
INSERT INTO 'dancecrib' VALUES (9888, '2017-05-28 19:13:18.183062+00', '2017-08-26 10:08:28.060741+00', 13554, 1, 202, 'ace', '1--::

 1M set to 2M as 1W set to 2W | turn RH ½, 1M facing out ; 1M closely followed by P cast R round 2M, dance down facing 3W

9--::

 ½ tandem Reel3 in 1diag, 1M Rsh to 3W (1M & 1W loop R singly for lead change, so 1W now leads) ; ½ tandem Reel3 in 2diag, 1W Rsh to 2W (lead change)

17--::

 Continue pattern twice, 1c to 2plx (2,1x,3)

25--::

 1M followed by P cast R round 3W, dance up into lines across, 1M+2c & 1W+3c facing dn/up ; 1c set | Petronella turn to 2pl (2,1,3)



*Deviser''s note: Bars 9-24 are similar to Bars 9-24 of "Pelorus Jack" Book 41.*', 2);
INSERT INTO 'dancecrib' VALUES (11030, '2018-08-22 08:08:54.373366+00', '2022-12-22 18:22:56.446675+00', 12753, 1, 202, 'ace', '1--::

  1c+2c RHA ; LHA (1,2,3)

9--::

  1c dance down {3}, dance up {3} and cast to 2pl (2c up) (2,1,3)

17--::

  Turn CPCP and face 1cnrs

25--::

  Reels3{6} on sidelines, 1c LSh to 1cnrs | 1c cross to 2pl (2,1,3) ', 4);
INSERT INTO 'dancecrib' VALUES (2657, '2012-01-22 19:29:51.85006+00', '2021-02-26 22:20:01.730674+00', 9193, 1, NULL, 'ace', '1–::

  1c cross RH below 2c, cast off, dance to top NHJ and cast (2c up) to (2,1x,3)

9–::

  Mirror Reels3 on sides (1c start in and down), 1c finish facing 2cnr (2c+3c make a final loop) .

17–::

  1c+2cnrs Corners Pass and Turn, 1c turn RH to face 1cnr ; 1c+1cnrs Corners Pass and Turn, 1c crossing to (2,1,3)

25–::

  All circle6 L [3 bars] and, with weight on both feet, swivel round L ; all chase cclw to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14034, '2021-05-15 14:41:53.002828+00', '2021-05-15 14:47:39.999095+00', 6392, 1, 202, 'ace', '1--::

  1c turn RH | cast off (2c up) ; turn LH (2,1)

9--::

  2c+1c RHA ; LHA. 1c & 2c retain LH in centre ready for

17--::

  2C Promenade (2,1)

25--::

  2c+1c R&L (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (10678, '2018-04-22 12:05:48.386582+00', '2021-08-02 09:47:37.97666+00', 9423, 1, 202, 'ace', '_Strathspey_

1--::

  1c & 3c turn P RH ½ | 1c+3c RHA 1¼ into Reel4 across position | all set

9--::

  1c+2c & 3c+4c R&L {4} ; all turn P L, finishing into Reel4 across position

17--::

  All set | 1c+2c & 3c+4c ½ RHA ; 2c+4c LHA ¾ | M pulling Rsh back, 2c & 4c in promhold  dance out to 4pl/1pl (4,1,2,3)

25--::

  All in promhold chase cclw



_Reel_

1--::

  All W advance | set twice, pulling Rsh on [6] | all W dance to places

9--::

  All set to P | turn P RH ; set to cnrs | turn cnrs LH, facing P at end

17--::

  Interlocking Reels3, Rsh to P to start

25--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (2662, '2012-01-22 19:29:52.053262+00', '2021-05-15 18:49:36.265518+00', 3763, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1c lead down {3} and up {3} | cast off to 2pl (2c up)

17–::

  2c+1c turn RH to places ; repeat LH.', 3);
INSERT INTO 'dancecrib' VALUES (2666, '2012-01-22 19:29:52.266579+00', '2021-05-15 18:01:46.129693+00', 3784, 1, NULL, 'ace', '1-16::

  1c+3c set advancing | turn BH, opening to face each other down/up ; Reels3 on the sidelines 2c starting out and up (note: reel bridges two 8-bar phrases) ; 1c+3c turn BH twice, ending on sidelines, 1c facing out

17–::

  1c+3c full DblFig8 around 2c (3c cross up to start)

25–::

  2M+1W set advancing | turn BH to face partner on 1diag ; 1c+2c ½Poussette (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2663, '2012-01-22 19:29:52.092035+00', '2017-05-09 22:19:41.443134+00', 11438, 1, NULL, 'ace', '1–::

  1c turn LH | cast (2c up) ; cross LH and cast L to both face 2W

9–::

  1c set to 2W, turning inwards | set to 3M, and face 3W ; set to 3W, turning inwards | set to 2M, and face 1cnr

17–::

  Turn 1cnr LH | P RH ; 2cnr LH | P RH to (2,1,3)

25–::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2423, '2012-01-22 19:29:37.902524+00', '2020-12-06 18:44:38.513969+00', 2900, 1, NULL, 'ace', '1–::

  1c+2c set twice, 1c advancing and dancing down to finish BtoB between 2c facing own sides ; 1M+2M turn RH _while{4}_ 1W+2W turn LH, finish (2,13) with 1c in middle facing down

9–::

  1c+3c circle4 L, 1c turning inwards into ; 1c+2c circle4 R (2,1,3)

17–::

  1c dance up to top and cast off to 3pl (3c up) ; 2c+3c+1c turn RH, finish ready for

25–::

  3c+1c Poussette (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3610, '2012-07-21 11:45:47.872362+00', '2018-11-13 23:03:41.953387+00', 3769, 1, NULL, 'ace', '1–::

  1W+2W+3W Circle3 and back

9–::

  1M+2M+3M Circle3 and back

17–::

  1c down the middle (2c up) and up, finish on midline facing P, 1M above 1W

25–::

  1c set twice ; turn to (2,1,3)



{{explanation}}

Note: no hand or number of turns given for [29-32]', 3);
INSERT INTO 'dancecrib' VALUES (1806, '2012-01-22 19:29:03.311277+00', '2017-07-07 13:20:01.424229+00', 682, 1, NULL, 'ace', '1–::

  1c set, turn BH ; 1c facing 2c set and turn BH

9–::

  1c dance down, cast round 3c to 2pl (2c up) ; 1c set twice.

17–::

  2c+1c R&L (2,1,3)

25–::

  2C+1W & 1M+3c circle3 L ; 2c+1M & 1W+3c circle3 R, 1c finishing in the middle facing W side, 1M on R

33–::

  1c dance out, split and cast round the W ; meets, dance out between the M, split and cast to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3807, '2013-07-13 15:56:11.657667+00', '2019-03-15 09:48:58.130647+00', 3789, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c R&L

9–::

  1c, other cpls following, lead down, cross at bottom and cast up on opposite side (1x,2x,3x,4x)

17–::

  All set | 2c+4c dance up as 1c+3c cast ; All set | 2c+1c & 4c+3c ½ RHA (1,2,3,4)

25–::

  1c cross RH | cast (2c up) ; repeat LH (3c up)

33–::

  repeat RH (4c up) ; 1c turn BH 1½  (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (8901, '2015-09-11 17:21:21.08282+00', '2021-05-11 10:23:20.493758+00', 5823, 1, NULL, 'ace', '1--::  2c+3c cast to end and cross while{4} 1W+4W & 1M+4M turn 1 ½ RH, into middle positions (2x,4,1,3x) ; repeat figure, 2c & 3c turning LH (4x,3x,2x,1x)

9--::  Circle8 and back

17--::  Repeat [1-8] to places (1,2,3,4)

25--::  Revised version (2021):  1c cast (2c up), cross down RH  (3c up);  cast off (4c up) , 1c cross LH (2,3,4,1)



Original version: 1c cast (2c up), cross RH and cast off (3c up), 1c cross LH and cast off (4c up) (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (3611, '2012-07-21 11:45:48.501039+00', '2020-09-16 22:08:20.239843+00', 13130, 1, NULL, 'ace', '1–::

  1c set adv | turn BH and face up ; cast to 2pl and cross RH to face 1cnr (2c up)

9–::

  1c+1cnrs ½ diag. Reel4, pass Lsh ; repeat with 2cnrs, finish facing 3cnr pos.

17–::

  1c SetH&G , finish in middle Lsh to Lsh facing opp. side

25–::

  3c+1W & 1M+2c RHA, 1c dancing ahead to join the chase on opposite side; all chase ½ clw to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2667, '2012-01-22 19:29:52.307509+00', '2021-05-15 18:11:38.225758+00', 3783, 1, NULL, 'ace', '1–::

  All circle8 and back

9–::

  1c+2c & 3c+4c ½ R&L ; 1c+4c ½ R&L (2x,4,1,3x)

17–::

  Reels4 on both sidelines, pass Rsh in middle on last bars

25–::

  Middle couples cross over NHJ, the 4M+1M making the arch | all turn corner 1¼ easy hand to end facing in lines across (1c+4c at the ends) | all set

33–::

  All Men (on W side) RHA _while{4}_ All Women LHA ; wheels go round a second time, all changing to the other wheel (each W crosses in front of her M), 3c starting

41–::

  3c leads up out of the wheel, other couples following, and casts off, to order 2,4,1,3', 2);
INSERT INTO 'dancecrib' VALUES (13788, '2021-03-05 19:05:39.521935+00', '2021-03-05 19:16:33.480541+00', 20242, 1, 202, 'ace', '1--::
  1c lead down (2c up) ; on [5] 1c change sides and face up [: 1M dances below 1W who dance under P''s arm]. 1c lead up and face 1cnrs
9--::
  1c & 1cnrs set | 1c pivot R and dance RSh round 3cnrs, between nearest ends to centre then turn P RH to face 1cnrs _while{6}_ 1cnrs advance to centre {1}, turn RH and face original positions {1}, dance back to places {2}, stand still {2}
17--::
  ½ Reel4 on 1diag, pass P LSh to face 2cnrs ; ½ Reel4 on 2diag. 1c face 2cnrs
25--::
  1c & 2cnrs set | 1c pivot R and dance RSh round 4cnrs to 2pl | cross RH to 2plx _while{6}_ 2cnrs advance to centre {1}, turn P RH and face original positions {1}, dance back to places {2}, stand still {2} (3x,1x,2x)
33--::
  All set | chase clw ½ | set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2520, '2012-01-22 19:29:46.05209+00', '2020-12-07 21:47:09.525258+00', 3281, 1, NULL, 'ace', '1–::

  1c+2c RHA {3}, LHA back {3}, 1c cast off to 2pl _while{2}_ 2c dance up to 1pl (2,1,3)

9–::

  1W+2c & 1M+3c circle3 and back, 1c finishing facing 1cnrs

17–::

  1c set to and turn corners

25–::

  1c lead down between 3c, cross to own sides and cast up round 3c, dance up between 2c and cast off (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13791, '2021-03-06 16:37:13.467943+00', '2021-03-06 16:43:05.184268+00', 20243, 1, 202, 'ace', '1--::

  1c set | cross down to 2plx (2c up) ; 1c dance RSh round 1cnrs and face 1cnrs

9--::

  Corner Chain. On [15-16] 1c turn LH to 2plx and face out (2,1x,3)

17--::

  Reels3 on sides, 1c LSh to 2cnrs. 1c face 2cnrs

25--::

  Corner Chain. On [31-32), 1c turn LH to centre, 1M facing up, 1W down

33--::

  Reels3 across, 1c LSh to 3cnrs. On [39-40] 1c pass P RSh to 2pl (2,1,3) ', 2);
INSERT INTO 'dancecrib' VALUES (2677, '2012-01-22 19:29:52.709271+00', '2021-05-15 10:11:38.823941+00', 3829, 1, NULL, 'ace', '1–::

  1c+3c set | cast off (2c+4c up) ; turn LH (2,1,4,3,5)

9–::

  2c+1W & 3M+5c Lsh Reels3 across _while_{8} 1M+3W+4c Rsh Reel4 across (to start, 1M+3W pass Lsh), finish on sidelines (2,1,4,3,5)

17–::

  In the same groups of 3+4+3 dancers RHA ; LHA, 1c+3c finish passing Lsh to face 1cnr

25–::

  1c+3c Turn CPCP, replacing the final turn by pass P Lsh into

33–::

  All Dbl DTr, 1c+3c finish facing out on own side

41–::

  1c+3c dance out the sides casting R round 3cnr and meet P ; turn ¾ RH | cast off one (4c+5c up) (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (2649, '2012-01-22 19:29:51.482917+00', '2021-05-15 19:23:58.850583+00', 3728, 1, NULL, 'ace', '1–::

  1M+2M ½ Fig8 round the W ; 1W+2M ½ Fig8 down (1c is on M side, 2c on W side, the W on 1diag)

9–::

  1W+2W progressive BtoB ; set | cast cclw  _while_{4}    1M+2M set | cast clw ; Progressive BtoB (all have now changed sides)

17–::

  Turn opposite BH ½ | Circle4 L ½ ; ½ R&L, end in promhold with P, facing across (1c is on W side, 2c on M side)

25–::

  All advance to midline, M Lsh to Lsh, and continue with Tournée (2,1)



{{explanation}}

Progressive Back to Back: pass Rsh, and pivot L ½ | Retire into exchanged places', 2);
INSERT INTO 'dancecrib' VALUES (2560, '2012-01-22 19:29:47.672509+00', '2023-01-10 11:33:47.253751+00', 3437, 1, NULL, 'ace', '1–::

  1c+2c ½RHA, stay in middle ; 2c+1c lead down the middle

9–::

  2c+1c ½LHA ; 1c+2c lead up the middle to own places

17–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (8074, '2013-10-05 20:55:21.433133+00', '2014-04-30 23:23:59.478155+00', 8357, 1, NULL, 'ace', '1–::
  1M+2W & 3M+4W Turn RH ½ | cast clw round standing dancer on own side, to (1,2,3,4) ; dance the pattern of ½ M-Chain (finish 1c+3c on W side, 2c+4c on M side, all W above M)
9–::
  Reels4 on sidelines
17–::
  1W+2M & 3W+4M Turn LH ½ | cast cclw round P ; dance the pattern of L-Chain (2x,1x,4x,3x)
25–::
  All set | 2c cross RH and stand {4} _while_{6} 1c+4c+3c turn BH ½, dance up between 2C and cast off to (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2692, '2012-01-22 19:29:53.318051+00', '2017-02-06 11:51:05.739804+00', 13273, 1, NULL, 'ace', '1–::

  1c+2c+3c mirror Reels3 on the sides, to start 1c cross down, 2c out and up, 2c finish facing out (1x,2,3)

9–::

  1c dance down NHJ and face out _while{2}_ 2c cast up (2,1x,3) | 1c turn 3c EH on the side ; 1c turn 2c EH 1½ (1x,2,3)

17–::

  1c cross down for ½ Fig8 round 2c ; 1c+2c RHA and stay in middle

25–::

  Allepousse: 1c dances as 2C Allemande _while{8}_ 2c dances as 2C Poussette (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14232, '2021-08-14 00:22:24.651798+00', '2023-02-04 01:23:04.672561+00', 14667, 3, NULL, 'ace', '1-8::
    1L+2M set advancing & turn RH; 1M+2L repeat
9-16::
    1s+2s dance R&L ending facing down/up on sides
17-24::
    1s+2s set to each & change places (Men RH, Ladies LH); 1s+2s set to
    each & change places (Men LH, Ladies RH), 1s face out, 2s face in
25-28::
    1s cast (2s step up), 2s+1s set', 0);
INSERT INTO 'dancecrib' VALUES (10473, '2018-03-02 16:58:16.74101+00', '2018-03-02 17:39:26.041104+00', 13489, 1, 202, 'ace', '_Jig_

1--::

  All S&Link, M face out at end ; all W LHA to P place _while{4}_ all M chase clw ½ to opposite W places

9--::

  All S&Link, W face out at end ; all M LHA, ending with LHJ _while{4}_ all W chase clw ½, Rsh to P at end

17--::

  All turn P RH 1 ½ into promhold facing clw ; all chase clw ½ (1,2,3,4)

25--::

  Circle8 and back



_Strathspey_

33--::

  All S&Link, M face out at end ; all M turn next person LH | turn P RH, all face in at end, W on M''s left

41--::

  All S&Link, W face out at end ; all M turn cnrs LH | turn P RH, all face P at end

49--::

  Interlocking Reels4

57--::

  Circle8 and back



_Reel_

65--::

  All S&Link, M face out at end ; 4 bars of Schiehallion reels, all face in at end, W on M''s left

73--::

  All S&Link, W face out at end ; 4 bars of Schiehallion reels, all face P at end

81--::

  ½ Gr-Chain (2 bars per hand) (1,2,3,4)

89--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (2674, '2012-01-22 19:29:52.588561+00', '2019-02-23 00:45:58.450644+00', 3803, 1, NULL, 'ace', '1–::

  1c dance behind own lines, cast outwards, and back

9–::

  Mirror Reels3 on the sides (1c starts in and 2c up), take hands when possible (1,2,3)

17–::

  1c lead down | set to P ; lead up and cast off (2c up) (2,1,3)

25–::

  All C A&R {1+1} | dance BtoB | Turn P BH', 3);
INSERT INTO 'dancecrib' VALUES (2682, '2012-01-22 19:29:52.909698+00', '2015-02-18 21:35:42.65259+00', 10306, 1, NULL, 'ace', '1–::

  1c turn RH | cast off ; cross LH and cast off to face up between 3c in promhold, M on the R

9–::

  Lsh Reel3 across with 3c, 1c finish between 3c facing up and split

17–::

  Mirror Reels3 on opposite sides, 1c finish between 3c NHJ

25–::

  1c dance to top | split and turn 2c easy hand ; cross down between 3c and cast up into

33–::

  Teapots R and L (RHA with end couples ; pass Rsh into LHA) (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2686, '2012-01-22 19:29:53.061973+00', '2014-04-30 23:23:59.598941+00', 3891, 1, NULL, 'ace', '1–::
  1c down the middle NHJ | face P and set ; dance up NHJ | cast off to face 1cnrs (2c up)
9–::
  Turn 1cnrs RH, pass Rsh ; turn 3cnrs LH, pass Lsh (cnrs dance 4-bar turns)
17–::
  Turn 2cnrs RH, pass Rsh ; turn 4cnrs LH, 1c finish on own side BtoB for
25–::
  DTr (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2676, '2012-01-22 19:29:52.668383+00', '2019-08-29 18:43:44.948219+00', 13588, 1, NULL, 'ace', '1–::

  1c+2c S&Link, finish 2c facing 1c NHJ ; S&Link to (2x,1x,3)

9–::

  1c, 2c following, dance down {3}, change sides with NHJ, W passing above M and under his arm, 2c+1c dance up to (2,1,3), 2c facing out

17–::

  2c turn 1c EH on sides ; 1c turn 3c EH, 1c finish BtoB facing 1cnr

25–::

  SetH&G , petronella to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (4947, '2013-08-21 08:30:57.69661+00', '2023-02-12 16:16:22.292833+00', 1578, 3, NULL, 'ace', '1-8::

    1s+2s+3s cross RH, set, cross back RH & set

9-16::

    1s turn RH 1.1/2 times, cast 1 place & turn LH once to face 1st

    corners

17-24::

    1s change places RH with corners & set, change places with corner

    person RH & turn partner LH to face 2nd corners

25-32::

    1s change places RH with corners & set, change places with corner

    person RH & cross LH with partner to places', 0);
INSERT INTO 'dancecrib' VALUES (2688, '2012-01-22 19:29:53.154091+00', '2020-12-21 11:00:49.08685+00', 9419, 1, NULL, 'ace', '{{explanation}}

A new 1st couple starts from 1pl every 16 bars. Couples are referred to by their place



1–::

  1plC+2plC+3plC mirror Reels3 on the sides, 2plC starting out and up (1,2,3,4)

9–::

  1plC cross RH | cast off (2plC up) ; cross LH | cast off (3plC up) (2,3,1,4)

17–::

  1plC+2plC+3plC mirror Reels3 on the sides, as in [1-8].

25–::

  1plC cross RH | cast off (2pl C up) ; cross LH | cast off (3pl C up) _while{8}_ 3plC facing 4plC set | change places on the sides, the M LH and the W RH ; both couples set to P | the new 4plC sets as the new 3plC steps up.



{{explanation}}

Repeat [17-32] three times, but the third time, the original 1c, arriving in 1pl after the reels [65-72] stands still for the last 8 bars [73-80].', 3);
INSERT INTO 'dancecrib' VALUES (10145, '2017-09-24 15:34:55.664412+00', '2017-09-24 15:38:54.195055+00', 4887, 2, 160, 'ace', '1-8::  1s+2s set, RHA1/2; 2s+1s set, cross over RH.

9-16::  6 hands round & back.

17-24::  1s 1/2 fig.8 round 2s; 1s 1/2 fig.8 round 3s. 

25-32::  2s+1s R&L.', 3);
INSERT INTO 'dancecrib' VALUES (14401, '2021-10-26 15:03:01.050304+00', '2021-10-27 04:14:58.287908+00', 13796, 2, NULL, 'ace', '1--::
  Mirror Reels3 on opppsoite sides, 1c crossing down (1x,2,3)
9--::
  Mirror Reels3 on own sides. On [15-16] 1c cross down to 2plx and face out _while{2}_ 2c continue the reel to 1pl (2,1x,3)
17--::
  1c dance RSh round 1cnrs to centre, pull RSh back and dance RSh round 4cnrs to 2pl (2,1,3)
25--::
  1c dance BtoB ; dance up to top and cast off to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12136, '2019-09-02 08:55:45.980313+00', '2021-03-20 19:46:44.391257+00', 8271, 1, 202, 'ace', '*Trio face trio RR.*



1--::

  All set | Circle6 L ¼ ; dance BtoB with opposite person

9--::

  Repeat [1-8]

17--::

  All cnrs set advancing diagonally | RHA and face centre | Pivot R to places as on [16] _while{8}_ centres cast R and chase clw ½ to exchanged places ; set | cross RH and face out and to the R

25--::

  RSh Reels3 with P, all cnrs ending with loops to face new line3', 2);
INSERT INTO 'dancecrib' VALUES (2705, '2012-01-22 19:29:53.835333+00', '2021-05-13 15:56:15.118576+00', 3957, 1, NULL, 'ace', '1–::

  1M+2W set | 1M cast (2M up) ; 1W+2M set | 1W cast (2W up) (2,1,3)

9–::

  2c+1W & 1M+3c RHA ; Lsh Snake Pass (unwind the RHA, 1c leading, pass other snake Lsh through 2plx and chase cclw to) (3,1,2)

17–::

  3c+1M & 1W+2c LHA ; Rsh Snake Pass (unwind the LHA, 1c leading, pass other snake Rsh through 2plx and chase clw to) (2,1,3)

25–::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2633, '2012-01-22 19:29:50.845612+00', '2021-05-16 17:38:49.751617+00', 3678, 1, NULL, 'ace', '1–::

  1c+2c Poussette

9–::

  1W+2M change places RH, cast clw round P to own places ; 1c+2c RHA

17–::

  1M+2W change places LH, cast cclw round P to own places ; 1c+2c LHA

25–::

  1c+2c Knot', 2);
INSERT INTO 'dancecrib' VALUES (13945, '2021-04-09 08:35:29.140154+00', '2022-10-14 06:36:26.080737+00', 15672, 1, 202, 'ace', '*1c & 2c start on opposite sides*
1--::
  1c & 4c set | cast inwards (2c & 3c step out) ; 2c & 3c chase clw ½, 2M & 3M casting to start _while{4}_ 1c+4c ½ R&L (3x,4x,1,2)
9--::
  Reels4 on sides, 3M & 2M looping to places (3x,4x,1,2)
17--::
  3c+4c & 1c+2c RHA. 3M & 2M face out ; 3c & 2c chase clw ½, 2M & 3M leading _while{4}_ 4c+1c LHA. 4c & 1c LHJ face nearest ends (2x,4x,1,3)
25--::
  4c & 1c lead out LH, M crossing in front of P, and cast inwards (to 2x,4,1x,3) ; 4c & 1c Birl (elbow grip) 1½ (2x,4x,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10027, '2017-07-24 03:18:22.349163+00', '2022-01-13 21:17:53.572058+00', 17898, 1, 202, 'ace', '1--::

 1c parallel Fig8 on sidelines, 1c Rsh to 2c to start

9--::

 Parallel Reels3 on sidelines, 1c Rsh to 2c to start, 1W facing out at end

17--::

 1W followed by P cast round 2W | dance between 2c to M side ; cast round 2M to 2pl (2c up on [23-24]) (2,1,3)

25--::

 1c+3c RHA ; 2c+1c LHA, 1W facing out at end.', 2);
INSERT INTO 'dancecrib' VALUES (15274, '2022-12-02 22:36:50.947161+00', '2023-02-13 23:15:22.742505+00', 21189, 1, 1645, 'ace', '1--::

  1c+2c & 3c+4c DblFig8, 1c & 3c start crossing down as 2c & 4c dance up

9--::

  2c & 1c dance down, turn W under on [12] ; dance up to opp sides (1x,2x,3,4)

17--::

  3M+4W set | cross RH ; 3W+4M set | cross RH (1x,2x,4x,3x)

25--::

  All set | chase &frac12; way clw | set (3,4,2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15442, '2023-02-13 11:07:22.43259+00', '2023-02-22 17:18:27.200756+00', 21340, 1, 1645, 'ace', '1--::

  1s set | lead down below 3c, cross & cast up (2,1x,3)

9-12::

  2c+1c Circle4 to L

13-24::

  2c+1c+3c R&L for 3 couples

25--::

  1c+3c Circulating Knot: 1c start turning RH to face up as 3c face down, 1c end turning LH to own sides (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (2460, '2012-01-22 19:29:40.142064+00', '2017-07-07 13:23:17.607163+00', 3045, 1, NULL, 'ace', '1–::

  1c+2c RHA, LHA

9–::

  1c lead down the middle {3}for 3 steps, up {3}, turn once (can be RH or BH) round (to 1pl)

17–::

  1c+2c+3c G-Chain (1c crosses)

25–::

  1c+2c+3c set, cross RH, set, cross RH

33–::

  1c+2c set twice, advancing for ; ½ Poussette (the diagram shows a start on the centre line, not on the diagonal)', 3);
INSERT INTO 'dancecrib' VALUES (11762, '2019-04-03 10:33:49.632836+00', '2019-04-03 10:48:22.646532+00', 19255, 1, NULL, 'ace', '*Start (1,2,3x,4x)*

1--::

  1c+4c long cast to centre as 2c+3c set advancing and dance to end (2,3,4x,3x) ; 1c+4c turn P RH into promhold facing the end 

9--::

  2c+1c(promhold) & 4c(promhold)+3c Rsh Reels3 across

17--::

  1c+4c dance out the end, cross LH and cast to middle ; 4c turn 1c RH 1½ on the side (or birl) (2,4,1x,3x)

25--::

  Circle8 and back (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (10753, '2018-05-09 07:41:33.048511+00', '2020-11-13 13:19:37.8702+00', 18206, 1, 202, 'ace', '1--::
  1c turn P RH | 1c (1W leading) cast off two places to 3pl centre and face up _while{8}_ 4c turn P RH | 4c (4M leading) cast up two places to 2pl centre and face down. 2c & 3c step out on [5-6] (2,4x,1x,3)
9--::
  4c & 1c set diagonally pulling RSh back on [10] | change places RSh with nearest cnrs ; 2c+3c LHA and stay in centre (4x,2,3,1x)
17--::
  2c & 3c set diagonally pulling RSh back on [18] | change places RSh with nearest cnrs ; 4c+1c LHA, pull LSh back 4c facing Wside, 1c facing Mside (2,4x,1x,3)
25--::
  1c (1W leading) & 4c (4M leading) dance RSh round 2M/3W to own sides and face down/up ; 1c pass 2c RSh to 2pl _while{2}_ 4c pass 3c RSh to 3pl (to 2,1,4,3) | 1c+4c change places LH (2,4,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2698, '2012-01-22 19:29:53.555849+00', '2016-11-15 16:02:55.144696+00', 3931, 1, NULL, 'ace', '1–::

  1c set | cast off 2 (2c+3c up) ; set | cast up 2 (2c+3c down)

9–::

  1c lead down {3}, up {3} | and cast off (2c up) (2,1,3)

17–::

  All Circle6 and back

25–::

  All A&R ; turn P BH', 3);
INSERT INTO 'dancecrib' VALUES (10259, '2017-11-14 23:37:54.984046+00', '2018-12-07 17:49:34.879543+00', 15229, 1, 202, 'ace', '1--::

  1M cast (2M up) | turn 2W BH ; 1W turn 2M BH | cast (2W up) (2,1,3)

9--::

  2c+1c set | turn P BH, open into ; Circle4L (2,1,3)

17--::

  1c set advancing to 1cnrs | turn 1cnrs BH into lines of 3 across ; 1c passing Lsh set advancing to 2cnrs | turn 2cnrs BH to face 1cnr (2,1x,3) 

25--::

  Reels3{6}, 1c Lsh to 1cnrs | 1c cross to 3pl (3c finish in 2pl) (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (2850, '2012-01-22 19:30:00.015258+00', '2021-01-25 16:29:18.780453+00', 13360, 1, NULL, 'ace', '1–::

  1c dance down the middle | Turn 3c EH (2c up) ; 1c (in 2pl) cross Rsh | turn 2c EH ½ to (1x,2,3)

9–::

  Repeat [1-8] (1,2,3)

17-20::

  1c set & cast off (2c up) (2,1,3)

21-32::

  R&L for 3 couples (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11763, '2019-04-03 12:52:35.01438+00', '2019-04-03 13:09:50.847475+00', 19256, 1, NULL, 'ace', '1--::

  1c (cross down) +2c ¾ DblFig8 | set (2x,1,3)

9--::

  1c (cross down) + 3c ¾ DblFig8 | set (2x,3x,1)

17--::

  Reels3{6} on the sides, 1c cross up and 3c dance out and down to start | 1c+3c change place on side (2x,1x,3x)

25--::

  All set | turn P RH 1½ | set (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11764, '2019-04-03 13:15:34.769051+00', '2019-04-03 13:30:49.087503+00', 19257, 1, NULL, 'ace', '1--::

  Horseshoe Chain: 4 hands of a Grand Chain, 2 bars/hand, changing place normally on the sides, but full turn with P at the ends (2,3,1)

9--::

  2c (cross down) + 1c (cast up) DblFig8 round 3c (2,3,1)

17--::

  Reels3 on the sides, 3c down and in, 1c cast up (2,3,1)

25--::

  Circle6 and back (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2710, '2012-01-22 19:29:54.068921+00', '2015-04-14 09:42:09.282868+00', 3972, 1, NULL, 'ace', '1–::

  1c Fig8 round 2c

9–::

  1c set twice ; turn twice BH

17–::

  1c lead down the middle (2c up) ; and up to face 1cnrs,

25–::

  1c set to and turn corners

33–::

  Reels3{6} on the sides (Lsh to 1cnrs) | 1c cross RH to 2pl', 3);
INSERT INTO 'dancecrib' VALUES (3809, '2013-07-13 15:56:12.108389+00', '2014-04-30 23:23:59.853879+00', 3935, 1, NULL, 'ace', '{{explanation}}
On 2nd chord 3c+4c cross (1,2,3x,4x)

1–::
  1c+4c set | Turn RH ; cast inwards (2c+3c to the ends) | turn RH ½ into promhold (W on L) facing 2W and 3W
9–::
  1c+4c in promhold »Pass and Turn«with 2W+3W ; repeat with 2M+3M, and finish 1c between 2c and 4c between 3c in facing lines across
17–::
  All set | 1c+4c change places LH with opposite ; lead out crossing and cast in to (2,4,1x,3x)
25–::
  1c+4c change places LH on side, lead out the end, cross and cast back | ½ RHA (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (2702, '2012-01-22 19:29:53.715014+00', '2014-04-30 23:23:59.884357+00', 3940, 1, NULL, 'ace', '1–::
  1c set | cast off two (2c+3c up) ; 1c set | cast back (2c+3c down)
9–::
  1c down the middle {3} and up {3} | cast off (2c up) and face 1cnrs
17–::
  1c set to and turn corners
25–::
  Reels3{6} on the sides, Lsh to 1cnr | 1c cross RH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1757, '2012-01-22 19:29:00.841124+00', '2017-07-07 13:31:52.375702+00', 522, 1, NULL, 'ace', '1–::

  1M+2W turn BH ; 1W+2M turn BH {3} to places, [on 8] 1c+2c+3c dance in

9–::

  1c+2c+3c Promenade

17–::

  1c cross RH, cast ; lead up, cross and cast (2c up)

25–::

  2c+1c+3c Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (10506, '2018-03-12 19:16:22.15105+00', '2020-11-14 10:34:15.975156+00', 18209, 2, 2703, 'ace', '1-8:: 1c+2c+3c RSh reels of 3 (1W face out)

9-16:: 1W followed by 1M cast off and cross to 2nd place opposite side (2c up 3-4) | 1M followed by 1W cast off and cross to 3rd place own side (3c up 7-8)

17-24:: 3c+1c set and rotate

25-32:: 2c+1c+3c Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2701, '2012-01-22 19:29:53.675071+00', '2021-05-13 16:01:22.571484+00', 3938, 1, NULL, 'ace', '1–::

  1c dance ½ Fig8 round 2c ; 1c dance ½ Fig8 round 3c, finish in 2pl own side, (2c up) (2,1,3)

9–::

  2c repeat [1-8], dancing round 1c+3c, 1c up on [15-16] (1,2,3)

17–::

  1c+2c ½ R&L ; 2c+1c set | cross RH (2,1,3)

25–::

  2c set | cast into 2pl (1c up) ; 1c set, cast into 2pl (2c up)', 2);
INSERT INTO 'dancecrib' VALUES (2592, '2012-01-22 19:29:48.998338+00', '2021-05-18 11:25:59.992132+00', 3569, 1, NULL, 'ace', '1–::

  1c+2c+3c G-Chain

9–::

  All Promenade

17–::

  1c set and cast off (2c up) ; 1c cross between 3c and cast up (2,1x,3)

25–::

  1c cross up between 2c and cast off ; Teapots R (1W+2c & 1M+3c RHA)

33–::

  2c+1c+3c A&R ; 1c turn RH', 2);
INSERT INTO 'dancecrib' VALUES (14035, '2021-05-17 07:37:59.248596+00', '2021-05-17 07:41:51.235277+00', 1099, 1, 202, 'ace', '1--::

  1c lead down ; and up (1,2,3)

9--::

  1c set | cast off (2c up) ; set | turn P RH ¾ into lines3 across. 1c face 4cnrs

17--::

  Reels3 across into lines3 across. 1c face P

25--::

  1c set | turn P RH ¾ ; set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2585, '2012-01-22 19:29:48.656092+00', '2021-05-18 20:17:11.24857+00', 3544, 1, NULL, 'ace', '1–::

  1c+2c ¾ R&L | All set (2,1,3)

9–::

  1c ½Fig8 R (1W up, 1M down) ; Teapots R (2c+1M & 1W+3c RHA)

17–::

  1c ½Fig8 L (1W up, 1M down) ; Teapots L (2c+1M & 1W+3c LHA)

25–::

  All Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (2703, '2012-01-22 19:29:53.755645+00', '2019-04-20 09:10:07.366589+00', 3941, 1, NULL, 'ace', '1–::

  1c+4c cross RH and cast to middle positions (2c+3c step to ends) ; 1c+4c RHA, finish in lines across facing up, 1c/4c between 2c/3c

9–::

  All Pas de Basque & Coupé R and L ; repeat

17–::

  1c+2c & 3c+4c Reels4 across (to 1,2,3,4)

25–::

  All circle8 and back

33–::

  1c cross RH | cast off ; cross LH | cast to bottom (2c+3c+4c up) (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2439, '2012-01-22 19:29:38.896807+00', '2020-12-06 18:46:22.770416+00', 2962, 1, NULL, 'ace', '1–::

  1W & 4M cast behind own line, and round its other end to meet in middle ; they turn ¾ RH _while{4}_ 1M & 4W repeat [1-4] (Lsh cast) to meet the others for

9–::

  All four ½ LHA and dance short way to exchanged places (4,2,3,1) ; all C turn RH

17-32::

  Repeat [1-16] from new positions (4W & 1M begin), all C finish in promhold, C facing C up/down (1,2,3,4) for

33–::

  The couples dance ½Reel4 {8}, finishing (4,3,2,1), at end 4c&1c cast into place and 2c&3c cross into place, 2W & 3M facing out, their P pivoting R

41–::

  4c+3c+2c Parallel Rsh ½Reel3 on own sides (to 2,3,4,1) ; all C turn RH', 3);
INSERT INTO 'dancecrib' VALUES (2718, '2012-01-22 19:29:54.449619+00', '2021-05-12 17:58:48.562661+00', 4019, 1, NULL, 'ace', '1–::

  Mirror Half Reels3 on sides, 1c start in and down ; 1c lead to top, cross and cast off (3,1x,2)

9–::

  Mirror Half Reels3 on sides, 1c start in and down (to 2,1,3) ; 2c+1c R&L one step per hand, 1c finishes facing 1cnrs.

17–::

  1c set to and turn 1cnr BH 1½, opening to both face 2cnr, 1cnr on the L ; both set to 2cnr and Circle3 L, breaking to finish (2,1x,3).

25–::

  1M+2c & 1W+3c Lsh Reels3{6} across | 1c cross RH to (2,1,3).', 2);
INSERT INTO 'dancecrib' VALUES (2712, '2012-01-22 19:29:54.148256+00', '2018-03-16 08:43:54.619764+00', 3980, 1, NULL, 'ace', '1–::

  1c in promhold (1M on the R) Reel3 with 2c (Rsh to 2M), 2c finish in 1pl

9–::

  Repeat with 3c, finish in centre, facing M side, 1M above 1W

17–::

  2c+3c dance R&L _while{8}_ 1c dance out on M side, divide and cast to meet in centre, dance out on W side, divide and cast into

25–::

  In lines across 1M+2c facing 1W+3c set twice ; 1c turn RH 1¾ to promhold to continue (2,1,3) (on 2nd time through, turn RH ¾ and dance down to 4pl (4c up))', 3);
INSERT INTO 'dancecrib' VALUES (9887, '2017-05-28 18:08:46.280253+00', '2017-08-26 07:43:47.996506+00', 13558, 1, 202, 'ace', '*3c & 4c start on opp sides*

1--::

 1M+2c & 4M+3c dance Reels3 across 1M/4M Lsh to 2W/3W but on [4] join P in promhold, complete the reel into two lines across, 1c/4c between 2c/3c facing dn/up

9--::

 All set | A&R{4} | 2c & 3c set to P _while_ 1c & 4c dance into line of 4 across, Rsh to opp person

17--::

 1c+4c ½ Reel4 across, on [8] 1W & 4W pivot R to face P ; 1c & 4c turn RH ½, W facing out, M behind P | 1c/4c cast R to 1pl/3plx (2,1,4x,3x)

25--::

 1c+4c set | ½ RHA (to 2,4,1x,3x) ; 2M+4M & 1M+3M turn RH _while{4}_ 2W+4W & 1W+3W turn LH', 2);
INSERT INTO 'dancecrib' VALUES (2709, '2012-01-22 19:29:54.02508+00', '2016-07-05 13:14:50.024817+00', 3963, 1, NULL, 'ace', '1–::

  1c lead down | turn ¾ RH ; set with RHJ, 1W turning under P’s R arm to face up, 1W with 1M following dance up

9–::

  1c+2W RHA, 1c finishing LHJ with 3M ; 1c+3M LHA to finish 1c facing 1cnrs

17–::

  ½Reel4 with 1cnrs, pass Rsh into ; ½Reel4 with 2cnrs to finish (3x,1x,2x), 1c facing 2c

25–::

  ½ G-Chain ; 2c & 1M+3M & 1W+3W turn RH  (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2950, '2012-01-22 19:30:04.208183+00', '2020-12-14 09:38:51.511398+00', 5007, 1, NULL, 'ace', '1–::

  1M+2W RH turn to 1M facing up between 2c facing down ; 1M+2c BiL _while{4}_ 1W dances under their arms once round 1M (down on W side, up on M side)

9–::

  1c down the middle and up

17–::

  1c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (2704, '2012-01-22 19:29:53.795575+00', '2017-07-07 13:25:59.761216+00', 3953, 1, NULL, 'ace', '1–::

  1c+2c set | ½ RHA ; set | ½ LHA

9–::

  1c+2c+3c set | cross RH ; repeat, 1c+2c finishing for

17–::

  1c+2c Poussette, 1c finishing in the middle for

25–::

  2c+1c+3c DTr.', 3);
INSERT INTO 'dancecrib' VALUES (3487, '2012-01-22 19:30:27.508634+00', '2017-07-07 13:29:29.573499+00', 6957, 1, NULL, 'ace', '1–::

  1W followed by 2W+3W chase cclw behind 1M+2M+3M to places

9–::

  1M followed by 2M+3M repeat clw round the W

17–::

  1c facing 2c set | change place RH ; set | change place LH ready for

25–::

  1c+2c Poussette, 1c finish BtoB in the middle facing own side for

33–::

  DTr, 1c finish facing W side NHJ 1W above 1M

41–::

  1c dance out between 2W & 3W, 1W casts up and 1M casts down, meet in the middle ; cast as before, between 2M & 3M, finish in 2pl', 2);
INSERT INTO 'dancecrib' VALUES (10260, '2017-11-15 04:54:11.78963+00', '2017-11-20 08:42:51.063023+00', 18074, 1, 202, 'ace', '1--::

  1c+2c S&Rotate (2,1)

9--::

  2c+1c RHA ; LHA

17--::

  1c cross up LHJ | cast to 2plx ; cross RH | cast up to 1pl centre (2c down to 2pl centre) ready for (1,2)

25--::

  Poussette (2,1)', 5);
INSERT INTO 'dancecrib' VALUES (2600, '2012-01-22 19:29:49.356567+00', '2015-03-27 20:40:08.730314+00', 3593, 1, NULL, 'ace', '1–::

  1c, starting inwards, fig8 round 2c and 3c

9–::

  Circle6 and back

17–::

  1c+2c+3c promenade

25–::

  1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (7832, '2013-08-21 08:31:49.444304+00', '2023-02-04 01:23:04.688908+00', 14952, 3, NULL, 'ace', '1-8::
    1s & 3s promenade 1/2 way round anticlockwise to end 1s facing up
    opposite 3s facing down, 1 & 3s set then dance 1/2 RH across back to
    places
9-16::
    2s & 4s repeat bars 1-8
17-24::
    All set to partners & change places RH, set HS to next person
25-32::
    Turn that person 2H (4 bars), set & turn partner RH 1/2 way
33-40::
    All dance interlocking reels of 4 giving RSh to partner
41-48::
    All dance 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (2708, '2012-01-22 19:29:53.95415+00', '2020-12-25 15:34:10.84938+00', 12953, 1, NULL, 'ace', '1–::

  1c cast one (2c up) | Turn ½ LH and face down LHJ ; cross down through 3c and cast to (2,1,3)

9–::

  Diagonal R&L (3x,1,2x)

17–::

  »Cross and link for 3«: 1c cross RH and face P _while{2}_ corners set | Link for 3 (as in S&Link) ; 1c cross LH up/dn and face P _while{2}_ corners set | Link for 3 the opposite way (person on R passes through middle) (2,1,3)

25–::

  1c turn ½ BH and face up NHJ | lead up through 2c ; cast to (2,1x,3) | cross to 2pl facing out



{{explanation}}

On 2nd turn, dancing C casts to 4pl (4c up).', 3);
INSERT INTO 'dancecrib' VALUES (13946, '2021-04-09 15:36:15.296452+00', '2021-04-09 15:44:16.02568+00', 15669, 1, 202, 'ace', '1--::

  1c & 3c set | Petronella turn in tandem ; 1c+3c set advancing passing LSh _while{2}_ 2c & 4c set | 2c+1c & 3c+4c set advancing passing LSh

9--::

  1c & 3c turn P BH ½ and face in _while{2}_ 2c+4c set advancing passing LSh | 1c+4c & 2c+3c set advancing passing LSh ; 4c & 2c turn P BH ½ and face in _while{2}_ 1c+3c set advancing passing LSh | 4c+3c & 1c+2c set advancing passing LSh

17--::

  1c & 3c turn P BH ½ and face in _while{2}_ 2c+4c set (3,4,2,1) | 4c Petronella turn in tandem to 1pl _while_ 2c Petronella turn in tandem to 3pl (to 4,3,2,1) ; 4c+2c ½ R&L (2,3,4,1)

25--::

  Circle8 and back (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (14497, '2021-12-20 15:30:09.831298+00', '2021-12-20 15:32:42.476859+00', 13181, 1, 1645, 'ace', '1-::

  1c, 5c & 3c alternating tandem Reel3, all changing lead at each end, 5c start RSh to 1c & end facing 4c

9-::

  4c, 5c & 2c repeat, 5c start LSh to 4c & end facing 1c

17-::

  5c+1c set | &frac12; RHA & 1c face 4c ; 1c+4c set | &frac12; RHA & 4c face 3c

25-::

  4c+3c set | &frac12; RHA & 3c face 2c ; 3c+2c set | &frac12; RHA & 2c face up to 5c (5,3,4,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (14036, '2021-05-21 07:23:38.684068+00', '2021-05-21 07:44:45.248595+00', 1701, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c in (1,2,3)

9--::

  Mirror Reels3 on opposite sides, 1c crossing down (1x,2,3)

17--::

  1c (+2c who dance up to follow) lead down | cross and cast round 3c _while_ 2c following cast round 3c, 1c & 2c meet ; 1c+2c lead up to top | 1c cast off to 2pl. 2c in 1pl face out (2,1,3)

25--::

  2c+1c DblFig8, 1c crossing up (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14038, '2021-05-23 08:21:46.07856+00', '2021-05-23 08:23:47.986264+00', 4591, 1, 202, 'ace', '1--::

  1c lead down ; and up (1,2,3)

9--::

  1c cross RH | cast off (2c up) ; set advancing | turn P BH ½ (PdB) opening to top then finish BtoB in 2pl centre facing own sides

17--::

  DTr. 1c in 2pl face 3cnrs (2,1,3)

25--::

  Reels3 on sides, 1c RSh to 3cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9711, '2017-04-05 19:41:36.723669+00', '2019-04-18 19:17:45.330646+00', 14543, 1, 202, 'ace', '_Strathspey_
1--::
  1c+2c Petronella in tandem | set ; repeat [1-2] ; cross RH, 1c to 2pl centre (2,1,3)
9--::
  1c set | turn BH ½ and face opp sides ; ½ Reels3 on sides, RSh to 1cnrs. 1c face 1cnrs[pos]. All clap twice

_Reel_
1--::
  Corners Pass and Turn on 1diag. On [4] 1c turn RH ½ to face 2cnrs[pos] ; Corners Pass and Turn on 2diag, *LSh to 2cnrs[pos]*. On [8] 1c turn LH ½ to finish LSh to P facing opp sides
9--::
  3c+1W & 1M+2c RHA{3}  Circle6{3} L | all cross RH (2,1,3)

*Note. Original instruction before 2017 was:*
9--:: 3c+1W & 1M+2c RHA{3} (to 3,1,2), Cross{2} Rsh, Circle6{3} L ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2614, '2012-01-22 19:29:50.051279+00', '2017-11-22 07:48:32.518836+00', 3620, 1, NULL, 'ace', '1–-::

  1c+2W RHA ; 1c+2M LHA (to 1,2,3)

9–-::

  1c cross RH, cast round 2c, cross LH, cast round 3c and lead to face 1cnrs (2c up),

17–-::

  1c set to 1cnr | to 2cnr ; cross RH to own side and cast up (2c down) (1,2,3)

25–-::

  1c+2c ½ R&L ; set | cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2615, '2012-01-22 19:29:50.09169+00', '2014-04-30 23:23:58.032708+00', 3621, 1, NULL, 'ace', '1–::
  1c+2c+3c mirror Reels3, 1c start inwards
9–::
  1c+2c+3c G-Chain (1c cross to start)
17–::
  1c slip BHJ down the middle and up ; open out upwards and cast to 2pl (2c up)  (2,1,3)
25–::
  1c (cross down) Fig8 round 3c, finish BtB facing 1cnr
33–::
  1c Turn 1cnr BH (in Skip Change) | pass P Rsh ; turn 2chr BH (Sk.Ch) | pass P Rsh to 2pl facing out
41–::
  1c cast off | dance to top, cross and cast off on opposite side | cross Lsh to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13116, '2020-08-18 07:35:27.630039+00', '2020-08-18 07:35:27.630039+00', 20069, 2, 2784, 'ace', '1-::
  1M sets to 2W and they turn RH; 1M+2M turn LH | 1c turn RH
9-::
  1c+2c Promenade
17-::
  1c dance down {2}, set, cast up to pl, set
25-::
  1c+2c Tournée', 0);
INSERT INTO 'dancecrib' VALUES (8902, '2015-09-14 21:57:12.181985+00', '2015-09-15 11:47:09.012298+00', 16735, 1, NULL, 'ace', '1-::  1c set | cast (2c up) ; All A&R , 1c changing sides RH (as in Trip to Bavaria) (2,1x,3)

9-::  1c set | cast (Rsh back = W up, M down) into lines across ; All A&R up/down, 1c changing lines.

17-::  Reels3 on the sides, 1c Lsh to 4cnr, 1c finish on midline facing P (M above W).

25-::  1c set RHJ | set again, 1W pulling back RSh to turn under arms ; 1c pass RH, dance out the ends and cast R to (2,1,3) ', 5);
INSERT INTO 'dancecrib' VALUES (9320, '2016-09-23 14:48:17.917502+00', '2017-03-02 07:42:24.644996+00', 10592, 1, NULL, 'ace', '1--::

  1c lead down 2, cross and cast up round 3c, cross RH, cast up to top (1,2,3)

9--::

  1c set | turn RH to between 2c ; in line across 1c set to 2c | 1c (start down) turn 2c EH ¾ to (1,2,3)

17--::

  Reels3 on sides, 2c start out and up (1,2,3)

25--::

  1c+2c set to P | All cast R about to same place ; turn P BH ½ | Half Circle4 L to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2716, '2012-01-22 19:29:54.36999+00', '2017-04-17 20:45:17.48555+00', 4015, 1, NULL, 'ace', '1–::

  2c diagonal Reel4 with 1cnrs, at end dance Lsh round P to face 2cnrs

9–::

  2c diagonal Reel4 with 2cnrs (2cnr loop by the R) (to 1,2,3)

17–::

  1c+2c+3c »snowball« G-Chain (1c begin, 2 bars per hand) (to 3,2x,1)

25–::

  3c+2c ½ R&L ; 3c ½ Fig8 R (3M up, 3W down) (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (12992, '2020-07-26 03:03:49.313619+00', '2020-11-13 20:48:45.640855+00', 11661, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; ½ Fig8 up round 2c (2,1x)

9--::

  2c+1c S&Link twice. Both W face out (2,1x)

17--::

  2c+1c M-Chain (2,1x)

25--::

  2c & 1c set facing up/down no hands | set diagonally ; set to P | 1c cross RH (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (2725, '2012-01-22 19:29:54.776495+00', '2014-04-30 23:24:00.262169+00', 4008, 1, NULL, 'ace', '1–::
  1M/1W lead down and cross through 3c/2c, meet, dance up for ; 1M+3c LHA & 1W+2c RHA
9–::
  All C in promhold Reel3 across (1c Rsh to 2c)
17–::
  1M/1W dance out through 3c/2c and up to places ; all C turn LH, 1c turning 1½ (to W on right)
25–::
  1c+3c ½ R&L ; 3c+2c repeat (to 2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (8078, '2013-10-09 11:18:47.632349+00', '2017-11-11 00:31:54.110083+00', 14993, 1, NULL, 'ace', '1–::

  1c set adv | turn BH ; dance below 3c (2c up) cross and cast up to (2,1x,3)

9–::

  Teapots R and L (2c+1M & 1W+3c RHA ; 2C+1W & 1M+3C LHA) (2,1x,3)

17–::

  Al chase ½ cclw ; 3c+2c ½ R&L _while_{4} 1c cross RH and cast R to face 1cnr

25–::

  CPCP (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2739, '2012-01-22 19:29:55.461402+00', '2021-05-10 21:54:04.344514+00', 4106, 1, NULL, 'ace', '1–::

  1c+2c turn RH ½ into | ½ RHA into ; 2c+1c turn RH, 2c finish facing out (2,1,3)

9–::

  Opposing Reels3 on own sides (1c inwards, Rsh to 4cnr) 1c finish facing 1cnr, 2c+3c finish with loops

17–::

  SetH&G to (2,1,3)

25–::

  Circle6 L {3}, cross R foot over L and chase back cclw to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2726, '2012-01-22 19:29:54.816423+00', '2014-11-12 11:23:37.907815+00', 4051, 1, NULL, 'ace', '1–::

  1c lead down the middle (2c up) ; and up to 1st corners

9–::

  1c set to 1st corners | 6-bar Reel4 in 1st diagonal, at end pass Rsh to face 2nd corners

17–::

  Repeat with 2nd corners, 1c ends Rsh to 2nd place own side

25–::

  1M+3c and 1W+2c RHA, LHA (no change over of 1c)', 3);
INSERT INTO 'dancecrib' VALUES (2728, '2012-01-22 19:29:54.895601+00', '2021-05-11 10:59:48.323306+00', 4068, 1, NULL, 'ace', '1–::

  1c+2c set twice ; half RHA {4}

9–::

  2c+1c set twice ; half LHA {4}

17–::

  1c lead down {3}, up {3}, cast off to 2pl (2c up)

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (10695, '2018-04-24 18:49:09.395991+00', '2020-11-14 10:54:44.282251+00', 18289, 1, 202, 'ace', '1--::

  1c+3c A&R ; 1c change places with 3c making an arch, both curving out to face in, W on M''s left (3x,2,1x,4)

9--::

  1c & 3c turn P RH into promhold | chase cclw to original places | turn P RH _while{8}_ 2c & 4c Petronella turn | set ; Petronella turn | turn RH ½ to places (1,2,3,4)

17--::

  2c+4c repeat [1-8], 4c making arch (1,4x,3,2x)

25--::

  Repeat [9-16] with exchanged figures (2c & 4c turn P RH... 1c & 3c Petronella turn...) (1,2,3,4)

33--::

  1c+2W & 3c+4W Circle3 L ; 2c+3W & 4c+1W Circle3 R (1,2,3,4)

41--::

  2c in promhold+1M+3W & 4c in promhold+3M+1W Reels3, 2c(4c) starting Rsh to 1M(3M)

49--::

  2c+4c RHA ; in promhold, dance round each other Rsh loop R to (1,4,3,2)

57--::

  1c+3c repeat [49-56] with LHA and Lsh (3,4,1,2)



*Repeat once more from new places with 2C & 4C starting*', 2);
INSERT INTO 'dancecrib' VALUES (2729, '2012-01-22 19:29:54.935517+00', '2020-12-10 00:08:49.620122+00', 4073, 1, NULL, 'ace', '1–::

  ½ RHA | cross RH ; circle 4H L (2,1)

9–::

  ½ LHA | cross LH ; set to P | 1c cast off into promhold facing up _while_ 2c dance up and face out

17–::

  Reel3{6} across, 1c Rsh to 2W | 1c dance up and turn inwards _while_ 2c dance in to 2pl NHJ

25–::

  1c+2c Rondel', 4);
INSERT INTO 'dancecrib' VALUES (2735, '2012-01-22 19:29:55.302508+00', '2020-12-10 09:49:11.333509+00', 4100, 1, NULL, 'ace', '1–::

  1M sets and cast off (2M up) _while{4}_ 2W sets and casts up (1W down) ; 1W+2M repeat (1,2,3)

9–::

  1c+2c Reel4 across, finish (2,1,3), 1c start by passing Lsh in the middle, 2c join in on [11],at end both M pivot R, 2W pivots L

17–::

  1c+3c repeat [9-16] (2,3,1)

25–::

  1c+3c set, 1c cast up _while{2}_ 3c step down ; 2c+1c+3c turn BH', 3);
INSERT INTO 'dancecrib' VALUES (2738, '2012-01-22 19:29:55.421495+00', '2020-12-26 09:59:50.072755+00', 14021, 1, NULL, 'ace', '1–::

  1c+2c S&Link (2,1,3) ; 1M with 1W following cast R round 2M, finish 1M between 3c and 1W between 2c

9–::

  1W+2c & 1M+3c ½ Lsh Reel3 across ; 1M with 1W following cast R round 3Mpl to (2x,1x,3x)

17–::

  ½ Lsh Reels3 on the sides, (1c starts up) ; 1c turn RH and pull back Rsh to face 1cnr _while{4}_ cnrs chase clw ½ to own places

25–::

  1cnrs pass and turn, pass Rsh ; 2cnrs pass and turn (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14037, '2021-05-21 20:46:01.251242+00', '2021-05-21 20:51:06.155716+00', 3287, 1, 202, 'ace', '1--::

  1c & 3c Petronella turn | set ; ½ Reel4 on midline. On [7-8] 1M+3W turn LH ¾ into line3 across

9--::

  Reel4 across with 2c. On [16] 1M & 3W finish on midline facing P

17--::

  3c & 1c Petronella turn | set (to 3,2,1) ; 1c(+2c+3c who dance down to follow) cast up to places (1,2,3)

25--::

  1c+2c lead down between 3c ; cast up, lead up to top | 1c cast off (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3812, '2013-07-13 15:56:12.82716+00', '2014-04-30 23:24:00.535724+00', 14280, 1, NULL, 'ace', '1–::
  1c set | 1M with 1W following casts off, crosses up between 2c | 1M casts off behind 2W as 1W dances up, 1c finish on midline in diamond pattern with 2c, 1W above facing 1M below
9-12::
  1M+2W & 1W+2M set | 1M+2M & 1W+2W set ;
13-16::
  1M dances up as 2M dances across, both take P in promhold and loop L to finish 1c in 2pl facing W side and down and 2c in 1pl facing M side, on [16] 3c step into promhold facing up
17–::
  All in promhold Reel3 on midline, finish (2,{1},3) with 1c in the middle LHJ facing 1cnr
25–::
  1c cast Lsh round 1cnr to 2plx ; turn P RH 1½ (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9656, '2017-03-17 00:17:36.388748+00', '2020-10-31 12:10:11.764247+00', 17487, 2, 1505, 'ace', '1-8:: 1st Turn R, cast to 2nd place and turn L to face 1st corners. 2s step up on 3 and 4

9-16:: Set to corners and partner (Hello Goodbye) ending 1M above, 1L below, left shoulder to left shoulder

17-24:: RHA once around. Supporting couples chase halfway as 1s turn L 1 1/2 to face 1st corner position

25-32:: 1s dance half reel of 4 with 1st corners, pass Right shoulder to dance reel of 4 with 2nd corners, end passing R shoulders to progressed places', 0);
INSERT INTO 'dancecrib' VALUES (2722, '2012-01-22 19:29:54.663956+00', '2015-03-25 10:58:27.372253+00', 4046, 1, NULL, 'ace', '1–::

  1c+4c set facing diagonally | 1W+4M cast R round own sideline and meet with ¾ RH turn in the middle, to places _while{6}_ 1M+4W make that turn and cast R round own sideline to places

9–::

  All dance Reels4 on the sides to finish (1,2,3,4) facing up/dn

17–::

  Middles (2c+3c) turn ends RH ½ way to form a St Andrew''s Cross (1c+4c retain RH and give LHA in the middle) | all set ; continue turns once round RH, at the end 1c+4c pass Rsh on own side to end (2,4,1,3) (1M+4W with polite turn)

25–::

  (Middle couples solo:) 4c+1c set, Women cross NHJ and face ends _while{2}_ Men cross over outside them and turn inwards to join P ; 4c(1c) lead up RH (lead down LH) between 2c(3c), cross and cast to 2pl(3pl) (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3636, '2012-08-10 14:09:23.358402+00', '2015-03-27 21:19:59.433601+00', 9911, 2, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; turn LH to face 1cnrs

9–::

  1c ½Reel4 with 1cnrs (pass P Rsh) ; Repeat with 2cnrs

17–::

  Repeat with 3cnrs (1cnr person) ; Repeat with 4cnrs (2cnr person)

25–::

  1W+2c & 1M+3c Reels3 across, Lsh to 1cnr

33–::

  2c+1c+3c circle6 and back



{{explanation}}

Note: Variant of “Mairi’s Wedding”, where 1c passes Rsh for [9-24]', 3);
INSERT INTO 'dancecrib' VALUES (2733, '2012-01-22 19:29:55.111227+00', '2018-11-13 01:47:49.180656+00', 4092, 1, NULL, 'ace', '1–::

  1c Rsh fig8 on own side round 2c & 3c

9–::

  1c+2c A&R ; RHA (1,2,3)

17–::

  1c with 2c following lead down the middle and up (2c leading) (2,1,3)

25–::

  Turn CPCP (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10149, '2017-09-24 16:25:41.413868+00', '2017-09-24 16:25:41.413868+00', 6222, 2, 160, 'ace', '1-8::  1s+2s set, turn RH, set.
9-16::  1s followed by 2s lead down the middle; 2s followed by 1s lead up to progressed places.
17-24::  2s+1s LHA; 1s+3s RHA.
25-32::  6 hands round & back.', 3);
INSERT INTO 'dancecrib' VALUES (9321, '2016-09-23 15:08:13.483463+00', '2017-03-03 21:28:18.846493+00', 16685, 1, NULL, 'ace', '1--::

  All turn P RH ½ | twirl out to opposite side ; All chase clw ½ (3,2,1)

9--::

  Lsh ½ Reels3 on the sides, 2c starting in and L (the leading cnr casts into the reel) (1,2,3) ; 1c (start outwards) turn 2c EH ½ | All set (2,1,3)

17--::

  2c+1W & 1M+3c RHA ; 1c dance to top and cast off (2,1,3)

25--::

  All turn P LH ¾ | BiL ; Turn LH to own side | All set (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10148, '2017-09-24 16:14:13.734417+00', '2018-02-19 00:44:33.229801+00', 5478, 2, 160, 'ace', '1-8::  1s+2s RHA; LHA.

9-16::  1s lead down&up.

17-24::  1s+2s set, turn BH; dance 4 hands once round to the L.

25-32::  1s cross RH, cast (2s up); cross RH, all set.', 3);
INSERT INTO 'dancecrib' VALUES (2926, '2012-01-22 19:30:03.214412+00', '2020-06-20 19:43:48.43448+00', 4940, 1, NULL, 'ace', '{{explanation}}

C face C RR, 1c faces clw, 2c cclw



1–::

  1c dance Fig8 round 2c (cross to start, use EH)

9–::

  2c repeat round 1c

17–::

  1c+2c R&L, 2c finish facing out

25–::

  Reel3 across, 1c in promhold start Rsh to 2m, at end meet next C', 3);
INSERT INTO 'dancecrib' VALUES (3813, '2013-07-13 15:56:12.976436+00', '2019-02-15 16:05:22.706139+00', 9724, 1, NULL, 'ace', '1–::

  All set | 1c+3c pass person opposite Lsh _while_{2} 2c+4c chase ¼ clw ; 4c+3c & 1c+2c Circle4 L

9–::

  Parallel Reels4 up/down

17–::

  4c+3c & 1c+2c RHA ; 4c+2c chase ¼ clw _while_{2} 3c+1c ½ LHA (into lines across, all face middle, NHJ with opposite) | All set

25–::

  Middle pairs swivelling inwards cross out between side pairs, and cast into square set (3,4,1,2) ; 1c+3c turn P BH | All circle8 clw ¼ (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2641, '2012-01-22 19:29:51.164054+00', '2019-02-21 21:59:07.161368+00', 9818, 1, NULL, 'ace', '1–::

  1c (long) cast behind 2c, dance in front of 3c, behind 4c (2c+3c+4c up (2,3,4,1)

9–::

  All circle L (2,3,4,1)

17–::

  1c (long) cast up behind 4c, dance infront of 3c, behind 2c (2c+3c+4c down) (1,2,3,4)

25–::

  1c set | cast to 4pl (2c+3c+4c up) ; All turn P RH', 3);
INSERT INTO 'dancecrib' VALUES (3657, '2012-12-03 22:16:05.819212+00', '2016-06-03 13:59:37.362616+00', 14602, 2, 1, 'ace', '1–8::

  1c+2c set twice ; RH across, finishing NHJ w/partner, 1c facing down, 2c facing up

9–16::

  1c+2c set twice up and down ; LH across, finishing in original places

17–24::

  1c lead down{3}, up{3}, cast off (2c up)

25–32::

  Circle4 round & back', 5);
INSERT INTO 'dancecrib' VALUES (2743, '2012-01-22 19:29:55.590812+00', '2014-04-30 23:24:00.602076+00', 10316, 1, NULL, 'ace', '1–::
  1c cross RH | cast (2c up) ; cross LH | cast L round 4cnr to join with P LH and 1cnrs RH
9–::
  The Spoke (set R, set advancing L to next corner, repeat 3 times) and finish as at start of figure but no hands
17–::
  Reels3 on sides, 1c starting Lsh to 2cnr, finish facing 1cnr
25–::
  diagonal Reel4 with 1cnrs, 1c finishes in middle facing up RHJ, 1M on the right (2, 1x in middle, 3)
33–::
  Mirror Reels3 on own side (1c lead up and cross at top, 2c dance out and down, 3c cast up) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2744, '2012-01-22 19:29:55.640892+00', '2014-04-30 23:24:00.617182+00', 12309, 1, NULL, 'ace', '1–::
  1c cross RH and cast off (2c up) ; All set  | 1c turn LH to face 1cnr
9–::
  SetH&G , making RH turn on [15-16] to face out (2,1,3)
17–::
  1c chase clw ½ round  _while_{4}    cnrs on 1diag cross RH | cnrs on 2diag repeat (3x,1x,2x) ; ½ Reels3 on opp. side (Lsh to 1cnr pos)
25–::
  ½ Reels3 across (1c Lsh to 3cnr pos) ; 1c turn RH | cast off (3c up)  (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (9894, '2017-05-29 14:43:44.336634+00', '2017-05-29 14:43:44.336634+00', 17771, 2, NULL, 'ace', '1-8::

    1c and 2c dance R & L, 1M + 2W finish facing out.

9-16::

    LSh Reels3 on sides.

17-20::

    1W+2W, 1M+2M turn LH 1 ½ .

21-24::

    1c + 3c RHA

25-32::

    1c + 3c Circle4 and back', 4);
INSERT INTO 'dancecrib' VALUES (2760, '2012-01-22 19:29:56.312704+00', '2015-04-05 12:23:17.769027+00', 4239, 1, NULL, 'ace', '1–::

  Mirror Reels3 on the sidelines (1c cross down) (1x,2,3)

9–::

  1c cross back into mirror Reels3 on own sides

17–::

  1c cross RH | cast (2c up) ; ½ Fig8 round 2c

25–::

  1c dance down between 3c and cast up to 2pl ; 2c+1c+3c turn RH', 3);
INSERT INTO 'dancecrib' VALUES (2723, '2012-01-22 19:29:54.696709+00', '2020-01-19 13:14:46.888301+00', 708, 1, NULL, 'ace', '1–::

  Reels3 on the sides, 1c cross down to start, finish 1c facing 3c (1x,2,3)

9–::

  1c+3c M-Chain up/dn the middle (1x,2,3)

17–::

  1c set | cast off (2c up) ; turn RH 1½ to 2pl (2,1,3)

25–::

  2c+1c+3c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (13947, '2021-04-10 11:49:32.725266+00', '2021-04-10 11:49:43.224353+00', 6485, 1, 1645, 'ace', '1-::

  1M+4W change places LSh ; 1W+4M repeat RSh (4x,2,3,1x)

9-::

  1c cast up to 1pl _while_ 4c dance down to 4pl ; 1c & 4c turn P 1&frac12; RH (1,2,3,4)

17-::

  1c+2c set | &frac12; RHA ; 1c+3c set | &frac12; LHA

25-::

  1c+4c set | &frac12; RHA ; all turn P 1&frac12; RH (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (8202, '2014-02-14 13:29:37.80815+00', '2016-06-03 14:06:56.296465+00', 15336, 2, 1, 'ace', '1–4::

  1c turn ½ RH moving down to 2pl (2c up) | 1c set, pulling RSh back to face 1st corners

5–16::

  Dance to each corner and set (1c finish facing partners in centre in 2pl)

17–20::

  1c set and turn ¾ LH _while_ 2+3c chase clockwise half-way

21–24::

  1M+3c, 1W+2c dance RH across (to 213 on sidelines)

25–::

  Circle6 and back', 5);
INSERT INTO 'dancecrib' VALUES (2745, '2012-01-22 19:29:55.692164+00', '2017-07-07 14:19:41.769342+00', 4144, 1, NULL, 'ace', '1–::

  1c+2c set | cross RH ; set | cross RH

9–::

  1c lead down the middle and back (1,2)

17–::

  1c+2c ½ RHA | set ; ½ LHA | set advancing into

25–::

  1c+2c All Round Poussette (1,2)

33–::

  1c+2c circle4 and back

41–::

  1c+2c Allemande', 3);
INSERT INTO 'dancecrib' VALUES (8289, '2014-06-23 14:27:08.392434+00', '2018-02-28 17:03:50.159251+00', 13680, 2, 1, 'ace', '*3c & 4c start on opposite sides (1,2,3x,4x)*

1–::

  1c&4c set | cast in (2c&4c to ends) ; 1c&4c dance ½ fig8 round 2c/4c to fin 21x43x.

9–::

  1c+4c set&link ; Circle4 to L

17–::

  2c+4c & 1c+3c reverse set&link ; 2c+4c & 1c+3c Circle4 to R (fin 423x1x)

25–::

  »Double Helix«: All set adv past partner (LS) ; pull RS back and cast to original sideline |

  turn ½ RH ; 4c+2c & 3c+1c ½ RH across (fin 241x3x)', 3);
INSERT INTO 'dancecrib' VALUES (2756, '2012-01-22 19:29:56.149013+00', '2021-05-09 11:26:54.869996+00', 4227, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; cross RH | cast R to finish 1W between 2c facing 1M between 3c

9–::

  1c set to P | turn RH to finish between cnrs ; set | turn RH to face 1cnr

17–::

  Set to and turn corners

25–::

  1c Lsh Reels3{6} with corners | cross to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2750, '2012-01-22 19:29:55.89272+00', '2019-03-15 01:07:00.462452+00', 4190, 1, NULL, 'ace', '1–::

  1c+4c cast inwards | 1c+4c cross cross between 2c and 3c, 1W+4W with NHJ and 1M+4M passing outside them ; 1c+4c dance outside the lines 4pl/1pl (1c passing outside 4c) | 4c+1c cross (4,2,3,1) 

9–::

  2c+3c lead out up/down and cross, cast in ; 2c+3c half R&L (to 4,3,2,1)

17–::

  4c+3c & 2c+1c Circle4 L ; ½Reels4 on the side (to 1,2,3,4)

25–::

  1c+2c half RHA, 1c+3c half LHA ; 1c+4c half RHA, all C cross RH (to 2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2747, '2012-01-22 19:29:55.773779+00', '2019-04-20 10:41:29.453482+00', 4165, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; turn LH to face out and L on own side

9–::

  2c+3c 1½ RHA, | [15-16] dance clw to next corner (Men in 3pl, W in 2pl) _while_{8}   1c dance cclw to 2pl {6} | turn LH to face 2cnr positions

17–::

  SetH&G (to 2cr and 3cnr positions), end with petronella into lines across (all W facing down, Men up)

25–::

  All NHJ coupé pas de basque (R and L) ; all set swiveling R ½ | All chase ¼ clw to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12501, '2020-01-12 12:55:51.591868+00', '2020-01-12 13:07:58.849372+00', 19737, 1, 202, 'ace', '1--::

  1c & 3c lead down {3}, lead up {3} and cast off to face 1cnrs (2c & 4c up)

9--::

  Corner Chain on 1diag

17--::

  Corner Chain on 2 diag. On [23-24] 1c turn P LH ¾

25--::

  2c+1W & 1M+4c+3W & 3M+5c RHA ; 1c & 3c turn P LH ½ and cast off (4c & 5c up) (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (9893, '2017-05-29 14:35:42.08452+00', '2017-05-29 14:35:42.08452+00', 17770, 2, NULL, 'ace', '1-4::

    1c dance down and 4c dance up 1 place, while 2c cast up and 3c cast down;

    1c + 4c dance ½ circle to the left.

5-8::

    4c + 1c turn partner BH and finish NHJ 4c facing up, 1c facing down.

9-20::

    4c + 1c take hands in promhold. All dance 3 x ½ Reels of 3 across the dance

    (to right to start, then left, then right) with 1c + 4c changing partners in centre at

    end of each ½ Reel to progress Men clockwise & Women anticlockwise. 1c

    on women''s side, 4c on men''s side.

21-24::

    2M+1W and 4W+3M turn RH, while 2W+4M and 1M+3W turn LH.

25-32::

    1c + 4c dance the Tournéé to finish on the sidelines in the order 2,4,1,3 (to begin

    they take hands in promhold and dance into the centre).

33-40::

    2c+4c dance ½ RHA, while 1c+3c dance ½ LHA. All set. 4c+2c dance ½ LHA,

    while 3c+1c dance ½ RHA. All set.

41-44::

    While 2c dance ½ Fig8 crossing down to 2nd place to begin, 4c cast up one

    place and dance down one place and 1c + 3c dance ½ double Fig8 (1c start

    by casting down one place, 3c by crossing up).

45-48::

    2W+4W and 1W+3W turn LH, while 2M+4M and 1M+3M turn RH.', 0);
INSERT INTO 'dancecrib' VALUES (3670, '2012-12-23 14:01:02.042984+00', '2014-04-30 23:24:00.859216+00', 4233, 1, NULL, 'ace', '1–::
  1c cross down and out the sides (no hands) (2c up) | turn 3c EH ; cross up and out the sides | turn 2c EH to DTr position
9–::
  Set as in DTr | turn person on R (=3cnr), and take DTr position facing opp. side ; set as DTr | turn 1cnr RH to face 4cnr
17–::
  Lsh Reels3 across, finish facing 3cnr (2,1,3)
25–::
  Rsh Inveran Reels3 on the side, 1c crossing to opp. side on [3-4] and back on [7-8] (2,1,3)

{{explanation}}
On second time through, 1c dance to 4pl and 4c finish in 3pl', 3);
INSERT INTO 'dancecrib' VALUES (2759, '2012-01-22 19:29:56.272099+00', '2014-04-30 23:24:00.874205+00', 4236, 1, NULL, 'ace', '1–::
  1c cross RH | cast off (2c up) ; cross LH | cast L round 4cnr , finish BtoB facing 1cnr
9–::
  1c set to and turn 1cnr RH ; repeat with 2cnr, finish BtoB (M facing up, W down)
17–::
  Crown triangles {6 bars: set up/dn | opp. side ; dn/up } | petronella to 2pl
25–::
  2c+1c+3c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (9810, '2017-04-25 18:28:51.27026+00', '2020-09-18 16:35:48.868892+00', 13556, 1, 202, 'ace', '1--::

 1c turn RH | cast (2c up) ; ½ Fig8 to R (2,1x,3)

9--::

 1c teapots R ; teapots L to face 1cnrs

17--::

 1c set to 1cnr | turn BH to face 2cnr ; set to 2cnr | turn BH to (2,1x,3)

25--::

 Reels3{6}, 1c Lsh to 1cnrs | 1c cross RH', 2);
INSERT INTO 'dancecrib' VALUES (2755, '2012-01-22 19:29:56.109662+00', '2020-12-12 10:42:26.118249+00', 4223, 1, NULL, 'ace', '{{explanation}}

Couple facc Couple RR



1–::

  All C set NHJ | turn person opposite BH, opening to face P ; repeat, now turning P and opening to original positions

9–::

  RHA ; LHA

17–::

  L-Chain

25–::

  CCLW couples set to P _while{2}_ CLW couples lead to next CLW place | all C turn RH ; CLW couples set to P _while{2}_ CCLW couples lead to next CCLW place, all C turn RH', 2);
INSERT INTO 'dancecrib' VALUES (2752, '2012-01-22 19:29:55.972082+00', '2020-12-20 11:20:08.514392+00', 9008, 1, NULL, 'ace', '1–::

  1c (start inwards)+2c mirror turn on sides 1½ ; 1c cast behind 3c | dance up to 2pl BtoB facing own side for

9–::

  DTr, but on [15-16], 1c (on opposite side) set turning right about to face P

17–::

  1c BHJ, slip down the middle & up to 2pl in the centre, facing up

25–::

  1W+2M+3M LHA _while{4}_ 1M+2W+3W RHA ; 1c ½ Fig8 up round 2c (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13554, '2021-01-16 18:15:11.108007+00', '2021-01-16 18:19:19.100243+00', 12094, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; turn LH (2,1x,3)

9-12::

  2c+1M & 1W+3c RHA (2,1x,3)

13-20::

  Reels3 on sides, 1c RSh to 2cnrs

21-24::

  Repeat [9-12] (2,1x,3)

25--::

  1c turn LH ; cast off (3c up) | cross RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2751, '2012-01-22 19:29:55.932811+00', '2021-05-09 18:00:44.149863+00', 4196, 1, NULL, 'ace', '1–::

  1c followed by 2c (dance up to start) lead down the middle ; and up, 2c leading, to exchanged places

9–::

  2c+1c+3c circle6 and back, finish 1c facing 3c for

17–::

  G-Chain (2c crossing)

25–::

  1c set twice ; dance down, divide and cast up to 2pl (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2528, '2012-01-22 19:29:46.376431+00', '2021-05-23 12:31:32.517561+00', 3338, 1, NULL, 'ace', '1–::

  1c+2c+3c set and cross RH ; repeat (1,2,3)

9-20::

  R&L for 3 couples, at end 1c face up in 1pl NHJ

21-24::

  1c long cast (2c up) to finish on 1diag, LH joined with P and RH with 1cnr

25–::

  THE SPOKE: 1c keeping LHJ BiL with 1cnrs {1} move on {1}, repeat with 2cnr ; with 3cnr, with 4cnr (all set for 8 bars)

33–::

  1c dance ½ Fig8 across, starting Lsh to 1cnr ; 1c turn LH 1½ to (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (12449, '2019-12-26 12:06:49.219895+00', '2019-12-29 10:53:22.623606+00', 17401, 1, 202, 'ace', '1--::
  1c cross RH | set ; cross down LH to 2pl | set _while{8}_ 2c set | cross RH ; cast up | cross LH (2,1,3)
9--::
  1c turn P RH 1½ to 2pl centre facing P | set and cast to 2plx facing in (2,1x,3)
17--::
  »Modified Corners Pass and Turn« [: same as Corners Pass and Turn except that 1c dance Fig8 on opposite sides, RSh to 2cnrs. On [17-20] 2cnrs dance in and turn RH back to places. On [21-24] 1cnrs dance in and turn LH back to places] (2,1x,3)
25--::
 1c turn P LH ; chase cclw to 2pl _while{8}_ all cnrs chase cclw to places (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (9153, '2016-06-04 16:16:41.811649+00', '2016-06-04 17:40:57.097921+00', 8986, 1, NULL, 'ace', '{{explanation}}

5 dancers in a square, 1+3 head, 2+4 on sides, 5 in middle facing 1

1--::

  1+5+3 Rsh Reel3

9--::

  4+5+2 Lsh Reel3 

17--::

  1+5 set | change places RH ; 1+4 repeat

25--::

  4+3 repeat ; 3+2 repeat (5,3,4,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (12912, '2020-07-01 00:19:13.246426+00', '2023-02-12 16:18:11.261159+00', 1552, 3, NULL, 'ace', '1-8::

    1s & 4s cross RH, cast down/up (2s & 3s step up/down).  1s+4s cross

    LH with partner & 1s+4s change places RH on sides, face in

    diagonally

9-16::

    1s+4s dance Petronella turn & set twice to end 2 (1) (4) 3

17-20::

    1L+2L also 3L+4L change places RH then 1M+2M also 3M+4M change

    places RH

21-24::

    2s+3s cross RH with partners. All 4 couples set advancing to meet

    partner.  (1) (2) (3) (4)

25-32::

    All dance Poussette, 1s to 4th place, 2s+3s+4s moving up 1 place.  2

    3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (2659, '2012-01-22 19:29:51.930457+00', '2016-11-02 17:24:04.89241+00', 5160, 1, NULL, 'ace', '1–::

  1c (long) cast off (2c up) ; 1c+3c Circle4 left

9–::

  1c cast to the top (2c down) ; 1c+2c Circle4 left

17–::

  1c lead down {3}, up {3} | cast into 2pl (2c up)

25–::

  2c+1c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2700, '2012-01-22 19:29:53.635638+00', '2017-07-07 13:37:32.975119+00', 3934, 1, NULL, 'ace', '1–::

  1c+2W circle3 L (to places) ; 1c+2M circle3 L (to places)

9–::

  1c down the middle and up

17–::

  1c+2c Allemande, finish 1W between 2c facing 1M between 3c

25–::

  Set in lines across, 1c turning L to 2pl on [26] | all set ; 1c dance down | cast to 2pl

33–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (2767, '2012-01-22 19:29:56.583771+00', '2019-04-24 21:41:24.426426+00', 4293, 1, NULL, 'ace', '1–::

  1M+2W turn RH ; 2M+1W turn RH 1½ and finish between the first pair in line across, 2c on W side

9–::

  NHJ in line dance down (turn R about) ; and up, finish in the middle BHJ with P (1,2) 

17–::

  1c+2c Poussette (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (2762, '2012-01-22 19:29:56.385157+00', '2019-08-28 14:04:07.766077+00', 4248, 1, NULL, 'ace', '1--::

  1c turn RH | cast off (2c up) ; turn LH to face 1cnr

9--::

  1c+1cnrs ½Reel4 and pass Lsh ; repeat with 2cnrs, 1c finish on opposite side (3x,1x,2x)

17--::

  1c set | petronella turn to midline _while{4}_ 2c+3c petronella turn to midline | 2c+3c set, with 3W+2M setting BtoB changing places as in DTr ; repeat figure to sidelines.

25--::

  Repeat [17-24] (now 3M+2W change places while setting BtoB), but on [31-32] 1c advance to meet P on midline (1W above, 1M below) and face R, ready for 

33--::

  2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (9955, '2017-06-13 15:44:41.63259+00', '2021-08-02 19:54:51.158735+00', 14723, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

 1c & 4c set | cast inwards (2c & 3c step out) ; 1c+4c ½ R&L, 4M & 1M face out (2,4,1x,3x)

9--::

 4c+1c La-Chain, all finish on sidelines in reel4 position

17--::

 »Axum reel« (3,1,4x,2x)

25--::

 Repeat »Axum reel«, all finish on sidelines in reel4 position (2,4,1x,3x)

33--::

 The W and the M on sidelines turn LH ; all chase cclw ½ (3,1,4x,2x)



 *Axum Reel: Every 2 bars all dance to the next position along the path 1M, 2W, 1W, 3W, 4W, 3M, 4M, 2M, 1M, etc., passing other dancers Lsh.*', 2);
INSERT INTO 'dancecrib' VALUES (9154, '2016-06-05 09:39:59.267438+00', '2016-06-05 09:39:59.267438+00', 16965, 2, NULL, 'ace', '1-8::

  All join hands on side-lines and set to partners | All turn partner with right hand once round in 4 bars | All set, first step to partners and turn on second step into position to be ready for: 

9-16::

  All three couples dance Grand Chain, 1st couple start across the set.

17-24::

  All three couples dance Reel of three on own sides, 2nd man/woman giving right shoulders to 3rd man/	woman.

25-28::

  1st and 2nd couples set, 1st couple cross down with right hands to face 3rd couple while 2nd couple step up.

29-32::

  1st and 3rd couples set, 1st couple cross down with left hands to third places while 2nd couple step up.



', 5);
INSERT INTO 'dancecrib' VALUES (8084, '2013-10-12 16:41:05.998721+00', '2014-04-30 23:24:01.073903+00', 14976, 1, NULL, 'ace', '1–::
  1c set | cast off (2c up) ; ½ Reels3 across Lsh to 1cnr (2x,1x,3x)
9–::
  S&Link3 to lines across ; 1c turn LH to face 1cnr (pos.)
17–::
  1c+1cnrs ½ Reel4 , pass Rsh ; repeat with 2cnr, 1c crossing Rsh to (2,1,3)
25–::
  3c+1c The Knot (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2763, '2012-01-22 19:29:56.424954+00', '2021-05-09 10:28:53.852602+00', 4262, 1, NULL, 'ace', '1–::

  1c+2c+3c Mirror Reels3 on opposite side (all C cross from top), finishing (1x,2x,3x)

9–::

  1c cross RH | cast (2c up) ; ½Fig8 round 1cnr pos. (2x,1x,3x)

17–::

  ½Reels3 on the sides, 1c Rsh to 2cnr pos. ; All C set | turn RH ½ into

25–::

  3c+1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2761, '2012-01-22 19:29:56.35258+00', '2020-02-12 09:31:08.554936+00', 10789, 1, NULL, 'ace', '1–::

  1c cross RH and face out | 1c+3c ¾ of a double fig8 round 2c, 3c crossing up to start (to 3,2,1)

9–::

  2c+1c cross RH to sideline | ½ RHA ; 3c+1c repeat (to 1,3,2)

17–::

  1c+3c circle4 L, finish 3c in the sidelines and 1c NHJ facing down ; 1c dance down between 3c+2c, and cast up to 2pl (3c up)

25–::

  3c+1c+2c the Knot (to 2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3814, '2013-07-13 15:56:13.310548+00', '2014-04-30 23:24:01.165561+00', 10795, 1, NULL, 'ace', '1–::
  1c lead down {3}, up {3} cast off and cross RH (2c up) (2,1x,3)
9–::
  Reels3 on the sides, Rsh to 1cnr, 1c finish BtoB on midline, 1M facing up
17–::
  Half Crown Triangles, at end pull Rsh back (2,1x,3) ; 1c turn RH to finish BtoB on midline, 1M facing down
25–::
  Half Crown Triangles, at end pull Rsh back (2,1,3) ; 1c turn RH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12769, '2020-04-17 23:36:46.71101+00', '2020-04-17 23:45:21.239488+00', 17670, 1, 202, 'ace', '1--::

  1c+3c DblFig8 round 2c, 1c crossing down (1,2,3)

9--::

  2c Fig8 R, LSh to 1cnrs (1,2,3)

17--::

  1W Fig8, LSh round 2M then 1M _while{8}_ 2W (following 1W) Fig8, RSh round 1M then 2M to places (1,2,3)

25--::

  1M & 2M repeat [17-24] with P (1,2,3)

33--::

  1c ½ Fig8 down round 2c ; 1c cross down LHJ between 2c, behind 3c to 3pl (2c+3c up on [39-40]) (2,3,1)



*Deviser''s note*:  

If danced in a four couple set, first couple will then step to the bottom as the new 1st and 3rd couples begin the double figures of eight.', 2);
INSERT INTO 'dancecrib' VALUES (2772, '2012-01-22 19:29:56.786764+00', '2020-12-12 10:46:14.886917+00', 4312, 1, NULL, 'ace', '1-4::

  1c+3c set, Petronella Turn

5-12::

  ½Reel4 on the midline, at end 1M+3W pass LH ; 1M+2c+3W LHA _while{4}_ 1W+3M chase clw to change places

13-20::

  repeat 5-12, end facing partners

21-24::

  1c+3c 1¼ turn RH, finishing 1c RHJ facing 2c NHJ and 3c on the side for

25–::

  1c+2c Rondel, but on [29‑32] 3c set advancing, make arch and dance to 2pl as 1c dance to 3pl', 2);
INSERT INTO 'dancecrib' VALUES (2730, '2012-01-22 19:29:54.990473+00', '2021-01-17 00:39:26.430526+00', 13357, 1, NULL, 'ace', '1–::

  1c+2c set | 1c cross down as 2c cast up ; All set as in DTr | 1c turn 1cnr RH to finish between end C

9–::

  ½ Reels3 across, Lsh to 4cnr ; ½ Reels3 on sides, Rsh to 3cnr pos (cnrs make loops), 1c pass Lsh to face 1cnr pos.

17–::

  ½ Reel4 on 1diag 1c pass Rsh ; ½ Reel4 on 2diag (2,1,3)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (3869, '2013-07-27 15:20:30.767289+00', '2017-11-13 09:45:38.731785+00', 14346, 1, NULL, 'ace', '{{explanation}}

First Figure



1–::

  All M RHA 1¼ , cast R behind W of opposite C, and curve R to face her (

9–::

  All dance intersecting Reels 4 (no hands in the middle)

17–::

  All M Circle4 R and pivot L to face same W ; All set | turn RH ½ to change places

25–::

  Double targe (W ¾ LHA _while_{2} M 1 pl clw | M turn W RH ; repeat, at end finish in square set with W on L (with swapped partner)



{{explanation}}

Second figure  

Repeat 1-32 with M and W switched, finish with own P (3,4,1,2)  

Third figure



1–::

  All set to P | turn RH ¾ to promhold ; promenade ½ round to (1,2,3,4)

9–::

  1c+3c set | cast R in front of side c and face across ; Circle4 L ½ | M leading dance to places

17–::

  2c+4c repeat

25–::

  Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (12984, '2020-07-25 09:26:12.445664+00', '2021-10-16 12:00:15.491256+00', 14009, 2, 2784, 'ace', '*3c+4c cross on 2nd chord (1,2,3x,4x)*
1-::
  1c in promhold (1M on the R) Reel3 with 2c (Rsh to 2M) _while_ 4c in promhold (4M on the R) Reel3 with 3c (Rsh to 3M), on bar 8 1c+4c dance towards each other and pivot to put W on the R (promhold)
9-::
  2W+1c+4c+3W 1/2 Reel4, on bar 12 1c+4c pivot to put M on the R (promhold) ; 2M+1c+4c+3M 1/2 Reel4, on bar 16 1c+4c pivot to put W on the R
17-::
  Repeat bars 9-16 with next cnrs cclw but omit pivot on last bar
25-::
  1c+4c 1/2 RHA, 2c+4c+1c+3c set, turn RH, 2c+3c retaining hands in promhold ready to start reels (W on left of P)
', 2);
INSERT INTO 'dancecrib' VALUES (2777, '2012-01-22 19:29:56.986032+00', '2014-04-30 23:24:01.256133+00', 4325, 1, NULL, 'ace', '1–::
  1c turn RH, cast off one (2c up) ; turn LH, cast off one (3c up)
9–::
  1c lead down the middle (3c down) ; and up to face 1cnrs
17–::
  1c set to and turn corners
25–::
  2c+1c+3c Reel3 in sidelines (Lsh to 1cnr) {6} ; 1c cross (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3692, '2013-01-29 22:58:03.416472+00', '2014-04-30 23:24:01.271105+00', 4333, 1, NULL, 'ace', '{{explanation}}
Four dancers in square formation

1–::
  All RHA ; LHA
9–::
  1+3 turn RH ¾ | All BiL ; 1+3 turn RH ½ | All BiL
17–::
  Reel4 across, finish in own places
25–::
  All advance to centre in PdB | Set pivoting R to face out ; Petronella to 1 place clw | set (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (8905, '2015-09-16 12:08:24.856133+00', '2015-09-16 12:08:24.856133+00', 16737, 1, NULL, 'ace', '1-::  1c turn RH moving down (2c up on [1-2]) to face 2cnr ; 1c+2cnrs ½ Rsh Reel4, and 1c meet and pivot R to face 1cnr

9-::  1c+1cnrs ½ Reel4, at end 1c pivot R and finish BtoB on midline, W facing up, M down ; 1c dance out the ends and cast L to (3x,1x,2x)

17--::  All cross RH | chase ¼ clw ; All change RH up/down | All chase ¼ clw (2,1,3)

25--::  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10476, '2018-03-02 21:52:39.097802+00', '2018-03-02 22:03:37.989458+00', 13486, 1, 202, 'ace', '1--::

  1c+3c R&L _while{8}_ 2c & 4c set | ½ RHA ; set | ½ LHA

9--::

  All Petronella turn | set H.Schottische | turn P RH ½ , on [16] M pivot R to face P

17--::

  Double Reels4 (LHA in the middle), into promhold facing cclw (W pull Rsh on [24])

25--::

  All Promenade cclw ¾, finishing facing P RHJ | All turn P RH ¾ (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (2782, '2012-01-22 19:29:57.186954+00', '2017-07-07 13:26:48.11805+00', 4359, 1, NULL, 'ace', '1–::

  1c+2c set twice ; half R&L (2x,1x,3)

9–::

  Repeat [1-8], finish (1,2,3) for:

17–::

  1c+2c Poussette (2,1,3)

25–::

  1c lead down the middle {3} and up to the top {3}, cast off one to face 1cnr

33–::

  Turn CPCP (to 2,1,3)



{{explanation}}

(Note: In 25-32, the way up + cast is long, and a phrasing 2 down, 4 up, cast 2 both looks and feels better).', 2);
INSERT INTO 'dancecrib' VALUES (2779, '2012-01-22 19:29:57.066157+00', '2016-11-15 16:17:33.548737+00', 4336, 1, NULL, 'ace', '1–::

  1c cast off 2, lead up, cast off to 2pl (2c up)

9–::

  2c+1c+3c circle6 and back

17–::

  All C turn RH ; turn LH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3879, '2013-08-11 09:49:20.422257+00', '2017-01-03 15:07:51.572383+00', 15074, 1, NULL, 'ace', '1--::

  1c cross RH | cast (2c up) ; cross LH between 3c and cast up (2,1,3)  

9--::

  2c+3c R&L, starting along the sidelines _while{8}_ 1c ½ Fig8 up ; ½ Fig8 down, at end make quick turn LH ¾ to face the ends (1M up, 1W down)  

17--::

  Opposing Reels3 on own sides (LSh to 3cnr), finishing (2,1,3) into  

25--::

  All circle 6H and back.', 5);
INSERT INTO 'dancecrib' VALUES (10475, '2018-03-02 19:46:36.6444+00', '2021-04-14 10:36:16.045231+00', 17531, 1, 202, 'ace', '1--::

  1c cross down RH between 2c | cast up to 1plx ; turn 2c EH 1 ½, touching H when possible (2,1x,3)

9--::

  1c turn 3c EH 1 ½ ; 1c cross up RH between 3c | cast down to 3pl (2,3,1)

17--::

  3c+1c set | 1c cast up to 2pl _while{2}_ 3c dance to 3pl (to 2,1,3) ; 2c+1c repeat [17-20] (1,2,3)

25--::

  1c turn P RH ; cast (2c up) | all set (2,1,3)



*Deviser''s note:*



[17-24] are similar to Set and link.', 2);
INSERT INTO 'dancecrib' VALUES (2789, '2012-01-22 19:29:57.466868+00', '2014-09-25 13:34:23.091927+00', 7543, 1, NULL, 'ace', '1–::

  1M+2W cross RH | set ; cross back RH | set _while{8}_ 1W+2M set | cross RH ; set | cross back RH

9–::

  2M Reel3 across with 1c (start Rsh to 1W)

17–::

  2W Reel3 across with 1c (start Lsh to 1M)

25–::

  1W+2M cross RH, 1W+1M change places RH ; 1W+2W cross RH, 2W+2M cross RH', 3);
INSERT INTO 'dancecrib' VALUES (2685, '2012-01-22 19:29:53.028208+00', '2017-02-14 15:40:13.718892+00', 9816, 1, NULL, 'ace', '1–::

  1c+3c Petronella to midline and set to P ; Turn P RH 1¼ to places (1,2,3)

9–::

  2c Petronella and set ; 2c pass LH and cast Lsh round 3cnr to 2pl facing 3c (1,2,3)

17–::

  G-Chain , 1c cross to start

25–::

  All set | Circle6 L ½ round (3x,2x,1x) ; All set | 1c cross RH _while_ 3c+2c ½ RHA (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2784, '2012-01-22 19:29:57.265314+00', '2016-07-28 17:05:34.856576+00', 9029, 1, NULL, 'ace', '1–::

  1c+3c set, dance down 2 places (2c+4c up) ; cast up one place and cross RH to face 1cnrs.

9–::

  1c+3c turn 1cnr LH, P RH, 2cnr LH, P RH to face 3cnr

17-28::

  (twice »cnr set, pass & turn«) 1c+3c each RHJ in centre of own »box« set to 3cnr | 1c+3c dance clw round cnr''s place _while{4}_ cnrs turn RH and return to place | 1c+3c RHJ set to 4cnr ; »cnr pass and turn« with 4cnrs

29-32::

  1c+3c turn RH and cast off one place on own sides (4c+5c up).', 4);
INSERT INTO 'dancecrib' VALUES (2684, '2012-01-22 19:29:52.989194+00', '2022-12-10 12:48:48.210745+00', 3888, 1, NULL, 'ace', '1–::

  1M set adv. to 2W | turn RH and face 1W ; 1c turn LH (wide turn)

9–::

  1W repeats [1-8] with other hands

17–::

  1c dance between 2c, cast behind 3c and turn BH ; dance to top, cast off (2c up) and face 1cnr

25–::

  1c set to 1cnr | to 2cnr and face P ; turn BH 1½ to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13555, '2021-01-16 19:18:02.446943+00', '2021-01-16 19:25:40.405872+00', 12092, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA (to 2x,1x,3) ; 1c turn RH 1¼ to between 2c. 1c face own sides

9--::

  Reel4 across. On [16] 1c turn LH briefly ready for

17--::

  1c ½ Fig8, LSh to 1cnrs[pos] ; ½ Fig8, LSh to 3cnrs[pos] _while{8}_ cnrs set | cross RH ; repeat (2x,1,3) 

25--::

  1c+3c ½ R&L ; set | cross RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12770, '2020-04-18 00:32:11.330734+00', '2020-04-18 00:37:59.582531+00', 19869, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; cross RH | cast off (3c up) (2,3,1)

9--::

  Mirror Reels3 on sides, 1c in and up, 3c out and down. 1c face 1cnrs _as_ 3c loop to 3pl

17--::

  SetH&G (2,1,3)

25--::

  1c turn 4cnrs RH ; 1c turn 3cnrs LH (2,1,3)

33--::

  All A&R ; 1c+3c S&Link (2,3,1)

41--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (13948, '2021-04-10 18:08:15.497311+00', '2021-04-10 23:09:11.269858+00', 20308, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; cross LH | all set clapping on [8] (2,1,3)
9--::
  Reels3 across, 1c RSh to 2cnrs. 1c face 2cnrs
17--::
  1c set R to 2cnr {1} and L to P {1} | turn ¾ RH (to 2,1,3) ; ½ Reels on sides. 1c face 3cnrs[pos]
25--::
  1c set R to 3cnr[pos] {1} and L to P {1} | turn ¾ RH ; dance RSh round 4cnrs[pos]', 2);
INSERT INTO 'dancecrib' VALUES (2713, '2012-01-22 19:29:54.189282+00', '2017-07-07 13:56:30.466309+00', 3986, 1, NULL, 'ace', '1–::

  1c+2c RHA {3}, LHA (5), finishing one place further on, i.e. 1c on M side

9–::

  1c+2c BHJ slip to change sides, 1c passing below 2c | set (inside foot first) advancing 1c up, 2c down ; slip to midline, 1c above 2c | set making ¼ turn and retiring to places (1,2)

17–::

  1c cast off | 1c turn RH (2c up) ; 1c lead up _while_{2} 2c cast off | 2c turn RH

25–::

  1c+2c set | cross RH ; ½R&L', 2);
INSERT INTO 'dancecrib' VALUES (9324, '2016-09-23 20:04:40.275596+00', '2016-09-23 20:04:40.275596+00', 16473, 1, NULL, 'ace', '1--::

  1M+2M S&Link ; 2M+1M+3M ½ Reel3, 1M Lsh to 3M _while{4}_ 1W+2W S&Link

9--::

  1M+2M S&Link ; 3M+2M+1M ½ Reel3, 2M Lsh to 3M (finish 1,2,3) _while{8}_ 2W+1W+3W Reel3, 1W Lsh to 3W (finish 2,1,3)

17--::

  1M+1W following cast off, cross up, cast off round 2W and cross to 2pl (2M up) (2,1,3)

25--::

  2c+1c+3c Circle6 and back

', 4);
INSERT INTO 'dancecrib' VALUES (9322, '2016-09-23 19:04:50.068844+00', '2016-09-27 18:01:03.452605+00', 15051, 1, NULL, 'ace', '1--::

  1c+2c Poussette (1,2,3)

9--::

  1c+2c ½ RHA | Set diagonally ; twirl to sideline (2x,1x,3) | 1c turn RH to face 1cnr as 2c cross RH 

17--::

  1c+1cns "corners pass and turn" with the change "corners turn ½ RH and twirl to opposite corner" ; 1c+2cnrs repeat, to (3x,1,2x), 1c face out 

25--::

  Reels3{6} on the sides, 1c Rsh to 3cnr (pos) | 2c+3c cross RH (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (2737, '2012-01-22 19:29:55.381512+00', '2016-06-07 08:49:14.177073+00', 4103, 1, NULL, 'ace', '1–::

  1W+2W and 1M+2M set and change places RH ; repeat changing back LH

9–::

  1c lead down the middle {3} and up {3} ; cross and cast to 2plx (2c up) (2,1x)

17–::

  2c+1c ½ R&L ; ½ L-Chain (1c now on M side)

25–::

  1c+2c ½ M-Chain (2,1x) ; 2c turn RH _while{4}_ 1c turn RH 1½ (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (4890, '2013-08-21 08:30:56.49255+00', '2023-02-12 16:35:44.678718+00', 1499, 3, NULL, 'ace', '1-8::

    1s cross RH & cast 2 places, dancing in turn 3s 1.1/2 times by

    nearer hands to end between 2s & 3s on opp sides facing out &

    holding hands

9-16::

    2s+1s+3s set, 1s set & turn 1st corners, pass RSh to face 2s/3s

17-24::

    2s+1s+3s set, 1s set & turn 2nd corners, pass RSh to 2nd place own

    sides

25-32::

    2s+1s+3s chase clockwise 1/2 way, set & turn partner RH ready for

    Allemande

33-40::

    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (2781, '2012-01-22 19:29:57.146071+00', '2017-07-07 14:28:20.568636+00', 4358, 1, NULL, 'ace', '{{explanation}}

Part I ‑ Strathspey



1–::

  1c dance down the middle, cast up round 3c and 2c back to places ; 1c+2c turn partners RH {2}, then the two men and the 2 women change places giving LH.

9–::

  1c set advancing to face 1cnrs | turn 1cnrs RH ; 2cnrs LH, P RH to face 1cnrs



{{explanation}}

Part II ‑ Jig



17–::

  1c set to 1cnrs and then to each other across the dance ; 1c turn BH to face 2cnrs

25–::

  1c set to 2cnrs and then to each other up & down the dance ; 1c turn ¾ BH to 2pl.', 2);
INSERT INTO 'dancecrib' VALUES (2780, '2012-01-22 19:29:57.106007+00', '2017-09-11 20:44:05.904486+00', 4356, 1, NULL, 'ace', '1–::

  1c cast off behind own lines and back

9–::

  1c lead down the middle and up, 2c stepping in for

17–::

  1c+2c Poussette, 1c finish facing 1cnr for

25–::

  Turn CPCP

33–::

  2c+1c circle4 L ½ (slow!) ; 1c+2c ½R&L



{{explanation}}

on 33-36 good dancers can circle 1½ times round for fun', 3);
INSERT INTO 'dancecrib' VALUES (2524, '2012-01-22 19:29:46.210462+00', '2021-05-23 20:26:59.968382+00', 3317, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) & finish a bit inside sidelines ; set, swiveling L on [6] to face out | cast L (1W up, 1M down) into

9–::

  2c+1W & 3c+1M in lines across NHJ advance {1}, retire {1} | turn opposite person BH ; open into circle6 L once round

17–::

  1c ¾ turn RH | lead down ; lead up, cross and and cast off to (2,1,3).

25–::

  2c+1c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (12118, '2019-09-01 16:59:10.616036+00', '2019-09-20 23:36:01.653729+00', 19585, 2, 160, 'ace', '0   ::  begin 1 2x 3 4x
1-8::  1s2s also 3s4s RHA; all dance back to back with partner. 2and 3s face on the sides.
9-24::  Grand Chain 2 bars/hand - to begin 1s and 4s cross RH, 2s3s change RH on side. All home (1 2x 3 4x)
25-32::  1s2s also 3s4s - Ladies Chain. End 1M 4M facing out.
33-36::  1M followed by 1W and 4M followed by 4W chase half round as 2s3s advance&retire.
37-40::  4s2s also 3s1s dance LHA half round, all set (2 4x 1 3x)', 2);
INSERT INTO 'dancecrib' VALUES (14328, '2021-09-18 21:31:03.111059+00', '2021-09-18 21:31:14.275882+00', 931, 1, 1645, 'ace', '1-::

  1c set | cast off (2c up) ; 1W+2c & 1M+3c &frac12; LSh Reels3 across (2x,1x,3x)

9-::

  1c RSh Reels3 on side (2x,1x,3x)

17-::

  1M+2c & 1W+3c &frac12; LSh Reels3 across (2,1,3) ; &frac12; RSh Reels3 on own sides, 1c end facing up to 3c (3,1,2)

25-::

  3c+1c set | change pl RH (1,3,2) ; 1c+3c set | change pl LH (3,1,2). 1c repeat from 2pl

', 2);
INSERT INTO 'dancecrib' VALUES (2695, '2012-01-22 19:29:53.437028+00', '2017-07-07 14:02:56.194014+00', 3921, 1, NULL, 'ace', '{{title}}

Strathspey



{{explanation}}

part



1–::

  All C G-Chain (top and bottom cross to start)

9–::

  All C circle8 and back

17–::

  1c+2c & 3c+4c circle4 and back

25–::

  1c+2c & 3c+4c ½RHA ; ½R&L (1,2,3,4)



{{title}}

Reel



{{explanation}}

part



33–::

  All couples cross RH ; cross back

41–::

  1c+2c & 3c+4c Poussette right round, finishing with a full turn on [15-16] into

49–::

  1c+2c+3c+4c Promenade

57–::

  Parallel Reels4 on own side, 2c passing 3c Rsh at the end', 3);
INSERT INTO 'dancecrib' VALUES (8098, '2013-10-24 23:14:02.047233+00', '2014-04-30 23:24:01.531075+00', 14022, 1, NULL, 'ace', '1–::
  1c set adv | turn BH and face down ; dance down between 3c and cast up to 2pl (2c up)
9–::
  2c+1c+3c Allemande, to finish 1c turn RH to face 4cnr (3,1,2)
17–::
  3c+1W & 1M+2c Reel3{6} across, Rsh to 4cnr | 1c cast R round 4cnr into centre _while_{2} 3c & 2c A{1}&R{1} to P
25–::
  3c+1W & 1M+2c Circle3 L {3}, into all ½ Circle6 {3} | all cross to own side (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2794, '2012-01-22 19:29:57.664272+00', '2021-05-08 11:05:05.552857+00', 4422, 1, NULL, 'ace', '1–::

  1c lead down the middle and up, finish in the middle, facing 2W

9–::

  1c set to 2W, set to 2M ; 1c dance between 2c and cast up to top place

17–::

  1c+2c A&R ; turn P RH {4}, finish 1c facing 2c (1,2)

25–::

  ½ Rondel ; 2c+1c set and cross LH to own sides (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (9155, '2016-06-05 17:41:45.327267+00', '2020-07-17 08:21:48.864412+00', 16952, 2, 1, 'ace', '1–::

  1c&2c dance tourbillon (on 7–8, 1c turn R to face down, 1W on 1M''s R)

9–::

  1c dance down | set ; turn BH | dance up to 1st corners

17–::

  Corners pass & twirl (1st corners, pass RS, 2nd corners, pass RS to fin 3x,1,2x)

25–28::

  ½Circle6 to L (to 2,1x,3)

29–32::

  1c turn BH ½ & twirl _while_ 2c+3c turn BH (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11765, '2019-04-04 09:39:14.633192+00', '2019-04-04 09:42:10.679918+00', 8037, 2, NULL, 'ace', '1-8::

  1C & 4C turn partner RH & cast inwards (2C & 3C step out); 1C & 4C dance ½Fig 8 around new end couples (finish on diagonals facing “corners”//

9-16::

  ALL set, then 1C & 4C pull Rsh back & dance ½ way Clockwise inside set to other end of their diagonal; 1C & 4C pull Rsh back again to face new “corner”, then ALL set//

17-32::

  ALL dance Diagonal Reels of 4 with Setting (4C & 1C pass Rsh with 2C & 3C, then 4C & 1C set turning in whilst 2C & 3C dance ½LHA; repeat three times from new positions, finishing 2:4:1:3 on side lines.    



*from “Dartmoor Aide-Memoire and Cribs” by Bob Simkins*', 2);
INSERT INTO 'dancecrib' VALUES (3006, '2012-01-22 19:30:06.610109+00', '2020-12-29 11:40:03.764781+00', 5223, 1, NULL, 'ace', '1–::

  1c RHJ, M on L, cast round 2M, cross, cast down round 3W, and up the middle to 1pl

9–::

  1c lead down the middle (2c up) ; 1c dance up _while_ turning first RH, then LH to finish facing 1cnr (not quite full turns)

17–::

  1c turn 1cnr RH | pass Rsh ; turn 2cnr LH | cross to 2pl

25–::

  1c+3c circle4 L ; 2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (13558, '2021-01-17 17:08:39.169619+00', '2021-01-17 17:16:29.205135+00', 13158, 1, 202, 'ace', '1--::

  1c & 5c RSh Fig8 on own sides. 1W & 5M face out

9--::

  1W & 5M (P following) cast R and cross to 2plx/4plx (2c & 4c step out) ; 1c & 5c turn P LH 1½ (2,1,3,5,4)

17--::

  2c+1W & 1M+3c+5W & 5M+4c RHA ; 1c & 5c passing P RSh, 2c+1M & 1W+3c+5M & 5W+4c LHA (2,1,3,5,4)

25--::

  All cross RH (to 2x,1x,3x,5x,4x) | 1c+3c change LH on sides ; all cross RH (to 2,3,1,5,4) | 1c+5c change LH on sides (2,3,5,1,4)', 2);
INSERT INTO 'dancecrib' VALUES (2795, '2012-01-22 19:29:57.704168+00', '2014-06-10 21:43:06.056692+00', 4424, 1, NULL, 'ace', '1–::

  All clap, 1W+2W+3W dance Rsh once round P to face down with him RHJ ; All lead down the middle

9–::

  All M turn P under R arm and lead up to (1x,2x,3x) ; All set, ½ RH turn into

17–::

  1c+2c+3c Promenade (1,2,3)

25–::

  1c+2W RHA, 1M finishing 2pl own side (2M up on [3-4]) ; 1c+2M LHA (2W up on [7-8]) to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3181, '2012-01-22 19:30:14.718267+00', '2020-07-02 10:02:33.046033+00', 5817, 1, NULL, 'ace', '1–::

  1c cross down (2c up) | 2c+1c set ; RHA (2,1x,3)

9–::

  2c+1c+3c parallel Reels3 on the sides, start 1c Lsh to 3c

17–::

  1c+3c LHA ; 1c cross LH and set

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (9287, '2016-09-09 21:17:12.688487+00', '2019-12-29 11:12:59.509209+00', 991, 1, NULL, 'ace', '1--::

  1c turn RH moving down and face out (2c up) ; cast Rsh round 3cnr into facing lines across | All set

9--::

  2c+3c all petronella one place cclw round the square _while{2}_ 1c turn RH ¾ to 2pl | All Set on the sides ; 2c+3c petronella one place further cclw as 1c turn RH ¾, into lines across | All set to opposite

17--::

  All dance BtoB with dancer opposite; 1c turn BH twice to face 1cnr _while{4}_ 2c+3c ½ R&L starting along the sides

25--::

  1c set to 1cnr | to P ; to 2cnr| petronella to 2pl (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2792, '2012-01-22 19:29:57.585778+00', '2017-11-08 23:25:43.600419+00', 4411, 1, NULL, 'ace', '1–::

  1c+2c Poussette

9–::

  1c dance down 2 places, turn BH ; dance up 2 places, turn BH, open upwards and face out

17–::

  1c+3c DblFig8 round 2c, 1c casting, 3c crossing up to begin, 1c finish facing out for

25–::

  1W+2W & 1M+2M turn EH 1½ ; 1c+3c repeat (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3058, '2012-01-22 19:30:08.713555+00', '2020-12-25 12:49:21.000488+00', 12692, 1, NULL, 'ace', '1–::

  1c+2c set | 1c cast _while{2}_ 2c cross up (no hands) ; 1c+3c set | ½ RHA (2x,3x,1x)

9–::

  2M+1W change places RH | 2W+1M change places RH ; 3c cross | all set advancing into

17–::

  1c+3c+2c Allemande

25–::

  2c+3c+1c Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (8077, '2013-10-09 10:54:13.324273+00', '2017-11-10 23:50:53.442425+00', 14987, 1, NULL, 'ace', '{{explanation}}

alias: The Reverend Alan Grant



1–::

  1c lead down (2c up) ; and up to just above 3c | turn P RH into promhold facing up

9–::

  Reel3 across with 3c, Lsh to 3M, on [16] 2c dance in and all cpls face up in promhold (2,1,3)

17–::

  All Allemande, at end 1c petronella to facing lines across 1W above, 1M below

25–::

  All set | A&R (1+1) ; all change places up/down | 1c petronella to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3737, '2013-05-22 14:33:23.277843+00', '2018-11-26 00:29:58.744392+00', 14890, 1, NULL, 'ace', '1--::

  1c turn RH ; 1c+2c (leading) dance between 3c and cast up (2,1,3,4)

9--::

  1c turn RH ; 1c+3c dance up and cast off (2,3,1,4)

17--::

  All A&R ; 1c+4c dance up between 3c and cast off (2,3,4,1)

25--::

  Circle8 and back

33--::

  1c dance up behind own line to the top and dance down waving goodbye', 3);
INSERT INTO 'dancecrib' VALUES (10150, '2017-09-24 19:24:48.214178+00', '2017-09-24 19:28:38.416834+00', 17949, 2, NULL, 'ace', '*Strathspey*  

1-8::

  All four couples petronella turn to finish in line up and down the dance, all set; All four couples petronella turn to the opposite site, join hands on the side lines and set.  

9-16::

  1s with 2s, 3s with 4s circle once round to the left; finish and join hands on the side lines, set and cross RH to own sides.  All four couples clap twice on last two beats of the strathspey - bar eight.  



*Reel*  

17-24::

  All four couples set without giving hands; 1c cross RH, cast to end, cross RH to finish own sides in 4th place, 2s, 3s & 4s, joining hands on sidelines, step up on bars 5 and 6.

25-32::

  All clap eight times; all spin partner for four bars.  



Repeat with new top couple



', 5);
INSERT INTO 'dancecrib' VALUES (2798, '2012-01-22 19:29:57.831171+00', '2021-05-08 11:00:27.035443+00', 4438, 1, NULL, 'ace', '1–::

  1M+2W change places RH | 1W+2M repeat ; 2c+1c turn P RH 1½ to (2,1)

9–::

  1c lead down the middle and up, cast round 2c to (2,1)

17–::

  2c+1c set advancing | set  ; set retiring | set

25–::

  Circle4 and back', 3);
INSERT INTO 'dancecrib' VALUES (2805, '2012-01-22 19:29:58.147429+00', '2017-11-13 14:19:49.885749+00', 14351, 1, NULL, 'ace', '1–::

  1c+2c set & cross RH ; 2c followed by 1c dance down behind 3c, in and up the middle, 2c crossing to 1pl facing out, and 1c to 2plx in the centre facing up

9–::

  Mirror Reels3 on the sides, 2c starting up, and end couples finish with loops (2,1x,3)

17–::

  2c+1W & 1M+3c circle3 L, on [20] 1c pass Rsh to change circles (end couples keep NHJ) ; 2c+1M & 1W+3c circle3 R.  At end 1c swivel L to face P on midline, M above W

25–::

  1c set | petronella to 2pl ; All turn P BH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2797, '2012-01-22 19:29:57.783386+00', '2016-04-05 20:33:38.132953+00', 4434, 1, NULL, 'ace', '1–::

  1c+2c set | cross RH ; set | cross RH (1,2,3)

9–::

  1c lead down the middle (2c up) ; and up, on [16] 1W finish between 2c facing down _while_ 1M retires to between 3c

17–::

  In lines across all set | all set, 1c twirling L into 2pl ; All set twice (2,1,3)

25–::

  All Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (8169, '2014-02-06 15:07:43.2724+00', '2014-10-28 14:20:21.917777+00', 15333, 1, NULL, 'ace', '1–::

  1c lead to bottom (2c up) | cast up to 2pl ; ½ diag R&L on 1diag

9–::

  ½ Reels3 across, 1c Rsh to 4cnr ; 1c ½ Fig8, Rsh to 2cnr _while_{4} 3W+2M (= 1cnr persons) ½ Rsh Reel4 on 2diag (2x,1x,3x)

17–::

  2c+1M & 2W+3c RHA (teapots) ; ½ Diag R&L on 1diag

25–::

  ½ Reels3 across, 1c Rsh to 2cnr ; 1c ½ Fig8, Rsh to 4cnr _while_{4} 3M+2W ½ Rsh Reel4 on 2diag (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2519, '2012-01-22 19:29:46.009888+00', '2021-05-24 09:55:50.760662+00', 3280, 1, NULL, 'ace', '1–::

  1c cross RH, cast off into lines across (M down, W up) facing 4cnr (2c up) ; 1c set to 4cnr | 1c set to 1cnr

9–::

  1c, NHJ with 1cnr, A&R ; 1c NHJ with 4cnr, A&R

17–::

  All cross up/dn Rsh and face back (now 3c+1M above, 1W+2c below) | All set, 1c finish facing 2cnr ; ½ Reels3 across, Rsh to 2cnr, finish in lines across

25–::

  Repeat [17-24], with the ½ Reels Lsh to 4cnr

33–::

  1c turn RH 1½ ; 1c cast Lsh round 3cnr to (2,1,3)



{{explanation}}

Note:	«cnr« above refers to position, not person  

Note	There are many variants, e.g. on [4-16] take opposite order for 1cnr and 4cnr; [21-32] start the reels across with the other corner; [33-36] turn LH.  The text above follows the original, from Scottish Dance Archives #71', 3);
INSERT INTO 'dancecrib' VALUES (2808, '2012-01-22 19:29:58.268969+00', '2020-12-12 11:07:17.176965+00', 4477, 1, NULL, 'ace', '1–::

  1c+2c S&Link ; 2c+1c+3c set | 2c+3c set _while{2}_ 1c Petronella Turn into facing lines across, 1W (1M) between 2c (3c)

9–::

  All set | Lsh Reels3{6} on opposite sides, all C dancing in (1W turning towards P) to all finish NHJ in the middle (2,1,3), 2c facing down and 1c & 3c facing up

17–::

  All C S&Link with P, all finish NHJ, 1c facing down ; repeat S&Link , 2c & 3c finish in sidelines and 1c pass Rsh to face 2cnrs

25–::

  »2cnrs pass and turn« (1c fast RH turn to face 1cnrs) ; »1cnrs pass and turn« (1c to 2pl)', 3);
INSERT INTO 'dancecrib' VALUES (10263, '2017-11-20 15:01:00.933929+00', '2020-12-25 07:39:06.731081+00', 13373, 2, 645, 'ace', '1–8::
  1s cross RH, cast off, cross LH, cast to the left. 1L ends between 2s. 1M ends between 3s.
9–16::
  1L+2s facing down & 1M+3s facing up set. All chase cw 1/4 round. 3M+2L cross RH. 2s+3s XR.
17–24::
  All dance mirror reels of 3 on the side. 1s dance in and up to start.
25–32::
  All 6H round and back.', 2);
INSERT INTO 'dancecrib' VALUES (2806, '2012-01-22 19:29:58.189028+00', '2017-02-13 02:56:33.180891+00', 4461, 1, NULL, 'ace', '1–::

  1c cast off two, cross below 3c, cast up behind 3c (2c step up and face out) to (2,1x,3)

9–::

  2c+1c+3c NHJ in lines of 3 on each side dance ½ round (2c+3c in SkCh as 1c sets), on [12] 2c+3c turn about to give other hand ; the lines Turn back (in the centre, 3W dances slightly in front of 3M both times) (2,1x,3)

17–::

  Reels3{6} on the sides, 1c Rsh to 2cnr | 1c turn ½ RH moving up as 2c cast off into

25–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (2803, '2012-01-22 19:29:58.067191+00', '2017-07-07 12:41:41.541425+00', 4450, 1, NULL, 'ace', '1–::

  1M cast (2M up) and turn 3W LH, finish between 2W and 3W ; 1W cast (2W up) and turn 3M RH to (2,1x,3)

9–::

  2c+1c RHA ; 1c+3c LHA, 1c finish facing 1cnr

17–::

  1c set to and turn cnrs

25–::

  Opposing Lsh Reels3{6} on the sides, 1c cross RH', 3);
INSERT INTO 'dancecrib' VALUES (2800, '2012-01-22 19:29:57.925543+00', '2017-07-07 13:01:12.845996+00', 4442, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; 1c+3c circle4 L

9–::

  1c set | cast to top (2c down) : 1c+2c circle4 L (in some areas: R) (2,1,3)

17–::

  1c lead down, cross below 3c, cast up to top, cross back and cast off to face 1cnr (2c up)

25–::

  Turn CPCP, finish facing 1cnr

33–::

  Reels3 with corners (Lsh to 1cnr) {6} | 1c cross RH to 2pl facing out

41–::

  Reels3 on own side (1c Rsh to 3cnr) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2599, '2012-01-22 19:29:49.278707+00', '2017-07-07 14:00:48.183277+00', 3588, 1, NULL, 'ace', '1–::

  1W+2W dance between 1M+2M, cast round partners ; meet close to own side and turn each other BH | the M dance in and all turn partners BH

9–::

  1M+2M repeat

17–::

  1c lead down the middle and up

25–::

  1c+2c Allemande', 3);
INSERT INTO 'dancecrib' VALUES (2664, '2012-01-22 19:29:52.178165+00', '2017-07-07 14:02:22.438747+00', 3774, 1, NULL, 'ace', '1–::

  1M+2W change places RH ; repeat going back and finish making a BH arch

9–::

  1W dances down under the arch, followed by her P on bar 11 (2W falls back to 2pl) ; 1c lead up to the top

17–::

  1c+2c Promenade

25–::

  1c+2c Poussette.', 3);
INSERT INTO 'dancecrib' VALUES (14268, '2021-08-28 16:18:09.322137+00', '2021-08-28 23:44:04.885605+00', 15237, 1, 202, 'ace', '1--::
  1c turn RH | cast off (2c up) ; Petronella turn into facing lines3 across | all set
9--::
  1M+2W+3W & 1W+2M+3M RHA ; 1c turn LH ¾ to sides | all set (2,1,3)
17--::
  1c (+2c following) dance down between 3c, cast up and dance to top, cast off to face 1cnrs _while_ 2c loop to 1pl
25--::
  Corners Pass and Turn (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2811, '2012-01-22 19:29:58.385714+00', '2016-06-03 13:24:27.648145+00', 13301, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; ½Fig8 round 2c (2,1x,3)

9–::

  Mirror Reels3 on own sides, 1c crossing down to begin (2,1,3)

17–::

  1c, with 2c following, lead down , 2c divide ; 1c with 2c following lead up, finish 1c facing 2c NHJ

25–::

  »The Surge« [1c+2c advance {1}, retire {1} | 1c dance down as 2c split and dance up ; 2c+1c turn BH and stay close | 2c+1c cast R out to sidelines (as in Argyll Strathspey)]  (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2421, '2012-01-22 19:29:37.794549+00', '2017-09-24 22:49:17.542888+00', 2887, 1, NULL, 'ace', '1--::

  1c set | turn BH ; lead down (2c up) | cross between 3c and cast up to face 1cnr

9--::

  SetH&G{6}| 1c Petronella to 2pl while{2} 2c+3c cross RH (2x,1,3x) 

17--::

  1c cast 1M down & 1W up and in through the ends, while{4} 2M+3M & 2W+3W set and cross RH on sidelines ; 1c LH turn to face 1cnr while{4} 2c+3c ½ chase clw

25--::

  Turn CPCP (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2812, '2012-01-22 19:29:58.425048+00', '2016-11-15 16:19:48.822663+00', 4491, 1, NULL, 'ace', '1–::

  1c+2c+3c Circle6 and back

9–::

  1c set | cast off (2c up) ; 2c+1c+3c turn RH into

17–::

  2c+1c+3c Allemande (3,1,2)

25–::

  All A&R ; 3c followed by 1c cast off and 2c dance up to (2,1,3) (second time: 3c dance through 4pl to 3pl and 1c dance to 4pl)', 3);
INSERT INTO 'dancecrib' VALUES (9897, '2017-05-29 23:14:04.722371+00', '2018-09-19 09:49:50.679458+00', 17690, 1, 202, 'ace', '1-4::

 All A&R

5-16::

 3C R&L (1,2,3)

17--::

 1W+2W+3W pass P Lsh | chase cclw to W side | set _while_ 1M+2M+3M set | cross to P place ; chase cclw to M side (3,2,1)

25--::

 ½ Mirror Reels3 to opp sides, 3M Rsh to 1W & 3W Lsh to 1M, 2c crossing from top places (to 1,2x,3x) ; 1c+2c ½ RHA | 1c+3c ½ LHA (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2732, '2012-01-22 19:29:55.070706+00', '2014-06-08 19:31:35.602739+00', 4086, 1, NULL, 'ace', '1–::

  1c turn RH | cast off 2 (2c+3c up) ; turn LH | cast back (2c+3c down)

9–::

  Mirror Reels3 on opposite  sides, 1c crossing down to start, 1c finish facing 1cnr and 2c in 1pl

17–::

  1c set to 1cnr | to 2cnr, finish on sides (2,1x,3) ; 1½ RH turn to 2pl (2,1,3)

25–::

  1M+3c & 1W+2c ½ Lsh Reel3 across ; 1c turn LH to 2plx

33–::

  1M+3c & 1W+2c ½ Rsh Reel3 across ; 1c turn RH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2816, '2012-01-22 19:29:58.581298+00', '2016-10-28 22:42:34.827896+00', 4511, 1, NULL, 'ace', '1–::

  1W+4M Petronella Turn | set to each other ; 1W turns 2M RH 1½  and 3M ½LH to 4Mplace _while{4}_ 4M turns 3W RH 1½ and 2W ½LH to 1Wplace

9–::

  1M+4W Petronella Turn with full swivel R to face dn/up | set to each other ; 1M turns 2W LH 1½ and 3W ½RH to 4Wplace _while{4}_ 4W turns 3M LH 1½ and 2M ½RH to 1Mplace (4x,2,3,1x)

17–::

  4c+2c & 3c+1c circle4 L 1¼ {3 bars} and open (4M & 1W leading) into facing lines {1} ; Touch in Circle8 and break into 1c+2c & 3c+4c circle4 L 1¼  to (1,2,3,4)

25–::

  ½ G-Chain (ends cross to begin) ; 1c turn RH 1½ to 4pl _while{4}_ 4c+3c+2c continue G-Chain (3-couple) to (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2813, '2012-01-22 19:29:58.464584+00', '2020-12-13 11:57:57.09836+00', 4494, 1, NULL, 'ace', '1–::

  All set | 1c+4c turn BH 1½ and cast to middle _while{6}_ 2c+3c cross RH, ½ RHA and lead to ends facing out (3,1x,4x,2)

9–::

  3c+1c & 4c+2c ¾ Dbl Fig8 | middles change places with ends EH on sidelines and face out (3x,1x,4x,2x)

17–::

  End couples cast to other end passing Rsh and cross RH _while{6}_ middle couples ½ RHA flowing into Circle4 L | All C set (2,4,1,3)

25–::

  2c+4c & 1c+3c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (2809, '2012-01-22 19:29:58.308743+00', '2020-12-13 11:53:46.607602+00', 4483, 1, NULL, 'ace', '1–::

  1c+2c ½ RHA | 1c+3c ½ LHA (2x,3x,1) ; 1c cast to top (3c down) | 1c turn RH into promhold facing down _while{2}_ 2c+3c cross RH to own side

9–::

  1c ½ Lsh (to 2W) Reel3 across with 2c ; then ½ Rsh (to 3M) Reel3 with 3c

17–::

  2c+1M & 1W+3c ½ Reels3 across (1M Rsh to 2W, 1W Rsh to 3M) ; 1c turn RH ¾ (or 1¾) to 2pl

25–::

  2c+1c+3c Circle6 and back (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (2814, '2012-01-22 19:29:58.502353+00', '2020-12-13 12:01:41.236118+00', 4500, 1, NULL, 'ace', '1–::

  1M+2W set | turn ¾ RH ; 1M casts R round 2M to place _while{4}_ 2W casts off R round 1W to place

9–::

  1W+2M repeat [1-8] round 2W & 1M, turning and casting L

17–::

  1c turn RH | lead down (2c up) ; cross below 3c and cast up (to 2,1x,3)

25–::

  Mirror Reels3 with corners (1c start in and up), 1c finish facing 1cnrs

33–::

  1c SetH&G {6}, 1c Petronella Turn to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14039, '2021-05-24 10:56:20.895072+00', '2021-05-27 19:06:57.938097+00', 1997, 1, 202, 'ace', '1--::

  Mirror Fig8 on sides, 1c in, joining NH where possible. 1c face down, 2c face up (1,2,3)

9--::

  1c+2c set on sides | turn RH on sides and face P ; 1c & 2c set to P | turn P RH ¾ into midline

17--::

  Reel4 on midline

25--::

  1c & 2c set |turn P LH ¾ to sides ; 1c set | cast off (2c up) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14394, '2021-10-16 12:09:30.229873+00', '2021-10-16 12:09:30.229873+00', 19191, 2, 2784, 'ace', '1-::
  G-chain, start by M giving RH to W on R (W pass each other RH; M pass W on R RH, W on L LH)
9-::
  Reel3 at ends, M start by passing W on R Rsh
17-::
  Turn opp person, W with BH clw, M with RH Tulloch hold
21-::
  W on R turn BH clw
25-::
  W on L turn BH clw
29-::
  M turn with RH Tulloch hold
33-::
  Turn opp person, W with BH cclw, M with LH Tulloch hold
37-::
  W on R turn BH cclw
41-::
  W on L turn BH cclw
45-::
  M turn with LH Tulloch hold
49-::
  M waltz with W on R
57-::
  M waltz with W on L
65-::
  Reel3 in lines, M start by passing W on R Rsh
73-::
  A&R, advance and pass to meet next trio', 2);
INSERT INTO 'dancecrib' VALUES (3520, '2012-01-22 19:30:29.053585+00', '2017-01-03 15:12:39.37245+00', 10856, 1, NULL, 'ace', '1-4::

  1c long cast to midline LHJ (2C up) and join RH (as in RHA) with end couple (2c+1W & 1M+3c)

5-8::

  All set | Both wheels turn 1/3 RHA and 2W+3M join LH in the middle

9–::

  Repeat [5-8] (3W+2M join LH) ; repeat, 1c now give no hands

17–::

  1c+2cnr Turn LH ; 1c+1cnr Turn RH (1c finish in 2plx, facing out)

25–::

  1c set, swiveling R to face in _while{2}_ 2c+3c cross RH | All set ; all C turn RH 1½ (2,1,3) .



{{explanation}}

The turns, progressing from slow to fast, symbolize that time seems to move more quickly as you grow older', 3);
INSERT INTO 'dancecrib' VALUES (15443, '2023-02-14 12:56:38.970513+00', '2023-02-14 12:57:01.483103+00', 17830, 1, 1645, 'ace', '1--::

  All set | 1c & 3c &frac12; turn opposite RH ; cast away passing 2c/4c RSh | chase &frac14; clw

  _while{6}_ 2c & 4c chase &frac14; clw ; pass 1c/3c RSh & &frac12; turn opposite RH ; cast away (2x,3x,4x,1x)

9--::

  1c+3c RHA ; &frac12; turn opposite RH | cast away, ending in tandem, W behind P (2x,1,4x,3)

17--::

  Alternating tandem Reels3 on sides, 1c/3c start RSh to 4M/2M

25-40::

  2c & 4c repeat [9-24]

41--::

  Circle8 to L & back (4,1,2,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3817, '2013-07-13 15:56:14.037514+00', '2020-10-01 18:18:10.027248+00', 14676, 1, NULL, 'ace', '1–::

  1c+2c The Knot, 1c finish facing 1cnrs

9–::

  SetH&G (2,1,3)

17–::

  1c cross down RH through 3c, cast up ; cross up RH through 2c, cast off to (2,1,3)

25–::

  Opposing ½ Reels3 across, 1c Lsh to 1cnr (2x,1x,3x) ; All turn RH ½ to centre and twirl R to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2823, '2012-01-22 19:29:58.887711+00', '2014-04-30 23:24:02.205534+00', 4548, 1, NULL, 'ace', '1–::
  1c+2c+3c Rsh Reels3 on the sides
9–::
  1c+2c+3c G-Chain (1c cross)
17–::
  1c lead down the middle ; and up, finish in the middle facing up
25–::
  1c cast off, dance NHJ between 3c, cast up and cross to 1cnr
33–::
  Turn CPCP
41–::
  Reels3{6} on the sides (Lsh to 1cnr) | 1c cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11343, '2018-11-18 10:16:03.126448+00', '2019-04-04 11:36:55.435384+00', 18560, 1, 202, 'ace', '1--::

  1c+2c+3c & 4c+5c+6c 6 bars of 3C S&Rotate, all M(W) face up(down) | all set

9--::

  ½ Reels4. On [12] middle lines3 across (4W+5W+6W & 1M+2M+3M) pivot L and face each other ; middle lines3 across turn opp person LH

17--::

  4W+5W+6W loop RSh round facing M _while{4}_ lines of 3M across dance BtoB, all back as on [17] ; 1M+2M+3M loop RSh round facing W _while{4}_ lines of 3W across dance BtoB, all back as on [21]

25--::

  Middle lines3 across (4W+5W+6W & 1M+2M+3M) pass opp person then next person RSh into 2 lines6 across | all chase clw ¼ | all clap and cross RH (3,6,2,5,1,4)', 5);
INSERT INTO 'dancecrib' VALUES (9158, '2016-06-07 21:37:35.823674+00', '2016-06-07 21:37:35.823674+00', 16998, 2, 1, 'ace', '1–::
  1c&2c dance double fig of 8 (1c crossing down, 2c casting up to begin;
  2c fin facing out)
9–::
  Mirror reels3 on sides (1c fin back-to-back in 2pl facing own sides, 2c fin
  in 1st pl)
17–::
  Double triangles (on 7–8, 1c dance round by RS to face ptr
  _while_ 3c set advancing)
25–::
  1c&3c poussette (to 2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2828, '2012-01-22 19:29:59.098639+00', '2017-07-07 13:17:46.603147+00', 4562, 1, NULL, 'ace', '1–::

  1c+2c set twice to P ; set twice up/down

9–::

  1c lead down, cross below 2c, cast off round 3c, lead to top, cross and cast to 2pl (2c up) (2,1,3)

17–::

  2c+1W & 1M+3c Reels3 across (Lsh to 1cnr) (2,1,3)

25–::

  1c+3c RHA ; 2c+1c LHA', 3);
INSERT INTO 'dancecrib' VALUES (9140, '2016-04-28 19:43:24.083526+00', '2020-04-18 22:22:36.828672+00', 13309, 1, NULL, 'ace', '1–::

  1c+3c ½ R&L ; 2c+4c repeat (3,4,1,2)

9–::

  All M RHA, to same places ; all W LHA, finish in middle facing P

17–::

  1c+3c & 2c+4c intersecting Reels4 (use ½ LHA in the middle) finish as started facing P (3,4,1,2)

25–::

  All dance the »Circle Knot«: Turn P RH ½ into Allemande hold facing cclw | promenade cclw to next position ; All drop RH and W dance into the middle | All turn LH into new positions (4,1,2,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1705, '2012-01-22 19:28:57.603263+00', '2017-07-07 14:05:34.188402+00', 327, 1, NULL, 'ace', '{{explanation}}

Special shape of set: 1M with 2M on R stands BtoB with 4M and 3M respectively ; all W face their P. The W are »outers«, the M »inners«.



1–::

  All set to P with some suitable Strathspey steps (e.g. Fling steps)

9–::

  ½Reel: all C pass Lsh, M to partners'' (»outer«) positions, 1W / 3W veering left to 2M / 4M positions, 2W+4W straight ahead to 3M / 1M positions | repeat from new positions ; repeat twice (all end diagonally opposite starting positions)

17–::

  All set to partners again

25–::

  Repeat ½Reel to original positions



{{explanation}}

Repeat at will.', 2);
INSERT INTO 'dancecrib' VALUES (2831, '2012-01-22 19:29:59.218087+00', '2017-07-07 14:16:59.268695+00', 4565, 1, NULL, 'ace', '1–::

  1c+2c Poussette (1,2,3)

9–::

  1c lead down the middle and up | cast off (2c up)

17–::

  1c+3c Circle4 and back

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (2825, '2012-01-22 19:29:58.967445+00', '2017-09-30 16:26:01.188775+00', 4555, 1, NULL, 'ace', '1–::

  1c+2c circle4 L, finish NHJ 1c facing 2c ; set, 1c turning in to face up | 1c cast off, 2c dance up (2,1,3)

9–::

  Mirror Reels3 on the sides, 1c start down and in, join hands when possible, 2c+3c finish with loops

17–::

  2c+1c+3c set | 2c+1c ½ LH turn and face down ; lead (LHJ) down, cross below 3c and cast up (1,2,3)

25–::

  1c+2c the Knot. (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9898, '2017-05-30 07:26:51.794927+00', '2017-10-21 00:01:36.293295+00', 17767, 2, 1058, 'ace', '1-8:: 1s, 2s, + 3s set and cross RH, Set and half turn RH into Prom hold

9-16:: All dance progressive promenade with 1s casting to face 1st Crnr

17-24:: 1s dance ''Hello-Goodbye'' setting ending with a clap & petronella turn to 2nd places

25-32:: 1s set, cast round 3rd corner, cross RH, cast right to own sides 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (13792, '2021-03-06 21:42:46.748203+00', '2021-03-07 10:11:11.850441+00', 20244, 1, 202, 'ace', '1--::

  1c ½ Fig8 down round 2c. 1c & 2c face on sides ; 1c & 2c set up/down | 1c+2c turn EH, 1c in and down (1x,2,3)

9--::

  1c lead down between 3c, cross and cast up to 2pl (2c up) ; all set | 1c Petronella Turn into facing lines3 across

17--::

  All set | all change places RH with opposite person ; all chase clw ½ into facing lines3 across, 1W between 2c in top place

25--::

  3C S&Link ; all turn P RH (2,1,3)

33--::

  1c+3c set | RHA ½ (to 2,3x,1x) ; set | cross RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (13793, '2021-03-07 13:15:03.150106+00', '2021-03-07 14:52:01.478615+00', 20250, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c in and down, couples giving hands when possible. 1c & 2c finish in centre facing P BHJ ready for

9--::

  2C Poussette. On [7-8] 1c opening to top finish BtoB in 2pl centre

17--::

  6 bars of DTr | 2c set diagonally _while{2}_ 1c turn 1cnrs RH and join LH with P on 1diag

25--::

  6 bars of The Spoke. On [30] after BiL in 2diag, 1c releasing all hands dance to 2pl (PdB L) facing in| all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14040, '2021-05-24 12:21:35.81812+00', '2021-05-24 12:26:45.779816+00', 5186, 1, 202, 'ace', '1--::

  1c lead down ; and up (1,2,3)

9--::

  1c set | cast off (2c up) ; set | turn P RH and face 1cnrs

17--::

  Set to and Turn Corners with RH (2,1x,3)

25--::

  Reels3 on sides {6}, 1c LSh to 1cnrs | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14041, '2021-05-24 19:48:57.763796+00', '2021-05-25 08:38:55.510258+00', 13834, 1, 1645, 'ace', '1-::

  1c cast (2c up) | 1c set adv to 1cnr _while_ all cnrs set diagonally ; 1c+1cnrs &frac12; RSh Reel4, 1c end passing LH to face across

9-::

  1c turn &frac34; RH | 1c set adv to 2cnr _while_ all cnrs set diagonally ; 1c+2cnrs &frac12; RSh Reel4, 1c end passing LH to face 1M up, 1W down

17-::

  1c pass RSh & cast round 2cnr through 2plx into ; 1W+3c (top) & 1M+2c &frac12; RSh Reels3 across, end on sides (3,1,2)

25-::

  1c+2c &frac12; poussette ; 3c+2c &frac12; poussette (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (2840, '2012-01-22 19:29:59.613529+00', '2014-04-30 23:24:02.510968+00', 4618, 1, NULL, 'ace', '1–::
  Interlocking Reels4, start Rsh to P
9–::
  1c+3c M-Chain
17–::
  1c passes P Rsh, 1M/1W dance behind next corner and in between that side couple, dance behind 3c and NHJ between 3c to places, 1W dancing under 1M''s arm on [24]
25–::
  All circle8 and back

{{explanation}}
Danced 4 times, each couple in turn being 1c; the whole pattern turns ¼ clw', 3);
INSERT INTO 'dancecrib' VALUES (3615, '2012-07-21 11:45:54.812005+00', '2014-04-30 23:24:02.542884+00', 11287, 1, NULL, 'ace', '1–::
  1c set | cast off (2c up) ; dance through 3c and cast up (2,1,3)
9–::
  All set | cross ; chase ½ round clw (3,1,2)
17–::
  »Teapots R and L«(1c RHA with end cpls ; 1c LHA with other end cpls)  (3,1,2)
25–::
  All chase cclw ½ round, cross LH and set', 3);
INSERT INTO 'dancecrib' VALUES (9532, '2017-01-04 16:28:34.210167+00', '2017-01-04 16:36:52.321526+00', 16406, 1, NULL, 'ace', '1--::

  All set and cross RH ; 1c+3c petronella to midline and set to P

9--::

  1c+3c Reel4 on midline

17--::

  1c+3c turn RH ¾ as 2c crosses | All Circle L once round (1,2,3)

25--::

  1c+2c dance between 3c and cast up on own side (2,1,3) ; 1c+3c dance up between 2c and cast down on own side (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2849, '2012-01-22 19:29:59.981224+00', '2014-07-08 07:39:30.837336+00', 11814, 1, NULL, 'ace', '1–::

  1c+4c set | cross RH ; cast to middle (2c/3c up/down). 1c+4c ½ LHA (2,4,1,3)

9–::

  Reels4 on the sides, finish middles facing ends on sidelines

17–::

  All set up/down | turn BH on sides ; 2c+4c & 1c+3c circle4 L, finish for

25–::

  2c+4c & 1c+3c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (3819, '2013-07-13 15:56:14.28768+00', '2017-04-24 07:49:17.142721+00', 14534, 1, NULL, 'ace', '1–::

  1c+2c set | Circle 4 L ½ ; turn P BH 1½  (2,1,3)

9–::

  1c ½ Fig8 L (i.e. M up) ; ½ diagonal R&L to the L (with 4cnrs)

17–::

  1c ½ Fig8 R (i.e. W up); ½ diagonal R&L to the R (with 3cnrs) (3x,1,2x) 1c face 1cnr

25–::

  1c+1cnrs pass, cnrs turn BH ½, and cast away as 1c pass Rsh ; repeat with 2cnrs (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1929, '2012-01-22 19:29:10.39917+00', '2021-02-13 12:51:56.532242+00', 10049, 1, NULL, 'ace', '1-16::

  1c cross RH, cast off (2c up) ; R&L for 3 couples, 1c finish facing 1cnr

17–::

  1c SetH&G

25–::

  Reels3{6} on the sides (Rsh to 2cnr) | 1c cross RH', 2);
INSERT INTO 'dancecrib' VALUES (9159, '2016-06-08 21:59:36.849257+00', '2016-06-08 21:59:36.849257+00', 891, 1, NULL, 'ace', '1--::

  1c dance down | set to 3c ; set turning in to face up | dance to top NHJ

9--::

  1c cast to 2pl (2c up) | 2c+1c+3c set ; 1c ½ Lsh Fig8 round 1cnr and face 1cnr

17--::

  1c turn 1cnr RH | BiL on 1diag ; 1c turn P LH 1¼ to face 2cnr

25--::

  1c turn 2cnr RH | BiL on 2diag ; 1c turn P LH 1¼ to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2848, '2012-01-22 19:29:59.940369+00', '2015-09-19 13:40:31.697906+00', 4641, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; cross LH | cast L (W up, M down)

9–::

  2c+1W &1M+3c Rsh Reels3 across

17–::

  1c NHJ set to 2W (swivel ½ inwards), set to 3M (veer L together), set to 3W (swivel ½ inwards), set to 2M (and face own 2cnr)

25–::

  Reels3{6} on the sides, Rsh to 2cnr | 1c cross RH to 2pl', 3);
INSERT INTO 'dancecrib' VALUES (2846, '2012-01-22 19:29:59.858312+00', '2019-02-11 00:54:01.221823+00', 9010, 1, NULL, 'ace', '1–::

  Top two M & bottom two W turn RH ; and chase clw to the diagonally opposite place

9–::

  Other two W & other two M repeat (LH, cclw) (4x,3x,2x,1x)

17–::

  Top two W & bottom two M cross, pass person opposite Rsh and cast R 2 places ; Other two M & other two W repeat (Lsh, cast L) (2,1,4,3)

25–::

  1c+4c ½ Fig8 round their end couple ; 1c+4c ½ R&L into

33–::

  Parallel Reels4 on the sides (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2837, '2012-01-22 19:29:59.458431+00', '2019-02-13 00:13:28.252968+00', 10566, 1, NULL, 'ace', '1–::

  All C set | cross RH ; set | 1c+4c turn RH ¾ _while{2}_ 2c+3c cross RH

9–::

  1c+4c reel4 on midline

17–::

  1M (1W following) + 4W (4M following) dance clw half round the set (to 4,2,3,1) ; 3W+1W & 3M+1M change places RH | 2W+1W & 2M+1M repeat LH (4,1,2,3)

25–::

  All C turn BH, opening into | 4c+1c & 2c+3c ½ circle4 L, opening into | All ½ circle8 L (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2844, '2012-01-22 19:29:59.775313+00', '2019-04-25 22:37:50.141071+00', 10567, 1, NULL, 'ace', '{{explanation}}

Round-the-room-. All couples face clw, men on the inside.



1–::

  Lead clw and back.

9–::

  Turn partner RH, LH, to places facing P

17–::

  With 1st corner (diagonally on the R) A&R, turn RH.

25–::

  With 2nd corner: A&R, turn RH.



{{explanation}}

Repeat the dance with this new partner.', 2);
INSERT INTO 'dancecrib' VALUES (3818, '2013-07-13 15:56:14.27403+00', '2020-08-31 16:07:20.280532+00', 14675, 1, NULL, 'ace', '1–::

  1W, with 2W following, Fig8 round the Men, start Lsh to 2M, finish in exchanged places

9–::

  1c+2c RHA ; LHA

17–::

  2M, with 1M following, Fig8 round the W, start Lsh to 2W (2,1)

25–::

  2c+1c Circle4 and back', 2);
INSERT INTO 'dancecrib' VALUES (2851, '2012-01-22 19:30:00.07329+00', '2017-05-14 10:05:24.195877+00', 4646, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; 1c turn 1¼ LH into

9–::

  1W+2c & 1M+3c set twice in lines across, but on [11-12] 1c Petronella to opposite sideline ; all set twice on sidelines (2,1x,3)

17–::

  2c+1c+3c circle6 and back

25–::

  Reels3{6} on the sides (Rsh to 2cnr) | 1c cross (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2839, '2012-01-22 19:29:59.572522+00', '2020-12-13 12:48:16.471771+00', 4610, 1, NULL, 'ace', '1–::

  1c cross RH | cast off 2 _while{4}_ 2c+3c set and cross up one ; 2c repeat _while{4}_ 3c+1c set and cross up (3,1,2)

9–::

  1c+2c circle4 Left ; 3c+1c circle4 R, 1c ends facing 1cnr pos.

17–::

  1c set to 1cnr | set to 2cnr, swiveling R to face P ; set & petronella to 2pl

25–::

  3c+1c+2c the Knot.', 2);
INSERT INTO 'dancecrib' VALUES (2841, '2012-01-22 19:29:59.654703+00', '2020-12-13 12:52:17.693836+00', 4620, 1, NULL, 'ace', '1–::

  1c+2c set | RHA | turn RH into

9–::

  1c+2c Allemande, 1c finishing by 1¼ LH turn for

17–::

  2c+1W & 1M+3c RHA ; 1c Turn LH 1½ to face 3cnr position _while{4}_ corners chase ½ clw

25–::

  ½Reel4 on 1diagonal, 1c pass Rsh ; ½Reel4 on 2diagonal (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2838, '2012-01-22 19:29:59.499475+00', '2020-12-23 11:10:21.797368+00', 10376, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; Turn LH 1¼ to between end C, facing 1cnr

9–::

  Lsh Reels3 across, finish 2c facing 3c up/down, and 1c in middle, Lsh to Lsh, 1W facing up, 1M down

17–::

  2c+3c ½ R&L, starting up/down _while{4}_ 1c dance out the end and cast L ; 1c turn LH (3x,1x,2x)

25–::

  S&Link3 twice (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2836, '2012-01-22 19:29:59.415958+00', '2020-12-25 12:20:34.270924+00', 11884, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; ½Fig8 round 2c, finish (2c+3c step in) all C in the middle facing up

9–::

  2c+1c+3c Allemande (3,1,2)

17–::

  1c ½Fig8 round 2c ; All set | 1c cross RH & face out _while{2}_ 3c+2c turn RH ½ to face each other in the middle (3x,1,2x)

25–::

  Opposing Reels3 on the sides, 1c starting out and to the R, at end 1c curve L about

33–::

  Diagonal R&L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13647, '2021-02-05 16:35:12.922027+00', '2021-02-13 20:13:30.392632+00', 20217, 2, NULL, 'ace', '1-8:: 1s cross down, cast down below 3s and dance up to 2nd place opposite sides. All set.
9-16:: 2L, 1s and 3M dance two bars of petronella into the middle to form the line up-down in the middle, set (1s turning right about and high cuts are recommended), 1M with 2s as 1L with 3s dance RHA to finish in lines but 1s in the middle facing 1st corners (pulling right shoulder back to come into back to back position)
17-24:: 1s dance Corners pass and turn with 1st then 2nd corners finishing in own lines
25-32:: All dance circle 6HR and back
', 0);
INSERT INTO 'dancecrib' VALUES (2870, '2012-01-22 19:30:00.914026+00', '2021-05-06 13:48:51.62283+00', 4744, 1, NULL, 'ace', '1–::

  1c (promhold, M on L) cast round 2M | cross up ; cast off (2c up) | dance to midline and out to 2pl (2,1,3)

9–::

  2c repeat (1,2,3)

17–::

  1c down the middle ; turn in and lead up | cast up behind 3c (2c up) to (2,1,3)

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (2857, '2012-01-22 19:30:00.34242+00', '2014-04-30 23:24:02.802138+00', 9473, 1, NULL, 'ace', '1–::
  1c+3c Fig8 round 2c (1c cast and 3c cross up)
9–::
  1c+2c+3c set, triple petronella, set, triple petronella
17–::
  3c+2c+1c A&R ; set, turn LH ½ into
25–::
  3c+2c+1c Promenade, at end 3c cast to 3pl and others dance up one (2,1,3)

{{explanation}}
Triple petronella is like petronella in tandem, but for 3 dancers in a row moving to 3 in line at right angles on the right', 2);
INSERT INTO 'dancecrib' VALUES (9160, '2016-06-10 10:38:40.432986+00', '2016-06-10 10:38:40.432986+00', 17020, 1, NULL, 'ace', '1--::

  All set | cross RH ; set | cross RH (1,2,3,4)

9--::

  1c+3c lead down (2c+4c up on [11-12]) ; 1c+3c lead up | turn LH to (2,1,4,3)

17--::

  2c+1c & 4c+3c R&L

25--::

  1c+4c S&Link ; RHA (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2866, '2012-01-22 19:30:00.757377+00', '2014-07-08 07:19:34.000195+00', 13617, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1c cast off 2, meet, dance to top, cast (2c up) (2,1,3)

17–::

  1c+3c RHA ; LHA

25–::

  All circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2868, '2012-01-22 19:30:00.835995+00', '2020-05-27 18:48:32.955394+00', 4725, 1, NULL, 'ace', '1–::

  1c+2c Promenade (1,2)

9–::

  1c down the middle and up

17–::

  1c+2c Allemande

25–::

  2c+1c Circle4 and back', 3);
INSERT INTO 'dancecrib' VALUES (14177, '2021-08-02 19:53:30.766188+00', '2021-08-02 20:00:20.800577+00', 1541, 1, 202, 'ace', '1--::

  All set | 1c & 3c turn RH _while{2}_ 2c & 4c turn RH ½ (to 1,2x,3,4x) ; 1c+2c & 3c+4c RHA. All finish in tandem near midline, all W leading

9--::

  Reel4 in tandem (no lead change) to sides as on [4]. All W face out (1,2x,3,4x)

17--::

  1c+2c & 3c+4c Parallel Reels4 across, all M passing LSh, all W casting (1,2x,3,4x)

25--::

  1c+2c ½ RHA | 1c+3c set up/down ; 1c+3c change places LH | 1c+4c ½ RHA (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2858, '2012-01-22 19:30:00.382625+00', '2021-01-10 21:22:22.847517+00', 12690, 1, NULL, 'ace', '1–::

  1c+2c+3c Rsh Reels3 on the sides, 1W finishes facing out

9–::

  1W, 1M following, casts off 2 and crosses (2c+3c up) ; 3c+1c RHA, 1W faces out (2,3,1x,4,5)

17–::

  1c+4c+5c Lsh Reels3 on the sides, 1W finishes facing out

25–::

  1W, 1M following, casts off 2 and crosses (4c+5c up) ; 5c+1c LHA (2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (2853, '2012-01-22 19:30:00.155117+00', '2019-03-05 11:13:21.162345+00', 9658, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c change places on the side RH | 1c+4c LHA | 2c+1c & 4c+3c turn RH ½ (1,2,3,4)

9–::

  Parallel Reels4 on own side (1,2,3,4)

17–::

  1c+2c & 3c+4c tournee, finish 2c in 1pl and the others ready for

25–::

  1c+4c+3c Allemande (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2864, '2012-01-22 19:30:00.678635+00', '2016-11-22 23:51:05.322293+00', 10653, 1, NULL, 'ace', '1–::

  1c set advancing | turn BH and face down NHJ ; join free hand with 2c who face out and up, and set | 1c turn 2c EH, (to 1,2,3 with 1c NHJ)

9–::

  1c dance down (2c start up and follow) {3}, and up (2c split and follow) {3} | 1c cast off one as 2c dance to top facing out (2,1,3)

17–::

  Mirror Reels3 on sides (1c in and down) join hands when possible, 2c+3c finish with loops (2,1,3)

25–::

  Lsh ½Reels3 across (M down W up) ; Lsh ½Reels3 across (M up W down)', 3);
INSERT INTO 'dancecrib' VALUES (2852, '2012-01-22 19:30:00.115462+00', '2019-03-12 23:39:12.728246+00', 4654, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c ½ RHA | 1c+4c LHA | 1c+2c & 3c+4c ½ RHA (1,2,3,4)

9–::

  Reels4 on the sidelines (mid couples face end couples to start) (1,2,3,4)

17–::

  Top three dancers on M side cross RH with bottom three on W side | Top three dancers on W side cross LH with bottom three on M side ; repeat (4x,3x,2x,1x)

25–::

  All set and cross RH (3c in 2pl stay facing out) ; 4c+3c+2c ½Reel3 on the sides (3c starts out and up) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3526, '2012-01-22 19:30:29.310642+00', '2021-02-14 20:40:27.676008+00', 9904, 1, NULL, 'ace', '1–::

  1M »solo R&L«, changing places with 1W RH | 2W LH ; 2M RH | 1W again LH (finish 1c on M side, 2c on W side)

9–::

  L-Chain.

17–::

  1W »½ solo R&L« changing places with 2M RH | 2W LH (1,2) ; 1c+2c turn P RH, into the middle for

25–::

  1c+2c Poussette. (to 2,1)



{{explanation}}

Dance is done 6 x 32,  twice for each couple', 3);
INSERT INTO 'dancecrib' VALUES (12455, '2020-01-01 01:21:09.146848+00', '2020-01-01 01:45:45.914531+00', 2715, 1, NULL, 'ace', '

1--::

  1c turn RH ½ | lead down (2c up), cast up round 3c, cross LH to own side and face out (2,1,3)

9--::

  2c+3c RHA, finishing in place _while{4}_ 1c cast Lsh round 4cnr and 1cnr to 2plx (2,1x,3) ;  2c+3c chase clw half round _while{4}_ 1c turn LH 1¾ 

17--::

  3c+1W & 1M+2c RHA ; 1c turn LH 1½ to face 1cnrs _while{4}_  3c+2c chase clw to places

25--::

  CPCP to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12772, '2020-04-19 13:02:04.097134+00', '2020-04-19 13:06:12.042439+00', 19885, 1, 202, 'ace', '1--::

  1c cast off (2c up) | ½ Fig8 R LSh round 1cnrs | dance to between ends facing 3cnrs

9--::

  Reels3 across, LSh to 3cnrs. 1c in centre LSh to P face own sides

17--::

  2c+1M & 1W+3c RHA, pass RSh ; 2c+1W & 1M+3c LHA (2,1x,3)

25--::

  1c cross LH | cast off (3c up) ; all turn P RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2863, '2012-01-22 19:30:00.63898+00', '2020-09-09 09:45:56.318847+00', 9639, 1, NULL, 'ace', '1–::

  1W+3M turn RH, 1W finishes in 2W place (2W up) ; 1M+3W turn LH (2M up), to (2,1,3)

9–::

  1c cross, cast R round 1cnr into the middle ; RHA with own corners, 1c finish facing 2cnr

17–::

  1c set to 2cnr | set to 1cnr ; petronella to between end couples (1W up. 1M down) | 1c set to P, pulling back Rsh to face out the ends

25–::

  1M+3c & 1W+2c (Rsh to 4cnr) Reels3{6} across | 1c cross RH to own side', 3);
INSERT INTO 'dancecrib' VALUES (2862, '2012-01-22 19:30:00.599866+00', '2020-12-13 12:56:04.513936+00', 4692, 1, NULL, 'ace', '1–::

  1c cross RH, cast (2c up) ; ½Fig8 L (M down, W up) to face 1cnr

9–::

  ½ Diag Reel4 with 1cnrs, pass Rsh ; ½ Diag Reel4 with 2cnrs to (3x,1x,2x)

17–::

  All cross RH, 1c face out | 3c+2c set _while{2}_ 1c cast R into lines across ; All cross RH up/down | 2c+3c set up/dn _while{2}_ 1c cast R (to 2,1,3)

25–::

  Opposing Reels3 on the sides, 1c Lsh to 3cnr (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2869, '2012-01-22 19:30:00.874859+00', '2020-12-13 12:59:41.462589+00', 4728, 1, NULL, 'ace', '1–::

  1c cast to 3pl _while{4}_ 3c set and dance to 1pl ; repeat from new places, at end 1c face out then down (1,2,3)

9–::

  1c facing 2c set and change places RH (with polite turns) ; 1c turn LH 1½ to face 1cnr

17–::

  Turn CPCP, 1c finish in 2pl (2,1,3)

25–::

  1c+3c circle4 L ; 2c+1c circle4 R (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (14269, '2021-09-03 02:00:55.224191+00', '2021-09-03 02:01:08.399447+00', 20453, 1, 202, 'ace', '1--::

  All turn P RH ½, face P and cast R to exchanged places ; 1c+2c & 3c+4c chase clw ½ (2,1,4,3)

9--::

  Reels4 on sides (2,1,4,3)

17--::

  All set | cross RH ; all set | 2c cross RH _while{2}_ 1c, 4c & 3c turn RH ½ into promhold (2,1,4,3)

25--::

  3C Allemande (2,3,4,1)', 5);
INSERT INTO 'dancecrib' VALUES (2788, '2012-01-22 19:29:57.427075+00', '2021-03-06 22:02:03.828184+00', 9009, 1, NULL, 'ace', '1–::

  1c with 2c+3c+4c following dance down between 5c and cast up to places

9–::

  1c (start inwards) Fig8 on own side round 2c & 3c _while_{8} 5c (start outwards, no cast) Fig 8 on own side round 4c & 3c (to 1,2,3,4,5)

17–::

  1c+2c RHA ; 1c cross down as 2c cast up | 1c+3c change places easy hand (2,3,1x,4,5)

25–::

  1c+4c LHA ; 1c cross down as 4c cast up | 1c+5c change places easy hand (2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (3452, '2012-01-22 19:30:26.104837+00', '2017-07-07 14:11:09.664131+00', 6817, 1, NULL, 'ace', '1–::

  1c+2c NHJ set twice, turn P RH

9–::

  1c sets twice to 2c ; 1c+2c turn P LH and join NH to face other C

17–::

  1c+2c circle4 L, finish NHJ on the sides ; 1c+2c dance BtoB with P

25–::

  1c lead down {3}, up {3} and cast off one place (2c up)', 3);
INSERT INTO 'dancecrib' VALUES (1772, '2012-01-22 19:29:01.543155+00', '2021-05-26 12:49:38.251175+00', 559, 1, NULL, 'ace', '1–::

  1c+2c+3c set twice ; and still holding hands, 1c leading, lines cross at the top (M passing outside W) and down opposite side (to 3x,2x,1x)

9–::

  Repeat, crossing at the bottom, 1c leading (1,2,3)

17–::

  Pickup Chain from top: (1c cross RH | 1c pass 2c LH on side ; 2c cross RH _while{2}_ 1c pass 3c RH on side | 2c pass 3c LH on side _while{2}_ 1c cross LH in 3pl) (3,2x,1)

25–::

  All W set advancing and join nearer hands, set retiring ; All M repeat

33–::

  Repeat pickup chain, 3c starting (1,2,3)

41–::

  1c cast off (2c up) ; all Turn RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2875, '2012-01-22 19:30:01.140553+00', '2016-11-27 11:04:42.770388+00', 4774, 1, NULL, 'ace', '1–::

  1c+2c R&L

9–::

  1c dance down, cast round 3c to 2pl (2c up) ; 1M+3c & 1W+2c RHA

17–::

  2c+1M & 1W+3c LHA ; 2c+1c+3c turn RH

25–::

  2c+1c+3c circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2883, '2012-01-22 19:30:01.452768+00', '2017-03-15 02:38:39.996893+00', 4805, 1, NULL, 'ace', '1–::

  1c set | 1W casts, 1M following, round 3W, 1W dances up round 3M and 1M dances up the middle, 1c face 3c (2c up on 7-8) (2,1x,3)

9–::

  2c+1c+3c G-Chain (2c cross), 2M+1M finish facing out

17–::

  2c+1c L-Chain

25–::

  2c+1c+3c A&R ; 1c turn RH 1½ to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9157, '2016-06-07 15:16:28.034013+00', '2019-02-03 21:28:40.262715+00', 3520, 1, NULL, 'ace', '1--::

  All A&R ; All set advancing to P, turn BH ½ and retire (1x,2x,3x,4x) 

9--::

  All repeat (1,2,3,4)

17-32::

  Augmented Grand Chain: starting across at the ends, turn RH ½ {1} turn next person LH 1½ {3} : repeat ;; repeat ; repeat using only ½ turns (1,2,3,4)

33--::

  1W+2M change places RH | 1M+2W repeat ; 2c+1c set advancing to P, turn BH ½ and retire (2,1,3,4) ; 

41--::

  1c+3c repeat the figure (2,3,1,4)

49--::

  1c+4c repeat the figure (2,3,4,1)

57--::

  All Circle8 and back (2,3,4,1)



*Note: crib derived from the video.*

', 2);
INSERT INTO 'dancecrib' VALUES (2871, '2012-01-22 19:30:00.953432+00', '2019-02-21 23:02:14.14233+00', 9683, 1, NULL, 'ace', '1–::

  1c long cast to 2pl (2c up) ; ½ Fig8 round 3c (2,1x,3)

9–::

  All set |1c set passing ; 1W+2W+3W & 1M+2M+3M circle3 L:

17–::

  1c cast R round 3cnr to 1M between 2c facing 1W between 3c ; All set in lines across | 1c set passing |

25–::

  2c+1W & 1M+3c RHA ; 1c+3c ½ Poussette (to 2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (10409, '2018-01-31 02:07:55.938935+00', '2018-01-31 02:12:55.591589+00', 16898, 1, 202, 'ace', '1--::

  1c slip down the middle ; lead up to face 1cnrs

9--::

  1c+1cnrs Corners Pass and Turn, pass P Rsh ; 1c+2cnrs repeat (2,1x,3)

17--::

  1c set advancing to centre, 1M facing up, 1W down | Crown Triangles, finishing 1W facing up, 1M facing down

25--::

  Reels3{6} across, 1c Lsh to 1cnrs (to 2,1,3) | all set', 2);
INSERT INTO 'dancecrib' VALUES (11963, '2019-07-14 18:40:26.504201+00', '2022-03-16 09:24:50.122107+00', 15566, 1, 202, 'ace', '1--::
  1c+2c Poussette (1,2,3)
9--::
  1c (touching NH briefly) long cast to 2pl (2c up) ; dance between 3c, cast up to face 1cnrs
17--::
  6 bars of SetH&G. On [23] all clap and 1c Petronella turn to 2pl (2,1,3)
25--::
  Circle6 L for 3 steps. On [28] all dance into centre and pivot R to face out ; on [29] all dance out and chase clw to places (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2872, '2012-01-22 19:30:00.989265+00', '2019-04-05 23:42:17.332445+00', 4759, 1, NULL, 'ace', '1–::

  1c set, dance down, cast up round 3c, dance up to 1pl facing out _while{8}_

::

  2c wait {2}, set ; dance between 3c and cast up to 2pl facing in and up _while{8}_  

::

  3c wait {4} ; set, dance in, touch NH facing down and face out in 3pl



9–::

  1c+2c+3c Reels3 on sides, 1c cast to start, cross down RH on [11], at end lead up with half RH turn to finish in 1pl ready for

17–::

  1c+2c Rondel

25–::

  2c+1c+3c G-Chain (2c cross to start)', 3);
INSERT INTO 'dancecrib' VALUES (2881, '2012-01-22 19:30:01.373851+00', '2020-12-22 23:21:15.510625+00', 4803, 1, NULL, 'ace', '1–::

  1c+2c Petronella turn and set ; turn RH ¾ into ½RHA (2,1,3)

9–::

  2c+1c+3c mirror Reels3 on opp. sides, 1c crossing down through 3c to start, 1c finish facing 2crs and 2c+3c loop into place

17–::

  Half diagonal Rsh Reel4 with 2cnrs, turn LH into ; half diagonal Lsh Reel4 with 1cnrs, at end 1c pass Lsh into

25–::

  1M+3c (at top) & 1W+2c circle3 L, break (1c leading) into ½ circle6 L, to places, All set (2,1,3)   

', 3);
INSERT INTO 'dancecrib' VALUES (3544, '2012-01-22 19:30:30.18602+00', '2014-04-30 23:24:15.723934+00', 7173, 1, NULL, 'ace', '1–::
  1M+2W set advancing and turn RH, 1W+2M repeat
9–::
  Reels3 on opposite sides (1c cross down)
17–::
  Reels3 on own side, 1c crossing back
25–::
  1c set, cross RH, cast off one (2c up), cross LH
33–::
  1c+3c circle4 L and back
41–::
  2c+1c R&L.', 2);
INSERT INTO 'dancecrib' VALUES (2890, '2012-01-22 19:30:01.748611+00', '2014-10-07 14:19:40.840032+00', 4830, 1, NULL, 'ace', '{{explanation}}

(This was formerly a 3c dance; 1c crossing below 3c on [5].



1–::

  1c long cast ; cross RH and cast up to P''s place (1x,2)

9–::

  1c+2c R&L, do not retain holds

17–::

  1M+2W, followed by 2M+1W lead down the middle on own side (1M starts with a long step. 2M with a small step) [3], both Pairs turn inwards ; lead up [1], 2M casts off, 1M speeds up | 1c+2c lead up to own places.

25–::

  Tournée.



{{explanation}}

To make 17 - 24 look seamlessly smooth, some components may take fractions of a bar longer or shorter than indicated', 3);
INSERT INTO 'dancecrib' VALUES (12299, '2019-10-20 00:09:08.984947+00', '2019-10-20 00:13:03.412229+00', 16787, 1, 202, 'ace', '1--::

  1c set | turn RH and face out | cast to 2pl (2c up) (2,1,3)

9--::

  1c+1cnrs set twice ; turn RH (2,1,3)

17--::

  1c+2cnrs set twice ; turn RH (1,2,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12773, '2020-04-20 07:40:57.037384+00', '2020-04-20 07:43:46.767896+00', 19884, 1, 202, 'ace', '1--::

  1c dance in slightly and cast off (2c up) ; ½ Fig8 up round 2c to centre into promhold facing up, 1W on 1M''s L

9--::

  Reel3 across, 1c RSh to 2W. 1c in centre face up

17--::

  1c lead up, cross and cast to 2pl ; 2c dance down and cast up round 1c to 1pl

25--::

  2C R&L (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2873, '2012-01-22 19:30:01.028623+00', '2021-03-27 19:47:03.164805+00', 4765, 1, NULL, 'ace', '1–::

  All set twice ; cross Rsh no hands

9–::

  Repeat back

17–::

  1c+2c reel4 across, finish in exchanged places (2,1,3)

25–::

  1c+3c repeat, but to same places (2,1,3)

33–::

  1c+3c RHA ; LHA

41–::

  2c+1c R&L

', 2);
INSERT INTO 'dancecrib' VALUES (13557, '2021-01-16 20:29:27.450186+00', '2021-01-17 16:46:41.733891+00', 12091, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c RHA {3}, LHA {3} | 1c & 3c cast off (2c & 4c lead up) (2,1,4,3,5)

9--::

  2c+1W & 1M+4c+3W & 3M+5c Circle3-or-4 and back

17--::

  1c & 3c Set to and Turn Corners (2,1x,4,3x,5)

25--::

  1c lead down between 4c, cross and cast up to 2pl, lead up between 2c, cast off to 3pl (4c up) _while{8}_ 3c lead down between 5c, cross and cast to 4pl, lead up between 4c, cast off to 5pl (5c up) (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (10675, '2018-04-22 08:09:58.81947+00', '2021-07-30 08:41:22.737062+00', 3403, 1, 202, 'ace', '1--::

  2c & 3c cast out to own end, lead dn/up to centre ; 2c+3c RHA  _while{4}_ 1c & 4c  set | cross RH, finishing 1c&3c facing dn, 2c&4c facing up (1x,2,3,4x)

9--::

  All set | 2c & 3c change places LH with cnrs (to 2,1x,4x,3) ; 1M+4M & 1W+4W cross RH behind W/M sides, dance to ends, meet P,  lead LHJ 1c(4c) up(dn) to 3plx(2plx), finishing 2c&1c facing dn, 4c&3c facing up (2,4x,1x,3)

17--::

  4c+1c LHA, finishing 2c&1c facing dn, 4c&3c facing up ; all set | 4c & 1c change places LH with cnrs (4x,2,3,1x)

25--::

  2M+3M & 2W+3W cross RH behind M/W sides, dance to ends, meet P, lead 2c(3c) up(dn) to 3pl(2pl) (to 4x,3,2,1x) ; 3c+2c RHA _while{4}_ 4c & 1c set | cross RH (to 4,3,2,1), 4c&3c&2c finishing in centre ready for

33--::

  4c+3c+2c Allemande (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (8453, '2014-11-18 19:06:02.268951+00', '2021-04-11 13:07:36.3231+00', 14510, 2, 160, 'ace', '1–::

 Cross, cast ; turn RH (face out) (2,1x,3)

9–::

 Reel3 (Rsh) on sides - pass Lsh to end 2pl own side facing out.

17–::

 Reel3 (Lsh) on side - pass Rsh to face 1crnr.

25–::

 Turn 1crnr RH, pass Rsh ; Turn 2crnr RH, pass Rsh to 2pl own side.', 2);
INSERT INTO 'dancecrib' VALUES (2891, '2012-01-22 19:30:01.789858+00', '2015-12-22 14:35:13.346414+00', 4832, 1, NULL, 'ace', '1--::

  1c+2c+3c mirror Reels3 on own sides (2c start out and up), at end 1c cross RH to (1x,2,3)

9--::

  1c+2c+3c set with pas de basque and coupe (balance) ; all turn P RH (1x,2,3)

17--::

  1c+2c+3c mirror Reels3 on own sides (1c cross down, 2c start out and up) (1,2,3) 

25--::

  1c dance down between 3c, cast up round them ; dance up through 2c and cast off to 2pl (2c up).

', 4);
INSERT INTO 'dancecrib' VALUES (9580, '2017-02-02 21:20:29.489234+00', '2020-08-23 10:10:31.708941+00', 17400, 2, 160, 'ace', '1-8::

  1C 2C RH Across ; 1M 2M set, 1M  cast and 2M dance up *AS* 1L 2L set x2.

9-16::

 1C  Chain - to begin 1C cross RH + 2C loop (path of Ladies Chain).

17-24::

  1M followed by 1L dance down [2], 1L followed by 1M dance up [4} , 1M dance  down and curl into 2pl as 1L dances down into top place.

25-32::

   1L 2L set, 1L dance down and 2L cast up *AS* 2M 1M set x2 ; 2C 1C LH Across.', 3);
INSERT INTO 'dancecrib' VALUES (2894, '2012-01-22 19:30:01.910597+00', '2021-05-03 09:28:02.105068+00', 4844, 1, NULL, 'ace', '1–::

  1c turn RH and cast off one place (2c up) ; 1¼ turn LH to:

9–::

  1c+1cnrs BiL, face and set to 1cnrs ; swivel R and again BiL, 1c turn ¾ RH to:

17–::

  1c+2cnrs BiL, face and set to 2cnrs ; swivel L and again BiL, 1c turn LH to finish 1M below, 1W above

25–::

  Teapots R+L (1W+2c & 1M+3c RHA, pass Rsh ; 1W+3c & 1M+2c LHA) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2885, '2012-01-22 19:30:01.538011+00', '2017-09-10 21:48:14.923583+00', 4808, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; all set | 1c petronella to centre, facing out BtoB _while{2}_ 2M+3W cast (Lsh back) to face them in line across _while{2}_ 2W+3M petronella (2W up, 3M down) to midline facing each other

9–::

  2M+1c+3W ½Reel4 across ; after passing Lsh 1c turn LH ¾ | 2W+1W & 1M+3M turn RH ½ and face that person

17–::

  1W+2W+3M+1M ½Reel4 on midline ; after passing Lsh 3M+2W turn LH ¾ | 2W+3W & 2M+3M turn RH ½ and face that person

25–::

  2W+3W+2M+3M ½Reel4 across ; All set | 1c set, turning R about _while{2}_ 2W+3W & 2M+3M turn RH ¾, all face clw round the set

33–::

  All ½ chase clw ; 2c+3c continue chase _while{4}_ 1c turn RH to (2,1,3)



{{explanation}}

(Hint: In all ½ turns and ½Reels face dancer of own sex).', 3);
INSERT INTO 'dancecrib' VALUES (10649, '2018-04-18 11:37:43.813551+00', '2018-04-19 02:16:26.589155+00', 13917, 1, 202, 'ace', '1--::

  1c cross LH, on [2] 1c(2c) face dn(up) | 1c+2c La Baratte (2,1x,3)

9--::

  2M+1W & 2W+1M set | 2M & 1M chase cclw ½ to exchange places _while{4}_ 2W+1W turn RH ½, face each other | cast R to exchange places (to 1,2x,3) | 1M+2M turn LH ¾ to finish BtoB in centre 1M(2M) facing up(dn) _ while{2}_ 1W&2W chase clw into midline, 1W(2W) facing 2M(1M)

17--::

  2W+1M+2M+1W 6 bars of Reel4 (to 2M,2W,1W,1M) | 2c & 1c turn P RH ¾, 1c facing 1cnrs at end (2,1,3)

25-36::

  Dance to Corners and Set, on [36] 1c finish in 2plx centre (3x,1x,2x)

37-40::

  3c & 2c chase clw ½ _while{4}_ 1c turn P RH 1½ (2,1,3) ', 4);
INSERT INTO 'dancecrib' VALUES (10654, '2018-04-18 21:25:03.735536+00', '2020-09-22 15:36:41.709134+00', 18284, 1, NULL, 'ace', '*Start (1,2,3x,4x)*



1--::

  Reels4 on the sides 

9--::

  1c+2c & 3c+4c S&Link ; 1c+4c ½La-Ch 

17--::

  1c+4c ½M-Ch ; All set | All turn P BH (2,4,1x,3x) 

25--::

  2c+4c & 1c+3c Circle4 and back', 3);
INSERT INTO 'dancecrib' VALUES (3652, '2012-11-08 15:48:38.547569+00', '2022-02-15 15:52:55.99841+00', 14458, 1, NULL, 'ace', '{{explanation}}

On second chord cross to (1,2,3x,4x)



1–::

  All set to P | 1M+2W & 3W+4M cross RH ; 1W+2M & 3M+4W cross LH | All cross RH (2,1,4x,3x)

9–::

  2c+1c & 4c+3c RHA ; 1c+4c LHA, 1M+4M finish facing out (2,1,4x,3x)

17–::

  2c+1c & 4c+3c Reels4 across: pass Lsh in the middle and cast clw in the loops, reels finish as started

25–::

  1W+4M following & 4W+1M following dance out through end couple, cast L to the other pair''s vacant places ; All turn P LH (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (2749, '2012-01-22 19:29:55.853415+00', '2017-04-22 15:30:12.366301+00', 4180, 1, NULL, 'ace', '1–::

  1M+2W turn RH ; 1W+2M turn RH

9–::

  1c lead down the middle and up

17–::

  1c set | cast (2c up) ; 2c+1c+3c A&R

25–::

  All chase clw once round {6} | All cpls set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2887, '2012-01-22 19:30:01.623208+00', '2020-09-22 16:15:34.341638+00', 4816, 1, NULL, 'ace', '1–::

  1c+4c long cast to centre _while{4}_ on [3-4] 2c+3c dance to end with loop ; 1c+4c Circle 4 L _while{4}_ 2c+3c turn RH

9–::

  1c+4c S&Link ; chase ½ clw | cross RH (2,1,4,3)

17–::

  1c+4c+3c ½ G_Chain ; set, cross RH (2,3,4,1)

25–::

  2c+3c & 4c+1c Poussette (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (14335, '2021-09-27 00:44:50.725338+00', '2021-10-27 11:20:43.999287+00', 16202, 1, 202, 'ace', '1--::

  1c+3c RHA ; chase clw ½ (3,2,1,4)

9--::

  2c+4c LHA ; chase cclw ½ (3,4,1,2)

17--::

  All turn P RH ; all W chase clw one place | all set to new P

25--::

  Circle8 and back



*Deviser''s note* : on 2nd time through  

17--::

  All turn P LH ; all M chase cclw one place | all set to new P  



3rd time through: repeat [17-24] 1st time through,  

4th time through: repeat [17-24] 2nd time through.', 0);
INSERT INTO 'dancecrib' VALUES (2884, '2012-01-22 19:30:01.493904+00', '2020-12-13 19:07:18.108704+00', 4806, 1, NULL, 'ace', '1–::

  1c+2c set, turn BH ; circle4 L

9–::

  1c down the middle (2c up) and up, to 1W/1M between 2c/3c facing 1cnr

17–::

  1W+2c & 1M+3c Rsh Reels3 across

25–::

  Corner, P, corner, and _while_ turning P lead to top, 2c dancing in below, for

33–::

  1c+2c Allemande (2,1,3)

41–::

  2c+1c+3c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (2897, '2012-01-22 19:30:02.055392+00', '2020-12-13 19:11:12.545222+00', 4857, 1, NULL, 'ace', '1–::

  1M+2W set adv & turn BH ¾ and pivot R _while{4}_ 1W+2M chase cclw half round them, all finish on midline facing P ; 1c+2c set | turn RH ¾ into

9–::

  2c+1c Allemande {6}, finish facing up RHJ | 1c cast and 2c lead up with loop to (2,1,3)

17–::

  All adv {1}, retire {1} | cross RH, to sidelines ; 1c+3c circle4 L (2x,1x,3x)

25–::

  All adv {1}, retire {1} | cross LH, to sidelines ; 2c+1c circle4 R', 3);
INSERT INTO 'dancecrib' VALUES (2895, '2012-01-22 19:30:01.95205+00', '2020-12-21 11:16:12.498682+00', 9560, 1, NULL, 'ace', '1–::

  1c+3c cross down into Fig8 round couple below _while{8}_ 2c+4c set and cross ; repeat

9–::

  1c+3c dance down the middle | set to P ; dance up | 1c casts to 3pl _while{2}_ 3c dances to 1pl

17–::

  3c+2c & 1c+4c R&L, finishing in middle for

25–::

  3c+2c & 1c+4c Poussette (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (1731, '2012-01-22 19:28:58.859417+00', '2021-03-06 22:25:55.318773+00', 9002, 1, NULL, 'ace', '1–::

  1c+3c set (1c face out) | »the Capstan« (1c+3c dance 1½ times round 2M/2W, 1c starting out, 3c in) (to 3,2,1)

9–::

  1c cross up (no hands) to face out (2c down) | 3M+1W & 1M+2W turn RH ¾ ; 1c pass up/down Rsh | 3W+1M & 1W+2M turn RH ¾ to (3,1x,2)

17–::

  All set | all turn P ½ RH ; all chase ½ clw (2,1x,3)

25–::

  2c+1M & 1W+3c RHA ; 1c ½fig8 Rsh round 4cnr (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1693, '2012-01-22 19:28:56.935125+00', '2021-12-20 15:38:52.836496+00', 301, 1, NULL, 'ace', '1–::

  1c+2c cross and set ; 1c dance between 2c, divide, behind and up between 3c to 2pl _while_{on 7-8} 2c dance up and in, joining 1c to face down for

9–::

  2c+1c Allemande (facing down) (1x,2x,3)

17–::

  1c+2c cross and set, advancing on [21] to 1diag for ; ½ Poussette, 1c finish facing 1cnrs

25–::

  Turn CPCP, 1c crossing LH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2892, '2012-01-22 19:30:01.830807+00', '2021-06-12 10:57:36.095864+00', 4835, 1, 202, 'ace', '1--::

  1c+4c RHA (2c & 3c step out on [1-2]) (to 2,1,4,3) ; 2c+3c LHA (1c & 4c dance out to original places on [5-6]) (1,2,3,4)

9--::

  Reels4 on sides

17--::

  All set | A&R | set 

25--::

  1c lead down, cross and cast behind 3c & 4c to 4pl (2c+3c+4c up on [27-28]) ; 1c turn P RH 1½ (2,4,3,1)

33--::

  Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (8132, '2013-12-07 00:35:32.748232+00', '2014-04-30 23:24:03.629597+00', 4881, 1, NULL, 'ace', '1–::
  1c cross RH | cast off ; 1c+3c Circle4 L (2,1x,3)
9–::
  1c cross RH | cast up ; 1c+2c Circle4 R (1,2,3)
17–::
  1c lead down and back, finish BtoB between 2c facing opposite side
25–::
  1c set to 2c | turn opposite RH and 1c join LH ; BiL | 1c turn LH to finish between 3c
33–::
  1c set to 3c | turn opposite RH and 1c join LH ; BiL | 1c turn LH (2c up) to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2903, '2012-01-22 19:30:02.259382+00', '2014-06-17 00:48:26.991693+00', 4871, 1, NULL, 'ace', '1–::

  1c set | cast off one (2c up) ; turn RH 1½ to finish in centre, 1M facing down, 1W up

9–::

  LHA with cnrs (2W+1M +3W & 2M+1W+3M), and pass Lsh ; RHA with partner''s corners, passing Rsh to (2,1x,3)

17–::

  2W+1M+3W & 2M+1W+3M BiL | Reels3{6} on the sides (start R, = Rsh to 1cnr) 1c pass Lsh to own side facing out

25–::

  repeat on own sides (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13949, '2021-04-11 13:00:30.353453+00', '2021-04-11 13:07:36.324327+00', 14510, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; turn P RH (2,1x,3)

9--::

  Reels3 on sides, 1c RSh to 1cnrs. On [15-16] 1c pass P LSh to 2pl (2,1,3)

17--::

  Reels3 on sides, 1c LSh to 4cnrs. On [23-24] 1c pass P RSh and face 1cnrs

25--::

  1c turn 1cnrs RH | pass P RSh ; turn 2cnrs RH | pass P RSh to 2pl (cnrs dance 4 bars) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11768, '2019-04-05 00:54:59.033692+00', '2019-04-05 00:54:59.033692+00', 19251, 1, NULL, 'ace', '1--::

  1c+2c ½ R&L ; set | Cross RH and 2c face out (2,1,3)

9--::

  2c+3c DblFig8 round 1c (3c cross up to start) (2,1,3)

17--::

  2c+1+3c Allemand (3,1,2)

25--::

  Circle6 and back (3,1,2)



', 3);
INSERT INTO 'dancecrib' VALUES (2900, '2012-01-22 19:30:02.140411+00', '2017-07-07 12:46:02.767134+00', 4862, 1, NULL, 'ace', '{{explanation}}

Two chords, on 2nd chord 1c change places and face 2c



1–::

  1W+2M & 1M+2W set and change places Rsh ; 2c+1c set to P and cross Rsh to face other C

9–::

  Repeat 1-8

17–::

  1c+2c circle4 L twice, ending for

25–::

  1c+2c Poussette (1c begin and end on the opposite side)



{{explanation}}

1c cross to own side and the new first couple cross to opposite side on [31-32] of their »idle« time (recommended by TACnotes and in the Strathspey List FAQ).  This dance is frequently done round-the-room, in which case DI = 100%', 3);
INSERT INTO 'dancecrib' VALUES (7833, '2013-08-21 08:31:49.452599+00', '2023-02-04 01:23:04.704028+00', 6931, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place & dance 1/2 Fig of 8 round 2s
9-16::
    1s with nearer hands joined set to 2L, turn inwards & set to 3M, set
    3L, turn & set to 2M & end BtoB (Man facing up & Lady down)
17-24::
    1s dance Double Triangles (up/down)
25-32::
    1s dance RH across (Man with 2s & Lady with 3s), 1s turn LH _while_
    2s+3s chase clockwise 1/2 way
33-40::
    1s dance RH across with same couples (have changed places), 1s turn
    LH & end in 2nd places _while_ 2s+3s chase clockwise 1/2 way
41-48::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (2902, '2012-01-22 19:30:02.219453+00', '2017-07-07 14:20:06.594459+00', 4865, 1, NULL, 'ace', '1–::

  1W+2W+3W dance cclw round the men, 1W leading

9–::

  1M+2M+3M repeat clw, on [16] 1c+2c dance in for

17–::

  1c+2c Promenade (1,2,3)

25–::

  1c+3c Poussette (2c up on bars 1-2)', 3);
INSERT INTO 'dancecrib' VALUES (9163, '2016-06-11 14:30:22.966326+00', '2023-01-14 15:43:41.428067+00', 17022, 1, NULL, 'ace', '1--::

  1c cross RH and dance &frac12; way around outside the set ; cross LH below 3c & dance around the outside back to place

9--::

  All &frac12; interlocking Reels4{3} ending with &frac12; LH turning the next dancer{1} so M face in ;

  M RHA _while{4}_ W chase &frac12; way cclw & pass opposite M LSh into centre

17--::

  W LHA _while{4}_ M chase &frac12; clw & end turning P &frac14; RH so W face out ;

  &frac14; Schiehallion reel

25--::

  Continue with a further &frac12; Schiehallion reel (4,1,2,3)

', 5);
INSERT INTO 'dancecrib' VALUES (2901, '2012-01-22 19:30:02.180419+00', '2020-05-27 08:11:41.975542+00', 4864, 1, NULL, 'ace', '1–::

  1c+2c+3c Rsh Reels3 on own sides

9–::

  1c set, cast off (2c up) ; ½ Fig8 up round 2c (2,1x,3)

17–::

  All A&R ; turn BH (2c+3c one turn _while_ 1c turn 1½ and finish BtoB facing own sides) for

25–::

  DTr', 3);
INSERT INTO 'dancecrib' VALUES (1631, '2012-01-22 19:28:51.961152+00', '2021-03-06 22:28:01.885776+00', 9001, 1, NULL, 'ace', '1–::

  1c+2c+3c chase clw half way round ; 1c dance to top and cast off (2c down) (3x,1x,2x)

9–::

  ½Reel4 with 3cnr ; BiL with RH to 4cnr pos. and LH to P | set to 4cnr pos

17–::

  ½Reel4 with 4cnr ; BiL with RH to 1cnr and LH to P | set to 1cnr

25–::

  2c+1W & 1M+3c circle3 L, 1c finish BtB in the middle ; 1c dance out (W up, M down) and cast R to 2pl', 3);
INSERT INTO 'dancecrib' VALUES (3820, '2013-07-13 15:56:15.247514+00', '2021-03-27 21:49:29.957753+00', 12569, 1, NULL, 'ace', '1–::

  All set | all turn BH twice | all set

9–::

  G-Chain (1c and 4c cross to start)

17–::

  1c+4c Fig8 on own side round 2c+3c, starting inwards, 1c passes infront of 4c each time.  On [24] 2c+3c dance in for

25–::

  1c+2c & 3c+4c ½ Poussette, on [28] 2c+3c dance to sidelines as  1c+4c  continue slow turn ; 1c+4c ½ Poussette (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12778, '2020-04-25 22:24:18.690358+00', '2021-07-30 08:59:57.997538+00', 19901, 1, 202, 'ace', '1--::
  2c Reel4 on 1diag. On [8] 2c pass LSh, BtoB on midline with 1M facing up
9--::
  ½ Reels3 across, 2c LSh to 3cnrs ; ½ Reels3 on sides, 2c RSh to 4cnrs[pos] (3x,2,1x)
17--::
  2c Reel4 on 2diag, LSh to 2cnrs[pos]. 2c in 2pl face out (3x,2,1x)
25--::
  2c chase clw one place _as_ 3c & 1c Petronella Turn to midline | 2c dance between 3c/1c to opposite sides _as_ 3c & 1c set ; 2c chase cclw to 2pl _as_ 3c & 1c Petronella Turn and set (3,2,1)
33--::
  2c ½ Fig8 down round 1c to 2plx ; 2c ½ Fig8 up round 3c to 3pl (1c up) (3,1,2)', 5);
INSERT INTO 'dancecrib' VALUES (14402, '2021-10-28 15:59:37.073905+00', '2021-10-29 17:18:22.905601+00', 20537, 1, 202, 'ace', '1--::

  1c set | pass RSh ; cast two places (2c up) | dance up to face 1cnrs

9--::

  SetH&G (2,1,3)

17--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag (3x,1x,2x)

25--::

  All chase clw ½ ; 1c birl to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2924, '2012-01-22 19:30:03.135087+00', '2020-12-14 09:33:58.051009+00', 4935, 1, NULL, 'ace', '1–::

  1c+2c cross, 1W+2W joining RH and passing between partners | 1W+2W & 1M+2M change places LH ; repeat [1-4] to (1,2,3)

9–::

  1c cross RH | 1W+2M & 1M+2W change places LH ; 1W+3M & 1M+3W full RH turn to (2,1x,3), all facing in

17–::

  All A&R ; all advance | 1c turn ½ RH to 1pl _while{2}_ 2c cast off and 3c retire (1,2,3)

25–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (8904, '2015-09-16 11:35:26.997404+00', '2015-09-16 13:30:19.291387+00', 16736, 1, NULL, 'ace', '1-4::  1W set _while{2}_ 1M+2c dance one place clw | 1W Spring Points _while{2}_ 1M+2c set ; 

5-16::  1c+2c R&L (cross to start), at end M face out ; ½ La-Chain (2,1x,3)

17--::  1M+1W following cast round 3W and cross (3c up) to (2,3,1) ; 3c+1c turn LH 1½ on the sides (2,1,3)

25--::  Lsh Reels3 on the sides, 1c starting up (2,1,3)



*option: 1W may set on [3-4]*

', 3);
INSERT INTO 'dancecrib' VALUES (10854, '2018-06-19 20:03:44.195098+00', '2018-06-19 20:03:44.195098+00', 18387, 1, NULL, 'ace', '1-::

  1c &frac12; turn RH &amp; twirl away to opposite side ; turn 1&frac12; BH to own sides

9-::

  1c+2c Bourrel, 1c retain BH in centre &amp; 3c step in ready for

17-::

  1c+3c &frac12; Poussette, 4c step in ; 1c+4c &frac12; Poussette (2,3,4,1)

25-::

  2c+3c DblFig8 (2c cross, 3c up to start) _while_ 4c+1c Circle4 &amp; back (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (13214, '2020-10-01 21:23:30.146618+00', '2021-03-07 16:58:50.844868+00', 20084, 1, 1645, 'ace', '*3c & 4c start on opposite sides (1,2,3x,4x)*

1-::

  1c & 4c long cast off/up touching NH (2c & 3c to ends on [3-4]) ; &frac12; Fig8 round 2c/3c (2,1x,4,3x)

9-::

  1c+4c LHA & face up/down on sides ; &frac12; RSh Reels4 on sides (3x,4,1x,2)

17-::

  All turn facing person 1&frac14; RH to lines across ; &frac12; RSh Reels4 across

25-::

  All turn same person 1&frac14; RH to sides, 1c facing 4c ; 1c+4c change pl LH & face P | all set (3,1,4x,2x)

33-::

  All &frac12; turn BH to face P | cast away to sides ; &frac12; Circle8 to L (2x,4x,1,3)

::

*Repeat once in strathspey time, then twice in reel time with RH turns in [33-34].*

', 2);
INSERT INTO 'dancecrib' VALUES (2913, '2012-01-22 19:30:02.684747+00', '2017-03-31 22:39:01.023027+00', 4911, 1, NULL, 'ace', '1–::

  1c+2c+3c set | 1c cross RH (1W long turn) ; 1c+2c change places on the sides LH (1M long turn) | 2c+1c+3c set (2,1x,3)

9–::

  1c Petronella turn | set ; turn LH 1½

17–::

  Reels3 across, 1c Lsh to 1cnr

25–::

  Reels3{6} on the sides, 1c begin Rsh to 2cnr | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2108, '2012-01-22 19:29:20.540529+00', '2017-07-07 14:16:26.645347+00', 1762, 1, NULL, 'ace', '1–::

  1c, NHJ, set twice to 2W ; 1c+2W Circle3 L

9–::

  1c+2W (on the L) set twice to 2M ; 1c+2c Circle4 L

17–::

  1c+2c RHA {3}, LHA {3} | 1c cast to face 1cnrs as 2c dance to top

25–::

  1c set to and turn cnrs

33–::

  Reels3 on the sides (Lsh to 1cnr), finish (2,1x,3)

41–::

  1c set twice ; turn RH 1½ (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10247, '2017-11-10 09:23:47.436027+00', '2020-07-12 15:54:02.381197+00', 15675, 2, 1993, 'ace', '1- 8::

  1M & 3W change places passing RSh and set, while 1W & 3M set and change places passing RSh. Repeat back to places.

9-12::

 1s cross RH to 2nd place, 1s turn 3s handy hand, to end slightly in from 2nd place facing opp sides (not back to back). 2s up 9&10.

13-16::

  1s set retiring to finish facing each other, ½ turn by the right hand to face each other and cast out on opposite sides.

17-20::

  1s cast round 1st corners to meet in centre, and pull RSh back to finish back to back, 1W facing up, 1M facing down.

21-24::

  1s cast round partners 2nd corners to 2nd place own sides.

25-28::

  1s & 3s dance as bars 1-4 (to 2 3x 1x).

29-32::

  3s & 1s ½ turn by the right hand to face each other and cast out on own sides.

', 0);
INSERT INTO 'dancecrib' VALUES (8269, '2014-05-15 08:29:30.396276+00', '2018-11-09 21:59:58.273968+00', 14381, 1, 1041, 'ace', '1--:: 1c set | turn BH ; dance down 1 place (2c up) | turn BH to face 1cnr

9--::  1c+1cnrs set H.Schottische ; turn 1cnr RH | turn P LH to face 2cnr

17--:: Repeat with 2cnrs, finish in the middle facing up

25--:: 1c cast off 2 places (3c+4c up) ; 1c turn BH 1½



', 4);
INSERT INTO 'dancecrib' VALUES (2915, '2012-01-22 19:30:02.762203+00', '2014-04-30 23:24:03.84579+00', 12334, 1, NULL, 'ace', '1–::
  1c cross RH and cast down (2c up) ; ½ Fig8 up (2,1,3,4)
9–::
  1c+3c+4c Inveran Reels3 (1c cross from top and bottom, 3c+4c stay on own side) (2,1,3,4)
17–::
  4c cross RH and cast up (3c down) ; ½ Fig8 down (2,1,4,3)
25–::
  2c+1c+4c inverted Inveran Reels (4c cross up, cross back from top)
33–::
  2c+1c+4c set | cross RH ; set | turn RH ½ and face up for
41–::
  2c+1c+4c Allemande (4,1,2,3)', 3);
INSERT INTO 'dancecrib' VALUES (3045, '2012-01-22 19:30:08.196827+00', '2021-12-20 15:39:47.189406+00', 5362, 1, NULL, 'ace', '1–::

  All A&R twice

9–::

  All clap 3 times {2}, beat with the heel 3 times {2} ; All pass person opposite Rsh to meet next couple', 2);
INSERT INTO 'dancecrib' VALUES (15444, '2023-02-16 12:47:45.200836+00', '2023-02-16 13:18:08.996299+00', 17807, 1, 202, 'ace', '1--::

  1c+2c DblFig8, 1c crossing down. 2c face out and up (1,2,3)

9--::

  Reels3 on opp sides, 1c crossing down to 2pl. 2c face out and up (1x,2,3)

17--::

  1c+2c change places EH 1½. 1c face out ; 1c+3c change places EH (to 2,3,1x) | 1c turn P LH ½ to 2pl centre and face up (2,3,1)

25--::

  1c dance up to top | cast off (3c down) ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15446, '2023-02-16 14:41:58.008338+00', '2023-02-16 14:44:01.175448+00', 17811, 1, 202, 'ace', '1--::
  1c+2c The Espagnole (2,1,3)
9--::
  All NHJ set advancing into midline, RSh to P | all M (3M leading) & all W (2W leading) chase clw to own sides (to 3,1,2) | 3c & 2c cross RH _while{2}_ 1c turn P RH to face 3cnrs[pos]
17--::
  ½ Reel4 on 1diag, pass P RSh to face 4cnrs[pos] ; ½ Reel4 on 2diag (2,1,3)
25--::
  1c+3c The Bourrel (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (9325, '2016-09-25 13:16:01.540415+00', '2016-09-25 13:16:01.540415+00', 16614, 1, NULL, 'ace', '1--::

  1c+2c Poussette

9--::

  1c set | cast (2c up) ; dance between 3c and cast up to 2pl in the middle facing up

17--::

  Reels3 on the sides, 1c starts in and up (2.1.3)

25--::

  1c+3c S&Link ; 3c+1c Circle4 L (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8906, '2015-09-16 22:17:24.394713+00', '2015-09-16 22:17:24.394713+00', 16738, 1, NULL, 'ace', '*3c+4c cross before the single chord (1,2,3x,4x)*



1--::  1c+2c & 3c+4c Set & Rotate (2,1,4x,3x)

9--::  Rsh Reels4 on both sides (2,1,4x,3x)

17--::  1c & 4c dance Rsh individually round 2c & 3c resp. to same places, and the M face out ; 1c+4c (M leading) chase cclw ½ to finish (2,4,1x,3x) 

25--::  All chase cclw half round, into ; ½ Circle8 R (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (9326, '2016-09-25 13:43:37.026416+00', '2016-10-12 16:20:51.972102+00', 16613, 1, NULL, 'ace', '1--::

  1c set | 1W, 1M following, cast off round 3W (2c up) and dance up to face 2M

9--::

  2M+1c (changing lead)+3M Rsh Reel3 on M side, 1W (1M behind) finish facing 2W

17--::

  2W+1c (changing lead)+3W Lsh Reel3 on W side,1c finish on midline

25--::

  1c dance up between 2c and cast to 2pl ; All turn P RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9327, '2016-09-25 16:57:15.546233+00', '2016-09-25 16:57:15.546233+00', 16570, 1, NULL, 'ace', '1--::

  1c+2c set | RHA | 1c cast as 2c dance up (2,1,3)

9--::

  1c turn 1cnr RH | pass Rsh ; turn 2cnr RH and (holding the RH) finish BtoB on midline facing end

17--::

  DTr up-down for 6 bars | 1c turn 1cnr LH while 2cnrs set, finish (2,1x,3)

25--::

  Reels3 on the sides, Rsh to 2nr (2,1x,3)

33--::

  1c ½ Fig8 R (2,1,3) ; All petronella to midline and set

41--::

  2c turn RH 1½ _while{4}_ 1c+3c ½ Reel4 ; All set | petronella to(2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2765, '2012-01-22 19:29:56.504516+00', '2021-05-09 09:27:06.058874+00', 4280, 1, NULL, 'ace', '1–::

  All C turn RH ; turn LH

9–::

  1c set | cast off (2c up) ; 2c+1c RHA

17–::

  1c set | cast off (3c up) ; 3c+1c LHA

25–::

  G-Chain (cross at top to start)', 2);
INSERT INTO 'dancecrib' VALUES (13559, '2021-01-18 10:09:12.220186+00', '2021-01-18 10:11:59.354533+00', 16917, 1, 202, 'ace', '1--::

  1c+3c LHA to places ; 1W & 3W (P following) chase cclw ¾ inside the square set

9--::

  1c+2c & 3c+4c RHA ; Circle4 L

17--::

  Reels4

25--::

  1c & 3c pass opposite person LSh and chase cclw to original places ; all chase cclw one place, face in and set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2911, '2012-01-22 19:30:02.605746+00', '2021-05-04 08:43:19.808896+00', 4908, 1, NULL, 'ace', '1-16::

  1M+2c Lsh ½ Reel3 ; 1M picks up P in promhold and continues Reel3 for 8 bars ; 1c with 2c following lead down (all on opposite side)

17–::

  2c followed by 1c lead to the top, 1c lead between 2c, cross and cast to (2x,1)

25–::

  1c ½ Fig8 round 2c ; 2c+1c set and cross LH (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (1807, '2012-01-22 19:29:03.371573+00', '2021-01-18 11:16:20.95554+00', 11913, 1, NULL, 'ace', '1–::

  All Turn RH ½ and twirl R to opp side ; 1c+3c ½ Fig8 round couple below (1,2x,3,4x)

9–::

  1c+2c & 3c+4c L-Chain, finish M as at start, W on diagonal facing P

17–::

  1c+2c & 3c+4c Reels4, finish M as at start, W on sideline beside them

25–::

  All set | 1c+2c & 3c+4c Petronella in tandem ; Set facing up/dn | Cross RH with person opposite (1,2x,3,4x)

33–::

  1c cast off as 2c cross up RH | 1c cross down RH as 3c cast up ; 1c cast off to 4plx as 4c cross up | 1c cross RH (2,3,4,1)

41–::

  2c+3c & 4c+1c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (2917, '2012-01-22 19:30:02.841689+00', '2019-03-12 11:39:19.136757+00', 4927, 1, NULL, 'ace', '1-16::

  1W+2W+3M+4M full petronella: move to next dancer''s place and set to dancer opposite (1W to 3M and 2W to 4M)

17–::

  All W RHA ; all turn P LH once round

25–::

  All M RHA ; all turn P LH once round

33–::

  All W, holding P with LH, RHA{8}, at the end the M pivot R to join BH with P with M facing next place cclw for

41–::

  All Poussette cclw round the square to places (move to next place, ¼ clw turn | repeat 3 times)



{{explanation}}

The dance may be repeated with the other four dancers starting.  

The dance flows better if the turns on 21-24 and 29-32 are danced as 1½ turns', 3);
INSERT INTO 'dancecrib' VALUES (2192, '2012-01-22 19:29:24.963581+00', '2017-07-07 14:18:27.954073+00', 2024, 1, NULL, 'ace', '1–::

  1c Reel3 on opposite side with 2c+3c (1x,2,3)

9–::

  1c Reel3 on own sides with 2c+3c (1,2,3)

17–::

  1c lead down the middle and up

25–::

  1c+2c Allemande, finish 1c in DTr position facing own sides (1c face up NHJ and open ; use PdB if desired)

33–::

  DTr (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2916, '2012-01-22 19:30:02.801838+00', '2017-05-23 08:49:31.464602+00', 4925, 1, NULL, 'ace', '1–::

  1c+3c Poussette (true »diamond«, no »diagonals«, the cpls are on the midline on [1] and [4]  on [7] 2c dance in

9–::

  1c+2c+3c Promenade

17–::

  1c down the middle {3}, up | cast off (2c up) (2,1,3)

25–::

  Circle6 and back



{{explanation}}

note: for the poussette 2c needs to move out wider.', 3);
INSERT INTO 'dancecrib' VALUES (2681, '2012-01-22 19:29:52.869431+00', '2017-07-07 14:20:28.419422+00', 3862, 1, NULL, 'ace', '1–::

  1c lead down the middle (2c up) ; turn RH ½, lead up to (2,1x)

9–::

  L-Chain, finish in promhold facing up, 2M+1W in 1pos (turn more) and 1M+2W in 2pos (turn less)

17–::

  2M+1W & 2W+1M Promenade, on last 2 bars 2M casts off to P and 1M dances up to 1W for

25–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (11156, '2018-09-25 08:02:33.950175+00', '2020-11-14 20:08:33.700864+00', 18660, 1, 1645, 'ace', '1-::  1c+2c &frac12; LHA | then 2c turn LH{4} | set _while{6}_ 1c &frac12; turn LH ; cast up | cross down RH & face each other

9-::  1c dance round each other RSh to (2x,1x,3) | 1c+3c turn EH, 1c end in tandem, M leading, facing 2M ;

      1c+2c &frac12; alternating tandem RSh Reel3 across, 1c end in centre, W leading, facing M side

17-:: 1c+3c &frac12; alternating tandem LSh Reel3 across, 1c end in centre 2pl facing up ;

      1c+2c turn EH, 1c end on sides (2,1x,3x) | 1c dance round each other LSh & take LH facing down

25-:: 1c cross down LH | cast up & take RH ; &frac12; turn RH _while{6}_ 3c set | turn RH{4} | then 1c+3c &frac12; RHA (2,3,1)

   :: *Bars 17-32 repeat 1-16 in reverse order with opposite hands at the other end of the set.*

', 5);
INSERT INTO 'dancecrib' VALUES (12502, '2020-01-12 16:58:28.427625+00', '2020-01-12 17:08:13.898823+00', 19747, 1, 202, 'ace', '1--::

  1c+2c ½ RHA | set (to 2x,1x,3) ; 1c+3c ½ LHA | set (2x,3x,1)

9--::

  Reels3 {6} on sides, 1c cross up, 3c dance out and down. 3c face out (to 2x,3x,1x) | 1c lead up to 2plx centre _while{2}_ 3c dance down to 3plx (2x, *1x*,3x)

17--::

  1c RHJ face P and set | turn RH ; 1c dance RSh round 1cnrs[pos] into facing lines3 across

25--::

  All A&R ; 3C S&Link (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11766, '2019-04-04 14:02:25.136985+00', '2019-04-05 22:51:49.644285+00', 14688, 1, NULL, 'ace', '*Start (1,2,3x,4x)*

1--::

  1c+4c cross RH and face out _while{2}_ 2c+3c set | 1c+2c & 3c+4c ¾ DblFig8 (2,1,4x,3x)

9--::

  1c+4c S&Rotate, (2,4x,1,3x).  For the next figure 4W+1M (on M side) & 4M+1W (on W side) form lead-change pairs.

17--::

  2W+both pairs (W leading)+3W ½ lead-change Reel4 on 2diag, pairs pass Lsh and face R towards same end ; 2M+both pairs (M leading)+3M ½ lead-change Reel4 on 1diag.  At end pairs (W leading) meet Rsh

25--::

  1c+4c dance Rsh round P and loop to sidelines ; All A&R (3,1,4x,2x)

', 3);
INSERT INTO 'dancecrib' VALUES (3417, '2012-01-22 19:30:24.586782+00', '2020-07-12 22:10:56.195488+00', 6687, 1, NULL, 'ace', '1–::

  1c+2c Circle4 and back, into

9–::

  1c+2c Poussette, 1c face out own side (2,1,3)

17–::

  Opposing Reels3 across, Rsh to 3cnr

25–::

  1c turn RH 1¼ _while_{4} 2c+3c ½ R&L ; 3c+1c+2c chase clw ½ to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9167, '2016-06-13 13:43:56.030124+00', '2016-06-14 00:50:10.193649+00', 17041, 1, NULL, 'ace', '1--::

  	1c+3c Reel4, to start the W cross passing Lsh and the M set (1,2,3,4)

9--::

  	2c+4c repeat, all finish facing corner (1,2,3,4)

17--::

  	All Turn cnr RH ; turn P LH (1,2,3,4)

25--::

  	All set to corner HS ; All with NHJ A&R to centre (1,2,3,4)

33--::

  	All “Schiehallion Link and Set” : (All W cast to P’s place as M dance to W place of next cpl to the R | All set ; All M cast to M’s place as W dance to join P | All set) (2,3,4,1)

41--::

  	Circle8 and back (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2778, '2012-01-22 19:29:57.025376+00', '2014-08-24 14:24:02.129641+00', 4334, 1, NULL, 'ace', '1–::

  1c+2c A&R ; half R&L

9–::

  1W+2M, turn RH 1½ to original places ; 1M+2W repeat

17–::

  1c lead down the middle and up

25–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (2929, '2012-01-22 19:30:03.334707+00', '2015-02-27 12:50:41.404439+00', 4943, 1, NULL, 'ace', '1–::

  1c long cast (2c up) ; dance between 3c and cast up

9–::

  Opposing Reels3 across, Lsh to 1cnr

17–::

  1c set | cross RH ; set | turn LH ¾ into

25–::

  Teapots R ; Teapots L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3201, '2012-01-22 19:30:15.477088+00', '2015-09-18 12:18:16.59597+00', 5872, 1, NULL, 'ace', '1–::

  1c+4c cross RH | cast to middle (2c+3c to ends) ; ½ Fig8 round end cpl (2,1,4,3)

9–::

  1c+4c in promhold (4M has P on L) Reels3 across with own end cpls, Rsh to 1W/4M position, finish 1c on M side facing 4c across  

17–::

  1c+4c in promhold dance Lsh once round each other ; lead out (1c down, 4c up) between end cpl ; cross and cast in (2,4,1,3)

25–::

  Circle8 and back



', 3);
INSERT INTO 'dancecrib' VALUES (2928, '2012-01-22 19:30:03.295198+00', '2020-09-09 09:52:13.391221+00', 9649, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; half Reels3 across, RSh to 4cnr (2x,1,3x)

9–::

  1c+1cnrs »pass and turn, 1c pass RSh ; 1c+2cnrs repeat, finish (2x,1x,3x)

17–::

  All set | cross RH ; chase ½ clw (3x,1x,2x)

25–::

  All S&Link3 twice (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2927, '2012-01-22 19:30:03.254552+00', '2020-12-19 15:08:39.971824+00', 8654, 1, NULL, 'ace', '{{explanation}}

3c+4c start on opposite side (1,2,3x,4x)



1–::

  1c+4c set | 1c+2c & 3c+4c ¾ DblFig8, 1c+4c cross in to begin, 2c+3c no cast (to 2x,1,4x,3), 1c facing 4c

9–::

  1c+4c R&L starting up/dn, final LH turn ¾ brings 1c+4c onto midline, men in middle

17–::

  1c+4c Men''s Targe: M turn RH ¾ _while{2}_ W chase cclw ¼ | turn P LH ; repeat (to 2x,4,1x,3)

25–::

  2c+3c set | turn RH ½ | all ½ Circle8 L (3,1,4x,2x)', 2);
INSERT INTO 'dancecrib' VALUES (14271, '2021-09-06 19:39:47.809809+00', '2021-11-15 23:48:20.41304+00', 20457, 2, 963, 'ace', '1-4::  All adv for two, retire for two  

5-8::  All dosido with partner  

9-12::  All set, pet into middle  

13-16::  1s+2s, 3s+4s half R4  

17-20::  All set, pet to side 2,1,4,3  

21-24::  2s+3s RH turn WHILE 1s+4s set&link 2,4,1,3

25-32::  Circle 8 hands round and back', 5);
INSERT INTO 'dancecrib' VALUES (9786, '2017-04-08 13:26:53.066305+00', '2021-01-18 18:25:48.05678+00', 11629, 1, 202, 'ace', '1--::

 1c+2c RHA ; LHA

9--::

 1W followed by 2W cross behind M side, 2W goes round 1M and 1W round 2M to dance across to W side having change places | 2W+1W set

17--::

 1M followed by 2M repeat symetric pattern [9-16]

25--::

 2c+1c R&L, ending with polite turn before starting again.', 2);
INSERT INTO 'dancecrib' VALUES (2931, '2012-01-22 19:30:03.414156+00', '2016-07-15 22:44:07.729394+00', 9104, 1, NULL, 'ace', '1–::

  All circle6 and back

9–::

  Each M with the two W on his right (own and opposite line) RHA ; the M pass Rsh into LHA with the W on the L.

17–::

  Each M Fig8 round opposite two W (starting Lsh to opposite W on his R) to finish between them

25–::

  All W turn W opposite RH 1½ to rejoin their M partner ; all trios set NHJ | all set swiveling R to face new trio', 3);
INSERT INTO 'dancecrib' VALUES (1654, '2012-01-22 19:28:53.243866+00', '2017-07-07 14:20:51.644662+00', 132, 1, NULL, 'ace', '1–::

  1c+2W diagonal Reel3, 1c starts Rsh, 2W dancing up (1,2)

9–::

  1c+2M diagonal Reel3, 1c starts Lsh, 2M dancing up (1,2)

17–::

  1c dance NHJ down between 2c, cast up ; turn BH (1,2)

25–::

  2c dance NHJ up between 1c, cast off, turn BH

33–::

  1W+2M & 1M+2W set to and turn RH (1c advancing, W in front of P ; take short way back on [36] ; 1c turn LH and cast off (2c up)

41–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (2946, '2012-01-22 19:30:04.04666+00', '2020-05-20 20:09:35.430536+00', 3996, 1, NULL, 'ace', '1–::

  Reel4 across, 1W+2M pass Lsh to start, at the end 1M+2W curve clw to bring 1M, 1W, 2M, 2W onto midline, all facing P.

9–::

  1c+2c ½ Reel4 ; turn P RH 1¼ to (2,1)

17–::

  2c+1c set | turn BH ; into Circle4 L

25–::

  2c+1c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (9319, '2016-09-22 22:39:19.469568+00', '2016-09-25 23:28:50.247177+00', 17388, 1, NULL, 'ace', '*(start 1,2,3x,4x)*



1--::

  1c+2c & 3c+4c Espagnole, at end 1c+4c turn 1½ times to finish centres facing corners on diagonal (2,1x,4,3x)

9--::

  1c+4c set H&G ½ round, centres again facing corners (2,4x,1,3x)

17--::

  4c+1c, starting out the ends, turn their cnr EH to (2,4x,1,3x) ; 4c+1c set and cross RH (2,4,1x,3x)

25--::

  All S&Link4 twice [same figure as S&Link for 3 couples, except that TWO LH dancers of each line dance to the RH end while the others cast] (3,1,4x,2x)

33--::

  All chase clw ½ way round ; turn P BH (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (2936, '2012-01-22 19:30:03.643269+00', '2014-04-30 23:24:04.188092+00', 4195, 1, NULL, 'ace', '{{explanation}}
or The Marquis of Huntly''s Highlanders

1–::
  1c Rsh Reels3{6} on sidelines with 2c+3c, 1c+2c continue to finish (2,1,3)
9–::
  1c lead down the middle and up to 2pl
17–::
  2c+1c circle4 and back', 3);
INSERT INTO 'dancecrib' VALUES (2450, '2012-01-22 19:29:39.510344+00', '2020-12-06 18:49:56.620446+00', 3033, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; 1c+3c RHA  (2,1x,3,4)

9–::

  Opposing tandem Reels3 across: 3W (+1M staying close behind) with 4c (Rsh to 4M) and 1W (+3M close behind) with 2c (Rsh to 2W), (to 2,3,1x,4)

17–::

  1c cross RH | cast off (4c up) ; 1c turn RH (2,3,4,1)

25-40::

  Four-couple diagonal R&L, as follows:

25-28::

  From 1W and 4M places cast down / up to other end of sideline {4}. _Meanwhile_ top 3 on M side change diagonally RH with bottom 3 on W side | those in 2pl and 3pl change LH on sidelines _while{2}_ those reaching 1M and 4W place cross to other side, ready to cast

29-40::

  repeat figure from new positions three times. (2,3,4,1)



{{explanation}}

From 1M position the moves are: RH to 2W pl | LH to 3W pl ; RH to 2M pl | LH to 3M pl ; RH to 4W pl | cross to 4M pl ; cast {4} to 1M pl)  All dancers follow the same cyclical pattern, or its inversion.', 3);
INSERT INTO 'dancecrib' VALUES (2947, '2012-01-22 19:30:04.086964+00', '2016-03-05 17:13:19.716319+00', 4998, 1, NULL, 'ace', '1–::

  Half G-Chain ; all set to P | turn ¾ RH

9–::

  All W ½LHA _while{2}_ M dance clw one place | all turn new P RH ½ ; repeat (M ½LHA, W ¼ clw)

17–::

  Repeat [9-16] to original places

25–::

  1c+3c dance in, change places RH, split and cast behind side C, pass RH to own place, forming a longwise set | All set

33–::

  All A&R ; 1c+2W+4M & +3c+2M+4W, circle4 L and open into lines of 4 across with 1c & 3c in the middle

41–::

  All A&R ; circle8 half way, finishing in square set opposite original places

49-72::

  Repeat [25-48] with 2c+4c as dancing couples

73-96::

  Repeat [1-24]', 2);
INSERT INTO 'dancecrib' VALUES (3735, '2013-05-17 20:54:26.938145+00', '2014-04-30 23:24:01.704286+00', 4433, 1, NULL, 'ace', '1–::
  1c+2c+3c set | cross RH ; set | cross RH (1,2,3)
9–::
  1c lead down the middle (2c up) ; and up, on [16] 1W finish between 2c facing down _while_ 1M retires to between 3c
17–::
  In lines across all set | all set, 1c twirling L into 2pl ; All set twice (2,1,3)
25–::
  All Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (2935, '2012-01-22 19:30:03.60439+00', '2017-11-14 10:44:10.416675+00', 4959, 1, NULL, 'ace', '1–::

  1c+2c set and cross RH ; all clap 3 times, 1c+2c cross back RH

9–::

  1c+2c ½ RHA, set ; all clap 3 times, 1c+2c ½ LHA back to places

17–::

  1c lead down the middle and up

25–::

  1c+2c ½ R&L, clap 3 times ; 1c+2c cross back RH to own sides.', 3);
INSERT INTO 'dancecrib' VALUES (3224, '2012-01-22 19:30:16.391889+00', '2017-02-14 23:37:45.482601+00', 8175, 1, NULL, 'ace', '1–::

  1c+2c turn ¾ BH to finish on midline | ½Reel4 | turn BH to sidelines (2,1,3)

9–::

  Reels3 across, Lsh to 1cnr, 1c finish facing 1cnr

17–::

  SetH&G , finish in 2pl

25–::

  2c+1c+3c circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2938, '2012-01-22 19:30:03.714125+00', '2016-03-10 11:24:18.95221+00', 11372, 1, NULL, 'ace', '1–::

  1c ½ Fig8 through 2c ; 1M+2W & 1W+2M turn EH, 2c finish facing out (1x,2)

9--::

  2c ½ Fig8 round 1c ; 1M+2M & 1W+2W turn EH (1x,2x)

17–::

  All set diagonally (no hands) | ½ RHA ; 2M+1W set | turn LH ¾ to face P on 2diag

25–::

  2c+1c diag Reel4, dancing / curving out to (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (2945, '2012-01-22 19:30:04.00222+00', '2015-05-26 01:14:51.594918+00', 4995, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; set, cast (1M down, 1W up) to between end couples

9–::

  Set twice in lines across, on [11-12] 1c petronella L to own sides ; 2c+1c+3c set twice, at end 1c advance to 1cnr

17–::

  Turn CPCP

25–::

  2c+1c+3c advance and join RH with P | M turn W under their R arm and retire _while_{2} W dances out to place (= Allemande R) ; repeat with LH.', 3);
INSERT INTO 'dancecrib' VALUES (13794, '2021-03-07 17:10:07.053225+00', '2021-03-07 17:31:20.467557+00', 20252, 1, 202, 'ace', '1--::
  Mirror Reels3 on opposite sides, 1c crossing down (1x,2,3)
9--::
  1c+2c turn EH ½ into DTr position | 6 bars of DTr. 1c face 3cnrs
17--::
  ½ Reel4 on 1diag, pass P RSh ; ½ Reel4 on 2diag, pass P LSh to 2plx (3x,1x,2x)
25--::
  All chase cclw ½ (to 2,1,3) ; 1c+3c turn on sides EH (1c out and down) 1½ (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (13795, '2021-03-08 00:30:04.322044+00', '2021-03-08 00:37:23.421492+00', 19480, 1, 202, 'ace', '1--::

  1W (1M following) & 4M (4W following) cast clw 1 place | cross to opposite sides (2c & 3c step out) ; ½ Reels4 on sides (3,4x,1x,2)

9--::

  3c & 2c repeat same pattern (1x,2x,3x,4x)

17--::

  All cross RH | top 2 dancers on Mside & bottom 2 dancers on Wside change places LH _while{2}_ others cross LH diagonally ; repeat same pattern [17-20] (4,3,2,1)

25--::

  Bottom 3 couples set | cross RH ; chase clw ½ (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (14042, '2021-05-26 23:40:24.294268+00', '2021-05-30 09:22:47.404575+00', 20347, 1, 202, 'ace', '1--::

  All turn P RH ½, face P and cast R to exchanged places ; all chase clw ½ (3,2,1)

9--::

  All set | 3c & 2c cross RH _while_ 1c turn RH ½ and face up ; 1c NHJ dance up to top and cast off (2c down) (3x,1x,2x)

17--::

  Reels3 across, 1c RSh to 4cnrs[pos] (3x,1x,2x)

25--::

  3C S&Link twice (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14043, '2021-05-27 16:24:17.872858+00', '2021-05-30 09:22:23.045506+00', 20346, 1, 202, 'ace', '1--::

  1c dance down, cast up round 3c and meet ; dance up between 2c, cast off and face 1cnrs (2c up on [7-8])

9--::

  ½ Reel4 on 1diag ; 1c turn P LH 1¼ and face 2cnrs[pos] _while{4}_ all cnrs chase clw ½

17--::

  ½ Reel4 on 2 diag ; 1c turn P LH to 2plx _while{4}_ all cnrs chase clw ½ (3x,1x,2x)

25--::

  3C S&Link twice (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (9168, '2016-06-14 11:44:30.747624+00', '2016-06-14 12:00:41.215794+00', 9758, 1, NULL, 'ace', '1--::

  1c (to start touch hands) Fig8 on own side round 2c+3c, at end 1c turn RH ½ to promhold facing down, as 2c+3c step in to promhold facing up

9--::

  Lsh Reel3 in promhold, at end 1c turn LH to own side and all flow into

17--::

  Circle6 and back to (1,2,3)

25--::

  “Link and Change”: All set | 1M+3W cast to other end of own sideline while 2M+3M dance up and 1W+2W dance down ; All new couples set | turn P BH to new places.

', 3);
INSERT INTO 'dancecrib' VALUES (9169, '2016-06-15 01:41:42.383905+00', '2016-06-15 01:41:42.383905+00', 350, 2, 160, 'ace', '1-8::
  1C set advancing, Turn BH once round (face up NHJ) ; set, cast to 2nd place.
9-12::
  1C Back-to-Back *while* 2C set advancing (1), turning to facing up (2), cast back to top place. 3C, similarly, set advancing (1) turn to face down (2) cast back to 3rd place.
13-16::
  1C turn RH 1_1/2 to face out *while* 2C 3C set advancing to meet on sidelines (1) and face out (2), cast back to places & face in.
17-24::
  Reels of 3 on sides - 1C Rsh to 1st corner to begin.
25-28:: 1C cast R, cross at top or bottom and cast to 2nd place *while* 2C 3C Back-to-Back.
29-32::
  All turn RH.', 0);
INSERT INTO 'dancecrib' VALUES (10656, '2018-04-19 08:21:17.942886+00', '2018-04-19 10:25:56.249858+00', 13912, 1, 202, 'ace', '1--::
  1M+2c & 1W+3 Mirror Reels3, 1M(1W) start Rsh(Lsh) to 2M(3W)
9--::
  1c La Baratte | continue turning LH to original places (1,2,3)
17--::
  All S&Link ; all W RHA to places facing out _while{4}_ all M set | cast R to places facing in
25--::
  8 bars of Schiehallion Reels (3,1,2)', 4);
INSERT INTO 'dancecrib' VALUES (2944, '2012-01-22 19:30:03.954279+00', '2018-11-20 08:05:40.882707+00', 4990, 1, NULL, 'ace', '1–::

  1c+2c Bourrel [1M+2W set adv | turn BH and twirl into BtoB, 1M facing down, 2W up _while{4}_ 1W+2M dance cclw to face P ; set to P | turn BH ¾] (2,1,3)

9–::

  1c+3c Bourrel (2,3,1)

17–::

  All dance Allemande (1,3,2)

25–::

  1c+2c ½ R&L _while{4}_ 3c set & cross RH ; All set | cross RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2941, '2012-01-22 19:30:03.836497+00', '2019-03-05 11:34:07.016341+00', 9772, 1, NULL, 'ace', '1–::

  1c cross down (2c up) | cast down (3c up) ; ½ Fig8 up through 3c (2,3,1)

9–::

  Crossover mirror Reels3, each couple crossing down from the top (2x,3x,1x)

17-28::

  2c+3c+1c R&L for 3 couples (2x,3x,1x)

29-32::

  All set and cross RH (2,3,1)

', 4);
INSERT INTO 'dancecrib' VALUES (2953, '2012-01-22 19:30:04.33464+00', '2017-07-07 14:03:20.037871+00', 5033, 1, NULL, 'ace', '1–::

  1c cast off one and cross RH, cast off one and cross LH and cast off to 4pl

9–::

  1c cast up one and cross LH, cast up one and cross RH and cast up to 1pl

17–::

  1c+2c & 3c+4c cross, the W passing NHJ under arches made by the M ; they all cross back, the W again pass under the arches

25–::

  1c+2c+3c+4c Poussette, 1c moving to the bottom, 2c+3c+4c one place up.', 3);
INSERT INTO 'dancecrib' VALUES (2951, '2012-01-22 19:30:04.248288+00', '2014-10-07 14:03:42.974614+00', 10419, 1, NULL, 'ace', '1–::

  1c lead down, up and cross | cast off (2c up) (2,1x,3)

9–::

  2c+1c L-Chain, 1M face out for

17–::

  1M, 1W following, cast off round 3W, up the middle, cast off round 2W, to (2,1,3)

25–::

  2c+1c Circle4 and back', 5);
INSERT INTO 'dancecrib' VALUES (2574, '2012-01-22 19:29:48.222611+00', '2017-07-07 14:22:00.291274+00', 3506, 1, NULL, 'ace', '1–::

  1c lead down the middle and up

9–::

  1W+2M set adv. | turn RH to places (1,2) ; 1M+2W set adv. | turn RH to W side as 1W crosses on [16] to face 2M (all 2pos, 1c BtoB between 2c)

17–::

  Reel4 across, at end 1c meet as 2c curves down into

25–::

  1c+2c Promenade

33–::

  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (2693, '2012-01-22 19:29:53.35738+00', '2016-06-15 10:16:11.968475+00', 3915, 1, NULL, 'ace', '1–::

  All A&R ; all turn RH

9–::

  Repeat

17–::

  4c leading, all dance down the middle ; and up, finish 1c facing 2c NHJ and 3c+4c in places

25–::

  1c+2c A&R ; change places in {4}, 2c making an arch (2,1,3,4)



*Repeat from (2,1,3,4), all couples dancing, 1c ending in 4pl (2,3,4,1)*

', 3);
INSERT INTO 'dancecrib' VALUES (3748, '2013-05-23 12:57:22.661128+00', '2014-04-30 23:24:01.894426+00', 14437, 1, NULL, 'ace', '1–::
  All turn P RH ½ and join LH below RH | slip down ; slip back up | in PdB change places with P and finish in Allemande hold facing up
9–::
  3c Allemande, on [15-16] 3c+1c set to finish NHJ facing each other
17–::
  3c+1c change places (3c makes arch) | change sides W under P''s arm ; change places (1c makes arch) | change sides (W under P''s arm) to finish facing out (3,2,1)
25–::
  ½ Reels3 on the sides (2c in and down) ; 1c turn 2c EH 1½ (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2962, '2012-01-22 19:30:04.704033+00', '2019-01-27 20:16:06.354612+00', 8729, 1, NULL, 'ace', '1–::

  1c (start inwards) Fig8 on own sides round 2c & 3c

9–::

  1c dance BtoB ; cast off (2c up) | turn ¾ RH to face out on M side NHJ (M below W)

17–::

  1c dance out, split (W up, M down) and cast round cnr and meet ; dance out on W side, cast to 2pl facing up NHJ

25–::

  2c+1c RHA, LHA, (2,1,3)

33–::

  1c turn RH | lead up between 2c ; cast off to 3pl (3c up on 37-38)

41–::

  3c+1c circle4 and back (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2955, '2012-01-22 19:30:04.419997+00', '2021-01-09 11:15:43.528914+00', 12745, 1, NULL, 'ace', '1–::

  1c cross down RH to between 2c | set to P ; dance up and cast to 2plx (2c up) (2,1x)

9–::

  2c+1c R&L, at end 1M face out.

17–::

  1M followed by 1W cast up, cross to own side (2c down) ; 1c turn LH (1,2)

25–::

  1c+2c Girandole (1c+2c set | 1W+2M turn RH ¾ _while_{2} 1M+2W cast L ; 1c+2c ¾RHA | 2c+1c turn RH ½) (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2960, '2012-01-22 19:30:04.625025+00', '2014-04-30 23:24:04.615615+00', 5065, 1, NULL, 'ace', '1–::
  1c turn RH | cast off (2c up) ; lead between 3c and cross | cast up (to 2,1x,3)
9–::
  All set | Rsh Reels3{6} across (W up, M down) (2,1x,3)
17–::
  Reels3{6} on the sides, Rsh to 2cnr | 1c cross RH and face up NHJ
25–::
  2c+1c circle4 L ; 1c turn towards each other into 1c+3c circle4 R.', 3);
INSERT INTO 'dancecrib' VALUES (2810, '2012-01-22 19:29:58.348104+00', '2021-05-07 21:20:46.340844+00', 4484, 1, NULL, 'ace', '1–::

  1c+2c set | turn BH ; circle4 L

9–::

  1c+2c Knot, 1c finish facing 1cnrs

17–::

  Turn CPCP, with final wide ¾ LH turn into

25–::

  Teapots R and L (1M+3c & 1W+2c RHA, 1c pass Rsh, cnrs not to sidelines ; 1M+2c & 1W+3c LHA) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2970, '2012-01-22 19:30:05.058184+00', '2021-04-28 09:27:20.591868+00', 5099, 1, NULL, 'ace', '1–::

  1W+2W A&R ; dance between P and cast round them back to places

9–::

  1M+2M repeat

17–::

  1c lead down and cross over between 2c, cast off on opposite sides round 3c ; cross over LH, and cast up to 2pl on own sides (2c up on [19-20])

25–::

  2c+1c+3c A&R ; 1c turn 1cnrs LH to (2,1x,3)

33–::

  2c+1c+3c A&R ; 1c turn 4cnrs RH to (2,1,3)

41–::

  2c+1c+3c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (8656, '2015-02-13 16:48:29.0202+00', '2021-07-30 08:12:39.118844+00', 11891, 2, 1, 'ace', '1–4::

  1c+2c set & link _while_ 3c set and cross RH (all join NH when setting)

5–8::

  2c set and cross RH _while_ 1c+3c set & link (all join NH when setting)

9–::

  1c cross RH | cast up ; dance up between 2c | cast off (3c down) [to 2x1x3x]

17–28::

  Rights&Lefts for 3 couples

29–32::

  All set and cross RH', 3);
INSERT INTO 'dancecrib' VALUES (8907, '2015-09-18 19:41:25.04481+00', '2015-09-18 19:41:25.04481+00', 10309, 1, NULL, 'ace', '1--::  1c cross | cast (2c up) ; 1c ½ Fig8 up to face 1cnr

9--::  “Corners pass and twizzle”:  1c dance to 1cnr, loop R to the middle, turn P RH ½ and pivot R to face 2cnr _while{4}_ 1cnr pass 1c Rsh to middle, turn RH ½ and cast R to exchanged corners ; 1c dance to 2cnr and cast R to 2plx _while{4}_ 2cnr pass 1c Rsh to middle, turn RH ½ and cast R to exchanged corners  (3x,1x,2x)

17--::  ½ Reels3 on the sides, 1c giving Lsh to 1cnr (pos) ; ½ Reels3 across, 1c Rsh to 4cnr (pos) (2,1,3)

25--::  Circle6 and back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2957, '2012-01-22 19:30:04.502125+00', '2015-05-27 19:54:02.424122+00', 5040, 1, NULL, 'ace', '1–::

  1c+3c cross RH into Mirror Reels3 on opposite sides (2c in and up)

9–::

  1c+3c cross back RH and repeat the reels

17–::

  1c cast off, meet below 3c ; lead to top and cast off to 2pl (2c up)

25–::

  2c+1c+3c set, cross RH ; repeat.', 3);
INSERT INTO 'dancecrib' VALUES (9328, '2016-09-26 10:45:39.742807+00', '2016-09-26 10:45:39.742807+00', 15964, 1, NULL, 'ace', '1--::

  1c+2c set advancing diagonally | retire ; cast clw ½ round (2x,1x,3)

9--::

  1c+3c repeat (2x,3x,1)

17--::

  1c dance to top, cast to 2pl (3c down) ; All set | 1c turn RH ¾ 

25--::

  2c+1W & 1M+3c LHA ; All set | All cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2958, '2012-01-22 19:30:04.545299+00', '2018-08-17 12:27:54.711312+00', 14355, 1, NULL, 'ace', '1–::

  1c+3c fig8 down, finish on own side in line between 2c/4c, all facing down

9–::

  In lines across dance down, pull back Rsh and dance up (2c+4c to places)

17–::

  1c dance to 1pl and cast to 3pl - _while_{4} - 3c dance to 1pl ; 3c+2c & 1c+4c RHA, finish in centre for

25–::

  3c+2c & 1c+4c Poussette (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (11749, '2019-03-30 03:50:15.21044+00', '2019-04-06 10:03:51.901548+00', 19207, 1, NULL, 'ace', '1--::

  1c lead down (2c up) ; 1c cross, W above M and under joined arms & face up | dance up to DTr position facing opp. side

9--::

  Set as DTr | Set R moving ¼ clw and join hands {1}, Set L {1} & keep LHJ ; 1c Turn 1cnr LH and P RH to face up on opp. side RHJ

17--::

  1c lead up, cross and cast off ; 2c+1W & 1M+3c RHA 

25--::

  Circle6 and back (2,1,3)







', 4);
INSERT INTO 'dancecrib' VALUES (1875, '2012-01-22 19:29:07.506885+00', '2021-01-18 18:48:21.696762+00', 11887, 1, NULL, 'ace', '1–::

  1c set | cast off two (2c+3c up) ; turn LH 1½ and face out (2,3,1x,4,5)

9–::

  2c+1c+5c ½ Reel3, 1c start Lsh ; 3c+1c+4c Rsh ½ Reel3, but 1c cross to own side (5,4,1,3,2)

17–::

  4c+1c+3c S&Link twice, at the end 1c face clw (5,3x,1x,4x,2)

25–::

  5c+1c+2c chase ½ clw ; all set | 1c cast to fifth place, _while_{2} the others cross (4c+5c cross up) (to 2,3,4,5,1)', 2);
INSERT INTO 'dancecrib' VALUES (8908, '2015-09-18 20:07:31.614884+00', '2015-09-18 20:07:31.614884+00', 13831, 1, NULL, 'ace', '1--::  All set | cross RH ; set | cross back RH

9--::  1c Fig8 round 2c

17--::  1c lead down and up, finish (2c step in) for

25--::  Allemande

', 3);
INSERT INTO 'dancecrib' VALUES (3826, '2013-07-13 15:56:16.069695+00', '2014-04-30 23:24:04.724004+00', 14659, 1, NULL, 'ace', '1–::
  1c+2c Turn RH ; RHA
9–::
  2c (leading)+1c lead down (1c split) ; 2c (leading) +1c lead up to (2,1,3)
17–::
  1c in allemande hold set to 2W, 3W, 3M, 2W and end facing up
25–::
  1c cross up LH and cast off ; cross LH between 3c and cast up to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3825, '2013-07-13 15:56:16.029381+00', '2022-04-10 15:59:19.383282+00', 5079, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1c turn RH | cast (2c up) ; ½ Fig8 R (2,1x,3)

17–::

  Diag. R&L (3x,1x,2x)

25–::

  All set | turn RH ; chase ½ clw (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1855, '2012-01-22 19:29:06.259161+00', '2017-07-07 14:22:48.398023+00', 848, 1, NULL, 'ace', '{{explanation}}

Part A



1–::

  Circle8 and back

9–::

  ½ G-Chain, 2 bars/H, (to 3,4,1,2)

17–::

  All RHA, W inside, NHJ with P (3,4,1,2)

25–::

  ½ G-Chain (to 1,2,3,4)

33–::

  All LHA, M inside, NHJ with P (1,2,3,4)



{{explanation}}

Part B



1–::

  1W sets alone inside, others Circle7 and back

9–::

  1W sets to P | turn R arm (elbow grip, M raise the free arm) ; 1W+opposite M (3M) set, turn L arm and face M to the L (4M)

17–::

  1W+M (=4M) set, turn L arm ; 1W+opposite M (2M) set, turn R arm and face R (Partner)

25–::

  1W+P+M opposite (1M+3M) Reel3, start Rsh to P, at end face L (M raise both arms)

33–::

  1W+M on the sides (4M+2M) Reel3, start Lsh to 4M



{{explanation}}

Dance A, then B with inside in turn 1W, 2W, 3W, 4W, then 1M, 2M, 3M, 4M (who dance with the W), finish with A  

Memorize: centre dancer Turns R,L,L,R, then Reels Rsh to P, Lsh across', 3);
INSERT INTO 'dancecrib' VALUES (3617, '2012-07-21 11:45:59.717677+00', '2014-04-30 23:24:04.818578+00', 13071, 1, NULL, 'ace', '{{explanation}}
3c+4c start on opposite side (1,2,3x,4x)

1–::
  1c+4c set | 1M+4M cast in (2M+3M step to end) ; 1c+2W & 3W+4c RHA
9–::
  1M+4M turn LH | cast L behind 2W/3W and take promhold with P on the R ; ½ Rsh Reels3 across (Rsh to 2M/3M) the corners finishing with loops
17–::
  1c (on W side) +4c (on M side) in promhold ½ Reels3 (Rsh to 3W/2W) ; 2c/3c finish in 4plx/1pl ; 1c+4c LHA in the centre, finish in the centre (3,4x,1,2x)
25–::
  ½ intersecting diagonal Reels4 (2c+3c dancing ½ LHA in the midle) ; 1c+4c Circle4 L (2,4x,1,3x)

{{explanation}}
Danced 4 times, successively led by 1M+4M, 2M+3M, 1W+4W, 3W+2W.', 3);
INSERT INTO 'dancecrib' VALUES (15445, '2023-02-16 13:37:53.681582+00', '2023-02-16 13:45:58.935425+00', 17809, 1, 202, 'ace', '1--::

  1c+2c DblFig8, 1c crossing down. 2c face out (1,2,3)

9--::

  *Modified Inveran Reels* : 1c & 2c cross down from 1pl and cross up from 3plx but 3c cross up from 3pl and cross down from 1plx (1,2,3)

17--::

  1c cross RH | cast off (2c up) ; ½ Fig8 L round 4cnrs (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2973, '2012-01-22 19:30:05.174596+00', '2014-04-30 23:24:04.880848+00', 5111, 1, NULL, 'ace', '1–::
  All set to P | 1c+4c turn RH ½ into the middle facing down/up _while_{2} 2c+3c cross RH ; 1c+4c advance NHJ, meet dancer opposite and dance NHJ out the side and cast to own end (1x,2x,3x,4x)
9–::
  All set toP | 1c+4c cross RH _while_{2} 2c+3c turn RH ½ into the middle facing own end ; 2c+3c dance out the end and cast to own places (1,2,3,4)
17–::
  1c+2c & 3c+4c RHA, LHA
25–::
  1c+4c cross diagonally to middle of set, using EH (1c RH, 4c LH) | 1c+4c circle4 L | continue circle ½ opening for 1W to lead 4W down the W side _while_{2} 4M leads 1M up the M side (2c+3c up) (to 2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (10411, '2018-02-01 11:13:54.542171+00', '2018-02-01 11:24:42.361299+00', 18236, 1, NULL, 'ace', '1--::

  1c cross down into Reels3 on opposite side, at end 2c face out (1x,2,3)

9--::

  1c turn 2c EH 1½ and 1c face out ; 1c turn 3c EH 1½ and 3c face out and down (2,3,1x)

17--::

  Reels3 on the sides, 1c crossing up to start, and finish in 3pl facing up NHJ (2,3,1)

25--::

  1c set to 3c | 1c set adv to 2c as 3c dance to 3pl ; 1c dance to top and cast off (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8255, '2014-04-24 11:29:21.411748+00', '2014-04-30 23:24:07.09706+00', 5499, 1, NULL, 'ace', '1–::
  1c+3c cross (3s make arch) ; repeat to place (1s make arch)
9–::
  2c+4c repeat (4s make arch, then 2s) (1,2,3,4)
17–::
  All W Fig8 round P (Lsh) and Cnr
25–::
  All M Fig8 round P (Rsh) and Cnr (1,2,3,4)
33–::
  All A{1}&R{1} | All prom cclw ¾ (4,1,2,3)', 3);
INSERT INTO 'dancecrib' VALUES (11770, '2019-04-06 22:01:10.639585+00', '2019-04-06 22:01:10.639585+00', 19052, 2, NULL, 'ace', '1-8::

  1s+2s 1/2 R&Ls, 2s+1s dance LH across, 1s finishing facing down in 2nd place

9-16::

  2s+1s+3s dance RSh reels of 3 on sides, 1s finishing facing down to 3s

17-24::

  1s+3s dance RH across, 2s+1s dance 1/2 double fig. of 8, 1s dancing up outside as 2s cross down

25-32::

  1s dance down around 3s, dance up through 3s & 2s, cast off to 2nd place', 5);
INSERT INTO 'dancecrib' VALUES (2398, '2012-01-22 19:29:35.642297+00', '2017-07-07 14:25:46.98459+00', 2747, 1, NULL, 'ace', '1–::

  1M+2W change places RH | 1W+2M repeat ; 1M+3M repeat | 1W+3W repeat (1c no polite turn) (2x,3x,1)

9–::

  3c+1c ½ R&L (1W no polite turn) ; 2c+1c ½ R&L (to 1,2,3)

17–::

  1c cross RH | cast off (2c up) ; turn 1¾ LH to face 1cnrs

25–::

  1c set to and turn 1cnrs to face P on 1diag. ; 1c set to P | Turn BH to face 2cnrs

33–::

  1c repeat with 2cnrs and 2diag., finish facing 2cnrs

41–::

  Reels3{6} on the sides (Rsh to 2cnrs) | 1c cross LH (giving a better transition to 2nd turn)', 3);
INSERT INTO 'dancecrib' VALUES (2979, '2012-01-22 19:30:05.428317+00', '2016-02-20 01:23:51.798854+00', 10327, 1, NULL, 'ace', '1–::

  All C A&R ; dance BtoB

9–::

  All C turn RH ; LH

17–::

  1c+2c & 5c+6c Circle4 and back _while{8}_ 3c+4c RHA ; LHA (OXO figure)

25–::

  1c slip to Bottom (other Cs up) ; all C turn RH (or birl) (2,3,4,5,6,1)



*Variant: on [25-28]:  1c+2c slip down* (3,4,5,6,1,2)



', 3);
INSERT INTO 'dancecrib' VALUES (8100, '2013-10-29 22:47:46.082638+00', '2019-01-12 20:50:22.038446+00', 12368, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; turn LH to opposite sideline | All set (2,1x,3)

9–::

  All turn P Rh ½ face and cast away ; all chase ½ clw (3,1x,2), 1c moving towards 4cnr

17–::

  ½ Reel4 with 4cnrs, 1c pass Rsh ; ½ Reel4 with 1cnrs, at end 1c approaches P in centre

25–::

  1c Turn RH ¾ to opposite sideline | All set ; All turn P RH 1½ (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14822, '2022-05-09 17:38:57.11832+00', '2022-05-09 17:39:07.945752+00', 20817, 1, 1645, 'ace', '1--::

  1c+2c set | petronella in tandem ; set facing up/down | &frac12; RHA (1c/2c end on M/W sides)

9--::

  1c+2c &frac12; L-Chain with 1M+2W crossing RH to start (2,1,3,4) ; all A&R

17--::

  *Muirland Willie (bars 1-4):* 1c cross down RH to 4plx | cast up

  _while{4}_ 3c set | cross down RH

  _while{4}_ 4c cast up to 2pl | cross RH (2,4x,1x,3x) ;

  4c+1c+3c chase &frac12; way clw (2,3,1,4)

25--::

  1c+4c *Rose progression:* 1M+4W set | &frac12; turn RH ; cast away | cross over

  _while{8}_ 1W+4M cross RH | cast up/down ; &frac12; turn RH ; cast away (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (12771, '2020-04-18 22:27:08.048822+00', '2020-04-18 22:31:33.487785+00', 19886, 1, 202, 'ace', '1--::

  1c dance RSh round P 1½ to 1plx ; cast off (2c up) | dance LSh round P ¾. 1W (1M behind) faces up

9--::

  Reel3 in tandem on 1diag, LSh to 2M. On [15-16] 1c dance RSh round P ¾. 1W (1M behind) faces down

17--::

  Reel3 in tandem on 2diag, RSh to 3M. On [23-24] 1c dance LSh round P into facing lines3 across, 1W between 2c

25--::

  All turn opposite person BH ½, face that person and cast away to exchanged places ; 1c dance LSh round P 1¼ to 2pl (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (15090, '2022-09-08 08:49:06.441659+00', '2022-09-08 08:52:39.419437+00', 21081, 1, 202, 'ace', '1--::
  1c turn RH | 1c, 1M leading, cast off to 2plx (2c up) ; 1c+3c ½ LHA (2,3x,1)
9--::
  1c turn LH | 1c, 1W leading, cast up to 2plx (3c down) ; 2c+1c ½ RHA (1,2x,3x)
17--::
  1c turn RH | ½ Mirror Reels3 {6} on sides, 1c out and down. On [23-24] 1c+2c continue the reel to exchanged places (3x,1,2x)
25--::
  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12764, '2020-04-15 18:22:27.618067+00', '2021-05-27 07:50:08.924968+00', 19925, 1, 202, 'ace', '1--::
  1c+2c A&R ; 1c & 2c turn P RH ½ | ½ RHA (2,1,3)
9--::
  1c A&R ; turn P LH 1¼ to face 1cnrs
17--::
  ½ Reel4 on 1 diag, 1c pull RSh back to face 4cnrs ; ½ Reel4 on 2diag, 1c pull RSh back to face 3cnrs
25--::
  ½ Reel4 on 1diag, 1c pull RSh back to face 2cnrs ; ½ Reel4 on 2diag. On [32] 1M pulling RSh back meet P in centre and 1c face down into allemande hold
33--::
  1c dance down {3}, swivel R to face up into allemande hold {1} ; dance up | cross and cast RH to 2pl (2,1,3)

*Deviser''s note*:  
In bars 17-32, 1st couple should take every opportunity to flirt during the ‘snub’ turns, and maintain eye contact on bars 38-40.', 4);
INSERT INTO 'dancecrib' VALUES (2978, '2012-01-22 19:30:05.390299+00', '2019-09-26 21:42:36.914764+00', 8069, 1, NULL, 'ace', '1–::

  Circle4 and back

9–::

  RHA ; LHA

17–::

  1c lead down (2c up) ; and up to 2pl (2,1)

25–::

  2c+1c turn P RH ; Turn P LH (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (2982, '2012-01-22 19:30:05.546399+00', '2014-07-14 21:16:24.064572+00', 13727, 1, NULL, 'ace', '{{explanation}}

2c start on opposite side (1,2x,3)



1–::

  1c cross down RH | cast down behind 3c ; cross up RH | cast up behind 2c (1,2x,3)

9–::

  All G-Ch, 1c cross to start, at end 1M+2M face out for

17–::

  1c+2c L-Chain

25–::

  1c+2c ½ R&L ; 1c+3c ½ R&L (2,3x,1)', 3);
INSERT INTO 'dancecrib' VALUES (9331, '2016-09-26 21:54:31.148546+00', '2016-09-26 21:54:31.148546+00', 5900, 1, NULL, 'ace', '1--::

  1W, 1M following, cast round 2W and up the middle into ; 1c+2c RHA

9--::

  1M, 1W following, cast down round 3M and up the middle into ; 1c+3c LHA

17-20::

  1c turn LH 1¼ to 2pl facing out (2,1,3) 

21-28::

  Reels3 on the sides, Lsh to 4cnr, 1c meet on midline 

29-32::

  1c turn RH 1¼ to 2plx facing out

33-40::

  Reels3 on the sides, Rsh to 1cnr , at end 1c crossing to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9332, '2016-09-26 23:40:17.907141+00', '2016-09-26 23:40:17.907141+00', 939, 1, NULL, 'ace', '1--::

  1c+2c+3c Reels3{6} on own side (2c start out and up) | 1c+2c continue to (2,1,3) 

9--::

  2c+1c+3c Gr-Chain (2,1,3), 

17--::

  2c+1c Poussette 

25--::

  1c “Pass Half Round”: cross Lsh and cast Rsh round 1cnr to meet P in middle ; Pivot R and cast Rsh round 4cnr to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9333, '2016-09-27 13:33:36.544372+00', '2016-09-27 13:33:36.544372+00', 1062, 1, NULL, 'ace', '1--::

  1c set | lead down turning RH ½ ; lead to top and turn inwards to face down as 2c step in and face up (1x,2 in middle)

9--::

  Reel4 with hands: to start the W cast clw as the M turn LH ¾ to place opposite | repeat pattern three times 

17--::

  1c+2c ½ RHA | all turn P RH ½ ; 1c cross up RH and cast off (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9334, '2016-09-27 14:27:21.082426+00', '2016-09-27 14:27:21.082426+00', 14262, 1, NULL, 'ace', '1--::

  1c+5c+6c+3c Parallel Reels4

9--::

  1c+5c & 6c+3c RHA _while{4}_ 2c+4c turn RH ½ and set ; 1c+5c & 6c+3c ½ LHA _while{2}_ 2c+4c cross LH and face cclw | 1c+3c chase clw ½ in centre _while{2}_ the others chase cclw ¼ round (2,6,4,5,3,1)

17--::

  Lsh Parallel Reels4 across

25--::

  DTr: 3c+1c, NHJ with two cnrs, set | set moving ¼ clw ; repeat (outside cpls may join NH) (2,6,4,5,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11788, '2019-04-14 00:01:23.4611+00', '2019-04-14 00:01:23.4611+00', 16608, 1, NULL, 'ace', '1--::

  1c lead down {3} and up {3} | cast (2c up) (2,1,3) 

9--::

  Mirror Reels3 on the sides, 1c in and down (2,i,3)

17--::

  1c (in and down) turn 3c EH ; 1c (in and up) turn 2c EH (2,1,3)

25--::

  All A&R ; turn P RH



', 3);
INSERT INTO 'dancecrib' VALUES (9330, '2016-09-26 18:03:24.755884+00', '2021-04-24 18:50:20.67995+00', 5494, 2, 160, 'ace', '1-8::

  1C dance down (nhj) between 2C , cast back to place ; cross over RH and cast to 2pl on opposite sides.

9-16::

  Chase [3+3+2] - 1L (followed by ptnr) cross up betwn 2C, cast behind 2L (3bars) -

  Cross up btwn 2C and cast behind 2M (3 bars) - cross to own side as 1M cast to 2pl.

17-24::

  2C 1C adv&ret. ; 2C 1C Turn RH (end in middle facing up).

25-32::

  2C 1C promenade.', 0);
INSERT INTO 'dancecrib' VALUES (10412, '2018-02-03 17:06:43.285978+00', '2018-02-04 01:40:44.667113+00', 16681, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c S&Link ; 2c+1c & 4c+3c ½  RHA | 1c+2c & 3c+4c change place RH on sides (2x,1x,4x,3x)

9--::

  Reels4 on the sides

17--::

  1c+3c cross RH and cast up _while{4}_ 2c+4c Turn RH ½ and lead down curving the long way ; 1c dance down the middle (2c+3c+4c up) and curve the long way (2,3,4,1)

25--::

  Circle8 and back

  

', 3);
INSERT INTO 'dancecrib' VALUES (12503, '2020-01-12 21:25:33.581448+00', '2020-01-12 21:25:33.581448+00', 1403, 1, NULL, 'ace', '1--::

  1c cross RH | cast off past 2c ; cross RH | cast up (1,2)

9--::

  1c (2c dance up and follow) lead down ; dance up, 2c leading, into

17--::

  2c+1c Promenade (2,1)

25--::

  RHA ; LHA

', 3);
INSERT INTO 'dancecrib' VALUES (2987, '2012-01-22 19:30:05.73501+00', '2016-04-04 01:22:23.580821+00', 5170, 1, NULL, 'ace', '1–::

  All set to P | 1c+4c cross RH _while{2}_ 2c+3c set diagonally ; 2c+3c Circle4 L ¾ (2c to M side, 3c to W side)

9–::

  2c+3c turn BH to promhold, W on the R, facing out, and promenade clw to face in in 2M/3W place respectively _while{8}_ 1c+4c set on diagonal | set advancing to centre ; Circle4 L half round | and dance out to 4pl/1pl

17–::

  4c+3c & 2c+1c Tournée, 3c & 2c dancing in as couples from sideline, 4c & 1c entering normally (to 3,4,1,2)

25–::

  1c+2c ½ RHA | 4c+2c ½ LHA ; 3c+2c ½ RHA | All cross RH (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (8163, '2014-02-01 23:21:26.335688+00', '2014-04-30 23:24:05.200908+00', 11639, 1, NULL, 'ace', '1–::
  1c+2c & 3c+4c RHA ; LHA _while_{8} 3c cross RH and chase clw ½ way to place (1,2,3,4,5)
9–::
  1M+2M+3M & 3W+4W+5W Reels3, 3c starts giving Lsh
17–::
  3M+4M+5M & 1W+2W+3W Reels3, 3c starts giving Rsh (1,2,3,4,5)
25–::
  2c+3c turn RH | lead up one _while_{4} 1M, with 1W following, cast off 2 and cross (2,3,1x,4,5) ; 4c+5c turn RH | lead up one _while_{4} 1M, with 1W following, cast off 2 and cross (2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (2234, '2012-01-22 19:29:27.124691+00', '2021-01-18 18:54:13.189173+00', 11879, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; 1M+2W set | turn RH ½ and face down RHJ.

9–::

  1M+2W lead down the middle and up to finish on 1st diagonal facing P

17–::

  2c+1c ½ Poussette with a slow final BH turn ; into ½ circle4 | set (2x,1x)

25–::

  2c+1c ½ DblFig8 (1c cross up to start) ; 1c turn BH', 3);
INSERT INTO 'dancecrib' VALUES (12983, '2020-07-25 09:24:38.716514+00', '2020-08-17 13:44:57.122119+00', 19977, 2, 2784, 'ace', '1-::
  1c+2c 1/2 RHA | 1c+3c 1/2 LHA; 1c+4c 1/2 RHA | all cross RH back to own sides (2,3,4,1)
9-::
  2c+3c+4c+1c 1/2 Reel4 on sides, on last bar 3W+4W and 3M+4M change places LH (1,4,3,2); 1c+2c+3c+4c 1/2 G-Chain (1c+4c, 3c+2c face to start) (2x,3x,4x,1x)
17-::
  1M casts, 1W following, crossing between 4c+3c, casts, crossing between 3c+2c, casts, crossing into 1pl {6} (2c+3c+4c down) 1c cross RH (1x,2x,3x,4x)
25-::
  1c+2c and 3c+4c 1/2 R&L (2,1,4,3); 1c+4c+3c 1/2 Reel3 (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2170, '2012-01-22 19:29:23.674724+00', '2017-05-31 16:23:29.719453+00', 11721, 1, NULL, 'ace', '*1-4*::

  1c cross RH | cast (2c up) and swivel to face opp. side in DTr position ;

*5-8*::

  Set as in DTr | 1c with person on R join LH under RH and turn ½ BH in PdB, finish in DTr position facing up/dn .  Other corners set diagonally

9–16::

  Repeat [5-8] facing up/dn ; repeat [5-8] facing across, finish 1c BtoB in middle, 1M facing down

*17-20*::

  “clover leaf” reels:  2c+3c dance in, passing close Rsh, and out to next cnr cclw _while{4}_ 1c dance Rsh round cnr position on R, and back to centre, passing Rsh and facing opp. side

*21-24*::

  Repeat, (1M finishes facing up)

25–32::

  Repeat, finishing (3x,1x,2x) ; all ½circle6 L to (2,1,3)



{{explanation}}

Note: The “crossed hands” turns into the new DTr positions simplify the change of hands.

', 3);
INSERT INTO 'dancecrib' VALUES (9994, '2017-07-07 21:32:11.121894+00', '2017-08-22 22:13:56.908557+00', 15000, 1, 202, 'ace', '1--::

  1c lead down (2c up) ; and up to face 1cnrs

9--::

  1c set to and turn cnrs (2,1x,3)

17--::

  ½ Reels3 on sidelines, 1c Lsh to 1cnrs ; 1c ½ Fig8 R (3,1,2)

25--::

  3c+1c+2c S&Rotate (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10151, '2017-09-26 22:24:53.633947+00', '2017-09-26 22:30:09.78562+00', 17978, 1, 202, 'ace', '1--::

 1c+2c RHA to RHJ in centre ; 1c & 2c turn P RH staying in the middle for

9--::

 1c+2c lead down ; and up staying in centre

17--::

 1c cast off _while_ 2c dance to 1pl | 1c ½ Fig8 R | 2c+1c+3c set (2,1x,3)

25--::

 1c turn 2cnrs RH ; pass P Rsh to 2pl | set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2986, '2012-01-22 19:30:05.695727+00', '2017-07-15 00:34:06.763559+00', 5168, 1, NULL, 'ace', '1–::

  1c cross RH | cast off two (2c+3c up) ; 3c+1c RHA, with the other partner take promhold and face up/dn

9–::

  Both pairs Rsh Reels3 across with 2c & 4c, (to 2,3,1x,4)

17–::

  2c+3c & 1c+4c Double Figs8 (3c & 1c cross to start) (2,3,1x,4)

25–::

  Drop-off G-Chain, ends start across, one bar/hand (1c stop on [6], 4c stop on [7] (to 2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2603, '2012-01-22 19:29:49.478304+00', '2019-07-18 10:30:59.164189+00', 3601, 1, NULL, 'ace', '1–::

  1c+2c R&L (1,2,3)

9–::

  1c (2c following) lead down ; 2c+1c lead up (2,1,3)

17–::

  2c+1c+3c set and cross RH ; repeat, 1c passing Rsh to finish BtoB facing own side

25–::

  DTr', 3);
INSERT INTO 'dancecrib' VALUES (2985, '2012-01-22 19:30:05.663292+00', '2020-12-24 18:09:13.14949+00', 10799, 1, NULL, 'ace', '1–::

  1c dance between 2c and cast up, dance between 3c and cast up into the centra (2c up) (2,1,3)

9–::

  2c+1W & 1M+3c ½ RHA | into 2c+3c LHA _while{4}_ 1c chase clw ½ round the outside | 1M+2c & 3c+1W ½ RHA, finish 1c facing down, M on the L

17–::

  1c dance down NHJ, and Twirl (change sides, W passes above M & under his arm) and up (to 2,1,3)

25–::

  All Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (3618, '2012-07-21 11:46:00.547475+00', '2020-12-26 09:57:46.344138+00', 13982, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) turn LH to face 1cnr

9–::

  1c turn 1cnr RH _while{2}_ 2cnr set | 1c turn LH to face 1cnr position _while{2}_ all cnrs chase 1 place clw ; repeat, finishing (3x,1x,2x)

17–::

  All S&Link3 twice (2,1,3)

25–::

  1c+3c the Knot (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (9335, '2016-09-28 23:35:02.930895+00', '2022-10-23 19:34:38.63451+00', 7653, 2, 2929, 'ace', '1-::

  1c dance down the middle, cast up around 4c, dance to top, cross RSh to opposite sides facing 2c

9-12::

  Turn 2c RH once and a half

13-16::

  Turn 3c LH once and a half

17-20::

  Turn 4c RH once and a half

21-24::

  1c turn LH once and a half to own sides

25-::

  All circle round and back', 2);
INSERT INTO 'dancecrib' VALUES (10266, '2017-11-21 11:46:26.301542+00', '2021-01-08 16:04:37.726828+00', 12869, 1, 202, 'ace', '1--::

  1c dancing RSh round P finish in DTr position  up/down (2c up), 1M facing down | 2c+1W & 1M+3c set ; 1c turn 4cnrs RH

9--::

  1c turn 1cnrs LH to 2plx into lines3 across ; all chase clw ½. 1c face P

17--::

  1c cross RH | dance RSh round 4cnrs[pos] (to 3x,1x,2x) : all turn P RH (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)

33--::

  Circle6 L {3}, pivot L ; chase cclw to places (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2983, '2012-01-22 19:30:05.582147+00', '2021-01-30 16:39:16.055492+00', 10957, 1, NULL, 'ace', '{{explanation}}

3c+4c start on opposite side (1,2,3x,4x)



1–::

  1c+2c & 3c+4c RHA ; 1c+4c cross RH | cast to middle positions (2c+3c to end)

9–::

  1c+4c LHA ; 1c+4c turn cnrs RH (2,1x,4,3x)

17–::

  Reels4 on the sides, 1c+4c omit last Lsh pass (2,4,1x,3x)

25–::

  1c+4c turn nearest cnrs RH ; 4c+1c LHA

33–::

  4c+1c cast to end | cross RH ; cast to middle | cross RH (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (13666, '2021-02-17 12:35:11.338036+00', '2021-02-17 12:41:45.813056+00', 3382, 1, 202, 'ace', '1--::

  All set to P | turn P RH. All W face out ; 4 bars of Schiehallion Reels (2,3,4,1)

9--::

  1c set to P | turn P RH ; 2c+1M RHA _while{4}_ 1W+4c LHA. 1c meet and dance NHJ to 4pl (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2990, '2012-01-22 19:30:05.853386+00', '2019-02-26 21:38:51.092005+00', 13129, 1, NULL, 'ace', '1–::

  1c+4c cast to middle (2c+3c step to end) | 1c+4c ½ RHA ; 4c+1c advance{1}, retire{1} | advance {1}, join NH with P and Retire{1} (2,4x,1x,3)

9–::

  4c facing 1c S&Link, 2c+4c & 1c+3c RHA (2,4,1,3)

17–::

  Parallel Reels4 on the sides

25–::

  Circle8 and back.  1W & 4M dance straight into the cast that follows.', 3);
INSERT INTO 'dancecrib' VALUES (12450, '2019-12-30 00:53:09.425568+00', '2019-12-30 01:02:39.631276+00', 8719, 1, 202, 'ace', '1--::
  All (no hands) advance {1}, set slighty L {1} | loop L to exchanged places ; All (no hands) advance {1}, set slighty L {1} | turn P RH ½ into allemande hold
9--::
  3C Allemande (3,2,1)
17--::
  2c+1c RHA into line4 across facing down, 1c in the middle, 2c close to same sex person, all except 2W looping more or less to places ; Line4 dance down 
25--::
  All turning inwards dance up, 1c leading to 2pl and facing out (to 3,1,2) ; 1c turn 2c on sides EH (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (11730, '2019-03-25 22:31:41.799051+00', '2019-03-25 23:31:47.220752+00', 10842, 1, NULL, 'ace', '*Part 1*

1--::

  All M advance to centre {1} and set L {1] _while_ All W set R {1} and advance {1}. meeting the opposite dancer as new P | turn new P RHi nto promhold facing cclw ; Promenade half round set

9--::

  Repeat [1-8] to rejoin own P and finish (3,4,1,2)

17--::

  3c+1c ½ R&L ; 2c+4c ½ R&L (1,2,3,4)

25--::

  "Crescent Reels4": 1M+2c+3W & 1W+4c+3M Reels4, 2c+4c start Lsh to P.  Finish all M in middle LHJ and RHJ with P who face clw



*Part 2*

33--::

 All "HS Balance" [Set HS step{1}, set R{1}, changing to LH with P (join new hands underneath) and W join RH | repeat back (other foot/hand)] ; All M LHA _while_ all W chase clw ½ round 

41--::

  Repeat from new places, finish (1,2,3,4) with Men facing out

49--::

  Double La-Chain, finish (1,2,3,4), with 1c+3c facing P

57--::

   "Crescent Reels4": 2W+1c+4M & 2M+3c+4W Reels4, 1c+3c start Lsh to P. (to 1,2,3,4)



*Part 3*

65--::

  All turn P RH | All W dance Rsh round P into the middle, RHA, to places (1,2,3,4)

73--::

  All turn P LH | All M dance Lsh round P into the middle, LHA, to places (1,2,3,4)

81--::

  All advance NHJ | Join NH with cnr and retire ; All set diagonally | turn cnr BH

89--::

  Circle8 and back (1,2,3,4)



  







', 3);
INSERT INTO 'dancecrib' VALUES (2291, '2012-01-22 19:29:30.085842+00', '2021-03-07 19:22:19.060922+00', 8977, 1, NULL, 'ace', '1–::

  Mirror Reels3 on own sides (all C touch hands with P), 2c starts in and up, 1c & 3c cast into the reel

9–::

  1c+2c continue reel to (2,1,3) | 1c turn RH ; cast L round 4cnr to meet in middle LHJ each facing own 2cnr

17–::

  set to 2cnr, at end swivel ½ L to face 4cnr RHJ | set to 4cnr, at end dancing ¼ turn backwards to face 1cnr ; set to 1cnr, at end swivel ½ R to face 3cnr LHJ | set to 3cnr and drop hands to face 2cnr

25–::

  2cnr pass and turn, on meeting P in the middle swivel ¾ R to face 1cnr ; 1cnr pass and turn (to 2,1,3)



{{explanation}}

(Note: on 2nd turn, 1c can be in 3pl of the set on [31] and turn 4c easy hand to face out in 3pl for the new reel, 1c finishing in 4pl', 2);
INSERT INTO 'dancecrib' VALUES (9899, '2017-06-01 22:27:52.311479+00', '2017-06-01 22:27:52.311479+00', 16210, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8, Lsh to 3cnr and face 1cnr

9--::

  CPCP, to (2,1,3), 1c facing out 

17--::

  1c cast L round 4cnr to midline and pass P RH while{4} corners A&R diagonally ; 1c cast R round 2cnr and cross RH to own side while{4} corners A&R diagonally (2,1,3)

25--::

  All dnce BtoB ; All clap, and turn P RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (14702, '2022-03-16 00:25:31.307642+00', '2022-03-16 00:25:45.502774+00', 18854, 1, 1645, 'ace', '1-::

  1c+2c & 3c+4c circle4 ; 1c & 3c petronella to centre line | set

9-::

  1c+3c &frac12; Reel4 ; set | petronella to own side (3,2,1,4)

17-::

  All set on sides | cross RH ; repeat (3,2,1,4)

25-::

  *The Double Rose:*  

  _1-2:_ 3M+2M set to 1W+4W, 3M & 4W advancing slightly _while_ 2W+3W & 1M+4M pass RSh to face out in 3M/2W places  

  _3-4:_ 3M+1W & 2M+4W &frac12; turn BH _while_ 2W+3W & 1M+4M dance up/down to 1M+2M/4W+3W places  

  _5-6:_ 3M+1W & 2M+4W cast away to exchanged places on sides _while_ 2W+4M & 3W+1M &frac12; turn BH  

  _7-8:_ 3M+2M & 1W+4W chase clw round bottom/top of set _while_ 2W+4M & 3W+1M cast away to exchanged places on sides (4,1,2,3)

', 2);
INSERT INTO 'dancecrib' VALUES (9900, '2017-06-01 22:46:55.594357+00', '2017-06-01 22:46:55.594357+00', 17776, 2, NULL, 'ace', '1-8::

  All pass opp. person RSH, dance LHA with next C (to change direction), pass (original) opp. person RSH.

9-16::

  1M followed by 1W dances cw around 2s, 1s pull back LSH on bar 12.  1W followed by 1M dances ccw back to place.  

17-24::

  2M followed by 2W dances cw around 1s, 2s pull back LSH on bar 20.  2W followed by 2M dances ccw back to place.

25-28::

  All turn opp. person LH ½ and staying close, face each other. All pull back LSH and dance to opp. side.

29-32::

  All dance Circle4 to the left with the next couple

', 5);
INSERT INTO 'dancecrib' VALUES (3001, '2012-01-22 19:30:06.379347+00', '2015-03-01 20:34:43.194654+00', 5209, 1, NULL, 'ace', '1–::

  1c cross RH, cast (2c up) ; 1c+3c RHA, finish 1M facing 1cnr, 1W behind him

9–::

  1c in tandem +1cnrs ½ diagonal Reel3, Rsh to 3W (1M & 1W loop R singly for lead change, so 1W now leads P) ; ½ diagonal Reel3, Rsh to 2W (+ lead change)

17–::

  Continue pattern twice

25–::

  2c+1c LHA ; 1c turn LH ½ | all set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3265, '2012-01-22 19:30:18.163416+00', '2020-11-14 22:50:41.308483+00', 9093, 1, NULL, 'ace', '1–::

  1c set advancing and swivel (man L, Woman R) to face out | 1M+2M & 1W+2W Turn ½ easy hand ; 1c+3c repeat [1-4] (to 2,3,1)

9–::

  1c ½Fig8 up and meet in middle ; dance to top and cast off (3c down) (2,1x,3)

17–::

  2c+1W & 1M+3c ½Reels3 across (Rsh to 4cnr) 1c finish in 2pl, M facing up, W down ; ½Reels3 on sides (Lsh to 3cnr pos), finish with loops (3x,1,2x)

25–::

  1c+2c RHA, 2W finishes facing out ; 1c turn LH to 2pl _while{4}_ 3c+2c chase ½ clw (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2996, '2012-01-22 19:30:06.183678+00', '2020-12-26 09:54:06.488556+00', 13589, 1, NULL, 'ace', '1–::

  1W+2M dance Rsh round P and cast R to finish BtoB BHJ with P ; 1c+2c ½ Poussette (2,1,3)

9–::

  2c+1W & 1M+3c Reels3{6} across, Lsh to 1cnr | 1W/1M dances up/down and pivots R to face P on midline in 1pl/3pl _while{2}_ 2c finish  BtoB with 3c, both NHJ and facing the end

17–::

  All set | 1W+2c & 3c+1M Circle3 L ½, finish 1c BtoB facing the ends and 2c facing 3c NHJ ; All set | 1c petronella and 2c+3c Link to (2,1,3)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (14045, '2021-05-27 17:51:47.296104+00', '2021-05-27 22:56:10.181586+00', 20344, 1, 202, 'ace', '1--::
  All chase clw ½ ; cross RH | set (3,2,1)
9--::
  All A&R ; dance BtoB (3,2,1)
17--::
  3c+2c 6 bars of R&L | all set (2,3,1)
25--::
  Circle6 and back (2,3,1)
', 5);
INSERT INTO 'dancecrib' VALUES (10267, '2017-11-22 10:11:22.739148+00', '2019-02-01 15:53:23.946487+00', 18079, 1, 202, 'ace', '1--::

  1c cross | cast (2c up) ; ½ Reels3 across, 1c Rsh to 4cnrs to start (2x,1,3x)

9--::

  ½ Reels3 on sidelines, 1c Lsh to 3cnrs to start ; 1c turn P LH 1 ½ to face 1cnrs position

17-28::

  Dance to corners and set

29-32::

  1c cast to 2pl, Lsh to 1cnrs _while{4}_ 2c & 3c A&R diag (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2999, '2012-01-22 19:30:06.301276+00', '2019-03-11 19:04:53.977181+00', 5208, 1, NULL, 'ace', '1–::

  All set twice ; turn RH, 1c+2c finish for

9–::

  1c+2c Allemande

17–::

  2c+1c+3c G-Chain (2c cross to start)

25–::

  1c+3c RHA ; LHA, into

33–::

  1c+3c Poussette, 1c finish BtoB on own side for

41–::

  3c+1c+4c DTr

49–::

  1c dance to 1pl (2c+3c down) ; 1c followed by 2c+3c+4c cast off on own side

57–::

  and lead up the middle, finish with 2c in 1pos ; 1c dance under arches formed by 2c+3c+4c (to 2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (8207, '2014-03-13 00:00:24.929756+00', '2019-02-26 23:07:08.714981+00', 13135, 1, NULL, 'ace', '1–::

  Parallel Rsh Reels3 on the sidelines

9–::

  1c turn 2c RH on sides | 1c+2c Circle4 L | turn P BH into diagonal for

17–::

  1c+2c ½ Poussette, 3c step in for ; 1c+3c ½ Poussette (2,3,1)

25–::

  All set | turn P BH and stay close ; All set | All cast away R to own sideline (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3012, '2012-01-22 19:30:06.852398+00', '2019-01-27 20:06:48.323339+00', 5239, 1, NULL, 'ace', '1–::

  1c Petronella Turn | set ; repeat (1x,2)

9–::

  Repeat (1,2)

17–::

  1c lead down the middle and up

25–::

  1c+2c Poussette (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (2877, '2012-01-22 19:30:01.218556+00', '2021-05-04 23:13:04.570655+00', 4784, 1, NULL, 'ace', '1–::

  1c+2c+3c Inveran Reels3 (1c crossing top and bottom)

9–::

  1c turn RH 1½ into 2plx facing out (2c up) ; 1c cast up round 2c and cross down to (2,1,3)

17–::

  G-Chain (2c cross)

25–::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10556, '2018-03-29 07:59:04.681781+00', '2020-10-18 10:22:33.96716+00', 17048, 1, 202, 'ace', '1--::

  1c 6 bars of Reels3 on opposite sides | 1c dance down into DTr position as 2c continues the reel to 1pl (2,1x,3)

9--::

  All set as in DTr | 1c dance Rsh round each other to exchanged places _while{2}_ 2c & 3c chase clw 1 place ; all set | 1c dance round each other, 1M ends facing 1cnr position, 1W behind 1M, _while{2}_ 2c & 3c chase clw 1 place

17--::

  1c ½ Reel3 in tandem (with lead change) on 1diag ; repeat on 2diag, 1c finish in centre, 1W on 1M''s L, facing down

25--::

  Mirror Reels3 on sidelines, 1c start in and down (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13796, '2021-03-08 20:09:42.707042+00', '2021-03-13 10:11:43.696389+00', 19712, 1, 202, 'ace', '1--::

  »3C Espagnole« [: 1W+2W & 2M+3M lead RHJ to opposite sides and cross _while{2}_ 1M & 3W chase 1 place clw (to Mside: 2W,1W,3W, Wside: 1M,3M,2M) | repeat same pattern from new positions (to Mside: 3M,1M,2M, Wside: 2W,3W,1W) ; 3M+2W "top couple" & 2M+1W "bottom couple" turn RH _while{4}_ 1M+3W "middle couple" turn LH] (Mside: 3M,1M,2M, Wside: 2W,3W,1W)

9--::

  All set | cross LH ; chase cclw ½ (Mside: 2M,1M,3M, Wside: 1W,3W,2W)

17--::

  3C Bourrel (3,2,1)

25--::

  2c+1c 6 bars of R&L | all set (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (3008, '2012-01-22 19:30:06.689517+00', '2018-11-05 17:16:31.95928+00', 5232, 1, NULL, 'ace', '1–::

  1c cross down into Mirror Reels3 on opposite side, finish facing 1cnr

9–::

  1c+1cnrs set | 1c dance Rsh round each other to 3cnr place _while_{2} 1cnrs dance Rsh to centre and face own place ; corners set to 1c | dance Rsh round each other to 3cnr place _while_{2} 1c dance to centre and twirl to face 2cnrs

17–::

  Repeat [9-16] with 2cnrs, 1c end facing 1cnr position

25–::

  ½ Diag Reel4 with 1cnrs, pass Rsh ; ½ Diag Reel4 with 2cnrs, pass Rsh to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10004, '2017-07-12 14:16:41.282429+00', '2017-09-29 10:35:20.074994+00', 17889, 2, NULL, 'ace', '::

 *start 2s & 3s cross to opp sides*

1- 4::

  1s cross Dn diag RH to 2nd pl (2s Up) while 4scross Up diag RH to 3rd pl (3s Dn1); then 1W, 4W and 1M, 4M ch pls on side LH: 

5- 8::

  1s ½ fig8 Dn thru 3s, 4s ½ fig8 Up thru 2s: 

9-16::

  4s1s set, ½ RH wheel then 2s1s and 4s3s set, ½ LH wheel to fin 1234: 

17-24::

  all Rof4 on sides (start 1s2s and 3s4s pass LSh to begin): 

25-28::

  1s, 4s cross RH then 1s+2s and 3s,4s ch pl LH on sides; 

29-32::

  AS 1W,4W and 1M,4M turn 1½ on sides to ch pls ALSO 2s,3s turn RH to fin 2(4)(1)3: Rptx4. 

 

', 2);
INSERT INTO 'dancecrib' VALUES (3828, '2013-07-13 15:56:16.849995+00', '2014-04-30 23:24:05.702917+00', 14544, 1, NULL, 'ace', '{{explanation}}
C face C RR, 1c face clw, 2c cclw

1–::
  1c dance between 2c and cast back to places : ½ RHA (slow) (2,1)
9–::
  2c repeat (1,2)
17–::
  All A&R to centre ; ½ R&L (2,1)
25–::
  ½ LHA (2,1) ; 1c+2c (W leads, M follows) »snake« Rsh round each other to finish BtoB facing next couple.', 3);
INSERT INTO 'dancecrib' VALUES (10152, '2017-09-29 10:35:20.077508+00', '2017-09-29 10:35:20.077508+00', 17889, 1, NULL, 'ace', '*Start (1,2x,3x,4)*

1--::

  1c cross down RH (2c up) _while{2}_ 4c cross up RH (3c down) | 1c+4c change places LH on side ; 4c+1c ½ Fig8 through end (2x,4,1,3x)

9--::

  4c+1c set | ½ RHA ; All set | 2c+1c & 4c+3c ½ LHA (1,2,3,4)

17--::

  Lsh Reels4 on the sides (1,2,3,4)

25--::

  1c+4c cross RH | 1c+2c & 3c+4c change places LH on sides ; 1c turn 4c RH 1½ _while{4}_ 2c+3c turn RH (2,4x,1x,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3014, '2012-01-22 19:30:06.931815+00', '2017-11-14 01:05:20.591934+00', 13822, 1, NULL, 'ace', '1–::

  1c+3c L-Chain, end in promhold

9–::

  1c+3c passing Lsh exchange places ; set advancing | turn person opposite BH ½ and face side couple

17–::

  Parallel Reels4 across, finish 1W facing 3W with P behind them

25–::

  1c+3c RSh Reel4 up/dn, 1W+3W pass Rsh to start, finish (1,2,3,4)

33-64::

  2c+4c repeat [1-32]

65–::

  All set | all W RHA | dance Lsh round P, to places

73–::

  All set | all M LHA | turn P RH ¾ to places, W facing out

81-96::

  Schiehallion Reels, at end W face out

97–::

  All W dance one place clw | turn that M RH ; dance one place clw | turn that M RH and face him

105–::

  G-Chain, 1 bar/hand, M finish facing cclw

113–::

  All M dance one place cclw | turn that W LH ; dance one place cclw | turn P LH into Allemande hold facing cclw

121–::

  All dance ½ way round to places ; turn W into BtoB in the centre facing P (as in Allemande) | turn P RH putting W in the centre again and honour partner', 3);
INSERT INTO 'dancecrib' VALUES (8253, '2014-04-24 11:29:08.276104+00', '2017-11-23 00:43:33.275661+00', 3017, 1, NULL, 'ace', '1–::

  All turn cnr RH ; All turn P LH

9–::

  Double L-Ch: All W ½ RHA as all M dance to P''s place | all M turn the W LH ½ ; repeat (1,2,3,4)

17–::

  All set | All M petronella to centre facing P and the W set and face them ; All W A&R _while{4}_ all M dance round the W Rsh, and to centre

25–::

  All cpls change places RH | all M chase one pl clw _while{2}_ the W ½ LHA, and face new P ; All M A&R _while_{4} all W dance round the M Rsh, and finish on the M''s right', 3);
INSERT INTO 'dancecrib' VALUES (2876, '2012-01-22 19:30:01.179777+00', '2021-04-13 21:56:55.396131+00', 4782, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1c lead down the middle (2c up) ; and up to face 1cnrs

17–::

  1c set to and turn corners, finish between corners

25–::

  Lsh Reels3{6} on the sides, 1c cross RH.', 3);
INSERT INTO 'dancecrib' VALUES (12451, '2019-12-31 10:43:51.637103+00', '2019-12-31 10:52:10.603377+00', 18996, 1, 202, 'ace', '1--::

  1c+2W & 2M+3c RHA. 2c LSh to P in centre ; ½ Reel3 on sides, 2c LSh to 2cnrs. 2c in 2plx face out (3,2x,1)

9--::

  2c RSh round 1cnrs to between ends ; 2c advance in and turn P RH 1¼ to 2pl (3,2,1)

17--::

  3c turn RH ½ to 2plx centre facing up NHJ _while{2}_ 2c dance up to 1pl centre facing down NHJ | 2c & 3c set ; 2c+3c ½ RHA | 3c cast off to 2pl _while{2}_ 2c cross up to 1pl and face out (2,3,1)

25--::

  Mirror Reels3 on sides, 3c in and down, 1c out and up (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10268, '2017-11-22 13:41:50.388495+00', '2017-11-23 03:52:19.031766+00', 18081, 1, 202, 'ace', '1--::

  1c+2c »Helix«: Both C set passing P Lsh | cast R to own place ; turn P RH ½ | ½ RHA (2,1,3)

9--::

  1c ½ Fig8 up; ½ Fig8 down, finish facing 1cnrs

17--::

  Corners Pass and Turn (2,1,3)

25--::

  1c+3c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3829, '2013-07-13 15:56:16.968692+00', '2020-09-17 22:29:31.325426+00', 13460, 1, NULL, 'ace', '1–::

  1c+5c A&R on the diagonal ; 1 cross RH and cast off 2 places (2c+3c up) (2,3,1x,4,5)

9–::

  3c+1c+4c Circle6 and back

17–::

  1c cross LH and cast off 2 places (4c+5c up) ; 2c+1c A&R on the diagonal

25–::

  All turn P RH ; turn P LH (2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (10561, '2018-03-29 18:25:17.227976+00', '2020-10-23 09:32:05.671505+00', 17053, 1, 202, 'ace', '1--::
  1c & 3c lead down ; and up crossing on [8] to 1plx/3plx and facing out (1x,2,3x,4)
9--::
  Mirror Reels4, 1c & 3c start out and down
17--::
  1c+2c & 3c+4c Set&Rotate (2,1x,4,3x)
25--::
  1c+4c+3c diagonal R&L (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (3016, '2012-01-22 19:30:07.01089+00', '2014-06-27 21:20:11.489416+00', 5262, 1, NULL, 'ace', '1–::

  1c+3c DblFig8 (1c cast to start) (1c finish in 2pl BtoB own side, 2c steps up)

9–::

  »Petronella Triangles«: 1c DTr {8}and finish facing 3cnr _while_{8} 2c+3c set | Petronella 1 place cclw ; set | Petronella 1 place cclw (to diagonally exchanged places)

17–::

  ½ diagonal Reel4 with 1cnrs, pass Rsh to face 4cnr positions ; ½ diagonal Reel4 with 2cnrs, finish facing 1cnr for:

25–::

  Reels3{6} across (Lsh to 1cnr), 1c turn RH  (2,1,3)  (but on 2nd time through 1c dance NHJ to 4pl as 4c continue the reel, casting into 3pl).', 3);
INSERT INTO 'dancecrib' VALUES (10773, '2018-05-20 00:25:18.627294+00', '2020-11-15 11:52:59.370815+00', 18318, 1, 202, 'ace', '1--::

  1c+2c set | La Baratte (1x,2x,3)

9--::

  2c followed by 1c lead down {3}, on [4] the W dance under P''s arm ; 1c followed by 2c dance up and cast off to 2pl, 2c finish in 1pl (2,1,3)

17--::

  1W followed by 1M ½ Fig8 R round 2M, 1c in tandem dance between 3c, separate and cast up to 2plx (2,1x,3)

25--::

  2c+1c+3c Circle4 L ; 2c & 3c chase back to places _while{4}_ 1c turn RH 1½ to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11504, '2019-01-09 14:30:00.138144+00', '2022-02-15 15:55:32.739571+00', 14459, 1, 1645, 'ace', '1-::

  1c+2c set | &frac12; RHA ; set | &frac12; LHA, 1c face out (1,2,3)

9-::

  1c+3c DblFig8 round 2c giving hands, 1c start by casting & end facing P in centre as 2c step in for

17-::

  1c+2c poussette (2,1,3)

25-::

  Circle6 to L & pivot ; chase cclw back to R (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3021, '2012-01-22 19:30:07.208104+00', '2018-04-09 18:36:13.740613+00', 9121, 1, NULL, 'ace', '1–::

  1c+2c RHA, finishing 1W facing out ; 1c with 1W leading, chase behind 2W and across the set to 2pl with 1W facing out on the men''s side. [2c up 7-8]

9–::

  1c+3c LHA. finishing 1W facing out ; 1c with 1W leading, chase behind 3M and across the set to 3pl with 1W facing out on the ladies'' side. [3c up 15-16]

17–::

  Parallel Reels3 on the sidelines, 1c Lsh to 3c

25–::

  1W+3W & 1M+3M 1½ LH turn ; 1c RH turn (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2906, '2012-01-22 19:30:02.377188+00', '2018-02-12 21:52:31.286844+00', 4882, 1, NULL, 'ace', '1–::

  1c+2c A&R ; half R&L

9–::

  2c+1c A&R ; half R&L

17–::

  1W followed by 1M cast off round 2c ; cast up and cross to place

25–::

  1M followed by 1W casts to 2pl (2c up) ; 1c ½ RH turn, join LH too and draw close, fall back to own side', 2);
INSERT INTO 'dancecrib' VALUES (8080, '2013-10-09 13:42:22.385603+00', '2019-10-23 18:09:49.981853+00', 10703, 1, NULL, 'ace', '1–::

  All turn P RH ; chase clw ½ way (3x,2x,1x)

9–::

  All turn P LH ; chase cclw ½ way (1,2,3)

17–::

  Lsh Reels 3 on the sides,

25–::

  1c lead down the middle{3} and back | cast off (2c up) (2,1,3)



*For beginner dancers, replace [17-24] by "1c dance  Lsh Fig8 on own side"*', 3);
INSERT INTO 'dancecrib' VALUES (12438, '2019-12-17 11:42:29.857508+00', '2020-04-22 20:32:10.274072+00', 19797, 1, NULL, 'ace', '1--::

  1W+2M & 4W+5M advance to meet {1} and cast R back to place {1} | 1c+2c & 4c+5c change places Rsh on the sides ; 2c+1c & 5c+4c Circle4 L (2,1,3,5,4)

9--::

  1c+3c+5c LHA ; 1W+3W+5W (upwards) & 1M+3M+5M (downwards) chase through end couple and cast R behind own lines to (2,5,3,1,4)

17--::

  3c+1c+4c dance 3C S&Rotate [set | all cast ¼ clw ; change places with P up/dn | all chase ¼ clw] (2,5,4,1,3)

25--::

  5c+1c ½ Fig8 outwards ; cross LH | All set (2,5,4,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (3028, '2012-01-22 19:30:07.483756+00', '2020-09-18 08:20:54.46575+00', 13469, 1, NULL, 'ace', '1–::

  1c+2c  Poussette (1,2)

9–::

  1W+2M set | cast clw (W down, M up) _while_{2}   P''s cross ; repeat figure (1M+2W set and cast) (2x,1x)

17–::

  1M+2W Turn RH 1½ ; 1W+2M repeat LH

25–::

  1c+2c Tournee', 2);
INSERT INTO 'dancecrib' VALUES (2155, '2012-01-22 19:29:22.950899+00', '2021-02-18 10:58:41.293004+00', 9853, 1, NULL, 'ace', '1–::

  1c dance down between 3c, cast up round 3c, dance to top, cast off (2c up) (2,1,3)

9–::

  1c set adv. passing P (cnrs also set) | turn 1cnr BH, opening (1c leading) into Circle4 L.  Cnrs finish in place, 1c between end Cs.

17–::

  1c set adv. | turn 2cnr BH, opening (1c leading) into Circle4 L.  Finish (2,1x,3)

25–::

  1c+3c set | 1c+3c ¾ DblFig8, 1c cast to start (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3023, '2012-01-22 19:30:07.286354+00', '2021-04-25 10:04:19.966609+00', 5282, 1, NULL, 'ace', '1–::

  1c+2c RHA, LHA. 1c finish in middle for

9–::

  1c slip down BHJ | and up ; cast to 2pl (2c up on 15-16)

17–::

  1c dance between 3c and cast up to face 1cnrs ; 1c set to 1cnr | to 2cnr,  at the end 1M pivots L, 1W pivots R to face P up/down

25–::

  1c lead out on W side, cast (1M up, 1W down) and meet in the middle ; lead out and cross between M, cast (1M down, 1W up) into 2pl

', 4);
INSERT INTO 'dancecrib' VALUES (14403, '2021-10-30 18:09:53.543338+00', '2021-12-20 19:11:26.034183+00', 10659, 2, 2401, 'ace', '1-8::  1s set & cast 2 places, cross RH and cast up to 2nd place opposite sides, on bars 7-8 2s dance up and face out
9-16::  2s, 1s, 3s, reflection reels of 3 on the sides giving hands as appropriate, 1s in and up to start, 1s cross RH on bars 15-16
17-24::  1s & 3s dance The Knot
25-32::  Six hands round and back
', 3);
INSERT INTO 'dancecrib' VALUES (13950, '2021-04-11 13:16:08.275229+00', '2022-04-26 15:10:50.156661+00', 19566, 1, 202, 'ace', '1--::

  1M casts off _as_ 2M step up _while_ 4W casts up _as_ 3W step down | 1M+4W set ; turn RH

9--::

  1W & 4M repeat same pattern [1-8] using LH (2,1,4,3)

17--::

  1c+4c The Bourrel (2,4,1,3)

25--::

  Circle8 and back



*Deviser''s note* : 1W and 4M after turning by the LEFT hand bars 13-16 dance across the set to start the bourrel while their partners who have stood still set advancing', 2);
INSERT INTO 'dancecrib' VALUES (14498, '2021-12-25 19:45:22.115646+00', '2021-12-25 19:51:49.76864+00', 11465, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 1c ½ Fig8 R round 3cnrs and face 1cnrs

9--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag (3x,1x,2x)

17--::

  3C S&Link twice (2,1,3)

25--::

  1c ½ Fig8 L round 2cnrs (to 2,1x,3) ; 1c cross RH | cast off (3c up) (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (15176, '2022-10-18 17:48:28.029679+00', '2022-12-22 18:31:37.925673+00', 10907, 1, 1645, 'ace', '1--::

  1c cross down into Fig8 round 2c

9--::

  Mirror Reels3 on the sides giving hands, 2c start out & up

17--::

  1c turn RH | cast off (2c up) ; turn LH (2,1,3)

25--::

  2c+1W & 1M+3c RHA, 1c pass RSh; LHA with other couple (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14270, '2021-09-06 15:21:27.834667+00', '2021-09-19 22:37:12.572007+00', 10456, 1, 202, 'ace', '1--::

  1c & 4c Petronella turn | set (2c & 3c step out) ; 1c & 4c turn P LH 1¼ into lines3 across, 1c between 2c & 4c between 3c facing opposite sides

9--::

  1c+2c & 3c+4c *Modified Celtic Reel* : 1c+2c & 3c+4c pass RSh | »outers« chase clw ¼ _while{2}_ »inners« turn LH ¾ and face same person ; repeat [9-12]

17--::

  Repeat [9-16] to finish as on [9], 1c facing down & 4c facing up

25--::

  1c & 4s set twice ; ½ R&L to sides (2,4,1,3)

33--::

  1M(+4M following) dance LSh round 3M and up between 3c  _while{4}_ 4W(+1W following) dance LSh round 2W and down between 2c ; 1c+4c ¾ LHA to sides (2,4,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11809, '2019-04-27 11:05:47.180152+00', '2020-11-15 12:08:44.832908+00', 18342, 2, 2929, 'ace', '1-4:: W w/ M on left side RH across half

5-8:: M repeat LH across half

9-16:: M circle round and back, finish skip change to place WHILE W dance ACW 4 bars, cast back, finish in middle

17-24:: Repeat with roles reversed, finish in promenade hold facing CW

25-40:: Advance to next place, set, repeat until back to original place

41-48:: W dance in, pull back RSh, set to partner, turn RH 1 1/4 to place

49-56:: M repeat w/ LH turn

57-64:: L fig 8 around partner and corner, start dancing in front of partner

65-72:: M repeat

73-80:: (Maypole RH across) 1C+3C dance in and dance RH across with hands pointed towards ceiling, spiral in on bar 6 and dance back to place

81-88:: 2C+4C repeat

89-96:: All circle round and back', 2);
INSERT INTO 'dancecrib' VALUES (3037, '2012-01-22 19:30:07.835832+00', '2014-07-29 09:24:53.127393+00', 5330, 1, NULL, 'ace', '1–::

  1c+4c set, cast to middle positions (2c+3c step to end) ; 1c&4c ½ Fig8 round end C (2,1x,4x,3)

9–::

  1M+4M and 1W+4W cross NHJ, (W under men''s arch), turn cnr ¾ with ''free'' hand ; 1c facing 4c change places NHJ (arch going up), turn cnr as before

17–::

  Repeat (Men''s arch ; arch going up)

25–::

  1c+4c ½ R&L ; turn P RH



{{explanation}}

Note that both times the couple moving UP makes the arch. ', 3);
INSERT INTO 'dancecrib' VALUES (3715, '2013-03-15 23:47:17.382796+00', '2016-04-18 22:16:40.104164+00', 14739, 1, NULL, 'ace', '1–::

  1c Fig8 on own side, start down between 2c, give hands when possible

9–::

  1c Fig 8 round 2c

17–::

  1c+2c RHA ; LHA, finishing for

25–::

  1c+2c Poussette (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3038, '2012-01-22 19:30:07.874867+00', '2020-12-19 14:23:09.914695+00', 8132, 1, NULL, 'ace', '1–::

  1M+2M A&R ; 1M followed by 2M cast up over top to W side _while{4}_ 1W+2W set and cross over

9–::

  1W+2W & 2M+1M repeat (1c & 2c have now changed places)

17–::

  1c+2c set up & down, set to partners ; 1c dance (join hands) up between 2c and cast to 2pl

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (10413, '2018-02-04 22:41:51.380311+00', '2018-02-04 22:48:58.010456+00', 16684, 1, NULL, 'ace', '1--::

  1c dance down to face 3c in line across | 1c+3c set ; 1c (start down) turn 3c EH to (2,1,3),| All set

9--::

  All Circle6 ½ ; All dance BtoB (3x,1x,2x)

17--::

  1c petronella{8} _while{8}_ 3c+2c cross RH | set ; change place RH on sides | set (2,1,3)

25--::

  2c+1W & 1M+3c RHA ; All turn P BH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10271, '2017-11-24 00:36:21.217632+00', '2021-01-27 04:30:18.568143+00', 9126, 1, 202, 'ace', '1--::
  1c set twice ; 1c (M leading) cast off and cross to 2plx (2c up) (2,1x,3)
9--::
  2c+1c L-Chain
17--::
  Parallel Reels3 on sides, 1c RSh to 3c (2,1x,3)
25--::
  1c+3c RHA ; 1c ½ Fig8 L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2907, '2012-01-22 19:30:02.41639+00', '2018-10-22 05:56:02.878749+00', 10535, 1, NULL, 'ace', '1–::

  1c set | cast off ; turn LH 1¼ into

9–::

  1c+1cnrs BiL | 1c+1cnr turn RH {4} | repeat BiL

17–::

  1c+cnrs Reels3 on the sides, Lsh to 2cnr, 1c finish LHJ and RHJ with 2cnr

25–::

  1c+2cnr repeat [9-16]

33–::

  Reels3 across, 1c Lsh to 3cnr, at end 1c cross RH as 2c+3c curve into place (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10270, '2017-11-23 03:42:55.546106+00', '2017-11-23 03:58:09.811144+00', 18077, 1, 202, 'ace', ' 	

1--::
  1c+2c S&Rotate, 1c ending in tandem, 1M facing 3cnr, 1W behind P ready for
9--::
  1c+1cnrs, ½ Reel3 in tandem (with lead change), 1M Rsh to 2M to start ; repeat with 2cnrs, 1W Rsh to 3M to start, 1c finish in centre facing down, 1W on 1M''s R
17--::
  1c lead down, cast up ; dance up, cast off _while{8}_ 3c+2c R&L up/dn (3x,1x,2x)
25--::
  S&Link3 ; repeat (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (3039, '2012-01-22 19:30:07.914231+00', '2019-02-08 17:41:09.911573+00', 8097, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c RHA ; LHA

9–::

  1c+3c lead down (2c+4c up) ; and up to between these Cs, facing own side

17–::

  1c+2c & 3c+4c Reels4 across, to (1,2,3,4)

25–::

  1c, others following, cast off to the bottom ; 1c make arch and others dance up under arch to (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (11773, '2019-04-07 02:22:40.787708+00', '2019-04-07 02:22:40.787708+00', 19187, 1, NULL, 'ace', '

1--::

  1c+3c ½ Petronella turn | set | Petronella turn | All set (1x,2,3x)

9--::

  2c Diagonal R&L with corners (first R, then L) (3,2,1)

17--::

  2c+1c Bourrel (3,1,2)

25--::

  Circle6 and back (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (9336, '2016-09-28 23:40:44.484315+00', '2021-01-04 15:19:11.397948+00', 15097, 2, 2929, 'ace', '1-::

  A&R twice

9-::

  L dance around P; M dance around P

17-18::

  Advance along line of dance

19-20::

  Change sides [L in front]

21-22::

  Change sides [M in front]

23-24::

  Rsh back to finish in circle [M on left]

25-28::

  Slip L twice, Lsh back in place

29-32::

  Slip R



Note: Finish bar 24 with M on right to make dance progressive', 0);
INSERT INTO 'dancecrib' VALUES (3736, '2013-05-17 22:37:52.926751+00', '2014-04-30 23:24:06.341959+00', 5384, 1, NULL, 'ace', '1–::
  Parallel Rsh Reels3 on own side
9–::
  1M+2W Turn RH to places ; 1W+2M repeat LH
17–::
  1c cross RH | cast off two (2c up) ; cross LH | cast up (2,1,3)
25–::
  1c+3c RHA ; 2c+1c LHA (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13118, '2020-08-22 21:00:32.553238+00', '2020-08-23 19:39:45.545103+00', 20071, 1, 1645, 'ace', '1-::

  1c dance down to 3pl | turn BH{4} | dance up _while{8}_ 3c dance up behind 2c | 3c+2c Circle4 to L | 3c cast off (1,2,3)

9-::

  1c+2c Poussette, on [16] 1c cast (L foot) as 2c dance up (2,1,3)

17-::

  All &frac12; Reels3 on sides, 2c cast, 1c in & down to start. 3c end with &frac12; turn BH to face down NHJ, 1c end facing up NHJ (3x,1,2) ; 3c+1c set | &frac12; RHA (1x,3,2)

25-::

  4 changes of Gr-Chain, 2c cross to start (2,1,3x) ; 1c+3c &frac12; R&L | 1c cross RH (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (3050, '2012-01-22 19:30:08.403321+00', '2020-09-02 18:05:07.039973+00', 5388, 1, NULL, 'ace', '1–::

  1c dance (NHJ) between 2c and cast up to places ; 2c repeat up between 1c, casting down

9–::

  1c+2c half L-Chain (2c has opposite sex role) and face P on sideline ; Set H.Schottische

17–::

  1c+2c half M-Chain (2c has opposite sex role) (to opposite side facing P) ; Set H.Schottische (2x,1x)

25–::

  2c+1c cross RH, set ; circle4 L', 3);
INSERT INTO 'dancecrib' VALUES (9337, '2016-09-29 12:25:41.334568+00', '2021-03-19 10:50:32.572192+00', 8480, 1, 202, 'ace', '1-::

 1c lead down {3}, up {3} | cross and cast off to 2plx (2c up)

9-::

 2c+1c La-Chain

17-::

 1M, 1W following, cast up and cross to own side (2c down) ; 1c+2c turn RH, finish to

25-::

 1c+2c Poussette

', 2);
INSERT INTO 'dancecrib' VALUES (13667, '2021-02-19 00:57:12.25955+00', '2021-02-19 00:59:01.168139+00', 15552, 1, 202, 'ace', '1--::

  All S&Link ; all W RHA and face P

9--::

  All dance BtoB ; turn P BH 1¼ (1,2,3,4)

17--::

  Circle8 and back

25--::

  All M LHA into promhold ; All Promenade cclw ¾ (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (3034, '2012-01-22 19:30:07.718163+00', '2021-04-25 08:49:13.962415+00', 5326, 1, NULL, 'ace', '1–::

  1c set (no advance), turn BH ½ into the middle NHJ facing 2c diagonally (drop hands) ; 1c set to 2c and face out | turn 2c EH ½ (2,1x,3)

9–::

  All A&R ; ½circle6 L (3x,1,2x)

17–::

  1c pass Lsh into ½ Rsh Reel4 with 1cnrs, pass Lsh into ; ½ Rsh Reel4 with 2cnrs (to 2,1x,3)

25–::

  1c ½Fig8 round 3c ; All turn RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3044, '2012-01-22 19:30:08.157086+00', '2021-04-25 08:38:57.783699+00', 5358, 1, NULL, 'ace', '1–::

  1c NHJ set twice to 2W, with her Circle3 left

9–::

  1c repeat with 2M

17–::

  1c down the middle and up finish with 2c stepping in for

25–::

  1c+2c Allemande, 1c finish facing 1cnr

33–::

  Corner, P, corner, P (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14607, '2022-02-15 20:22:21.699249+00', '2022-02-15 20:24:03.504865+00', 16517, 1, 1645, 'ace', '1--::

  *Butterfly Wings:* 2c+1c dance down | 2c cast up round 3c, 1c continue down & face up ;

  2c+1c dance up | curve out to sides (2,1,3)

9--::

  All set | cross passing RSh & face P in centre ; all retire to opp sides | &frac12; turn RH into allemande hold

17--::

  2c+1c+3c Allemande (3,1,2)

25--::

  3c & 2c set to P | cross RH, 3M & 2W face out ; chase &frac12; way clw (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3052, '2012-01-22 19:30:08.48165+00', '2014-04-30 23:24:06.419581+00', 723, 1, NULL, 'ace', '1–::
  1c cross RH | cast (2c does not step up) ; cross LH |, cast off to below 3c facing up
9–::
  1c (1W leading) dance up and out between 2W and 3W, 1M cast up and 1W down round 2W(3W) to meet in middle ; repeat, crossing out RH between 2M and 3M, 1W casting up, 1M down, and round 2M/3M to meet facing down
17–::
  1c lead down the middle and up to 1pl
25–::
  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (3054, '2012-01-22 19:30:08.555255+00', '2015-06-28 20:23:59.534703+00', 5403, 1, NULL, 'ace', '1–::

  1c+2c+3c set | Petronella Turn, set | Petronella Turn (1x,2x,3x)

9–::

  1c+2c+3c set | cross RH ; 1c facing 2c set and full turn EH, 2c starting outwards

17–::

  Inveran reels (mirror reels3 on the sides, 1c cross down to start, and cross up from the bottom (1,2,3)

25–::

  1c+2c Rondel (on 2nd turn, 4c step up and 1c dances to 4pl)', 2);
INSERT INTO 'dancecrib' VALUES (3051, '2012-01-22 19:30:08.442386+00', '2016-05-30 22:36:59.095828+00', 5389, 1, NULL, 'ace', '1–::

  1c in promhold with 2c reel3 across (Lsh to 2W), finish (2,1,3)

9–::

  G-Chain, 2c cross to start

17–::

  1c cross RH | turn 1cnr LH ; turn 2cnr RH | turn P ½ LH  to put 1M below 1W

25–::

  Teapots R ; and L (2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA) (2,1,3)



{{explanation}}

After 2nd time through the old 1c dances [1-8] with 4c to finish in 4pl.', 3);
INSERT INTO 'dancecrib' VALUES (3055, '2012-01-22 19:30:08.590151+00', '2014-11-05 16:56:47.539776+00', 9296, 1, NULL, 'ace', '{{explanation}}

2c stand on opposite sides to begin. (1,2x,3)



1–::

  1W+2M & 2W+3M set and turn RH (on sidelines) ; 1M+2W & 2M+3W set and turn LH

9–::

  2c set | cross RH ; ½ Rsh Reels3 on sides (2c goes R)

17–::

  2c set | cross LH, ½ Lsh Reels3 on sides (2c goes L), all end in the middle

25–::

  All C turn BH twice, ending in the middle ; dance out to sides and chase clw 2 places



{{explanation}}

Note: you end opposite another P to form new »couples« ; after 3 rounds you are back in original places.', 2);
INSERT INTO 'dancecrib' VALUES (10272, '2017-11-25 22:44:13.462231+00', '2020-09-08 16:48:18.52263+00', 9290, 2, 160, 'ace', '1-8::  1C+2W Reel3 on diagonal - 1C pass ptnr Rsh to begin.

9-16::  1C 2C half turn & cast (R) into partner''s place ; 4hands round to the left.  (1x 2x)

17-24::  1C+2M reel of three on diagonal - 1C pass Rsh to begin.

25-28::  1C 2C (still on opp. sides)  set and cross link (end NHJ with ptnr - 2C in top place facing down man on L and 1C in 2pl facing up woman on L) ;

29-32::  2C 1C set and cross link - end progressed on own sides.

', 2);
INSERT INTO 'dancecrib' VALUES (1641, '2012-01-22 19:28:52.570623+00', '2021-10-30 21:30:26.854145+00', 89, 1, NULL, 'ace', '1–::

  1c lead down the middle and loop up into 4pl (2c+3c+4c up on [3-4]) ; all set | Circle8 L for two places

9–::

  All M (at top) LHA _while{4}_ all W (below) RHA ; Continue both HA, but as each couple meets (order 1,4,3,2) they cross to the other wheel (W pass in front)

17–::

  As couples meet again the W join RH with P, the M dancing as if still in RHA, and (1c leading) unwind and lead up the middle and out to opposite sidelines {6} | all turn P RH ½ into

25–::

  1c+4c+3c+2c Allemande (to 2,3,4,1)



{{explanation}}

»Easier version« for [17-20]: As couples meet the W join NH with P who maintain RHA (continue as described)', 3);
INSERT INTO 'dancecrib' VALUES (3048, '2012-01-22 19:30:08.315791+00', '2016-09-04 22:28:03.176551+00', 10388, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c ½R&L (2x,1x,4x,3x) ; All chase ½ clw (to 3,4,1,2)

9–::

  3c+4c & 1c+2c RHA ; 4c+1c LHA (3,4,1,2)

17-32::

  Arches and Corners (as Postie''s Jig) (3,4,1,2)

33–::

  4M crosses with 1W | 1M crosses with 4W ; 1c+4c turn RH 1½ (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (3047, '2012-01-22 19:30:08.27526+00', '2016-11-15 16:10:38.962059+00', 5376, 1, NULL, 'ace', '1–::

  1c Half Petronella (2c up on [5-6]) (2,1x,3)

9–::

  2c+1c+3c Circle6 and back, retain hands on sides (2,1x,3)

17–::

  2c+1c+3c A&R ; 1c turn RH ½ (2,1,3) | All clap 3+3 times

25-28::

  1M+2M+3M & 1W+2W+3W Circle3 L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9533, '2017-01-06 20:37:31.430929+00', '2017-01-15 01:53:34.32963+00', 6151, 1, NULL, 'ace', '1--::

  Reels3 on own sides, 2c starts out and to the R (M up, W down), at the end 2c face out and 1c face 3c (1,2,3)

9--::

 1c+3c making arches set twice _while{4}_ 2c casts R and in through the end arch, 2c passes P Rsh ; 1c+2W & 2M+3c RHA  (1,2,3)

17--::

  All Circle6 L {3}, pivot L ; chase cclw to (1,2,3)

25--::

  1c+2c Set & Rotate (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3062, '2012-01-22 19:30:08.87827+00', '2014-04-30 23:24:06.594901+00', 5436, 1, NULL, 'ace', '1–::
  1c+2c RHA {3} , LHA{5} to 1c (2c) on M (W) side (¼ extra turn of the wheel)
9–::
  1c lead down the middle ; and up, 1M moving ahead of P to finish in own place, with 1W in 2M''s place.
17–::
  1c+2c R&L
25–::
  1c+2c set twice to P ; turn P BH (the M move in diagonally to begin) to finish (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (3069, '2012-01-22 19:30:09.213964+00', '2019-02-21 21:49:09.08351+00', 9108, 1, NULL, 'ace', '1–::

  1W, all other W following, cross, dance behind the Men, and back to places.

9–::

  The Men repeat.

17–::

  All W dance Rsh round P, to places ; All M repeat, Rsh.

25–::

  1c lead to 4pl (2c+3c+4c up) ; All clap 8 times.', 3);
INSERT INTO 'dancecrib' VALUES (10557, '2018-03-29 09:18:08.652796+00', '2020-10-18 10:29:04.69095+00', 17049, 1, 202, 'ace', '1--::

  All set | 1M+2W & 3M+4W cross RH ; all set | 2M+1W & 4M+3W cross RH (2x,1x,4x,3x)

9--::

  2c+1c & 4c+3c Circle4 and back

17--::

  All set | 1c & 3c, 1M & 3W leading, chase clw ½ to exchanged places _while{4}_ 2c & 4c set ; cross RH | all set (2,3,4,1) 

25--::

  2c+3c & 4c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (8214, '2014-03-19 20:59:51.431662+00', '2020-04-24 20:42:03.507375+00', 11105, 1, NULL, 'ace', '1–::

  1c+3c set advancing | LHA ¾ ; 1c+2c & 3c+4c ½ RHA | 1c+3c (W leading) chase ¼ clw _while{2}_ 2c+4c LHA ¾ (1c face 2c & 3c face 4c; 1M & 3M are on R of P)

9–::

  Parallel Rsh Reels4 up/down

17–::

  1c+2c & 3c+4c ½ R&L finish 1c facing 3c ; 1c+3c set | Circle ¾ L to finish (4,1,2,3)

25–::

  Circle8 and back (4,1,2,3)  



*Danced twice in Strathspey time, then twice in Reel time*

', 3);
INSERT INTO 'dancecrib' VALUES (11569, '2019-02-07 03:04:52.519654+00', '2020-12-07 13:01:16.682163+00', 10417, 1, 202, 'ace', '1--::

  1c cross | cast 2 places (2c up) ; turn RH 1¾ to face 1cnrs

9--::

  Turn CPCP (2,1,3)

17--::

  1c set | turn RH ¾ _while{4}_ 2c & 3c cross RH | set ; 1c repeat [17-20] and face out _while{4}_ 2c & 3c change places on sides | set (3x,1x,2x)

25--::

  1c dance RSh round 1cnrs | cross LH up/down ; dance LSh round 3cnrs | turn LH to face 3cnrs _while{8}_ 2c+3c R&L

33--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3830, '2013-07-13 15:56:17.552839+00', '2022-08-14 09:00:48.09471+00', 14658, 1, NULL, 'ace', '{{explanation}}

C faces C round the room



1–::

  Both W advance | curtsey and retire ; both M advance | bow and retire

9–::

  Circle4 and back

17–::

  R&L, finish in promhold

25–::

  Dance Lsh round opposite C, back along the line of dance, and Rsh half round next couple you meet and face them', 3);
INSERT INTO 'dancecrib' VALUES (3046, '2012-01-22 19:30:08.235973+00', '2022-11-20 14:29:45.249876+00', 5366, 1, NULL, 'ace', '1–::

  1c dance down the middle NHJ {3}, change sides (1W crosses above, under 1M''s L arm) {2}, dance up and behind 2c to 1plx

9–::

  Mirror Reels3 on opposite side, 2c starting out and up (1x,2,3)

17–::

  1W+2M & 1M+2W turn 1¼ easy hand ; 1c crosses down to between 3c and turn 3c 1¼ easy hand to (2,3,1)

25–::

  Circle6 and back.', 2);
INSERT INTO 'dancecrib' VALUES (13797, '2021-03-09 15:06:24.689419+00', '2021-03-09 16:26:16.007605+00', 5573, 1, 202, 'ace', '1--::

  1M+2M A&R ; 1W+2W A&R (1,2,3)

9--::

  1c »Mirror Fig8 on opposite sides« [: 1c cross down between 2c, out and behind 3c ; meet then up between 3c, out behind 2c to 1pl] (1,2,3)

17--::

  1c lead down ; and up to 1pl centre facing P. 2c step in ready for

25--::

  1c+2c Poussette (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3674, '2013-01-04 09:34:44.449703+00', '2019-02-04 13:34:57.427018+00', 5430, 1, NULL, 'ace', '1–::

  All four couples G-Chain  From here on follow the normal 3C/4L progression, only three couples dancing.

9–::

  1c set, touch hands and cast (2c up) ; 2c+3c set | 2c dance to 3pl as 3c cast up to 1pl (3,1,2)

17–::

  All A{1}&R{1} | repeat ; turn RH into Allemande hold (3,1,2)

25–::

  3C Allemande, 1c finish facing 1cnr (2,1,3)

33–::

  CPCP, 1c crossing LH to 2pl (1st time) or to 4pl (2nd time, 4c step up)', 3);
INSERT INTO 'dancecrib' VALUES (7834, '2013-08-21 08:31:49.536283+00', '2023-02-04 01:23:04.719348+00', 6932, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH & cast in 1 place, 1s & 4s dance 1/2 Figs of 8
    round end couples & end in line up/down middle holding hands (RH to
    partner)
9-12::
    2s facing down give nearer hand to 1M as 3s face up giving nearer
    hand to 4L & all set, 1s & 4s 1/2 turn partner RH _while_ 2s+3s set
13-16::
    2s facing down give nearer hand to 1L as 3s face up giving nearer
    hand to 4M & all set, 1s & 4s 1/2 turn partner RH _while_ 2s+3s set
17-24::
    1L followed by 4L cast up round 2M, cross down & cast round 3L
    _while_ 4M followed by 1M cast down round 3L, cross up & cast round
    2M for…
25-32::
    1s+4s dance 1/2 reel of 4 up/down middle (giving RSh to partner);
    4s+1s turn partners RH 1.1/4 times to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3056, '2012-01-22 19:30:08.631295+00', '2014-10-28 16:50:09.583735+00', 11722, 1, NULL, 'ace', '{{explanation}}

Couple face couple, at random throughout the room.



1–::

  NHJ with P advance to opposite couple | change to NHJ with opposite and retire sideways ; Turn opposite RH.

9–::

  NHJ with opposite advance towards P | change to NHJ with P and retire to place ; Turn P LH.

17–::

  L-Chain

25–::

  With P promenade at will, to face a new couple.', 2);
INSERT INTO 'dancecrib' VALUES (3070, '2012-01-22 19:30:09.253074+00', '2014-04-30 23:24:06.733842+00', 5450, 1, NULL, 'ace', '1–::
  1c+2c RHA {3}, LHA {5}, finishing (2,1x,3)
9–::
  2c+1c+3c BiL twice on both sidelines ; 1c turn BH (4 PdB) (2c down and meet on 15-16) for
17–::
  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (12781, '2020-04-28 06:34:08.689898+00', '2020-12-07 13:03:09.666186+00', 10412, 1, 202, 'ace', '1--::

  1c set | turn BH ; cast off (2c up) | all set (2,1,3)

9--::

  Reels3 across, 1c LSh to 1cnrs. 1c face 1cnrs

17--::

  ½ Reel4 on 1diag, pass LSh ; ½ Reel4 on 2diag (3x,1x,2x)

25--::

  1c cross RH | dance RSh round 1cnrs[pos] to between ends _while{4}_ 3c & 2c set | cross RH and face up/down ; 1c cross RH | dance RSh round 2cnrs[pos] to 2pl _while{4}_ 3c & 2c set | change places RH (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (2948, '2012-01-22 19:30:04.126368+00', '2021-04-29 20:50:03.372252+00', 5005, 1, NULL, 'ace', '1–::

  1c+2c set | cross RH ; repeat

9–::

  1c lead down the middle and up

17–::

  1c set | cast off (2c up) ; dance between 3c and cast up to face 1cnr

25–::

  CPCP (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3074, '2012-01-22 19:30:09.553381+00', '2021-01-17 18:32:28.199144+00', 12017, 1, NULL, 'ace', '1–::

  1c lead down, cross and cast up to 2plx _while_{4} 2c set & cross down to 3plx _while_{4} 3c cast up to 1pl & cross ; all C turn RH (3x,1x,2x)

9–::

  S&Link3 ; all M RHA and all W RHA, finish in lines across (1W+2c & 1M+3c)

17–::

  Rsh ½ Reels3 across (1c starts in and R) ; S&Link3 (2x,1,3x)

25–::

  Full diagonal R&L (3,1,2)



{{explanation}}

The progression is unusual.  The dance can be danced indefinitely in a 3c set.  In a 4c set, 3pl and 4pl must change places in the usual way after every 2nd turn.', 3);
INSERT INTO 'dancecrib' VALUES (3066, '2012-01-22 19:30:09.085633+00', '2017-02-14 16:27:08.679966+00', 11866, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; turn LH | cast L round 2cnr to finish 1W between 3c and 1M between 2c.

9–::

  1M+2c & 1W+3c Reels3 across, Rsh to 3cnr, at the end 1c turn LH to face 1cnr

17–::

  1c+1cnrs ½ diag Reel4, pass Rsh : ½ diag Reel4 with 2cnrs, pass Rsh to 2pl. (3x,1,2x)

25–::

  2c+1c+3c one pdb and six slip steps L halfway round ; 1c turn RH 1½ to (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (10274, '2017-11-28 00:36:24.959405+00', '2018-04-07 07:03:35.576846+00', 15122, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; 2c+1c+3c A&R (2,1,3)

9--::

  1c cast round 4cnrs into lines of 3 across ; All A&R

17--::

  Reels3 across, 1c Rsh to 1cnrs to start (2,1x,3)

25--::

  All set | 1c cross RH ; cast up (2c down) | 1c+2c advance into allemande hold

33--::

  1c+2c 6 bars of Allemande | 2c retire to 1pl _while{2}_ 1c cast to 3pl (3c up) (2,3,1)

41--::

  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (10273, '2017-11-26 00:32:05.827537+00', '2019-04-02 20:18:46.061134+00', 3690, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

  1c & 4c set | 1W followed by P casts behind 2W, dances in front of 3M, casts up and crosses to face 2M _while{6}_ 4W followed by P casts behind 3W, dances in front of 2M, casts down and crosses to face 3M (2c & 3 c step out on [7-8])

9--::

  1c+4c ½ Reel3 in tandem in 1 diag (with lead change), on [12], 1M+4W & 4M+1W turn LH ½, 1c (1W leading) facing up to 2W, 4c (4W leading) facing down to 3W ; repeat [13-16] in 2 diag (with lead change), 1c facing across to 2M, 4c facing across to 3M

17--::

  Repeat [9-16], on [24], 1M+4W & 4M+1W turn LH ½ to sidelines in Reel4 position (2,1x,4,3x)

25--::

  Parallel ½ Reels4 on sidelines, on [27-28] 1c+4c meet, turn BH (to 3x,1x,4,2) ; all set | cross RH (3,1,4x,2x)', 2);
INSERT INTO 'dancecrib' VALUES (11774, '2019-04-07 08:53:44.055087+00', '2019-04-29 11:57:10.124756+00', 10932, 2, 26003, 'ace', '1-4:: Face in joining hands set in circle, then link with corner.

5-8:: Rep back to original place.

9-12:: 1s & 3s 1/2 turn & twirl give right hand.

13-16:: 2s & 4s repeat. 3,4,2,1.

17-20:: 1s&2s face partner dance 1/2 diag reel of 4.

21-24:: 1&3 Repeat (always face partner to begin 1/2 reels)

25-28:: 1s&4s Repeat.

29-32:: ALL 4 couples turn partner both hands. (Finish 1 place clockwise round square 4123)', 0);
INSERT INTO 'dancecrib' VALUES (8910, '2015-09-19 19:58:32.275102+00', '2015-09-19 19:58:32.275102+00', 15710, 1, NULL, 'ace', '1--::  1c dance down | set advancing and passing, and face up (2c up) ; dance up and cast off to 2plx, and M faces out

9--::  2c+1c L-Chain, 1c finish BtoB on midline, M below W

17--::  1c dance out the end, cast L through 2plx ; turn LH 3/4 , dance out same end, cast R to 2pl _while_ on [19-20] 2c+3c A&R [1+1] touching RH (2,1,3)

25--::  1c+3c Bourrel (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (3083, '2012-01-22 19:30:10.503323+00', '2020-12-16 10:17:52.986618+00', 5495, 1, NULL, 'ace', '1-16::

  Special G-Chain, for each RH pass in {1}, for each LH 1½ turn in {3} (total 12 bars) ; 1c turn RH and face down *(variant: _while{4}_ 2c+3c also turn RH on the sideline)*

17–::

  1c dance between 3c and cast up (2c up) ; turn BH and open (W on R) to face 2W

25–::

  Set to 2W (& turn in to) set to 3M (& face L to) set to 3W (& turn in to) set to 2M and face up

33–::

  Mirror Reels3 on sides, 1c start up, 2c+3c cast to begin (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3073, '2012-01-22 19:30:09.512877+00', '2020-12-21 11:14:41.194047+00', 9513, 1, NULL, 'ace', '1–::

  All M, 1M leading, chase ½ clw _while{4}_ all W, 1W leading, chase ½ cclw inside them ; All set | cross RH (3,2,1)

9–::

  Repeat from new positions, 3M & 3W leading (1,2,3), 1c faces out

17–::

  1c cast behind own lines and dance up NHJ _while{8}_ 2c+3c step up twice, down twice, into

25–::

  1c+2c Poussette (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13798, '2021-03-09 16:52:49.237183+00', '2021-03-09 17:11:22.169441+00', 3738, 1, 202, 'ace', '1--::
  1c cast off | lead up ; cross and cast to 2plx (2c up) (2,1x,3)
9--::
  1c lead down between 3c ; cross and cast to face 1cnrs
17--::
  Set to and Turn Corners (2,1x,3)
25--::
  Reels3 on sides, 1c LSh to 1cnrs | 1c cross RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2975, '2012-01-22 19:30:05.256677+00', '2021-03-27 19:44:47.851539+00', 5118, 1, NULL, 'ace', '1–::

  1c starting inwards, Fig8 around 2c+3c

9–::

  G-Chain (1c cross)

17–::

  1c cross down RH (2c up) | cast below 3c ; cross LH | cast up to face 1cnr

25–::

  SetH&G (to 2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14182, '2021-08-05 08:05:32.18965+00', '2021-08-05 08:06:38.89859+00', 2836, 1, 202, 'ace', '1--::
  1c set | cast off (2c lead up) ; 2c+1c ½ DblFig8, 1c crossing up (2x,1x,3)
9--::
  1c+3c repeat [1-8]. 1c meet into promhold as 3c face out (2x,3x,1)
17--::
  ½ Reel3 across, 1c in promhold RSh to 3M ready for ; ½ Reel3 across, 1c in promhold LSh to 2W (2,1,3)
25--::
  Parallel Reels3 on sides, 1c up, 2c & 3c casting (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3725, '2013-04-11 22:39:38.744961+00', '2014-04-30 23:24:06.932152+00', 13466, 1, NULL, 'ace', '1–::
  1c ½ Fig8 round 2c (2c up on [1-2]) finish NHJ facing down ; 1M+2W+3W LHA _while_{4} 1W+2M+3M RHA
9–::
  1c in promhold +3c RshReel3 across (3c finish in 2pl)
17–::
  1c in promhold +4c RshReel3 across (4c finish in 3pl)
25–::
  1M+4W+5W LHA _while_{4} 1W+4M+5M RHA ; 1c split and cast up into ½ Fig8 round 5c (5c up on [31-32]) (2,3,4,5,1)', 2);
INSERT INTO 'dancecrib' VALUES (15091, '2022-09-08 10:13:42.15768+00', '2022-09-08 10:21:40.663174+00', 21094, 1, 202, 'ace', '1--::

  1c+2c cross RSh | chase clw ½ ; RHA (2,1,3)

9--::

  1c+3c cross LSh | chase cclw ½ ; LHA. 1c retain LH in 3pl centre (2,3,1)

17--::

  1c lead up LH to top | cross and cast off _while{4}_ 2c+3c set up/down | change place RH, 2c to 3pl ; all set | cross RH (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3619, '2012-07-21 11:46:04.032837+00', '2014-04-30 23:24:06.962772+00', 11286, 1, NULL, 'ace', '1–::
  Crossover Reels3 on the sides, 1c crossing down (1x,2,3)
9–::
  1c lead down the middle (2c up) and up to DTr position
17–::
  DTr, finish (2,1x,3)
25–::
  1c turn RH ; ½ Fig8 L (W up, M down) to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3082, '2012-01-22 19:30:10.463535+00', '2019-02-04 18:41:39.789702+00', 5493, 1, NULL, 'ace', '1–::

  1c dance BtoB ; set, cast off one (2c up)

9–::

  ½Reel3 across, Rsh to 2cnrs ; ½Reel3 across, Rsh to 1cnr (in 4cnr position)

17–::

  1c repeat bars 1-8 (3c up).

25–::

  1c repeat bars 9-16 with 3c & 4c.

33–::

  1c set, cast to 4pl. (4c up) ; All C turn RH', 2);
INSERT INTO 'dancecrib' VALUES (10480, '2018-03-03 20:18:32.242718+00', '2018-03-10 18:34:43.833492+00', 13355, 1, 202, 'ace', '1--::

  1c Fig8 down round 2c (1,2,3) 

9--::

  1c (leading) + 2c (start upwards) lead down ; 2c lead up, split, dance behind 3c and up to 1pl _while{4}_ 1c lead up to 2pl facing out (2,1,3)

17--::

  2c+3c R&L (no polite turns) _while{8}_ 1c Fig8 on sidelines, start Rsh to 3cnrs (2,1,3)

25--::

  Circle6 and back (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11772, '2019-04-06 23:02:29.402719+00', '2019-04-07 15:37:34.359918+00', 18251, 1, NULL, 'ace', '1--::

  1M advance | set to P ; dance Lsh ¾ round P to sideline | in promhold dance to 2pl and face down (2c up) (2,1m,3)

9--::

  1c set in promhold | set pivoting inwards ¾ into BtoB ; 1c cast up and dance down to centre (2,1m,3)

17--::

  2c+1c+3c Mirror Reels3{6} on the sides, 1c starts between 3c, and gives hands when possible | 1c dance down and 3c cast up into (2,3m,1m)

25--::

  3c+1c Poussette (2,1,3)   



*1c, newly wed, is encouraged to set advancing on [31-32], and dance the second time through from opposite sides.*

', 3);
INSERT INTO 'dancecrib' VALUES (12452, '2019-12-31 13:29:19.894915+00', '2019-12-31 13:51:51.788972+00', 17748, 1, NULL, 'ace', '

1-16::

  1c set | cast off (2c up) ; 2c+1c+3c R&L for 3C, 1c finish facing 1cnr

17--::

  1c+1cns ½ diag. Reel4, pass Rsh ; 1c+2cnrs ½ diag Reel4, finish (3x,1x,2x)

25--::

  All turn P RH ; chase clw to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3694, '2013-01-30 00:47:42.985761+00', '2014-05-30 15:45:00.841448+00', 5460, 1, NULL, 'ace', '1–::

  1c set | cast below 2c ; turn BH and dance to top facing out

9–::

  2c in promhold reel3 across (Rsh to 1W) with 1c who cast, 2c finish in 1pl facing out and 1c meet

17–::

  1c in promhold reel3 across (Rsh to 2W) with 2c who cast, finish (1,2) with 1c facing out

25–::

  1c cast off _while_{2} 2c turn BH ½, dance up NHJ and face out (2x,1) | repeat (1x,2x) ; repeat (2,1x) | 1c cross RH (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (8894, '2015-09-07 00:30:14.159952+00', '2015-09-21 02:06:18.015744+00', 16731, 2, NULL, 'ace', '1-8::

  1C set, set adv. to join RH;

  1C lead down the middle.

9-10::

  1C change places: 1L cross  under joined hands, 1M cross below 1L,

11-14::

  1C lead up the middle.

15-16::

  1C cast to 2pl opp. sides.

17-24::

  1L 3C also 1M2C dance RH Across;

  change ends , dance LH Across.

25-32::

  All adv&ret; 1C turn RH 1_1/2 to own sides.', 2);
INSERT INTO 'dancecrib' VALUES (3092, '2012-01-22 19:30:10.927549+00', '2015-07-07 11:32:46.571967+00', 5522, 1, NULL, 'ace', '1–::

  1c cross RH, cast off (2c up) ; 2c+1c RHA

9–::

  1c cross LH, cast off (3c up) ; 3c+1c LHA

17–::

  1c dance to top, cast off (own side), pass between 3c and cast up to 1cnr (3c down)

25–::

  Reel4 with 1cnrs, and dance Rsh round P to face 2cnr

33–::

  Reel4 with 2cnrs, end (2,1,3)

41–::

  All Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (3093, '2012-01-22 19:30:10.967698+00', '2016-06-07 21:59:01.634052+00', 5525, 1, NULL, 'ace', '1–::

  1c set | cast off two places (2c up) and lead up to 1cnrs

9–::

  1c set to 1cnr | turn 1cnr RH and join LH in the middle ; BiL | turn 1¼ LH to 2cnrs

17–::

  Repeat with 2cnrs | cross to (2,1,3)

25–::

  2c+1c+3c circle6 and back.', 3);
INSERT INTO 'dancecrib' VALUES (8242, '2014-04-14 21:31:58.057518+00', '2014-09-04 09:16:07.034083+00', 15421, 1, NULL, 'ace', '1–::

  1c cross into Snowball Chain (3,2x,1)

9–::

  Circle6 L {3}, pivot L by crossing R foot over L and chase back (3,2x,1)

17–::

  2W sets adv | 2c set, with 2W retiring and 2M advancing ; 2W cast up and cross , 2M following (3c down), to (2,3,1)

25–::

  RSh Reels3 on the sides (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3075, '2012-01-22 19:30:09.596545+00', '2020-12-26 02:20:43.465727+00', 11565, 1, NULL, 'ace', '1-6::

  1c+3c chase cclw half round (1M+3W cast to start) ; 2c+1c ½ LHA (3x,1,2x)

7-8::

  1c keeping LHJ turn ½ _while_ 2c dance out to sideline {1} and into middle {1} _while_ 3c step in on [8], all finish facing down in promhold  (3x,1x,2x)

9–::

  All take Allemande hold and dance down ; turn in as in Gay Gordons and dance up again (M on right), finish 3c+2c pn sidelines, 1c facing up in Allemande hold (3x,1x,2x)

17–::

  1c sets to 3c and turning as in Gay Gordons faces down | 1c sets to 2c, finish facing P ; 1c dances to own side in 4 PdB, 1W dancing under her own R arm as in Gay Gordons (3x,1,2x)

25–::

  3c+1c+2c diagonal R&L   

*On the second turn, 1M omits polite turn to start the chase, and 1c dances to 4pl at the end (4c up)*', 3);
INSERT INTO 'dancecrib' VALUES (13799, '2021-03-09 23:44:09.74023+00', '2021-03-11 16:11:26.25843+00', 20253, 1, 202, 'ace', '1--::
  All W (1W leading) chase cclw behind Mline back to places (1,2,3,4)
9--::
  All M (1M leading) chase clw behind Wline back to places (1,2,3,4)
17--::
  1c BHJ slip down ; and up (1,2,3,4)
25--::
  All couples BHJ (4c leading) slip down ; 2c+3c+4c slip up under arch made by 1c (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (2956, '2012-01-22 19:30:04.462639+00', '2021-04-29 09:43:30.444067+00', 5034, 1, NULL, 'ace', '1–::

  1c slip down the middle and up

9–::

  2c repeat, finish in 2pl NHJ facing up

17–::

  1c+2c turn EH 1½ in sideline (2c starts up the middle) ; 1c dance BtoB (2,1)

25–::

  2c+1c RHA ; LHA', 3);
INSERT INTO 'dancecrib' VALUES (14450, '2021-11-15 16:46:30.957077+00', '2021-11-15 16:46:30.957077+00', 20558, 2, 963, 'ace', '1-4::  
  1M, flwd by 1W, cast to 3rd plc (2s&3s up 3/4)
5-8::  
  3C & 1C dance LHA
9-12::  
  1M, flwd by 1W, dances up around 3W to 2nd plc (3s dwn 11/12)
13-16::  
  2C & 1C dance RHA - to end all 3C facing up in prom hold (3C dance in on 16)
17-24::  
  2C,1C,3C dance 3C allemande  3,1,2
25-28::  
  3C,1C,2C circle 6 hands round halfway 2x,1x,3x
29-32::  
  2C,1C,3C set and cross LH to own sides

  Note:  3C set variation - 25 - 32 circle 6 hands round and back 3,1,2', 5);
INSERT INTO 'dancecrib' VALUES (3831, '2013-07-13 15:56:17.985926+00', '2021-03-27 18:24:15.763777+00', 14674, 1, NULL, 'ace', '1–::

  1c long cast behind own side ; and back

9–::

  1c+2c R&L

17–::

  1c set | cast off  (2c up) ; 1c+3c RHA

', 3);
INSERT INTO 'dancecrib' VALUES (8049, '2013-09-23 23:02:57.028031+00', '2022-08-16 20:42:40.06898+00', 14818, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; ½ Fig8 up round 2c (2,1,3)

9–::

  2c+1W & 1M+3c RHA ; Lsh Snake Pass (unwind the RHA, 1c leading, pass other snake Lsh through 2plx and chase cclw) (3,1,2)

17–::

  3c+1M & 1W+2c LHA ; Rsh Snake Pass (unwind the LHA, 1c leading, pass other snake Rsh through 2plx and chase clw) (2,1,3)

25–::

  circle6 L, pivot L ; chase cclw to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14179, '2021-08-04 02:09:06.392011+00', '2021-08-04 08:51:19.146475+00', 20416, 1, 202, 'ace', '*3c & 4c start on opposite sides*
1--::
  1c & 4c ½ Fig8 round nearest couple (to 1x,2,3x,4) ; 1c & 4c dance to centre into promhold, pass each other RSh, 1c to Mside middle facing up, 4c to Wside middle facing down
9--::
  ½ Reels on sides, 1c RSh to 2M, 4c RSh to 3M. 1c+4c passing RSh change sides ; ½ Reels3 on opposite sides, 1c RSh to 2W, 4c RSh to 3W. 1c in 3pl centre & 4c in 2pl centre face out (2,4x,1,3x)
17--::
  All set to nearest cnrs | change places with nearest cnrs, 1W & 4W RH, 1M & 4M LH (to 4x,2,3x,1) ; repeat [17-20] to sides, using opposite hands (2,4x,1,3x)
25--::
  1c dance down, cross and cast to 3plx _while{4}_ 4x dance up, cross and cast to 2pl (to 2,4,1x,3x) ; 2c+4c & 1c+3c Circle4 L (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (14044, '2021-05-27 17:31:26.026844+00', '2021-05-31 00:28:41.473488+00', 20345, 1, 202, 'ace', '1--::
  1c+2c Set&Rotate (2,1,3)
9--::
  2c+1c RHA ; 1c+3c LHA. 1c face up (2,1,3)
17--::
  Parallel Reels3 on sides, 1c RSh to 2c. 2c & 3c loop to places (2,1,3)
25--::
  All A&R ; all dance BtoB (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (13201, '2020-09-18 23:17:57.795063+00', '2020-12-07 13:04:39.827729+00', 10407, 1, 202, 'ace', '1--::

  1c turn 2c RH on sides ; dance BtoB on sides (1,2)

9--::

  1c & 2c turn P RH ; dance BtoB (1,2)

17--::

  2c (1c following) lead down ; 1c (2c following) lead up all remaining in centre (1,2)

25--::

  1c cast off _while_ 2c dance up to 1pl | 1c ½ Fig8 up round 2c | 1c cross RH (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (3085, '2012-01-22 19:30:10.592729+00', '2017-07-07 12:36:31.744052+00', 5497, 1, NULL, 'ace', '1–::

  1c set and cast off one ; set and cast back

9–::

  1M cast off (1W follows) behind 2M, between 2c, behind 2W and cross to finish below 2M/2W

17–::

  1W cast up (1M follows) behind 2W, between 2c, behind 2M and cross to finish 1c in own places

25–::

  1c+2M Reel3 on M sideline (1M & 2M begin Lsh, 1W entering below them ; 1M+2M end in exchanged places, 1W in own place

33–::

  1c+2W Reel3 on W sideline (1W & 2W begin Rsh, 1M entering below them, finish (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (10414, '2018-02-04 23:00:43.838517+00', '2018-02-04 23:25:50.832102+00', 16686, 1, NULL, 'ace', '1--::

  All A&R ; 1c+4c cast to middle and join NH | set advancing to P and (turning inwards) face out, BtoB with P   _while{4}_ 2c cross up LH  and 3c cross down RH | 2c+3c set (2x,1,4,3x)

9--::

  1c NHJ with 4c dance out | cast round own end to between end couple ; change places (1c makes arch) | Turn other end cpl EH ¾ to (2x,4,1,3x)  

17--::

  Circle8 ½ ; 1c+4c ½ Fig8 round end cpl (3,1,4,2)

25--::

  All turn P RH ; All set twice (no hands) (3,1,4,2)

', 3);
INSERT INTO 'dancecrib' VALUES (9902, '2017-06-02 15:21:54.641483+00', '2017-06-03 13:44:16.900412+00', 17580, 1, NULL, 'ace', '1--::

  1c cross down (2c up) into DTr pos | 6 bars of DTr, and face own side

9--::

  1c cast Rsh round 3cnr to midline | set pivoting clw ½ ; cast Rsh round 2cnr to 2plx | set adv with Turn BH ½ and twirl R to face 3cnr _while{8}_ 2c+3c set adv bringing L shoulders close & hands joined high (“Maypole”) | LHA (in Maypole) | petronella to own cnr and face diagonally in

17--::

  1c+3cnrs ½ diag. Reel4, 1c pass Lsh (2cnrs set and pivot clw twice) ; repeat with 4cnrs (1cnrs setting), 1c finish in middle LHJ facing opp. side

25--::

  1c turn LH 1½ _while{4}_ cnrs chase clw ½ ; 1c petronella to 2pl and all set (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3098, '2012-01-22 19:30:11.18346+00', '2021-01-24 12:53:30.796662+00', 11402, 1, NULL, 'ace', '1–::

  1c ½ Fig8 round 2c ; cross LH below 2c (2c up) | cast L (1M down, 1W up) to between end couples

9–::

  1c ½ Petronella to finish 1M between 2c and 1W between 3c

17–::

  Reels3{6} across (Lsh to 2cnr) | 1c turn RH ¾ to 2pl

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (3090, '2012-01-22 19:30:10.840377+00', '2018-08-06 16:55:09.923816+00', 5520, 1, NULL, 'ace', '1–::

  1M+2W Turn BH, to places ; 1c Turn BH

9–::

  1W sets twice to 2M ; 1c turn BH

17–::

  1M+2W change places RH ; 1W+2M repeat (2x,1x)

25–::

  2c+1c Ret {1}, Adv {1} | cross RH ; 1c dance to top and cast to 2pl (2,1)', 5);
INSERT INTO 'dancecrib' VALUES (3095, '2012-01-22 19:30:11.05686+00', '2015-04-26 22:29:36.798626+00', 8088, 1, NULL, 'ace', '1–::

  1c cross RH, cast off (2c up) ; ½ Fig8 L (Rsh to 4cnr) (2,1,3)

9–::

  Reels3 on own sides, Lsh to 3cnr, 1c finishing on 1diagonal RHJ and LHJ with 3cnrs, (2c & 3c loop into places)

17–::

  »The Spoke«: (8 PdB) 1c BiL with cnrs {1}, move ¼ turn clw {1}, repeat 3 times _while{8}_ corners either BiL or set diagonally

25–::

  2c+1c+3c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (3106, '2012-01-22 19:30:11.534348+00', '2015-02-14 14:18:27.126931+00', 5555, 1, NULL, 'ace', '1–::

  1c cross down into Mirror Reels3 on opposite sides with 2c+3c (1x,2,3)

9–::

  1c ½ Fig8 round 2c ; 1c (BHJ) slip down to between 3c | set (top foot starting) (2c+3c up, 4c step in)

17–::

  1c+4c Poussette (2,3,4,1)

25–::

  2c+3c & 4c+1c RHA ; all C turn LH (3M polite L turn into next repetition).', 3);
INSERT INTO 'dancecrib' VALUES (3099, '2012-01-22 19:30:11.22321+00', '2014-04-30 23:24:07.347948+00', 5532, 1, NULL, 'ace', '{{explanation}}
start couple facing couple, as in Foursome Reel

1–::
  W enter the centre and set
9–::
  W turn LH to face opposite M
17–::
  All set
25–::
  All turn, finishing M in centre
33-64::
  Repeat, finishing W in centre', 2);
INSERT INTO 'dancecrib' VALUES (9903, '2017-06-03 23:04:27.932983+00', '2017-06-03 23:04:27.932983+00', 11194, 1, NULL, 'ace', '1--::

  1c+2c R&L

9--::

  1c+2c RHA ; 1W+2W chase clw half round to exchanged places

17--::

  1c+2c LHA ; 1M+2M chase cclw half round to exchanged places (2,1)

25--::

  2c+1c turn P LH ; clap 3 times (shout "LEFT") passing opposite LSh to face next cpl. ', 1);
INSERT INTO 'dancecrib' VALUES (3107, '2012-01-22 19:30:11.613308+00', '2021-01-03 13:54:50.131061+00', 13274, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; 1c dance Rsh round 4th corner to (2,1,3)

9–::

  2c+1W & 1M+3c RHA ; all chase clw half round (3x,1x,2x)

17–::

  Circle6 and back

25–::

  3c+1W & 1M+2c LHA ; all chase cclw half round to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3100, '2012-01-22 19:30:11.265737+00', '2020-09-18 08:09:06.411178+00', 13467, 1, NULL, 'ace', '1–::

  1c+2c+3c Rsh Reels3 on own side, at end 1W faces out

9–::

  1W with 1M following cast off to 3plx (2c+3c up) ; 1c turn 3c RH ½ on sideline | 1c turn 2c LH ½ on sideline (1x,2,3), 1W faces out

17–::

  1c+2c+3c Parallel Lsh Reels3 (on opposite side), at end 1W faces out

25–::

  1W with 1M following cast off to 3pl (2c+3c up) ; 1c turn 4c RH 1½ on sideline (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (3122, '2012-01-22 19:30:12.248736+00', '2020-09-26 07:05:27.13801+00', 14075, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; cross Rsh | 1c turn 2c on side EH ¾ and 1c take promhold

9–::

  ½ Reel3 on W side, 1c Rsh to 3W ; repeat on M side, Rsh to 2M, 1c finish between 3c

17–::

  1c lead down LH, cross out through 2pl and cast to 3plx _while{4}_ 3c+2c cross RH and set ; 1c cross LH and cast up _while{2}_ 2c+3c change RH on sides | All set (2x,1x,3x)

25–::

  All A&R ; All turn P RH 1½ (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13364, '2020-11-02 01:22:23.737262+00', '2023-02-04 01:23:10.931527+00', 20099, 3, NULL, 'ace', '1-8::
    1s set, dance in & cast to 2nd place, set advancing to face 1st
    corners (2s step up bars 5-6)
9-12::
    1s dance Corner Pass & RSh turn (no hands) with 1st corners, pass
    RSh to face 2nd corners
13-16::
    1s dance Corner Pass & RSh turn with 2nd corners to finish in 2nd
    place opposite sides with 1L facing up, 1M facing down 2 (1) 3
17-24::
    1s dance LSh reels of 3 on opposite sides (LSh to 1st corners)
25-32::
    1s dance Fig of 8 on own sides starting by giving RSh to 4th Corners
    (1L crosses up, 1M crosses down to start)', 0);
INSERT INTO 'dancecrib' VALUES (3101, '2012-01-22 19:30:11.306482+00', '2020-12-16 10:22:36.231893+00', 5543, 1, NULL, 'ace', '1–::

  1M followed by 2M Fig8 round 2W (Rsh) and 1W, to finish in exchanged places

9–::

  1W+2W set twice (1M+2M stand still) ; 1c+2c circle4 to face partners diagonally

17–::

  1c+2c advance | retire ; advance again | 2c retire _while{2}_ 1c turn ¾ RH to finish on 2diag for

25–::

  1c+2c Lsh Reel4, at end 1W+2W turn LH to finish (2,1).', 3);
INSERT INTO 'dancecrib' VALUES (14049, '2021-05-28 00:24:46.172221+00', '2021-05-28 00:24:59.960855+00', 14347, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c in and down (1,2,3)

9--::

  1c+2c turn EH 1½ on sides ; 1c+3c turn EH 1¾ on sides into DTr position

17--::

  DTr (2,1,3)

25--::

  Circle6 and back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3091, '2012-01-22 19:30:10.880104+00', '2021-03-27 19:39:41.138452+00', 5521, 1, NULL, 'ace', '1–::

  Reels3 on own side, 1c starting in, 2c out and up (1,2,3)

9–::

  1c+2c double Fig8, to start 1c cross down

17–::

  1c cross RH | cast off  (2c up) ; cross RH | set (2,1,3)

25–::

  Mirror Reels3 on own sides, 1c start out and up, and finish with loop into 2pl to flow into next movement



{{explanation}}

Note: at end of second turn, 1c cast to 4pl as 4c enters reel from 4pl', 3);
INSERT INTO 'dancecrib' VALUES (3117, '2012-01-22 19:30:11.999724+00', '2021-01-09 21:31:16.239837+00', 12742, 1, NULL, 'ace', '1–::

  1c set |cast (2c up) ; ½ Fig8 round 2c (2,1x,3)

9–::

  Reels3 across, 1c Lsh to 1cnr

17–::

  1c lead down ; change sides, 1M dances below 1W who turns under his arm, and lead up to 2pl in promhold

25–::

  1c+2cnrs diag ½ Rsh Reel3 ; 1c+1cnrs diag ½ Lsh Reel3 to finish (3x,1,2x)

33–::

  Diagonal R&L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3096, '2012-01-22 19:30:11.098773+00', '2017-03-19 11:32:27.540538+00', 8956, 1, NULL, 'ace', '{{explanation}}

3c+4c cross on 2nd chord (1,2,3x,4x)



1–::

  1c+4c cross RH and cast to centre (2c+3c step to ends) ; 1c+4c set twice, hand joined in circle, at end pivot R to face corners

9–::

  2c+3c full diag. Reels4 giving LH in the centre _while{8}_ 1c+4c ½ reel4 round cnr, pass Lsh in centre | repeat round next cnr cclw, and face »third« cnr (1c faces 3c, 2c faces 4c)

17–::

  Turn cnr RH | 1c+4c ½ LHA ; turn new cnr RH | 1c & 4c change places on side LH (2,4,1x,3x)

25–::

  Parallel Reels4 on the side', 3);
INSERT INTO 'dancecrib' VALUES (3102, '2012-01-22 19:30:11.345677+00', '2019-03-06 11:17:58.826595+00', 8575, 1, NULL, 'ace', '1–::

  1M+4W advance to P | 1c+4c set ; 1W+4M advance as P retire | 1c+4c set and take promhold, facing centre M on own side

9–::

  1c with 2M+3M & 4c with 2W+3W Rsh Reels 3, finish in square set (cclw 1M+1W, 2W+3W, 4W+4M, 3M+2M)

17–::

  All set NHJ per pair | all Petronella in tandem one pl cclw ; repeat

25–::

  Circle8 and back, finish longwise (4x,3x,2x,1x)

33–::

  4c+3c & 2c+1c ½ R&L (no polite turns) ; 4c+1c cross RH | ½ RHA (3,1,4,2)', 3);
INSERT INTO 'dancecrib' VALUES (9997, '2017-07-09 22:34:30.614369+00', '2017-07-09 22:39:26.604286+00', 5907, 1, 202, 'ace', '1--::

 1M+2W cross passing Rsh | cast Lsh round P ; cross passing Rsh | cast R round person on own side to places

9--::

 1c+2c R&L

17--::

 1W+2M cross passing Lsh | cast Rsh round P ; cross passing Lsh | cast L round person on own side to places

25--::

 1c+2c Knot (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (10816, '2018-06-03 19:31:49.963214+00', '2020-11-15 12:15:35.517602+00', 18369, 1, 202, 'ace', '1--::

  1c NHJ set advancing | 1M+2c LHA _while{4}_ 1W+3c RHA to places | all set, On [8], all W face out

9--::

  2 bars of Schiehallion Reel | all turn facing person RH ; all W LHA to next place _while{2}_ all M chase one place clw | all turn facing person RH, all W in centre facing out (2W facing 1M, 3W facing 2M, 1W facing 3M)

17--::

  All W 2 bars of SetH&G to between M | all M set on R foot, set pivoting on L foot to finish in centre facing person as on [16] ; All M 2 bars of SetH&G to between W | all set NHJ (2,3,1)

25--::

  Circle6 and back (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3114, '2012-01-22 19:30:11.874189+00', '2015-02-14 14:28:52.216831+00', 14076, 1, NULL, 'ace', '{{explanation}}

2c start on opposite side (1,2x,3)



1–::

  2c cross RH | cast to the R ; ½ Lsh Reels3 across

9–::

  2c cross RH up/dn | cast R ; ½ Lsh Reels3 on the sides (3x,2,1x)

17–::

  8 bars of R&L for 3 couples

25–::

  All turn new partner RH ; All chase clw ½ round.



{{explanation}}

All dancers have moved two places clw around the 3c set, finishing 3M, 3W, 2M on M side, and 2W, 1M, 1W on W side.  The new pairs become the new couples (1,2x,3).', 3);
INSERT INTO 'dancecrib' VALUES (3110, '2012-01-22 19:30:11.707303+00', '2021-01-10 21:20:44.741764+00', 12693, 1, NULL, 'ace', '1–::

  1c cross | cast off two (2c+3c up) ; 2c+1c advance on diagonal and retire up/dn, finish in the centre

9–::

  2c+1c R&L up/dn, on [15-16] 1c cast up (3c down) and 2c finish facing out (2,1,3)

17–::

  Reels3 on the sides, 1c start in and up, finish facing 2cnr

25–::

  Set to 2cnr | Set to 1cnr swiveling R ; dance to 2pl | All set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3112, '2012-01-22 19:30:11.789494+00', '2020-12-24 18:00:41.929214+00', 10774, 1, NULL, 'ace', '1–::

  1c Turn BH | dance NHJ into middle ; 1M+2c LHA _while{4}_ 1W+4c RHA

9–::

  2c+1c+4c in promhold Rsh Reel3 across.

17–::

  1c dance out between 3c, divide and cast back to middle ; Turn RH | 1W /1M dance out between 4c / 2c and cast to original place.

25–::

  G-Chain, one step per hand.



{{explanation}}

Repeat with 2c, 3c, 4c leading.', 3);
INSERT INTO 'dancecrib' VALUES (3664, '2012-12-13 22:43:35.718974+00', '2014-04-30 23:24:12.619101+00', 14606, 1, NULL, 'ace', '1–::
  1c set | cast (2c up) ; ½ Fig8 round 2c (2,1x,3)
9–::
  1c set | cast up (2c down) ; ½ Fig8 round 2c
17–::
  1c lead down the middle (2c up) and up to 2pl (2,1,3)
25–::
  All Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (3116, '2012-01-22 19:30:11.95775+00', '2021-02-20 21:00:05.070816+00', 9760, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; Teapots R (1c RHA with couple on R), 1c face 1cnr

9–::

  SetH&G , finish BtoB facing M up, W down

17–::

  Reels3 across, Rsh to 2cnr, finish passing Rsh to face 1cnr, the corners dancing a final loop

25–::

  Turn CPCP (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3115, '2012-01-22 19:30:11.915913+00', '2021-04-24 09:22:45.266192+00', 5591, 1, NULL, 'ace', '1–::

  1M+2W change places RH ; 1W+2M repeat (2x,1x)

9–::

  2c+1c A&R ; ½ R&L

17–::

  1c down the middle and up

25–::

  1c+2c Poussette (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (13800, '2021-03-10 00:53:24.289604+00', '2021-04-27 20:29:31.219989+00', 12388, 1, 202, 'ace', '1--::

  1M+2W dance RSh round P ; meet in centre and turn RH 1½ back to places (1,2)

9--::

  1W+2M dance LSh round P ; meet in centre and turn LH 1½ back to places (1,2)

17--::

  1c long cast dancing behind own lines ; and back to 1pl (1,2)

25--::

  *The Diddle* : 1M & 2W set | cross to P''s place _while{4}_ 1W+2M set advancing diagonally, meet and turn RH to face P on 2diag ; 1M & 2W dance a ½ Reel4 on 2diag to exchanged places _while{4}_ 1W & 2M dance RSh round P to next place clw own sides (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (3113, '2012-01-22 19:30:11.832248+00', '2021-04-24 09:25:31.28239+00', 5581, 1, NULL, 'ace', '1–::

  1c+2c circle4 and back

9–::

  L-Chain, end in promhold

17–::

  All Promenade (passing Lsh) around two C''s and back to place

25–::

  1c+2c LHA ; turn person opposite RH 1½ and move on to meet next couple', 2);
INSERT INTO 'dancecrib' VALUES (14047, '2021-05-27 23:20:39.946105+00', '2021-08-24 18:39:49.521518+00', 19120, 1, 202, 'ace', '1--::
  1c Fig8 down round 2c _while{8}_ 2c set | cross RH ; repeat [1-4] (1,2,3)
9--::
  1c cross RH | cast off (2c up) and meet ; dance down and cast to 2plx (2,1x,3)
17--::
  1c Fig8 down round 3c _while{8}_ 3c set | cross RH ; repeat [17-20] (2,1x,3)
25--::
  Mirror Reels3 on sides, 1c in and up. On [29-30] 1c cross down to 3pl and continue the reel on own sides (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (3833, '2013-07-13 15:56:18.251264+00', '2022-01-29 17:08:35.146438+00', 14673, 1, NULL, 'ace', '1–::

  1c+2c+3c Mirror Reels3 on own side, 2c starts out and up, finish for

9–::

  1c+2c Half Rondel (1c dance under 2c arch, both cross W in front to (2x,1x) ; Set and cross (2,1)), but 1c finish facing own side for

17–::

  DTr, at end 1c finish facing down NHJ

25–::

  1c dance between 3c, cast up and meet ; dance between 2c and cast to (2,1,3)



{{explanation}}

Note: at end of 2nd turn, 1c cast to 4pl and 4c step up', 3);
INSERT INTO 'dancecrib' VALUES (14706, '2022-03-17 08:52:09.777518+00', '2022-03-17 08:54:56.035915+00', 1339, 1, 202, 'ace', '1--::

  1c+2c set | turn P BH opening to face down NHJ ; 2c (1c following) dance down between 3c | cast up (2,1,3)

9--::

  All cross P RH | 2M+1W & 1M+3W cross RH ; all cross opposite person RH | 2W+3W & 2M+3M cross RH

17--::

  All cross opposite person RH | 1W+3M & 2W+1M cross RH (to 3x,1x,2x) ; all set | turn P RH ½ into Allemande hold (3,1,2)

25--::

  3C Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14275, '2021-09-07 12:06:31.736029+00', '2023-02-14 07:50:29.529396+00', 9136, 2, 3069, 'ace', '1-3:: 1C turn RH
4-6:: 1C cast off one place, 	2nd couple step up on 5 & 6.
6-8:: 1C turn LH, finish LSh to LSh facing opposite sides.
9-12:: 1W+2C and 1M+3C RH across. 1C pass RSh
13-16:: 1W+3C & 1M+2C dance LH across.
17-24:: 1+2+3 C, Reels of Three on the side. 1+3M & 1+2W pass RSh. 2+3C cast into place at the end.
25-32:: 1+2C Poussette.', 3);
INSERT INTO 'dancecrib' VALUES (8235, '2014-04-03 10:25:24.024779+00', '2014-11-12 17:13:07.670088+00', 15412, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c RHA ; chase clw ½ (4x,3x,2x,1x)

9–::

  4c+3c & 2c+1c R&L, finish middles facing ends

17–::

  Parallel reels4 on the sides (4x,3x,2x,1x)

25–::

  4c+3c & 2c+1c LHA ; all chase cclw to places (1,2,3,4)

33–::

  1c+2c ½ LHA | 1c+3c ½ RHA ; 1c+4c LHA | All cross RH, retain RH for next RHA', 3);
INSERT INTO 'dancecrib' VALUES (3111, '2012-01-22 19:30:11.747317+00', '2019-02-07 21:06:17.758698+00', 10013, 1, NULL, 'ace', '1–::

  1c lead down and cast up into 4pl (2c+3c+4c up) ; All cpls turn RH ½ | LH ½ (2,3,4,1)

9–::

  2c+3c & 4c+1c LHA ; RHA

17–::

  2c+3c & 4c+1c Petronella in tandem | repeat 3 times, to places

25–::

  Circle8 and back (2,3,4,1)



', 3);
INSERT INTO 'dancecrib' VALUES (3124, '2012-01-22 19:30:12.328361+00', '2018-02-13 18:33:33.500825+00', 5621, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; cross RH, 1c casts R round 3cnr to finish in line across between 2cnr and 3cnr

9–::

  Circle6 and back

17–::

  1c change places up/dn RH | Fig8 round 4cnr and 1cnr, start Rsh), finish on sideline facing 2cnr

25–::

  1c Reels3{6} on opposite sides (Rsh to 2cnr) | cross RH', 2);
INSERT INTO 'dancecrib' VALUES (3123, '2012-01-22 19:30:12.2886+00', '2019-03-11 11:23:57.409912+00', 5618, 1, NULL, 'ace', '1–::

  All set, 1c+2c & 3c+4c ½ RHA ; all ½ circle8 L  (3,4,1,2)

9–::

  All set, 3c+4c & 1c+2c ½ LHA ; all ½ circle8 R  (1,2,3,4)

17–::

  1c dance down to 4pl (2c+3c+4c up) and curl to face up, 3c face up and 2c+4c face down ; all C set H.Schottische on the sidelines (2,3,4,1)

25–::

  Reels4 on the sidelines (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10277, '2017-11-28 14:18:54.064708+00', '2018-10-31 12:17:14.849051+00', 15116, 1, 202, 'ace', '1--::

  1M set | 1c set ; 1M dances Lsh round P to finish in promhold with 1W on 1M''s L

9--::

  1c+2c Reel3 across, 1c Rsh to 2M to start, 2c ending in 1pl

17--::

  2W+1W+3W LHA _while{4}_ 2M+1M+3M RHA ; 1c dance out between 2c & 3c and cast down to 4pl (3c+4c up) (2,3,4,1)

25--::

  2c+3c & 4c+1c R&L', 4);
INSERT INTO 'dancecrib' VALUES (12456, '2020-01-01 02:07:05.873746+00', '2020-01-01 03:54:11.210687+00', 13559, 1, NULL, 'ace', '*Start (1,2,3x,4x)*

1--::

  1c+2c & 3c+4c RHA, end 1c facing 2c and 3c facing 4c ; set to and pass opposite RH and face again (2,1,4x,3x)

9--::

  Reels4 on the sides, at end 4c+1c don''t pass but finish BtoB, (2,4x,1,3x) middles facing ends

17--::

  All set | 4c+1c petronella to form a line across (1M,4W,1W,4M, middles facing ends) ; 1c+4c set | turn opposite RH till "outer" faces out with the "inner" behind.  _Meanwhile{6}_ 2c+3c link (no hands) ; set facing down/up NHJ | link again, to sidelines.

25--::

  1M+4W following & 4M+1W following cast R, round 1M/4W positions and in the ends to (2,4,1x,3x) ; 4c+1c Circle4 L

', 3);
INSERT INTO 'dancecrib' VALUES (3623, '2012-07-21 11:46:06.127944+00', '2014-04-30 23:24:07.856337+00', 11288, 1, NULL, 'ace', '1–::
  1c set | cast off (2c up) ; 1c pass Rsh, curve R to face P, and twirl R to face out (2,1x,3)
9–::
  Reels3 across, Rsh to 1cnr, finish facing 1cnr
17–::
  Turn 1cnr RH | pass Rsh ; turn 2cnr RH | turn P RH ½ as 2c+3c dance in and all face up
25–::
  2c+1c+3c Promenade', 3);
INSERT INTO 'dancecrib' VALUES (13668, '2021-02-19 01:14:24.379146+00', '2021-02-19 01:16:24.24229+00', 15553, 1, 202, 'ace', '1--::

  1c (1W leading) Fig8 on Mside, LSh to 3M into 2 lines3 across facing down, 1W between 3c

9--::

  All dance down ; and up

17--::

  Parallel Reels3 across, 1c RSh to 2W-or-3W {6} (2c to 1pl) | 1c turn BH opening to face down _while_ 3c dance in and face up NHJ

25--::

  1c+3c The Rondel ', 2);
INSERT INTO 'dancecrib' VALUES (3128, '2012-01-22 19:30:12.513915+00', '2016-01-22 08:04:39.703175+00', 11919, 1, NULL, 'ace', '1–::

 2c followed by 1c lead down, cross below 3c, cast up ; 1c turn LH to face 1cnr as 2c cross (no hands) to 1pl on [5-6]

9–::

  SetH&G , finish in middle, M above W

17–::

  Teapots R, Teapots L, finish 1M behind 1W, facing up

25–::

  1c dance up, cast off on opposite side ; ½ Fig8 up (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9905, '2017-06-04 23:46:19.672742+00', '2019-01-24 13:30:35.329342+00', 1471, 1, 202, 'ace', '1--::

 1c cross RH | set ; 1c+2c+3c cross RH | all set (1,2x,3x)

9--::

 1c+2c RHA finish 1c facing 2c _while{4}_ 3c turn RH ; 1c+2c dance BtoB on sidelines _while{4}_ 3c dance BtoB, 1c facing 2c again (1,2x,3x)

17--::

 1c+2c Petronella into line of 4 across, W BtoB | set ; Petronella | set (2x,1,3x)

25--::

 Mirror Reels3 on the sides, 1c start in and up, 2c & 3c crossing to own sides from 2plx to 3pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3679, '2013-01-10 16:35:41.537013+00', '2021-02-23 18:05:36.261054+00', 13613, 1, NULL, 'ace', '1–::

  1c cross down RH to 2plx (2c up) | 2c+1c set ; 1c cross down LH (3c up) | 3c+1c set (2,3,1)

9–::

  Mirror Reels3 on sides (2c&1c start with a cast, 3c in and down), giving hands  on [11-12] 1c cross up LH to opposite reel, 2c finish with loops and 1x face out (to 2,3,1x)

17–::

  1c cast up one as 3c dance down and loop into 3pl | 1c turn RH ½ and twirl to own side | cast R round 3cnr to between end cpls

25–::

  1c meet and turn 1W under joined R arms _while_{2} 2c+3c turn RH ½ and all face down in the middle | continue as The Knot (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (3120, '2012-01-22 19:30:12.124411+00', '2020-12-17 22:02:42.315563+00', 5612, 1, NULL, 'ace', '1–::

  2c+3c RHA ; 1M+2M+3M & 2W+3W+4W ½Reels3 on own sides (1M+2M and 3W+4W begin Lsh)

9–::

  2M+1M+4W+3W (in middle places) LHA ; 2M+1M+4M and 1W+4W+3W ½Reels3 on own sides (1M+4M and 1W+4W begin Rsh) (to order 3,4,1,2)

17–::

  3c+2c chase clw half way round _while{4}_ 1c+4c half R&L ; 2c+1c & 4c+3c half R&L (to 1,2,3,4)

25–::

  All C ½Reels4 on own sides ; 4c+3c+2c ½Reels3 on own side (3c+4c begin Rsh) (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (3121, '2012-01-22 19:30:12.192059+00', '2020-12-17 22:08:51.765249+00', 5616, 1, NULL, 'ace', '1–::

  1c+2c+3c Inveran Reels3, all cpls cross at top and bottom (1c cross down, 2c out and up, 3c cross up, passing behind 1c), at end dance on to (2,1,3,4)

9–::

  1c set, cast off (3c up) ; 2c+3c & 1c+4c Circle4 L

17–::

  1c set, cast off (4c up)  (2,3,4,1) ; 3c+1c turn P RH into promhold facing up _while{4}_ 2c+4c turn P RH 1½ into promhold facing down

25–::

  Reel4 for 4 couples, at the end the middle Cs pass Rsh, 2c&4c crossing to own side (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3129, '2012-01-22 19:30:12.552911+00', '2020-12-17 22:12:02.696767+00', 5628, 1, NULL, 'ace', '1–::

  1c set advancing | turn ¾ BH to 2pl on midline (2c up) ; 1c set up/dn | Turn LH 2pl facing out and L _while_ 2c+3c step in to face each other NHJ

9–::

  2c+3c set dn/up, turn person opposite BH ; set to P, form arch NHJ and dance out to end places with loop _while{8}_ 1c chase ¾ round cclw to midline 1M in 1pl and 1W in 3pl {6} and dance under arch and pass Lsh

17–::

  Reels3 across, Lsh to 1cnr, finish facing 1cnr

25–::

  Corner, P, corner, P', 2);
INSERT INTO 'dancecrib' VALUES (3127, '2012-01-22 19:30:12.474715+00', '2021-04-22 20:44:26.327918+00', 5624, 1, NULL, 'ace', '1–::

  1c followed by 2c lead down ; 2c+1c ½ R&L inside the set

9–::

  1c (leading)+2c lead up to (1x,2x,3) ; 1c+2c ½ R&L, 1c to face 1cnr (1W no polite turn)

17–::

  SetH&G , with petronella to (2,1,3)

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (9995, '2017-07-09 21:12:14.518856+00', '2017-07-09 23:32:53.568947+00', 17886, 1, NULL, 'ace', '1--::

  All set | cross RH ; set | cross RH

9--::

  1c lead down and up (1,2,3)

17--::

  1c+2c Allemande (2,1,3) 

25--::

  Circle 6 and back (2,1,3)

::

  *on second time, 1c dances from 2pl and 1c+3c dance the Allemande. Finish (2,3,1).  Repeat all twice (6 x 32 in all)*', 3);
INSERT INTO 'dancecrib' VALUES (14183, '2021-08-05 09:54:59.01503+00', '2021-08-05 09:57:03.558774+00', 1051, 1, 202, 'ace', '1--::

  1c cast off (2c up) | turn P RH ; cast off, meet and lead up to 2pl facing up and out (2,1,3)

9--::

  ½ Parallel Reels3 on sides, 2c crossing down (to 3,1,2x) ; 1c+2c ½ DblFig8, 2c crossing up (3,1x,2)

17--::

  ½ Parallel Reels3 on sides, 3c crossing down (to 2,1x,3x) ; 1c+3c ½ DblFig8, 3c crossing up (2,1,3)

25--::

  1c+2c turn EH on sides, RH on Mside, LH on Wside ; 1c+3c turn EH on sides (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9274, '2016-07-14 22:35:49.84001+00', '2016-09-30 14:39:46.073296+00', 12321, 1, NULL, 'ace', '1--::

  1c+2c set | RHA | 1c cast off as 2c dance up (2,1,3)

9--::

  Mirror Reels3 on the sides, 1c start in and down, 1c cross up from 2pl on [13-14] , finish (2,1x,3)

17--::

  All set | 1c petronella to midline as 2c+3c set ; All set in lines across | 1c petronella to (2,1,3)

25--::

  Circle6 and back



', 3);
INSERT INTO 'dancecrib' VALUES (9998, '2017-07-09 23:20:17.389703+00', '2017-07-10 10:42:47.50521+00', 6448, 1, 202, 'ace', '1--::
 1c set | cross RH ; cast (2c up) | turn LH to face 1cnrs
9--::
 Reel4 in 1diag, on [16] 1c turn LH to 2plx facing out (2,1x,3)
17--::
 1c Fig8 on opp side, 1c Lsh to 2cnr to start, on [24] 1c turn LH to face 4cnrs
25--::
 Reel4 in 2diag, on [32] 1c turn LH to 1M/1W between 3c/2c facing dn/up
33--::
 Reels3 across, 1c Lsh to 1cnr to start (2,1,3)
41--::
 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2817, '2012-01-22 19:29:58.620297+00', '2017-09-30 01:14:51.800083+00', 4512, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; 2c+1W & 1M+3c LHA (2,1x,3,4)

9–::

  1c cross RH | cast to 3pl (3c up) ; 3c+1M & 1W+4c LHA (2,3,1,4)

17–::

  1c set | lead up to top & cast to 4pl (4c up) (2,3,4,1)

25–::

  2c+3c & 4c+1c reels4 across, to (2,3,4,1)

33–::

  All set twice & turn P RH', 2);
INSERT INTO 'dancecrib' VALUES (10415, '2018-02-04 23:30:02.367103+00', '2018-02-04 23:52:17.380952+00', 16680, 1, NULL, 'ace', '1--::

  1c cross down to face opp. side in DTr pos. (2c up) | 6 bars of DTr 

9--::

  1c dance out own side, cast L round 4 cnr and turn P LH to face 1cnr _while{8}_ 2c+3c dance into centre, pull Rsh back and dance out ; chase clw ½  

17--::

  1c+1cnrs ½ diag Reel4 and pass Rsh ; 1c+2cnrs ½ diag Reel4 and 1c pass Rsh to (2,1,3)

25--::

  All A&R and clap ; All turn P RH [or birl]', 3);
INSERT INTO 'dancecrib' VALUES (3148, '2012-01-22 19:30:13.395427+00', '2020-01-07 08:20:40.55538+00', 5723, 1, NULL, 'ace', '1–::

  1M Fig8 round 2W and 1W, (start Rsh to 2W), on [1-4] 2W sets swiveling right about on the spot ; on [5-8] 1W sets swiveling left about.

9–::

  1M+2W lead down the middle ; and up to 1pl (on [15] 1W dances down to 2pl)

17–::

  1M+2W & 2M+1W Allemande.

25–::

  1M+2W turn RH, finish in 2pl ; 1M+1W turn LH, finishing in 2pl (2W up) (2,1).', 3);
INSERT INTO 'dancecrib' VALUES (8171, '2014-02-07 15:58:10.348975+00', '2014-04-30 23:24:08.156997+00', 5697, 1, NULL, 'ace', '1–::
  1c set | change places RH ; 1c+2c set | change places RH (1,2x,3)
9–::
  1c+2c+3c set | change places RH ; All set advancing | turn P BH ½ to (1,2x,3)
17–::
  Gr-Chain (1c cross to start)
25–::
  2c+1c ½ R&L ; 1c turn RH 1½  (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3143, '2012-01-22 19:30:13.162662+00', '2014-04-30 23:24:08.186857+00', 5702, 1, NULL, 'ace', '1–::
  1c lead down the middle and up
9–::
  1c set, half turn BH ; 1M+2W & 1W+2M RH turn to 2c in 1pl and 1c in 2pl opposite sides
17–::
  2c+1c R&L
25–::
  2c+1c half L-Chain ; 1c+2c turn P RH to original positions
33–::
  1c+2c circle4 and back
41–::
  1c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (3835, '2013-07-13 15:56:18.759429+00', '2017-11-11 13:21:49.935883+00', 14342, 1, NULL, 'ace', '{{explanation}}

Couples facing clw are 1c; couples facing cclw are 2c



1–::

  All W dance Rsh round M opposite ; All birl /spin with opposite

9–::

  All M dance Rsh round P ; All birl /spin with P, ending facing partner, 1c with BHJ

17–::

  1c slip clw passing between 2c who slip cclw | All set, 2c moving in to join BH as 1c separates ; 2c slip clw passing between 1c who slip cclw | All set, finish NHJ with P

25–::

  All advance and retire ; All pass opposite Rsh and next person Lsh to face a new couple (having passed two couples).', 3);
INSERT INTO 'dancecrib' VALUES (15177, '2022-10-20 11:41:26.302093+00', '2022-10-20 11:44:20.2215+00', 1400, 1, 1645, 'ace', '1-::

  1c & 4c &frac12; Fig8 round 2c/3c ; dance in to meet (2c & 3c to ends) |

  1c+4c set joining hands in circle _while{2}_ 2c & 3c set & face down/up

9-::

  1c & 4c petronella to next place to R in circle | set _while{4}_ 2c+3c change pl on sides | set ;

  1c & 4c repeat [9-12] _while{4}_ 3c & 2c cross RH | set

17-::

  4c & 1c lead out nearest end, cross & cast inwards _while{4}_ 3c+2c pass on sides | set ;

  all cross RH | set (2,4,1,3)

25-::

  Circle8 & back (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14274, '2021-09-07 11:48:16.072206+00', '2023-01-20 11:52:48.776514+00', 2922, 2, 3069, 'ace', '1-4:: 1C cross RH, cast off 1 place. 2C step up.

5-8:: 1C 1/2 figure of 8, finish facing 1st Corners.

	1W down round 3W, 1M up round 2M.

9-16	:: 1C + 1Cnr, Reel of 4 across, on last bar 1C pass LSh face 2Cnr

17-24:: 1C + 2Cnr, Reel of four across, 1+3Couple ready for poussette.

25-32:: 1+3C poussette.', 3);
INSERT INTO 'dancecrib' VALUES (3836, '2013-07-13 15:56:18.799944+00', '2014-11-02 21:49:47.867143+00', 14672, 1, NULL, 'ace', '1–::

  2c ½ Fig8 R (Lsh to 1cnr) to face 2cnr ; ½ Rsh Reel3 on side (3,2x,1)

9–::

  2c ½ Lsh Reels3 across (2W down, 2M up) ; 2c ½ Fig8 (Lsh to 1cnr pos) to (3x,2x,1x)

17–::

  3c+2c set | ½ RHA ; 1c ½ Fig8 round 3c (2,3,1)

25–::

  G-Chain (1c cross) (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3272, '2012-01-22 19:30:18.442031+00', '2020-05-15 13:41:59.953211+00', 6130, 1, NULL, 'ace', '{{explanation}}

8 couples, W on R, form square; two C to each side, all face in; »odd« C (1,3,5,7) on the R, »even« C (2,4,6,8) on the L.  

Part A



1–::

  All Circle16 and back

9–::

  Sides join NH into big star RHA once round with W 1,3,5,7 in the centre, finish »odd« Cs in inner square, »even« Cs outside them

17–::

  All set twice to P ; Turn P BH

24-40::

  Concentric G Chains, 2 bars/hand, the »inner square« with PdB, »outer square« with Sk-Change



{{explanation}}

Part B



1–::

  in centre 1W + 5W set twice ; Tulloch turn _while{8}_ the others Circle14 and back

9–::

  1W+5W set to and turn P ; 1W+6M & 5W+2M set and turn

17–::

  1W+1M+6M & 5W+5M+2M Opposing Reels3

25–::

  Repeat [1-8], using the other arm for the Tulloch turn

33–::

  1W+8M & 5W+4M (W with their corners) set and turn ; 1W+3M & 5W+7M set and turn

41–::

  1W+3M+8M & 5W+7M+4M Opposing Reels3, finish in own position



{{explanation}}

Repeat all part B with successively 2W+6W, 3W+7W, 4W+8W in centre.  For the first Tulloch turn, the »odd« C use R arm, the ''even« couples L arm.  

Repeat all part B with successively 1M+5M, 2M+6M, 3M+7M, 4M+8M in centre  

Repeat part A', 3);
INSERT INTO 'dancecrib' VALUES (14704, '2022-03-16 05:00:25.738808+00', '2022-03-17 09:26:08.716361+00', 11482, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

  1c+2c & 3c+4c 6 bars of Tourbillon. 2c & 4c NHJ face down _as_ 1c & 3c NHJ face up | all set (2x,1x,4,3)

9--::

  2c+1c & 4c+3c RHA ; LHA (2x,1x,4,3)

17--::

  1c & 4c NHJ dance out through ends and cast inwards ; 1c+4c ½ R&L (2x,4x,1,3)

25--::

  ½ Reels4 on sides ; all set twice (3,1,4x,2x)', 2);
INSERT INTO 'dancecrib' VALUES (3651, '2012-10-16 21:46:24.947731+00', '2021-03-27 18:57:54.124699+00', 14477, 1, NULL, 'ace', '1–::

  1c long cast (2c up) ; 2c+1W & 1M+3c RHA (2,1,3)

9–::

  2c+1M & 1W+3c LHA, at end 1c pass Rsh and swivel R to finish (2,1x,3) ; All set twice

17–::

  2c+1c L-Chain

25–::

  1c half Petronella (to 2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (13669, '2021-02-19 12:41:48.709066+00', '2021-02-19 17:23:04.902963+00', 10668, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; Petronella turn between ends | set turning on [8] to face 1cnrs

9--::

  Reels3 across, 1c RSh to 1cnrs (2,1x,3)

17--::

  2c+1M & 1W+3c RHA, pass RSh ; 2c+1W & 1M+3c LHA (2,1x,3)

25--::

  All A&R ; 1c turn P RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3142, '2012-01-22 19:30:13.122359+00', '2019-02-04 09:51:20.127082+00', 7296, 1, NULL, 'ace', '1–::

  1c+2c+3c set | cross RH ; set | ½ Circle L (3,2,1)

9–::

  2c+1c set | RHA | 1c dance up and face out as 2c casts off (3,1,2)

17–::

  Mirror Reels3{6} on the sides, 1c starts out and up | 3c pass 1c, 1c passing outside (1,3,2)

25–::

  3-couple knot (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (10416, '2018-02-05 00:02:17.110067+00', '2018-02-05 00:13:54.171012+00', 16679, 1, NULL, 'ace', '1--::

  1c cross RH | cast to 2plx (2c up) ; ½ Fig8 Rsh round 3cnr to face 1cnr

9--::

  ½ diag Reel4 with 1cnrs, pass Rsh ; ½ diag Reel4 with 2cnrs, pass Lsh to face 3cnr

17--::

  set to and turn 3cnr BH ; repeat with 4cnr (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)

33--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (13459, '2020-12-07 17:58:37.21752+00', '2020-12-07 18:00:30.728027+00', 20151, 1, 202, 'ace', '1--::

  1c & 2c turn P RH 1 ¾ to midline ; ½ Reel4

9--::

  2c & 1c turn P RH ¾ to sides | set ; 2c+1c turn RH on sides (2,1)

17--::

  Circle4 and back

25--::

  2c & 1c set advancing, pull RSh back then dance to places ; repeat [25-28] with LSh back (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (3162, '2012-01-22 19:30:13.951416+00', '2019-03-04 23:15:43.892082+00', 10798, 1, NULL, 'ace', '1–::

  1c+2c set | ½ RHA ; 1c+3c set | ½ LHA (2x,3x,1)

9–::

  1c set | dance to top ; cross and cast to 3plx, on [16] all step in for

17–::

  Inverted 3c Allemande (face down to start) (to 1x,3x,2x)

25–::

  All set R {1} and circle6 ½ L; All turn P RH (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3152, '2012-01-22 19:30:13.545631+00', '2014-04-30 23:24:08.333973+00', 5734, 1, NULL, 'ace', '1–::
  1c+2W RHA ; LHA, finish in line across facing down, 1W (on M side) +1M+2W, and 2M steps in to face the line
9–::
  All down the middle (2M dances backwards) ; and up, both W turning inwards to join 2M (1M dances backwards), finish 1c facing 2c in the middle, W on M''s right
17–::
  1c+2c L-Chain up/down, at end 1c make full turn, into
25–::
  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (3156, '2012-01-22 19:30:13.709377+00', '2014-06-01 03:26:34.568508+00', 5752, 1, NULL, 'ace', '1–::

  1c Fig8 round 2c (cross down)

9–::

  Mirror Reels3 on sides, 1c starts in and down, 1c+2c making extra loop into

17–::

  2c+1c+3c DTr

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (3157, '2012-01-22 19:30:13.749144+00', '2014-04-30 23:24:08.425526+00', 5754, 1, NULL, 'ace', '1–::
  1c set twice ; turn RH 1½ to (1x,2)
9–::
  1c sets twice to 2c ; turn LH 1½ on sideline to (2,1x)
17–::
  1W+2W change place RH | 1c+2c turn LH ½ (1M to 1W place, 2M to own place)  ; 1c turn RH ¾ and 2c turn RH 1¼ into position for
25–::
  1c+2c Poussette (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (3158, '2012-01-22 19:30:13.788634+00', '2014-04-30 23:24:08.440748+00', 5755, 1, NULL, 'ace', '1–::
  1c set | turn BH (2c dance up) ; dance down one place | turn BH to face 1cnr (1M helps 1W using RH)
9–::
  1c turn 1cnr RH finishing between end couples, facing P | 1c set to P advancing to face 2cnrs _while_{2} 2c+3c set facing diagonally ; 1c turn 2cnr RH and finish between corners | 1c set advancing to face 3cnr _while_{2} 2c+3c set as before
17–::
  1c+3cnrs ½Reel4, pass Lsh ; 1c+4cnrs ½Reel4, 1c pass P Lsh and dance out into
25–::
  3c+1c+2c chase clw ½ round ; 2c+1c+3c turn BH', 3);
INSERT INTO 'dancecrib' VALUES (3033, '2012-01-22 19:30:07.678778+00', '2020-12-15 19:32:13.35232+00', 5320, 1, NULL, 'ace', '1–::

  1c+2c circle4 L ; set, 1c cast off one _while{2}_ 2c dance up and face out

9–::

  Reels3 on own side (1c starts down and in), 1c ends facing 1cnrs

17–::

  1c change place RH with 1cnrs | 1c+1cnr set ; change back RH | 1c 1¼ turn LH to face 2cnrs

25–::

  1c+2cnrs repeat, to (2,1,3).', 2);
INSERT INTO 'dancecrib' VALUES (3153, '2012-01-22 19:30:13.584599+00', '2021-02-12 18:51:03.554614+00', 10066, 1, NULL, 'ace', '1–::

  All C set | turn BH ½ and face P in the centre ; All twirling R dance out to opposite side | and set (1x,2x,3x,4x)

9–::

  1c+2c & 3c+4c RHA ; 1M+2W & 3M+4W change places RH and face P | all turn P BH ½ and face P

17–::

  Parallel ½Reels4 on the sides ; 4M+3W & 2M+1W change places RH | All set to P (4,3,2,1)

25–::

  4c+3c+2c the Knot (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (9535, '2017-01-10 00:11:46.860378+00', '2017-01-10 00:18:46.644234+00', 17495, 1, NULL, 'ace', '1--::

  1c set | cast (2c up) ; turn BH 1¼ to face W side NHJ

9--::

  2c+1M & 1W+3c Mirror Reels3 across, 1c starts out between the W, 

17--::

  1c dance out between the W, cast away from each other and in through the ends, cross Rsh in the middle, out the end and cast R to (2,1,3)

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10000, '2017-07-10 00:28:34.835748+00', '2017-07-13 07:04:59.253933+00', 16907, 1, 202, 'ace', '1--::

 1c+2c+3c set | cross RH ; chase clw ½ (3,2,1)

9--::

 3c+2c+1c set | cross RH ; 2c+1c S&Link (3x,1x,2x)

17--::

 1c ½ Fig8 to L ; repeat to face 2cnr pos

25-36::

 Dance to Corners and Set

37-40::

 1c turn RH 1 ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3029, '2012-01-22 19:30:07.522808+00', '2021-02-20 20:53:58.460106+00', 9764, 1, NULL, 'ace', '1–::

  1c+3c turn RH (2c+4c up) & face down | lead down, cast behind 4c resp. 5c | dance up middle to 2pos/4pos BtoB for

9–::

  Double DTr, 1c+3c finish facing 4cnr

17–::

  2c+1W & 1M+4c+3W & 3M+5c Rsh Reels3/4/3 across, 1c+3c finish on midline facing own side, RHJ with P

25–::

  1c+3c ½ RH turn | BiL ; ½ RH turn | cast off to 3pl/5pl (4c+5c up) (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (3180, '2012-01-22 19:30:14.679085+00', '2021-01-30 10:58:45.825459+00', 11107, 1, NULL, 'ace', '1–::

  1c set adv | turn BH and face up ; cast (2c up) and petronella (W up, M down) into facing lines across

9–::

  All S&Link3 twice

17–::

  All Circle6 and back into lines across

25–::

  Opposing ½Reels3 across, Rsh to 1cnr ; 1c turn BH ¾ to 2pl | 3c+1c+2c set

33–::

  1c followed by 2c dance up between 3c & cast to (3,2,1) ; 2c followed by 3c dance down between 1c & cast up to (2 3 1)', 2);
INSERT INTO 'dancecrib' VALUES (3161, '2012-01-22 19:30:13.912481+00', '2021-04-02 22:00:12.300502+00', 11758, 1, NULL, 'ace', '1–::

  Circle8 and back

9–::

  All W RHA to places ; All M LHA, finish facing P who step L to form a cross of two straight lines

17-32::

  Intersecting Reels4{12}, with ½ LHA in the middle ; all set to P | turn RH ¾ to face cnr

33–::

  All turn cnr LH ; Turn P RH to original places, W facing out

41-56::

  Full Schiehallion Reel, to places

57-72::

  G-Chain (2 bars/hand), finish facing cclw in promhold

73–::

  All promenade once cclw, at end place W in centre', 3);
INSERT INTO 'dancecrib' VALUES (14180, '2021-08-04 10:06:17.359057+00', '2021-08-04 10:10:59.324658+00', 3543, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c ½ DblFig8, 1c & 3c cross down. All face as for Reel4 (to 1x,2x,3x,4x) ; all set | change places RH on sides. All face into Reel4 (2x,1x,4x,3x)

9--::

  Parallel Reels4. On [16] 1M+4M & 1W+4W turn RH ¼ into line4 across. 1c face down

17--::

  1c & 4c set | 1M+4M & 1W+4W turn RH ½ ; all set | 1M+4M & 1W+4W turn RH ¾ to sides (2x,4x,1x,3x)

25--::

  All set | cross RH and retain hands hold ; 2c+4c & 1c+3c RHA (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10133, '2017-09-15 18:57:26.724335+00', '2022-09-09 08:52:29.859932+00', 15120, 1, 202, 'ace', '1--::

 1c turn BH into facing down | 1c dance down between 3c (2c up) and cast up to 2pl | 1c turn BH ½ and face each other between 1cnrs

9--::

 1c pull back Rsh to dance ½ Reel4 in 1diag, turn BH ½ and face each other between 2cnrs ; 1c pull back Rsh to dance ½ Reel4 in 2diag to 2plx (3x,1x,2x)

17--::

 3c+1c+2c set | Petronella in tandem for 3 into lines across ; repeat [17-20] to sidelines (2,1,3)

25--::

 1c+3c set | turn P BH into 1diag ; 1c+3c ½ Poussette (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11007, '2018-08-17 13:21:23.794498+00', '2022-10-21 07:05:01.91938+00', 10872, 2, 160, 'ace', '1-8::  1C cross, cast 1 place; cross LH, cast 1 place.

9-16::  1C dance to the top  (NHJ), cast to 2nd place [3C down]; turn LH 3/4. End 1M btwn 2C - 1W btwn 3C facing up/down.

17-24::  LSh Reels3 across the dance. End facing 2nd corner.

25-32:: Diagonal Reel4 end in 2nd place on own sides.', 3);
INSERT INTO 'dancecrib' VALUES (10201, '2017-10-24 01:16:21.296852+00', '2021-04-12 06:19:55.48558+00', 18002, 1, 202, 'ace', '1--::
  1c+2c S&Link. 2W & 1M face out ; ½ Parallel Reels3 on sides, 1c LSh to 3c. 1c face 1cnrs[pos]
9--::
  ½ Reel4 on 1diag, 1c RSh to 1cnrs[pos]. On [11-12] 1c turn BH ½ facing P into 2diag ; ½ Reel4 on 2diag, 1c (pulling RSh back) RSh round 2cnrs[pos] to 2plx (2x,1x,3x)
17--::
  1c dance up between 2c | cast off _while{4}_ 2c & 3c set | cross RH, 2W & 3M looping to places ; 1c lead down LH between 3c, cross and cast up to 2pl _while{4}_ 2c & 3c set | change places LH on sides, 2M & 3W looping to places (3,1,2)
25--::
  All turn BH {3}, Circle6 L {5} (3,1,2)

*Deviser''s note* : On bars 25-32, the turn should be phrased over three bars. On [27] 1st couple dance out to the sides, 2nd couple keep hands closest to the top joined, 3rd couple keep hands closest to the bottom joined and all, moving clockwise, join hands in a circle.', 5);
INSERT INTO 'dancecrib' VALUES (3168, '2012-01-22 19:30:14.193561+00', '2014-04-30 23:24:08.599426+00', 9194, 1, NULL, 'ace', '1–::
  1c set | cast off (2c up) ; turn LH 1¼ to face 1cnr
9–::
  ½ diag Reel4 with 1cnrs, pass Lsh ; repeat with 2cnrs, 1c finish M above W for
17–::
  1c turn LH 1½ _while_{4} corners chase ½ clw ; 2c+1W & 1M+3c RHA (2,1,3)
25–::
  2c+1c R&L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3167, '2012-01-22 19:30:14.154117+00', '2014-05-14 15:06:24.837199+00', 13278, 1, NULL, 'ace', '1–::

  1c dance down the middle (2c up) ; and up to between 2c who face down

9–::

  1c+2c turn EH ¾ to sidelines | 1c (start inwards) turn 3c ; All A&R (2,1,3)

17–::

  All set | cross RH ; chase ½ round clw (3,1,2)

25–::

  All set | cross LH ; chase ½ round cclw (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3160, '2012-01-22 19:30:13.874615+00', '2014-05-30 14:28:13.436713+00', 5759, 1, NULL, 'ace', '1–::

  1c+2c+3c circle6 and back

9–::

  1c+2c set, ½ RHA ; 2c+1c+3c set | 2c+3c cross over RH (face out) _while_{2} 1c turn RH to face 2cnr

17–::

  Reels3{6} on sideline, Rsh to 2cnr | 1c turn RH ½ into promhold facing up in 1pl _while_{2} others loop and make pairs (2M+3W & 2W+3M) in promhold on sideline, facing in

25–::

  Rsh Reel3 across in promhold, to starting places

33–::

  1c + pair on W side (2W+3M) + pair on M side (2M+3W) Promenade, at the end 3M cast off one and 2M dance up one place into:

41–::

  1c+2c+3c 3-couple Poussette (to 2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3171, '2012-01-22 19:30:14.316604+00', '2017-12-11 08:14:08.146369+00', 10457, 1, NULL, 'ace', '1–::

  1c+2c »Revolve« (1W+2M turn ¾ RH to join NH with P, all facing clw | The line turns ¾ clw to put 1M in 2Mpl and 2W in 1Wpl | 1W+2M turn ¾ RH (to 2,1,3)

9–::

  2c+1c+3c turn RH ; 2c+3c set and cross RH _while_{4} 1c turn LH (& keep hands joined)

17–::

  1c continue ½ LH turn | cast L round 2cnr pos and in ; pass Lsh | dance Lsh round 1cnr pos.

25–::

  Reels3{6} on the sides, Rsh to 2cnr position | All cross RH', 2);
INSERT INTO 'dancecrib' VALUES (15447, '2023-02-16 17:58:41.946394+00', '2023-02-17 09:17:27.974812+00', 20819, 2, 963, 'ace', '1-4::  

  Set to partner and turn partner RH  

5-8::  

  All W touch LH in the middle then dance Rt Sh round their corner back to place

9-12::    

  Set to partner and turn partner LH  

13-16::   

  All M touch RH in the middle then dance Lt Sh round their corner back to place  

17-24::  

  All set and link with partners then set and link with next person to finish women one position cw and men one position ccw round the set  

25-32::  

  All circle six hands round and back with new partner ready to repeat with new partner from new positions 

 ', 2);
INSERT INTO 'dancecrib' VALUES (3173, '2012-01-22 19:30:14.411431+00', '2016-06-02 11:27:22.258702+00', 5794, 1, NULL, 'ace', '1–::

  1c cross down RH (2c up) to 2plx and BiL with cnrs ; 1c cast R into lines across | all set

9–::

  All Reels3 across,Rsh to 1cnr, finishing (2,1x,3)

17–::

  1c lead down | lead to the top ; cross and cast to (2,1,3)

25–::

  2c+1c R&L.



{{explanation}}

Note: [3-4] is NOT in DTr position.', 3);
INSERT INTO 'dancecrib' VALUES (3165, '2012-01-22 19:30:14.075208+00', '2019-03-06 18:50:26.746015+00', 8493, 1, NULL, 'ace', '1–::

  All circle8 and back

9–::

  All W RHA, then Lsh around partners back to place

17–::

  All M LHA, then Rsh around partners back to place, face out

25–::

  All a double L-Chain

33–::

  All set to P, turn RH ; set to corner, turn LH

41–::

  Interlocking Reels4 on the circle

49–::

  All dance double R&L, 2c+4c start RH with partners

57–::

  All W Fig8 around partners and corner (start Lsh to P)

65–::

  All M Fig8 around partners and corner (start Rsh to P)

73–::

  All Promenade anti-clw once round, hold RH for bow and curtsey', 2);
INSERT INTO 'dancecrib' VALUES (10279, '2017-11-28 23:05:32.423708+00', '2018-04-09 09:39:51.573794+00', 15110, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; ½ Fig8 round 3c (2,1x,3)

9--::

  S&Link3 twice (3x,1,2x)

17--::

  1c ½ Fig8 round 3c ; 3c+1c+2c ½ Mirror Reels3 on sidelines, 1c in and down to start (2x,1x,3x)

25--::

  2c cast to 3plx _while{2}_ 1c cross to 1pl & 3c cross to 2pl (to 1,3,2x) | repeat [25-26] from new positions (to 3x,2,1) ; repeat [25-26] from new positions (to 2x,1x,3x) | cross RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10417, '2018-02-06 00:09:36.931499+00', '2018-05-25 11:35:45.077931+00', 18237, 1, NULL, 'ace', '1-8::

  1M starts on [1], 2M on [3], 3M on [5]:  All pass P RSh | dance behind the W, cross below 3W and dance up own side line (all W clap on bar 1+3+5) (1,2,3)

9-16:: 

  W repeat Lsh (the M clap)  (1,2,3)

17-24::

  1c+2c R&L   (1,2,3)

25-32::

  1c slip down BHJ (2c+3c up) ; pivot outwards and slip up to 3pl (2,3,1)



', 3);
INSERT INTO 'dancecrib' VALUES (11776, '2019-04-07 22:43:47.677545+00', '2019-04-07 22:44:00.123277+00', 19260, 1, 1645, 'ace', '1-::

  1c+2c mirror S&Link, 1c casting (2,1,3) ; 1c turn 1&frac34; BH to face 1cnrs

9-::

  1c set to & turn 1cnrs ; repeat with 2cnrs, end facing 3cnrs

17-::

  1c &frac12; diag RSh reel4 with 3cnrs, pass RSh ; repeat with 4cnrs, end in centre facing up, 1M on R

25-::

  1c cross up | cast to 2pl _while{4}_ 2c+3c &frac12; R&L (2,1,3) ; 1c+3c mirror S&Link, 1c casting (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (3172, '2012-01-22 19:30:14.365832+00', '2021-03-21 20:00:01.155229+00', 8140, 1, NULL, 'ace', '1–::

  1c+2c DblFig8 (1c cross down, 2c dance up to begin) to finish 1c facing across, 2c facing down, 3c facing up

9–::

  1c+2c+3c G-Chain to finish 2c facing down

17–::

  2c+3c DblFig8 (2c cross down, 3c dance up to begin) to finish 2c facing up

25–::

  1c followed by 2c (who dance up), dance down the middle {4} and up (with 2c leading)

33–::

  2c+1c+3c circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (3624, '2012-07-21 11:46:08.184064+00', '2014-04-30 23:24:08.808916+00', 14518, 1, NULL, 'ace', '1–::
  1c set | dance down below 3c (2c up on [5-6]) and cast up to face 1cnr
9–::
  1c+1cnrs diag. ½ Reel4, pass Lsh ; 1c+2cnrs ½ Reel4, pass Lsh to face 3cnr
17–::
  CPCP, finish 1M facing up, 1W down
25–::
  ½ Reels3 across (1c Lsh to 3cnr pos.) ; ½ Reels3 on the sides (1c Rsh to 4cnr pos.) 2c+3c finish with loops (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3187, '2012-01-22 19:30:14.948163+00', '2019-03-06 18:05:08.380572+00', 8539, 1, NULL, 'ace', '1–::

  1c+3c advance _while_{2} 2c+4c step sideways away from P | 1c+3c exchange P and dance to between 2c and 4c facing out ; with NHJ BiL | all corner pairs turn EH to own places

9–::

  2c+4c with 1c+3c repeat

17–::

  All set to P | turn P RH and face corner ; All set to corner| turn RH to face cclw in promhold

25–::

  All Promenade once round cclw, the M returning to places.



{{explanation}}

The women have moved one place cclw. Repeat 3 times to original places.', 2);
INSERT INTO 'dancecrib' VALUES (15094, '2022-09-10 10:42:23.431991+00', '2022-09-13 12:32:01.877959+00', 8121, 2, 1, 'ace', '1–::

  All set to partners then corners ; 1M+2L & 3M+4L turn LH _while_ 1L+4M & 3L+2M turn RH

9–12::

  1L dances out through 4c then round 4L into 3M''s pl  

  _while_ 3L dances likewise out through 2c into 1M''s pl  

  _while_ 1M&3M dance clockwise round 4M/2M then in through 4c/2c to 3L/1L''s pl

13–16::

  1M&3M collect ptrs in prom hold and dance back to places round outside

  _while_ 2c+4c advance/retire

17–28::

  All dance 3/4 Schiehallion reel [L casting into reel]

29–32::

  All dance propelled pivot turn RH



Repeat with 2c&4c dancing 9–16.

   ', 3);
INSERT INTO 'dancecrib' VALUES (3188, '2012-01-22 19:30:14.988165+00', '2016-02-28 19:57:02.042979+00', 5829, 1, NULL, 'ace', '1–::

  1W (1M following) cast off 1 place, cross to M side, cast off 1 pl, cross to W side, cast off 1 pl, cross to below 4M place opposite side *(the meandering brook)*

9–::

  1c dance (NHJ) up under arch by 4c {2}, 1½ BH turn {4}, dance up under arch by 2c to own places {2} *(bridges and pools)*

17–::

  1c lead down the middle, as 2c+3c+4c dance up the sides and follow ; 4C casts from the top as the others lead up and cast, 1c casting too (1,2,3,4) *(inverting waterfalls on the tidal lower river).*

25–::

  1c+2c+3c+4c dance BtoB ; 1M+2M & 1W+2W turn RH ½ {1}, 1M+3M & 1W+3W turn LH ½ {1}, 1M+4M & 1W+4W turn RH ½ {2} *(river meets the sea)*', 3);
INSERT INTO 'dancecrib' VALUES (3191, '2012-01-22 19:30:15.11533+00', '2014-04-30 23:24:08.992174+00', 10921, 1, NULL, 'ace', '1–::
  All Circle8 and back
9–::
  1c+3c ½ R&L ; 2c+4c ½ R&L and all face cnr
17–::
  Interlocking Reels4, Rsh to cnr (3,4,1,2)
25–::
  All Petronella in tandem 1place cclw ; set to P | turn P BH (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (3183, '2012-01-22 19:30:14.790185+00', '2017-04-26 22:24:49.40067+00', 9642, 1, NULL, 'ace', '1–::

  Mirror Reels3 on the sides, 1c cross down, 2c starts up, to (1x,2,3), 2c facing out

9–::

  1c turn 2c EH 1½ on sideline ; 1c dance between 3c and cast up to (2,1x,3)

17–::

  Mirror Reels3 on the sides, 1c cross up to start, 1c finish facing 1cnr

25–::

  1c set to 1cnr | turn RH to face 2cnr ; set to 2cnr | turn RH to (2,1,3)

33–::

  All Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (3193, '2012-01-22 19:30:15.195106+00', '2014-04-30 23:24:09.022389+00', 5847, 1, NULL, 'ace', '1–::
  1c+2c ½ RHA, finish in the middle ; 2c+1c ½Poussette{4} (to 1,2)
9–::
  1c lead down the middle and up
17–::
  1c+2c ½ RHA ; turn RH 1½

{{explanation}}
(The dance is currently (spring 2008) being considered for revision. The »half poussette« is »half a Poussette all round«.  TacNotes gives the 4 bar half Poussette as »away and turn, travel and turn | into centre, retire«. The Manual (more recent) says »couples end the half poussette with a full turn«; this requires very good technique.', 2);
INSERT INTO 'dancecrib' VALUES (3185, '2012-01-22 19:30:14.869574+00', '2015-01-30 22:39:58.8281+00', 5821, 1, NULL, 'ace', '1–::

  1W, followed by 2W,3W,4W chase cclw round all the M

9–::

  1M, followed by 2M,3M,4M chase clw round all the W

17–::

  1c down middle and up (can also be in slip step).

25–::

  All clap 3x | stamp foot 3x ; 1c cast to bottom (other Cs up)  (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (9271, '2016-07-14 16:51:45.712388+00', '2016-09-30 14:42:49.876478+00', 12321, 2, 160, 'ace', '1-8::

  1C with 2C set and dance right hands across once round. 1C cast off one place.

9-16::

  1C dance reflection reel of three on own side, but cross to opposite side on way to top, and cast into second place (2C and 3C dance out to begin reel).

17-20::

  All set in side lines, 1C petronella turn into centre, as corners set. (1C finish with 1M between 2C facing down and 1W between 3C facing up).

21-24::

  All set, three and three across the dance, 1C petronella turn to own sides.

25-32::

  2C, 1C and 3C circle left and back.', 0);
INSERT INTO 'dancecrib' VALUES (10001, '2017-07-10 18:35:47.610458+00', '2020-02-12 16:46:00.580316+00', 11183, 1, 202, 'ace', '1--::

 1c followed by 2c+3c+4c cast off to 4pl, as they meet dance in promhold up to places, 1c & 3c cast off one place _while_ 2c & 4c dance with a loop respectively to 1pl & 3pl (2,1,4,3)

9--::

 2c+1c & 4c+3c RHA ; LHA, 1c & 4c finish BtoB in centre facing cnrs diagonally

17--::

 Crossing double Reels4 (swift ½ LHA in the middle)

25--::

 1c & 4c still in centre turn their cnrs BH ; all turn P BH to sidelines (2,1,4,3)

33--::

 1c+4c+3c Knot (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11775, '2019-04-07 21:40:45.952997+00', '2020-04-19 00:00:46.506248+00', 19240, 1, NULL, 'ace', '1--::

  1c set advancing, passing Lsh and pivot R to face P | Turn BH and face down ; dance down (2c up) | Turn BH and finish backs to 1cnr

9--::

  "Corners chase and turn": 1c cross Rsh to 3cnr place, face in and set _while{4}_ 1cnrs pass Rsh, pivot R to turn BH and finish with backs to 3cnr ; repeat figure, 1cnrs go to own place and set as 1c finish with backs to 2cnr 

17--::

  Repeat with 2cnrs, 1c finishing (2,1,3) with 1c facing out 

25--::

  "3C Chain Progression": 1c cast ¼ clw round set _while{2}_ 2c & 3c Turn RH ¾ | 2M+3W turn 1½ LH _while{4}_ the others promenade ½ clw round set | 3c+2c turn RH ¾ _while{2}_ 1c chase ¼ clw to (3,1,2)







', 3);
INSERT INTO 'dancecrib' VALUES (14048, '2021-05-28 00:08:11.29966+00', '2021-05-28 00:11:42.001201+00', 12532, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 L round 4cnrs to 2pl centre BtoB facing own sides

9--::

  *Petronella DTr* : same as DTr except that 2c & 3c Petronella turn 1 place cclw when 1c change places. On [15-16] 1c pivot R to finish on midline 1W facing up, 1M facing down

17--::

  3c+1W & 1M+2c RHA (to 3x,1x,2x) ; all chase clw ½ (2,1,3)

25--::

  Circle6 and back (2,1,3)



*Deviser''s note* : 1st couple may choose to twirl right about on bar 16 and end left-shoulder to left

shoulder, woman above man, ready for the right hands across on bars 17-20.', 2);
INSERT INTO 'dancecrib' VALUES (12774, '2020-04-22 23:49:27.577367+00', '2020-04-22 23:56:43.803533+00', 19866, 1, 202, 'ace', '1--::

  1c cast to 3pl (2c+3c up) | set advancing into promhold facing 3W ; ½ Reel3 across, RSh to 3W. 3c loop to 3pl _as_ 1c NHJ in 2pl face up (2,*1*,3x)

9--::

  ½ Mirror Reels3 on sides, 1c out and up, 2c in and down. 1c in promhold, 1W on 1M''s L, face 3W ; ½ Reel3 across, RSh to 3W. 1c NHJ in 2pl face down (3,*1*,2)

17--::

  Mirror Reels3 on sides, 1c out and down, 2c in and up. 1c NHJ in 2pl face down (3,*1*,2)

25--::

  »The Serpentine« [: (middle C always starts inwards} 1c+2c change places EH | 3c+2c (other hand) repeat ; 3c (other hand) +1c repeat, 2c+1c+3c set]', 2);
INSERT INTO 'dancecrib' VALUES (10155, '2017-10-01 22:33:40.370759+00', '2020-06-27 20:42:00.798275+00', 17678, 2, 1645, 'ace', '1-::

  All set | all cast 1pl clw to (M side: 2M,3M,3W; W side: 1M,1W,2W) ; 1c+2M &amp; 3c+2W RHA

9-::

  All cross RH with opposite person | chase 1pl clw to (1x,2x,3x) ready for ; 2c+1cnrs, starting on the sides, &frac12; diag RSh Reel4, 2c end passing LSh to 4cnrs

17-::

  2c+4cnrs &frac12; diag Reel4 to (3,2,1) ; 2W+3c &amp; 2M+1c RHA

25-::

  3c+2c &frac12; poussette ; 3c+1c &frac12; poussette (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (14406, '2021-11-03 10:50:40.750809+00', '2021-11-04 10:41:55.506284+00', 20538, 2, NULL, 'ace', '1- 8:: 1s+2M reel of 3 across, 2M gives RSh to 1L to begin



9-16::  1s+2L reel of 3 across, 2L gives LSh to 1M to begin



17-24:: 1s+2s set, turn partner BH once round & circle left once round, finishing with 1s facing down & 2s      facing up, nearer hands joined with partner



25-32:: 1s+2s Rondel. 1s finish in 2nd place facing down ready for next turn of the dance.

', 5);
INSERT INTO 'dancecrib' VALUES (3186, '2012-01-22 19:30:14.908578+00', '2021-04-19 22:17:38.697645+00', 5824, 1, NULL, 'ace', '1–::

  All C A&R ; turn RH to face clw for:

9–::

  All chase clw once round

17–::

  1c+2c & 3c+4c RHA ; LHA, 1c&4c finish facing each other up/down NHJ

25–::

  1c+4c A&R ; dance to middle (2c+3c step out to ends) join RH with person opposite and face out and cross (2,4,1,3)

33–::

  4c (at top) & 1c (bottom) full Fig8 round end couple (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3197, '2012-01-22 19:30:15.319818+00', '2014-04-30 23:24:09.088593+00', 5860, 1, NULL, 'ace', '1–::
  1c cross to 2plx (no hands) (2c up) | 1c turn 3c easy hand, to meet between 3c ; 1c dance up NHJ opp. side | 1c turn 2c easy hand, 1c finish in 2plx facing down
9–::
  1c cross down into 2c+1c+3c mirror Reels3 on own sides, 1c finish in middle LHJ each facing own 1cnr
17–::
  1c set to 1cnrs, turning inwards to join RH | set to 3cnr, as these cnrs set advancing and join ; 1c+1cnrs RHA, finish 1cnrs in own places and 1c facing 2cnrs RHJ
25–::
  Repeat 17-24 with 2cnrs, interchanging »L« and »R« (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11777, '2019-04-08 21:43:03.117778+00', '2019-04-08 22:19:13.557435+00', 19269, 1, NULL, 'ace', '1--::

  1c pass P Lsh and 1M pivots L, into promhold in the middle facing 2M | Diag. Lsh Reel3{6} with 2M+3W; finish 2M in 1M place and 1c in 1W place facing out

9--::

  1c+2W+3M diag. Reel3, finish (2,1,3) 

17--::

  1c+3c Allemande (2,3,1)

25--::

  All Circle6 and back (2,3,1)



', 1);
INSERT INTO 'dancecrib' VALUES (14181, '2021-08-04 10:36:36.931351+00', '2021-08-04 10:37:38.297508+00', 6510, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; 1c+1W & 1M+3c RHA. 1c finish on midline LSh to P

9--::

  1c turn P LH | turn 1cnrs RH ; turn 2cnrs LH | turn P RH and face 2cnrs

17--::

  ½ Reel4 on 2diag. On [20] 1c turn P RH and face 1cnrs ; ½ Reel4 on 1diag. 1c face 4cnrs[pos]

25--::

  ½ Reels3 on sides, 1c RSh to 4cnrs[pos] (to 2x,1,3x) ; 1c dance LSh round 3cnrs[pos] to 2pl _while{4}_ 2c & 3c set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3620, '2012-07-21 11:46:04.352658+00', '2014-04-30 23:24:07.125199+00', 8075, 1, NULL, 'ace', '1–::
  All A&R ; All dance BtoB
9–::
  1c+2c R&L
17–::
  3c+4c RHA ; LHA
25–::
  1c cast to 4pl (2c+3c+4c up) ; 1c turn RH', 2);
INSERT INTO 'dancecrib' VALUES (3203, '2012-01-22 19:30:15.555278+00', '2017-07-07 14:11:52.766769+00', 5878, 1, NULL, 'ace', '1–::

  1c+2c set twice ; RHA (1,2,3)

9–::

  Repeat with LHA

17–::

  Parallel Rsh Reels3 on the sides

25–::

  1c cross | cast (2c up) ; ½ Fig8 down round 3c, finish BtoB facing own side for

33–::

  DTr

41–::

  1c (cross up) Fig8 round 2c (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3199, '2012-01-22 19:30:15.398462+00', '2018-07-17 10:29:40.678529+00', 8809, 1, NULL, 'ace', '1--::

  1c & 2c set R, set L advancing for | ½ Poussette | all set (2,1,3)

9--::

  3C Knot, 1c finish facing 1cnrs[pos]

17--::

  ½ Reel4 on 1diag, 1c pass Lsh ; ½ Reel4 on 2diag (2x,1x,3x)

25--::

  3C S&Link ; cnrs chase clw ½ _while{4}_ 1c turn BH 1¼ (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (3195, '2012-01-22 19:30:15.240263+00', '2016-11-15 16:07:37.826173+00', 5858, 1, NULL, 'ace', '1–::

  1c lead down, and up | cast to 2pl (2c up) (2,1,3)

9–::

  1c lead down, and up to 2pl | cast to 3pl (3c up) (2,3,1)

17–::

  All circle6 L, 1c finish in 3pl NHJ facing up ; 1c dance to top and cast off (3c down) (2,1,3)

25–::

  All turn P RH ; repeat LH', 3);
INSERT INTO 'dancecrib' VALUES (9536, '2017-01-10 02:11:09.445016+00', '2017-01-10 02:11:09.445016+00', 17488, 1, NULL, 'ace', ' 

1--::

  1c turn RH ½ moving down (2c up) and keep RHJ | set to P ; pull Rsh back and cast clw and in through the ends, finish (pull Rsh back) B to B on midline (W above M)

9--::

  Inverting triangles up/down: set as in DTr | All advance 2 steps and pivot R ; All set | All advance 2 steps and pivot R

17--::

  1c turn 1cnr LH | turn P RH ; turn 2cnr LH | turn P Rh to (2,1,3)

25--::

  Circle6 and back (2,1,3)

 

', 3);
INSERT INTO 'dancecrib' VALUES (3206, '2012-01-22 19:30:15.673855+00', '2017-03-22 10:58:18.496697+00', 7935, 1, NULL, 'ace', '1–::

  1c lead to the bottom and cast back to place

9–::

  4c cast up to the top and lead back to place

17–::

  2c+3c Circle4 and back

25–::

  1c+4c turn P RH ; repeat LH

33–::

  2c+3c Figs8 round nearest end cpl

41–::

  1c cross RH | cast ; cross LH and cast to bottom (2c+3c+4c up) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10281, '2017-11-29 13:11:34.381999+00', '2017-11-30 00:17:30.132365+00', 15109, 1, 202, 'ace', '1--::
  1c followed by 2c & 3c dance down ; all crossing over on [5], 3c followed by 2c & 1c dance up (3x,2x,1x)
9--::
  S&Link3 twice (1,2,3)
17--::
  1c set | cross RH ; cast (2c up) | 1c set advancing passing Lsh to finish BtoB facing own sides for
25--::
  2c+1c+3c DTr, on [31-32] 1c petronella turn into lines of 3 across, 1c facing 4cnrs
33--::
  Reels3{6}, 1c Rsh to 4cnrs to start (to 2,1x,3) | 1c cross RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10154, '2017-10-01 21:54:50.412446+00', '2017-10-03 23:30:54.39916+00', 17991, 1, NULL, 'ace', '1--::

  1c+4c turn RH ¾ to midline (2c+3c to ends) | 1c+4c ½ Reel4 on midline | All petronella 1 place R 

9--::

  2c+3c ½ Reel4 on midline ; All petronella 1place R | 4c+1c turn RH ¾ (3c+2c to middle) to (4x,3,2,1x) 

17--::

  All set | 4c+3c & 2c+1c ½ RHA ; 3c+2c turn RH 1½  (3,4,1,2)

25--::

  4c+1c Espagnole  (3,1,4,2)

', 4);
INSERT INTO 'dancecrib' VALUES (12958, '2020-07-12 16:48:28.725688+00', '2020-07-12 16:48:39.040746+00', 20047, 1, 1645, 'ace', '1-::

  1c & 5c turn RH | cast inwards (2c & 4c to ends) ; 1c+3c+5c &frac12; mirror Reels3, 3c starting up & out _while{4}_ 2c & 4c turn RH into promhold

9-::

  2c & 4c (promhold) Reels3 across with 5c & 1c, 2c & 4c end taking hands in circle with 3c, 5c/1c end in 1pl/5pl (5,2x,3,4,1)

17-::

  2c+3c+4c set in circle | two changes of Gr-Chain (1 bar/hand), 2c+3c change on sides & 4c cross to start ; 3M+4M, 3W+4W & 2c turn BH | &frac12; circle6 to L (5,2,4,3,1)

25-::

  All set | 5c+2c & 3c+1c &frac12; RHA _while_ 4c cross RH ; all set | all cross RH (2,5,4,1,3) 

::

  *Crib derived from the video*

', 2);
INSERT INTO 'dancecrib' VALUES (3205, '2012-01-22 19:30:15.633977+00', '2017-12-17 16:28:51.213518+00', 5885, 1, NULL, 'ace', '1–::

  1c Fig8 round 2c, giving hands

9–::

  All Mirror Reels3 on own side, 1c starts in, join hands on meeting P

17–::

  1c turn BH | 1c dance to 3pl NHJ _while{4}_ 2c+3c continue reel to top and follow behind 1c ; 3c+2c+1c set facing down | 1c cast to top, 2c+3c following to finish (1,2,3)

25–::

  1c+2c Tourbillon (1c+2c turn P BH ½, opening out to one place clw in the square (1c to W side, 2c to M side) | 1c set to 2c ; repeat figure (to 2x,1x) | 2c+1c cross RH) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3208, '2012-01-22 19:30:15.75211+00', '2014-05-21 12:26:05.074941+00', 14243, 1, NULL, 'ace', '1–::

  All Circle6 and back

9–::

  1c NHJ dance down | set ; dance up | cast to 2pl (2c up) facing 1cnr

17–::

  1c+1cnrs pass and turn ; 1c+2cnrs repeat, finish 1c facing out (2,1,3)

25–::

  Chaperoned Chain progression (2c+3c turn RH ¾ to midline _while_{2} 1c cast R ¼ round set | 2M+3W turn LH 1½  _while_{4}   1M+2W & 3M+1W in promhold dance ½ round set clw | 1c dance clw to 2pl  _while_{2}   3c+2c turn RH ¾)  (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (14611, '2022-02-17 00:11:16.783703+00', '2022-03-21 20:56:15.058899+00', 20666, 1, 1645, 'ace', '1-::
  1c+2c & 3c+4c S&Link ; 1c+4c S&Link (2,4,1,3)
9-::
  *Crescent circles:* All M, NHJ, &frac12; circle round to L across the top & back _while{8}_ all W &frac12; circle to R & back, W making a crescent in front of M
17-::
  2c+4c & 1c+3c RHA ; set facing diagonally in centre | pull RSh back & cast away to own sides
25-::
  All circle8 to L & back (2,4,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (3760, '2013-06-12 10:56:14.626069+00', '2014-04-30 23:24:10.060337+00', 6057, 1, NULL, 'ace', '1–::
  1c long cast to 3pl (2c+3c up) ; 2c repeat (3,1,2)
9–::
  3c+1c+2c The Knot, 1c face 1cnr
17–::
  1c set to 1cnr | dance round P Rsh ; set to 2cnr | dance round P to (2,1,3)
25–::
  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13801, '2021-03-10 09:34:34.329055+00', '2021-03-10 17:32:29.833707+00', 2681, 1, 202, 'ace', '1--::

  1c & 2c turn P RH ½ and stay in middle RHJ | RHA ½ ; turn P RH to sides. 1c face out, 1M up & 1W down (2,1,3)

9--::

  Reels3 on sides, 1c RSh to 3cnrs (2,1,3)

17--::

  All A&R ; 1c turn P BH (PdB) opening lower hands into BtoB facing 1cnrs

25--::

  ½ Reel4 on 1diag, pass P LSh ; ½ Reel4 on 2diag (3x,1x,2x)

33--::

  3c+2c changes places RH on sides _while{2}_ 1c Petronella turn into facing lines3 across | all set ; 2c & 3c cross RH _while{2}_ 1c Petronella turn to 1pl | all set (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3081, '2012-01-22 19:30:10.422904+00', '2014-11-09 23:48:23.765831+00', 10008, 1, NULL, 'ace', '1–::

  2c+3c+4c circle6 and back _while{8}_ on [5-8] 1c+5c turn RH

9–::

  1c+3c Fig8 down, cross down to start (1,2,3,4,5)

17–::

  1c with 2c & 3c with 4c turn EH 1½ on the sides (1c+3c start inwards) (2,1,4,3,5) ; 1c+3c cast off | cross up LH to face 1cnr

25–::

  1c & 3c ½Reels4 with 1cnrs, Pass Rsh ; repeat with 2cnrs

33–::

  Repeat with 3cnrs, finish with Rsh loop to 1W-1M-3W-3M on midline ; 1c+3c ½Reel4 on midline

41–::

  3c+1c turn RH 1¼ (5,3x,4,1x,2) ; 3c+1c ½ Fig8 across to the L (M down, W up) (3M+1W pass Rsh between 4c) (5,3,4,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (15448, '2023-02-17 09:10:57.35342+00', '2023-02-17 09:17:27.976063+00', 20819, 1, 202, 'ace', '1--::

  All set to P | turn P RH ; all W touch LH in centre then dance RSh round cnrs back to places

9--::

  All set to P | turn P LH ; all M touch RH in centre then dance LSh round cnrs back to places

17--::

  All S&Link with P ; repeat with next person. All have progressed one place (M cclw, W clw)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (14612, '2022-02-17 09:09:53.072887+00', '2022-02-17 17:51:52.206352+00', 20667, 1, 202, 'ace', '1--::

  1c cast behind own lines and back to 1pl _while{8}_ 3c lead up to top and down the middle to 3pl (1,2,3)

9--::

  1c+2c Espagnole (2,1,3)

17--::

  1c+3c Espagnole (2,3,1)

25--::

  Mirror Reels3 on sides, 1c in and up (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10156, '2017-10-02 08:02:21.991855+00', '2019-04-18 17:34:06.960044+00', 16126, 1, 202, 'ace', '1--::

 1c turn RH | cast (2c up) ; All set | All turn P LH ½ into Allemande hold facing down

9--::

 Inverted 3C Allemande (3x,1x,2x)

17--::

 All set | 1c turn LH ½ to middle facing up, cast round 3c to 3pl _while{4}_ 2c cross LH and cast to 2pl _while{2}_ 3c cross LH (3,2,1)

25--::

 Progressive (non-crossing) G-Chain: top C full turn RH _while{2}_ sides change RH | bottom C full turn LH _while{2}_ sides change LH ; repeat [25-28] (2,1,3)

33--::

 Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (3207, '2012-01-22 19:30:15.712744+00', '2020-02-10 15:41:29.433615+00', 5889, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1c+2c set, cross RH, set, cross back RH

17–::

  1c followed by 2c lead down the middle ; and up, 1c passing between 2c

25–::

  Allemande', 3);
INSERT INTO 'dancecrib' VALUES (14278, '2021-09-07 20:41:10.105878+00', '2021-09-07 20:43:16.733124+00', 20459, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; dance down between 3c | cast up to face 1cnrs

9--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag. 3c face down, 2c face up (3x,1x,2x)

17--::

  1c turn P RH ¾ | set _while{4}_ 3c+2c set | change places RH ; 1c turn P RH ¾ | set _while{4}_ 2c+3c set to P | cross RH (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3218, '2012-01-22 19:30:16.155394+00', '2015-06-06 06:45:02.119121+00', 11185, 1, NULL, 'ace', '1–::

  1c lead down the middle and up, facing out

9–::

  Reels3 on the sides (2c in & up), 1c crossing down into other reel on [11-12], 1c finish facing out (1x,2,3)

17–::

  1c cast off 2 (2c up) and dance up to DTr position facing opposite side ; All set and 1c face end couple on R (1M down, 1W up) | All set as DTr

25–::

  1W+2c & 1M+3c Rsh Reels3{6} across | 1c cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2275, '2012-01-22 19:29:29.205935+00', '2020-12-06 11:31:51.086179+00', 2321, 1, NULL, 'ace', '1–::

  1c & 2c Espagnole, 1c end facing 1cnr  (2,1,3)

9-20::

  Dance to Each Corner and Set (»Free« cnrs set _while{2}_ Centre couple change place Rsh with the cnrs, who then pass each other Rsh to face next cnr on R | repeat this five times (on alternating diagonals) to finish 1c facing 3cnr position)

21-24::

  1c+1cnr {3cnr pos} turn ¾ BH, opening up to face diagonally across the set with 1cnr on the R, and set _while{4}_ 2cnrs set diagonally and cross RH

25–::

  1c+1cnr A&R diagonally ; 1c+1cnrs ¾ RHA (to 2,1,3)



{{explanation}}

Espagnole: both W lead RHJ to M side, cross and cast back to exchanged places _while{4}_ Men cross to W side, lead RHJ back to M side and cross to exchanged places ; all turn P EH (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (3226, '2012-01-22 19:30:16.470815+00', '2015-02-18 21:38:17.538743+00', 10920, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; ½ Fig8 up (2,1,3,4)

9–::

  1c+3c RHA, LHA (2,1,3,4)

17–::

  Lsh opposing Reels3 across: (1W+3W behind dancing as one) with 2c and (3M+1M behind) with 4c (to 2,3,1,4)

25–::

  1c+4c ½ R&L ; turn RH 1½  (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (3412, '2012-01-22 19:30:24.331446+00', '2016-03-02 07:46:27.263197+00', 6671, 1, NULL, 'ace', '1–::

  All couples ½ Reels4 on sidelines ; 4c+3c & 2c+1c RHA

9–::

  Repeat back to (1,2,3,4)

17–::

  1c+2c+3c ½ circle6 L _while{4}_ 4c turn BH 1½ ; all dance two petronella turns to (3,2,1,4)

25–::

  3c+2c & 1c+4c the Knot (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2475, '2012-01-22 19:29:40.979777+00', '2020-12-07 21:38:46.188005+00', 3108, 1, NULL, 'ace', '1–::

  1c+2c ½ DblFig8 (to start, 1c cross down and 2c dance up, 2c finish facing out) ; 1c dance down NHJ between 3c and cast up to 2plx _while{4}_ 2c cast up and stand (2x,1x,3)

9–::

  1c+3c ½ DblFig8 (1c cross down and 3c dance up) ; 1c dance up NHJ between 2c and cast off to 2pl own side (2x,1,3x)

17–::

  1c Petronella {8} (to 2x,1x,3x)

25–::

  2c+3c Petronella {8} _while_ 1c casts Rsh back | cross (M / W between 3c /2c) ; cast to 2pl | set with 2c+3c (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3221, '2012-01-22 19:30:16.274224+00', '2021-01-08 00:01:19.036455+00', 5937, 1, NULL, 'ace', '1–::

  1c+2c R&L

9–::

  1c down the middle and up and face out (1,2,3)

17–::

  1c casts off one, cross RH ; cast off one, lead up on opp. side to finish between 2c in line across, both M facing down and W up

25–::

  1c+2c BiL | 1W+2M & 2W+1M turn LH ½ ; BiL | continue LH turns, 1c crossing down and 2c dancing up (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10261, '2017-11-15 05:31:12.233079+00', '2021-08-04 11:50:47.382799+00', 10977, 1, 202, 'ace', '1--::

  1c+2c+3c set | 2c followed by 1c dance down between 3c and cast up to (2,1,3)

9--::

  2c+1c+3c set | 1c followed by 3c dance up between 2c and cast off to (2,3,1)

17--::

  1c cross RH | cast up (3c down) ; 1c lead down LH, cross between 3c to 2pl (2,1,3)

25--::

  1M+2M turn LH while 1W+2W turn RH ; 1M+3M turn RH while 1W+3W turn LH



*Note. After 2nd time through: 1c+4c turn 1 ½ on [29-32]*', 2);
INSERT INTO 'dancecrib' VALUES (14330, '2021-09-19 22:44:57.530589+00', '2021-09-19 22:51:54.663877+00', 8535, 1, 202, 'ace', '1--::

  1c set | 1c (1W leading) cast off to 2plx (2c up on [5-6]) | 1c turn RH into promhold to face 3W

9--::

  ½ Reel3 on 1diag ; ½ Reel3 on 2diag. 1c in 2plx centre face down (3x,1x,2x)

17--::

  1c dance down between 2c | cast up to 2plx ; all turn P RH ½ into allemande hold

25--::

  3C Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3222, '2012-01-22 19:30:16.313602+00', '2021-03-14 23:32:46.128737+00', 8703, 1, NULL, 'ace', '1–::

  1c set, cast off two places (2c up) ; 1c, joining RH change sides (woman dancing below her P and under his R arm), retaining RH lead up to 2pl opposite sides of the dance (1M remains facing out)

9–::

  2c+1c L-Chain, 1c finish facing down

17–::

  2c+1c+3c G-Chain (2c cross over RH at the top, 2c+3c change places giving RH to begin the chain), 1c finish by dancing in to face their 1cnrs.

25–::

  1c set to 1cnr, set to each other across the dance ; set to 2cnrs and Petronella Turn into 2pl on own sides.', 2);
INSERT INTO 'dancecrib' VALUES (3832, '2013-07-13 15:56:18.224399+00', '2021-03-27 18:54:58.452271+00', 14551, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c RHA, LHA

9–::

  4c set | 3c set ; 2c set | 1c set

17–::

  All (4c leading) lead down the middle and (1c leading) lead up

25–::

  1c+2c ½ RHA | 1c+3c ½ LHA ; 1c+4c ½ RHA | All cross RH

33–::

  Circle8 and back (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (14825, '2022-05-09 23:31:54.104524+00', '2022-05-09 23:32:02.987054+00', 20810, 1, 1645, 'ace', '1--::

  1c, 2c & 3c turn P BH twice ; chase &frac12; way clw (3x,2x,1x)

9--::

  1c, 2c & 3c turn P BH twice ; chase &frac12; way clw (1,2,3)

17--::

  1c+2c set adv | turn P 1&frac14; BH into diagonal ; &frac12; Poussette, 1c pull RSh back to end BtoB in centre facing own sides

25--::

  1c Pass & Turn with 1cnrs, pass RSh ; Pass & Turn with 2cnrs ending on own sides (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14613, '2022-02-18 02:52:20.438226+00', '2022-02-18 02:53:06.986923+00', 19782, 1, 202, 'ace', '1--::

  1c & 3c set diagonally | RHA | set diagonally (1,2,3)

9--::

  2c Petronella turn | set ; cross RH up/down | dance LSh round 3cnrs to 2pl (1,2,3)

17--::

  1c lead down {3}, lead up {3} | cast off (2c up) (2,1,3)

25--::

  1c+3c The Tournée (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3230, '2012-01-22 19:30:16.627404+00', '2014-04-30 23:24:09.618387+00', 5964, 1, NULL, 'ace', '1–::
  1c ½ RH turn to finish between 2c, 2c+1c BiL ; drop RH and turn LH half round, 1c+2c BiL
9–::
  Repeat bars 5-8 ; 1c turn ¾ RH to places, curving into
17–::
  1c lead down the middle and up
25–::
  1c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (3235, '2012-01-22 19:30:16.823098+00', '2014-04-30 23:24:09.6938+00', 5982, 1, NULL, 'ace', '1–::
  1c cast off behind own lines and cast back
9–::
  1W+2M set and change places RH _while_{4} 1M+2W change places RH and set ; repeat
17–::
  1c lead down the middle | turn RH ; lead up and cast off to 2pl (2c up)
25–::
  2c+1c set | turn BH ; open into circle4 L.', 3);
INSERT INTO 'dancecrib' VALUES (14549, '2022-01-10 19:11:15.82893+00', '2022-01-13 16:10:33.05187+00', 20619, 1, 202, 'ace', '1--::
  All set | cross RH ; set | turn RH ½ into promhold facing up (1,2,3)
9--::
  3C Promenade (1,2,3)
17--::
  1c lead down ; and up to 1pl centre BHJ. On [24] 2c step in (1,2,3)
25--::
  1c+2c Poussette (2,1,3)

*Deviser''s note* : On the 2nd, 4th and 6th times through the dance it is recommended to dance a three couple poussette, with the bottom two couples stepping in on bar 24. ', 5);
INSERT INTO 'dancecrib' VALUES (10283, '2017-12-02 01:37:25.563647+00', '2018-04-10 12:23:47.704619+00', 15108, 1, 202, 'ace', '1--::

  1c+2c »The Roulette«: [Petronella turn into midline | turn BH ½ finishing NHJ 1c facing W side & 2c M side ; 1W+2M RHJ, all dance{1} round clw in a line 1 step, drop P''s hand, 1W+2M (inners) turn RH to finish 1W in 2Wpl and 2M in 1Mpl _while{3}_ 1M & 2W (outers) dance round clw to face P] (2,1,3,4)

9--::

  1c+3c »Chain&Turn«: [1M+3W turn RH ¾ into 2diag | 1M+3M & 1W+3W turn LH ½ ; 1W+3M turn RH 1 ¼] (2,3,1,4)

17--::

  1c+4c »The Revolve«: [1W+4M turn RH ¾ to join LH with P, 1c & 4c facing clw | The line turns ¾ clw to end with 1M in 4Mpl and 4W in 1Wpl | 1W+4M turn RH ¾] (2,3,4,1)

25--::

  2c+3c & 4c+1c RHA ; LHA', 4);
INSERT INTO 'dancecrib' VALUES (3225, '2012-01-22 19:30:16.431737+00', '2019-02-21 20:24:33.058679+00', 5945, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c Reels4 across, (1W+2M begin by Lsh pass, etc), finish (2,1,4,3)

9–::

  1c+4c RHA ; 2c+1c & 4c+3c LHA

17–::

  1c+4c+3c set | cross RH ; set, Circle6 L to (2,3,4,1)

25–::

  All circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (3223, '2012-01-22 19:30:16.352697+00', '2019-03-10 19:04:16.54186+00', 5939, 1, NULL, 'ace', '1–::

  1c+4c set | cast to middle (2c+3c step to end) ; 1c+4c Circle L

9–::

  2c+3c set | cast to middle (1c+4c step to end) ; 2c+3c RHA (1,2,3,4)

17–::

  1c down the middle and up, on [24] others step in for

25–::

  4 couple Poussette (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3236, '2012-01-22 19:30:16.862386+00', '2018-08-12 19:52:13.40815+00', 5983, 1, NULL, 'ace', '1--::

  All cross RH | set ; A&R (1x,2x,3x)

9--::

  1c+2c ½ RHA | set ; 1c+3c ½ LHA | set (2,3,1x)

17--::

  1c followed by 3c dance down {3}, 3c followed by 1c dance up {3} | 3c cast to 3pl _while{2}_ 1c dance to 2pl and face out (2,1x,3)

25--::

  1c turn 3c EH, 1c dance up to between 2c ; 1c turn 2c EH ¾ | cross RH to 2pl (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (13552, '2021-01-11 09:26:01.345576+00', '2021-03-10 10:02:32.523009+00', 9021, 1, 202, 'ace', '1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; turn P LH into St Andrews Cross, RHJ with cnrs

9--::

  All set | 1c+4c ¼ LHA moving on 1 place ; repeat [9-12] (2,4,1,3)

17-28::

  Intersecting Reels4 (½ LHA in 2 bars in centre). 4c between 2c face up _while_ 1c between 3c face down

29-32::

  4c cast off to 2pl _while_ 1c cast up to 3pl (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8039, '2013-09-16 17:58:14.5494+00', '2014-04-30 23:24:09.753978+00', 15057, 1, NULL, 'ace', '1–::
  Mirror Reels3 on the sides, 2c start out and up (1,2,3)
9–::
  1c+2c ½ poussette ; 1c+3c ½ poussette (2,3,1)
17–::
  All pass P Rsh and face P, and cast to opposite side ; Turn P BH 1½
25–::
  3c+1c Tournee (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2441, '2012-01-22 19:29:38.998679+00', '2021-05-27 21:35:07.684191+00', 2970, 1, NULL, 'ace', '1–::

  1W+2W+3W circle3 L, to places ; 1M+2M+3M repeat

9–::

  1c lead down the middle and up

17–::

  1c+2c Poussette

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (3241, '2012-01-22 19:30:17.089599+00', '2014-04-30 23:24:09.830225+00', 6010, 1, NULL, 'ace', '1–::
  1c cross RH, cast (2c up) ; dance between 3c (3c up) , behind 4c (4c up) to (2,3,4,1x)
9–::
  3c+4c+1c Reel3 on side (1c in, 4c out and down to begin)
17–::
  1c repeat bars 1-8 from 4th position, dancing up the set (1,2,3,4)
25–::
  1c+2c+3c Reels3 on side (1c in, 2c up and out to begin)
33–::
  1c cross RH | cast (2c up) and give RH to P, LH to 1cnr ; BiL, 1c turn RH to 2cnr
41–::
  1c+2cnrs BiL, 1c cast off behind 3c, lead up RH crossing over to 1pl own side facing down (2c down)
49–::
  1c+2c ½ R&L, giving RH on the side to begin ; repeat with 3c
57–::
  Repeat with 4c ; all C turn RH 1½.', 2);
INSERT INTO 'dancecrib' VALUES (3243, '2012-01-22 19:30:17.168894+00', '2019-03-10 16:17:05.481787+00', 6020, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c circle4 L, 1c+3c finish in centre facing down ; 3c (leading) +1c dance between 4c and cast up to (3,2,1,4)

9–::

  Mirror Reels4 on the sides, 1c+3c start in and down

17–::

  3c+1c Fig8 round C below, on [24] all C dance into centre for

25–::

  3c+2c & 1c+4c ½ Poussette ; all C turn BH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3675, '2013-01-05 12:18:42.24323+00', '2016-03-27 22:42:48.602371+00', 14655, 1, NULL, 'ace', '1–::

  All set | cross RH ; All set | 1c turn RH and face down _while{2}_ 2c+3c turn RH ½ and face up

9–::

  In promhold 1c+2c+3c Rsh Reel3 on midline, finish 1c facing 2c and 3c in 3pl (1x,2,3)

17–::

  1c+2c RHA and hold RH to P ; 1c cross RH and cast _while{4}_ 2c turn RH moving up (2,1,3)

25–::

  1c dance down NHJ, cast up ; All C turn RH', 3);
INSERT INTO 'dancecrib' VALUES (13802, '2021-03-10 17:34:53.517962+00', '2021-03-10 23:51:48.985376+00', 20254, 1, 202, 'ace', '1--::

  1M+2W Turn Halfway and Cast _while{4}_ 1W & 2M chase clw ½ to exchanged places ; all repeat same pattern, 1W+2M turning and 1M & 2W chasing (1,2)

9--::

  1c+2c RHA ; LHA and stay in the middle (1,2)

17--::

  1c (+2c who dance up to follow) lead down ; 2c (1c following) lead up and stay in the middle facing up. On [24] 3c & 4c step in ready for (2,1,3,4)

25--::

  4C Allemande (4,3,1,2)

33--::

  All Turn Halfway and Cast (to 4x,3x,1x,2x) ; Circle8 L ½ (2,1,3,4)', 4);
INSERT INTO 'dancecrib' VALUES (3234, '2012-01-22 19:30:16.783105+00', '2021-04-16 11:40:52.227872+00', 5981, 1, NULL, 'ace', '1–::

  1c Turn RH and cast (2c up) ; turn LH and cast off (3c up)

9–::

  3c+1c 4-bar Poussette to change places, 1c finish facing 1cnr ; set to 1cnr | set to 2cnr, 1c face down (2,1,3)

17–::

  1c+3c Circle L and back

25–::

  2c+1c Promenade', 3);
INSERT INTO 'dancecrib' VALUES (14186, '2021-08-05 22:06:55.109491+00', '2021-08-05 22:19:55.130547+00', 8567, 1, 202, 'ace', '1--::
  1c set | cross RH ; 1c+2c set | All chase 1 place cclw, 1W & 2W casting. 1M & 2M face out
9--::
  L-Chain.
17--::
  1c & 2c Petronella turn in tandem (to 2x,1) | 1c+2c NHJ set up/down ; 2c ½ Fig8 down round 1c (2,1)
25--::
  2c+1c A&R{1+1} twice ; turn P BH (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (10284, '2017-12-02 02:59:33.229465+00', '2017-12-02 03:02:32.682619+00', 2336, 1, 202, 'ace', '1--::

  1c+2c »The Roulette«: [Petronella turn into midline | turn BH 1/2 finishing NHJ 1c facing W side & 2c M side ; 1W+2M RHJ, all dance{1} round clw in a line 1 step, drop P''s hand, 1W+2M (inners) turn RH to finish 1W in 2Wpl and 2M in 1Mpl while{3} 1M & 2W (outers) dance round clw to face P] (2,1,3)

9--::

  3C Knot (3,1,2)

17--::

  3M & 2W dance in slightly, cast to 2pl, pass Lsh to face 1cnrs position (1c step out) ; 2W+3M ½ Reel4 in 1 diag, pass Lsh to 2plx (to 3W,3M,1M on W side, 1W,2W,2M on M side)

25--::

  All set | All W at top & all M at bottom RHA | 2M leading +1M+3M & 3W leading +1W+2W chase clw 2 places (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3734, '2013-04-20 22:52:08.155491+00', '2017-03-09 16:10:24.881518+00', 7311, 1, NULL, 'ace', '1–::

  1c+2c ½RHA _while_{2} 3c ½ turn LH | 2c ½ turn RH _while_{2}1c+3c  ½LHA (2,3,1) ; 2c+3c ½RHA _while_{2} 1c ½ turn LH | 3c ½ turn RH _while_{2} 2c+1c ½LHA (312)

9–::

  1c set | ½Reels3{3} across (Lsh to 1cnr) ; into ½Reels3{3} on the sides (Rsh to 2cnr), end facing 1W pos. (1W to L of 1M)

17–::

  1c set to 1W pos (2M) | turn inwards and set to 3M pos (3L) ; set to 3W pos (3M) | turn inwards and set to 1M pos (2L) and face R about to face 3W pos (1W behind 1M)

25–::

  1c+1cnrs ½diagonal lead-change Rsh Reel3 ; 1c (1W leads)+2cnrs ½diagonal lead-change Rsh Reel3 (to 312)', 3);
INSERT INTO 'dancecrib' VALUES (14070, '2021-06-16 09:02:19.343238+00', '2022-02-18 12:56:50.103616+00', 20350, 1, 202, 'ace', '1--::
  1c lead down ; lead up (2c up on [5-6]) and face 4cnrs
9--::
  Reel4 on 2diag _while{8}_ 1cnrs A&R {1+1} diagonally | set ; repeat [9-12]. 1c face 3cnrs
17--::
  1c dance RSh round 3cnrs ; turn 3cnrs LH, all finishing into promhold facing up ready for
25--::
  3C Promenade (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (11256, '2018-10-07 07:05:15.652981+00', '2022-04-26 09:25:27.664711+00', 16915, 1, 202, 'ace', '1--::

  1c+2c Bourrel (2,1,3)

9-20::

  3C R&L (2,1,3)

21-24::

  1c turn RH | cast to 3pl (3c up) (2,3,1)

25--::

  3c+1c The Knot', 2);
INSERT INTO 'dancecrib' VALUES (7906, '2013-08-21 08:31:51.175656+00', '2023-02-04 01:23:10.941982+00', 10960, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s & 3s set, 1s cross RH, cast behind 2s & cross up to places
    _while_ 3s 1/2 turn RH, cross up & cast to places
17-24::
    1s cast 1 place, 1/2 turn RH, 1L dances up between 2s & casts to 2nd
    place own side _while_ 1M dances down between 3s & casts up to place
25-32::
    1s dance RH across (1L with 2s & 1M with 3s), pass RSh & dance LH
    across with other couple', 0);
INSERT INTO 'dancecrib' VALUES (10371, '2018-01-06 02:40:07.577727+00', '2020-08-23 20:44:30.597553+00', 14820, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c set | RHA | 1c & 4c cast inwards (2c & 3c dance out) (2,1,4,3)

9--::

  1W+2M Allemande Right as 4W+3M Allemande Left _while{4}_ 1M+2W & 4M+3W set twice ; 1M+2W Allemande Right as 4M+3W Allemande Left _while{4}_ 1W+2M & 4W+3M set twice (2,1,4,3)

17--::

  Parallel Reels4, ending with 1c facing 4c

25--::

  1W+4W & 1M+4M set | change places LH ; 2c+4c & 1c+3c Circle4 L (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10855, '2018-06-21 13:08:07.242051+00', '2018-06-21 16:08:17.10646+00', 18378, 2, 2758, 'ace', '1-8::

  1s cross RH, cast behind 2s (2s move up), cross RH, cast behind 3s (3s move up) and finish in 3rd position

9-16::  

  2s+3s+1s dance 6 bars of snowball chain, 1s and 3s cross right hand as 2s set

17-24   ::

  1s+2s+3s circle to the left, on 7-8 bring right foot in front of left foot to change directions, chase back. 3s finish on the sidelines, 2s and 1s finish in the middle, hands joined, ready for a poussette.

25-32   ::

  2s+1s Poussette', 5);
INSERT INTO 'dancecrib' VALUES (10903, '2018-07-15 06:06:38.731683+00', '2018-10-07 12:31:24.705407+00', 10264, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; cross RH | cast R round 1cnrs into lines3 across

9--::

  Reels3 across{6}, 1c starting Lsh to 4cnrs | 1c turn LH to face 1cnrs (2,*1*,3)

17--::

  Reel4 on 1diag, pass Lsh

25--::

  Reel4 on 2diag (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3242, '2012-01-22 19:30:17.128959+00', '2018-02-12 22:14:28.739505+00', 6017, 1, NULL, 'ace', '1–::

  1c+2c RHA ; ½ R&L

9–::

  2c+1c LHA ; 1½ LH turn

17–::

  Set up/down on sidelines | set to partner ; ½ R&L

25–::

  Repeat', 2);
INSERT INTO 'dancecrib' VALUES (3131, '2012-01-22 19:30:12.631107+00', '2014-04-30 23:24:07.885033+00', 5641, 1, NULL, 'ace', '1–::
  1c cross RH | cast off ; turn LH ½ and lead up to 1pl in the middle facing down
9–::
  1c+2c circle4 and back
17–::
  1c lead down the middle and up
25–::
  1c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (3132, '2012-01-22 19:30:12.669817+00', '2022-11-12 18:43:22.549392+00', 5654, 1, NULL, 'ace', '1–::

  1c+2c turn RH and face other C | set ; RHA

9–::

  1M+2W cross RH | 1W+2M cross RH ; ½ R&L  (1,2)

17–::

  All set | circle4 L | set advancing into

25–::

  Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (3248, '2012-01-22 19:30:17.410347+00', '2020-09-18 15:59:35.149301+00', 13502, 1, NULL, 'ace', '1–::

  1c set | Cross RH ; 1c+2c change pl. on side LH | set up/down (2,1x)

9–::

  L-Chain

17–::

  1c lead down | lead up ; cross above 2c and cast off (2,1)

25–::

  Poussette (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (10763, '2018-05-15 23:36:10.152299+00', '2019-01-18 19:11:25.999412+00', 18335, 1, NULL, 'ace', '1-::  All &frac12; interlocking RSh Reels4 to (3,4,1,2) ; turn P RH

9-::  All &frac12; interlocking RSh Reels4 to (1,2,3,4) ; turn P 1&frac14; RH to M BtoB in centre

17-:: M H&G set to P & diagonally to other M to end facing next W (W set for 4 bars) ; M turn W 1&frac12; RH to W BtoB in centre

25-:: W repeat [17-24] to (2,3,4,1) ending NHJ with P

33-:: All S&Link to diagonals ; S&Link to W (1,2,3,4) opposite M (3,4,1,2) who face out

41-:: All &frac12; Dbl Ladies Chain to (3,4,1,2) ; All set | turn P RH so W face out

49-:: All &frac12; Schiehallion reels back to (1,2,3,4) & turn into allemande hold

57-:: All dance cclw round the set in allemande hold back to place

::    Repeat 1-64 in reel time

', 5);
INSERT INTO 'dancecrib' VALUES (8081, '2013-10-09 14:18:48.435698+00', '2014-04-30 23:24:10.01466+00', 14295, 1, NULL, 'ace', '1–::
  1c Adv{1} join RH, retire{1} | Turn BH ½ and face 2c ; 1c+2c Adv{1} and join RH | retire{1}| 1c turn 2c BH ½ (2,1x,3)
9–::
  All A&R {1+1} | all turn P BH ; 1c cast R round 1cnr into middle facing 1cnr
17–::
  1c set to 1cnr | dance clw round P to face 2cnr ; set to 2cnr | dance clw round P to (2,1,3)
25–::
  Reels3 on the sides, 1c starts outwards, Rsh to 3cnr, change side on [3-4] and back on [7-8] (oval shape as in Inveran Reels)', 3);
INSERT INTO 'dancecrib' VALUES (3644, '2012-08-23 22:01:40.716372+00', '2016-08-16 14:54:30.398329+00', 14535, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; dance between 3c and cast up (2,1,3)

9–::

  Diagonal R&L (3x,1,2x)

17–::

  All S&Link3 into lines across ; repeat (2,1x,3)

25–::

  1c ½ Fig8 L (W up, M down) ; All turn P RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2438, '2012-01-22 19:29:38.83753+00', '2021-05-27 21:50:01.200249+00', 2957, 1, NULL, 'ace', '1–::

  1c set to 2c | 1c cross RH ; repeat

9–::

  1c cross | cast off (2c up) ; ½ Fig8 up (2,1,3)

17–::

  1c dance down below 3c, cast up ; dance up between 2c, cast off

25–::

  2c+1c R&L (2,1,3)

33–::

  Opposing Reels3 across, 1c starting Lsh to 1cnr

41–::

  Opposing Reels3 across, 1c starting Rsh to 2cnr', 2);
INSERT INTO 'dancecrib' VALUES (3246, '2012-01-22 19:30:17.332404+00', '2020-12-25 11:11:11.115433+00', 11564, 1, NULL, 'ace', '1–::

  All Reels4 on own side.

9–::

  1c+2c & 3c+4c RHA ; 1c cast off and 4c cast up _while{2}_ 2c & 3c dance to end and curve into place | All set (2,1,4,3)

17–::

  2c+1c & 4c+3c Dbl Fig8, 2c & 4c crossing down to start, except that on [23-24] 1c cross to 3pl and 4c cast up to 2pl (2,4,1,3).

25–::

  All set | all turn BH {4} | All set .', 2);
INSERT INTO 'dancecrib' VALUES (13805, '2021-03-11 00:51:50.629166+00', '2021-05-03 23:08:35.003399+00', 15589, 1, 202, 'ace', '1--::
  1c+2c The Knot. On [7-8] 1c turn LH and face 1cnrs
9--::
  ½ Reel4 on 1diag ; ½ Reel4 on 2diag
17--::
  Repeat [9-16] (2,1,3)
25--::
  ½ Reels3 across, 1c LSh to 1cnrs (to 2x,1x,3x) ; 1c cross RH and cast to 3pl _while{4}_ 2c & 3c turn P LH 1½, 3c moving to 2pl (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (9795, '2017-04-15 22:21:14.325539+00', '2021-05-27 22:07:32.824447+00', 2955, 1, 202, 'ace', '1--::

 1c+2c Circle4 and back

9--::

 RHA ; LHA

17--::

 1c lead down (2c up) ; lead up, 1W between 2c facing 2M, 1M between 3c facing 3W

25--::

 Reels3 across, Lsh to 1cnr (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3758, '2013-06-08 21:30:32.018294+00', '2014-04-30 23:24:10.081149+00', 13690, 1, NULL, 'ace', '1–::
  1c turn RH | cast (2c up) ; All set | 2c+3c cross LH _while_{2} 1c turn LH ¾ to face 3cnr (position)
9–::
  Set«H&G«, petronella to (2x,1x,3x)
17–::
  ½ Reels3 across, 1c Lsh to 3cnr ; ½ Reels3 across, Lsh to 1cnr (2x,1x,3x)
25–::
  S&Link3 ; repeat (3,1,2)
33–::
  All chase clw ½ way ; set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3250, '2012-01-22 19:30:17.576795+00', '2017-01-31 17:06:23.67309+00', 6048, 1, NULL, 'ace', '1–::

  1c cross down RH (2c up) to 2plx in DTr position with corners | set as DTr ; cast up, meet and dance down to 2pl in middle

9–::

  2M+1W+3M RHA, _while_{4} 2W+1M+3W LHA ; 1c followed by 2c+3c dance down the middle

17–::

  3c+2c+1c dance up the middle, 3c casting to 3pl, flowing into ; 1W+2M+3M LHA, _while_{4} 1M+2W+3W RHA

25–::

  1c dance to top, cast off one ; ½ Fig8 up round 2c.', 3);
INSERT INTO 'dancecrib' VALUES (3254, '2012-01-22 19:30:17.701829+00', '2015-04-03 18:58:06.573599+00', 10681, 1, NULL, 'ace', '1–::

  1c turn RH and cast (2c up) ; All S&Link3, but, at the end, the dancers who started on the left pull back Lsh to enter the reels

9–::

  Reels3 on own sides (Lsh to 4cnr pos.), 1c finish just inside the ends of the set

17–::

  1c cross up/dn LH | cast L round 1cnr pos (to 3,1x,2) ; All S&Link3 (modified)

25–::

  Lsh Reels3{6} on opp. side, Lsh to 2ncr pos. | 1c pass Rsh to (2,1,3) (on 1st repeat, flow into the RH turn)', 3);
INSERT INTO 'dancecrib' VALUES (10110, '2017-09-03 23:45:37.06511+00', '2023-02-04 01:23:10.952367+00', 7075, 3, NULL, 'ace', '1-8::
    1s set Advancing, join RH to lead down (2s step up 3-4).  1s set,
    join LH, lead up & turn to face 1st corners
9-16::
    1s turn 1st corner RH, partner LH, 2nd corner RH, partner LH to end
    in 2nd place opp sides
17-24::
    2s+1s+3s set, cross RH, set & 2s+3s cross RH to own side _while_ 1s
    turn 1.1/4 RH to face 2nd corners
25-32::
    Reels of 3 on sides, RSh to 2nd corner (6 bars).  1s cross to own
    side, 2nd place (bars 31-32)', 0);
INSERT INTO 'dancecrib' VALUES (15095, '2022-09-10 10:50:34.929632+00', '2022-09-10 10:50:34.929632+00', 14278, 2, 1, 'ace', '1–::
  1c set | cast off [2c up] ; 1c+3c circle4/L and turn BH into line for …
9–12::
  1c+3c ½ Poussette [3c to pl, 1c to centre in 2pl, M in front, L right behind ptr]
13–16::
  1c [in tandem]+2M+3L dance ½ RS Reel3, changing lead [fin 1L in front facing 3M on diagonal]
17–20::
  1c [in tandem]+3M+2L dance ½ RS Reel3, changing lead
  [fin 1L in 2M''s pl, 1M&2L pulling RS back to fin BtoB on diagonal facing ptrs]
21–24::
  1c+2c ½ Poussette [M unusually facing up, to 3x1x2x]
25–::
  1c set | cast up [2c down] ; all turn BH 1½ to own sides', 3);
INSERT INTO 'dancecrib' VALUES (10481, '2018-03-04 17:16:33.798878+00', '2018-03-04 17:17:52.346513+00', 13485, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; set | 1M cast down (3M step up) _while{2}_ 1W cast up (2W step down) (2,3,1 on M side, 1,2,3 on W side)

9--::

  ½ Reels3 on sidelines, 1M Lsh to 3M & 1W Lsh to 2W to start (to 1,3,2 on M side, 3,2,1 on W side) ; 1c, passing between standing persons on opposite sides, chase clw ½ (1W,3M,2M on M side, 3W,2W,1M on W side)

17--::

  1W+3M+2M & 1M+2W+3W ½ Reels3 on sidelines, 1W Rsh to 3M & 1M Rsh to 2W to start (to 2M,3M,1W on M side; 1M,2W,3W on W side) ; 1c, passing between standing persons on opposite sides, chase cclw ½ (2,3,1 on M side, 1,2,3 on W side)

25--::

  1c set to P | cast into 2pl (3M step down, 2W step up) ; turn RH _while{4}_ all clap 3/3/3/1 times (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15092, '2022-09-08 11:47:54.175251+00', '2022-09-08 11:52:57.225609+00', 21092, 1, 202, 'ace', '1--::

  1c set | lead down to bottom ; cross (2c up) | cast up to 2plx (2,1x,3)

9--::

  Mirror Reels3 on sides, 1c in and up (2,1x,3)

17--::

  2c+1c *Circulating Slip Knot* : 1c & 2c turn P into allemande hold, facing each other, 2c on Mside, 1c on Wside | 2 bars of a regular Knot for 2c, an inverted Knot for 1c ; 1M & 2M lead P LH across the set | 1c+2c ½ LHA (2,1x,3)

25--::

  1c ½ Fig8 R round 2cnrs ; all turn P LH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13560, '2021-01-18 22:59:35.192634+00', '2021-01-18 23:01:17.444675+00', 9425, 1, 1645, 'ace', '{{explanation}}
Strathspey (square)

1-::
  1c cross NH into Fig8 round opposite sides, on [8] 1c & 3c advance to centre NHJ (1x,2,3,4)
9-::
  1c+3c Rondel & end facing out (3x,2,4,1)
17-::
  2c & 4c (in promhold) RSh Reels3 on sides, 1c & 3c cast away from P to start & take NH where possible
25-::
  2c+4c in promhold advance, M LSh together, into Tournee
  _while{8}_ 3c & 1c cast to opposite ends passing RSh on sides ;
  1c/3c turn 1&frac34; LH/RH to longwise set (1,4,2,3)

{{explanation}}
Reel (longwise)

33-::
  1c & 2c set | cross RH ; cast off (4c & 3c up) | 1c+3c &frac12; RHA, 1M+3W & 3M+1W end facing out in promhold (4,3x,1,2x)
41-::
  &frac34; RSh Reels3 on sides, 3M+1W/1M+3W end on sides in 1plx/4pl, 4c/2c end in 2pl/3plx
49-::
  All set | turn &frac34; RH ; set | turn &frac34; ending BHJ on centre line, M & W on alternate sides
57-::
  3M+1W & 4c also 2c & 1M+3W Poussette, all M start retiring. On [63-64] side couples retire as end couples set & open out to reform square (4,1,2,3)
', 2);
INSERT INTO 'dancecrib' VALUES (3260, '2012-01-22 19:30:17.963354+00', '2014-04-30 23:24:10.202721+00', 13138, 1, NULL, 'ace', '1–::
  1c+2c & 3c+4c ½ Dbl Figs8, 1c+3c cross to begin ; All set | turn P BH to diagonal line for
9–::
  1c+2c & 3c+4c ½ Poussette ; 1c+4c ½ Poussettte (2,4,1,3)
17–::
  2c+4c & 1c+3c Circle4 L, finish in middle, C facing C ; All set, turn opposite EH, 2c+1c (=upper Cs) passing inside, to (2,4,1,3)
25–::
  Mirror Reels4 on the sides, the W Lsh, the M Rsh (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8124, '2013-11-27 06:52:53.475887+00', '2015-02-24 14:51:18.764614+00', 15269, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c Circle4 L, finish NHJ cpl facing cpl up/down ; 1c+3c turning inwards cast off one _while_{4} 2c+4c dance up (2,1,4,3)

9–::

  1c+4c Rondel (2,4,1,3)

17–::

  2c+4c & 1c+3c S&Link, all hands joined on the sides ; repeat

25–::

  Reels4 on the sides (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3257, '2012-01-22 19:30:17.845172+00', '2014-11-11 13:31:23.673814+00', 10470, 1, NULL, 'ace', '1–::

  1c+2c S&Link ; 1c turn BH to face 1cnr

9–::

  1cnr Chain (1c+1cnr turn RH ½ | 1cnrs turn RH in middle ; 1c+1cnr turn RH ½ | 1c turn LH 1¼ to face 2cnr)

17–::

  2cnr Chain, as above.  Finish 1M / 1W between 2c / 3c

25–::

  In lines across A&R ; 1c turn BH 1¾ (or ¾?) to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3263, '2012-01-22 19:30:18.082329+00', '2015-02-21 01:16:00.379085+00', 6964, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; All Set | All circle6 L ½ round (3x,1x,2x)

9–::

  1c cross RH | cast R ; cross (up/dn) RH | cast R _while{8}_ 2c+3c set diagonally | ½ RHA ; repeat (to 3x,1,2x)

17–::

  ½ Reels3 across, Rsh to 2cnr ; 1c turn BH 1½

25–::

  3c+1c+2c The Knot (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3738, '2013-05-22 16:31:16.546051+00', '2014-04-30 23:24:10.239443+00', 14891, 1, NULL, 'ace', '1–::
  All Circle8 and back
9–::
  All promenade, to places.(1,2,3,4)
17–::
  1M+3W Fig8 round 2c _while_{8} 1W+3M Fig8 round 4c
25–::
  2M+4W Fig8 round 3c _while_{8} 2W+4M Fig8 round 1c (1,2,3,4)
33–::
  1c+3c ½ R&L ; continue{4} as in G-Chain
41–::
  All W ½ RHA ; All set to and turn P RH (4,3,2,1)
49–::
  2c+4c ½ R&L ; continue{4} as in G-Chain
57–::
  All M ½ LHA ; All set to and turn P RH (3,4,1,2)
65–::
  All W cast R ½ round outside ; in front of and round P''s place,
73–::
  All M cast L ½ round outside ; in front of and round P
81–::
  All Circle8 and back (1,2,3,4)', 3);
INSERT INTO 'dancecrib' VALUES (3155, '2012-01-22 19:30:13.665597+00', '2021-04-20 18:43:20.52054+00', 5741, 1, NULL, 'ace', '1–::

  1c long cast to face 2cnr (2c up) ; set to and turn 2cnr BH

9–::

  ½Reels3 on the sidelines, Lsh to 1cnr ; ½Reel3 across, 1c giving Rsh to 4cnr position (to 3x,1,2x)

17–::

  All A{1}&R{1} | all cross Rsh ; 1c cast L into lines of 3 across (M up, W down)

25–::

  In lines across A{1}&R{1} | all cross Rsh ; 1c cast R into (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3576, '2012-05-20 19:51:14.007192+00', '2017-11-14 06:21:22.690311+00', 14428, 1, NULL, 'ace', '1–::

  1W followed by 1M cast off (2c up on 3-4) and cross ; 2c+1c RHA (1W face out)

9–::

  1W followed by 1M cast off (3c up on 11-12) and cross ; 1c+3c LHA (2,3,1)

17–::

  1c cross RH | cast up (3c down) ; 1c petronella turn | all set in lines across

25–::

  1c cross RH up/down | cast R _while_{4} 2M+3M & 2W+3W dance BtoB ; all turn P RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3627, '2012-07-21 11:46:12.025755+00', '2014-04-30 23:24:10.658153+00', 11291, 1, NULL, 'ace', '1–::
  1c turn RH 1½ ; cast off (2c up) | turn LH to face 1cnr
9–::
  SetH&G , finish BtoB in middle, M facing up. W down
17–::
  ½ Reels3{3} across, Rsh to 2cnr, 1c pass Rsh into ½ reels3{3} across, Rsh to 4cnr position | 1c turn RH (2,1,3)
25–::
  Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9134, '2016-04-12 07:51:44.297851+00', '2022-09-08 07:30:29.409722+00', 16909, 1, 202, 'ace', '1-::

 1c+2c RHA{3}, LHA{3} | 1c cast to 2pl, 2c dance to top (2,1,3)

9-::

 Mirror Reels3, 1c start in and down

17-::

 2c+1W & 1M+3c RHA ; with 1c leading LSh Snake Pass to (3,1,2)

25-::

 3C Set&Rotate (2,1,3)



*Note. After 2nd time through 1c (+ 4c) may repeat (1-8) to go to 4pl.*

', 3);
INSERT INTO 'dancecrib' VALUES (8744, '2015-03-26 11:01:54.419912+00', '2015-03-26 11:01:54.419912+00', 16181, 1, NULL, 'ace', '1--::

  1W+3W, P following, cast off, cross to opposite side ; cast up (M up the middle) and set (1x,2,3x,4)

9--::

  Repeat from new places, the Men leading (1,2,3,4)

17--::

  1c+3c lead down and up

25--::

  1c+2c & 3c+4c Poussette, 1c & 4c passing in the middle (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10003, '2017-07-12 14:08:47.19308+00', '2017-07-12 14:08:47.19308+00', 17888, 2, NULL, 'ace', '1- 4::

  1s&3s cross diag Dn to 2nd & 4th pls (2s, 4s Up1 bars 1,2) then 1s3s ½ turn person below them (1M RH, 1W LH); 

5- 8::

  1s&3s ½ fig8 Up thru cple above to fin 24153: 

9-12::

  AS 2s4s (tops) & 5s3s (botts) RH wheels ALSO 1s turn RH (4M, 5W stay facing out); 

13-16::

  AS 2s (top cple) & 3s (bott cple) turn LH ALSO 1M+4s LH wheel & 1W+5s LH wheel: 

17-24::

  2s4s (tops) & 5s3s (botts) Set & Rotate: 

25-32::

  all ½ chase clkwise to (5)(3)(1)(2)(4) opp sides then all cross Rh to own sides:', 2);
INSERT INTO 'dancecrib' VALUES (8219, '2014-03-23 21:29:16.992547+00', '2014-04-30 23:24:10.766618+00', 1749, 1, NULL, 'ace', '1–::
  1c dance down between 2c and cast up to place ; 1c dance BtoB
9–::
  2c dance up between 1c and cast off to place ; 2c dance BtoB
17–::
  1c+2c set | ¾ R&L (2,1)
25–::
  Circle4 and back (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (14614, '2022-02-18 21:49:47.679041+00', '2022-02-18 21:51:58.783705+00', 20668, 1, 1645, 'ace', '1--::
  1c cross RH | cast off (2c up) ; all A&R, 1c face 1cnrs on the sides (2,1x,3)
9--::
  1c set to & turn 1cnrs, face 2cnrs on the sides ; repeat with 2cnrs & face 1cnr again
17--::
  Reels3{6} starting LSh to 1cnr | 1c cross RH to own sides (2,1,3)
25--::
  Circle6 to L & back (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (2025, '2012-01-22 19:29:15.605859+00', '2023-02-17 11:49:26.107847+00', 1476, 1, NULL, 'ace', '1–::

  1c set, turn BH ; 1c+2c half R&L (2x,1x)

9–::

  2c+1c turn BH to own sides, 1c face up NHJ ; 1c dance up and cast off (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (3271, '2012-01-22 19:30:18.40111+00', '2020-12-17 22:29:11.279104+00', 6116, 1, NULL, 'ace', '1–::

  1c lead down | turn RH {4}| lead up (1,2,3,4)

9–::

  1W+2W+3W set (holding hands) to 2M+3M+4M, change places LH ; the 3 top persons on M side repeat with the bottom 3 on W side, changing places RH

17–::

  1M+2M+3M+4M (now in top four places!) RHA _while{4}_ 1W+2W+3W+4W LHA ; M continue RHA, joining NH with P as they meet, to form a double wheel, 1c dance down to 4pl and make an arch, the other couples follow

25–::

  2c+3c+4c dance under arch and cast up to (2,3,4,1) ; 2c+3c & 4c+1c circle4 L.', 3);
INSERT INTO 'dancecrib' VALUES (3258, '2012-01-22 19:30:17.884462+00', '2020-12-20 11:16:43.922136+00', 8511, 1, NULL, 'ace', '1–::

  All set to P | 2 hands of G-Chain to face next ; repeat from new places (face original corner person)

9–::

  Turn that person LH 1¼ ; All W RHA _while{4}_ All M chase ½ cclw, to places

17–::

  All NHJ with P Adv {2} and touch hands, Ret {2} ; Adv {1} and swivel R to chase (M leading) to next place clw

25–::

  Circle10 and back (5,1,2,3,4)', 2);
INSERT INTO 'dancecrib' VALUES (10857, '2018-06-21 16:07:55.59652+00', '2018-06-21 16:08:45.121152+00', 18378, 1, 202, 'ace', '1--::
  1c cross RH  | cast (2c up) ; cross RH | cast (3c up) (2,3,1)
9--::
  6 bars of Snowball Chain, 1c cross RH to start | 1c & 3c cross RH _while{2}_ 2c set (1,2,3)
17--::
  Circle6 L {3}, cross R foot over and pivot L ; chase cclw to (1,2,3), 1c & 2c staying in centre BHJ for
25--::
  1c+2c Poussette (2,1,3) ', 2);
INSERT INTO 'dancecrib' VALUES (3261, '2012-01-22 19:30:18.002886+00', '2014-08-23 20:08:51.573586+00', 8524, 1, NULL, 'ace', '1–::

  1c cross down between 2c for Fig8 on opposite side (to 1x,2,3)

9–::

  1c+2c turn RH 1¼ ; 1c+2c ½Reel4 on midline, finish facing P, _while{4}_ 3c turn RH 1¼

17–::

  2c turn RH 1¼ _while{4}_ 1c+3c ½Reel4 on midline ; 3c+1c turn RH 1¼ (2,1,3)

25–::

  2c+3c+1c circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (3166, '2012-01-22 19:30:14.114525+00', '2018-11-06 15:15:35.328673+00', 5765, 1, NULL, 'ace', '1–::

  1W+2W NHJ set advancing {2}, turn P BH {4}, set retiring {2}

9–::

  1M+2M repeat

17–::

  1M+2W set and change places RH ; 2W+2M repeat LH (2M finishes facing out)

25–::

  1c+2c L-Chain

33–::

  2c followed by 1c (Men on L) dance down the middle, on 4th bar the W dance under P''s arm ; all dance up

41–::

  1c+2c Poussette (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (3277, '2012-01-22 19:30:18.67913+00', '2019-09-25 08:02:07.506832+00', 6148, 1, NULL, 'ace', '1–::

  1c+3c, M leading W, dance between couple on L and cast clw to opposite place ; All circle8 ½ L

9–::

  2c+4c repeat, W leading M, through C on R ; All Circle8 ½ R

17–::

  All W RHA, to face P from centre ; set | turn RH ½ to put M in centre

25–::

  All M LHA, to face P ; set | turn RH into promhold, 1c+3c facing clw, other Cs facing centre

33–::

  1c+3c promenade ½ round clw _while{4}_ 2c+4c A&R ; repeat with couples interchanged

41–::

  1c+3c ½R&L ; 2c+4c ½R&L

49–::

  1c+3c, W leading M, dance between couple on R and cast cclw to opposite place ; All circle8 ½ R

57–::

  2c+4c repeat, M leading W, moving to L and clw ; All circle8 ½ L



{{explanation}}

Note:This follows the original description (see http://moirastacey.wordpress.com/17-slainte-mhor/)  

This dance is sometimes danced as a medley: first as Strathspey, repeat as Reel (S64+R64).', 3);
INSERT INTO 'dancecrib' VALUES (3259, '2012-01-22 19:30:17.923428+00', '2020-12-18 20:46:43.854031+00', 7517, 1, NULL, 'ace', '1–::

  All set and cross RH ; set and cross RH

9–::

  All circle6 and back, finish 1c facing 3c down/up in the middle

17–::

  1c+3c ¾ of R&L up/down | 3c cross LH to sidelines _while_ 1c cast off one (2c up) (to 2,1x,3)

25–::

  1c cross down into ½ Fig8 round 3c ; 1c followed by 3c dance up (NHJ) to top and cast off to order 2,3,1', 3);
INSERT INTO 'dancecrib' VALUES (7835, '2013-08-21 08:31:49.544712+00', '2023-02-04 01:23:04.738329+00', 6933, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    2s & 3s dance out ends & cast in to meet other partner in prom hold,
    2s+3s dance 1/2 RSh reels of 3 on sides (dancing to right) & end in
    prom hold with own partner in 2nd/3rd place (2s face up 3s down)
    (4) 2 (3) 1
9-16::
    2s dance LSh reel of 3 across with 4s _while_ 3s dance LSh reel
    across with 1s ending in prom hold with other partner & curving
    round to right (3M+2L face up, 3L+2M face down)
17-24::
    2s+3s (dancing out ends) dance 1/2 LSh reels of 3 on sides ending on
    sides order 13(2)(4) in Sq.Set formation, all set & 1s+3s also 4s+2s
    1/2 turn 2H on sides to end on corners of square
25-32::
    All set diagonally & circle 8H round to left.  3 1 (4)(2)', 0);
INSERT INTO 'dancecrib' VALUES (14050, '2021-05-28 00:57:26.598015+00', '2021-05-28 10:12:01.319736+00', 11939, 1, 202, 'ace', '1--::
  1c set | cast off 2 places ; meet P, dance up to top and cast off (2c up) (2,1,3)
9--::
  Diagonal R&L (3x,1,2x)
17--::
  ½ Reel3 across, 1c LSh to 4cnrs[pos], 2c & 3c passing P RSh ; ½ Reels3 on sides, 1c LSh to 2cnrs[pos]. On [23-24] 1c turn LH and face 1cnrs
25--::
  1c turn 1cnrs RH, pass P RSh ; turn 2cnrs RH, pass P RSh to 2pl (cnrs dance for 4 bars)
33--::
  Circle6 and back (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14272, '2021-09-07 00:55:27.293875+00', '2021-09-07 20:52:18.790693+00', 20458, 1, 202, 'ace', '1--::
  All A&R ; 1c & 3c Petronella turn into midline | set
9--::
  *Weasel Reel* : All continuously dance ½ Reel4 on midline, dancers who reach the end cast clw on sides and rejoin the reel at the other end. All finish as on [9]. Dancers entering and leaving the reel pass RSh.
17--::
  1c & 3c turn P RH 1¼ (to 1,2,3) ; 1c+2c S&Link (2,1,3)
25--::
  2c+1c RHA ; 1c+3c LHA (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14615, '2022-02-19 22:56:11.777644+00', '2022-02-19 22:56:23.221917+00', 11562, 1, 1645, 'ace', '1--::

  1c+2c+3c set | Circle6 &frac12; way to L (3x,2x,1x) ; all M dance RSh round P who dance in on [8] to face down in promhold

9--::

  3c+2c+1c Promenade (3x,2x,1x)

17--::

  1c & 3c set | 1c cast up _while_ 3c cross down (1x,2x,3) ; 1c+2c &frac12; R&L, 1W faces out (2,1,3)

25--::

  1W, 1M following, casts behind 3W & up the middle ; all turn P RH, 1c turning 1&frac14; (2,1,3)

::

  *After their 2nd repetition 1c must slip quickly to the bottom*

', 2);
INSERT INTO 'dancecrib' VALUES (3287, '2012-01-22 19:30:19.088389+00', '2020-02-10 15:43:59.887728+00', 10855, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; ½ Fig8 up (2,1x,3)

9–::

  G-Chain, (2c cross to start)

17–::

  1c turns RH | cast off (3c up) ; ½ Fig8 round 3c (2,3,1)

25–::

  3c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (3274, '2012-01-22 19:30:18.558361+00', '2022-01-30 22:41:55.79987+00', 6136, 1, NULL, 'ace', '1–::

  4c dance up one NHJ and cast to place _while{4}_ 3c cast down and dance up NHJ to place, facing down ; 4c with 3c+2c following, dance NHJ to 2pl, and cast off (to 1,2,3,4)

9–::

  4c followed by 3c+2c+1c dance to top NHJ and cast off (to 1,2,3,4) {6} | 1c+2c & 3c+4c turn EH ½ on sidelines, 2c & 4c pass inside (to 2,1,4,3, 2c+4c facing out)

17–::

  2c+1c & 4c+3c half DblFig8, 1c & 3c start crossing up ; turn other C EH on the sidelines (2x,1x,4x,3x)

25–::

  2c+1c & 4c+3c half DblFig8 ; 1c+4c+3c ½Reels3 on sidelines, 4c start out and up (to 2,3,4,1)



{{explanation}}

In bars 1-16 it is important to be back in places in time. All figures join together in a continuous flow) (I need to check if couples cast down or dance down behind own lines to start', 3);
INSERT INTO 'dancecrib' VALUES (3179, '2012-01-22 19:30:14.648629+00', '2022-01-29 17:37:40.714706+00', 5804, 1, NULL, 'ace', '1–::

  »En Rond« progression (1W+2W & 1M+2M change places LH on sides | set to P ; 1c+2c circle4 R) (2,1,3)

9–::

  1c dance in slightly and swivel L to cast Lsh round 4cnr, pass between that end couple and curve R to face 1cnrs ; turn 1cnr RH to finish 1W (1M) between 2c (3c) | set in lines across.

17–::

  1c dance in slightly and swivel L to cast Lsh round 1cnr, pass through sidelines and curve R to face 2cnr ; turn 2cnr RH, to sideline | All set (2,1x,3)

25–::

  All A&R ; 1c set advancing turning BH ½ round and set retiring to own side', 3);
INSERT INTO 'dancecrib' VALUES (10777, '2018-05-20 17:10:28.54652+00', '2022-10-21 23:18:22.654849+00', 30, 1, 202, 'ace', '1--::

  1c+2c set | 1c cast (2c cross up) (to 2x,1,3) ; 1c+3c repeat [1-4] (2x,3x,1]

9--::

  Mirror Reels3 on sidelines, 3c out and up (2x,3x,1)

17--::

  3c+1c ½ R&L (to 2x,1x,3) ; 2c+1c ½ R&L (1,2,3)

25--::

  1c+2c Poussette (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3291, '2012-01-22 19:30:19.245803+00', '2016-10-04 21:31:45.274412+00', 6186, 1, NULL, 'ace', '1–::

  1M+4W cast to centre | turn RH 1½ | dance out the sides to exchanged places

9–::

  1W+4M repeat, using LH (4x,2,3,1x)

17–::

  2c+3c set | dance NHJ out the ends and cast to places | ½ RHA (to 4x,3x,2x,1x)

25–::

  All C set | circle8 L ½ round | set  (1,2,3,4)

33–::

  1c+2c ½ R&L ; 1c+3c ½ R&L

41–::

  1c+4c ½ R&L ; All C set and cross RH  (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13202, '2020-09-18 23:39:56.557037+00', '2020-12-07 12:58:00.716468+00', 10410, 1, 202, 'ace', '1--::

  Parallel Reel3 on sides, 1c RSh to 2c (1,2,3)

9--::

  1c dance down ; and up to 2pl (2c up on [11-12]) (2,1,3)

17--::

  Circle6 and back (2,1,3)

25--::

  All A&R ; all dance BtoB (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3290, '2012-01-22 19:30:19.206578+00', '2014-04-30 23:24:10.879738+00', 6182, 1, NULL, 'ace', '1–::
  1c cast off two places and lead up the middle
9–::
  1c+2c+3c RHA ; LHA
17–::
  1c lead down the middle and up
25–::
  1c+2c Poussette (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (3278, '2012-01-22 19:30:18.719234+00', '2016-08-29 22:40:32.922994+00', 6150, 1, NULL, 'ace', '{{explanation}}

2c & 4c cross to opposite sides: (1,2x,3,4x)



1–::

  1c+4c set and cross RH ; all C set | ½ RH turn to face nearest end in Allemande hold

9–::

  1c+2c (start up) & 3c+4c (down) Allemande, finishing interleaved (1c and 4c pass) (2,4x,1,3x) 

17–::

  4c+1c LHA, at end W face out ; 2c+4c & 1c+3c RHA

25–::

  All circle8 and back (to 2, 4x, 1, 3x)



*(option: on [15-16] 4c+1c may make full LH turn into the LHA)*', 3);
INSERT INTO 'dancecrib' VALUES (10280, '2017-11-29 12:20:29.006739+00', '2018-04-10 11:44:49.22293+00', 15113, 1, 202, 'ace', '1--::

  1c+2c+3c set | advance{1}, touching joined hands briefly, and retire{1} ; all pivot R and chase clw ½, 2c dancing in to face 3cnrs

9--::

  2c ½ Reel4 in 1 diag, pass Rsh to face 4cnrs ; ½ Reel4 in 2 diag (1,2,3)

17--::

  All advance{1} to take P''s RH at shoulder height, and *retaining hands*  retire{1} | all change places{1} RH, W dancing under M''s R arms, and retire{1} to sidelines ; repeat [17-20] with LH (1,2,3)

25--::

  1c NHJ dance up and cast to 2pl (2c up) ; 1c NHJ followed by 3c NHJ dance up and cast (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (3282, '2012-01-22 19:30:18.876278+00', '2017-03-05 08:21:17.091561+00', 8477, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; turn LH 1¾ to face 1cnr

9–::

  Reel4 with 1cnrs, at end pass Lsh into

17–::

  Reel4 with 2cnrs, finish 1M below 1W for

25–::

  Teapots R ; Teapots L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3285, '2012-01-22 19:30:19.010267+00', '2020-09-03 16:03:08.147599+00', 6168, 1, NULL, 'ace', '1–::

  1c lead down ; change sides, W passing below M and under her own arm pulling Lsh back, and lead up to 2plx (2c up on 7-8) (2,1x)

9–::

  2c+1c L-Chain (2,1x)

17–::

  2c+1c set twice ; circle4 L

25–::

  1c ½ Fig8 round 2c ; turn RH', 3);
INSERT INTO 'dancecrib' VALUES (2914, '2012-01-22 19:30:02.724487+00', '2020-06-22 10:06:29.283172+00', 7613, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; turn RH and face out

9–::

  Cast L round 4cnr and in through the ends ; turn LH to finish BtoB, 1W facing up, 1M down

17–::

  2c+1W & 1M+3c Circle3 L, 1c pass Rsh into ; 2c+1M & 1W+3c Circle3 R, 1c finish in 2pl BHJ

25–::

  1c slip down the middle | and up ; dance up between 2c and cast to meet BHJ

33–::

  1c slip UP the middle | and down ; cross RH between 3c and cast up to 2pl (2,1x,3)

41–::

  Mirror Reels3{6} on opposite sides, 1c starting up between 2c | 1c cross to own side (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3281, '2012-01-22 19:30:18.837223+00', '2020-12-20 23:42:18.217099+00', 9120, 1, NULL, 'ace', '1–::

  All set twice ; RHA

9–::

  1c turn BH ½ _while{2}_ 2c cast up into 1pl, all facing down NHJ in line across | 1c+2c dance down {4} | 1c turn BH ½ _while{2}_ 2c dance on and in to finish 2c behind 1c, all facing up NHJ

17–::

  1c+2c dance up to top ; 1c cast into 2pl _while{2}_ 2c dance into 1pl | 2c+1c turn RH to own sides

25–::

  2c+1c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (3279, '2012-01-22 19:30:18.757362+00', '2020-12-23 11:01:26.265304+00', 10286, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; turn LH and cast off (3c up) (2,3,1x)

9–::

  Mirror Reels3 on the sides, 3c starting out and down

17–::

  3c continue the reel to3pl _while{2}_ 1c NHJ dance to the top | 1c cast off and ½Fig8 down to (2,1,3)

25–::

  1c turn 1cnr RH and pass P Rsh ; turn 2cnr RH and pass Rsh to (2,1,3) (corners turn for {4})', 3);
INSERT INTO 'dancecrib' VALUES (3284, '2012-01-22 19:30:18.971342+00', '2021-04-14 11:09:41.157+00', 6161, 1, NULL, 'ace', '1–::

  1c+2c ½R&L ; 1c+3c ½R&L (2x,3x,1)

9–::

  1c cross RH, cast up (3c down) ; ½ Fig8 down to face 1cnrs

17–::

  ½Reel4 with 1cnrs, pass Lsh ; ½Reel4 with 2cnrs with fast ½turn LH into

25–::

  3c+1W & 1M+2c RHA ; Lsh Snake Pass (unwind the RHA, 1c leading, pass other snake Lsh through 2plx and chase cclw to) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14051, '2021-05-29 18:18:04.756887+00', '2021-05-29 18:18:20.455505+00', 2118, 1, 202, 'ace', '1--::

  1c lead down ; and up (1,2)

9--::

  2c lead down ; and up to 1pl (1c down) (2,1)

17--::

  1c+2c lead down. All pivot R ; 2c+1c lead up to places (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (9875, '2017-05-21 14:41:22.050877+00', '2019-01-18 19:18:08.898053+00', 17755, 1, 1645, 'ace', '1-::

  Mirror Reels4 on sides (M RSh, W LSh) with 1c & 3c starting down and in as 2c & 4c start up and out

9-::

  1c+2c & 3c+4c &frac12; DblFig8 ; 1c & 3c in promhold &frac12; LSh Reels3 across with 2c & 4c

17-::

  1c & 3c RHA with 2M & 4M ; 1c & 3c LHA with 2W & 4W to (2,1,4,3) with 1c & 3c in centre LHJ facing up

25-::

  1c & 3c lead up LH, cross, cast down on opposite side to (2,3x,4,1x) ; 3c & 1c 1&frac12; turn RH to (2,3,4,1) 3c & 1c facing out for repeat

', 3);
INSERT INTO 'dancecrib' VALUES (10858, '2018-06-21 16:51:36.524633+00', '2018-06-21 16:52:30.678983+00', 18379, 1, 202, 'ace', '1--::

  1c set advancing | turn BH ; dance down 2 places (2c+3c up) | turn BH to 3pl (2,3,1)

9--::

  3c+1c Tourbillon (2,1,3)

17--::

  All chase clw ½ (to 3x,1x,2x) ; turn P RH ½, face P | cast R to exchanged places (3,1,2)

25--::

  1c+2c Poussette (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (3286, '2012-01-22 19:30:19.049527+00', '2018-07-23 10:28:13.702583+00', 14318, 1, NULL, 'ace', '1–::

  1c turn RH ; turn LH

9–::

  1c+2c RHA ; LHA

17–::

  1c+2c+3c Circle6 and back

25–::

  1c+2c+3c+4c A&R twice

33–::

  5c dance up the middle and cast to place

41–::

  1c dance to 5pl (others up) ; All C swing.', 3);
INSERT INTO 'dancecrib' VALUES (3298, '2012-01-22 19:30:19.534238+00', '2019-12-13 15:04:31.29707+00', 6221, 1, NULL, 'ace', '1–::

  Circle12 and back

9–::

  1c+3c+5c advance | ½ circle6 L ; turn P BH twice and face outer couple

17–::

  1c+4c & 3c+6c & 5c+2c Rondel (inner couples pass under first arch, finish with 2c+4c+6c (new "inners") in LH star (M in middle, NHJ with P). (1c+3c+5c are new outer couples)

25–::

  "Inners" LHA ; the M repeat LHA _while{4}_ each W RHA with her outer couple. Finish all C in promhold in radial pairs, "inners" with Lsh in the centre facing cclw, touching Rsh with "outers" facing clw

33–::

  Circular Reel6 (all cpls dance once round, passing other couples Lsh/Rsh alternately) 

41–::

  1c+4c & 3c+6c & 5c+2c RHA, ending with "outers" (1c+3c+5c) opposite their original positions, while "inners" (4c+6c+2c) in promhold face cclw ; "inners" dance out and cast L round next couple ; finish all in »opposite« places (4,5,6,1,2,3)

49-88::

  Repeat 9-48 from new places

89–::

  Circle12 and back', 3);
INSERT INTO 'dancecrib' VALUES (3325, '2012-01-22 19:30:20.610863+00', '2021-04-12 22:17:53.628615+00', 6336, 1, NULL, 'ace', '1–::

  1c+2c Poussette (1,2,3)

9–::

  1c turn RH | cast off (2c up) ; cross RH and cast R round 1cnr to finish BtoB facing 1cnrs

17–::

  1c set to 1cnrs, set to 2cnrs and face P ; 1c spiral R round P 1½ to face 4cnr

25–::

  1W+2c & 1M+3c Rsh Reels3{6} across | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15180, '2022-10-22 02:18:50.635645+00', '2022-10-22 02:19:14.531188+00', 13555, 1, 202, 'ace', '1--::

  1c (1w leading) cast off | cross to 2plx (2c up) ; turn P RH (2,1x,3)

9--::

  Circle6 and back (2,1x,3)

17--::

  Reels3 across, 1c RSh to 4cnrs (2,1x,3)

25--::

  1c set | cast off (3c up) ; ½ Fig8 up round 3c (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (15179, '2022-10-21 00:06:19.732227+00', '2022-10-21 21:02:12.525324+00', 21133, 1, 202, 'ace', '1--::
  1c+2c Set and Mirror Link, 1c dancing in. 1c face out ; 1c+3c set ; changes place EH. 3c face out (2,3,1)
9--::
  Mirror Reels3 on sides, 3c out and up (2,3,1)
17-20::
  All set | A&R {1+1} (2,3,1)
21-32::
  3C R&L (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (3294, '2012-01-22 19:30:19.375581+00', '2016-06-03 13:51:09.186546+00', 6199, 1, NULL, 'ace', '1–::

  1c lead down | Turn RH ; lead up | cast to 2pl (2c up)

9–::

  2c+1c+3c The Knot (3,1,2)

17–::

  Teapots R and L  (1c RHA with C on the R ; pass Rsh, LHA with C on the L)

25–::

  Snake (unwind the LHA, 1c leading the others, pass other snake Rsh, pass through 2plx, cross at other end and cast R to (2,1,3) ; All turn P RH', 2);
INSERT INTO 'dancecrib' VALUES (10890, '2018-07-12 21:18:29.979933+00', '2019-01-18 19:22:03.181117+00', 18395, 1, NULL, 'ace', '1-::  1c & 3c &frac12; turn BH opening out into centre 1c facing 3c | set ; repeat with opposite person back to sides (W in exchanged pl)

9-::  1c & 3c &frac12; MChain ending in promhold with P (3,2,1,4) ; dance back to (1,2,3,4) passing RSh

17-32:: 2c & 4c repeat 1-16

33-:: All S&Link to face cnr ; Bourrel-like sequence: set adv passing cnr LSh | &frac12; turn next person BH & twirl away

41-:: All set adv passing next person LSh | turn P BH (3,4,1,2) ; then all &frac12; interlocking Reels4 to (1,2,3,4)

49-:: All dance BtoB passing RSh ; all M LHA to face P

57-:: All dance BtoB passing LSh;  all W RHA

65-:: All circle 8H round & back

73-:: All turn P BH | set ; advance joining hands |

      retire to form heart shape (1c hands forward facing 2c/4c, 3c hands backward)

', 5);
INSERT INTO 'dancecrib' VALUES (3843, '2013-07-13 15:56:21.006041+00', '2014-04-30 23:24:10.955802+00', 11731, 1, NULL, 'ace', '1–::
  All A&R ; clw trios pass under 2 arches made by cclw trios
9–::
  With new opposites Circle6 and back
17–::
  Middles RHA to the R ; LHA to the L
25–::
  All trios slip R and back; repeat passing other trio Lsh to face new trio.', 2);
INSERT INTO 'dancecrib' VALUES (3303, '2012-01-22 19:30:19.726291+00', '2017-04-14 13:52:46.955318+00', 6236, 1, NULL, 'ace', '1–::

  Inveran Reels3, all C crossing down from the top and up from the bottom (1,2,3)

9–::

  1c cross RH | cast off (2c up) ; ½ Fig8 up round 2c to face 1cnr

17–::

  1c+1cnrs Reel4, on [24] 1c take RH

25–::

  1c turn RH | cast off on opposite side (3c up) ; 1c ½ Fig8 round 3c (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3301, '2012-01-22 19:30:19.653721+00', '2014-04-30 23:24:11.077218+00', 6233, 1, NULL, 'ace', '1–::
  1c+2c RHA, LHA
9–::
  1c lead down the middle (2c up) and up, to face 1cnrs
17–::
  Set to and turn corners, 1W (1M) finishing between 2c (3c) facing P
25–::
  1c set twice ; turn 1¼ BH to 2pl', 3);
INSERT INTO 'dancecrib' VALUES (13961, '2021-04-18 00:16:50.238771+00', '2021-05-30 16:27:43.932181+00', 20327, 1, 202, 'ace', '1--::
  1c+2c Circle4 and back (1,2,3,4)
9--::
  1c dance down {3}, dance up {3} | cast off (2c up) (2,1,3,4)
17--::
  1c Fig8 up round 2c (2,1,3,4)
25--::
  1c+3c Allemande (2,3,1,4)
33--::
  1M+4W turn RH 1½ ; 1W+4M turn LH 1½ (2,3,4x,1x)
41--::
  All A&R, 4c & 1c changing sides BH on [42] ; all turn P RH (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (10005, '2017-07-13 00:14:00.231537+00', '2017-12-03 13:43:35.079434+00', 14074, 1, 202, 'ace', '1--::

  1c+2c S&Rotate (2,1,3)

9--::

  Reels3 across, 1c Rsh to 2cnrs to start, finish facing 1cnrs

17--::

  Corners Pass & Turn in 1diag, 1c pass Rsh ; Corners Pass & Turn in 2diag to 2plx (2,1x,3)

25--::

  Reels3{6} on sidelines, 1c Lsh to 1cnrs to start | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10483, '2018-03-04 22:11:16.39295+00', '2018-03-04 22:14:14.73838+00', 5902, 1, NULL, 'ace', '1--::

  1W+2W dance Rsh round P and face P close by ; set to P | twirl R to own side (1,2)

9--::

  1M+2M repeat (1,2)

17--::

  1c lead down and up

25--::

  1c+2c Allemande



', 3);
INSERT INTO 'dancecrib' VALUES (10285, '2017-12-02 17:38:08.340339+00', '2017-12-03 19:01:44.211664+00', 11037, 1, 202, 'ace', '1--::

  1c Fig8 down round 2c

9--::

  1c followed by 2c lead down ; and up, 1c passing between 2c, both staying in the middle, 3c step in for

17--::

  3C Promenade (1,2,3)

25--::

  1c set | cross RH ; cast (2c up) | cross LH to 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3299, '2012-01-22 19:30:19.57371+00', '2020-12-17 22:39:01.489968+00', 6224, 1, NULL, 'ace', '1–::

  1c lead down crossing below 2c and behind 3c to 3plx (2c+3c up) ; 3c+1c circle4 {3}, on last bar 1c cast up to 2plx _while_ 3c dance down to 3pl (2,1x,3)

9–::

  1c ½ DblFig8 with 3c (both C cross Lsh in middle) ; ½ DblFig8 with 2c (2x,1x,3x)

17–::

  2c+1c+3c dance BtoB ; 2c+1c+3c turn BH 1½

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (3302, '2012-01-22 19:30:19.693228+00', '2020-05-21 09:19:08.616836+00', 11190, 1, NULL, 'ace', '1–::

  1c cross RH | cast off 2 (2c+3c up) ; 2c+1c set, cross RH and stay inside sidelines (2x, 3,1)

9–::

  2c+1c M-Chain up/down

17–::

  3W+1M change places LH | 3M+1W repeat RH ; 2c+1c+3c set | cross RH

25–::

  All Circle6 and back.', 2);
INSERT INTO 'dancecrib' VALUES (14451, '2021-11-15 17:21:16.618487+00', '2021-11-15 17:21:16.618487+00', 16142, 2, 963, 'ace', '1-2::  
  1C cast one plc (2s up)
3-4::  
  1C pass Lsh, 1c give LH to 1st crn and pivot into prom hold (1st crns on right)
5-8::  
  1C with crn in prom hold pass Lsh for 1/2 reel 4 on 2nd crn diag back to crn  
9-12::  
  1C with crn, release LH, dance in for 1/2 RHA and out to 3x,1x,2x
13-24::
  R&Ls for 3Cs ; 3M and 2W finish facing out; 1W facing up 1M facing down
25-28::  
  3C,1C,2C 1/2 Lsh R3 on the side  2x,1x,3x
29-32::  
  All set and cross RH  (2nd time thru 3C&1C 1/2 RHA)
  
', 5);
INSERT INTO 'dancecrib' VALUES (3296, '2012-01-22 19:30:19.454571+00', '2017-07-20 16:43:27.718739+00', 12739, 1, NULL, 'ace', '1–::

  1M+2W turn RH ; 1c+2W LHA opening into line facing down, 1M in the middle, 1W on own side, 2W on M side

9–::

  In line across dance down the middle, 2M following, all turn right about ; 2M leads the women back up, 1M following. Finish in a diamond, with 2M at the top facing 1M in 2pl, the W in the sidelines.

17–::

  All set | petronella turn ; set | petronella turn, finishing (1x,2).

25–::

  1c dance between 2c, cast up ; cross RH | cast to 2pl (2c up).', 3);
INSERT INTO 'dancecrib' VALUES (10853, '2018-06-19 06:22:25.686876+00', '2018-07-04 01:28:14.417416+00', 18386, 1, 202, 'ace', '1--::
  1c ½ Fig8 down round 2c ; 1c+2c S&Link, 1W & 2W face out (2,1x)
9--::
  2c+1c M-Chain (2,1x)
17--::
  2c+1c chase clw ½ ; set | turn RH ½ to centre, facing up (1x,2)
25--::
  1c cast to 2plx _while{2}_ 2c lead up to 1pl | all set ; 1c ½ Fig8 up round 2c (2,1) ', 5);
INSERT INTO 'dancecrib' VALUES (10286, '2017-12-03 13:52:09.633529+00', '2017-12-06 12:37:38.91382+00', 17737, 1, 202, 'ace', '1--::

  2c & 4c Mirror Fig8 on sidelines, starting in

9--::

  1c+2W & 2M+3c+4W & 4M+5c RHA ; 1c+2M & 2W+3c+4M & 4W+5c LHA, 2c & 4c finishing facing 1cnrs

17--::

  Corners Pass & Turn in 1diag ; Corners Pass & Turn in 2diag (1,2,3,4,5)

25--::

  1c+2c & 3c+4c S&Link (to 2,1,4,3,5) ; 1c+4c & 3c+5c S&Link (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (10287, '2017-12-03 22:10:24.416027+00', '2017-12-04 09:44:16.974042+00', 11031, 1, 202, 'ace', '1--::

  1c cross RH | cast below 2c ; cross RH | cast back to 1pl (1,2)

9--::

  1c lead down ; and up, staying in the middle, 2c step in for

17--::

  2C Allemande (2,1)

25--::

  Circle4 and back



*Repeat in Reel Time from new positions.*', 4);
INSERT INTO 'dancecrib' VALUES (3307, '2012-01-22 19:30:19.87703+00', '2015-02-16 00:51:32.367559+00', 13614, 1, NULL, 'ace', '1–::

  Mirror Reels3 on the sides, all Cs crossing down from the top (1x,2x,3x)

9–::

  1c slip down the middle ; and up to 2plx (2c up on [11-12])  (2x,1x,3x)

17–::

  All S&Link to lines across ; All A&R up/down

25–::

  All S&Link (3,1,2) ; All turn P RH into

33–::

  Allemande (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3304, '2012-01-22 19:30:19.759154+00', '2014-04-30 23:24:11.127485+00', 10853, 1, NULL, 'ace', '1–::
  1c dance below 3c and cast up to places | set (1,2,3)
9–::
  Mirror Reels3 on the sides, all cross down from the top , finish (1x,2x,3x)  with 2c facing out
17–::
  Reels3 on the sides, 2c starting out and down, and all cross up from the bottom, to (1,2,3), 1c facing 2c
25–::
  1c set to 2c | all set to P ; 1c casts off (2c up) | 2c+1c set, each dancer swiveling R about. (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14617, '2022-02-20 17:43:25.458043+00', '2022-02-20 17:43:52.131377+00', 1960, 1, 1645, 'ace', '1-::

  1c+2c set | &frac34; DblFig8 (2,1x,3)

9-::

  1c+2W RHA ; 1c+3M LHA, 1c end facing 1cnrs

17-::

  1c+1cnrs diag RSh Reel4, 1c end as if passing RSh but turn towards P & touch LH, 1M facing up, 1W down

25-::

  1M+2W+3W & 1W+2M+3M RHA ; 2c+1M & 1W+3c LHA (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3872, '2013-08-05 07:20:39.450785+00', '2016-08-21 22:01:10.3875+00', 15044, 1, NULL, 'ace', '1–::

  1c+2M & 3c+4M RHA 1¼, 1c & 3c finishing in middle facing down, other cpls in own place ; 1c+2W & 3c+4W LHA, finish facing down

9–::

  1c+4M & 3c+5M RHA same way ; 1c+4W & 3c+5W LHA, 1W & 3W face out on own side with P behind

17–::

  1c & 3c (W leading) cast up 1 place, cross, cast up on M side to original places the W looping R

25–::

  1c cross | cast 1 (2c up) ; 1c followed by 3c dance up & cast to (2,3,1x,4,5)

33–::

  1c cross | cast 1 (4c up) ; 1c followed by 5c dance up & cast to (2,3,4,5,1)', 2);
INSERT INTO 'dancecrib' VALUES (3310, '2012-01-22 19:30:19.987008+00', '2014-04-30 23:24:11.218468+00', 6250, 1, NULL, 'ace', '1–::
  1c+3c turn RH ½  | dance down in promhold ; cross below 3pl/5pl and cast up to face 1cnr _while_{8} 2c+4c set | cast up one ; stand for [5-8]
9–::
  1c+3c 1cnr pass and turn and swivel R to face 4cnr ; 4cnr pass and turn (to 2,1,4,3,5)
17–::
  1M+1W+3M+3W each dance Fig8 round couple to their L (between 4c, 1W & 3M pass RH first time, LH second time) _while_{8} 2c+4c+5c set | cross RH ; set | cross LH
25–::
  1c+3c set advancing to midline with P on R | BiL ; 1c+3c turn ¾RH | cast off to 3pl / 5pl (4c+5c up) (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (10234, '2017-11-09 00:07:06.967305+00', '2019-01-18 19:33:19.26535+00', 18044, 2, 1645, 'ace', '1-::

  1c+2c &frac12; turn P RH | 1c+2c &frac12; RHA ; 1c+3c LHA

9-::

  1c turn 1 &frac14; LH to centre line ; 2c+1W & 1M+3c RHA to sides (2,1,3)

17-::

  1c cross RH | cast R ; cross LH | cast L _while{8}_ 2c+3c set | cross RH ; set | change places LH on the side (3x,1,2x)

25-::

  1c cross LH | cast L ; cross RH | cast R _while{8}_ 3c+2c set | cross RH ; set | change places LH on the side (2,1,3)

::

  *After 2nd repeat, 1c dance [1-4] again with 4c to end in 4th place*

', 3);
INSERT INTO 'dancecrib' VALUES (8166, '2014-02-04 22:27:02.34203+00', '2014-04-30 23:24:11.239313+00', 9390, 1, NULL, 'ace', '1–::
  1c set | cross down (2c up) ; set to P | turn 1¼ LH to face 2cnr
9–::
  2cnrs pass and turn (pass 2cnr Rsh, corners turn RH, pass back) 1c meets swiveling R into BtoB facing corners ; 1cnrs pass and turn, 1c meets swiveling ¼R ready for
17–::
  2c+1W & 1M+3c RHA ; unwinding (1c trailing) into chase ½ clw (to 3x,1,2x)
25–::
  3c+1M & 1W+2c LHA ; unwinding (1c trailing) into chase ½ cclw (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3311, '2012-01-22 19:30:20.023792+00', '2014-04-30 23:24:11.244752+00', 6255, 1, NULL, 'ace', '1–::
  1c set | cast off (2c up) ; All turn RH and face up in allemande hold
9–::
  2c+1c+3c Allemande, on [15-16] 3c+2c cross RH as 1c turn LH to face their 3cnr (pos)
17–::
  1c ½ diag Reel4 with 1cnrs, pass Lsh ; ½ Reel4 with 2cnrs (2,1,3)
25–::
  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (3312, '2012-01-22 19:30:20.071184+00', '2017-02-06 16:34:45.437644+00', 14400, 1, NULL, 'ace', '{{explanation}}

Woman on the R of her partner, all forming a single circle.



1–::

  All A&R ; circle L

9–::

  All A&R ; circle R

17–::

  All W fig8 round P and cnr, dancing in front of P to begin

25–::

  All M repeat, finish facing P in the circle

33–::

  Change places RH | with next person LH ; turn next person BH and open up into big circle', 3);
INSERT INTO 'dancecrib' VALUES (3313, '2012-01-22 19:30:20.109261+00', '2015-05-12 22:29:42.659781+00', 11113, 1, NULL, 'ace', '1–::

  All set | dance BtoB | set

9–::

  2c+4c ½ DblFig8 round 3c (2c cast, 4c cross up) ; 1c & 5c ½ Fig8 round nearest C (cross to start) (1x,2x,3,4x,5x)

17–::

  3c cross RH, cast R round end, dance in through the middle and pass Rsh into 3plx (1x,2x,3x,4x,5x)

25–::

  1c dance to the bottom and cast to 5plx (other Cs up) | all cross RH (2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (14616, '2022-02-20 16:31:25.360283+00', '2022-02-20 16:33:27.592891+00', 19980, 1, 1645, 'ace', '1--::

  *&frac34; Snowball Chain:* 1c cross RH | 1c+2c change pl LH ; 2c+1c cross RH | 2c+1c set (2x,1)

9--::

  *Circulating Knot:* 2c & 1c &frac12; turn RH into allemande hold, BtoB, 2c facing up for inverted Knot, 1c facing down for standard Knot & end with LH turn to face other couple in allemande hold (1x,2)

17--::

  *Circulating Allemande:* 1c, facing down, dance inverted Allemande _as_ 2c, facing up, standard Allemande (2,1x)

25--::

  2c+1c set | 1c &frac12; Fig8 up through 2c | 2c+1c set (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (14187, '2021-08-06 08:46:00.720943+00', '2021-08-06 08:51:00.081783+00', 10978, 1, 202, 'ace', '1--::

  1M casts to below 3c _while_ 1W dance down the middle. 1c (1W leading) cast up 1 place (2c up on [3-4]), ½ Fig8 L round 3M to 2pl (2,1,3)

9--::

  All set | 1c turn P RH ½, face P and pivot R to dance RSh round 1cnrs

17--::

  Reels3 across, 1c LSh to 4cnrs (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10486, '2018-03-05 07:29:14.305325+00', '2018-11-09 20:10:49.731826+00', 13975, 1, 202, 'ace', '1--::

  1c & 2c dance BtoB ; 1c NHJ cast off to 2pl _while{4}_ 2c dance up and loop to 1pl (2,1,3)

9--::

  1c+1cnrs A&R diagonally ; repeat with 2cnrs (2,1,3)

17--::

  1c pass P Lsh, Rsh round 1cnrs, pass P Lsh, Rsh round 2cnrs, pass P Lsh to 2pl facing out (2,1,3)

25--::

  Reel3 on sidelines, 1c Lsh to 4cnrs to start, on [31-32] 1c may pass P Rsh to 2pl or not, pulling Rsh back to 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3314, '2012-01-22 19:30:20.149027+00', '2017-02-13 02:28:06.886853+00', 6271, 1, NULL, 'ace', '1–::

  1W+2M & 3W+4M set and change place RH ; all set to P and change place RH

9–::

  Parallel Reels4 on the sides

17–::

  With NHJ on the sides all set | cross RH ; 1c+2c & 3c+4c circle4 left {3} and form diagonal lines for

25–::

  2c+1c & 4c+3c ½Poussette to (1,2,3,4) ; 1c lead down and cast up into 4pl (2c+3c+4c up) (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (11780, '2019-04-10 12:31:20.179329+00', '2019-04-10 12:36:42.219084+00', 13637, 1, NULL, 'ace', '1--::

  All Circle6 and back, finish in promhold

9--::

  All Promenade (1,2,3)

17--::

  3c lead far up ; and down, to place, on [24] 1c+2c step in and face each other NHJ

25--::

  1c+2c Rondel (2,1,3)

33--::

  2c+1c Poussette (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (3316, '2012-01-22 19:30:20.260686+00', '2015-06-24 23:28:42.115256+00', 11769, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; 1c petronella into DTr position | all set as in DTr

9–::

  1c dance out and cast R round 1cnr to between end couple _while{4}_ 2c+3c A&R diagonally ; 1c petronella into DTr position (BtoB, M below W) | all set as in DTr

17–::

  1c dances between end couple and cast R round 4cnr _while{4}_ 2c+3c A&R diagonally (to 2,1,3) ; Teapots R (1c RHA with couple on R), finish facing 1cnr

25–::

  SetH&G (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3323, '2012-01-22 19:30:20.530995+00', '2017-07-07 14:24:41.989919+00', 6323, 1, NULL, 'ace', '1–::

  1c lead down the middle, cross below 3c and cast up one place (2c up) ; 2c+1c+3c turn BH (1c Turns 1½) (2,1,3)

9–::

  1c cast up one place, dance between 2c, turn BH (1M uses RH to help P) to face 1cnrs

17–::

  Turn corner, P, corner, P

25–::

  1c set to 1cnr | to 2cnr, finishing between corners ; 2c+1c+3c turn RH (1c 1½ turn) to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12890, '2020-06-21 13:19:30.550743+00', '2020-06-21 13:20:01.214846+00', 6056, 1, 202, 'ace', '1--::

  1c & 4c set | 1W & 4M cast inwards (2W & 3M step out) ; 1W+4M turn RH into centre BtoB facing own sides between 3W & 1M

9--::

  Diagonal Reel4 starting LSh. On [15-16] 1c pass P LSh to sides as on [5]

17--::

  New ends set | 1M & 4W cast inwards (2M & 3W step out) ; 1M+4W turn LH into centre BtoB  facing own sides between 1W & 4M (2,1,4,3)

25--::

  Diagonal Reel4 starting RSh. On [23-24] 1c pass P RSh to sides as on [21]

33--::

  1c cross RH | cast off (4c up) ; ½ Fig8 down round 3c (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10157, '2017-10-02 09:40:47.588048+00', '2020-11-10 12:25:49.851944+00', 17888, 1, 202, 'ace', '1--::

  1c & 3c cross down RH to 2plx/4plx respectively facing out (2c & 4c up) | 1c+4c & 3c+5c change pl EH on sides ; 1c & 3c ½ Fig8 up (2,4,1,5,3)

9--::

  Top 2 cpls & bottom 2 cpls RHA _while{4}_ 1c turn RH ; 4c+1W & 1M+5c LHA _while{4}_ 2c+3c turn LH (2,4,1,5,3)

17--::

  Top & bottom 2 cpls S&Rotate (4,2,1,3,5)

25--::

  All chase{6} clw ½ | All cross RH (5,3,1,2,4)', 4);
INSERT INTO 'dancecrib' VALUES (3318, '2012-01-22 19:30:20.339745+00', '2014-04-30 23:24:11.435976+00', 13615, 1, NULL, 'ace', '1–::
  1c+3c lead down {3}, up {3} | and cast off (2c+4c up) (2,1,4,3,5)
9–::
  2c+1c DblFig8 (1c crossing up) _while_{8} 4c+3c+5c mirror Reels3 on the sides (3c start in and down) (2,1,4,3,5)
17–::
  2c+1c+4c mirror Reels3 on the sides (1c start in and down) _while_{8} 3c+5c DblFig8 (3c crossing down)  (2,1,4,3,5)
25–::
  1c+3c cross RH | cast off (4c+5c up) ; ½ Fig8 up (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (3628, '2012-07-21 11:46:13.763196+00', '2014-04-30 23:24:11.497012+00', 11292, 1, NULL, 'ace', '1–::
  1c cross down RH, cast behind 3c and lead to the top, cast off (2c up) (2,1x,3)
9–::
  Mirror Reels3 on the sides, to start 1c cross LH to 3pl and 3c cast up, 2c+3c finish with loops (2,1,3)
17–::
  All set | advance {1} and touch P''s RH and retire {1} ; All turn LH, 1c finish facing 1cnr
25–::
  Corners pass and turn, 1c take RH in passing (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3846, '2013-07-13 15:56:21.332546+00', '2016-01-29 23:59:25.023191+00', 14648, 1, NULL, 'ace', '1-4::

  1c Petronella Turn _while{2}_ 2c cast up with PdB to 1pl to make diamond shape | all set ;

5-16::

  1c+2c continue full petronella together, 1c ends in 1pl, and 2M (above) facing 2W on midline

17-20::

  1c dance down the middle _while{2}_ 2W casts up (Lsh to 1W) and joins 2M to dance down the middle behind 1c

21-24::

  2c makes an arch, 1c dances up under it and to the top, 2c following

25–::

  1c+2c Poussette



*Common variant: 2c step up on [1-2]*



', 3);
INSERT INTO 'dancecrib' VALUES (3317, '2012-01-22 19:30:20.300455+00', '2016-04-26 00:10:11.656215+00', 6287, 1, NULL, 'ace', '1–::

  1c+2c RHA ; 1c cast off _while{2}_ 2c dance to top | 1c set advancing swiveling R to finish BtoB facing own sides for

9–::

  DTr, finish with a petronella to between end couples facing 4cnr

17–::

  Rsh Reels3 across (to 2,1x,3)

25–::

  2c+1c+3c circle6 L {6} | 1c cross RH', 3);
INSERT INTO 'dancecrib' VALUES (10288, '2017-12-04 00:26:45.192735+00', '2017-12-04 10:50:26.444897+00', 11029, 1, 202, 'ace', '1--::

  All set | 1W followed by 1M & 3W followed by 3M chase inside cclw ¼ to face odd cpls ; all set | 1W followed by 1M & 3W followed by 3M chase cclw ¼ to exchanged places (3,2,1,4)

9--::

  Repeat [1-8] with 2c & 4c (3,4,1,2)

17--::

  Double M-Chain, finishing all W facing out

25-40::

  Schiehallion Reel

41--::

  Circle8 and back



*Repeat in Reel Time from new positions.*', 4);
INSERT INTO 'dancecrib' VALUES (8153, '2014-01-11 13:53:46.688474+00', '2014-11-09 21:46:00.978184+00', 6295, 1, NULL, 'ace', '1–::

  1c+2c R&L

9–::

  1c Fig8 round 2c (1,2)

17–::

  1M+2W Turn RH to places ; 1W+2M turn LH to midline, facing P who steps in on [24]

25–::

  1c+2c Poussette



{{explanation}}

Danced in a 4C set, all couples starting', 3);
INSERT INTO 'dancecrib' VALUES (1714, '2012-01-22 19:28:57.986394+00', '2021-07-03 14:18:20.25351+00', 340, 1, NULL, 'ace', '1–::

  3c followed by 1c dance down the middle | set ; dance up the middle, 1c cast off to 3pl _while{2}_ 3c dance up to 1pl (3,2,1)

9–::

  »Pick-up chain«, from below: 1c cross RH, 1c+2c change places LH ; 1c+3c change places RH _while{2}_ 2c cross RH ; 1c cross LH _while{2}_ 3c+2c change places LH (to 1,2x,3)

17–::

  1c+2c set advancing to join NH in a circle | releasing hands, 1c+2c Petronella one place R ; Set NHJ | repeat petronella, to sidelines (2,1x,3)

25–::

  1c ½ Fig8 L (W up, M down) ; All turn RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10291, '2017-12-05 11:32:12.758793+00', '2018-02-01 00:35:18.193811+00', 18102, 1, NULL, 'ace', '1--::

  1c+3c petronella to midline | set to P ; partners change place RH | 1W+3M change place LH

9--::

  Reel4 and chase: 1M+3W ½ Reel4 on midline ; chase ½ clw _while{8}_ 2c chase ¼ clw | ½ Reel4 | chase ¼ clw _while{8}_ 1W+3M pass opposite Rsh | chase ½ clw | dance in along midline and pivot R to face same end (All face P).

17--::

  1c+3c petronella turn to own side | All set (1,2,3) ; All turn P RH to finish BHJ for

25--::

  3C Poussette (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10158, '2017-10-02 23:20:09.550227+00', '2020-10-03 18:15:45.227865+00', 14965, 1, 202, 'ace', '1--::

  Mirror Reels3, 1c start in and down (1,2,3)

9-24::

  2c+3c S&Link ; 1c+3c+2c 3C R&L

25--::

  3C Knot (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (14053, '2021-05-30 16:28:27.434241+00', '2021-05-30 16:32:50.09226+00', 8447, 1, 202, 'ace', '1--::

  1c set | cast off 2 places (2c+3c up) ; 1c set | cast up (3c down) (2,1,3)

9--::

  1c turn RH ½ | 2c+1c ½ RHA (to 1,2x,3) ; 1c lead up and cast to 2pl _while{4}_ 2c turn RH ½ and lead up to 1pl (2,1,3)

17--::

  1c+3c set | ½ RHA ; repeat [17-20] (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10265, '2017-11-21 10:46:58.931297+00', '2021-08-06 09:46:23.928454+00', 11968, 1, 202, 'ace', '1--::

  1c+2c ½ RHA | set ; 1c+3c ½ LHA | set (2x,3x,1)

9--::

  1c cast up round 3c, dance to top (3c down on [11-12]), cast off round 2c to 2pl | Petronella turn into lines of 3 across

17--::

  All A&R ; ½ Reels3 across, 1c Rsh to 1cnr position to start (2,1,3)

25--::

  Circle6 and back



*Note on variations (devisers):*



- On 1st(2nd) time through, 1W(1M) ends in centre [24], dancing (set, clog, step dance) for 6 bars _while_ all Circle5 and back; on [31-32], Circle breaks so that 1W(1M) dances to 2pl.

- 3c can step down on [9-10] instead of [11-12]', 2);
INSERT INTO 'dancecrib' VALUES (3322, '2012-01-22 19:30:20.490615+00', '2019-03-07 22:47:26.203053+00', 7521, 1, NULL, 'ace', '1–::

  1c+4c advance to centre on diagonal and retire ; long cast to middle places (2c+3c step to ends)

9–::

  2c+3c Repeat from new places (1,2,3,4)

17–::

  1c cross RH, cast off one (2c up) ; cross LH, cast off 2 (3c+4c up)

25–::

  All turn RH ; turn LH (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (3324, '2012-01-22 19:30:20.571004+00', '2019-03-09 21:48:37.215853+00', 6328, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; ½ Fig8 up (2,1,3,4)

9–::

  1c+3c+4c Mirror Reels3, 1c starts in and down

17–::

  1c cross RH | cast off (3c up) ; ½ Fig8 round 4c (2,3,1,4)

25–::

  2c+3c+1c Mirror Reels3, 1c start in and up

33–::

  1c cross RH | cast off (4c up) ; turn RH 1½ (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (3327, '2012-01-22 19:30:20.69064+00', '2014-10-13 14:17:04.28974+00', 6349, 1, NULL, 'ace', '1–::

  1c+2c+3c set, ½ circle6 L ; repeat

9–::

  1c lead down below 2c, cross and cast round 3c ; dance up to the top, cast to face 1cnrs (2c up)

17–::

  1c turn corner, P, corner, P to finish between corners

25–::

  2c+1c+3c A&R ; 1c turn BH 1½', 3);
INSERT INTO 'dancecrib' VALUES (10292, '2017-12-05 16:37:40.249789+00', '2017-12-05 16:43:42.670096+00', 17465, 1, 202, 'ace', '1--::
  1c set | cast (2c up) ; turn LH to face 3W, 1W behind 1M
9--::
  ½ tandem reel3 in 1diag, 1c Lsh to 3W to start ; ½ tandem reel3 in 2diag, 1c Lsh to 3M to start, 1c finishing in centre 1W on 1M''s L, NHJ facing up
17--::
  Mirror Reels3, 3c in and down to start, all joining NH with P when possible (3x,1x,2x)
25--::
  3M+1M+2M NHJ slip to the R to own side _while{4}_ 3W+1W+2W slip to the L to own side, M passing behind W ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3629, '2012-07-21 11:46:14.064472+00', '2019-10-03 19:28:04.078677+00', 8743, 1, NULL, 'ace', '1–::

  1c lead down (2c up) ; 1c lead up | turn RH into promhold facing 2M

9–::

  1c with 2M+3M Rsh Reel3, finish facing 2W

17–::

  1c with 2W+3W Lsh Reel3, finish 1c facing up LHJ and 2c facing 3c (2, 1mid, 3)

25–::

  2c+3c R&L starting up/down  _while_{8}   1c lead up, cross, cast off, lead down LHJ, cross, cast up to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3402, '2012-01-22 19:30:23.877123+00', '2016-08-30 21:24:58.073537+00', 6634, 1, NULL, 'ace', '1–::

  1c+2c Reel4 across, (1W+2M pass Lsh in middle to start) (2,1,3)

9–::

  2c+1c+3c G-Chain (2c cross at beginning)

17–::

  2c+1c R&L

25–::

  1c dance between 3c | cast up ; dance up between 2c | cast off to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14618, '2022-02-21 09:02:45.65781+00', '2022-02-21 09:05:33.121794+00', 17971, 1, 202, 'ace', '1--::

  1c cast off (2c up) | all set ; 1c+1cnrs dance BtoB (2,1,3,)

9--::

  1c+2cnrs dance BtoB ; all set | 1c cast off (3c up) (2,3,1)

17--::

  All A&R ; all turn P RH into promhold (2,3,1)

25--::

  3C Promenade (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (7907, '2013-08-21 08:31:51.184484+00', '2023-02-04 01:23:10.962387+00', 13538, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1L+2M chase 1/2 way as partners set, all cross RH with opposite
    dancer, 1M+2L chase 1/2 way as partners set & all cross RH with
    partner.  2 1
17-24::
    1s & 2s dance DoSiDo, 1s+2s dance RH across
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (15096, '2022-09-10 10:55:06.011195+00', '2022-09-10 10:55:06.011195+00', 11886, 2, 1, 'ace', '1–4::
  1c set | 1M+2L set [1M adv to middle]
5–8::
  1c+2L ½ Reel3 [1M LS to 1L to start; fin 1M in orig pl, 1L&2L have changed pl]
9–12::
  1L [in 2pl] + 2M set | 1c set [1L adv to middle]
13–16::
  1c+2M ½ Reel3 [1L LS to 2M to start; fin 1c in middle below 2C facing up]
17–::
  1c dance up | cast round 2c ; set adv | cast RS to own sides
25–::
  Rights and Lefts', 3);
INSERT INTO 'dancecrib' VALUES (13537, '2021-01-09 01:22:11.712126+00', '2023-02-04 01:23:11.128613+00', 7077, 3, NULL, 'ace', '{{explanation}}
Non-progressive Square Set

1-8::
    All Ladies cast behind partner & chase clockwise round, back to
    place
9-16::
    All Men cast behind partner & chase anticlockwise round, back to
    place
17-24::
    1s+3s Adv+Ret & dance DoSiDo with opposite dancer
25-32::
    2s+4s repeat 17-24
33-40::
    All circle 8H round & back (OR all chase clockwise round back to
    place)', 0);
INSERT INTO 'dancecrib' VALUES (13561, '2021-01-18 23:20:11.838275+00', '2021-01-18 23:22:42.010945+00', 10438, 1, 1645, 'ace', '1-::

  1c+2c & 3c+4c RHA ; 1c & 3c cast off _while{2}_ 2c & 4c lead up | 1c & 3c set advancing swiveling R to finish BtoB facing own sides for

9-::

  Double DTr, on [15-16] 1c & 3c petronella to face own sides, 1W/3M between 2c/5c, 1M+3W BtoB between 4c

17-::

  1W+2c & 3M+5c RSh Reels3 across at top/bottom _while{8}_ 1M+3W+4c RSh Reel4 across in 3pl, all ending on sides (2,1x,4,3x,5)

25-::

  1c+4c & 3c+5c Circle4 1&frac12; to L (2,4x,1,5x,3) | 4c & 5c cross RH (2,4,1,5,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3863, '2013-07-21 10:05:38.124244+00', '2014-04-30 23:24:11.616458+00', 14981, 1, NULL, 'ace', '1–::
  1c set | ½ turn BH (finish NHJ facing up) ; cast to 2plx (2c up) | turn RH into
9–::
  1c, in allemande hold, down the middle, turn in as in Gay Gordons, and up to 2pl (2,1x,3)
17–::
  Mirror Reels3 on the sides (1c out and up) , finish facing 1cnr
25–::
  1cnrs pass and turn ; 2cnrs pass and turn (2,1,3)
33–::
  1c+3c set | 1W cast off and 3M cast up _while_{2} 1M+3W pass Rsh to (2,3,1) ; 3c+1c RHA (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3239, '2012-01-22 19:30:17.010619+00', '2019-03-10 19:02:20.671913+00', 5996, 1, NULL, 'ace', '1–::

  1c Fig8 round 2c

9–::

  3c Fig8 round 2c

17–::

  All M dance Rsh loop round P ; all W repeat

25–::

  2c dance down between 3c, cast up, dance up between 1c, cast off

33–::

  1c lead down the middle {3}, up {3}, cast to bottom (2c+3c up)', 3);
INSERT INTO 'dancecrib' VALUES (11781, '2019-04-10 13:07:47.028332+00', '2019-04-10 13:24:27.161711+00', 11645, 1, NULL, 'ace', '*Couple face couple Round the Room*

1--::

  RHA ; LHA

9--::

  All set twice to P ; Turn BH

17--::

  BHJ with P Slip (M to L, M pass BtoB) ; and back (W pass BtoB)

25--::

  Circle4 L ; Set to opposite | pass opposite Rsh to meet next cpl

', 3);
INSERT INTO 'dancecrib' VALUES (10290, '2017-12-05 00:51:25.385756+00', '2017-12-07 10:16:51.690569+00', 11033, 1, 202, 'ace', '1--::
  1c+2c & 3c+4c RHA ; LHA
9--::
  1c & 4c set | cast inwards (2c & 3c to end) ; 1c+4c ½ R&L finishing facing out the ends between end cpls who face up/down
17--::
  All set twice ; 1c & 4c drop hands with P, turn ¾ easy way to sidelines, end cpls facing out (2,4x,1x,3)
25--::
  All set twice, end cpls pivoting to face in ; 4c & 1c turn RH 1 ½ (2,4,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3295, '2012-01-22 19:30:19.414442+00', '2014-04-30 23:24:10.970778+00', 6202, 1, NULL, 'ace', '1–::
  1c+2c A&R ; dance BtB
9–::
  1c+2c A&R ; ½ R&L (2x,1x)
17–::
  1c ½ Fig8 up ; 2c+1c turn RH
25–::
  2c ½ Fig8 down ; 2c+1c turn RH', 2);
INSERT INTO 'dancecrib' VALUES (13119, '2020-08-23 20:13:44.885338+00', '2020-08-24 08:47:15.036587+00', 20070, 2, NULL, 'ace', 'The Bleecker Reel (R3x40) (3 dancers in a triangular set) Sue Trapp, Leaflet.  

Dancers are numbered anticlockwise from the top: dancer 1 at the top, etc



1-::

  Top dancer (1) turns dancer 2 ("1st corner") RH then dancer 3 ("2nd corner") LH & finish facing dancer 2

9-::

  Reel of 3. To begin, dancer 1 gives RSh to dancer 2. To finish, dancer 1 dances back to top place

17-::

  All set & petronella one place anti-clockwise; repeat one more place. Dancer 2 is now at top

25-::

  All dance RH across & LH back

33-::

  All circle 3H round & back

', 4);
INSERT INTO 'dancecrib' VALUES (14046, '2021-05-27 19:24:27.987587+00', '2021-05-31 01:17:42.191446+00', 17285, 1, 202, 'ace', '1--::
  5c (+4c+3c+2c+1c following) lead down ; 1c (+2c+3c+4c+5c following) lead up (1,2,3,4,5)
9--::
  1c & 3c cross RH | cast off (2c & 4c up) (to 2,1x,4,3x,5) ; 1c & 3c turn P RH 1¼ into midline
17--::
  Reel4 on midline _while{8}_ 2c+4c+5c Reels3 on sides, 2W+4W & 4M+5M passing RSh. 1W faces up, 3M faces down
25--::
   1c (1W leading) dance RSh round 2W to 2plx _while{4}_ 3c (3M leading) dance RSh round 5M to 4plx. 1W & 3M face out ; 2c+1c & 3c+5c RHA. 1W & 3M face out (2,1x,4,3x,5)
33--::
  1c (1W leading) cast off to 3pl _while{4}_ 3c (3M leading) cast off to 5pl (4c & 5c up on [35-36]) ; all turn P RH (2,4,1,5,3)
41--::
  Circle10 and back (2,4,1,5,3)', 4);
INSERT INTO 'dancecrib' VALUES (3329, '2012-01-22 19:30:20.770989+00', '2021-03-14 20:29:36.730839+00', 11533, 1, NULL, 'ace', '1–::

  1c+4c dance to the middle and meet | dance out NHJ on own side and cast to places facing in ; 1c+2c & 4c+3c turn on sideline EH 1½ (2,1,4,3)

9–::

  1c+4c RHA (to sidelines) ; LHA

17–::

  2c+1c & 4c+3c circle4 L ; and back

25–::

  1c dance to top facing out {1} and turn 2c EH 1½ _while{4}_ 4c dance down and cast up to 4pl (3c up) ; 1c (start inwards) change place with 3c EH {1} and (start outwards) turn 4c 1½ EH to (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (11778, '2019-04-10 10:08:09.961114+00', '2019-04-11 10:58:30.019178+00', 13889, 1, NULL, 'ace', '1--::

  1c set | cross RH ; cast off (2c up) | turn LH to face 1cnr

9--::

  1c+1cnrs ½ diag. Reel4, 1c pass Rsh into ; 1c+2cnrs ½ diag. Reel4,  in both half reels the cnrs clap LH and 1c clap RH when passing 

17--::

  1c turn 1cnr persons (in 3cnr pos) RH into promhold, cross diagonally passing Rsh, leave 1cnr in own place | 1c turn LH to face 4cnr (pos)

25--::

  1c turn 2cnr persons RH into promhold, cross diagonally passing Rsh, leave 2cnr person in own place | 1c cross RH (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (3339, '2012-01-22 19:30:21.170742+00', '2017-11-25 01:07:40.106289+00', 6382, 1, NULL, 'ace', '1–::

  1c+2c set | circle4 | turn P BH into

9–::

  1c+2c+3c mirror Reels3 on own sides, 1c in and 2c out and up to begin (1,2,3)

17–::

  1c+2c Chain progression: 1c+2c turn RH ¾, 1M+2W turn LH 1½ _while{2}_ 1W & 2M chase clw ½ round, 2c+1c turn ¾ RH (to 2,1,3)

25–::

  All circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (3330, '2012-01-22 19:30:20.810868+00', '2014-04-30 23:24:11.661966+00', 6359, 1, NULL, 'ace', '{{explanation}}
Can be danced by any number of couples, add 12 bars for each extra couple; Running step throughout, 3 steps per bar.

1–::
  1c turn RH 2½ ; 1W turn 2M LH (1M runs down), P RH
9–::
  1W turn 3M LH, P RH ; 4M LH, P RH
17–::
  1M turn 4W LH (1W runs up) P RH ; 3W LH, P RH
25–::
  1M turn 2W LH, P RH ; 1W+2M & 1M+2W turn LH (2c finish one place up), 1c turn RH
33–::
  Repeat with 3c ; repeat with 4c, finishing with 1½ RH turn (may overrun by 2 bars)', 2);
INSERT INTO 'dancecrib' VALUES (3341, '2012-01-22 19:30:21.251025+00', '2021-04-12 21:58:58.437016+00', 6386, 1, NULL, 'ace', '1–::

  1c+2c circle4 to the left ; 1c+2c chase clw ½-round to finish on opposite sides, 2c facing 1c (2x,1x,3)

9–::

  Rsh Reels3 on sides

17–::

  1c, followed by 2c lead down the middle {3}, (2c split for) 1c+2c lead up {3} | and cross to own side RHJ, the W passing below the M and under the joined arms, into

25–::

  1c+2c Poussette (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3337, '2012-01-22 19:30:21.09262+00', '2014-10-27 00:35:01.724075+00', 6381, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; turn 1¼ LH

9–::

  1M+3c & 1W+2c RHA ; 2c+3c chase ½ clw _while{4}_ 1c turn LH to face up (W on L) (3x,1x,2x)

17–::

  1c lead to top , cast off ; lead to bottom, cast up to (3x,1x,2x)

25–::

  All set | all turn RH into the middle, facing clw ; all chase ½ clw (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11518, '2019-01-19 07:35:56.945674+00', '2019-01-19 07:39:34.737279+00', 14620, 1, 202, 'ace', '1--::

  1c set | turn RH and face out | cast to 2pl centre and face down NHJ (2c up) (2,1,3)

9--::

  Reels3 on sides taking hands when possible, 1c in and down, 3c out and up (2,1,3)

17--::

  1c+3c Tourbillon (2,3,1)

25--::

  All A&R ; all dance BtoB (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3336, '2012-01-22 19:30:21.05336+00', '2019-02-04 12:30:26.491509+00', 6380, 1, NULL, 'ace', '1–::

  All C RH turn ; all M stand as all W pass P Rsh to one place clw | All set to ''new P''

9–::

  Repeat bars 1-8, with ''new partners'' (Women end halfway round the set)

17–32::

  Repeat bars 1-16, but turn LH, the W stand, and the M dance cclw (all C end halfway round the set)

33–::

  1c+3c RHA ; both C, M leading, chase clw. round the set to original places

41–::

  2c+4c repeat [33-40] (1,2,3,4)

49–::

  All W Fig8 round P and cnr, starting Lsh

57–::

  Men repeat [49-56], starting Rsh

65–::

  1c+3c change places, 1c passing under 3c arch | set to P ; repeat back to places, 1c making arch

73–::

  2c+4c repeat bars 65-72 with 4c making the first arch

81–::

  All Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (3340, '2012-01-22 19:30:21.210462+00', '2014-04-30 23:24:11.8143+00', 6384, 1, NULL, 'ace', '1–::
  1M+2W & 3M+4W set to each other and change places RH ; 1W+2M & 3W+4M repeat (2x,1x,4x,3x)
9–::
  2c+1c and 4c+3c ½ R&L ; 1c facing 2c, 3c facing 4c set twice on sidelines (1,2,3,4)
17–::
  Reels4 on the sidelines
25–::
  1c lead down {3} and turn inwards on [28] (2c+3c+4c up on [27-28]) ; 1c+4c circle4 left.', 3);
INSERT INTO 'dancecrib' VALUES (10293, '2017-12-05 22:12:31.492837+00', '2017-12-05 22:13:44.080113+00', 17383, 1, 202, 'ace', '1--::

  1W set | cast (2W up) ; 1W dance Lsh round 3W _while{4}_ 1M set | cast (2M up) (2,1,3)

9--::

  Reels3 on sidelines, 1c Rsh to 4cnrs to start, 2W facing out at end

17--::

  1W+2c RHA _while{4}_ 1M dance Rsh round 3M ; 1W+3c LHA _while{4}_ 1M+2c LHA (2,1,3)

25--::

  All A&R ; 1c turn RH', 2);
INSERT INTO 'dancecrib' VALUES (10294, '2017-12-06 13:04:59.148524+00', '2017-12-06 14:16:06.002771+00', 11050, 1, 202, 'ace', '1--::

  1c+4c cast inwards (2c+3c step to end) | 1c+4c Fig8{6} round end cpls touching hands when possible (2,1,4,3)

9--::

  1c+4c Petronella turn to midline | set ; 1/2 Reel4, on [16] 4c+1c dance out to own sides (2,4,1,3)

17--::

  2c+4W & 1M+3c RHA _while{4}_ 4M+1W turn RH ; 2c+4M & 1W+3c LHA _while{4}_ 4W+1M turn LH

25--::

  2c+4c & 1c+3c Poussette', 4);
INSERT INTO 'dancecrib' VALUES (3249, '2012-01-22 19:30:17.449397+00', '2019-03-10 16:14:15.373958+00', 6035, 1, NULL, 'ace', '1–::

  1c+3c ½ L-Chain (polite turn for M) ; turn P RH and face side couple for

9–::

  Parallel Reels4 across

17–::

  1c facing 2c & 3c facing 4c set | turn RH ½ ; 2c/4c dance Rsh past same person and cast clw to 3pl/1pl  _while_{4}   1c+3c set to P | change place RH

25–::

  Circle8 and back (4,1,2,3)', 3);
INSERT INTO 'dancecrib' VALUES (3338, '2012-01-22 19:30:21.130994+00', '2020-04-13 06:23:43.949204+00', 11725, 1, NULL, 'ace', '1–::

  1c+2c+3c Mirror Reels3 on sides, 1c cross down to start (1x,2,3)

9–::

  1c cross | cast off (2c up) ; turn LH to DTr position, W facing up, M down

17–::

  DTr up/down, finish (2,1x,3)

25–::

  1c cross down LH | cast up through 2pl ; dance up NHJ and cast to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12775, '2020-04-23 18:54:47.758523+00', '2020-04-23 19:04:47.175113+00', 9125, 1, 202, 'ace', '1--::

  1c dance down between 2c| cast up to 1pl ; 1c dance down between 3c| cast up facing 1cnrs (2c up) (2,*1*,3)

9--::

  1c set R to 1cnr {1} and L to P {1} | turn ¾ RH ; set R to 2cnr and L up/down to P | turn ¾ RH to 2pl facing out (2,1,3)

17--::

  ½ Mirror Reels3 on sides, 1c out and down (to 3,1,2). 1c in 2pl face down ; 1c turn 2c on sides EH (3,1,2)

25--::

  ½ Mirror Reels3 on sides, 1c out and up (to 2,1,3). 1c in 2pl face up ; 1c turn 2c on sides EH (2,1,3)



*Deviser''s note*:  

At the end of the second time through, the first couple, after turning second couple, dance down to fourth place, nearer hands joined, while fourth couple step up.', 2);
INSERT INTO 'dancecrib' VALUES (12246, '2019-09-24 18:33:08.028304+00', '2021-11-04 22:13:35.78879+00', 19665, 1, 1645, 'ace', '1-::

  1c set | 1M casts off as 1W petronellas to 1pl centre (2c up) ;

  *&laquo;LIGO Set&Link&raquo;* 2W+1W+2M+1M+3M set taking hands in L-shape |

  2W dances to 3M pl _while_ others cast clw to new L-shape (across 1pl & down W side)

9-::

  3W+1W+2M+1M+3M repeat [5-8] ; 1c dance RSh &frac12; way round each other then birl (or turn 1&frac12; RH) to face 1cnr[pos]

17-::

  1c+1cnrs &frac12; diag RSh Reel4, 1c pass LSh to 2cnr[pos] ; repeat with 2cnrs, 1c pass RSh to own side

25-::

  Circle6 & back (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (13203, '2020-09-18 23:54:53.357216+00', '2020-12-07 12:58:28.169392+00', 10409, 1, 202, 'ace', '1--::

  1c+2c RHA ; LHA (1,2)

9--::

  1c Fig8 down round 2c (1,2)

17--::

  1c (2c following) lead down ; 1c (2c following) lead up all remaining in centre (1,2)

25--::

  2C Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2019, '2012-01-22 19:29:15.246643+00', '2023-02-17 11:53:41.436239+00', 1452, 1, NULL, 'ace', '1–::

  1c+2c set, 1c cast off, turn RH and lead up to the top centre _while_{8} 2c turn RH, lead up and cast to 2pl for

9–::

  1c+2c Allemande  (2,1,3)

17–::

  1W+2c & 1M+3c RHA (Teapots R) ; 1c dance (NHJ) up between 2c and cast off one

25–::

  1M+2c & 1W+3c LHA (Teapots L) ; 1c dance (NHJ) down between 3c and cast up into 2pl', 2);
INSERT INTO 'dancecrib' VALUES (8256, '2014-04-24 11:29:26.798483+00', '2021-04-12 22:09:21.437136+00', 6358, 1, NULL, 'ace', '1–::

  All petronella to midline and set ; All turn P BH 1¾, finish on opposite sides, 1c NHJ facing down and 2c+3c on sidelines

9–::

  1c dances between 2c, down behind 3c to meet below 3c ; 1c cross up into ½ Fig8 round 2c, finish BtB between 2c, facing own side

17–::

  1c+2c »Spurtle«(½ Reel4 across, 2c finish in 1pl and 1c fast turn RH to face 3c in the same way) ; 1c+3c »Spurtle«, 3c to 3pl and 1c to facing 1cnr

25–::

  1c set »H&G« to finish (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3630, '2012-07-21 11:46:14.559368+00', '2014-04-30 23:24:11.844935+00', 11293, 1, NULL, 'ace', '1–::
  1c+2c set twice (one PdB up/down, one diagonally, two to P) ; 1c+2c turn RH into
9–::
  1c+2c Allemande, at end all twirl R to own side facing clw round set, and 3c join in (2,1,3)
17–::
  All chase clw ½ round set ; turn P RH (3x,1x,2x)
25–::
  All Circle6 ½ L to places ; All dance BtoB', 3);
INSERT INTO 'dancecrib' VALUES (1941, '2012-01-22 19:29:10.9802+00', '2023-02-17 18:29:27.223168+00', 1182, 1, NULL, 'ace', '1–::

  1c turn RH, cast off 1 place, turn 1¼ LH to 1W facing 2M, 1M behind P

9–::

  1W followed by 1M diagonal Reel3, Rsh to 2M, finish by 1c swiveling L so that 1M faces 2W

17–::

  1M followed by 1W diagonal Reel3, Lsh to 2W

25–::

  1c turn RH 1½ ; 2c+1M & 1W+3c LHA', 2);
INSERT INTO 'dancecrib' VALUES (13562, '2021-01-18 23:49:11.337798+00', '2021-01-18 23:51:10.605312+00', 16197, 1, 1645, 'ace', '1-::

  1c set | dance down 3 places & cast back up (1,2,3,4)

9-::

  Mirror Reels4 on sides, 1c & 3c start in & down

17-::

  1c dance down 3 places & cast up 2 places (2c up on [21-22]) | all set (2,1,3,4)

25-::

  *4C Chain progression:* 2c & 4c (ends) turn &frac34; LH _while{2}_ 1c & 3c turn &frac34; RH | 2W & 4W (ends) chase &frac12; way cclw to other end _while{4}_ 2M+1W & 3W+4M NHJ chase &frac12; way clw _while{4}_ 1M+3W (centre) turn 1&frac12; LH | 4c & 2c (ends) turn &frac34; LH _while{2}_ 3c & 1c turn &frac34; RH (4,3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (3871, '2013-08-04 22:18:28.328363+00', '2015-08-12 23:06:54.793542+00', 14741, 1, NULL, 'ace', '1–::

  1c (in and down) Fig8 on own sides (give hands) (1,2,3)

9–::

  1c cross into Reels3{6} on opp. sides | 2c dance up as 1c face 1cnr

17–::

  1c+cnrs Pass&Turn, pass Rsh ; repeat with 2cnr, finish (2,1,3)

25–::

  All set | cross RH ; chase ½ clw to (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (3351, '2012-01-22 19:30:21.680372+00', '2017-07-07 14:05:10.434809+00', 6407, 1, NULL, 'ace', '1–::

  1c (1M on the L) in promhold cast into Fig8 around 2c (Lsh to 2M), to places

9–::

  2c (2W on the L) in promhold cast up into Fig8 around 1c (Rsh to 1M), to places

17–::

  1M+2M dance between and around own partner to places ; 1c dance between 2c and cast up to places

25–::

  1W+2W dance between and around 1M & 2M ; 1c lead down {1}, up {1} and cast off to 2pl (2c up)



{{explanation}}

Note: Keep the set narrower and longer than usual, and play the music a bit more slowly', 3);
INSERT INTO 'dancecrib' VALUES (1796, '2012-01-22 19:29:02.773641+00', '2020-09-19 00:09:49.072397+00', 644, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c, circle4 and back

9–::

  1c in promhold (man on R) dance down the middle ; and up behind the M line, end in own place

17–::

  Rsh Reels4 on the sides

25–::

  1c cross RH | cast off 3 places (2c+3c+4c up) ; 1c turn RH 1½  to (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (9843, '2017-05-13 17:24:54.145521+00', '2021-09-23 20:42:05.393791+00', 14329, 1, 202, 'ace', '1--::

 1c cross RH | cast (2c up) ; cross LH | cast to 3pl (3c up) (2,3,1)

9--::

 2c cross RH | 3c cross RH ; 1c cross RH | all cross Rsh

17--::

 2c cross LH | 3c cross LH ; 1c cross LH | all cross Lsh

25--::

 All dance BtoB, 1c finish in centre NHJ facing up ; 1c dance up, cast round 2c to 2pl (3c dn) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10420, '2018-02-07 10:51:09.736142+00', '2018-03-15 22:14:55.061203+00', 18239, 2, 1645, 'ace', '1-:: 

  1c dance down below 3c | cast up to 2pl (2c up) ; dance around each other passing RSh (no hands) | cast up to 1pl (2c down) 

9-::

  All dance mirror Reels3 with all crossing down from 1pl (1x,2x,3x)

17-::

  All set | all cross RH (1,2,3) ; all set | 1c turn RH into promhold _while{2}_ 2c cast and take promhold _while{2}_ 3c dance up to 2pl in promhold (1,3,2)

25-::

  All dance 3C allemande to (2,3,1)

', 5);
INSERT INTO 'dancecrib' VALUES (11519, '2019-01-19 13:57:08.319297+00', '2019-01-19 14:00:28.132183+00', 19094, 1, 202, 'ace', '1--::

  1c+2c ½ R&L ; 1c+3c ½ DblFig8, 1c crossing down (2x,1,3x)

9--::

  Mirror Reels3 on sides, 1c in and up (2x,1,3x)

17--::

  All set | cross RH ; Circle6 L ½ (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3349, '2012-01-22 19:30:21.601088+00', '2019-01-22 13:19:06.877823+00', 9643, 1, NULL, 'ace', '1–::

  1c+2c set diagonally | petronella to next place on the right ; set as before | cast clw back to own places

9–::

  1W+2M turn BH ; 1M+2W repeat

17–::

  Circle4 and back, finish 1c facing 2c ready for

25–::

  Rondel', 3);
INSERT INTO 'dancecrib' VALUES (10159, '2017-10-03 07:33:27.474658+00', '2019-03-07 19:54:50.426203+00', 14966, 1, 202, 'ace', '1--::

  1c lead down (2c up) ; on [5] 1M turn P under R arm and lead up to finish in the middle facing opp side for

9--::

  1W+2c & 1M+3c RHA (Teapots R), pass RSH ; Teapots L finishing in promhold facing 2W

17--::

  Reel3 on W side, 1c start Lsh to 2W (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (3847, '2013-07-13 15:56:21.794523+00', '2019-02-12 02:31:28.639687+00', 14657, 1, NULL, 'ace', '1–::

  2W Rsh Reel3 with 1M+3W (1,2,3)

9–::

  All turn P RH ; All chase ½ clw (3x,2x,1x)

17–::

  2M Lsh Reel3 with 3M+1W

25–::

  All turn P LH ; All chase ½ cclw (1,2,3)

33–::

  All A&R ; 1c cast to 3pl (2c+3c up)', 4);
INSERT INTO 'dancecrib' VALUES (10296, '2017-12-07 13:34:18.271336+00', '2021-08-06 20:50:49.309578+00', 10285, 2, 2697, 'ace', '1-8::

     1s+2s set | 1s+2s dance RH across ½ way | 1s+3s set | 1s+3s dance LH across ½ way (2s and 3s to finish on opposite sides)

9-16::

    1s cross up RH between 2s, cast down to 2nd place, dance down and cast up to 2nd place opp. sides 

17-24::

    2s+1s+3s dance Set & Link for 3 twice 

25-32::

     Circle 6h round and back', 5);
INSERT INTO 'dancecrib' VALUES (3345, '2012-01-22 19:30:21.441909+00', '2021-03-08 21:39:27.261822+00', 8954, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c set, turn BH opening into ; Circle4 L, ending for

9–::

  1c+2c & 3c+4c ½Poussette, 2c (3c) finishing in 1pl (4pl) ; 1c+4c ½Poussette (order 2,4,1,3)

17–::

  4c+1c turn RH ½, twirl (Rsh back) to opposite place ; ½ Fig8 round end couple

25–::

  Parallel Reels4 on the sides (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3347, '2012-01-22 19:30:21.52188+00', '2020-09-06 20:27:03.256837+00', 8496, 1, NULL, 'ace', '1–::

  1c lead down the middle and back and stay facing out.

9–::

  Reels3 on the sides (2c dance in and up ; 3c finish with a loop).

17–::

  1c+3c DblFig8 round 2c, to start 1c cast and 3c cross up , 1c stay facing out.

25–::

  1c+2c change places easy hand | all set ; all turn P RH.', 2);
INSERT INTO 'dancecrib' VALUES (3353, '2012-01-22 19:30:21.760671+00', '2021-04-11 18:50:19.36542+00', 6414, 1, NULL, 'ace', '1–::

  1W+2W+3W dance round the men, 1W leading, finish in places

9–::

  1c+2c+3c down the middle (3c leading)  and up, on last bar 1c cast off and 2c dance up (to 2,1,3) (2c+3c face out)

17–::

  2c+1c+3c Reels3 on the sides, all cross down from 2pl (1c on bar 1, then 2c and 3c) and all join NH on dancing up from 2pl, 2c+3c finish with a loop (to 2x,1x,3x)

25–::

  2c+1c+3c A&R {1+1}twice ; turn P ½ BH and face P, pull Rsh back and dance out to own side', 3);
INSERT INTO 'dancecrib' VALUES (3342, '2012-01-22 19:30:21.290412+00', '2021-04-11 23:19:58.615906+00', 6391, 1, NULL, 'ace', '1–::

  1c Petronella turn to midline | dance down RHJ with PdB (1W dances forwards, 1M backwards) to 4pos (2c+3c+4c up) ; turn 1¼ RH to 4pl (2,3,4,1), mid couples face end couples

9–::

  Reels4 on own sides, adding ¼ loop at the end to form lines across

17–::

  6 bars of Reels4 across | turn P ½ RH moving to (3,2,1,4) on midline in allemande hold facing up

25–::

  4c Allemande (no step right to start) (to 4,1,2,3)', 3);
INSERT INTO 'dancecrib' VALUES (3289, '2012-01-22 19:30:19.166684+00', '2021-04-14 10:33:17.167911+00', 6178, 1, NULL, 'ace', '1–::

  1W+2c & 1M+3c Reel3 (Rsh to 1cnr person, 1M passes down in front of 1W to begin)

9–::

  1W+3c & 1M+2c Reel3 (Lsh to 2cnr person), end in middle facing W side, 1M above 1W

17–::

  1c lead out between 2W & 3W, cross and cast round them to meet in the middle ; 1c lead between 2M & 3M and cast round them, 1M dancing up the middle and 1W across (to 1,2,3)

25–::

  1c dance BtoB ; cast off (2c up) | turn RH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3713, '2013-02-27 22:34:02.455598+00', '2014-04-30 23:24:12.21021+00', 14718, 1, NULL, 'ace', '1–::
  1c+2c the Knot, 1c face 1cnr (2,_1_,3)
9–::
  1c+1cnrs Corner Chain, 1c finish facing 2cnr
17–::
  1c+2cnrs Diag Reel4  (2,1,3)
25–::
  1c+3c set | 1c dance ¾ Dbl Fig8 giving hands _while_{6}  3c cast up, dance down,cast up (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3631, '2012-07-21 11:46:15.386982+00', '2014-05-26 19:38:42.323204+00', 11480, 1, NULL, 'ace', '1--::

  All set | turn BH and face up in the middle NHJ ; 1c cast off to 3pl  while{4} 2c dance up and cast to 2pl while{4} 3c dance up and cross to 1plx, 3M facing up, 3W facing down (3x,2,1)

9--::

  3c+1c L-Ch up/dn the set  Finish (3x,2,1)

17--::

  2c Petronella into lines across | all set ; 2c petronella to sides | all set (3x,2x,1)

25--::

  2c+1c ½ RHA | 1c+3c ½ LHA (to 1,3,2) ; all set | turn P RH into

33--::

  1c+3c+2c Allemande (2,3,1)



', 3);
INSERT INTO 'dancecrib' VALUES (3361, '2012-01-22 19:30:22.07529+00', '2015-09-02 12:28:23.670499+00', 7282, 1, NULL, 'ace', '1–::

  1c cast off 2 (dance in to begin) (2c+3c up) ; 2c+1c 1¼ turn RH to midline, facing P

9–::

  2c+1c Reel4 on midline, 2M and 1W end facing opposite side, with P behind

17–::

  2c & 1c chase clw round 3c to (1,3,2) ; All A&R

25–::

  3c+2c turn RH ½, leading into ½ RHA, to sidelines ; 1c+2c repeat (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2010, '2012-01-22 19:29:14.840627+00', '2023-02-17 12:03:41.021514+00', 1428, 1, NULL, 'ace', '1–::

  1W+2M lead to 3pl (2W+3c up) ; 1M+2W repeat (3c+1W+2M up)

9–::

  1c (not facing!) lead up to 1pl (3c+2M down) ; 2c lead up to 2pl (3c down) (1,2,3)

17–::

  1c turn RH | cast off (2c up) ; turn LH to face 2cnrs

25–::

  Set to 2cnrs, to 1cnrs ; 1½ RH turn to 2pl', 2);
INSERT INTO 'dancecrib' VALUES (3366, '2012-01-22 19:30:22.274045+00', '2014-04-30 23:24:12.34639+00', 6451, 1, NULL, 'ace', '1–::
  1c lead down the middle (2c up) and up to 2pl
9–::
  ½Reels3 across, Lsh to 1cnrs ; ½Reels3 on sidelines (Rsh to 2cnr pos), cnrs end with loop
17–::
  ½Reels3 across, Lsh to 3cnr pos ; ½Reels3 on sidelines (Rsh to 4cnr pos) (to 2,1,3) (1c and 2cnrs move cclw, 1cnrs move clw)
25–::
  2c+1c+3c circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (3362, '2012-01-22 19:30:22.115515+00', '2019-03-09 20:08:28.823092+00', 6431, 1, NULL, 'ace', '1–::

  1W+2W+3M+4M advance (touch NH) and retire, cross Lsh to P and chase ½ round set to L

9–::

  1M+2M+3W+4W repeat to the R (to 3x,4x,1x,2x)

17–::

  All set, circle8 L half round, set (2,1,4,3)

25–::

  1c+4c+3c turn RH to face up, lead up and cast off on own side (to 2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10161, '2017-10-04 22:57:34.829959+00', '2018-04-07 23:33:03.583104+00', 14525, 1, 202, 'ace', '1--::

  1M+2W turn BH 1 ½ _while{4}_ 1W & 2M chase cclw ½ (to 2x,1x,3) ; 2c+1c ½ LHA | 1c+2c turn LH on sidelines (1,2,3)

9-24::

  1c+2c S&Link ; 2c+1c+3c 3C R&L

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (3357, '2012-01-22 19:30:21.91764+00', '2019-02-04 18:35:21.31497+00', 6419, 1, NULL, 'ace', '1–::

  1c promenade cclw round outside of set.

9–::

  1M+2c & 1W+3c Mirror Reels3 (Lsh to 2W, Rsh to 3M), touching hands.

17–::

  All W RHA ; continue clw in front of own place, behind next M, finish beside next M (ie. 1 place cclw from own place)

25–::

  All M repeat LH / cclw (finish 1 place clw from own place)



{{explanation}}

Repeat twice with new partners.', 2);
INSERT INTO 'dancecrib' VALUES (10297, '2017-12-09 02:19:00.078138+00', '2017-12-12 12:07:47.493494+00', 11044, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; turn LH to face 1cnrs

9--::

  1c+1cnrs BtoB ; 1c turn 1cnrs RH, pass Lsh to face 2cnrs

17--::

  Repeat [9-16], pass Rsh (2,1,3)

25--::

  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (3368, '2012-01-22 19:30:22.352406+00', '2021-04-11 11:27:03.968636+00', 6471, 1, NULL, 'ace', '1–::

  1M+2W turn RH ; turn LH

9–::

  1W+2M repeat, end on diagonal between 1M & 2W

17–::

  1M+1W+2M+2W BiL twice ; 1W+2M turn ¾ LH, meeting partners who step in for

25–::

  Poussette', 3);
INSERT INTO 'dancecrib' VALUES (3365, '2012-01-22 19:30:22.234453+00', '2020-12-17 22:47:00.3828+00', 6450, 1, NULL, 'ace', '1–::

  1W+2M change place RH, set ; Turn LH ¾ and cast L to own sideline _while{8}_ 1M+2W set, change place RH ; set, turn LH to face own side between the others, in line across

9–::

  Reel4 across, at end 1M & 2W don''t pass but join LH and RH to P

17–::

  BiL | 1c & 2c turn ½ RH ; BiL | 1c & 2c turn ½ RH finishing (2,1)

25–::

  2c+1c RHA ; 2c turn 1c EH on sides, 2c start outwards (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (3359, '2012-01-22 19:30:21.995219+00', '2019-03-09 23:46:10.509655+00', 6420, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c join RH on side and Balance in Lines across | Hold RH and BiL on own side (2,1,4,3) ; the middle pairs (1M+4M & 1W+4W) hold LH and BiL across | hold LH and BiL on sides (2,4,1,3)

9–::

  Reels4 on the sides

17–::

  2c+4c & 1c+3c Circle4 ; 4c+1c LHA (2,4,1,3)

25–::

  1c+3c ½ R&L ; 3c+1c cross RH , 4c+3c change places on side LH (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (3275, '2012-01-22 19:30:18.598659+00', '2014-11-11 11:38:21.536101+00', 12720, 1, NULL, 'ace', '1–::

  All Circle6 and back

9-24::

  3 couple R&L ; All dance BtoB. (1,2,3)

25–::

  1c set adv. and swiveling (M Left, W Right) to face out | 1M+2M & 1W+2W turn ½ Easy Hand (to 2,1,3) ; 1c+3c repeat [25-28] (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11382, '2018-12-14 08:54:52.702343+00', '2019-02-23 18:26:44.340646+00', 19104, 1, 202, 'ace', '1--::

  2c+1c following DblFig8 round 3c, 2c crossing down (2,1,3)

9--::

  1c+3c following DblFig8 round 2c, 1c crossing up (2,3,1)

17--::

  1c set | lead up LHJ to face 1cnrs (3c down) ; 4 bars of SetH&G

25--::

  Reel4 on 2diag (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3356, '2012-01-22 19:30:21.878493+00', '2020-12-19 14:27:19.131418+00', 8238, 1, NULL, 'ace', '1–::

  1c turn LH | cast off (2c up) ; turn LH 1¼ to between end couples, all C face P

9–::

  All set to P | 2c+3c ¾ R&L _while{6}_ 1c petronella to 2plx ; turn RH ¾ | petronella and face out (3,1,2)

17–::

  All dance chaperoned chain progression, flowing into

25–::

  Circle6 and back (2,1,3)



{{explanation}}

Chaperoned chain progression:  Developed by Tim Wilson and Tom Winters.  2c+3c dance a chain progression: Turn P RH |  3M+2W turn LH 1½ while{4} their P dance clw ½ round | 2c+3c turn P RH to exchanged places.  Meanwhile, 1M & 1W cast R and dance clw around the set, taking 3W & 2M respectively in promhold for bars 3-6.', 2);
INSERT INTO 'dancecrib' VALUES (3363, '2012-01-22 19:30:22.155803+00', '2020-12-21 16:50:02.178947+00', 9940, 1, NULL, 'ace', '1–::

  All set | 1c+2c & 3c+4c ½ RHA _while{2}_ 5c cross RH ; All set | 2c+4c+5c cross RH _while{2}_ 1c+3c set advancing and swivel R to face opposite side, BtoB with P

9–::

  1c+3c with 1cnrs »pass and turn« and pass Rsh to face 2cnrs ; »2cnrs pass and turn«, finish facing 3cnr

17–::

  1c+3c SetH&G , finish Lsh to Lsh facing opposite side

25–::

  All RHA: 2c+1W & 1M+4c+3W & 3M+5c | 1c+3c turn LH ¾ and cast off one (4c+5c up)  (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (3367, '2012-01-22 19:30:22.312518+00', '2020-12-25 21:37:22.390079+00', 13228, 1, NULL, 'ace', '1–::

  1c followed by 2c dance down the middle ; and up, 2c leading (2,1,3)

9–::

  1c Fig8 between 2c _while{8}_ 2c set | cross RH ; repeat

17–::

  1c ½ Fig8 between 3c ; 2c+1M & 1W+3c RHA

25–::

  1c turn LH 1¾ and face out (2,1x,3) ; ½ Fig8 starting Lsh to 2cnr (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13563, '2021-01-19 00:22:12.297563+00', '2021-01-19 06:33:45.801348+00', 9487, 1, 202, 'ace', '1--::
  1c Fig8 down round 2c to 1pl centre and face down _while{8}_ 3c Fig8 down round 4c to 3pl centre and face up
9--::
  1c & 3c set | 1c+3c ½ RHA ; set. On [14] PdB L to face P | turn P LH ½ to sides (3,2,1,4)
17-20::
  2c turn P RH to 2pl centre and face down _while{2}_ 4c turn P RH to 4pl centre and face up | 2c & 4c set
21-28::
  2c+4c R&L up/down to sides and face up (3,2,1,4)
29-32::
  2c turn 3c & 4c turn 1c on sides 1½, RH on Mside, LH on Wside (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (14453, '2021-11-16 17:50:43.605872+00', '2021-11-16 17:50:43.605872+00', 16646, 2, 963, 'ace', '1-8::  
  1c&3c set; dance 3/4 mirror 8s (2s,4s, up 5/6); 1c&3c finish b/b facing own side
9-16::  
  dbl,dbl inverted triangles with no hands; 1c&3c finish nearer hands joined, facing dwn  
17-24::   
  1c&3c cast up around cpl below them: dance 1/2 8 up around cpl above them  
25-32::  
  All 5 cpls adv for one, retire for one twice: 1c&3c cross RH and cast (4s,5s up 31/32)  2,4,1,5,3
   
  ', 5);
INSERT INTO 'dancecrib' VALUES (10419, '2018-02-07 10:00:18.561048+00', '2018-02-07 11:46:55.189409+00', 18239, 1, NULL, 'ace', '1--::

  1c dance down between 3c | cast up to 2pl (2c up) ; 1c dance Rsh round P (no hands) | cast up to 1pl (2c down) (1,2,3)

9--::

  Mirror Reels3 on sides, all crossing down from 1pl (1x,2x,3x)

17--::

  All set | All cross RH ; All set | 1c turn RH _while{2}_ 2c cast to 3pl _while{2}_ 3c dance up, all taking promhold (1,3,2)

25--::

  3C Allemande (2,3,1)

', 5);
INSERT INTO 'dancecrib' VALUES (3380, '2012-01-22 19:30:22.934098+00', '2017-07-07 13:28:55.065395+00', 6518, 1, NULL, 'ace', '1–::

  1c lead down the middle {3} lead up {3} | cast off (2c up).

9–::

  2c repeat (1c up)

17–::

  1M+2M dance between 1W+2W, cast round P to places ; 1W+2W repeat

25–::

  1c+2W Reel3 on diagonal (1c start Rsh).

33–::

  1c+2M Reel3 on diagonal (1c start Lsh)

41–::

  1c+2c set and cross ; ½ R&L', 2);
INSERT INTO 'dancecrib' VALUES (3848, '2013-07-13 15:56:22.298917+00', '2014-04-30 23:24:12.482792+00', 14527, 1, NULL, 'ace', '{{explanation}}
2c begin on opposite sides (1,2x,3)

1–::
  1c+2c R&L, M face out
9-12::
  1c+2c ½ L-Chain, finish in line across with W RHJ
13-20::
  1c+2c The Targe [1W+2W turn RH ¾ as 1M+2M chase ¼ cclw onto midline | middles turn ends LH ; repeat, finish with ¾ turn to sidelines]
21-24::
  2c+1c ½ L-Chain (2,1x,3)
25–::
  Parallel Reels3 on the sides (1c starts down, Rsh to 3c) (2,1x,3)
33-56::
  1c+3c repeat [1-24] with M and W interchanged (2,3x,1)
57–::
  Parallel Reels3 on the sides (3c starts up, Rsh to 2c) (2,3x,1)

{{explanation}}
Repeat twice', 3);
INSERT INTO 'dancecrib' VALUES (3371, '2012-01-22 19:30:22.464329+00', '2021-04-10 11:36:44.389141+00', 6484, 1, NULL, 'ace', '1–::

  1c set, cross down RH, 1W making long R turn (2c up) ; set, turn LH to face 1cnr

9–::

  1c set to 1cnr, turn 1cnr RH once round ; ½ a diagonal Reel4 with 1cnr to finish (1c passing Lsh) facing 2cnrs

17–::

  1c repeat [9-16] with 2cnrs to finish in the centre, facing own sides, 1M above 1W

25–::

  3c+1M & 1W+2c RHA (to 3x,1x,2x) ; all chase ½ round clw to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3369, '2012-01-22 19:30:22.392127+00', '2021-04-11 11:08:46.08478+00', 6477, 1, NULL, 'ace', '1–::

  1c+2c cross RH ; cross back RH

9–::

  1c+2c RHA ; LHA

17–::

  1c down the middle and up

25–::

  1c+2c Allemande', 3);
INSERT INTO 'dancecrib' VALUES (10423, '2018-02-11 16:42:03.948075+00', '2018-02-13 12:53:50.54352+00', 18241, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; ½ diag R&L with 1cnrs

9--::

  All chase cclw ½ ; ½ diag R&L with 1cnrs (3x,1x,2x)

17--::

  3c+1M & 1W+2c RHA ; with 1c leading Lsh Snake Pass to (2x,1x,3x)

25--::

  All set | Petronella turn ; set | Petronella turn (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3849, '2013-07-13 15:56:22.365985+00', '2014-04-30 23:24:12.558437+00', 13314, 1, NULL, 'ace', '1–::
  1W+3M turn ½ RH and twirl R to exchanged places ; 1M+3W repeat (3x,2,1x)
9–::
  2c dance Rsh round 1cnr and meet, twirl R to face 4cnr ; ½ Reel4 on 2diag, meet and twirl R to face 2cnr
17–::
  2c dance Rsh round 2cnr and pass Lsh to face 3cnr ; ½ Reel4 on 1diag, at end curve R to (1,2,3)
25–::
  1c+2c ½ RHA | 1c+3c ½ LHA ; 2c turn LH 1½  _while_{4}   3c turn RH 1½ (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3370, '2012-01-22 19:30:22.431474+00', '2016-03-10 11:35:46.046118+00', 9417, 1, NULL, 'ace', '1–::

  2c set | 2M cast up and 2W down to beyond end ; 2M+1c & 3c+2W RHA

9–::

  2c set advancing | turn P BH and face end ; 1c+2M & 2W+3c LHA (1,2,3)

17–::

  1c+2c+3c the Knot (3,2,1)

25–::

  2c cross RH | cast to bottom (1c up) ; ½ Fig8 up round 1c (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (3377, '2012-01-22 19:30:22.722535+00', '2018-09-30 17:16:34.829323+00', 6505, 1, NULL, 'ace', '1–::

  1c turn 2½ RH (1x,2)

9–::

  1M+2W & 1W+2M turn LH 1½ (to 2,1x) ; 1c+2c ½ L-Chain, finish (1c turn less, 2c more) with 1W & 2M in own position, facing across and holding P BH ready for

17–::

  2c+1c Poussette (modified) : 1c+2c travel across{2} | ¼ turn {1}, travel and ¼ turn {1} ; (the rest as a normal poussette)', 3);
INSERT INTO 'dancecrib' VALUES (3381, '2012-01-22 19:30:22.973844+00', '2018-10-14 09:12:58.937762+00', 13473, 1, NULL, 'ace', '1–::

  1c Fig8 round 2c

9–::

  1c cross down into Reels3 on opposite sides

17–::

  1c cross back into Reels3 on own sides (1,2,3)

25–::

  1c dance down below 3c (2c up) and cast to 2pl ; All turn RH', 2);
INSERT INTO 'dancecrib' VALUES (3383, '2012-01-22 19:30:23.063286+00', '2021-01-09 21:50:44.369862+00', 11720, 1, NULL, 'ace', '1–::

  1c+2c set | cross LH into ½ LHA | 1c+2c set (2,1,3)

9–::

  1c parallel Fig8 on sideline, starting up with Lsh to 2c

17–::

  1c+3c repeat [1-8] using RH (to 2,3,1)

25–::

  3c+1c RHA ; 2c+3c LHA (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (3376, '2012-01-22 19:30:22.682324+00', '2020-12-24 10:25:39.231929+00', 10601, 1, NULL, 'ace', '1–::

  1c+2c turn BH | into circle4 left {4} | split to turn P BH (1,2)

9–::

  Poussette (1,2)

17–::

  1c+2c The Knot, at the end 1M joins 1W again in Hip-promhold facing up (L Hands as in a normal promenade, M''s R arm behind the W''s back, hand on her R hip)

25–::

  1c ½ Fig8 Lsh round 2M ; split while dancing to the top and cast round 2c to 2pl.

', 3);
INSERT INTO 'dancecrib' VALUES (10295, '2017-12-07 12:37:42.547089+00', '2017-12-07 15:09:21.057524+00', 11038, 1, 202, 'ace', '1--::
  All set to P | turn P BH ; all M dance Rsh round P
9--::
  Gr-Chain no hands, starting Rsh to P, 1 step per bar
17--::
  1c+3c La-Chain
25--::
  2c+4c La-Chain
33--::
  All W RHA ½ | turn opposite M LH ; all W RHA ½ | turn P LH
41--::
  All M LHA ½ | turn opposite W RH ; all M LHA ½ | turn P RH
49--::
  All set to P | La Baratte (ending W on M''s L)
57--::
  All set NHJ | all dance Rsh ½ to P, finish facing cnrs ; all turn cnrs LH
65--::
  All set to P | turn P BH ; all W dance Rsh round P
73--::
  Gr-Chain', 4);
INSERT INTO 'dancecrib' VALUES (3386, '2012-01-22 19:30:23.227382+00', '2017-01-27 21:53:48.996848+00', 9014, 1, NULL, 'ace', '1–::

  Reels4 on the sides, Lsh on W side, Rsh on M side, each cpl crosses down from the top, 1c starting (1x,2x,3x,4x)

9–::

  1W+2M & 3W+4M set | change places RH ; 1M+2W & 3M+4W repeat LH (2,1,4,3)

17–::

  2c+1c & 4c+3c Poussette (2,1,4,3)

25–::

  1c+3c turn BH ½ and face up | dance to top and cast off to 4plx resp. 2plx | cross RH and face out to begin again. (2,3,4,1)



', 3);
INSERT INTO 'dancecrib' VALUES (3372, '2012-01-22 19:30:22.504484+00', '2020-05-04 20:08:03.477259+00', 6489, 1, NULL, 'ace', '1–::

  1M+2W lead down (2M up) ; and up to 2plx

9–::

  1c+2c A&R ; women + opposite M turn ¾ onto sideline (to 1,2x)

17–::

  1c+2c with NHJ on sides A&R ; turn P RH (2c turn 1½) into

25–::

  1c+2c Poussette.', 3);
INSERT INTO 'dancecrib' VALUES (14054, '2021-05-30 21:06:20.996047+00', '2021-05-30 21:06:37.366774+00', 5772, 1, 1645, 'ace', '1-::

  1c & 3c set | cross RH ; set | petronella to centre line, M facing down, 2c face clw

9-::

  All dance Weasel Reel up/down: Reel4 on midline (M down, W up), on reaching ends

  pass RSh, chase &frac12; way clw on opposite side & rejoin reel, finish in starting place,

  but 1W+3M end turning &frac34; LH to line across facing 2c

17-::

  All dance Weasel Reel across the set, 1W+2M & 3M+2W start passing RSh, all finish in starting place,

  but 1W+3M end turning &frac34; _RH_ to face P on centre line

25-::

  1c & 3c set | turn &frac34; RH ; 1c+2c S&Link (2,1,3)

::

  *On 2nd time through, 1c dance to 4pl on [31-32]*

', 2);
INSERT INTO 'dancecrib' VALUES (13953, '2021-04-14 08:50:58.606495+00', '2021-04-14 08:52:38.029485+00', 18087, 1, 202, 'ace', '1--::

  All set | turn P RH ½ and face P ; cast R to exchanged places | turn P BH (1x,2x,3x)

9--::

  Circle6 L and cross RH (1,2,3)

17--::

  1c lead down between 2c, cross down and cast off behind 3c, meet, cross up between 3c and cast up behind 2c to 1pl (1,2,3)

25--::

  1c+2c The Knot (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13564, '2021-01-20 01:25:15.042217+00', '2021-01-20 01:38:37.182136+00', 10243, 1, 202, 'ace', '1--::

  1c+3c ½ L-Chain ; 1W & 3W (both M following) chase ¼ clw behind sides, dance in passing same sex standing person LSh and face P

9--::

  1c+3c Poussette. On [15-16] 3M & 1M (both W following) pull LSh back and chase to nearest sides facing P, M on W''s place (3x,2,1x,4)

17--::

  3c & 1c turn P LH ½ | 2c+4c ½ R&L ; all set (3,4,1,2)

25--::

  All turn P RH | turn cnr LH | turn P RH into promhold and promenade 1 place cclw (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (14055, '2021-05-31 22:18:54.135984+00', '2021-05-31 22:19:06.416848+00', 7852, 1, 1645, 'ace', '1-::

  1c set | cast (2c up) ; set | &frac12; turn LH to face 1cnrs

9-::

  *Diagonal Weasel Reel:* Reel4 on 1st diagonal, pass RSh on reaching corners,

  chase &frac12; way clw via 4cnr pos & rejoin reel,

  corners end in original places, 1c end dancing LSh &frac34; round P to face 2cnrs

17-::

  Repeat [9-16] on 2nd diagonal, 1c end reel with usual LSh pass (facing 2cnrs)

25-::

  1M/1W dance Fig8 across round 2c/3c, starting RSh to 2cnr, end in 2pl (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10418, '2018-02-07 00:37:59.494745+00', '2018-02-07 12:16:00.95897+00', 18238, 1, NULL, 'ace', '1--::

  All turn P RH ¾ and W join hands | All Balance in crossing lines ; All M dance 1 place clw _while{2}_ All W ½ LHA | with new P Balance as before 

9--::

  Turn new P RH ½ | All W dance 1 place clw _while{2}_ All M ½ LHA into middle, facing P ; All dance BtoB with P, M finish in middle facing P (2,3,4,1) 

17--::

  All turn P RH ¾ | All M "swoop" to opposite W place passing Rsh as the W loop R to the M place ; All MW pairs turn RH ½ | All M "swoop" back to own position (M and W have switched places) (2,3,4,1) 

25--::

  Circle8 and back  (2x,3x,4x,1x)

::

  *Repeat, M and W switching places on each turn.* 

', 3);
INSERT INTO 'dancecrib' VALUES (3392, '2012-01-22 19:30:23.467396+00', '2014-04-30 23:24:12.77868+00', 9013, 1, NULL, 'ace', '1–::
  1c set, cast off (2c up), 2c+1c+3c set and ½ RH turn to face down
9–::
  2c+1c+3c Allemande starting down, end 2c+3c on opposite sides, 1c facing 3cnr positions (1cnr persons)
17–::
  SetH&G , at end all set in lines across (1M below, 1W above)
25–::
  All cross RH up/down (cnrs no polite turns) | 1c cast to R into 2plx ; all couples cross RH | 1c & 3c change places LH on sidelines (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3385, '2012-01-22 19:30:23.192738+00', '2017-07-07 12:53:24.654539+00', 6523, 1, NULL, 'ace', '1–::

  1c cast off behind own lines ; cast back to places

9–::

  1c cross into 1W+2M & 1M+2W 1½ RH turn, to (2,1x,3) ; 1W+3M & 1M+3W LH turn, 1c finish facing 1cnrs

17–::

  SetH&G , finish 1M facing up and 1W facing down

25–::

  Reels3{6} on the sides (Rsh to 2cnr) | 1c cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1931, '2012-01-22 19:29:10.495285+00', '2023-02-17 18:32:46.818956+00', 1145, 1, NULL, 'ace', '1–::

  1c set | cross RH ; cast (2c up) | turn RH to opposite side facing out (2,1x,3)

9–::

  *(interlocking reels3)* 1c dance Rsh Fig8 round 1cnr and 4cnr positions _while{8}_ 2c+3c dance Reels3 on the sides, finish as begun

17–::

  *(interlocking reels3)* 1c dance Lsh Fig8 round 2cnr and 3cnr positions _while{8}_ 2c+3c dance Reels3 on the sides, finish (2,1x,3)

25–::

  All set | 1c turn RH ¾ ; all set in lines across | 1c turn RH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3782, '2013-07-13 15:56:05.036666+00', '2014-08-13 02:47:19.970581+00', 14569, 1, NULL, 'ace', '{{explanation}}

Starting positions (1,2,3,4x,5x,6x)



1–::

  1c+2c & 5c+6c DblFig8, 1c&6c crossing in to start

9–::

  Two Mirror Reels3 on each side, 2c&5c start out and to own end (1,2,3,4x,5x,6x)

17–::

  1W+1M following & 6W+6M following dance through the middle.  The W pass W Lsh and M Rsh, and cast R behind 2W/5W and on to the end, the M pass the W Rsh and M Lsh, and cast L behind 2M/5M, to finish (6,2,3,4x,5x,1x)

25–::

  6c+2c & 5c+1c change places EH on the side (1c&6c start inwards) | 6c+3c& 4c+1c turn EH 1½ to (2,3,6,1x,4x,5x), 3c&4c facing out to start again



{{explanation}}

The 3C version of this dance is called »Three Feisty Women«.  

Dance 6 times through to places.', 3);
INSERT INTO 'dancecrib' VALUES (11833, '2019-05-06 22:29:39.844284+00', '2020-09-19 09:39:01.253814+00', 19290, 2, NULL, 'ace', '1-8:: 1st and 3rd couples (dancing couples) long cast to 2nd and 4th places, 2nd and 4th couples stepping up on bars 3 and 4. Dancing couples spin to finish facing first corners.



9-12:: Dancing couples set to their own corners (corners set back), and turn two hands, opening out so that the dancing ladies and their corners face down the set, and the dancing men and their corners face up the set.  

  2M – 1L 	2L  

  4M – 3L 	1M – 4L  

  5M 	3M – 5L  

  Positions at bar 12



13-16:: Dancing couples, with corners, advance and retire on the diagonal.



17-24:: Dancing couples pass right shoulder with their own corners to dance reels across the set, reels of 3 at the top and bottom and a reel of 4 in the centre.



25-32:: Dancing couples turn left hand ¾, cast off one place on their own sides, and spin to finish. 24153.

', 5);
INSERT INTO 'dancecrib' VALUES (10487, '2018-03-05 08:46:47.333591+00', '2018-04-04 21:28:28.018371+00', 17885, 1, 202, 'ace', '1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 1c+4c RHA and face nearest end NHJ (2,1x,4x,3)

9--::

  2c+1c & 4c+3c change places on sidelines (2c & 3c moving outwards | 6 bars of DblFig8, 1c & 4c *casting* inwards to start (2,1,4,3)

17--::

  1c+4c S&Rotate (2,4,1,3)

25--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (11784, '2019-04-13 00:33:25.339694+00', '2019-04-13 00:46:09.1264+00', 18851, 1, NULL, 'ace', '1--::

  1c+2c RHA ; LHA

9--::

  1c set | cross RH ; cast off (2c up) | turn RH to face 1cnr

17--::

  1c+1cnrs Pass and Turn ; 1c+2cnrs repeat, 1c crossing to (2,1,3)

25--::

  Circle6 and back

', 3);
INSERT INTO 'dancecrib' VALUES (3394, '2012-01-22 19:30:23.547272+00', '2021-01-09 11:42:09.632806+00', 7527, 1, NULL, 'ace', '1–::

  1M & 2W cross and cast Rsh round P ; turn RH 1½ to own places

9–::

  1W & 2M repeat Lsh / LH

17–::

  1c BHJ slip down the middle and up

25–::

  Poussette', 3);
INSERT INTO 'dancecrib' VALUES (3393, '2012-01-22 19:30:23.507377+00', '2019-02-07 11:45:56.297935+00', 10644, 1, NULL, 'ace', '1–::

  1c+3c set | ½ DblFig8 round 2c (1c cross down to start) | All set (1x,2,3x)

9–::

  1c+2W & 2M+3c RHA ; 1c+2M & 2W+3c LHA

17–::

  2W+1c & 2M+3c ½ Lsh Reels3 across ; ½ Rsh Reels3 on sidelines, Rsh to 2cnr (to 3,2x,1)

25–::

  2c+3c ½RHA | all set ; all turn partner BH, 3c turning 1½  (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3400, '2012-01-22 19:30:23.79386+00', '2016-02-01 22:30:57.165074+00', 6612, 1, NULL, 'ace', '1–::

  All set | W making arches, All M dance Rsh round P to places |

9–::

  All M also join hands, 1M & 4W lead clw chase ½ round ;  all turn P RH (4x,3x,2x,1x)

17–::

  All set | M making arches, All W dance Lsh round P

25–::

  All W also join hands, 1W & 4M lead cclw chase ½ round ;  all turn P LH (1,2,3,4)

33–::

  1c cross RH | cast off (2c up) ; 1c turn LH | cast off (3c up)

41–::

  1c turn RH | cast off (4c up) ; 1c turn LH (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (3396, '2012-01-22 19:30:23.627368+00', '2014-04-30 23:24:12.896501+00', 6577, 1, NULL, 'ace', '1–::
  1c+2c+3c all W A&R and set _while_{6} all M set, A&R | all cross RH
9–::
  All C set, Petronella to midline ; turn BH, Petronella back to (1,2,3), 1W+2M face out
17–::
  1c+2c Reel4 across, 1M+2W starting Lsh, and 1W+2M cast R, at end 1W+2M turn LH into:
25–::
  1c+2c Rondel.', 3);
INSERT INTO 'dancecrib' VALUES (3390, '2012-01-22 19:30:23.387368+00', '2021-02-26 14:09:06.354973+00', 9220, 1, NULL, 'ace', '1–::

  1c set | dance between 2c (2c up) | cast on own side behind 3c and lead up to face 2W in promhold

9–::

  1c with 2cnrs diagonal Reel3

17–::

  1c+2M LHA (1W ahead) ; 1c+3W RHA to (2,1x,3), 1c facing out

25–::

  Opposing Reels3 on the sides, Lsh to 2cnr, at end 1c cross diagonally to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (7908, '2013-08-21 08:31:51.197718+00', '2023-02-04 01:23:11.401855+00', 10000, 3, NULL, 'ace', '1-8::
    4s turn RH, cast up 1 place, dance down between 3s & cast back to
    3rd place
9-16::
    1s+2s also 4s+3s dance RH across & LH back
17-24::
    4s turn RH, cast up 1 place, dance down between 2s & cast back to
    2nd place
25-32::
    1s+4s+2s+3s dance reflection reels of 4 (4s & 3s in & up)
33-40::
    4s turn RH, cast up 1 place, dance down between 1s & cast back to
    1st place
41-48::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8257, '2014-04-24 11:29:28.088759+00', '2020-09-07 23:14:42.838636+00', 9190, 1, NULL, 'ace', '1–::

  1c+2c set | turn BH ; Circle4 L

9–::

  1c set and cast off (2c up) ; 2c+1c+3c advance {1}, retire {1} | 1c dance in to face 1cnr

17–::

  Set »H&G«, to (2,1,3)

25–::

  1c+3c Poussette (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3398, '2012-01-22 19:30:23.707296+00', '2021-03-14 23:23:08.056991+00', 8715, 1, NULL, 'ace', '1–::

  1c+2c+3c+4c dance BtoB ; all C ½ RH turn leading into ½ RHA (to 2,1,4,3)

9–::

  1c+4c dance BtoB ; LHA to face »own corners« (in own initial positions)

17–::

  1c+4c all turn corner R Elbow grip | ½LHA to opposite corner ; turn other corner R Elbow grip | ½LHA to positions of bar 8, but 1M and 4W face out

25–::

  1c (M leading) + 4c,  (W leading) cast R, round the end couple, down (up) other side, to exchanged positions (order now 2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14057, '2021-06-01 00:42:21.609331+00', '2021-06-01 00:46:10.921351+00', 8448, 1, 202, 'ace', '1--::

  1c (+2c who dance up to follow) lead down ; 2c+1c lead back to exchanged places (2,1,3)

9--::

  1c Fig8 on sides, out and up, joining NH where possible (2,1,3)

17--::

  1c cast off | dance down behind own lines ; turn away | dance up to 2pl (2,1,3)

25--::

  2c+1c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2390, '2012-01-22 19:29:35.168516+00', '2021-06-01 20:50:34.83385+00', 2725, 1, NULL, 'ace', '1–::

  All C turn RH (2M+3W add polite turn) | half G-Chain (ends cross to start) | all cross RH (4,3,2,1)

9–::

  3c+2c ½RHA | lead to top/bottom ; set | cross RH to own side _while{8}_ 4c+1c set | cast to middle ; RHA finishing on the diagonal for

17–::

  4c+1c ½ Poussette, end couples dancing in on [20] for ; 2c+1c & 4c+3c ½ Poussette (1,2,3,4)

25–::

  All C set | turn RH, 2c+3c+4c staying in middle ; they lead up one _while{2}_ 1c cast to 4pl | all C set (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (15178, '2022-10-20 13:09:06.705475+00', '2022-10-20 13:09:16.68397+00', 21152, 1, 1645, 'ace', '1--::

  1c cross down into Reels3 on opp sides, 3c also cross down from 1pl on [5]

9--::

  Repeat, 1c & 3c crossing back to own sides from 1 pl (1,2,3)

17--::

  1c &frac12; turn LH | cast off ; &frac12; Fig8 to L (M down, W up) ending outside 2pl own side

  _while{8}_ 2c & 3c &frac12; turn LH | chase &frac14; cclw to M in 1pl, W in 3pl ;

  &frac12; turn LH with P on sides | chase &frac14; cclw to just inside corner pos (3x,1,2x)

25--::

  1c chase &frac12; way clw, dance in between 3c & 2c ; turn P 1&frac12; RH

  _while{8}_ 3c+2c circle4 to R, release & slip out to corner pos ; chase &frac12; way cclw (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3633, '2012-07-21 11:46:17.032798+00', '2014-04-30 23:24:13.003034+00', 11295, 1, NULL, 'ace', '1–::
  1c set | dance down the middle (2c up) ; cast up round 3c and turn RH to join LH with 1cnr
9–::
  1c+1cnrs BiL | turn 1cnr LH to join LH with P and RH with 2cnr ; BiL | turn 2cnr RH to (2,1x,3)
17–::
  Reels3{6} on the sides, Lsh to 1cnr | 1c cross RH (2,1,3)
25–::
  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (8044, '2013-09-18 13:41:21.105999+00', '2016-02-29 14:23:51.1633+00', 14681, 1, NULL, 'ace', '1-4::

  1c cross down (no hands) to 4plx | cross RH to 4pl _while_{4} 2c+3c+4c dance up one place | set

5-16::

  Repeat [1-4] three times from new positions (1,2,3,4)

17–::

  All A&R ; 1c set and cast to 4pl (2c+3c+4c up on [23-24])

25–::

  Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (11523, '2019-01-20 07:23:02.265388+00', '2019-01-20 07:27:30.302557+00', 9284, 1, 202, 'ace', '1--::

  All Petronella Turn | set ; repeat (1x,2x,3x)

9--::

  2c dance down | face P and set ; lead up | cast through 2pl to 3pl (3c up) (1x,3x,2)

17--::

  3c ½ Fig8 R (to 1x,3,2) ; 1c set | lead down and cross to 3plx _while{4}_ 2c set | cast to 1pl (2,3,1)

25--::

  All set | cross RH ; repeat (2,3,1)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (9946, '2017-06-08 05:51:26.851839+00', '2017-10-05 06:09:37.017844+00', 14724, 1, 202, 'ace', '1--::

 1c set | cross RH ; 1c cross down into ½ Fig8 round 2c (1,2,3)

9--::

 1c lead down and up, 2c & 3c step in on [16] for

17-::

 3C Allemande (3,2,1)

25--::

 3c cast to 3pl _while{2}_ 2c & 1c dance up one touching NH briefly | all set ; all turn P RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3667, '2012-12-19 11:14:35.696813+00', '2014-04-30 23:24:13.123864+00', 14619, 1, NULL, 'ace', '1–::
  1c set | cast off (2c up) ; cross down RH and cast up (2,1x,3)
9–::
  1c cross up RH into mirror Reels3 on own side, joining NH when possible, finish with loop (2,1,3)
17–::
  All S&Link3 ; all chase ½ clw into lines across
25–::
  All S&Link3 ; All turn P RH [or birl if preferred] (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8212, '2014-03-17 13:54:12.313499+00', '2016-09-04 19:56:29.760755+00', 6650, 1, NULL, 'ace', '1–::

  All petronella to midline | Set ; change place with P RH | »end« dancers chase ¼ clw as »middles« turn LH 3/4 , into line across facing P

9–::

  Reel4 across

17–::

  »middles« turn LH ¾ as »ends« chase ¼ clw, all onto midline facing P | change place with P RH ; All set | petronella to (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (3404, '2012-01-22 19:30:23.959918+00', '2021-04-05 20:15:12.934323+00', 6638, 1, NULL, 'ace', '{{explanation}}

This dance can also be danced as a 3C or 7C dance.



1–::

  1c+3c turn RH | cast off (2c+4c up) ; dance down one and cast up to face 1cnr

9–::

  Set to and turn corners (to 2,1x,4,3x,5)

17–::

  All A&R ; 1c+3c cross RH | change places LH on sideline with couple below (to 2,4,1,5,3)

25–::

  Circle10 and back', 3);
INSERT INTO 'dancecrib' VALUES (3413, '2012-01-22 19:30:24.376389+00', '2014-04-30 23:24:13.212731+00', 12038, 1, NULL, 'ace', '1–::
  1c set | turn LH ; cast to 2pl (2c up) turn RH to face 1cnrs
9–::
  Turn 1cnr LH | P RH ; 2cnr L | P RH into promhold facing 2M
17–::
  ½ Reel3 on 1diag, Rsh to 2M ; ½ Reel3 on 2diag, Rsh to 3M, finish 1L with 1M close behind facing 2M in 1cnr pos
25–::
  Lead-change Rsh ½ Reel3 on 1diag ; lead-change ½ Reel3 on 2diag, Lsh to 2cnr pos, (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3192, '2012-01-22 19:30:15.155175+00', '2020-07-13 08:59:59.791119+00', 5843, 1, NULL, 'ace', '1–::

  1c+2c set | ¾ of DblFig8, 1c cast to start (2,1x,3)

9–::

  All set | cross RH ; set | turn RH ½ and W swivel R to face sideline with M close behind (2,1x,3)

17–::

  Rsh Reel3 , couples dancing as one, M behind W, 1c starting to M side and up, at end couples split to nearest sideline

25–::

  2M+1W+3M & 2W+1M+3W Parallel Rsh Reels3, 1c starting up, 3c ends in 3pl, but 2c+1c dance on slightly to finish in line across, the M BtoB in the middle facing the other W

33–::

  Reel4 across, the M omit the final Lsh pass but curve to take RH with P, 1c facing up, 2c down

41–::

  2c followed by 1c lead down between 3c, cross and cast up | 2c+1c cross RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3407, '2012-01-22 19:30:24.116611+00', '2021-03-25 23:51:22.708291+00', 7529, 1, NULL, 'ace', '1–::

  1c, with 2c+3c following, lead down the middle ; All set to P | lead up

9–::

  3c+2c+1c Allemande (1,2,3)

17–::

  1c cast off two, dance up the middle, cast off to 4pl (2c+3c+4c up)

25–::

  All turn P RH ; all turn P LH (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (3401, '2012-01-22 19:30:23.835687+00', '2021-04-07 16:17:51.335176+00', 6616, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  1c+4c set, 1M+4W cast into BtoB on »2nd diagonal« facing P (2M+3W step to end) ; 1c+4c set, turn P BH

9–::

  Reel4 (2nd diagonal), end in own places (2M+3W step back)



{{title}}

Reel



17–::

  1c+4c set, cast to middle positions (2c+3c step out) ; 1c+4c RHA

25–::

  1c+4c set, cast to the ends (2c+3c step back) ; 1c+2c & 3c+4c LHA



{{title}}

Strathspey



33–::

  1c+4c set, 1W+4M cast into BtoB on »1st diagonal« facing P (2W+3M step out) ; 1c+4c set, turn P BH

41–::

  Reel4 (1st diagonal), end in own places (2W+3M step back)



{{title}}

Reel



49–::

  1c+2c set, ½ RHA ; 1c+3c set, ½ LHA

57–::

  1c+4c set, ½ RHA ; All C set, cross (Men''s arches) (to 2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (14056, '2021-05-31 23:11:47.697724+00', '2021-05-31 23:12:01.30162+00', 3016, 1, 1645, 'ace', '1-::

  1c dance down the middle & back, 2c step in for

9-::

  1c+2c Poussette{6} | end turning P &frac34; RH to face down/up on centre line (2W,2M,1W,1M)

17-::

  *Interlocking Reels3:* Pass P RSh | 1M+2W dance LSh round each other _while_ ends wide loop ;

  pass P RSh | 1W+2M dance LSh round each other _while_ ends wide loop

25-::

  2c & 1c set to P | petronella (2x,1x) ; set | cross RH (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (14059, '2021-06-02 10:22:32.846702+00', '2021-06-02 10:26:00.429185+00', 8450, 1, 202, 'ace', '1--::

  1c+2c RHA ; LHA ready for 

9--::

  2C Allemande (2,1,3)

17--::

  1c cross RH | cast off (3c up) ; ½ Fig8 up round 3c (2,3,1)

25--::

  3c+1c Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3418, '2012-01-22 19:30:24.629262+00', '2020-09-19 20:40:07.003122+00', 13719, 1, NULL, 'ace', '1–::

  1M+2c & 1W+3c Mirror Reels3, 1c pass between the side C to start

9–::

  All set to P | turn RH and W face out ; all W loop R to M place as all M ½ LHA to W place opposite

17–::

  Repeat [13-16] from new places (M and W exchange roles) ; repeat again, M face out

25–::

  All M chase clw ½ _while_{4} All W LHA to meet P ; All C turn P RH ½ opening into CircleL 2/3 round, finish (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (3331, '2012-01-22 19:30:20.850971+00', '2017-07-07 13:35:10.668914+00', 6362, 1, NULL, 'ace', '1–::

  1c cast off 2, lead up, cast off round 2c and cross to face 1cnr (2c up)

9–::

  SetH&G

17–::

  Turn CPCP

25–::

  Reels3 with cnrs, Lsh to 1cnr

33–::

  Reels3 on own side, Rsh to 4cnr', 2);
INSERT INTO 'dancecrib' VALUES (10488, '2018-03-05 19:46:29.795848+00', '2018-03-05 19:53:47.823184+00', 16058, 1, 202, 'ace', '1--::

  1c set | cross RH ; cast (2c up) | turn P LH to face 1cnrs

9--::

  ½ Reel4 in 1diag, pass Lsh ; ½ Reel4 in 2diag finishing in centre Lsh to P facing own side

17--::

  1M+3c & 1W+2c RHA, pass Rsh ; 1M+2c & 1W+3c LHA finishing in centre Rsh to P facing own side

25--::

  Rsh »Snake Pass« {6} [unwind the LHA, 1c leading, pass other snake Rsh through 2pl and chase clw] (to 2x,1x,3x) | All cross RH

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11524, '2019-01-20 07:35:21.508247+00', '2019-01-20 07:39:15.583731+00', 9282, 1, 202, 'ace', '1--::

  1c+2c Espagnole (2,1)

9--::

  1c ½ Fig8 up round 2c ; 2c ½ Fig8 down round 1c (2x,1x)

17--::

  2c+1c ½ R&L ; Circle4 L (1,2)

25--::

  1c lead down | turn RH ; lead up | cast (2c up) (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (3416, '2012-01-22 19:30:24.508213+00', '2019-02-05 23:14:06.136141+00', 6680, 1, NULL, 'ace', '1--::

  1W cross down as 1M cross | 1c cast Rsh round 2c ; 1c turn LH into line across between 2c facing opposite side

9--::

  Reel4 across, 2c finish in 1pl, 1c omit last Lsh pass to move straight into

17-32::

  1c repeat [1-16] with 3c

33-48::

  1c repeat [1-16] with 4c, 1c finish with ½ LH turn and face up RHJ (2,3,4,1)

49--::

  1c lead to top ; cross and cast off to 4pl (2,3,4,1)

57--::

  All Circle8 and back. (2,3,4,1)



', 3);
INSERT INTO 'dancecrib' VALUES (3411, '2012-01-22 19:30:24.280747+00', '2019-03-09 14:06:11.808258+00', 6662, 1, NULL, 'ace', '1–::

  1M+2M+3M advance towards P and dance back to place ; 1M+2W & 2M+3W & 3M+4W turn RH

9–::

  1W+2W+3W advance towards P, curve down to join RH with next man below, and dance under own arch back to place and face out

17–::

  1W+2W & 1M+2M turn 1½ (women RH, men LH) ; 1c followed by 2c dance down behind own lines and in round resp. 4c and 3c, 2c+1c meet P and dance up the middle (2c to 1pl facing out and 1c to 2pl in centre facing up)

25–::

  2c+1c+3c mirror wheels in sideline (1c finish facing down NHJ) ; 3c+1c+4c mirror wheels in sideline (1c to 4pl)', 2);
INSERT INTO 'dancecrib' VALUES (8047, '2013-09-22 20:13:52.225359+00', '2015-02-24 15:38:05.292449+00', 14541, 1, NULL, 'ace', '1–::

  All set | 1W, followed by 1M+2M+3M cast off 2, cross below 3W and up the M side till 1W is in 1M place, and 3M has just passed 3W

9–::

  3M (beckoning) followed by 3W+2W+1W (who crosses) chase clw round set to own places (1M+2M up on [15-16]) (1,2,3)

17–::

  1c cross RH | cast (2c up) ; 1c+3c LHA (2,1x,3)

25–::

  2c+1c RHA ; 1c Turn RH 1½ (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10045, '2017-08-16 11:19:09.732778+00', '2018-02-07 21:45:11.72385+00', 17630, 1, NULL, 'ace', '*start (1,2,3x,4x)*  

1--::

  1c+2c & 3c+4c S&Rotate (2,1,4x,3x)

9--::

  1c+4c S&Link, finish 1c facing 4c NHJ ; 1c+4c S&Link, finish on sidelines middles facing ends (the W pivot R) (2,4,1x,3x)

17--::

  Reels4 on the sides

25--::

  2c+4c & 1c+3c R&L, starting along the sides (2,4,1x,3x)



*Danced 4 times through, as Strathspey, Strathspey, Reel, Reel.*

', 3);
INSERT INTO 'dancecrib' VALUES (3421, '2012-01-22 19:30:24.781428+00', '2016-05-11 01:28:26.958169+00', 6704, 1, NULL, 'ace', '1–::

  1c cross down into Mirror Reels3 on opposite side (1x,2,3)

9–::

  1W+3c & 1M+2c Reels 3 across (Rsh to 3cnr person), 2c finish in 1pl _while_ 1c passes Lsh to face 1cnr LHJ (2,1,3)

17–::

  1c set to 1cnr, swivel inwards into RHJ | set to 3cnr ; then to 2cnr and swivel into LHJ | set to 4cnr, and face 1cnr

25–::

  Turn CPCP (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3423, '2012-01-22 19:30:24.859635+00', '2021-04-05 13:30:07.811448+00', 6707, 1, NULL, 'ace', '1–::

  3c half Petronella to (1,2,3x,4,5)

9–::

  All set | dance BtoB | Set

17–::

  3W+2c & 3M+4c Opposing Rsh Reels3 across

25–::

  3W+1c & 3M+5c Opposing Rsh Reels3 across, 3c finish on midline between end couples, facing P

33–::

  1c set twice ; cast to 5pl _while_{8}   3c set twice, 3M advancing up ; turn BH 1¼ to 2pl (2c+4c+5c up) (2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (3426, '2012-01-22 19:30:24.997705+00', '2015-10-30 11:51:58.233269+00', 6710, 1, NULL, 'ace', '1–::

  1c cast (2c up) to 1M between 3c and 1W between 2c (loop R), into facing lines across ; All A&R up/dn

9–::

  1c cast (Rsh back) round 4cnr to exchanged places (no loop) ; All A&R up/dn

17–::

  1c A&R in PdB ; cast (Rsh back) round 2cnr to (2,1x,3)

25–::

  2c+1c R&L

33–::

  2c+1c dance BtoB ; 2c face 1c and dance BtoB on side

41–::

  1c cross| cast up (2c down) ; set | cast to 2pl (2c up) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10844, '2018-06-11 00:37:19.393585+00', '2023-02-04 01:23:11.426682+00', 18341, 3, NULL, 'ace', '1-8::
    1s dance RSh round each other back to place; set & cast to 2nd place
    (2s step up 7-8)
9-16::
    1L+2s also 1M+3s dance reels of 3 across (LSh to 1st corner to
    start). 1s pass RSh to face 2nd corners
17-20::
    1s+2nd corners dance Corner Pass+Turn. 1s end facing 3rd corners
21-28::
    1s dance "Hello-Goodbye" setting finishing facing 1st corners
29-32::
    1s+1st corners dance Corner Pass+Turn. 1s end in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (3851, '2013-07-13 15:56:23.081983+00', '2020-10-01 17:43:40.418767+00', 14668, 1, NULL, 'ace', '1–::

  1c Turn RH | cast off (2c up) ; set | cross RH and face out (2,1x,3)

9–::

  Reels3 on the sides, Rsh to 1cnrs, finish BtoB in centre facing opp. side for

17–::

  DTr, 1c finish in centre facing down on opp. side

25–::

  1c lead between 3c, cross and cast up, dance between 2c and cast off to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3850, '2013-07-13 15:56:23.039899+00', '2020-10-01 17:46:39.759541+00', 14669, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  1c turn BH twice ; cast to face 1cnrs (2c up)

9–::

  SetH&G , finish with petronella to (2,1,3)



{{title}}

Reel



17–::

  1c Turn RH ¾ _while_{2} 2c+3c cross RH | set in lines across ; 1c Turn RH ¾ _while_{2} 2c+3c cross RH up/down | All set (3x,1x,2x)

25–::

  S&Link3 twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2525, '2012-01-22 19:29:46.249678+00', '2020-12-07 21:50:28.262137+00', 3323, 1, NULL, 'ace', '1–::

  1c advance and touch RH {1}, retire {1} | cross LH ; lead down RH (2c up) | turn LH to face 1cnrs

9–::

  Turn CPCP (to 2,1,3)

17–::

  2W+1W+3W set, advance ; retire, and set, _while{8}_ 2M+1M+3M stand | set ; A&R

25–::

  All cross RH | ½ circle6 L ; All cross LH | ½ circle6 R (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14188, '2021-08-07 11:32:39.341223+00', '2021-08-08 06:49:07.364641+00', 20425, 1, 1645, 'ace', '1--::
  1c+2c & 4c+5c *Flirt & Cast:* 1W+2M & 4W+5M advance to centre {1}, pivot R to original place {1} | chase 1 place clw _while{4}_ 1M+2W & 4M+5W stand | advance to centre {1}, curve R to own sides (2,1,3,5,4) ; 2c+1c & 5c+4c RHA
9--::
  1c+5c &frac12; R&L without polite turn, 3c A&R {1+1} on [11-12] ; 5c & 1c turn P 1&frac12; RH (2,5,3,1,4)
17--::
  3c+1c+4c dance 3 Couple (Promenade) Chain Progression (2,5,4,1,3)
25--::
  2c+5c+4W & 4M+1c+3c Circle 5H part way to L | set with hands joined ; complete Circle 5H round to sides (2,5,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10657, '2018-04-19 12:00:18.576555+00', '2018-04-19 14:50:32.593168+00', 13909, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; cross RH, cast R round 1cnr to centre, BtoB facing opposite side

9--::

  2c+1c+3c »Saltire triangles« [joining hands, all set. On 2nd PdB, releasing hands, 1c dance ¼ L to face 1M(1W) up(dn), 2c(3c) pivot ¼ to face dn(up) | as in Crown Triangles, repeat similarly [9-10] 3 times, 1c facing 4cnrs at end]

17-32::

  2c+1c+3c »Square reel of 6«  

_17--_

  ½ Reels3 on sidelines, 1c Rsh to 4cnrs to start, finish in centre facing 1cnrs position ; ½ Reels3 across, 1c Lsh to 1cnrs position to start, finish in centre facing 2cnrs position  

_25--_

  ½ Reels3 on sidelines, 1c Rsh to 2cnrs to start, finish in centre facing 3cnrs position ; ½ Reels3 across, 1c Lsh to 3cnrs position, finish in 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3717, '2013-03-24 14:17:11.152874+00', '2019-02-04 13:37:05.758962+00', 14748, 1, NULL, 'ace', '1–::

  1c cross RH, cast (2c up), cross LH, cast to bottom and cross up, staying in the middle facing up

9–::

  Hands3 across with own corners (1W LH, 1M RH); 1c lead to top and cross down (2,1,3)

17–::

  Mirror Reels3 on own side, 1c start in and down (2,1,3)

25–::

  All A&R ; 1c turn RH and cast off (3c up) (2,3,1)

33–::

  All Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10302, '2017-12-11 11:35:20.359977+00', '2017-12-11 11:37:25.700149+00', 18104, 2, NULL, 'ace', '1-8::

  With nearer hands joined, balance/set and pass right hands with oncoming dancer,  balance/set and giving left hands and pass the next oncoming dancer.

9-16::

  With this couple dance right hands across  and back with the left.

17-24::

  Dance a right shoulder Gypsy turn with the opposite dancer ( no hands, just eye contact); dance a right shoulder Gypsy turn with partner.

25-32::

  The women giving right hands change places; the men giving left hands change places, all set facing partner and giving right hand half turn to face a new couple.

', 5);
INSERT INTO 'dancecrib' VALUES (10303, '2017-12-11 11:54:02.141501+00', '2017-12-11 11:54:02.141501+00', 18105, 2, NULL, 'ace', '1-4::

  Dance four hands round to the left.

4-8::

  Giving both hands turn partner once round, finishing in promenade hold.

9-16::

  Dance past the facing couple right shoulder, the next couple by the left shoulder and dance left hands across with the oncoming third couple.

17-24::

  Dance four hands round to the right, giving both hands turn partner once round clockwise.

25-32::

  Dance a ladies'' chain.

', 5);
INSERT INTO 'dancecrib' VALUES (10300, '2017-12-10 15:58:20.162545+00', '2017-12-12 12:20:46.276282+00', 11041, 1, 202, 'ace', '1--::

  1c & 2c turn P RH ; turn LH

9--::

  1c lead down (2c up on [11-12]) ; and up to 2pl facing out and up (2,1,3)

17--::

  Mirror Reels3, 1c out and up to start, all taking hands in centre

25--::

  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (14190, '2021-08-08 02:41:22.291296+00', '2022-09-13 12:25:23.050692+00', 8078, 1, 202, 'ace', '1--::

  Reels4 (1,2,3,4)

9--::

  1c lead down ; turn RH ½ and lead up to between 2c. 1c face opposite sides

17--::

  Reel4 across

25--::

  1c dance to top and cast to 4plx (2c+3c+4c up) ; 1c cross RH | all set', 2);
INSERT INTO 'dancecrib' VALUES (3420, '2012-01-22 19:30:24.741302+00', '2022-09-25 13:52:19.488142+00', 6701, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; turn 1¼ RH to promhold facing M side

9–::

  1c Rsh ½Reel3 with 2M+3M ; Rsh ½Reel3 with 3W+2W, 1c finish in centre facing 3W (now in 1W pl)

17–::

  1c set to 3W pulling Rsh back | set to 2W ; set to 2M | 1c set to 3M _while_{2} 3c+2c set advancing into

25–::

  3c+1c+2c Allemande', 3);
INSERT INTO 'dancecrib' VALUES (3429, '2012-01-22 19:30:25.15963+00', '2016-02-11 23:51:32.31734+00', 13745, 1, NULL, 'ace', '1–::

  1c cross RH | cast off 2 ; cross LH and cast up to face 1cnr (2c up)

9–::

  ½ Diag Reel4 with 1cnrs ; 1c Turn LH to face 2cnr

17–::

  ½ Diag Reel4 with 2cnrs ; 1c Turn LH 1½ to midline, M below W

25–::

  Teapots R (3c+1W & 1M+2c RHA), at end 1c pass Lsh to opposite side ; All Chase clw ½ to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3852, '2013-07-13 15:56:23.228824+00', '2014-04-30 23:24:13.521655+00', 14656, 1, NULL, 'ace', '1–::
  1W, 1M following, casts off one | cross (2c up) ; cast off on M side | cross (3c up) and 1W faces out (2,3,1),
9–::
  Reels3 on the sides, 1c Lsh to 3c , 1W&3M face out
17–::
  1c+3c ½ L&R, starting LEFT H on sideline (2,1x,3x) ; 2c+1c repeat (1,2x,3x)
25–::
  1c set | cast off (2c up) ; All A&R, 2c+3c changing sides RH on [30] (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3433, '2012-01-22 19:30:25.323535+00', '2015-02-23 22:27:27.362789+00', 11586, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; 2c+1c+3c A&R

9–::

  1c cross LH and cast L into lines across ; 2c+1W & 1M+3c A&R

17–::

  Reels3 across 1c giving Rsh to 1cnr, finish BtB facing 1cnr

25–::

  1c turn 1cnr RH | pass P Rsh ; turn 2cnr RH, pass P Rsh to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3427, '2012-01-22 19:30:25.037238+00', '2017-07-07 13:42:41.443144+00', 6711, 1, NULL, 'ace', '1–::

  1M cast off one (2M up), turn 3W LH to finish between 2W and 3W ; 1W repeats (RH with 3M, to between 2M and 3M) (2W up) (2,1x,3)

9–::

  Circle6 and back, 1c to face 1cnrs

17–::

  1c set to and turn corners (to 2,1x,3)

25–::

  All A&R ; 1c turn RH 1½', 3);
INSERT INTO 'dancecrib' VALUES (3434, '2012-01-22 19:30:25.36298+00', '2017-07-07 14:10:39.180566+00', 6721, 1, NULL, 'ace', '1–::

  1c+2c set twice ; cross RH and face P (1x,2x,3)

9–::

  1W+2W turn to face and cast to own sideline outside P ; 1M+2M turn to face and cast round P to own side (W step to own place)  (1,2,3)

17–::

  1c lead down ; cast up round 3c, meet and lead up (1,2,3)

25–::

  1c cross | cast (2c up) ; turn 1½ RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3435, '2012-01-22 19:30:25.402362+00', '2014-07-25 23:04:49.150364+00', 15027, 1, NULL, 'ace', '1–::

  1c+2c+3c A&R ; All cross RH | All chase ¼ clw into lines across (M below W)

9–::

 All A&R up/dn ; All change place with P LH and chase ¼ cclw to own places

17–::

  All circle6 and back

25–::

  1c ½ Fig8 round 2c ; 1c cross RH | cast off (2c up) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3422, '2012-01-22 19:30:24.821595+00', '2014-09-22 15:13:25.886315+00', 9770, 1, NULL, 'ace', '1–::

  (1c set | cast off 2 and lead to top) _while{8}_ (2c wait | set ; cast off one and lead up to 2pos) _while{8}_ (3c wait {4} ; set | cast off to 3pos) for

9–::

  1c+2c+3c Promenade, at end 1c cast to 2pl and 2c dance to top (2,1,3)

17–::

  1c cross between 3c | cast up ; cross between 2c | cast to 2pl

25–::

  All Petronella turn | set up/down ; 1¼ turn RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3437, '2012-01-22 19:30:25.481398+00', '2021-04-05 13:16:18.987418+00', 6736, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; dance down between 3c and cast up to 1cnrs

9–::

  1c set to 1cnrs, then to dancer on the right (4cnr) ; 1c+4cnr RH turn to sidelines, 2c+1c+3c set

17–::

  Reels3 across (Rsh to 2cnr = 1W down, 1M up), finishing in the middle for

25–::

  2c+1c+3c Allemande (to 3,1,2)

33–::

  1c cross RH, 3W+2M change places RH ; 3M&2W repeat, all cross RH (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3441, '2012-01-22 19:30:25.664818+00', '2014-04-30 23:24:13.718987+00', 6763, 1, NULL, 'ace', '1–::
  1c Rsh Reels3 on opposite side, 1M crossing behind P to begin, at end 1W crosses above 1M to (1,2,3)
9–::
  1c Rsh Reels3 on own side (1,2,3)
17–::
  1c lead down the middle and up
25–::
  1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10304, '2017-12-11 14:12:08.282592+00', '2017-12-11 14:13:07.420381+00', 18107, 2, NULL, 'ace', '1-8::

  Four hands round in a circle and back

9-16::

  Right hands across and back

17-24::

  Dance back to back with partner.  Turn opposite  dancers with left hand once round finishing in promenade hold with new partner.

25-32::

  Promenade anywhere in the room, on the last two bars find another couple to repeat the dance.



*The left hand turn can be replaced by a birl/swing.*

', 5);
INSERT INTO 'dancecrib' VALUES (3244, '2012-01-22 19:30:17.255262+00', '2020-07-13 21:40:27.231895+00', 6029, 1, NULL, 'ace', '1–::

  1c (NHJ) set twice to 2W ; circle3 L with her

9–::

  1c+2W (on left) in line set twice to 2M ; circle4 with him, end in own places

17–::

  1c followed by 2c & 3c lead down to 3pl ; all cross and dance up on opposite sides (to 1x,2x,3x)

25–::

  1c+2c+3c set, 1c cast off one _while_ 2c dance up and 3c set ; 2c+1c+3c turn BH 1½', 3);
INSERT INTO 'dancecrib' VALUES (3493, '2012-01-22 19:30:27.745249+00', '2014-04-30 23:24:14.707318+00', 11813, 1, NULL, 'ace', '1–::
  1c+3c advance | set ; 1W+3M & 1M+3W dance out between side couple, split and cast to own place
9–::
  2c+4c repeat
17–::
  All L-Chain with ½RHA in middle, keep hold LH for
25–::
  Turn LH ¾ (M in middle) | set to P ; turn RH into
33–::
  Promenade ¾ cclw | set to P', 3);
INSERT INTO 'dancecrib' VALUES (14191, '2021-08-09 15:42:08.837393+00', '2021-08-09 15:46:06.634015+00', 8062, 1, 202, 'ace', '1--::

  1c Fig8 on sides, in and down (1,2,3)

9--::

  1c slip down ; and up. 1c stay in middle (1,2,3)

17--::

  1c long cast to 2pl (2c up) ; 1c+3c Circle4 L (2,1,3)

25--::

  2c+1c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8821, '2015-07-26 12:43:19.930311+00', '2017-01-12 16:58:05.703741+00', 16519, 2, 1, 'ace', '1–4::

  1s+2s RH across finish 2s facing down

5–8::

  1s+2s+3s dance ½ reels of 3 on sides, 2s give L shoulder to 3s to begin

9–12::

  3s+2s (at top) RH across finish 2s facing down

13–16::

  3s+2s+1s dance ½ reels of 3 on sides, 2s give L shoulder to 1s to begin

17–24::

  1s+2s+3s Set and Rotate (3 2 1)

25–32::

  3s+1s RH across to face up, 3s cast to 3rd place whilst 1s lead up and cast

  to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (3457, '2012-01-22 19:30:26.306069+00', '2020-09-18 08:11:18.586247+00', 13468, 1, NULL, 'ace', '1–::

  1c+2c RHA ; 1c turn RH 1¼, finish 1W+2c in line across NHJ with 1M behind

9–::

  All dance down the middle, on [12] 1c change place Rsh and 2c swivel inwards into ; 2c+1M in line across NHJ with 1W following dance up the middle, finish at top with 1W in 2pl on midline

17–::

  1M+1W cast R round 2W and cross to (2,1) ; 2c+1c Circle4 L

25–::

  2M+1W turn RH ; 2W+1M turn LH', 3);
INSERT INTO 'dancecrib' VALUES (3431, '2012-01-22 19:30:25.244451+00', '2018-01-23 09:35:31.339148+00', 6720, 1, NULL, 'ace', '1–::

  1W+2W advance NHJ to P and set ; retire and set

9–::

  1M+2M repeat

17–::

  1c (2c dance up and follow) lead down the middle ; and up, 2c leading and casting to 2pl, all finish in promhold facing up

25–::

  1c+2c Allemande.', 3);
INSERT INTO 'dancecrib' VALUES (10489, '2018-03-05 21:16:19.845502+00', '2018-04-26 22:53:41.166137+00', 16057, 1, 202, 'ace', '1--::

  1c & 3c set | cross RH ; cast (2c & 4c up) | turn LH facing 1cnrs

9--::

  ½ Reels4 in 1diag, pass Rsh ; ½ Reels4 in 2diag, pass Rsh to face 3cnrs

17--::

  ½ Reels4 in 1diag, pass Rsh to form a line on the midline, M facing up, W facing down ; ½ Reel4, on [24] 1M+3W change places LH

25--::

  3M+5c & 3W+4c+1M & 1W+2c LHA, on [28] 3c & 1c pass P Lsh to change places ; 3W+5c & 3M+4c+1W & 1M+2c RHA to sidelines (5,3,4,1,2)

33--::

  Circle10 and back.', 2);
INSERT INTO 'dancecrib' VALUES (9878, '2017-05-21 14:51:48.222701+00', '2018-12-22 23:31:28.408393+00', 17757, 1, 1645, 'ace', '1-::

  Extended Espagnole: 1W+2W also 3W+4W lead RH to opposite sides & cross _while{2}_ 2M+3M lead LH to opposite sides & cross _while{2}_ 1M & 4M cross singly (W:2143 on M side, M:1324 on W side) | repeat three times from new psns to (4,3,2,1)

9-::

  3c turn LH 1&frac12;  _while{4}_ 2c turn RH 1&frac12; ; 4c+3c & 2c+1c S&Link (3x,4,1,2x)

17-::

  4c+1c LHA _while{4}_ 3c & 2c chase &frac12; clw to (2,4,1,3) ; 2c+4c & 1c+3c RHA

25-::

  All RSh Reels4 on the sides, 4M+1M end with &frac12; LH turn retaining hands (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3697, '2013-02-04 23:29:47.772231+00', '2014-04-30 23:24:13.780879+00', 6771, 1, NULL, 'ace', '1–::
  1c lead down the middle and up {6} | cast off (2c up) (2,1,3)
9–::
  Teapots R ; and L
17–::
  All A&R ; dance BtoB
25–::
  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (3446, '2012-01-22 19:30:25.863593+00', '2014-04-30 23:24:13.826289+00', 6793, 1, NULL, 'ace', '1–::
  1c+2c+3c mirror Reels3 on sidelines (2c start out and up)
9–::
  1c dance down | cast up ; dance down two (2c up) and cast up to 2pl (2,1,3)
17–::
  2c+1c+3c Teapots R (1M down) ; L (1M up)
25–::
  2c+1c+3c circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (3634, '2012-07-21 11:46:18.916161+00', '2014-04-30 23:24:13.856501+00', 13210, 1, NULL, 'ace', '1–::
  1c ½Fig8 round 2c ; cross RH | 1c+2c set (1,2,3)
9–::
  Chain Progression: 1c+2c turn RH ¾ | 1W+2M (outers) chase ½ clw _while_{4}   1M+2W (inners) turn LH 1½ | 2c+1c turn RH ¾ , and 1c face out (2,1,3)
17–::
  ½ Reels3 on sides, Rsh to 3cnr, 1c cross into ; ½ Reels3 on opp. side, Rsh to 1cnr, at end 1c finish BtoB, W facing up, M down for
25–::
  Crown Triangles {4 bars} to (2,1,3) ; All turn RH
33–::
  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3447, '2012-01-22 19:30:25.90341+00', '2017-07-07 14:08:49.277591+00', 6797, 1, NULL, 'ace', '{{explanation}}

Throughout this dance a special slow »menuet« PdB (step, step, close) is used.



1-6::

  1M+2W turn RH, 2W to own place, 1M to 2M place (2M up on [4-6].

7-12::

  1W+2M turn LH, 2M to 1M place, 1W to 2W place (2W up on [10-12] (2,1,3)

13-24::

  1c+3c R&L (3 steps per hand), 1c finish facing 1cnrs

25-36::

  Turn CPCP (3 steps per hand) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14194, '2021-08-09 23:54:18.883848+00', '2021-08-23 18:33:10.404217+00', 8077, 1, 202, 'ace', '1--::

  1W+2c Reel3 across, 1W RSh to 2M

9--::

  1M+2C Reel3 across, 1M LSh to 2W

17--::

  1c set | cast off (2c up) ; turn P LH (2,1)

25--::

  2c+1c R&L (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (10393, '2018-01-19 02:09:58.787432+00', '2022-02-21 09:05:33.120433+00', 17971, 2, 963, 'ace', '1-2::

  1c cast, 2s up

3-4::

    2+1+3 set

5-8::

    1c + 1st cnr back to back

9-12::

    1c + 2nd cnr back to back

13-14::

   2+1+3 set

15-16::

   1c cast, 3s up

17-20::

   2+3+1 adv/ret

21-24::

   2+3+1 turn partner RH into promenade hold

25-32::

   2+3+1 promenade   2,3,1

', 5);
INSERT INTO 'dancecrib' VALUES (12776, '2020-04-24 17:02:01.938825+00', '2020-04-26 09:56:31.370565+00', 19959, 1, 202, 'ace', '_Strathspey_
1--::
  Interlocking Reels4, RSh to P (1,2,3,4)
9--::
  2c & 4c set | advance {2} ; set | retire {2} _while{8}_ 1c & 3c pass opposite person RSh to exchanged places, cast away from P, chase behind sides to places, passing other person RSh (1,2,3,4)
17--::
  Repeat [9-16], even and odd couples having changed pattern (1,2,3,4)
25--::
  1c+2c & 3c+4c pass opposite person RSh and face out | all chase clw one place (to 3,2,1,4  all W on P''s L) ; 1c+2c & 3c+4c pass opposite person RSh and face P | all set (4,1,2,3)
33-64::
  Repeat from new positions (3,4,1,2)  

_Reel_
1-64::
  Repeat in Reel time', 4);
INSERT INTO 'dancecrib' VALUES (2544, '2012-01-22 19:29:47.032778+00', '2020-12-07 21:59:09.087262+00', 3390, 1, NULL, 'ace', '1–::

  1c+2c set, ½ RHA ; set, cross RH (2,1,3)

9–::

  All set, cross RH ; 2c+3c set and change places on sidelines, 3c passing inside (M RH, W LH) _while{4}_ 1c cast off round 3c and dance up NHJ into

17–::

  3c+1c+2c Wheels (on W side: RHA, on M side: LHA) twice round, in the second round 1c, then 2c and 3c change to the wheel on own side, at end 1c, then 2c and 3c take promhold into

25–::

  1c+2c+3c Promenade, at end 1c casts off to 2pl, 2c dances to top.', 2);
INSERT INTO 'dancecrib' VALUES (10306, '2017-12-11 15:44:01.176475+00', '2021-01-04 16:07:07.722607+00', 13209, 1, 202, 'ace', '1--::

  1c & 5c cross RH | cast inwards (2c & 4c step out) ; 1c+5c ½ RHA (to 2,5,3,1,4) | 1c & 5c cast outwards to ends (5,2,3,4,1)

9--::

  5c & 1c BtoB ; turn P RH _while{8}_ 2c+3c+4c Gr-Chain

17--::

  Circle10 and back

25--::

  5c cast to 4pl (2c+3c+4c step up) ; All turn P BH (2,3,4,5,1)', 2);
INSERT INTO 'dancecrib' VALUES (13565, '2021-01-20 01:51:10.771374+00', '2021-01-20 01:57:36.718387+00', 18570, 1, 202, 'ace', '1--::
  1c turn 2c on sides, starting in and down | 2c continue to 1pl _while_ 1c dance down to 2pl centre ; 1c turn 3c EH and face 1cnrs
9--::
  Reel4 on 1diag. On [16] 1c pass P LSh, 1M facing up, 1W facing down
17--::
  2c+1M & 1W+3c RHA, pass RSh ; 2c+1W & 1M+3c LHA. 1c face 2cnrs
25--::
  Reel4 on 2diag (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3451, '2012-01-22 19:30:26.064826+00', '2021-04-05 10:49:55.843907+00', 6816, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) to join RH and LH with 1cnr ; BiL | turn 1cnr LH to (2,1x,3)

9–::

  1c cross RH | cast R round 3cnr to join RH and LH with 2cnr ; BiL | turn 2cnr LH to 1M between 2c facing 1W between 3c

17–::

  1c set advancing & swiveling R (M faces up, W down) | continue as in DTr (set ; change places | set)

25–::

  Reels3{6} on opposite side (Lsh to 1cnr) | 1c cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14192, '2021-08-09 15:53:38.17864+00', '2021-08-09 15:55:59.60601+00', 6347, 1, 202, 'ace', '1--::

  1c lead down {3}, lead up {3} | cast off (2c up) (2,1,3)

9--::

  All turn P RH ; turn P LH (2,1,3)

17--::

  1c Fig8 up round 2c (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10490, '2018-03-06 00:21:42.952143+00', '2018-03-06 00:31:05.295263+00', 18248, 2, NULL, 'ace', '1-8::

  1s lead down & up

9-16::

  1s, 2s & 3s promenade

17-24::

  1s set, cast, turn LH to finish facing 1st corners (2s step up on Bars 3 & 4)

25-32::

  1s dance a ½ diagonal reel of 4 with 1st corners, pass RSh into ½ diagonal reel of 4 with 2nd corners, 1s finish in 2nd place on opposite sides

33-40::

  1s, 2s & 3s chase for 4 bars and turn RH for 4 bars   (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (10153, '2017-09-29 17:19:33.236328+00', '2019-02-12 23:54:21.065113+00', 17979, 1, 202, 'ace', '1--::

 All A&R{1+1} | 1c+2c & 3c+4c RHA | 1c+2c & 3c+4c A&R{1+1}

9--::

 Reels4 (1,2,3,4)

17--::

 1M+2W & 3M+4W cross RH | middle 2 cpls set diagonally ; 1W+2M & 3W+4M cross LH | middle 2 cpls set diagonally (2x,1x,4x,3x)

25--::

 1c+4c circle4 L ; 4M followed by 1M & 1W followed by 4W chase cclw ½ through nearest ends  to own sides (2x,4,1,3x)

33--::

 4c+1c turn P RH 1½ ; 2c+4c+1c+3c circle8 L ½ (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (3364, '2012-01-22 19:30:22.194179+00', '2019-03-09 20:01:15.249756+00', 6436, 1, NULL, 'ace', '1–::

  1W+2M+3W+4M Petronella to midline _while_ partners step R to diamond positions  | all set ; top and bottom circle4 L

9–::

  1W+2M+3W+4M reel4 on midline

17–::

  1c+2c & 3c+4c RHA to own places ; all C dance BtoB finishing BHJ for

25–::

  4c Poussette (to 2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3691, '2013-01-27 20:01:29.322748+00', '2014-04-30 23:24:14.069213+00', 8842, 1, NULL, 'ace', '1–::
  1c+4c set (facing down/up) | lead through the middle NHJ, 1c passing under arch by 4c and cross over, the M crossing first and the W passing under his arm | 1c+4c cast, 2c+3c stepping to end (2,4x,1x,3)
9–::
  Repeat from new places (4x,3x,2x,1x)
17–::
  4c, the others following, cast to own places ; all turn RH (1x,2x,3x,4x)
25–::
  1c+2c & 3c+4c cross to own sides, M making arches | 1c+2c & 3c+4c change places on sides, 1c+4c making arches ; 1c+4c cross RH and ½ RHA (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3678, '2013-01-08 13:44:53.911639+00', '2014-04-30 23:24:14.099395+00', 13445, 1, NULL, 'ace', '1–::
  3c set | cast up ; dance between 1c (2c down) and cast off (1,3,2)
9–::
  3c dance ½ Reels3 across, Rsh to 2cnr (1x,3x,2x) ; repeat. Rsh to 4cnr (1.3.2)
17–::
  1c+3c S&Link ; 1c&2c S&Link (3,2,1)
25–::
  2c with 3c following cross down into fig8 round 1c (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3462, '2012-01-22 19:30:26.50552+00', '2015-07-04 23:05:09.366231+00', 6848, 1, NULL, 'ace', '1–::

  1c cast behind own lines and cast back, on [8] all dance in for

9–::

  1c+2c+3c Promenade, 1c casting off to 1cnrs and 2c finish in 1pl

17–::

  1c set to 1cnrs, set to 2cnrs, swivelling R to between corners ; All circle6 L (2,1x,3)

25–::

  All A&R ; all turn BH to own side (1c 1½ turn) (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (8909, '2015-09-19 01:40:32.392132+00', '2022-08-12 08:29:12.465432+00', 2172, 2, 160, 'ace', '1-8::

  1C set, cast 1pl ; RH Across - 1L with 2C and 1M with 3C.

9-16::

  1C set, cross RH ; 1M cast around 3L as 1L cast around 2M - finish back to back with ptnr facing own sides.

17-24::

  Double Triangles.

25-32::

  6Hands round & back.', 2);
INSERT INTO 'dancecrib' VALUES (3464, '2012-01-22 19:30:26.584896+00', '2022-09-30 12:03:40.354625+00', 10857, 1, NULL, 'ace', '1–::

  1c+2c set | cross RH ; set | cross RH

9–::

  1M, 1W following, casts off and cross (2c up) (to 2, 1x) ; 1c set to P | 1c set to 2c

17–::

  2c+1c L-Chain

25–::

  1c set to P | 1W, 1M following, casts up, cross to own side | 1W dances behind 2W and 1M in front of 2M to (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (7836, '2013-08-21 08:31:49.55295+00', '2023-02-04 01:23:04.771693+00', 14954, 3, NULL, 'ace', '1-8::
    All set & 1s+2s also 3s+4s dance 1/2 R&L & all set
9-16::
    1s+2s dance 1/2 LH across as 3s+4s dance 1/2 RH across then 2L+3L
    followed by 2M+3M, 1M+4M, 1L+4L promenade clockwise in turn around
    set to end 2L+2M+1M+1L on Mens side & 3L+3M+4M+4L on Ladies side
17-24::
    Repeat bars 1-8 from new places
25-32::
    Repeat bars 9-16 from new places with dancers on Ladies side (3M &
    4M) leading the promenade
33-40::
    _4_ Men at top & 4 Ladies at bottom, circle 4H round, all drop hands
    & chase clockwise 2 places (now opposite partners) & cross RH to end
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8083, '2013-10-12 16:20:30.093298+00', '2014-04-30 23:24:14.263975+00', 14975, 1, NULL, 'ace', '1–::
  1c+5c turn RH ½ | Chase clw (1M & 5W leading) behind sideline to 4pl/2pl | turn P RH to face 1cnr _while_{8} 3c set | dance up (2c+4c step down) ; and curve into 1pl | set (3,5,2,1,4)
9–::
  Corners Chain with setting: 1c&5c change place RH with 1cnr | cnrs turn LH as 1c+5c set ; change back with cnr | turn LH 1¼ to face 2cnr
17–::
  Repeat with 2cnr, at end 5c+1c turn P LH to finish on midline facing own side, M above W (3,5,2,1.4)
25–::
  RHA in pattern 3-4-3 ; 5c+1c BiL on midline | turn P LH ¾ to (3,5,2,1,4)', 3);
INSERT INTO 'dancecrib' VALUES (14705, '2022-03-16 23:13:08.062802+00', '2022-03-16 23:13:23.230608+00', 17014, 1, 1645, 'ace', '1--::

  1c & 3c S&Link ; &frac12; RHA | 3W+1M & 3M+1W &frac12; turn RH & 1c/3c end in tandem facing 2W/3W (1,2,3,4)

9--::

  1c & 3c, M leading, &frac12; alternating tandem RSh Reels3 with 2W+4M & 4W+2M ; 1c+3c &frac12; LHA | cast, LSh back to opp place (3,4x,1,2x)

17--20::

  4c & 2c S&Link, 2W+4W &frac12; turn LH into line across

21--28::

  4M+2W+4W+2M &frac12; RSh Reel4 across, 2W & 4W omit last LSh pass to end facing P

29--32::

  2c & 4c turn 1&frac14; RH to sides (3,4,1,2)

33--::

  *Set & Rotate for 4 couples:* W set _while_ M &frac12; RHA | all cast clw, W to P''s place, M to next W place clw ;

  M set _while_ W &frac12; RHA | all cast clw to next place (4,1,2,3)

41--::

  All circle8 to L, pivot & chase back (4,1,2,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3578, '2012-05-31 22:08:51.341798+00', '2019-01-30 23:42:16.893246+00', 12246, 1, NULL, 'ace', '1–::

  1M+2L & 3M+4L set | change places RH ; cross to own side passing opposite Rsh |  cast clockwise to own places

9–::

  All dance RSh reels of 4 on sides

17–::

  1c+2c & 3c+4c RHA ; 2c+3c LHA

25–::

  1c & 4c cross RH | cast inwards one place (2c+3c step to end) ; 1c+4c ½ R&L.  (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3468, '2012-01-22 19:30:26.743339+00', '2021-03-27 21:48:06.659465+00', 12567, 1, NULL, 'ace', '1–::

  1c Mirror Figs8 on own side, start inwards and give hands to standing couples

9–::

  Mirror Reels3 on the sides, 2c starts out and up, finish 1c facing 2c

17–::

  1c with 2c dancing up and following dance down the middle, and up 1c leading (2c split)

25–::

  1c+2c Poussette (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3466, '2012-01-22 19:30:26.663858+00', '2021-04-04 11:42:11.162323+00', 6879, 1, NULL, 'ace', '1–::

  1c+2c turn RH ½ | lead down (1c divide) ; lead up (2c leading) | 2c turn RH ½ to 1pl _while_{2} 1c faces 1cnr

9–::

  SetH&G , finish BtB, 1M facing up, 1W down.

17–::

  ½Reel4 with 2cnrs, Pull Rsh back, ½Reel with 1cnrs (3x,1,2x)

25–::

  3 Couple Knot (2c+3c full turn to start)', 2);
INSERT INTO 'dancecrib' VALUES (3463, '2012-01-22 19:30:26.54534+00', '2021-04-04 19:08:45.042849+00', 6849, 1, NULL, 'ace', '1–::

  1c set | cast off 2 ; meet and lead to the top, finish facing down NHJ

9–::

  1c (arch) dance down as 2c+3c lead up | 1c dance up NHJ as 3c cast to 3pl ; 2c+1c Circle4 L (2,1,3)

17–::

  1c facing 3c NHJ set up/dn | 1c+3c set to P, 1c ends facing up, 3c in 3pl ; 2c facing 1c NHJ set up/dn | 2c+1c set to P, retiring to sidelines (2,1,3)

25–::

  1c+3c Circle4 L ; 2c+1c LHA', 3);
INSERT INTO 'dancecrib' VALUES (9779, '2017-04-08 07:32:30.650076+00', '2021-08-05 22:28:24.545564+00', 10458, 1, 202, 'ace', '1-- ::

 1c+2c & 3c+4c progressive DblFig8 (1c cross, cast ; cross up, cast _while{8}_ 2c set, cross up ; cast, cross up) (2,1,4,3)

9-- ::

 Mirror Reels4 (2c&4c start out and down, 1c&3c start in and up)

17-- ::

 2c+1c & 4c+3c S&Link ; 2c+3c S&Link (1,3,2,4)

25-- ::

 All set | All turn P BH twice to finish in centre facing down | 1c&2c dance down one _while{2}_ 3c&4c cast up one (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (14193, '2021-08-09 16:02:27.655292+00', '2021-08-09 16:04:46.534693+00', 243, 1, 202, 'ace', '1--::

  1c turn RH ; turn LH

9--::

  1c+2c RHA ; LHA

17--::

  2c lead down ; lead up

25--::

  1c lead down ; lead up to 2pl (2c up on [27-28]) (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (3461, '2012-01-22 19:30:26.465841+00', '2019-02-04 14:55:37.472483+00', 6845, 1, NULL, 'ace', '1--::

  1c turn RH ; 1W & 3M set | cast to 2pl (2M/2W step down/up) (1M+3M+2M on M side, 2W+1W+3W on W side)

9--::

  1W & 3M ½ Fig8 R, LSh to P ; ½ Reels3 on side, RSh to 4cnrs[pos] (2M+1W+1M on M side, 3W+3M+2W on W side)

17--::

  8 bars of 3C R&L (1,2x,3)

25--::

  1c+2c set | ½ RHA (to 2,1x,3) ; 1c set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3460, '2012-01-22 19:30:26.426126+00', '2019-03-07 22:45:54.16974+00', 7531, 1, NULL, 'ace', '1–::

  1M+3M turn RH ; chase clw round set to exchanged places

9–::

  1W+3W turn LH ; chase cclw round set to exchanged places

17-32::

  2c+4c repeat 16 bars

33–::

  1c+3c in promhold A&R ; pass other C Rsh and bear right into

41–::

  1c+3c RHA ; LHA to own places

49-64::

  2c+4c repeat 16 bars

65–::

  All M dance in front of P, behind next W, in front of next W, behind next W, to places

73–::

  All W repeat dancing to left/clw

81–::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (3472, '2012-01-22 19:30:26.867787+00', '2017-04-27 20:28:51.533341+00', 12743, 1, NULL, 'ace', '1–::

  1c lead down {3}, up {3} | turn BH ½ and open out to face 2c. (1,2,3)

9–::

  1c set to 2c | change places on sideline Easy H (1c pass inside) and 1c face 2c ; 2c+1c R&L one step per hand 1c finish facing 1cnrs.

17–::

  1c set to 1cnr, to P ; to 2cnr (HG setting) | 1c petronella to BtoB, 1M facing up. 1W down.

25–::

  Opposing Reels3{6} with cnrs, Rsh to 2cnr | 1c cross RH. (2,1,3).', 2);
INSERT INTO 'dancecrib' VALUES (3387, '2012-01-22 19:30:23.267784+00', '2017-11-12 21:57:59.040611+00', 6539, 1, NULL, 'ace', '1–::

  1c+2c RHA {3}, 1c cast off as 2c dance to 1pl ; 1c+3c repeat LH (2,3,1)

9–::

  1c set, dance NHJ to top (3c down) ; cast off, turn RH to face 1cnr

17–::

  1c dance Rsh round 1cnr | Lsh round P ; Rsh round 2cnr | turn P LH to face 1cnr

25–::

  1c SetH&G {6} | turn RH to 2pl (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10422, '2018-02-10 16:20:03.212398+00', '2018-02-10 16:23:19.421197+00', 13773, 1, NULL, 'ace', '1--::

  1c+2c & 4c+5c Poussette _while{8}_ 3c set | cross RH; set | cross RH (1,2,3,4,5)

9--::

  1c+3c dance down one (2c+4c up) | set ; cast Rsh round 4cnr to face P on 1diag 

17--::

  1c set advancing and passing as 1cnrs set | turn 1cnr BH and face P on 2diag ; repeat with 2cnrs to (2,1x,4,3x,5)

25--::

  All set | 1c+3c cast off as 4c+5c dance up ; 1c+3c ½ Fig 8 up (2,4,1,5,3)



', 2);
INSERT INTO 'dancecrib' VALUES (8243, '2014-04-15 23:38:42.706536+00', '2014-04-30 23:24:14.344814+00', 6894, 1, NULL, 'ace', '1–::
  1c cross,| cast off one (2c up), cross LH, cast off and lead up to face 1cnr
9–::
  1c turn 1cnr RH | turn P LH _while_ cnrs chase one place clw ; 1c turn 2cnr person (in 1cnr place) RH | 1c pass Lsh to 2plx as cnrs chase one place again (3x,1x,2x)
17–::
  All set | petronella to midline ; All set | turn P RH ¾ into Allemande hold
25–::
  3C Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3476, '2012-01-22 19:30:27.02854+00', '2019-03-06 18:51:37.791893+00', 8466, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c R&L.

9–::

  1c Fig8 between 2c _while_{8} 3c Fig8 between 4c.

17–::

  2c Fig8 between 1c _while_{8} 4c Fig8 between 3c.

25–::

  1c cast off 3 places (other C up), all turn partner RH.', 2);
INSERT INTO 'dancecrib' VALUES (9269, '2016-07-14 14:51:33.014478+00', '2022-01-30 20:21:04.519498+00', 17141, 1, 1041, 'ace', '1--  ::  1C set | 1M set twice _while{4}_ 1W dance Rsh round P and back to place | 1c cross RH (1W face up) (1x,2)  

9--  ::  M-chain up/dn  

17--::  1st half of Set&Rotate ; RHA  

25--::  2nd half of Set&Rotate (2,1x) ; 1c turn RH 1½ (or R elbow pivot turn)  (2,1)



*Bar 1-16 2nd time through*  

1--  ::  1C set | 1W set twice _while{4}_ 1M dance Lsh round P and back to place | 1c cross LH (1M face up) (1x,2)  

9--  ::  L-chain up/dn 



*On [3-6] alternative: Highland setting steps*

', 4);
INSERT INTO 'dancecrib' VALUES (3473, '2012-01-22 19:30:26.907981+00', '2021-01-10 21:13:28.723958+00', 12696, 1, NULL, 'ace', '1–::

  1c set | cast ; pass through 3c and cast up

9–::

  Teapots R and L (2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA), and pass Lsh to face 1cnr

17–::

  1c SetH&G , finish BtoB facing 2cnr

25–::

  Opposing Reels3{6} on opposite sides, Rsh to 2cnr | 1c cross RH', 3);
INSERT INTO 'dancecrib' VALUES (8222, '2014-03-26 09:12:10.819585+00', '2014-04-30 23:24:14.466771+00', 9675, 1, NULL, 'ace', '{{explanation}}
All couples face centre in a big circle NHJ

1–::
  All waltz towards centre and back, turn toward P and face out ; waltz out NHJ and back
9–::
  Gypsy with P with eye contact, no hands ; turn P RH, finish M facing in
17–::
  Join hands in big circle and balance R and L | change place with neighbour LH ; Balance in circle again | turn neighbour LH ½ and face P
25–::
  Dance BtoB with P ; Pass P Rsh and turn new P BH and face centre', 3);
INSERT INTO 'dancecrib' VALUES (3480, '2012-01-22 19:30:27.19334+00', '2021-03-25 23:45:35.189795+00', 7533, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1W+2M Turn LH ; 1M+2W Turn RH

17–::

  1c BHJ slip down | and up ; cast to 4pl (2c+3c+4c up)

25–::

  4c+1c R&L  (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (3470, '2012-01-22 19:30:26.787839+00', '2021-02-06 13:07:03.259205+00', 10602, 1, NULL, 'ace', '1–::

  1M, followed by 1W, cast off one place and cross over below 2c, and back to own places (2c don''t step up or down)

9–::

  1c+2c Circle4 and back, to finish 1c facing 2c down/up

17–::

  2c making arch dance up to 1pl and hold the arch for all couples passing _while_{8} 1c dance down the middle and up to 2pl

25–::

  2c+1c Promenade

', 2);
INSERT INTO 'dancecrib' VALUES (13566, '2021-01-20 02:50:06.04135+00', '2021-01-20 13:20:59.482682+00', 18799, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; 2c+1M & 1W+3c RHA. 1c on sides face 1cnrs (2,1x,3)
9--::
  Fig8 on sides, 1c LSh to 1cnrs
17--::
  1c turn P LH | turn 1cnrs RH ; turn 2cnrs LH | turn P RH (2,1,3)
25--::
  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12780, '2020-04-27 23:09:35.653287+00', '2021-02-24 22:10:07.873284+00', 8918, 1, 202, 'ace', '1--::
  1c set | turn RH ½ to centre and face down ; lead down between 3c (2c up) | cast up to 2plx (2,1x,3)
9--::
  Mirror Reels3 on sides, 1c in and up, 2c out and down. 2c & 1c face up/down (2,1x,3)
17--::
  2c & 1c set | change places EH, 1c in and up (to 1x,2,3) ; 1c+2c set to P | 1c turn RH ½ _as_ 2c step in, both into allemande hold
25--::
  2C Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3474, '2012-01-22 19:30:26.948285+00', '2021-03-25 23:49:09.309234+00', 7532, 1, NULL, 'ace', '1–::

  1c dance between 2c and cast up ; 1c+2c turn RH into

9–::

  1c+2c Allemande, at end 1c turn RH into

17–::

  1c+1cnrs BiL | 1c turn RH ¾ into ; 1c+2cnrs BiL | 1c turn RH to (2,1,3)

25–::

  All Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (3389, '2012-01-22 19:30:23.348165+00', '2021-04-09 10:48:17.336026+00', 6550, 1, NULL, 'ace', '1–::

  1c lead down, cross below 3c and cast up ; dance up between 2c and cast into 2pl (2c up) to face 3c (2,1x,3)

9–::

  1c turn 3c EH (1c passing inside) ; repeat with 2c (2,1x,3)

17–::

  1W+3c & 1M+2c RHA ; 1c dance ½ Fig8 L (Rsh round 4cnr) (2,1,3)

25–::

  All C set | dance BtoB | set.', 3);
INSERT INTO 'dancecrib' VALUES (11522, '2019-01-19 20:01:17.202571+00', '2021-06-02 11:27:57.466763+00', 2656, 1, 1645, 'ace', '1-::

  1c turn 1&frac12; BH ; 1c+2c turn 1&frac12; BH on sides (2,1x)

9-::

  2c+1c L-Chain

17-::

  2c+1c set twice ; 1c &frac12; fig8 up round 2c (2,1)

25-::

  2c+1c R&L (2,1)

:: *Crib derived from the video*', 1);
INSERT INTO 'dancecrib' VALUES (3479, '2012-01-22 19:30:27.15149+00', '2014-07-02 05:45:48.840005+00', 6915, 1, NULL, 'ace', '{{explanation}}

C face C RR



1-16::

  1c facing 2c set, change places Rsh (W waltz turn R ¾, M ¼) ; set to P, change places as before.  Repeat, to own places.

17-32::

  All joining hands balance forward and backward | M balancing on the spot bring W on their L over to their R using BH ; repeat three times {4+4+4}

33--::

  Waltz around the other couple, M passing Lsh, and moving anti-clockwise to meet next couple.



*Note: Waltz setting is close to A{1}&R{1}.*', 3);
INSERT INTO 'dancecrib' VALUES (3484, '2012-01-22 19:30:27.387839+00', '2021-03-06 21:54:59.728053+00', 9015, 1, NULL, 'ace', '1–::

  1c cross down Rsh (2c up) | 1c (passing outside)+3c change places EH ; 2c & 1c (starting inwards) change places with  3c / 4c EH on sides, | join NH and BiL on both sidelines (3,2,4,1x)

9–::

  Reels4 on sidelines (Rsh on M side, Lsh on W side)

17–::

  »Double Capstan«: 3c dance between 2c+4c, cast up round them and dance to 4pl _while_{8} 1c cast up round 2c dance down between 4c and cast up to 1pl (1,2,4,3)

25–::

  1c cross RH | cast off 2 (2c+4c up) ; All turn P RH (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3854, '2013-07-13 15:56:24.02199+00', '2017-07-21 22:50:15.200063+00', 14667, 1, NULL, 'ace', '1–::

  1W+2M set advancing | Turn RH to place ; 1M+2W repeat (2,1)

9–::

  R&L

17–::

  1c facing 2c set | change pl. EH, 1c passing inside ; 2c facing 1c set | change pl. EH, 1c passing inside, 1c finish facing out

25-28::

  1c casts to 2pl (2c up) | All set.', 3);
INSERT INTO 'dancecrib' VALUES (10308, '2017-12-11 20:11:35.636809+00', '2017-12-11 20:11:35.636809+00', 18106, 2, NULL, 'ace', '1-4::

  Couples take nearer hands and set, men dance two skip changes of step to the centre; 

5-8::

  Pulling right shoulder back, men dance out towards  partner, give right hand and turn to finish back in the circle.

9-16::

  Couples take nearer hands and set, women two skip changes of step to the centre, pull left shoulder back, dance out towards partner and giving left hands turn to places.

17–20::

  Women stand still, while men dance in front of partner and the next woman in the circle, returning back to place by dancing behind the same two dancers outside the circle.

21-24::

  Men stand still while women dance in front of partner, and the next man in the  circle and behind them back to place.

25-32::

  All take hands in the circle and using slip step dance round to the left and back again.

', 5);
INSERT INTO 'dancecrib' VALUES (3486, '2012-01-22 19:30:27.468427+00', '2018-08-27 20:42:14.110964+00', 6956, 1, NULL, 'ace', '1–::

  1c+2c Poussette

9–::

  1c turn RH | cast to 2pl (2c up) ; ½ Fig8 to the L (M up, Wdown)

17–::

  1W+2c & 1M+3c Rsh ½Reels3 across ; 1M+2c & 1W+3c Rsh ½Reels3 across (to 2,1x,3)

25–::

  2c+1c+3c A&R{1+1} | A&R{1+1} ; 1c turn BH 1½', 3);
INSERT INTO 'dancecrib' VALUES (3485, '2012-01-22 19:30:27.428699+00', '2018-02-21 22:23:03.886777+00', 10548, 1, NULL, 'ace', '1–::

  1c cross down RH (2c up) | set ; cross down LH (3c up) set (2,3,1)

9–::

  1c cross RH | change pl. LH on sideline (2,1x,3) ; 2c+1c ½R&L, with extra ¼ turn into line across, W in the middle

17–::

  The Targe [1W+2W turn RH ¾ as 1M+2M chase ¼ cclw onto midline | middles turn ends LH ; repeat, finish (2,1x,3)]

25–::

  1c cross down LH between 3c and cast up ; dance up between 2c and cast off (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2320, '2012-01-22 19:29:31.400758+00', '2019-01-27 23:52:21.712669+00', 13001, 1, NULL, 'ace', '1–::

  1M+2c LHA _while{4}_ 1W+3c RHA ; All set to P | Turn RH

9–::

  All M dance Rsh round P ; RHA to place

17–::

  All W dance Lsh round P ; LHA to place and face out

25-40::

  Schiehallion Reel (to 2,3,1)

41–::

  Circle6 and back (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (3410, '2012-01-22 19:30:24.239502+00', '2014-04-30 23:24:13.167545+00', 6658, 1, NULL, 'ace', '1–::
  1c NHJ set twice to 2W ; 1c+2W circle3
9–::
  1c NHJ set twice to 2M ; 1c+2M circle3
17–::
  1c lead down the middle and up
25–::
  1c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (3508, '2012-01-22 19:30:28.363132+00', '2021-02-04 12:51:15.933312+00', 10864, 1, NULL, 'ace', '1–::

  1c+2c Set&Rotate (set to P | cast 1 place clw ; change place RH with P | chase 1 place clw), 1c finish ready for

9–::

  Teapots R ; and L (1W+2c & 1M+3c RHA ; 1M+2c & 1W+3c LHA)

17-32::

  3-couples R&L {12} ; all C turn RH', 3);
INSERT INTO 'dancecrib' VALUES (3858, '2013-07-13 15:56:24.622232+00', '2021-03-27 18:51:10.912321+00', 14644, 1, NULL, 'ace', '{{explanation}}

Note: no hands are used in crossing or turning



1–::

  1c cross R and cast off to face 1cnr

9–::

  Turn 1cnr L ; turn 2cnr R

17–::

  Reels3 on the sides with cnrs, Lsh to 1cnr

25–::

  1s dance up, cast off and cross R

', 3);
INSERT INTO 'dancecrib' VALUES (3498, '2012-01-22 19:30:27.940208+00', '2016-04-26 06:27:32.368138+00', 9765, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  All Circle8 and back

9–::

  All C S&Link, finishing next to corner ; all S&Link with corner, (finishing opposite P) but M face out

17–::

  Turn new partner LH ; All ½ L-Chain (L make wheel in middle), finish facing cnr (no polite turn)

25–::

  Set to and turn cnr RH, to face P ; set to and turn P LH

33–::

  All W set advancing into centre swiveling R ¼ | and cast into clw spiral out to L position 3 places clw | turn that M ½ RH

41–::

  All M set advancing into centre swiveling R ¼ | and cast into clw spiral out to L position 3 places clw | turn P ½ RH

49–::

  G-Chain, 1 step / hand

57–::

  All C face P and Petronella Turn (W now in centre, BtoB) | all set to P ; all C turn 1¼ BH (to 3,4,1,2)



{{title}}

Reel



{{explanation}}

Repeat 1-64, to own places, but on [61-64] turn RH', 4);
INSERT INTO 'dancecrib' VALUES (3499, '2012-01-22 19:30:27.980043+00', '2019-10-28 07:52:00.298476+00', 7018, 1, NULL, 'ace', '{{explanation}}

C face C RR



1–::

  Circle4 and back

9–::

  1W+2W dance BtoB ; turn RH (1x,2)

17–::

  1M+2M repeat (1x,2)

25–::

  All Turn P LH into promhold ; Pass Lsh and promenade to meet next couple.', 3);
INSERT INTO 'dancecrib' VALUES (13831, '2021-03-21 17:30:27.507025+00', '2022-10-23 19:51:38.569176+00', 7523, 1, 202, 'ace', '1--::

  1c turn RH | cast off 2 places ; meet and cross LH to 2plx (2c up on [5-6]). 1c face out (2,1x,3)

9--::

  Mirror Reels3 on sides, 1c out and up, 2c in and down. 2c & 1c face each other on sides (2,1x,3)

17--::

  2c+1c set | turn BH. 1c+3c face each other on sides ; 1c+3c set | turn BH (2,1x,3)

25--::

  1c cross RH | Circle6 L (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (3666, '2012-12-18 12:40:04.575957+00', '2021-03-26 23:21:36.251001+00', 14607, 1, NULL, 'ace', '1–::

  1c set | cross RH, cast off 2 (2c up) and dance up to face 1cnr

9–::

  1cnrs Pass and Turn, pass Rsh ; 2cnrs Pass and Turn, pass Rsh to face own side for

17–::

  DTr, but on [20] 1M dances extra loop turning R on the spot, and on [24] 1c finish in centre facing up, 1M turning extra ¼ turn and 1W extra ¾ turn

25–::

  1c dance between 2c | cast off and join NH ; dance between 3c and cast up (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3481, '2012-01-22 19:30:27.234256+00', '2021-04-03 19:19:47.009969+00', 6919, 1, NULL, 'ace', '{{explanation}}

3c+4c cross over on 2nd chord (1,2,3x,4x)



1–::

  1c+4c, starting inwards, Fig8 on own sideline round the middle couples

9–::

  1c+4c turn RH 1½ and face out ; cast to middle (2c+3c step to end) | 1c+4c ½RHA, finish in promhold with other partner facing 2M & 3M

17–::

  Pairs in promhold Rsh Reel3 on the sidelines, finish in sideline facing out between the »corners«

25–::

  1c+4c give outside hands to corners and turn ½ | cross over inwards to 3pl (2pl) _while_{2} corners cast back to the ends ; turn the new corners once round with the other hand to finish (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (14195, '2021-08-10 06:41:41.953632+00', '2021-08-10 06:45:43.955249+00', 8074, 1, 202, 'ace', '1--::

  1c Fig8 down round 2c (1,2,3)

9--::

  1c cross RH | cast off (2c up) ; cross LH | cast off (3c up) (2,3,1)

17--::

  3c+1c R&L (2,3,1)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (3501, '2012-01-22 19:30:28.059705+00', '2019-03-17 23:26:38.503327+00', 1566, 1, NULL, 'ace', '1–::

  1W+2M & 3W+4M cross RH | cast Rsh round P to face P on diagonal ; 1c+2c & 3c+4c half poussette (2,1,4,3)

9–::

  1c+4c+3c the Knot (2,3,4,1)

17–::

  2c+3c & 4c+1c LHA ; RHA

25–::

  Parallel Rsh Reels4 on the sides, at the end top W and bottom M make loop into the next repeat.', 3);
INSERT INTO 'dancecrib' VALUES (8050, '2013-09-25 08:16:07.370906+00', '2021-07-30 06:11:30.553255+00', 15148, 1, NULL, 'ace', '1–::

  All (3c leading) dance down the middle ; and up (1c leading) (1,2,3)

9–::

  1c turn RH | cast (2c up) ; turn LH to sidelines (2,1,3)

17–::

  1c Fig8 round end couple, start Lsh to 1cnr (1W up, 1M down)

25–::

  All Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (3505, '2012-01-22 19:30:28.245442+00', '2021-04-02 17:37:38.193534+00', 7031, 1, NULL, 'ace', '1–::

  All set | 1c with 2c & 3c with 4c change places with hands, 1c & 4c passing outside ; 1c+4c set | cross, W between M

9–::

  Parallel Rsh reels4 on sides.

17–::

  1c+4c set | Petronella in Tandem ; set | Petronella in tandem to own side.

25–::

  All circle8 & back.  (2,4,1,3).', 2);
INSERT INTO 'dancecrib' VALUES (3500, '2012-01-22 19:30:28.019687+00', '2014-04-30 23:24:14.84371+00', 13730, 1, NULL, 'ace', '1–::
  1c+2c DblFig8, 1c crossing down to start, at end 2c face out
9–::
  1c+2c turn EH 1¼ on side (2c to 1pl) and 1c face down NHJ ; 1c dance down and turn 3c EH, 3c finish in 3pl and 1c facing 1cnr
17–::
  1c+1cnrs ½ diag. Reel4 and pass Rsh ; repeat with 2cnrs, 1c finish on midline Lsh to Lsh facing own side
25–::
  3c+1M & 1W+2c RHA (3x,1x,2x) ; All chase clw ½ round (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3640, '2012-08-20 21:50:38.699761+00', '2014-04-30 23:24:14.910123+00', 13706, 1, NULL, 'ace', '1–::
  All Circle8 and back
9–::
  All turn P RH ; dance BtoB
17–::
  1c down the middle and up
25–::
  1c set twice ; dance down under arches by 2c+3c+4c who step up (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3855, '2013-07-13 15:56:24.351382+00', '2020-12-26 10:42:48.627949+00', 14647, 1, NULL, 'ace', '1–::

  1c dance down to between 3c (2c up) | 1c set passing P Lsh into line across ; 1c+3c ½ Reel4 across, at end 1c stay on opposite side of P

9–::

  1c dance up to between 2c | 1c set passsing Lsh into line across ; 1c+2c ½ Reel4 across, finishing in lines across 2c+1M facing 1W+3c

17–::

  All turn person opposite RH ; 1c petronella to own side _while{2}_ 2c+3c set up/down | All set to P (2x,1,3x)

25–::

  2c+1W & 1M+3c ½ Reels3 across, Lsh to 1cnr ; 1c turn RH 1 ½ to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2150, '2012-01-22 19:29:22.691326+00', '2018-02-12 21:05:42.934597+00', 1891, 1, NULL, 'ace', '1–::

  1c+3c cross RH, cast off (2c+4c up) ; cross LH, cast left looping round 4cnr into BtB in 2pl/4pl facing own side for

9–::

  Double DTr (to 2,1,4,3,5)

17–::

  1c+3c lead down one, cast up one ; turn RH and lead up (2c+4c down) and face down, other couples face up. (1,2,3,4,5)

25–::

  1c facing 2c & 3c facing 4c set and turn BH ½ ; 1c facing 4c & 3c facing 5c set and turn BH ½ (to 2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (10425, '2018-02-12 20:39:29.208223+00', '2018-02-12 21:20:48.617195+00', 12504, 1, NULL, 'ace', '1--::

  1c+4c ½ Fig8 round next cpl ; 1c+2c & 3c+4c turn each other EH on the sides, finishing 1c facing 4c in the middle (1x,2,3x,4)

9--::

  1c+4c set advancing _as_ 2c+3c cast to own end | 1c+4c petronella in tandem ; set | petronella in tandem (2,4x,1,3x)

17--::

   4c+1c S&Link with P, the W pivoting R into ; 2c+4c & 1c+3c RHA (2,4,1x,3x)

25--::

  Reels4 on the sides (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (12137, '2019-09-02 15:15:45.925404+00', '2019-09-21 01:28:01.611892+00', 19597, 2, 160, 'ace', '1-8:: 1s cast to 2pl [4] ; 1W2s and 1M3s RHA. (face 1cor)

9-16:: 1s 1cor half diag. reel4 (pass R) ; 1s 2cor half diag. reel4 (pass R + face)

17-24:: 1s set, gypsy R ; 1s set, gypsy L (face 4th corner).

25-32:: 1s 4cor half LEFT shoulder reel4 (pass L) ; 1s 3cor half Lshoulder reel4 (end on own sides)

33-40::  1M2s and 1W3s dance LHA ; 1s cast to 3pl [4].', 2);
INSERT INTO 'dancecrib' VALUES (11533, '2019-01-21 02:25:01.192464+00', '2019-01-21 02:29:29.016189+00', 13305, 1, 202, 'ace', '1--::

  1c turn BH | open out upwards and cast (2c up) ; 1c Turn Halfway and Cast, facing out _while{4}_ 2c & 3c A&R (2,1x,3)

9--::

  1c loop RSh round 1cnrs, pass P RSh up/down and pivot R to face P on midline _while{4}_ 2c & 3c A&R diagonally touching hands ; 1c set | turn BH ¼ and pivot R to face 1cnrs

17--::

  ½ Reel4 on 1diag, turn P BH and pivot R to face 2cnrs ; ½ Reel4 on 2diag to 2plx (3x,1x,2x)

25--::

  3C S&Link (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3503, '2012-01-22 19:30:28.137539+00', '2020-09-19 21:08:22.033621+00', 13728, 1, NULL, 'ace', '{{explanation}}

C face C Round the Room



1–::

  L-Chain, finish in promhold facing other C

9–::

  Promenade in cclw loop round opposite C and the C behind them

17–::

  Both W set advancing, acknowledge, and cast R to places ; both M repeat

25–::

  Progressive R&L (polite turn only on [32]: pass person opposite RH | pass P LH ; repeat with next C', 3);
INSERT INTO 'dancecrib' VALUES (8075, '2013-10-05 22:36:21.412232+00', '2021-03-01 11:04:14.476055+00', 9158, 1, NULL, 'ace', '{{explanation}}

All couples form big circle facing in, M on L of W.



1–::

  All facing centre A&R ; set | set to P

9–::

  All turn P RH ; repeat LH and finish BtoB with P, M facing clw

17–::

  G-Chain, 2 bars/hand, 4th hand is with new P, M making polite turn

25–::

  All Circle L and R', 3);
INSERT INTO 'dancecrib' VALUES (2472, '2012-01-22 19:29:40.821319+00', '2020-12-08 09:03:01.839608+00', 3102, 1, NULL, 'ace', '1–::

  1c+2c+3c Inveran reels (1c crosses at top and bottom) (1,2,3)

9–::

  1c followed by 2c dance down {4} ; set to P | dance up, 2c to 1pl and 1c in middle facing up NHJ

17–::

  1c followed by 3c dance up, cast off round 2c ; dance down | 1c cast up round 3pl to 2pl _while{2}_ 3c curve to 3pl.

25–::

  2c+3c R&L starting along sidelines _while{8}_ 1c Lsh Fig8 to the right around end couple positions (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3494, '2012-01-22 19:30:27.783152+00', '2020-12-21 16:31:01.4716+00', 9804, 1, NULL, 'ace', '1–::

  1c cross | cast (2c up) ; dance down | cast up round 3c (2,1x,3)

9–::

  Teapots R (2c+1M & 1W+3c) ; 1c turn LH _while{4}_ 2c+3c chase ½ clw

17–::

  Teapots R (3c+1M & 1W+2c) to (3x,1x,2x) ; all cross RH | all set advancing

25–::

  3c+1c+2c Allemande



{{explanation}}

crib needs to be checked', 2);
INSERT INTO 'dancecrib' VALUES (3507, '2012-01-22 19:30:28.325121+00', '2020-12-25 15:20:18.168288+00', 12694, 1, NULL, 'ace', '1–::

  1W+2M change places RH and face P | Parallel Rsh Reels3{6} on the sides

9–::

  1M+2W change places LH, 2c face 1c | Parallel Lsh Reels3{6} on the sides (2x,1x,3)

17–::

  2c+1c set | Turn P BH ½ and face down NHJ ; dance (1c leading) between 3c, divide and cast up, 1c curve in and face down

25–::

  All W LHA _while{4}_ all M RHA, finish (2,1,3) with 1c in the centre facing down ; 1c+3c turn EH 1½ (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (14333, '2021-09-24 09:21:15.564479+00', '2021-09-24 09:25:13.36255+00', 20495, 1, 1645, 'ace', '*3c & 4c start on opposite side (1,2,3x,4x)*

1--::

  1c+2c & 3c+4c RHA ; LHA, 1M & 4M end facing out

9--::

  1M & 4M, followed by P, cast off | &frac12; Fig8 out nearest end (2c & 3c step out on [3-4]) | 1M & 4M cross over to original side facing down/up _while_ 1W & 4W end RSh to each other, all in line across ready for

17--::

  1c+4c Targe, all end on sides facing clw (2,4,1x,3x)

25--::

  All chase &frac12; way clw ; all turn P RH (3,1,4x,2x)

', 2);
INSERT INTO 'dancecrib' VALUES (3524, '2012-01-22 19:30:29.219081+00', '2021-01-23 21:54:45.059168+00', 13729, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; 2c+1W & 1M+3c RHA, 1c face 1cnr

9–::

  1c+1cnrs diagonal Reel4, on [15-16] 1c turn RH to face M up W down

17–::

  1c dance Rsh round 2cnr into ; 2c+1M & 1W+3c RHA, 1c face 2cnr

25–::

  1c+2cnrs Diagonal Reel4, to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10163, '2017-10-08 10:07:06.299528+00', '2017-10-08 10:07:06.299528+00', 10082, 1, NULL, 'ace', '1--::

  1c set | cast (2c up) ; 1c dance clw round 4cnr to finish BtoB facing end cpl (1cnr+4cnr)

9--::

  2c+1W & 1M+3c Circle3 L{3} and open out, 1c leading on own side and join in Circle6 for an instant ; 1M+2c & 3c+1W continue with Circle3 L to (2,1x,3)

17--::

  1c set | turn RH ¾ ; 1c dance Rsh round 2cnr to finish BtoB facing other end cpl (3cnr+2cnr)

25--::

  Repeat [9-16] from exchanged places (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3857, '2013-07-13 15:56:24.502596+00', '2014-04-30 23:24:15.154057+00', 14645, 1, NULL, 'ace', '1–::
  1c dance BtoB ; cross RH | cast (2c up)
9–::
  2c+1c R&L, 1c finish facing 1cnr
17–::
  1c SetH&G , at end petronella to (2,1,3)
25–::
  All chase clw {6} | all set', 3);
INSERT INTO 'dancecrib' VALUES (3523, '2012-01-22 19:30:29.180176+00', '2021-03-31 09:01:10.90707+00', 7093, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; ½Fig8 L (M dn, W up) to face 1cnr

9–::

  1c turn 1cnr RH | turn P LH ; ½ Reel4 with 2cnrs and face 4cnr pos

17–::

  1c turn 4cnr (2cnr person) RH | turn P LH ; ½ Reel4 with 1cnrs , finish in lines across, 1W+3c facing 1M+2c

25–::

  All set | cnrs cross up/dn RH as 1c turns ¾ RH (to 2x,1x,3x) ; All set and cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3517, '2012-01-22 19:30:28.809004+00', '2014-04-30 23:24:15.246894+00', 7061, 1, NULL, 'ace', '1–::
  1M+2W turn RH to places ; 1W+2M turn RH 1½ to face P for
9–::
  1c+2c Rsh diagonal Reel4, all ending in own places
17–::
  1c+2c Set&Rotate (set diagonally | cast 1 place clw ; change RH with P | chase 1 place clw)
25–::
  2c+1c R&L

{{explanation}}
note the difference: the standard Set&Rotate starts with set to P', 3);
INSERT INTO 'dancecrib' VALUES (3546, '2012-01-22 19:30:30.292618+00', '2014-04-30 23:24:15.755242+00', 7179, 1, NULL, 'ace', '1–::
  1c+2c A&R ; turn RH
9–::
  Promenade
17–::
  1c turn RH moving down | cast up ; turn LH (2c up) (to 2,1)
25–::
  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (3516, '2012-01-22 19:30:28.767668+00', '2019-03-08 19:13:41.693011+00', 7060, 1, NULL, 'ace', '1–::

  1c cross RH and face out | turn 2c ½ EH and face in ; turn 3c ½ EH | turn 4c ½ EH (2,3,4,1x)

9–::

  All set | cross RH ; all set | cross RH (1c face out)

17–::

  1c cast to top, cross RH, cast off to bottom (2,3,4,1)

25–::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (3436, '2012-01-22 19:30:25.441498+00', '2014-04-30 23:24:13.643029+00', 6734, 1, NULL, 'ace', '1–::
  1c set, cast off 2 places, dance up to the top, 2c step in on 7-8
9–::
  1c+2c Poussette, 1c set adv on [15-16] to face 1cnrs
17–::
  1c ½Reel4 with 1cnrs, pass Lsh ; 1c ½Reel4 with 2cnrs, finishing 2plx, (to 3x,1x,2x)
25–::
  3M+1M+2M Petronella Turn onto centre line | set _while_{4} 3W+1W+2W set | Petronella Turn to face partners ; 3c+1c+2c turn ¾ RH into
33–::
  3c+1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2697, '2012-01-22 19:29:53.515579+00', '2020-09-19 09:56:55.514026+00', 8965, 1, NULL, 'ace', '1–::

  1c cross RH | cast off one (2c up) ; 1c dance Lsh round 1cnr to 2plx facing 2cnr

9–::

  ½Reels3 on the sides, Rsh to 2cnr (»loop« where needed) ; ½Reels3 across, Lsh to 3cnr

17–::

  ½Reels3 on the sides, Rsh to 4cnr ; ½Reels3 across, Lsh to 1cnr (2,1x,3)

25–::

  1c ½ RH turn staying in the middle M facing up, W down | dance out the ends ; cast R to opposite side | cross RH _while{8}_ 2c & 3c dance out the ends NHJ | cast to meet on the sidelines NHJ ; join NH to P and dance out the ends as before | cast to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10299, '2017-12-10 15:41:29.256445+00', '2017-12-12 12:15:52.468157+00', 11042, 1, 202, 'ace', '1--::

  1c set | 1W followed by 1M casts off 2, 1W crosses below 3c and casts up M side while 1M dances up the middle, both to P’s place (2c up on [7-8]) (2,1x,3)

9--::

  Parallel Reels3, 1c Lsh to 2c

17--::

  1c set | lead up, cross at top, cast off to face 1cnrs

25--::

  Corners Pass & Turn to 2plx (2,1x,3)

33--::

  1c set | turn LH ; cast L round 2cnrs facing 3cnrs

41--::

  Reels3 across, 1c Rsh to 3cnrs to start (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (3509, '2012-01-22 19:30:28.403373+00', '2021-01-24 12:12:09.902549+00', 11479, 1, NULL, 'ace', '1–::

  1c (starts inwards) +2c ½ turn EH on sidelines | 1c (outwards) +3c repeat ; 1c dance up to top and cast off (3c down) (2,1,3)

9–::

  1c set adv. to join LH and RH to 1cnr | BiL ; turn 1cnr ¾ RH into | set in lines across

17–::

  1c set adv. to join LH and RH to 2cnr | BiL ; turn 2cnr ¾ RH into | all set (2,1x,3)

25–::

  Reels3{6} on the sides, Rsh to 2cnr | 1c cross RH.', 3);
INSERT INTO 'dancecrib' VALUES (3514, '2012-01-22 19:30:28.684192+00', '2021-01-29 22:39:09.305354+00', 11112, 1, NULL, 'ace', '1–::

  1c+2c turn RH | 1c cast as 2c lead up ; 1c+3c repeat (3c face out & up) (2,3,1)

9–::

  Mirror Reels3{6} on sides | 3c cast off as 1c dance up to face 1cnr

17–::

  Set H&G, finish BtoB 1M/1W facing up/dn

25–::

  2c+1M & 1W+3c Rsh Reels3{6} across | all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13828, '2021-03-20 20:12:13.257255+00', '2021-06-03 06:48:25.016797+00', 7461, 1, 202, 'ace', '*3c & 4c start on opposite sides*

1--::
  1c & 4c set | turn P RH ½ and face inside the set ; 1c & 4c advance | ½ RHA and retaining RH face outside the set
9--::
  4c & 1c lead through ends, cross and cast inwards facing each other on sides (2c & 3c step out) (to 2,4,1x,3x) ; 4c & 1c set | change places RH (2,1x,4,3x)
17--::
  2c+1c & 4c+3c RHA ; all set | 2c+1c set _while{2}_ 4c & 3c cross RH (2,1x,4x,3)
25--::
  1c+4c+3c ½ Reels3 (to 2,3,4x,1x) ; all turn P RH (2,3,4x,1x)', 4);
INSERT INTO 'dancecrib' VALUES (3521, '2012-01-22 19:30:29.099825+00', '2021-03-27 19:01:54.617933+00', 10000, 1, NULL, 'ace', '1–::

  4c turn RH | cast up ; dance down | cast up (3c down) (1,2,4,3)

9–::

  1c+2c & 4c+3c RHA ; LHA

17–::

  4c repeat [1-8] up round 2c (1,4,2,3)

25–::

  Mirror Reels4 on the sides: 4c and 3c start in and up joining hands

33–::

  4c repeat [1-8] up round 1c (to 4,1,2,3)

41–::

  All circle8 and back

', 2);
INSERT INTO 'dancecrib' VALUES (3519, '2012-01-22 19:30:28.980789+00', '2021-03-31 09:45:38.327771+00', 7071, 1, NULL, 'ace', '1–::

  1M, 1W following, cast behind 2M (2c up) and cross ; 1W, 1M following, cast behind 3M (3c up) and cross (to 2,3,1)

9–::

  1c dance to the top | cast off ; dance between 3c and cast up (3c down) to face 1cnr

17–::

  1c set to and turn corners, to sideline facing in (2,1x,3)

25–::

  1M dancing in below 1W leads 1W out the W side, 1c divide, cast and meet in the middle ; lead out the M side, 1c divide and cast to (2,1,3).', 2);
INSERT INTO 'dancecrib' VALUES (3512, '2012-01-22 19:30:28.586475+00', '2021-04-02 17:24:03.794537+00', 7049, 1, NULL, 'ace', '1–::

  1c+2c half DblFig8 (2c cast and 1c cross down to start) ; 1c+2c+3c ½Reels3 on sides (2c start out and up) (to 3,2x,1x)

9–::

  2c+1c half DblFig8 (2c out and 1c cross up to start) ; 3c+2c+1c ½Reels3 on sides (2c start out and down) (to 1,2,3)

17–::

  1c dance down to 2pl own side BtoB (2c up) | all set as in DTr ; 1c turn 3cnr RH into facing lines across (1M at top, 1W below) | all set

25–::

  1c pass Rsh to stand BtoB, 1M+3c & 1W+2c holding hands | all set ; turn 4cnr RH into sidelines ; all set (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3635, '2012-07-21 11:46:21.422386+00', '2021-04-02 17:26:51.788915+00', 7042, 1, NULL, 'ace', '1–::

  1c cross to 2pl (2c up) | 1c set to 3c ; 1c set | 1c set to 2c

9–::

  1c (cross up) +2c ½ double Fig8 ; 1c (cross) +3c ½ Double Fig8 (2x,1x,3x)

17–::

  2c+1c+3c Petronella Turn | set, finish near opp. sideline ; all chase ½ clw

25–::

  3c+1c+2c the Knot', 2);
INSERT INTO 'dancecrib' VALUES (3529, '2012-01-22 19:30:29.439133+00', '2014-04-30 23:24:15.478085+00', 7109, 1, NULL, 'ace', '1–::
  1c+2c+3c set and cross RH ; repeat
9–::
  1c lead down the middle ; and up, staying in the middle
17–::
  1c long cast to 2pl (2c up) ; 1c+3c circle4 L
25–::
  2c+1c R&L.', 3);
INSERT INTO 'dancecrib' VALUES (3458, '2012-01-22 19:30:26.346502+00', '2015-01-11 23:36:55.063896+00', 6834, 1, NULL, 'ace', '1–::

  1c Fig8 down round 2c

9–::

  2c Fig8 up round 1c

17–::

  1c cross RH | cast off (2c up) ; cross RH | All set (2,1,3)

25–::

  All Circle6 and back.', 3);
INSERT INTO 'dancecrib' VALUES (11534, '2019-01-21 02:58:05.914016+00', '2021-01-03 12:47:23.857178+00', 13310, 1, 202, 'ace', '1--::

  1W+2M & 3W+4M Turn Halfway (RH) and Cast ; 1c+2c & 3c+4c RHA

9--::

  1M+2W & 3M+4W Turn Halfway (LH) and Cast ; 2c+1c & 4c+3c LHA (2x,1x,4x,3x)

17--::

  2c & 4c ½ Fig8 down ; 1c + 3c ½ Fig8 up (2,1,4,3)

25--::

  1c+4c+3c Allemande (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (14707, '2022-03-17 20:54:15.88556+00', '2022-03-17 20:55:51.146956+00', 13894, 1, 1645, 'ace', '1--::

  1c & 4c turn BH & open out to face down/up | dance towards each other (2c & 3c out) ; Circle4 to L, pull RSh back & face cnrs

9--::

  Intersecting diag RSh Reels4 with &frac12; LHA in centre, 1c & 4c end facing same cnrs

17--::

  1c & 4c set to cnrs | change pl RH ; set | change pl LH & 1c face 4c

25--::

  1c+4c RHA, 1W & 4M face out ; 1W & 4M, followed by P, cast R & end beside P, 1c facing up, 4c down between 2c/3c

33--::

  4c+1c change pl up/down | cast in (2,1x,4x,3) ; 1c+4c &frac12; R&L (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3580, '2012-06-29 08:44:27.078905+00', '2018-02-14 22:06:14.052271+00', 7090, 1, NULL, 'ace', '1–::

  1c set adv | Turn single R ; slip down BHJ below 3c and cast up (2c up) (2,1,3)

9–::

  Teapots R (2c+1W & 1M+3c RHA) ; 1c pass Lsh, cast L round 2cnr and meet in promhold facing 3W (2,1,3)

17–::

  1c ½ Reel3 across with 3c, Rsh to 3W ; 1c split into ½ Reels3 on own side, starting out and up

25–::

  1c in promhold (M on R) ½ Reel3 across with 3c, Rsh to 3W ; 1c split into ½ Reels3 on own side, starting out and down (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3534, '2012-01-22 19:30:29.677758+00', '2014-04-30 23:24:15.555398+00', 7139, 1, NULL, 'ace', '1–::
  1c+4c cross RH and cast in (2c+3c step out), ½ Fig8 outwards, finish all BtoB in the centre facing nearest cnr
9–::
  1c+4c double »Hello&Goodbye«setting, finish opposite the diagonally opposite corner
17–::
  1c+4c turn this cnr RH ; LHA in the middle to sides (to 2,4x,1x,3)
25–::
  1c+3c ½R&L ; 4c+3c ½R&L (to 2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3536, '2012-01-22 19:30:29.749795+00', '2014-04-30 23:24:15.584169+00', 9534, 1, NULL, 'ace', '1–::
  1c turn LH | cast off (2c up) ; turn RH 1½ into
9–::
  Turn 2cnr LH | P RH ; 1cnr LH | P RH to face 2cnr
17–::
  Opposing Rsh Reels3{6} with cnrs | cross LH
25–::
  All Circle6 R and back', 2);
INSERT INTO 'dancecrib' VALUES (3543, '2012-01-22 19:30:30.134027+00', '2017-07-07 13:15:08.981082+00', 7172, 1, NULL, 'ace', '1–::

  1c Rsh Reels3 on opposite side, 1M crossing behind P to begin, at end 1W crosses at top to own place (1,2,3)

9–::

  1c Rsh Reels3 on own side (1,2,3)

17–::

  1c lead down, cross and cast behind 3c ; dance up to top and cast off (2c up) to face 1cnr

25–::

  Set to and turn cnrs (to 2,1x,3)

33–::

  2c+1c+3c A&R ; 1c turn RH 1½ to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10492, '2018-03-06 23:35:57.296116+00', '2018-03-06 23:36:42.114365+00', 15047, 1, 202, 'ace', '1--::

  1c+2c »The Helix« [set passing Rsh | cast R to own place ; turn P RH ½ | ½ RHA] (2,1,3)

9--::

  Reels3 on sidelines, 1c Rsh to 3cnrs, finishing facing 1cnrs

17--::

  1c+1cnrs pass, cnrs turn RH ½, face and cast away to exchanged places as 1c meet and pass Rsh ; repeat with 2cnrs (to 3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3535, '2012-01-22 19:30:29.712951+00', '2020-12-18 20:28:01.236322+00', 7141, 1, NULL, 'ace', '1–::

  1M+2M set and cast down _while{4}_ 2W+3W set and cast up _while{4}_ 1W+3M turn LH to P''s place ; repeat figure

9–::

  Repeat figure (3x,2x,1x) ; All chase cclw to places

17–::

  All C dance Lsh BtoB ; turn P LH, 1c+2c finish for:

25–::

  1c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (3538, '2012-01-22 19:30:29.89947+00', '2017-07-07 14:09:36.99964+00', 7143, 1, NULL, 'ace', '1–::

  1c+2c circle4 L, at end 1c cast off and 2c dance to 1pl ; 1c+3c repeat (to 2,3,1)

9–::

  1c dance up one | cast up one ; dance to 3pl and cast to the top (3c down)

17–::

  1c dance between 2c, behind 3c and lead up to 1cnr | 1c set to 1cnr, to 2cnr.

25–::

  Reels3{6} with corners (Rsh to 2cnr) | 1c cross RH to 2pl



{{explanation}}

Book 19 uses only »lead«.  We follow TACnotes in »lead« (RHJ) and »dance« (NHJ)', 3);
INSERT INTO 'dancecrib' VALUES (3540, '2012-01-22 19:30:30.001648+00', '2014-04-30 23:24:15.645604+00', 7152, 1, NULL, 'ace', '1–::
  1W followed by 1M Lsh Fig8 round 2W and 3W, _while_{8} 4M followed by 4W Lsh Fig8 round 3M and 2M,, finish (1x,2,3,4x) with 1c facing 4c NHJ
9–::
  1c set to 4c _while_{2} 2c/3c dances up/down to join the end Cs in two facing lines of 4 across NHJ | all set advancing ; 2M+1W+3M+4W (on M side) & 2W+1M+3W+4M (on W side) RHA, again into the lines across
17–::
  1c+2c & 3c+4c Reels4 across, 1c & 4c end on midline RHJ with P, LHJ in middle
25–::
  1c+4c BiL, turn P ¾ RH to face up RHJ ; 1c+4c lead up, cast off round 2c to (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3558, '2012-01-22 19:30:31.009562+00', '2017-07-07 13:37:57.909017+00', 7219, 1, NULL, 'ace', '1–::

  1c+2c+3c circle6 and back, finish in middle for

9–::

  1c+2c+3c Promenade, 1c+2c finish in middle for

17–::

  1c+2c Poussette, 1c finishing with ¼L turn and falling back to 1W(1M) between 2c(3c)

25–::

  Set twice in lines across, 1c turning to own sides on 27-28 ; all set twice to P.', 2);
INSERT INTO 'dancecrib' VALUES (2896, '2012-01-22 19:30:02.007369+00', '2020-08-07 08:47:08.972492+00', 4848, 1, 202, 'ace', '1--::

  1c turn RH and retain hands ; lead down into ½ Fig8 (1x,2)

9--::

  2c repeat [1-8] with LH and up (1x,2x)

17--::

  RHA ; LHA (1x,2x)

25--::

  1c & 2c turn P RH ; ½ R&L (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (10493, '2018-03-07 23:28:22.052615+00', '2018-03-08 06:11:49.463293+00', 18249, 2, 1, 'ace', '1-:: 1c lead down below 3c [2c up on 3-4] ; 1c cast up round 3c | 1c petronella 

   [fin in lines across, 1M+3c facing up, 1W+2c facing down]

9-20:: R&L for 3 couples

21–24:: 1c turn BH 1¼ times [to 213]

25–:: 2c+1c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (3541, '2012-01-22 19:30:30.043821+00', '2021-03-21 20:08:15.3666+00', 8120, 1, NULL, 'ace', '1–::

  1c set advancing and face down NHJ | 1c dance down _while_{2} 2c dance to top ; 1c set and pivot L, 1M cast down and 1W up to midline for

9–::

  In facing lines across, all Set | All advance {1}, 2c+3c retire _while_{1} 1c dance R about to sideline (2,1x,3) ; repeat from new positions, finish in lines 1M between 2c facing 1W between 3c

17–::

  Circle6 L ¾ ; 2W+1c+3M (i.e. on 1diagonal) ½ Reel4 (3,1,2)

25–::

  3c+1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3859, '2013-07-13 15:56:24.767144+00', '2021-03-27 18:48:47.150569+00', 14666, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; turn LH 1½ to finish BtoB between 2c

9–::

  1c+2c Reel4 across, at end 1c pass Rsh to face 1cnr

17–::

  Turn CPCP, finish between 3c, BtoB facing opposite side

25–::

  1c+3c Reel4 across, 3c finish in 2pl, 1c meet in centre

33–::

  1c turn LH and cast up on own sides (3c down) ; 1c turn RH. (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3528, '2012-01-22 19:30:29.397242+00', '2021-03-30 21:15:10.182853+00', 7105, 1, NULL, 'ace', '1–::

  1c set | long cast to 2pl (2c up on [5-6]) | set advancing to 1cnrs

9–::

  1c ½Reel4 with 1cnrs, pass Rsh ; 1c ½Reel4 with 2cnrs finishing BtoB in the middle, 1M facing up, 1W down

17–::

  DTr up / down, finish 2pl own side (3x,1,2x)

25–::

  Diagonal R&L (M down, W up) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14060, '2021-06-03 07:35:02.518025+00', '2021-06-03 07:39:43.424753+00', 8460, 1, 202, 'ace', '1--::

  1c lead down {3}, lead up {3} | cast off (2c up) (2,1,3)

9--::

  All set | A&R | set (2,1,3)

17--::

  2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12837, '2020-05-16 22:24:31.15757+00', '2021-06-03 14:22:04.404649+00', 2538, 2, 2784, 'ace', '1-::

  1c+2c set, 1/2 RHA; set, 1c turn LH to face 3W promhold _while_ 2C cross LH

9-::

  1c+3c 1/2 Reel3 to finish facing 2M; 1c+2c 1/2 Reel3 to finish 1c facing W side

17-::

  1W 1/2 Reel3 with M giving Lsh to 2M _while_{4} 1M casts round 3M; 1c face M side 1W 1/2 Reel3 giving LS to 2W _while_{4} 1M casts round 3W, finish facing 1 cnr position

25-::

  1s 1/2Reel4 with 1 cnrs (pass P LS); repeat with 2cnrs 

', 2);
INSERT INTO 'dancecrib' VALUES (3533, '2012-01-22 19:30:29.636428+00', '2018-10-17 06:45:48.452394+00', 7125, 1, NULL, 'ace', '1–::

  1c (2c+3c follow) lead down the middle ; split for 1c+2c+3c to dance up NHJ (1,2,3)

9–::

  1c+2c RHA (2M no twirl) ; 2c+3c LHA (1,2,3)

17–::

  1M+2W dance BtoB ; 1W+2M repeat

25–::

  1c turn 2c RH on sides, All clap  ; 1c (starting inwards) turn 2c EH 1½ on the side', 3);
INSERT INTO 'dancecrib' VALUES (11535, '2019-01-21 12:39:26.879251+00', '2019-01-21 12:44:49.511099+00', 18164, 1, 1645, 'ace', '*3c & 4c start on opposite sides (1,2,3x,4x)*

1-::

  All W advance | all set to P ; W retire as M advance | turn P RH into allemande hold, 1c & 2c facing up, 3c & 4c down

9-::

  Circulating allemandes to (4x,3x,2,1)

17-::

  4c+3c & 2c+1 &frac12; R&L ; 4c+1c &frac12; R&L (3,1,4x,2x)

25-::

  3c+1c & 4c+2c RHA ; LHA  (3,1,4x,2x)

:: *Crib derived from the video*

', 1);
INSERT INTO 'dancecrib' VALUES (10659, '2018-04-19 18:17:44.944734+00', '2018-04-19 21:34:35.615358+00', 13906, 1, 202, 'ace', '*3c & 4c start on opposite sides*
1--::
  1c & 4c set | cast inwards (2c & 3c step out) ; 1c & 4c RHA 1½ ending 1M (4W following) facing 3M and 4M (1W following) facing 2M
9--::
  Rsh Reel3 on sidelines in tandem (no lead change), finishing in one line of 4 across with 1M & 4M BtoB in centre (1M facing M side) and 1W & 4W facing P
17--::
  ½ Reel4 across ; 4c(1c) dance to 2pl(3plx), both W across the set, both M to their R | all set (2,4,1x,3x)
25--::
  All dance BtoB ; 2c+4c & 1c+3c Circle4 L   ', 5);
INSERT INTO 'dancecrib' VALUES (3531, '2012-01-22 19:30:29.554238+00', '2019-02-20 22:09:01.89131+00', 7120, 1, NULL, 'ace', '1–::

  1c set | cast (2c up), cross RH, cast R round 1cnr to face 1cnr

9–::

  ½Reel4 with 1cnrs, pass Lsh ; repeat with 2cnrs

17–::

  Repeat with 3cnr ; repeat with 4cnr, finish in middle ; 1W facing up ; 1M facing down.

25–::

  1W+2c & 1M+3c circle3 L, 1c passing through 2pl into ; 1M+2c & 1W+3c circle3 R', 3);
INSERT INTO 'dancecrib' VALUES (3548, '2012-01-22 19:30:30.440866+00', '2015-07-13 21:35:54.679351+00', 11617, 1, NULL, 'ace', '1–::

  1c set | 1W (1M following) casts behind W side and crosses below 3c, 1W dances up behind M line while 1M dances up the middle, to (1x,2,3), 1M facing out

9–::

  All C Rsh Reels3 on the sides. 1M finishes facing out.

17–::

  1M (1W following) dance behind W side and crosses below 3c, 1M dances up behind M line while 1W dances up the middle, to (1,2,3) | 1c set

25–::

  1c+2c Chain Progression: (turn P RH ¾ | 1M+2W turn LH 1½ _while{4}_ 1W+2M dance clw half round set and face P | turn P RH ¾) to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13952, '2021-04-13 18:43:39.694577+00', '2021-04-13 18:58:26.548492+00', 15913, 1, 202, 'ace', '1--::
  1c+2c The Espagnole. On [7-8] 1c turn LH to face 1cnrs (2,1,3)
9--::
  4 bars of Dance to Corners and Set ; ½ Reels3 across, 3M LSh to 1M, 2W LSh to 1W (Mside cnrs : 3W,1M - Wside cnrs : 1W, 2M - Centre RSh to RSh : 3M facing 1W, 2W facing 1M,)
17--::
  4 bars of Dance to Corners and Set ; ½ Reels3 on sides, 2M RSh to 3M, 3W RSh to 2W (Mside : 2W,3W,1W - Wside : 1M,2M,3M)
25--::
  All turn opposite person RH ½, face that person | cast R to exchanged places ; 1M+2M & 3W+1W turn RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3556, '2012-01-22 19:30:30.876239+00', '2017-06-19 21:10:39.612163+00', 7204, 1, NULL, 'ace', '1–::

  1c+3c Petronella to midline | set to P ; 1c+3c ½Reel4

9–::

  3c+1c Petronella to own side, 3c+2c+1c set ; all turn P RH into

17–::

  3c+2c+1c Allemande (1,2,3)

25–::

  1c cross RH, cast off one (2c up) ; ½ Fig8 round 2c (2,1,3)



{{explanation}}

After their second turn, 1c casts to 4pl on [32] as 4c steps up', 3);
INSERT INTO 'dancecrib' VALUES (2467, '2012-01-22 19:29:40.555954+00', '2019-01-21 23:50:22.718719+00', 9636, 1, NULL, 'ace', '1–::

  1c+2c circle4 L ; 1c long cast to 3pl (2c+3c up)  (2,3,1,4,5)

9–::

  Teapots R ; and L (1c RHA with C on R ; LHA with C on L)

17–::

  1M+5W & 1W+2M Turn RH to places ; 1M+2W & 1W+5M repeat LH

25–::

  1c long cast to 5pl (4c+5c up) ; 5c+1c circle4 R (2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (8745, '2015-03-29 23:34:01.270661+00', '2015-03-29 23:34:01.270661+00', 16183, 1, NULL, 'ace', '1--::

  All set NHJ | 1c+4c set ; 1c long cast to 4pl while{4} 4c lead to top and face out (4,2,3,1)

9--::

  4c+2c & 3c+1c DblFig8, 4c & 3c cast to begin

17--::

  4c+2c & 3c+1c RHA ; LHA (4,2,3,1)

25--::

  4c+2c & 3c+1c Mirror S&Link, the end couples casting and the middles dancing inside ; 4c+1c Circle4 L (2,4,1,3)

33--::

  Circle8 & back (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (14189, '2021-08-07 19:04:46.941455+00', '2021-08-07 19:08:25.567556+00', 20427, 1, 1645, 'ace', '1--::
  1c cross down RH (2c up), retain RH | set LH joined with 2c+3c (as if for LHA on opp side) ; 1c &frac12; turn RH | set again LH joined with 2c+3c
9--::
  LHA on own side ; Snake Pass, passing RSh through 2cnr pos & up/down opp sides, end 1c in centre 1W/1M facing down/up, 3c & 2c on opp sides
17--::
  1c pass LSh into RHA on sides with 3c+2c ; Snake Pass, passing LSh through 3cnr pos & up/down own side, end 1c in centre 1W/1M facing down/up, 2c & 3c on own sides
25--::
  1c set | turn &frac34; RH _while{4}_ 2c+3c &frac12; L&R starting on sides (3x,1x,2x) ; chase &frac12; way clw (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13460, '2020-12-07 20:16:26.461725+00', '2020-12-07 23:23:12.001841+00', 20180, 1, 202, 'ace', '1--::

  1c turn P RH | cast off (2c up) ; turn LH 1 ¼ into lines3 across facing down

9--::

  All dance down | 1c pivot R to face Mside ; ½ Parallel Reels3 across, 1c LSh to 2M/3M. All face up

17--::

  All dance up | 1c pivot R to face Wside ; ½ Parallel Reels3 across, 1c RSh to 2M/3M. 1c face up

25--::

  1c (1W leading) cast R behind Wside and cross to 3plx (3c up on [27-28]) | 1c cross RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3549, '2012-01-22 19:30:30.495876+00', '2015-01-11 23:27:41.039225+00', 7182, 1, NULL, 'ace', '1–::

  1c down the middle {3} and up | cast off (2c up)

9–::

  Reels3 across, 1c Rsh to 2cnr , finish facing 1cnr

17–::

  Turn CPCP

25–::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (12893, '2020-06-23 05:47:02.449635+00', '2020-06-23 05:51:53.277705+00', 15668, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c set | dance diagonally to centre then pivot R ; dance to next place clw and face P on sides | set to P

9--::

  Reels4

17--::

  Repeat same pattern [1-8] (2x,1x,4x,3x)

25--::

  1c+4c 4 bars of Espagnole (to 2x,4x,1x,3x) ; all set | cross RH (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10861, '2018-06-23 10:44:20.207192+00', '2020-10-13 08:45:05.759546+00', 15663, 1, 202, 'ace', '*5 dancers in square, 1+4 on top, 2+3 on bottom, 5 in centre.*

1--::

  1+2+5 RHA ; 5+3+4 LHA

9--::

  5 turn 1 RH ; turn 3 LH

17--::

  5 turn 2 RH ; turn 4 LH

25--::

  5+2+3 RHA ; 5+1+4 LHA

33--::

  5+1 set | change places LH ; 1+2 set | change places LH

41--::

  2+3 set | change places LH ; 3+4 set | change places LH (5+3 on top, 1+2 on bottom, 4 in centre)', 2);
INSERT INTO 'dancecrib' VALUES (3555, '2012-01-22 19:30:30.825589+00', '2021-01-20 10:13:50.847388+00', 11772, 1, NULL, 'ace', '1–::

  1W+2M turn RH ¾ | turn P LH once, into diagonal line facing clw (1M+2W swivel L) ; Line rotates ¼ clw | 1M+2W (outers) dance on one place on sideline _while_{2} 1W+2M (inners) turn ½ RH to (2x,1x)

9–::

  All C turn ½ RH and twirl to (2,1) ; Circle4 L

17–::

  1c set | turn BH and face up ; dance up | cast to 2pl

25–::

  2c+1c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (3545, '2012-01-22 19:30:30.227376+00', '2021-02-25 19:59:00.963687+00', 9351, 1, NULL, 'ace', '{{explanation}}

8C longwise set.



1–::

  1c slip to the bottom ; 1W stays there and 1M+8W slip to the top (all clapping)

9–::

  8M+1W slip to the top ; 1W to own place and 8c slip back to place

17-32::

  1c & 8c strip the willow down (up) the set (other couples finish one place nearer end) to finish in 4+5pl in a circle holding hands in arches (2,3,4,1,8,5,6,7)

33–::

  2c followed by 3c+4c & 7c followed by 6c+5c cast down (up) behind own lines, pass in under the side arches, join NH with P and dance out through the top (bottom) arches to new places

41–::

  1c+8c circle4 and back _while_{8} other cpls make Hullichan swing turns R and L', 2);
INSERT INTO 'dancecrib' VALUES (3478, '2012-01-22 19:30:27.111731+00', '2021-04-03 19:26:32.943304+00', 6913, 1, NULL, 'ace', '1–::

  1c+2c Poussette

9–::

  1W+2M set advancing | turn RH to place ; 1M+2W repeat

17–::

  1c Fig8 round 2c

25–::

  1c+2c Allemande', 2);
INSERT INTO 'dancecrib' VALUES (3557, '2012-01-22 19:30:30.937781+00', '2017-07-07 14:23:52.366523+00', 7210, 1, NULL, 'ace', '1–::

  1c cast | turn BH ; cast off | turn BH

9–::

  1c lead to top, cross and cast off (2c up) ; 2c+1c R&L (one step per hand), 1c finishes facing 1cnrs

17–::

  1c set to and turn corners (to 2,1x,3)

25–::

  All A&R ; All turn BH (1c 1½ times) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11536, '2019-01-22 00:29:44.49492+00', '2019-01-22 00:29:56.731595+00', 19168, 1, 1645, 'ace', '1-::

  1c cross RH | cast off (2c up) ; &frac12; fig8 M down, W up (2,1,3)

9-::

  All dance in{1} to face P on centre line, M(W) facing down(up), set L & &frac14; turn to face out | set R & &frac14; turn so M(W) face up(down), set L to face P on centre line ; all turn P 1&frac14; RH (2,1,3)

17-::

  All chase &frac12; way clw (3x,1x,2x) ; all turn P into allemande hold | set

25-::

  Allemande for 3C (2,1,3)

:: *Crib derived from the video*

', 1);
INSERT INTO 'dancecrib' VALUES (2843, '2012-01-22 19:29:59.736682+00', '2020-12-08 09:43:47.645571+00', 3244, 1, NULL, 'ace', '1–::

  1c+2c set, 1c ½ RH turn to 2pl in middle facing P _while{2}_ 2c cast up ; 1c set and turn LH to hold hands with P and 1cnrs

9–::

  H.Schottische BiL ; ½Reel4 on 1diagonal, at end 1c join LH and RH to 2cnrs for

17–::

  H.Schottische BiL on 2diagonal ; ½Reel4 on 2diagonal

25–::

  1c 1½ LH turn _while{4}_ all corners chase half round clw ; Teapots R (1W+2c & 1M+3c RHA)



{{explanation}}

Highland Schottische BiL: 1c RHJ to cnr and LHJ to P: all set HS {1}, while setting to R drop LH and pass cnr changing to LHJ (take LH under RH) {1} ; on return change hands back (take RH under LH) {2}, at end 1c touch LH briefly before the ½Reel.', 2);
INSERT INTO 'dancecrib' VALUES (3550, '2012-01-22 19:30:30.556732+00', '2019-02-23 00:48:52.23894+00', 7188, 1, NULL, 'ace', '1–::

  1c lead down to bottom ; cast up round 4c, up between 3c, then up behind 2c to places

9–::

  All set, M with Rocking Step and W with Glasgow Highlander step with turn 

17–::

  All cpls set, cross Rsh, M making arches ; repeat back (1,2,3,4) 

25–::

  Reels4 on the sidelines

33–::

  1c+2c ½ RHA | 1c+3c ½ LHA ; 1c+4c ½ RHA | all C cross RH (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (3551, '2012-01-22 19:30:30.608877+00', '2019-02-21 21:26:14.408571+00', 7189, 1, NULL, 'ace', '1–::

  1M+2W+3M+4W Rsh Diagonal Reel4, to places

9–::

  1W+2M+3W+4M Rsh Diagonal Reel4, to places

17–::

  1c+4c turn RH | cast to middle (2c+3c step to ends) ; 1c+4c circle4 L and 4c faces up for

25–::

  1c+4c+3c Rsh ½Reel3 on the sides ; 2c+3c & 4c+1c circle4 L. (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (13951, '2021-04-13 18:36:44.260322+00', '2021-04-13 18:51:43.953422+00', 16929, 1, 202, 'ace', '1--::

  1c+2c The Espagnole. On [7-8] 1c turn LH to face 1cnrs (2,1,3)

9--::

  4 bars of Dance to Corners and Set ; ½ Reels3 across, 3M LSh to 1M, 2W LSh to 1W (Mside cnrs : 3W,1M - Wside cnrs : 1W, 2M - Centre LSh to LSh : 3M facing 1W, 2W facing 1M,)

17--::

  4 bars of Dance to Corners and Set ; ½ Reels3 on sides, 2M RSh to 3M, 3W RSh to 2W (Mside : 2W,3W,1W - Wside : 1M,2M,3M)

25--::

  All turn opposite person RH ½, face that person | cast R to exchanged places ; 1M+2M & 3W+1W turn RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3559, '2012-01-22 19:30:31.105499+00', '2014-11-11 10:43:34.510036+00', 12412, 1, NULL, 'ace', '{{explanation}}

Circle of couples, men inside, women outside



1–::

  Rsh gypsy P ; Turn P''s neighbor on L LH

9–::

  Lsh gypsy P ; Turn P''s neighbor on R RH

17–::

  BHJ with P shashay cclw {2} | keep holding leading hands and turn W under, to L of M, forming one circle NHJ all facing out ; All balance out | balance in, all M take W on R in ballroom hold

25–::

  Waltz around circle clw with new P', 2);
INSERT INTO 'dancecrib' VALUES (3563, '2012-01-22 19:30:31.296723+00', '2016-02-27 09:43:11.022552+00', 7234, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c ¾ DblFig 8 (1c & 3c cast), 1c & 3c Turn LH to 1cnrs.

9–::

  2c+1W & 3M+5c Reels3 across _while_{8} 1M+4c+3W Reel4 across (all Rsh to 1cnrs) into

17–::

  1c+3c Turn CPCP (to 2,1,4,3,5) into

25–::

  1c+4c & 3c+5c Allemande (2,4,1,5,3)', 5);
INSERT INTO 'dancecrib' VALUES (13806, '2021-03-11 08:58:58.234015+00', '2021-03-11 09:06:22.205441+00', 16654, 1, 202, 'ace', '1--::

  1c & 4c turn P RH | cast inwards (2c & 3c step out) ; ½ Fig8 round nearest ends(2,1x,4x,3)

9--::

  1c+4c RHA then join LH with nearest cnrs ; all set twice pivoting ¼ L on [14] & [16] to face opposite direction

17--::

  1c+4c LHA and face cnrs[pos] _while{4}_ cnrs chase clw ½ to exchanged places, all on sides (to 3x,1x,4x,2x) ; ½ Reels4 on sides, 1c & 4c passing RSh on [24]. 4c & 1c on sides face cnrs (2x,4x,1x,3x)

25--::

  All set twice, pivoting to face in on [28] ; all Turn Halfway and Cast (2,4,1,3)

33--::

  Circle8 and back (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3572, '2012-01-22 19:30:31.710735+00', '2017-05-01 20:34:30.287581+00', 13590, 1, NULL, 'ace', '1–::

  1c cross down RH (2c up) and cast R to between end cpl facing 4cnr ; ½ Lsh Reels3 across, 1c face 1cnr (pos)

9–::

  ½ Reel4 on 1diag, 1c pass Rsh and face 2cnr pos. ; ½ Reel4 on 2diag, 1c finish BtoB in middle facing opposite side (3, 1x_mid, 2)

17–::

  DTr, 1c finish Rsh to Rsh facing opposite side

25–::

  3c+1M & 1W+2c LHA finish as started ; 1M leading 3c & 1W leading 2c dance to 1cnr {1}, 4cnr {2}, 2pl own side {1}, to finish (2,1,3).  This is like the »Snake Pass«, but with sharp angles, forming the letter »Z« for Zoologist (from a note by the deviser).', 3);
INSERT INTO 'dancecrib' VALUES (2545, '2012-01-22 19:29:47.088458+00', '2021-05-22 01:18:27.216583+00', 3391, 1, NULL, 'ace', '{{explanation}}

3c+4c change sides on 2nd chord to (1,2,3x,4x). Top/bottom symmetrical dance



1–::

  2c+3c set, dance out through end couples and cast back to places | turn P ¾ BH (the M are now BtoB)

9–::

  2c+3c H.Schottische Poussette | Turn P BH 1¼ to finish 3c facing 2c NHJ (1,3,2x,4x)

17–::

  2c+3c set H.Schottische ; 3c+2c circle4 L, to sidelines (1,3,2x,4x)

25–::

  1c+3c (start down) & 2c+4c (start up) each dance the knot (3,1,4x,2x)', 3);
INSERT INTO 'dancecrib' VALUES (2343, '2012-01-22 19:29:32.302634+00', '2021-06-03 14:58:32.196023+00', 2525, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c set, ½ RH turn and open to 2c+4c on M side and 1c+3c on W side, M below P, facing across the set (as in a Tourbillon) ; all S&Link (M now above P)

9–::

  2c & 3c cross, pass person opposite Rsh and cast R to exchanged places ; 1c+3c & 2c+4c RHA

17–::

  All C dance BtoB with P ; ½Reels4 on sidelines (to 2c+1c on W side, 4c+3c on M side, M below P)

25–::

  2c+4c & 1c+3c circle4 L 1¼ ending on diagonal for ; ½Poussette (to 2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11786, '2019-04-13 16:14:15.178868+00', '2019-04-13 16:17:34.799174+00', 19273, 2, NULL, 'ace', '*couple face couple RR, 1st couples face clockwise* 

1-8::

  1s and 2s circle and back

9-16::

  1s dance half figure of eight through 2s. On the diagonal, 1s and 2s advance and retire (optional hand clap with opposite!).

17-24::

  2s dance half figure of eight through 1s. On the diagonal, 1s and 2s advance and retire.

25-32::

  With nearer hands joined with partner, set to opposites. Turn about (towards partner) to face couple who were behind and set to them. With new opposites, dance half rights and lefts (men finish with a polite turn).



  

', 5);
INSERT INTO 'dancecrib' VALUES (3565, '2012-01-22 19:30:31.381528+00', '2017-07-07 12:37:21.497827+00', 7242, 1, NULL, 'ace', '1–::

  1c+2c set twice ; 1M+2W & 1W+2M turn BH to places (1M crosses as 1W crosses down, make the turns on that side, and 1c returns to 1pl), 1M faces out (1,2,3)

9–::

  1c dances down Lsh to own sideline | cast L round end and dance up Lsh to sideline ; 1c cross RH and cast off to face 1cnr (2c up)

17–::

  Turn CPCP, finish facing 1cnr

25–::

  Reels3{6} with corners, Lsh to 1cnr | cross to 2pl. (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2569, '2012-01-22 19:29:48.021978+00', '2020-12-08 09:51:33.156891+00', 3486, 1, NULL, 'ace', '1–::

  1c long cast (2c up) ; All Turn RH into

9–::

  3c Allemande (3,1,2)

17–::

  All set | cross RH ; chase clw ½ round (2,1,3)

25–::

  Half diag. R&L to the R, _while{4}_ the »free dancers« (2W+3M) chase ½ clw to exchanged places (3x,1x,2x) ; Half diag. R&L to the L, _while{4}_ the »free dancers« (3W+2M) chase ½ cclw to exchanged places (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9501, '2016-11-18 09:10:43.451207+00', '2018-03-07 22:44:11.851055+00', 15047, 2, 274, 'ace', '1-2:: 1c & 2c set advancing passing partners by Rsh
3-4:: 1c & 2c cast round partner towards their own place
5-6:: 1c & 2c half turn partner by RH
7-8:: half RA to change places (release hands slightly early on bar 8 to get into position for)
9-16:: Reels3 on own sides (1M Rsh to 2M and 1W Rsh to 3W to start).  Finish 1c facing 1st corner
17-20:: 1c ''corner pass with twirl'' with 1st corner (1c dance corner pass while 1 corners half turn right and twirl to change places)
21-24:: 1c ''corner pass with twirl'' with 2nd corner (finish 3x 1 2x)
25-32:: Diagonal RL (start: 1M with 2M, 1L with 3L) (finish 2 1 3)', 4);
INSERT INTO 'dancecrib' VALUES (3579, '2012-06-07 23:36:57.223209+00', '2019-01-22 13:18:18.46669+00', 9187, 1, NULL, 'ace', '1–::

  G-Chain (1c cross to start)

9–::

  1c dance down middle NHJ | Set to P ; Turn BH ½ and face top NHJ | dance up to stand BtoB between 2c (in 2pl) facing opposite side

17–::

  The Spurtle: 1c+2c ½ Reel4 across, 2c to 1plx and 1c quick RH turn to face 3c the same way ; 1c+3c repeat, 1c finishing in 3plx (2x,3x,1x)

25–::

  All set | petronella to midline ; set to P | petronella to (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11255, '2018-10-06 17:55:22.634056+00', '2018-10-07 14:43:52.290896+00', 7033, 1, NULL, 'ace', '1--::

  All set adv | All turn P RH, 1c+3c to places and 2c face P in centre ; 2c set and turn LH to face out own side

9--::

  Reels3 on the sides, Lsh to 4cnr (1,2,3)

17--::

  6 Hand across, L ; repeat R (1,2,3)

25--::

  1c+2c ½ R&L _while{4}_ 3c turn LH 1½ ; 2c turn RH 1½ _while{4}_ 1c+3c ½ R&L (2,3,1)

33-96::

  Repeat [1-32] twice.  At end 1c face 2c and 3c face P (1,2,3)

97-112::

   All clap, Gr-Chain (2 bars/hand) ; All turn P RH, 1c+3c to places as 2c turn 1½ and join LH with 1cnr

113--::

  BiL with 1cnrs | 2c turn RH and join LH with 2cnr ; BiL | 2c turn RH to own side in the centre, facing P 

121--::

  All set, 1c+3c advancing | All set RHJ passing P (W pass under the joined arms) ; All set | All set RHJ passing P (w pass under joined arms) and hold RHJ for bow/curtsey



  

', 4);
INSERT INTO 'dancecrib' VALUES (11257, '2018-10-07 21:59:19.751908+00', '2018-10-08 17:04:35.400783+00', 1656, 1, NULL, 'ace', '1--::

  [The Buckie:] 1c+2c set | cross RH ; chase clw ½ (2,1,3)

9--::

  [RH interlinked Chain:]  2W+1M turn RH ¾ and cross to own side _while{4}_ 1W+2M cross to opp. side and turn RH ¾ (all back to places bar 9) ; 2c+1c RHA (2,1,3)

17--::

  [LH interlinked Chain:] 1W+3M turn LH ¾ and chase 1 place cclw _while{4}_ 1M+3W cast 1 place cclw and turn LH ¾ (all back to places bar 17) ; 1c+3c LHA (2,1,3)

25--::

  Reels3{6} on the sides, 2c Rsh to 1c | 1c&3c change places LH (2,3,1)

', 4);
INSERT INTO 'dancecrib' VALUES (11787, '2019-04-13 16:41:02.078749+00', '2019-04-13 16:41:02.078749+00', 10268, 2, NULL, 'ace', '1-8::

 	1W cross to pass 1M LS; 1M set in place turning over LS. 1W followed by 1M cast one place; 2C step up on bars 3 & 4. 1C & 3C dance RH across once round.

9-16::

 	2C & 1C allemande.

17-24::

 	1M cross to pass 1W RS; 1W set in place turning over RS. 1M followed by 1W cast one place; 2C step up on bars 19-20. 1C & 3C dance LH across once round.

25-32::

 	RS reels of three on the sides, 1M giving RS to 2M and 1W giving RS to 2W. 1C end in 2nd place on own sides.', 5);
INSERT INTO 'dancecrib' VALUES (10860, '2018-06-23 08:43:41.979303+00', '2018-06-24 07:40:33.49594+00', 15662, 1, 202, 'ace', '1--::
  1c+2c+3c »Bottom open U-Chain« [as Gr-Chain, 2 steps/hand, 1c+2c change places RH to start _while{2}_ 3c set, 1c & 2c also set at bottom instead of crossing] (3x,1,2x)
9--::
  ½ diag R&L, 1c going R | ½ diag R&L, 1c going L (2,1,3)
17--::
  1c turn RH to 2pl and face out _while{4}_ 2c & 3c set | cross RH (to 2x,1,3x) ; ½ Reels3, 1c Rsh to 3cnrs[pos] (3x,1,2x)
25--::
  1c turn LH to 2pl and face out _while{4}_ 2c & 3c set | cross RH (to 3,1,2) ; ½ Reels3, 1c Lsh to 4cnrs[pos] (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (9996, '2017-07-09 21:54:37.627506+00', '2017-12-13 22:49:06.507607+00', 17887, 2, NULL, 'ace', '1- 8::

  1s with 2s & 3s dance reflection reels of 3 on sides, with 1s crossing down to face out on bars 7-8 as 2s dance up 

9-14::

  1s give RSh to 1st corner for 2s+1L, 3s+1M dance LSh reel of 3 across (6 bars)

15-16::

  1s turn ¾ LH to 2nd place own sides

17-24::

  2s+1s+3s set, 1s dance down between 3s, cast up & in, dance up between 2s & cast into 1st place as 2s step down

25-32::

  1s+2s dance the Z-progression:

::

  1M, with right hand, crosses 1L in front of him to 2M’s place as 2M steps up & 1M dances to 1L’s place

::

  1s+2s set

::

  1M, with left hand, crosses 1L in front of him to 2L’s place as 2L steps up & 1M dances to 2M’s place

::

  2s+1s set



Note:  Bars 9-16: 1s are dancing out RSh around their 1st corner positions whilst 2s (& 3s similarly) pass their partner LSh across the set (2 bars - in version 1 this was a 1/2 turn left hand), which then flows into a 1/2 reel across (4 bars), by which time 2s & 3s are back home and 1s can dance into the centre to turn LH to 2nd place own sides.



', 5);
INSERT INTO 'dancecrib' VALUES (10165, '2017-10-08 20:03:29.464443+00', '2021-07-16 00:04:32.138761+00', 17992, 1, 202, 'ace', '1--::

  1c lead{3} down, lead{3} up | cast off (2c up) (2,1,3)

9--::

  2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA (2,1,3)

17--::

  All set | All cross RH ; All chase clw ½ (3,1,2)

25--::

  Circle6 and back (3,1,2)', 5);
INSERT INTO 'dancecrib' VALUES (14196, '2021-08-10 12:01:04.775729+00', '2021-08-10 12:07:12.530082+00', 11081, 1, 202, 'ace', '1--::
  All set | turn P BH opening into ; 1c+2c & 3c+4c Circle4 L into two parallel 1diag lines4, 1W (on Mside),1M,2W,2M (on Wside), 3W (on Mside),3M,4W,4M (on Wside)
9--::
  1c+2c & 3c+4c ½ Poussette (to 2,1,4,3) ; 1c+4c RHA (2,1,4,3)
17--::
  Reels4 (2,1,4,3)
25--::
  1c+4c The Tournée (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10312, '2017-12-14 10:46:46.734095+00', '2018-02-16 05:32:22.257879+00', 13356, 1, 202, 'ace', '1--::
  1c set | cast (2c up) ; set | turn LH ¾ ending in centre facing M up, W down _while{4}_ 2c & 3c turn P LH ending facing out
9--::
  Reels3 on sidelines, 1c Lsh to 3cnrs to start, 1c ending in centre BtoB facing own sides, 2c & 3c ending with loops
17--::
  6 bars of DTr | 1c in centre dance with 2 PdB Rsh ¾ round P ending BtoB facing M up, W down _while{2}_ 2c & 3c set
25--::
  1M+2c & 1W+3c Circle3 L ; open into Circle6 L (to 2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10313, '2017-12-15 02:40:51.476037+00', '2017-12-15 02:45:38.487414+00', 17102, 1, 202, 'ace', '1--::
  1M+2W & 3M+4W turn RH ½ face and cast away to exchanged places ; Circle8 L ½ (to 3M,3W,1M,1W on M side and 4M,4W,2M,2W on W side)
9--::
  4M+3W & 2M+1W turn RH ½ face and cast away to exchanged places ; Circle8 L ½ (2,1,4,3)
17--::
  Parallel Reels4
25--::
  1c+4c S&Link ; 2c+4c+1c+3c cross RH | set (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9869, '2017-05-20 01:14:33.785186+00', '2017-12-15 11:15:40.270278+00', 16471, 1, 202, 'ace', '1--::
  1M+2W turn RH ½, face each other | cast R to exchanged places ; chase clw ½ _while{8}_ 1W+2M chase cclw ½ ; turn RH ½, face each other | cast R to exchanged places (1,2,3)
9--::
  1c+3c DblFig8 (1c cross down)
17--::
  1c lead down between 3c | cross to 2plx (2c up) ; lead up | cross to 2pl (2,1,3)
25--::
  2c+1c Slip Knot', 2);
INSERT INTO 'dancecrib' VALUES (3566, '2012-01-22 19:30:31.424778+00', '2017-07-07 12:35:51.840629+00', 7245, 1, NULL, 'ace', '1–::

  1c set, cast off (2c up) ; 2c set, cast off (1c up) (1,2,3)

9–::

  1c+2c ½ RHA, set ; ½ LHA, 1c cast off to face 1cnr (2c dance to 1pl)

17–::

  1c set to and turn corners

25–::

  2c+1c+3c Reels3{6} on the sides, 1c giving Lsh to 1cnrs ; 1c cross to 2pl.', 3);
INSERT INTO 'dancecrib' VALUES (10491, '2018-03-06 15:14:20.2747+00', '2018-03-07 18:52:26.196917+00', 16515, 2, 2269, 'ace', '1--::
  1s+2s petronella into centre, set advancing, finishing back to back with partners, 1L & 2nd man turn RH halfway to finish facing each other, then petronella turn to finish 1L in 2nd place own sides, _while_ 2nd man finishes in first place own side, meanwhile 1M and 2L dance round clockwise to finish in new positions opp partners 2143
 9--::
  1s giving RH cross down between 3s, cast up, meet, cross up between 2s and cast off to finish side by side in centre facing opp sides
17--::
  1L with 2s, 1M with 3s dance RH across, pull right shoulder to face and turn with both hands 1 3/4 to finish 2nd place own sides
25--::
  2s, 1s & 3s dance ''corner pass & turn'' 1s start passing by right shoulder from side lines dance round 1st corner, while 1st corners turn two hands and dance back to places, 1s pass right shoulder round 2nd corners who repeat.  1s pass each other right shoulder to 2nd places.  Repeat from 2nd place
', 0);
INSERT INTO 'dancecrib' VALUES (10863, '2018-06-24 07:56:08.510755+00', '2021-05-16 09:41:51.427451+00', 15676, 1, 202, 'ace', '1--::

  1c & 2c set advancing | turn BH ; dance down and cast up round 3c (2,1,3)

9--::

  1c dance up and cast to 2pl ; turn RH to 2pl facing out (2,1,3)

17--::

  Reels3 on sidelines, 1c start Rsh to 3cnrs. On [23-24], 1c cross Lsh on 2diag to 2plx (2,1x,3)

25--::

  Reels3 on sidelines, 1c start Lsh to 2cnrs. On [31-32], 1c cross Rsh on 1diag to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8408, '2014-09-26 13:41:56.838685+00', '2015-03-30 23:37:26.050464+00', 15285, 1, NULL, 'ace', '1--::

  1c ½ Fig8 around 2c ; 1c ½ Fig8 around 3c (2c up on [7-8]) (2,1,3)

9--::

  1c turn P RH ¾ | turn 1cnr LH ; turn P RH ¾ | turn 2cnr LH into lines across (1M above, 1W below)

17--::

  All A&R up/dn ; 1c change place up/dn RH and cast R to (2,1,3)

25--::

  All A&R ; All turn P RH

', 3);
INSERT INTO 'dancecrib' VALUES (10662, '2018-04-20 20:25:50.89809+00', '2018-04-23 07:22:19.939413+00', 13908, 1, 202, 'ace', '1--::
  1M+3W & 1W+3M Fig8 round 2c/4c
9--::
  1c+3c in promhold dance Rsh round each other in centre and cast Lsh, 1c(3c) round 4c(2c) to opposite sides (3,2,1,4)
17--::
  2c+4c repeat [1-8]
25--::
  2c+4c repeat [9-16] (3,4,1,2)
33--::
  Circle8 and back, facing P at end
41--::
  Interlocking Reels4 on the circle: starting Lsh to P, on [44], turn about and complete the reel dancing back to places. On [47-48], turn P LH ¾, finishing all W in centre facing clw, all M facing cclw
49--::
  All W RHA ½ _while{2}_ all M chase cclw ¼ | all W turn nearest M LH ½, finishing all M in centre facing clw, all W facing cclw ; all M RHA ½ _while{2}_ all W chase cclw ¼ | all M turn P LH ½, finishing all W in centre facing clw, all M facing cclw (2,3,4,1)
57--::
  Repeat [49-56], finishing facing P, all W BtoB in centre (1,2,3,4)
65--::
  All Petronella turn | turn P BH ½ ; repeat [65-68] into promhold facing cclw
73--::
  Promenade (1,2,3,4)', 4);
INSERT INTO 'dancecrib' VALUES (1609, '2012-01-22 19:28:50.745073+00', '2018-10-08 20:07:13.585928+00', 9812, 1, NULL, 'ace', '1–::

  1c+2c+3c petronella to centre line | set ; turn P ¾RH | set. (1x,2x,3x)

9–::

  1c+2c set | ½ RHA ; 1c+3c set | ½ RHA (2,3,1x)

17–::

  1c cast up (3c down), dance to top NHJ and cast off | 1c set pulling Rsh back to face out. (2,1x,3)

25–::

  1c cast R, cross RH up/down ; cast to L to 2pl _while_{6}   2M+3M & 2W+3W change places RH | set up/down ; change back RH. | 2c+1c+3c set



', 3);
INSERT INTO 'dancecrib' VALUES (12892, '2020-06-21 14:32:26.579773+00', '2020-06-22 19:33:04.743894+00', 17665, 1, 202, 'ace', '1--::
  Mirror Reels3 on sides, all crossing from top (1x,2x,3x)
9--::
  All set | cross RH ; 1c cast off below 3c and dance up to 2pl centre and face up _while{4}_ 2c set and dance up to 1pl and face out and down _while{4}_ 3c set twice (2,1,3)
17--::
  1W+3W+2W RHA _while{4}_ 1M+3M+2M LHA ; 1c LHJ cross up between 2c and cast off into 2pl centre and face down (2,1x,3)
25--::
  1W+2M+3M RHA _while{4}_ 1M+2W+3W LHA ; 1c LHJ cross down between 3c and cast up to 2pl (2,1,3)

*Deviser''s note*:  
Second repetition, 1st couple cross below 3rd couple, and curve into 4th place while 4th couple step up to start the mirror reel.', 2);
INSERT INTO 'dancecrib' VALUES (10864, '2018-06-24 11:54:53.874026+00', '2020-10-13 08:55:14.859821+00', 15666, 1, 202, 'ace', '1--::

  Circle8 and back (1,2,3,4)

9--::

  2c+3c RHA ; LHA _while{8}_ 1c+4c chase clw round the set to places (1,2,3,4)

17--::

  1c+2c & 3c+4c turn RH on sidelines ; »Parallel 4C S&Link» [all set | on each sideline, the 2 leftmost dancers dance in, 1M(2M) to 2pl(4pl), 4W(3W) to 3pl(1pl), curving in round Rsh, the two rightmost cast R, 3M(4M) to 1pl(3pl), 1W(2W) to 2pl(4pl)] (3,1,4,2)

25--::

  Parallel Reels4 (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (10289, '2017-12-04 14:19:16.431096+00', '2020-11-10 23:15:47.630992+00', 17887, 1, 202, 'ace', '1--::
  Mirror Reels3{6}, 1c in to start | 1c cross to 2pl facing out _while{2}_ 2c dance up to 1pl (2,1x,3)
9--::
  1W+2c & 1M+3c Reels3{6} across, 1c Rsh to 1cnrs to start | 1c turn P LH ¾ to 2pl (2,1,3)
17--::
  All set | 1c dance down, cast up round 3c, dance up between 2c, cast into 1pl (2c down) (1,2,3)
25--::
 1c+2c »Z-Progression« [: 1c cross RH, 1W to 2Mpl (2M up) and 1M to 1Wpl | 1c+2c set ; 1c cross LH to 2pl (2W up) | 2c+1c set] (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14061, '2021-06-03 07:43:41.993795+00', '2021-06-03 08:03:29.977969+00', 8451, 1, 202, 'ace', '1--::

  1c set | turn P BH | cast off (2c up) (2,1,3)

9--::

  All set | 1c turn P BH ¾ into midline ; 1c cross RH up/down | dance RSh round 2cnrs to 2plx _while{4}_ 2c & 3c A&R up/down (2,1x,3)

17--::

  All set | 1c turn P BH ¾ into midline ; 1c cross RH | dance RSh round 4cnrs to 2pl _while{4}_ 2c & 3c A&R (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2578, '2012-01-22 19:29:48.381409+00', '2020-12-08 22:21:21.045528+00', 3525, 1, NULL, 'ace', '1–::

  1c (2c following) dance in and up to cast off , down between 3c, cast up and dance to the top, then 1c cast _while_ 2c dance up (2,1,3)

9–::

  1c cross RH, dance Rsh round 1cnr, Lsh round 2cnr to finish BtB in the middle facing opp side.

17–::

  Joining hands to cnrs, all set twice, on [20] 1c dance to 2plx, swiveling R to face in ; 1c set | Turn LH ¾ to face 1cnr

25–::

  1c Reel3{6} with cnrs (Lsh to 1cnr) | 1c cross RH to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1979, '2012-01-22 19:29:13.061397+00', '2019-04-15 22:22:07.91074+00', 13272, 1, NULL, 'ace', '1–::

  1W sets adv. to 1M who sets | turns 2M LH to centre facing 2M ; 1W+2M set | 1W turn 1M RH and cross to face out on W side

9–::

  1W followed by 1M cast off and dance across to 2plx and face up (2c up) ; Parallel ½ Rsh Reels3 on the sides, 3W makes loop, 2W slides in

17–::

  3c+1M & 1W+2c RHA, 1c staying on opposite side into ; 1c+2c LHA (to 3,1x,2,4), 1W facing out

25–::

  1W followed by 1M casts behind 2M and up the middle ; 1c turn LH ¾ _while_{6} 3c+2c ¾ R&L | All set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10866, '2018-06-25 06:18:56.454403+00', '2018-06-25 06:32:16.297526+00', 123, 1, 202, 'ace', '1--::

  All set |cross RH ; repeat [1-4] (1,2,3,4)

9--::

  1c+2c & 3c+4c Poussette

17--::

  1c+2c & 3c+4c DblFig8, 1c & 3c start out and down

25--::

  ½ Mirror Reels4, 1c & 3c start out and down ; 1c turn BH and cast to 4pl _while{4}_ 2c+3c+4c continue into ½ Mirror Reels3 (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2479, '2012-01-22 19:29:41.882886+00', '2017-12-17 01:08:53.359475+00', 9864, 1, NULL, 'ace', '1–::

  All circle10 and back   

9–::

  1c+2c & 4c+5c LHA ; RHA, finish c facing c up/dn NHJ _while{8}_ 3c set | cross RH ; set | cross RH and face out and R  

17–::

  1c+2c & 4c+5c “mirror” Rondels (end couples make arch) _while{8}_ 3c chase clw ½ round the set {6} | cross LH to own place and face out and L (2,1,3,5,4)  

25–::

  1c+3c+5c Reels3 on the sides, 3c start out and L, at end 3c face out and 5c face in _while{8}_ 2c+4c set | Turn P RH | set  (2,1,3,5,4)  

33–::

  1c+3c & 5c+4c change places on the side EH | 1c+4c repeat | 1c turn 5c EH 1½ (2,3,4,5,1)  

*(note: this crib follows Jean Shaw’s 2017 description, which differs for [1-8] and [23-40])*



', 3);
INSERT INTO 'dancecrib' VALUES (1612, '2012-01-22 19:28:50.942589+00', '2018-10-08 20:13:33.205594+00', 9286, 1, NULL, 'ace', '1–::

  1c dance down (2c up) ; 1M turns below 1W, who passes under his arm, dance up to 2plx BtoB in the middle

9–::

  Set as in DTr | turn 1cnr RH ; set as in DTr | turn 2cnr LH

17–::

  Reels3 on opp. sides, Rsh to 1cnr, at end 1c dance straight to (2,1,3)

25–::

  All Set one PdB on R foot, circle6 L ; 1 PdB on L foot, circle6 R (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10314, '2017-12-18 16:49:53.142357+00', '2017-12-18 17:25:52.608256+00', 18122, 2, NULL, 'ace', '1-4::

  1C set and cross RH

5-8::

  1M cast off 2 places round 3L into the centre as 1L following partner casts round 2L into the centre,  2C step up on 7-8

9-16::

  1L with 2C and 1M with 3C dance RH across and LH across

17-20::

  1M followed by 1L casts up round 3L into 2nd place own sides

21-24::

  all adv+ret

25-32::

  all 6 hands round and back', 3);
INSERT INTO 'dancecrib' VALUES (10167, '2017-10-08 22:12:27.957705+00', '2019-09-07 17:38:24.008034+00', 17988, 1, 202, 'ace', '1--::
  1c+2c & 3c+4c Circle4 L ; 2c+3c Circle4 L (1,2,3,4)
9--::
  Mirror Reels4 on sides, RSh on Mside, LSh on Wside, all crossing from top (1x,2x,3x,4x)
17--::
  1W+2M & 4W+3M cross RH | 1W+4W change places LH ; 2W+1M & 3W+4M cross RH | 1M+4M change places LH (2,4,1,3)
25--::
  2c+4c & 1c+3c Poussette (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10317, '2017-12-18 23:39:17.981075+00', '2017-12-19 12:53:51.24761+00', 11036, 1, 202, 'ace', '1--::

  2c followed by 1c dance down | turn P BH and face up ; 1c followed by 2c dance up | turn P BH to finish NHJ 1c facing 2c

9--::

  1c+2c Rondel (2,1,3)

17--::

  1c lead down crossing over between 3c, cast up to 2pl ; lead up crossing over between 2c, cast off to 2pl

25--::

  2c+1c+3c set | turn P BH remaining in middle ; 1M+2c & 1W+3c Circle3 L', 2);
INSERT INTO 'dancecrib' VALUES (10316, '2017-12-18 23:08:17.172716+00', '2017-12-19 15:28:41.353586+00', 11030, 1, 202, 'ace', '1--::

  1M+2M & 2W+3W set | 1M+2M+2W+3W ½ RHA _while{2}_ 1W+3M set ; set | repeat [1-4] dancing LHA (1,2,3)

9--::

  1c set | cast off 2 places (2c up on ([13-14]), lead up LH crossing over into DTr position facing opposite sides

17--::

  6 bars of DTr | 1c turn inwards to face down NHJ, M on W''s R, _while{2}_ 2c & 3c set

25--::

  1c dance down | cast off to 2pl ; all turn P RH', 4);
INSERT INTO 'dancecrib' VALUES (2557, '2012-01-22 19:29:47.554031+00', '2021-06-05 19:36:48.774374+00', 2372, 1, NULL, 'ace', '1–::

  1c+2c+3c set, 1W+2W+3W cross passing Rsh to P and chase clw round top to own side in reversed order

9–::

  G-Chain (1W+3M cross to start), all finish in the middle for

17–::

  3 Pairs Allemande (to 1W/3M,2c,3W/1M)

25–::

  All set, all M cross passing Rsh to P and chase clw to own places (1,2,3)

33–::

  1c+2c+3c turn ¾ RH and BiL ; 3c turn 1¼ RH to 3pl _while{4}_ 1M+2W turn 1¼LH and 1W+2M chase around them clw to 2,1,3', 2);
INSERT INTO 'dancecrib' VALUES (12206, '2019-09-13 21:30:58.647921+00', '2020-01-08 11:38:26.374731+00', 6880, 1, 1645, 'ace', '1-::

  1c+2c petronella in tandem | set R{1}, W/M facing down/up NHJ & travel L{1} ; circle4 L to (1,2,3,4)

9-::

  1c cross RH | cast off to 3pl ; &frac12; fig8 up through 2c & take promhold facing up in 3pl _while{8}_ 3c turn RH ½ | lead up & cross to 1pl ; cast off to 3pl | lead up & take promhold, 2c step in to take promhold on [16] (3,2,1,4)

17-::

  3c+2c+1c progressive promenade to (2,1,3,4), 2c face out, 1c face up in centre

25-::

  2W+1W+3W RHA _while{4}_ 2M+1M+3M LHA, 2c end in 1pl as 1c+3c dance down the middle into ;

  3W+1W+4W LHA _while{4}_ 3M+1M+4M RHA to (2,3,4,1)

', 4);
INSERT INTO 'dancecrib' VALUES (10318, '2017-12-19 17:15:06.315622+00', '2017-12-19 17:20:50.553033+00', 11039, 1, 202, 'ace', '1--::

  Circle6 and back

9--::

  1c lead down (2c up) ; and up to face 1cnrs

17--::

  2c+1c+3c Turn Corners and Partner (2,1x,3)

25--::

  All set | BtoB | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10319, '2017-12-19 18:28:12.407178+00', '2017-12-19 18:33:17.38966+00', 18129, 1, 202, 'ace', '1--::
  Circle6 and back
9--::
  1c set | cast (2c up) ; set | Petronella turn into facing lines of 3 across
17--::
  S&Link3 twice
25--::
  ½ Reels3 on opposite sides, Rsh to 1cnrs position ; 1c turn RH 1 ¼ _while{4}_ 2c & 3c set | cross RH (2,1,3)', 1);
INSERT INTO 'dancecrib' VALUES (10320, '2017-12-19 19:33:55.226421+00', '2017-12-19 19:34:15.256979+00', 15189, 1, 202, 'ace', '1--::

  1c slip down the middle ; and up _while_ all clap 16 times (1,2,3,4)

9--::

  1c followed by 2c+3c+4c cast to 4pl and make an arch ; 2c+3c+4c dance up through the arch (2,3,4,1)

17--::

  All set twice ; turn P BH (skip change)

25--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (8278, '2014-06-09 00:58:57.611088+00', '2017-12-19 21:24:44.016776+00', 15457, 1, NULL, 'ace', '1--::

  1c set | cross RH ; cast off (2c up) | turn RH to face 2cnr

9--::

  ½ Reels3 on the sides, 1c Rsh to 2cnr ; ½ Reels3 across, 1c Lsh to 1cnr (pos), to (2,1x,3) 

17--::

  1c lead down {3}, change sides, W passing under M’s arm, and up (2c down) (1,2,3)

25--::

  1c+2c the Knot

', 4);
INSERT INTO 'dancecrib' VALUES (10322, '2017-12-19 23:46:19.482381+00', '2017-12-19 23:46:39.087229+00', 18131, 1, 202, 'ace', '1--::

  1c+2c change places on sidelines, 1c start outwards, 2c face out | 1c followed by 2c dance down between 3c, cast up to top, 1c & 2c staying in centre for

9--::

  2C Allemande, 1c facing 1cnrs at end

17--::

  Corner Chain in 1diag

25--::

  Corner Chain in 2diag (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10315, '2017-12-18 21:31:21.395276+00', '2020-11-13 10:07:23.369951+00', 18123, 2, NULL, 'ace', '1-8::

  1C set, passing RSh  to opposite side, 1M+2M  petronella turn to finish opposite ladies and all set (fig. 1)

9-16::

  Reel of four across the set: Men pass LSh  to the ladies and  all finish facing own partner.

17-24::

  1C+2C turn partners B hands once round, into RH across once round (finish as starting the tournee: (fig 2) 1C at the top facing men''s side, 2C at the bottom  facing the ladies'' side.

25-32::

  Dance  2 couple Allemande  down and up: 1C take 1 step to face across the dance and dance down on the Ladies side, 1C pass RSh to finish own side, while  2C take 1 step to face across  the dance  and  dance up on the Men`s side. On bar 1 Men take a long step. 

', 5);
INSERT INTO 'dancecrib' VALUES (10323, '2017-12-20 00:17:18.790888+00', '2017-12-21 23:11:01.428372+00', 18132, 1, 202, 'ace', '1--::

  Circle6 and back

9--::

  1c BHJ slip down the middle | set ; slip up the middle to top | cast to 2pl (2c up)

17--::

  1c cross RH | cast R round 1cnrs position _while{4}_ 2c & 3c cross RH | set, into facing lines of 3 across ; all pass P Rsh to exchanged places | 1c cast R round 2cnrs position to 2plx _while{2}_ 3c & 2c set to P (3x,1x,2x)

25--::

  ½ Reels3 on sidelines, 1c Lsh to 1cnrs position to start ; all turn P RH 1

½', 2);
INSERT INTO 'dancecrib' VALUES (13807, '2021-03-11 14:59:23.458157+00', '2021-03-11 15:02:35.302634+00', 14499, 1, 202, 'ace', '1--::

  1c & 3c Petronella in tandem | 1c & 3c set ; 1c+3c LHA. 1c face 4c, 3c face 2c

9--::

  ½ Parallel Reels4 ; 4c+1c & 3c+2c ½ R&L. On [15-16] 4c turn P LH ¾. 4M faces 1c _while_ 4W faces 2c

17--::

  3c set twice _while{4}_ 1c+4M & 4W+2c Circle3 L. On [20] 4M pivot R to 4W''s left, 4c facing 2c ; 4c & 2c Petronella in tandem | 4c & 2c set (4,1,2,3)

25--::

  Circle8 and back (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (8914, '2015-09-22 14:42:40.215869+00', '2017-03-03 21:46:46.849607+00', 16682, 2, 1, 'ace', '1–4::

  All set & link

5–8::

  W dance ¾ RH across _while_ M set | cast 1pl to R to fin beside ptr (1 pos ACW)

9–::

  2c+4c [“head” cpls] ½ RL ; 1c+3c [“side” cpls] ½ RL

17–::

  ½ Grand chain [1 step/hand] ; all turn ptr R

25–::

  Circle8 to L [6 slip steps, cross, pivot] ; all chase ACW [to pl at end of bar 20]

', 3);
INSERT INTO 'dancecrib' VALUES (4640, '2013-08-21 08:30:51.989543+00', '2023-02-17 18:32:46.820956+00', 1145, 3, NULL, 'ace', '1-8::

    1s set, cross RH, cast 1 place & turn RH to 2nd place on opposite

    side

9-16::

    1s dance Interlocking reels of 3 across giving RSh to 1st corner

    _while_ 2s+3s dance reels of 3 on sides, 1s end 2nd place opposite

    sides

17-24::

    1s dance Interlocking reels of 3 across giving LSh to 2nd corner

    _while_ 2s+3s dance reels of 3 on sides, 1s end 2nd place opposite

    sides

25-32::

    2s+1s+3s set, 1s 3/4 turn RH & set in lines across, 1s turn RH to

    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (10495, '2018-03-08 23:54:12.148254+00', '2018-03-09 08:15:04.870174+00', 7459, 1, NULL, 'ace', '1--::

  1c+3c set adv | turn opposite RH ½ ; 1c+3c LHA ¾ and the M twirl L and take P in promhold

9--::

  Reels3 across (2c & 4c split), 1c+3c start Rsh to the M they face, all finish in own place (1,2,3,4)

17--::

  Circle8 and back (1,2,3,4)

25--::

  All turn P RH ½ into allemande hold facing out | dance 1 place cclw : each M puts W in middle as [5-6] of an Allemande | turn P LH ¾  (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (3730, '2013-04-17 16:06:18.038715+00', '2019-01-24 15:13:17.738409+00', 7311, 2, 274, 'ace', '1 - 4::

  1c+2c 1/2 RHA while 3c 1/2 turn LH, 2c 1/2 turn RH while 1c+3c 1/2 LHA

5 - 8::

  2c+3c 1/2 RHA while 1c 1/2 turn LH, 3c 1/2 turn RH while 2c+1c 1/2 LHA (312)

9--::

  1c set, 1/2 Reels3{3} across (Lsh to 1cnr), into 1/2 Reels3{3} on the sides (Rsh to 2cnr), end facing 2nd cnr position (1L on 1Ms left)

17--::

  1c set to 2nd corner (2M), turn inwards and set to 4th corner (3L), set to 1st corner (3M), turn inwards and set to 3rd corner (2L), 1c turn right about to face 1st corner (1L behind 1M)

25--::

  1c in tandem + 1cnrs 1/2 diagonal Rsh Reel3 (1M & 1W loop R singly for lead change, so 1W now leads P), 1c + 2cnrs 1/2 Rsh Reel3 (1M & 1W loop R singly for lead change, so 1M now leads P) (312)

', 5);
INSERT INTO 'dancecrib' VALUES (1614, '2012-01-22 19:28:51.027034+00', '2018-10-08 20:23:53.025543+00', 14013, 1, NULL, 'ace', '1–::

  1c+2c Tourbillon (2,1,3)

9–::

  2c+1c+3c ½ Reels3 on the sides (1c start Rsh to 4cnr), at end cnrs make loops ; ½ Reels3 across, 1c Lsh to 1cnr and pass Lsh to centre facing 3cnr (3x,1,2x)

17–::

  [Set to cnrs and cast away:] 1c set to 3cnrs | 1c cast R and out to 1cnr _while{2}_  cnrs dance into centre and swivel R to face the cnr they came from ; 1c set to centres | centres cast R and out, back to original cnr  _while{2}_ 1c dance into centre and swivel R to face 4cnr

25–::

  Repeat [17-24] on 2diag, finish passing Rsh to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3379, '2012-01-22 19:30:22.89406+00', '2018-08-17 12:26:25.32852+00', 6513, 1, NULL, 'ace', '{{explanation}}

Set of 4 (or any even number of) lines of W+M+W facing in pairs, sideways to the public, »top« & »up« being to that W side where the public is. All start together.  

The W to the L (R) of each M at the start are called Wl (L) and Wr (R).



1–::

  Circle6 and back

9–::

  All Wl advance diagonally and retire _while{4}_ all (M+Wr) Promenade half round cclw and drop woman in diagonally opposite place ; 1M+2M turn 1¼ LH

17–::

  All Wr advance diagonally and retire _while{4}_ all (M+Wl) Promenade half round cclw and drop woman in diagonally opposite place ; 1M+2M turn LH to finish between their W, all facing other trio

25–::

  All pass Rsh through facing trio, set swiveling ½ R on second PdB ; pass back Rsh, set to face new trio (the new end trios swivel R ½)

33-64::

  The two middle trios repeat 32 bars (Wl and Wr dance from exchanged positions). End trios stand.

65-96::

  All trios repeat 32 bars, at the final setting [31-32] all make ¼ turn (to the R or L as may be), the women of each »trio« to face each other, the M to face »up«.

97–::

  All M turn »upper W« RH ; turn »lower W« LH

105–::

  Turn »upper W« RH ; and in promhold dance Lsh round »lower W«, finishing to that woman''s right facing »up«, all in a long line across

113–::

  All set 4 times in balance/PdB

121–::

  All W set advancing, set with full right turn ; set advancing, point 4 times _while{8}_ all M set with 16 high-cuts during one full right turn.



{{explanation}}

end:	Bow/curtsey, M step forward between W for final bow/curtsey.', 3);
INSERT INTO 'dancecrib' VALUES (2561, '2012-01-22 19:29:47.711586+00', '2019-04-15 23:42:53.057222+00', 3441, 1, NULL, 'ace', '1–::

  1c (cross down)+2c+3c Mirror Reels3 on opposite sides (touch hands), 1c+3c finishing for

9–::

  1c+3c L-Chain up / down, finish 1c facing 3c NHJ

17–::

  1c+3c set | petronella in tandem (Skip Ch.) ; repeat across _while{8}_ 2c cross RH, cast R to midline ; cross RH up /down, cast R (to 3x, 2x, 1)

25–::

  All chase ½ way clw to (1x, 2, 3) ; 1c cross RH and cast to 2pl (2c up) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10665, '2018-04-21 10:38:12.758716+00', '2018-04-21 11:00:10.482889+00', 4834, 1, 202, 'ace', '1--::

  All Petronella turn into middline | set ; turn P RH 1½ (1,2,3,4)

9--::

  All set | cross RH ; set | 1c & 2c turn RH into allemande hold _while{4}_ 3c & 4c cross RH

17--::

  1c+2c 6 bars of Allemande | 1c release LH, lead down and cross over to 4plx facing out _while{2}_ 2c release RH, turn P LH to 1pl  facing out (3c+4c up) (2,3,4,1x)

25--::

  1c(2c) cast up(dn) round nearest cpls, meet behind sidelines, both M give LH to W they meet, dance in between 3c & 4c, M pass W in front of them to meet P | 1c(2c) lead up(dn) and cross over to 1pl(4plx) ; repeat [25-28] from exchanged places, 1c(2c) facing out(in) at end (2,3,4,1x)

33--::

  2c+3c RHA _while{4}_ 4c turn P RH ½ crossing down to 4plx and 1c cast up to 3plx | 1c+4c ½ RHA ; 2c+3c & 4c+1c LHA (2,3,4,1)

41--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (1620, '2012-01-22 19:28:51.388514+00', '2018-10-08 20:35:13.894316+00', 40, 1, NULL, 'ace', '1–::

  1c set to 2c | turn that person BH ; 1c+2c set to P, turn BH into

9–::

  1c+2c Allemande, 1c finish facing 1cnr

17–::

  SetH&G , on [23-24] petronella turn with clap to 2pl (2,1,3)

25–::

  All Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1629, '2012-01-22 19:28:51.861901+00', '2018-10-08 21:10:04.346156+00', 11567, 1, NULL, 'ace', '1–::

  1c+2c advance and turning R about return to places ; ½ R&L (2x,1x,3)

9–::

  2W+1W+3W ½ diagonal Reel3 (1W Rsh to 3W) ; 2M+1M+3M repeat (1M Lsh to 3M) (3x,1x,2)

17–::

  1c, 3c following, lead down, on [20] the M (dancing below) turn P under their arm and lead up, 2c steps in for

25–::

  3c+1c+2c Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12959, '2020-07-14 08:32:53.545577+00', '2020-07-14 08:37:07.031684+00', 7025, 1, 202, 'ace', '1--::

  1c+2c RHA {3}, 1c cast off _while{1}_ 2c lead up to 1pl ; ½ DblFig8, 1c crossing up (2x,1x)

9--::

  Repeat [1-8] with LHA (1,2)

17--::

  1c+2c Circle4 L ½ (to 2x,1x) | turn P BH ; Circle4 L ½ | 1W+2W & 1M+2M turn BH on sides (1,2)

25--::

  2C Knot (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11789, '2019-04-17 13:47:07.894265+00', '2019-04-17 13:53:39.54456+00', 232, 1, NULL, 'ace', '1--::

  1W+2M turn RH 1½ to change places ; 1c+2c set to P and turn P RH

9--::

  Reels3 on the sides, 1c&2c pass P Rsh to begin

17--::

  1M+2W turn LH 1½ to change places ; 1c+2c set to P and cross RH to own side (2,1,3)

25--::

  Circle6 and back

', 3);
INSERT INTO 'dancecrib' VALUES (10031, '2017-07-29 21:32:21.645551+00', '2022-11-05 11:45:59.114771+00', 7552, 2, 1, 'ace', 'Couples round the room facing anticlockwise, ladies on the men''s right.
Start with ladies'' left hands on men''s right shoulders, men''s right arms loosely around ladies'' waists.

1–2:: Bouncing on the inner foot, touch heel then toe of outer foot to the ground twice.
3–4:: Walk forward for three steps then turn towards partner to face in the opposite direction.
5–8:: Repeat in the opposite direction, finishing facing partner.
9–10:: With both hands joined, jump onto both feet, then kick right foot across left; jump onto both feet again, then kick left foot across right.
11–12:: The man raises his left hand (and the lady''s right), dropping the other hand, and the lady (walking forward) turns once under the raised hands. Finish in ballroom hold.
13–16:: Polka around the room, finish ready to start again.', 3);
INSERT INTO 'dancecrib' VALUES (10499, '2018-03-10 21:56:43.65507+00', '2019-01-18 19:15:43.092254+00', 18250, 2, 1645, 'ace', '1-::
  1c+2c Adv&Ret _while{4}_ former 1c (if any) dance down & loop to 4pl as 4c ; 1c+2c & 3c+4c RHA
9-:: 
  All Adv&Ret ; 1c+2c & 3c+4c LHA
17-::
  1c slip down  (2c+3c+4c up on 19-20); and back up ending in the centre in 2pl
25-::
  2c+3c+4c circle 6H round & back around 1c who turn (however they like) in the centre (2,3,4,1)
', 5);
INSERT INTO 'dancecrib' VALUES (10325, '2017-12-22 01:59:45.397775+00', '2017-12-22 02:02:52.768935+00', 18139, 1, 202, 'ace', '1--::
  1c cross | cast (2c up) ; 1c turn 3c RH | turn 2c LH, 1M+2M ending facing out (2,1x,3)
9--::
  2c+1c La-Chain
17--::
  1c dance down between 3c, cast off ; dance up between 2c, cast to 2plx
25--::
  2c+1c+3c A&R ; 1c turn BH 1 ½ _while{4}_ 2c+3c turn P BH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11790, '2019-04-17 14:22:49.156767+00', '2019-04-17 14:22:49.156767+00', 19142, 1, NULL, 'ace', '*All form single circle RR, facing in*

1--::

  All W Fig8 round P and round M on their R

9-::

  All M Fig8 round P and round W on their L 

17-::

  In circle NHJ all A&R ; All Advance and face P, keeping HJ with P | All M retire, guiding W, finish W inside facing P outside 

25-::

  All dance BtoB with P ; All look R and birl or turn new P RH, finish in single circle, W on the R of P.', 3);
INSERT INTO 'dancecrib' VALUES (10326, '2017-12-22 02:22:28.60576+00', '2017-12-22 02:22:44.587161+00', 18140, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; 2c+1c+3c A&R

9--::

  1c Petronella turn into facing lines of 3 | all set ; 1c Petronella turn to 2pl : all set (2,1,3)

17--::

  Reels3, 1c Rsh to 4cnrs to start

25--::

  Turn Corners and Partner (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2992, '2012-01-22 19:30:05.931848+00', '2020-03-04 22:58:30.425727+00', 5198, 1, NULL, 'ace', '1–::

  1c cast off (2c up) | 1c ½Fig8 between 2c | 1c turn LH to 1cnr.

9–::

  1c turn 1cnr RH | pass Rsh ; turn 2cnr LH | pass Lsh to face 1cnr.

17–::

  ½Reel4 with 1cnrs, pass Lsh ; ½Reel4 with 2cnrs, finishing facing 3cnr (1cnr person)

25–::

  1c set to 3cnr, 1c spiral Rsh round each other (skip change !) ; 1c set to 4cnr (2cnr person) spiral Rsh as before to face out in 2plx.

33–::

  1c cast R round 1cnr and meet in the middle _while{4}_ corners ½R&L (no polite turns) ; all turn RH (1c face out to cast on next [1-2]) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10867, '2018-06-25 10:27:16.769022+00', '2018-06-27 05:18:32.544731+00', 10532, 1, 202, 'ace', '1--::
  1c+2c ½ R&L ; set | cross RH (2,1,3)
9--::
  1c dance up, cast round 2c to 2pl ; dance down, cast round 3c to 2pl (2,1,3)
17--::
  1c+1cnrs Allemande Turn R ; 1c+2cnrs Allemande Turn L (2,1,3)
25--::
  1W+2c & 1M+3c RHA ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10503, '2018-03-11 21:18:30.118516+00', '2018-03-11 21:18:30.118516+00', 18254, 1, NULL, 'ace', '*Strathspey*  

1--::

  1c set | cast (2c up) ; 1c gypsy turn Rsh ¾ into lines across (1W above 1M)  

9--::

  S&Link3 ; All set | cross (no hands) (2,1x,3)  

17--::

  S&Link3 ; 1c chase clw ½ _while{4}_ 3c+2c LHA  

25--::

  1c gypsy turn Rsh ½, into Turn RH and twirl to own side (312).  



*Repeat twice as Strathspey and three times as Reel*  ', 2);
INSERT INTO 'dancecrib' VALUES (10502, '2018-03-11 21:03:38.796286+00', '2018-07-17 09:31:27.256252+00', 2826, 1, NULL, 'ace', '1-::

  1M+2W turn RH ; 1W+2M turn RH

9-::

  1c followed by 2c lead down ; 2c followed by 1c lead up | clap &amp; dance out to (2,1)

17-::

  2c+1c RHA ; LHA

25-::

  2c+1c Circle 4H to L ; &frac12; Circle back | clap &amp; petronella back to (2,1)

', 4);
INSERT INTO 'dancecrib' VALUES (10501, '2018-03-11 20:09:21.577255+00', '2018-07-17 09:45:47.951187+00', 5674, 1, NULL, 'ace', '1-::

  1c Fig8 round 2c

9-::

  1c &amp; 2c cross RH | set ; repeat back to place

17-::

  1c dance down the middle and back

25-::

  1c+2c &frac12; RHA | set ; cross RH | set (2,1)

', 4);
INSERT INTO 'dancecrib' VALUES (10496, '2018-03-09 23:21:44.450265+00', '2018-07-18 15:41:57.755507+00', 2485, 1, NULL, 'ace', '1-::

  1c+2c set | &frac12; RHA ; set adv taking LH | 1c turn LH to 1cnr _while_ 2c cross LH

9-::

  1c+1cnrs &frac12; RSh Reel4, pass LSh to ; 1c+2cnrs &frac12; RSh Reel4 (3x,1x,2x)

17-::

  1c petronella | set ; petronella | set (3x,1,2x)

25-::

  1c turn 1&frac14; LH ; 1c dance RSh round 4cnrpos to 2pl _while{4}_ 3c+2c dance track of &frac12; crossing diag RSh Reels4 with &frac12; LHA in centre (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (10667, '2018-04-21 11:38:25.678129+00', '2018-07-18 14:56:49.189071+00', 3431, 1, NULL, 'ace', '1-::

  1c &amp; 2c set to P | set facing on sides ; set to P | 1c cast _while_ 2c dance up NHJ &amp; face out (2,1,3)

9-::

  Mirror Reels3 on sides, 1c in &amp; down to start

17-::

  1c set | turn RH{3}, then{3} cast to L round 4cnrs to end facing 1cnrs

25-::

  Turn CPCP (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10324, '2017-12-21 19:48:59.17764+00', '2023-01-26 21:50:45.594574+00', 18137, 1, 202, 'ace', ' 	



1--::

  1c dance down the middle and up | cast (2c up) (2,1,3)

9--::

  ½ Reel4 in 1diag, pass Rsh ; ½ Reel4 in 2diag, 1c finish in midline Rsh to Rsh facing own side

17--::

  1c cast Rsh round 3cnrs position, 1c finish in centre Rsh to Rsh, M(W) facing down(up) ; 1M+3M+2M & 1W+2W+3W LHA

25--::

  1c cast Lsh round 1cnrs position to 2plx ; all turn P LH 1 ½ (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (10505, '2018-03-12 19:12:23.069779+00', '2018-12-29 12:02:26.528337+00', 18213, 2, 2703, 'ace', '1-8:: 1W+3M set and cast two places (W down, M up) ; turn LH to each other''s place

9-16:: 1M+3W set and cast two places (M down, W up) ; turn LH to each other''s place

17-24:: 2W+3c & 2M+1c LSh 1/2 reel of three across | 2c 1/2 Fig8 R

25-32:: 3c+2c Knot', 2);
INSERT INTO 'dancecrib' VALUES (1670, '2012-01-22 19:28:54.112972+00', '2020-05-15 13:47:42.074717+00', 14098, 1, NULL, 'ace', '1–::

  All set | 1c+3c cross RH _while{2}_ 2c pass Lsh to face 1cnr (pos.) ; 2c+1cnrs (pos.) ½ diag. Reel4, 2c finish between end cpls

9–::

  All set up/dn | 2c+3c cross LH on the sides _while{2}_ 2c pass Lsh to face 2cnr (pos.) ; 2c+2cnrs (pos.) ½ diag. Reel4, to (3x,2x,1x)

17–::

  All set | 1c+3c cross RH _while{2}_ 2c turn LH to end Lsh to Lsh, M facing up, W dn ; dance through end C and cast L to (3,2,1)

25–::

  3c+2c »Bea''s Delight Progression« (3W+2M turn RH ¾ to give LH to P | BiL ; 3W(2M) each followed by P dance up(down) casting L and down(up) opposite side, crossing to (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2617, '2012-01-22 19:29:50.172273+00', '2020-12-08 22:48:39.645773+00', 3625, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  1c+2c RHA {3} LHA {3} | 1c cast to 2pl _while{2}_ 2c dance to top (2,1,3)

9–::

  1c+3c R&L



{{title}}

Reel



17–::

  1c+2c circle4 and back, finish 1W facing up, 1M down

25–::

  2c+1c+3c Rsh reels3 on own side (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11539, '2019-01-25 00:00:12.413308+00', '2019-12-17 20:55:07.673164+00', 2383, 1, NULL, 'ace', '1--::

  1c set | cross RH ; cast off (2c up) | cross LH and face out (2,1,3)

9--::

  2c+3c RHA _while{4}_ 1c chase cclw half round ; 1c set advancing | 1c turn BH to (2,1x,3)

17--::

  1c 1/2 Fig8 L (cross out the end and cast R) _while{4}_ 2c+3c set diagonally and dance to next position on the R ; all repeat the figures (3x,1x,2x)

25--::

  1c repeat [17-20] _while{4}_ corners chase two positions cclw (2cnrs pass in front of 1c, 1cnrs behind) ; 1c set advancing | turn RH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8915, '2015-09-22 18:50:53.145304+00', '2015-09-22 18:50:53.145304+00', 16762, 2, NULL, 'ace', '1-8::   All clap and dance four hands round and back.

9-16::  Half rights and lefts. Start by crossing right with your opposite. Near hands joined with your opposite, dance out or into the circle, away from your partner, for two bars and back for two bars.

17-24::  Half rights and lefts. Start by crossing right with your partner. Near hands joined with your opposite, dance out or into the circle, away from your partner, for two bars and back for two bars.

25-32::  Take near hands with partner, set, advance , retire and pass right shoulders with that couple and on to a new couple.

', 0);
INSERT INTO 'dancecrib' VALUES (12687, '2020-03-28 10:06:44.998429+00', '2021-06-06 11:24:21.491336+00', 18939, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 up round 2c into promhold. On [8] 2c step into promhold. 2c & 1c face up (2,1)

9--::

  2C Allemande (1,2)

17--::

  1c lead down ; and up into 1pl centre BHJ. On [8] 2c step in and join BH (1,2)

25--::

  Poussette (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (10516, '2018-03-16 21:47:08.266644+00', '2018-08-18 18:40:11.333016+00', 1125, 1, NULL, 'ace', '*Start in a large triangular set numbered (1,2,3) clw with W at the corners, M 1 yard inside them facing out to P.*

*The basic pattern is: [1-12] W dance the _theme_ while M dance one of the _variations_.*

*On [13-16] all turn P 1½ RH. Then repeat [1-16] with M & W in reversed roles.*

*Repeat [1-32] with different _variations_ from the sets below.*

*_The detailed instructions (with diagrams) are highly recommended!_*  

&nbsp;  



_Theme:_ [1-4] All W dance in passing P RSh, pass other W RSh (or touch RH) &

               dance out between opposite M to next corner cclw from starting place (2,3,1) ;

               repeat twice to original place.

               *The W path in each 4 bars is a smooth crescent curving R with 3 skip change,*

               *then turning in slightly, so [4] resembles slipsteps, to make an angle into the next crescent.*  



&nbsp;  



_A. Elementary Set_  

   1. _Theme (only):_ [1-12] M stand  

   2. _Following:_ [1-12] M dance out to P''s place | follow{10} P 2 bars behind, speeding up for the turn.  

   3. _Travel and Set:_ [1-4] M face cclw & dance to next M place passing W LSh | set ; repeat twice.  

   4. _Set and Wheel:_ [1-4] M set | touching LH dance to next M place cclw passing W LSh ; repeat twice.  

   5. _Its Me Again:_ [1-12] M face in for A&R ; face out & dance round P''s place ;; repeat [1-4] & face out for the turn.  

   6. _The Brooch:_ [1-4] M dance to next M place cclw (2,3,1) & next again (3,1,2) ; repeat twice (W pass M LSh going in and out).  

&nbsp;  



_B. Intermediate Set_  

   1. _The Brooch:_ see A.6 above.  

   2. _In, On, Out:_ [1-4] M advance{1}, circle 3H ⅔ L{2}, drop hands & retire{1} ; repeat twice.  

   3. _Marsh Marigold:_ [1-4] M passing LSh dance across to opp side & turn sharp L to M pl (3,1,2) ; repeat twice.  

   4. _Eight and a Half:_ [1-12] M 1½ Fig8 on own spoke: RSh round P''s pl ; LSh round M in centre ;; repeat [1-4].  

   5. _Petronella Round:_ [1-4] M face cclw & petronella twice to next M pl cclw (2,3,1) ; repeat twice.  

   6. _Interlacing:_ [1-4] M dance round next M pl cclw & return home ; repeat twice.  

&nbsp;  



_C. Advanced Set_  

   1. _The Brooch:_ see A.6 above.  

   2. _Heads and Tails:_ [1-12] M BtoB passing RSh, retire RHJ with next W ; M keep RH (as W dance round), retire to centre & dance face to face passing LSh ;; face in & repeat [1-4], retire home RHJ with P.  

   3. _Loops:_ [1-4] M face P, turn P RH as W dance in, dance 1 pl clw & start turning next W at the next cnr ; repeat twice.  

   4. _Twist and Set:_ [1-4] M petronella turn to centre ½ way to next M pl clw | set ; repeat in the centre ;; turn on to next M pl | turn again home.  

   5. _Wild Tulip:_ [1-4] M face cclw, dance out, turn sharp L, dance across to next M pl on L passing M LSh ; repeat twice.  

   6. _Left Swing:_ [1-12] M dance in{1}, grasp L forearm of M in front with LH & swing{9} (left arms across) | return home for the turn.  

&nbsp;  



_57 Varieties:_ See the detailed instructions for many other possibilities.

', 4);
INSERT INTO 'dancecrib' VALUES (11537, '2019-01-24 15:32:59.571348+00', '2019-01-24 15:32:59.571348+00', 17750, 1, NULL, 'ace', '1--::

  1c lead down the middle & up, finish 1W facing out (1,2,3)

9--:: 

  1W, with 1M following, cast off (2c up on [11-12]), cross below 3c, cast up and 1W crosses, 1c finish in 2pl facing down (2,1,3)

17--::

  Grand Chain (2,1,3)

25--::

  Circle6 & back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14454, '2021-11-17 12:05:18.709061+00', '2021-11-17 12:05:32.271036+00', 3629, 1, 1645, 'ace', '1-::

  All set | 1c & 4c dance in & face P in lines across between 2c/3c ;

  1c & 4c turn P &frac34; RH _while_ 2M+3M turn &frac34; _LH_ _while_ 2W+3W turn &frac34; RH so 2c face P | all set

9-::

  Intersecting Reels4, 1c & 4c pass RSh, 2c pass LSh & 3c cast R to start then alternate passing LSh in centre

17-::

  1c & 4c set to P | petronella to sides _while{4}_ 2M+3M turn &frac34; RH _as_ 2W+3W turn &frac34; _LH_ | 2c & 3c cross RH (1x,2x,3x,4x) ;

  all chase &frac12; way clw (4,3,2,1)

25-::

  4c+3c+2c &frac12; Reels3 on sides ; all turn P RH | all set (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (12453, '2019-12-31 14:11:47.809369+00', '2019-12-31 14:40:00.099944+00', 14717, 1, NULL, 'ace', '*3 dancers in line across, d1 facing down between d3 (on his R) facing d2 (on his L) (3,1,2)*

1--::

  d1 A&R ; d1 R&A  _as_ d2+d3 A&R

9--::

  All dance down ; and up, to (2,1,3), d1 facing up and d3 facing d2

17--::

  d1 casts Lsh round d3 as d3 A&R ; d1 casts Rsh round d2 as d2 A&R (3,1,2)

25--::

  "Linear R&L": [d1+d2 change place RH | d3+d2 repeat LH ; d3+d1 repeat RH | d2+d1 repeat LH, d2 making polite turn to face down]  



 *Option: d1 can begin facing up, and d2 omits the final polite turn*

', 3);
INSERT INTO 'dancecrib' VALUES (10868, '2018-06-27 05:36:11.823173+00', '2018-06-27 11:43:15.677249+00', 10531, 1, 202, 'ace', '1--::
  2c followed by 1c Fig8 down round 3c (2,1,3)
9--::
  1c Petronella turn into lines3 across | 1c set ; 1c cross RH | cast R to 2plx (2,1x,3)
17--::
  1c Allemande Turn R ; 1W+2c & 1M+3c LHA (2,1x,3)
25--::
  1c Allemande Turn L ; 1W+3c & 1M+2c RHA, 1c finish facing 1cnrs on sidelines (2,1x,3)
33--::
  1c set to 1cnrs pivoting R to face 2cnrs | set to 2cnrs pivoting L ¼ to face P ; 1c turn RH 1½ to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10668, '2018-04-21 11:42:31.370001+00', '2018-07-17 11:07:49.165466+00', 5558, 1, NULL, 'ace', '1-::

  1c &amp; 2c set adv | turn P BH to face down/up NHJ with P ; 1c &amp; 2c set to opposite | change places RH ending on sides facing in (2,1)

9-::

  1c &amp; 2c set to P | cross RH ; set | cross back LH, 1c to centre facing up LHJ, 2c to sides facing out (2,1)

17-::

  1c &amp; 2c DblFig8, 1c crossing up, 2c casting off to start (2,1)

25-::

  1c continue &frac12; Fig8 round 2c ; turn 1&frac12; RH to (2,1)

', 4);
INSERT INTO 'dancecrib' VALUES (3601, '2012-07-21 11:45:32.334378+00', '2020-08-24 22:24:12.786307+00', 14413, 1, NULL, 'ace', '1-16::

  Snowball Chain, 2 bars per hand, 1c start by crossing (to 5,4x,1,3x,2)

17-20::

  5c & 2c (both start inwards, use EH) turn 4c & 3c respectively on the sides into DblDTr position (4x,5,1,2,3x, with 5c+2c BtoB) | All set

21-24::

  To switch places, 5c cast off 2 and pass Lsh _while_{4} 2c lead up 2 and cross, into DblDTr position (4x,2x,1,5x,3x, with 2c+5c BtoB)

25-32::

  All set | 2c+5c repeat [21-24], but now to sidelines | 4c+3c cross (4,5,1,2,3)', 3);
INSERT INTO 'dancecrib' VALUES (12782, '2020-04-28 14:42:27.427272+00', '2020-04-28 14:55:05.702412+00', 12053, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c crossing down (1x,2,3)

9--::

  1c turn 2c EH, 1c in and down ; 1c ½ Fig8 down round 2c (1,2,3)

17--::

  1c+2c ½ RHA | 1c & 2c turn RH ½ ; 1c+3c Circle4 L. 1c & 3c NHJ in centre face up (2,1,3)

25--::

  1c (3c following) dance up round 1c and cast off to exchanged places (to 2,3,1) ; 3c & 1c dance BtoB (2,3,1)

33-48::

  Repeat [17-32] from new positions (3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (12783, '2020-04-29 00:17:51.827162+00', '2020-04-29 00:20:40.435755+00', 19448, 1, 202, 'ace', '1--::

  1c set | cross RH and face down ; 1c & 2c set up/down | change places LH (2,1x,3)

9--::

  2c+1c La-Chain (2,1x,3)

17--::

  1M (1W following) dance RSh round 1cnr, up the middle, RSh round 2cnr to 2pl (2,1,3)

25--::

  All A&R ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (4608, '2013-08-21 08:30:51.377552+00', '2023-02-17 18:37:17.013843+00', 1097, 3, NULL, 'ace', '1-8::

    1L+2L+3L cross, dance RSh round partners & back to places, 1s cross

    RH & change places LH with 2s on the sides

9-16::

    1L with 2M+3M Adv+Ret, 1M with 2L+3L Advance & as they Retire. 1L

    dances towards partner

17-24::

    1L with partner on her right in prom hold dance out Ladies'' side,

    cast up round 2L, separate to dance out between 2s+3s own sides,

    cast down round 3s & lead up to 2nd place own sides

25-32::

    1s+3s set, 1M casts down 1 place as 3L casts up _while_ 1L+3M turn

    LH, 3s+1s set, 1M casts back up as 3L casts down _while_ 1L+3M turn

    RH', 0);
INSERT INTO 'dancecrib' VALUES (4761, '2013-08-21 08:30:54.749252+00', '2023-02-17 12:27:49.134533+00', 1314, 3, NULL, 'ace', '{{explanation}}

3s & 4s on opp sides



1-8::

    1s+2s also 3s+4s dance 1/2 R&L. 1s & 4s dance 1/2 Fig of 8 round end

    couples

9-16::

    1s+4s set on sides, dance RH across 1/2 way & 1M followed by 4L

    dances down between 3s & casts up Men''s side _while_ 4M followed by

    1L dances up between 2s & casts down Ladies'' side  (2) 1 (4) 3

17-24::

    1s in prom hold dance reel of 3 on Men''s side (LSh to 2L to start)

    _while_ 4s in prom hold dance reel of 3 on Ladies'' side (LSh to 3L

    to start)

25-28::

    1s dance 1/2 reel of 3 across with 2s (RSh to 2M to start) _while_

    4s dance 1/2 reel of 3 across with 3s (RSh to 3M to start).

29-32::

    1s dance down between 3s, separate & cast to 3rd place opposite side

    _while_ 4s dance up between 2s (passing 1s RSh), separate & cast to

    2nd places.  2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (10040, '2017-08-09 14:00:47.559165+00', '2019-01-18 19:03:47.814083+00', 17919, 1, 1645, 'ace', '*On 2nd chord, 1c & 3c cross to opposite sides (1x,2,3x,4)*

1-::

  1c & 4c in promhold dance Reels3 with 2c & 3c (RSh to 2M & 3M) ending with 1c facing 4c in centre, 2c & 3c in 1pl & 4plx

9-::

  1c+4c &frac12; RHA | turn 2cnr LH ; pass LSh on sides | turn 1cnrpos RH to face them on sides (2,1,4x,3x)

17-::

  All dance RSh Reels4 on sides, 1c+4c end with &frac12; LH turn so all face clw

25-::

  All chase &frac12; way clw ; 1c+4c &frac12; R&L _while{4}_ 3c & 2c turn 1&frac12; RH (optionally staying joined) to (3x,1,4x,2)

', 3);
INSERT INTO 'dancecrib' VALUES (10671, '2018-04-21 11:59:03.807875+00', '2018-07-17 09:45:04.257596+00', 5590, 1, NULL, 'ace', '1-::

  1M+2W turn RH ; 1W+2M turn RH

9-::

  1c+2c advance &amp; retire ; &frac12; R&amp;L (2x,1x,3)

17-::

  3c cast up | lead up to 1pl facing out _while{4}_ 1c cross down to 3pl | cast up _while{4}_ 2c lead down | cross to 3pl facing out (3,1,2) ; &frac12; mirror Reels3 on sides taking NH, 1c in &amp; up to start, 2c &amp; 3c end with loops (2,1,3)

25-::

  1c dance down NHJ | cast up ; all turn P RH (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (8746, '2015-04-01 17:21:22.173356+00', '2015-04-01 17:22:29.715822+00', 16184, 1, NULL, 'ace', '1–::

    1c+2c & 3c+4c S&Link ; 1c+4c ½ R&L (2,4x,1x,3)

9–::

    1c+4c set | ½ RHA ; turn P RH, finish in middle NHJ, 1c facing 4c

17–::

    1c set to 4c | Pass the other C, 4c making arch ; both C dance out the ends and cast in to own sideline (2,4,1,3)

25–::

    Rsh reels4 on the sides (2,4,1,3)





', 2);
INSERT INTO 'dancecrib' VALUES (10870, '2018-06-28 20:44:34.606656+00', '2018-10-22 22:13:30.740587+00', 18355, 1, NULL, 'ace', '1-::

  1c+3c RHA _while{4}_ 2c+4c chase ½ way cclw ; 4c+2c LHA _while{4}_ 1c+3c chase ½ way clw (3,4,1,2)

9-::

  1c+3c modified Bourrel: M dance ½ way cclw _while{4}_ W set adv | ½ turn BH & twirl away ; set to P | turn RH 1¼ (1,4,3,2)

17-::

  2c+4c repeat (1,2,3,4)

25-::

  All ¼ Schiehallion reel ; set to P (W touch RH in centre) | turn BH (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10869, '2018-06-27 09:08:07.665707+00', '2018-06-27 11:29:23.863105+00', 6259, 1, 202, 'ace', '1--::

  1c set | cast 2 places ; cross Rsh | cast up to 2plx (2c up) (2,1x,3)

9--::

  Mirror Reels3 on sidelines, 1c start in and up (2,1x,3)

17--::

  Reels3 across, 1c start Lsh to 3cnrs. On [23-24], 1c meet in centre, pull Rsh back to face 1cnrs

25-36::

  Dance to Corners and Set, on [36] 1c finish in 2plx centre (3x,*1x*,2x)

37-40::

  1c turn RH to 2pl _while{4}_ 2c+3c chase clw ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10508, '2018-03-13 21:07:31.887175+00', '2018-07-17 09:38:55.302138+00', 3968, 1, NULL, 'ace', '1-::

  1c cross RH | cast off (2c up) ; 2c cross RH | cast off (1c up) to (1x,2x)

9-::

  1c &amp; 2c cross RH | &frac12; RHA ; 2c &amp; 1c cross LH | &frac12; LHA (1x,2x)

17-::

  1c set | cast off below 2c ; set | dance up to (1x,2x)

25-::

  2c set adv | lead up &amp; cross above 1c ; 1c cross RH | cast off _while{4}_ 2c cast off | dance up to (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (10670, '2018-04-21 11:51:58.76871+00', '2018-07-17 09:43:37.848776+00', 4920, 1, NULL, 'ace', '1-::

  1c set | turn BH ; lead down | cast up round 3c back to (1,2,3)

9-::

  Cross-over Reels3 on sides, all crossing down from 1pl (1x,2x,3x)

17-::

  1c+2c set | turn P BH opening out to face down/up NHJ with P ; 1c & 2c set to opposite | M(W) change pl LH(RH), 1c face out (2x,1x,3x)

25-::

  Cross-over Reels3 on sides, all crossing down from 1pl back to own sides (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (10507, '2018-03-12 23:52:31.508635+00', '2018-07-18 15:16:00.713829+00', 2849, 1, NULL, 'ace', '1-::

  1M+2W set adv | &frac12; turn RH ; 1M/2W cast to R round 2M/1W _while{2}_ 1W+2M set adv | 1c+2c &frac12; RHA (2x,1x)

9-::

  1W+2M set adv | &frac12; turn LH ; 1W/2M cast to L round 2W/1M _while{2}_ 1M+2W set adv | 2c+1c &frac12; LHA (1,2)

17-::

  1M+2W set adv | &frac12; turn RH ; cast to R, cross &amp; start to dance down/up _while{8}_ 1W+2M stand | set adv ; turn almost twice by L arm ending facing P as if for Reel4 across

25-::

  All pass P RH | 1W &amp; 2M cast slightly to R ; stand{4} _while{6}_ 1M+2W turn LH{4} | cast to L round 2M/1W to (2,1)

', 4);
INSERT INTO 'dancecrib' VALUES (10509, '2018-03-13 21:30:45.020346+00', '2018-07-17 10:18:08.027812+00', 3521, 1, NULL, 'ace', '1-::

  1c+2c Circle4 ; 1c+2c set | 1c cross down RH _while_ 2c cast up (2,1x)

9-::

  2c followed by 1c lead down _while_ 3c dance up to 1pl | 3c cross RH _while_ 1c &amp; 2c &frac12; turn RH to sides (3x,1,2x) ; all A&amp;R (1 step) | all cross RH (3,1x,2)

17-::

  3c+1c+2c Circle6 ; all turn P LH (3,1x,2)

25-::

  3c+1c+2c &frac12; Gr-Chain (3c cross to start) ; 1c turn RH _while{4}_ 2c &amp; 3c A&amp;R (1 step) | cross RH (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (10669, '2018-04-21 11:47:47.956577+00', '2018-07-17 11:11:23.371508+00', 367, 1, 1645, 'ace', '1-::

  1c+2c+3c set | cross RH ; set | 1c cast off to 3pl _while_ 2c &amp; 3c each cross up RH (2,3,1x)

9-::

  1c dance up NHJ | cast up behind 2c (3c down) ; lead down | turn RH to face 1cnrs

17-::

  1c set to and turn corners, ending on sides (2,1x,3)

25-::

  2c+1c+3c advance &amp; retire ; 1c turn 1&frac12; RH (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (10457, '2018-02-25 10:19:11.093366+00', '2018-11-22 20:23:20.726617+00', 18246, 1, 202, 'ace', '1--::

  1c dance down between 3c, cast up to 2pl ; turn RH 1 ¼

9--::

  1M+2c & 1W+3c LHA, pass Lsh ; 1M+3c & 1W+2c RHA, finish facing 1cnrs

17--::

  Reel4 in 1diag, on [23-24] 1c pass Rsh to 2plx (2,1x,3)

25--::

  2c+1c+3c chase clw ½ ; 2c+3c chase clw ½ _while{4}_ 1c turn RH (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (13784, '2021-03-02 19:37:09.541133+00', '2021-03-11 15:43:50.544907+00', 20239, 1, 202, 'ace', '1--::
  1c lead down {3}, lead up {3} | cast off (2c up) (2,1,3)
9--::
  All A&R ; 1c cast off, meet P and cross up to 2plx (2,1x,3)
17--::
  2c+1c M-Chain. 1W finishes facing 2M, 1M behind in tandem (2,1x,3)
25--::
  ½ Reel3 on 1diag, 1c (1W leading) RSh to 2M. On [28] 1c pull RSh back to change lead ; ½ Reel3 on 2diag, 1c (1M leading)  RSh to 2W (3x,1,2x)
33--::
  Diagonal R&L (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (2051, '2012-01-22 19:29:17.154331+00', '2018-08-18 22:34:51.338048+00', 1543, 1, NULL, 'ace', '1–::

  1c+2c turn RH to places ; 1c+2c RHA (1,2,3)

9–::

  Parallel Rsh Reels3 on the sides, but 1c+2c extend reel to form line across (2M, 1M, 2W, 1W), 3c ends in 3pl

17–::

  1c+2c ¾ Reel4 across (2W,2M,1W,1M)| pass P Rsh to own side (2,1,3)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (11010, '2018-08-18 18:37:02.79069+00', '2018-08-18 18:56:33.74103+00', 15211, 1, 202, 'ace', '1--::

  1c+2c ½ R&L ; ½ RHA | set (1,2,3)

9--::

  1c lead down ; and up (1,2,3)

17--::

  1c+2c Poussette, finish BtoB in the middle (2,*1*,3)

25--::

  DTr (2,1,3)

33--::

  Reels3 on sidelines, 1c RSh to 3cnrs', 2);
INSERT INTO 'dancecrib' VALUES (3594, '2012-07-21 11:45:23.029472+00', '2018-08-19 08:58:53.178073+00', 14519, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; turn LH 1½ till 1W faces 2M with 1M just behind her.

9–::

  1c+1cnrs ½ Rsh lead-change Reel3, at end 1c (1M leading) face 3M ; 1c+2cnrs ½ Lsh lead-change Reel3, finish 1c (1W leading) facing 3W pl

17–::

  1c (1W leading) +1cnrs ½ Rsh lead-change Reel3 and face 3M (in 1W pl) ; 1c (1M leading)+2cnrs ½ Lsh lead-change Reel3, finish in middle on own side

25–::

  1c dance between 3c, cast up, dance up between 2c, cast off to (2,1,3)



{{explanation}}

Note that in [9-24] 1c dances one full Reel3 on M sideline, ½ Reel3 across, ½ Reel3 on W sideline, while the corners dance alternate diagonal ½ Reels3  

The dance is also known as »Uncle George«', 3);
INSERT INTO 'dancecrib' VALUES (12565, '2020-02-04 17:35:28.062091+00', '2020-02-04 17:35:28.062091+00', 19841, 2, NULL, 'ace', '1st and 4th couples active, 3rd and 4th couples start on partner’s side



1- 6::   Actives cross RH & cast inward 1 place, cross RH to finish face up on M side, down  on W side.2s and 3s step outward on bars 3-4.

7- 8::   M leading, Actives cast up around 2M on M side, down around 3M on W side



9-12::   M still leading Actives dance a half tandem reel of 3 across the dance, LSh to the W, to finish in lines of 4

13-16::   In lines of 4 across the dance, all set then change places RH up and down the dance to end facing CW



17-20::   All chase CW, half-way

21-24::   Actives RHA in the middle, while corners continue to chase to their positions at bar 17



25-32::   Actives, W leading, dance 2 diag half tandem reels of 4, passing RSh in the center   2  4  1x  3x', 2);
INSERT INTO 'dancecrib' VALUES (11540, '2019-01-25 11:47:23.783113+00', '2019-01-25 17:40:49.797447+00', 1406, 1, NULL, 'ace', '1--::

  1M & 3W change places: 1M/3W set advancing to 2W/2M (who set not advancing) | 1M/3W turn 2W/2M RH ½ ; All set | cross RH

9--::

  1W & 3M repeat [1-4] to change places (3,2x,1) ; All set | 2c cross RH _while{2}_ 3c+1c turn RH ½ and face each other NHJ

17--::

  All set | Circle6 L ½, on [22] dance in, pivot R and chase clw to (3x,2,1x)

25--::

  All set | 3c cross down to 3pl _while{2}_ 2c+1c cast up ; 1x ½ Fig 8 up (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12808, '2020-05-12 09:15:52.560938+00', '2021-08-10 16:59:23.964646+00', 15951, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; dance down the middle

9--::

  1c dance up to 2pl centre ; 1W+3M+2M LHA _while{4}_ 1M+3W+2W RHA

17--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2 diag (3x,1x,2x)

25--::

  1c cross RH | dance RSh round 1cnrs[pos] _while{4}_ cnrs set | cross RH ; 1c cross RH up/down | dance RSh round 4cnrs[pos] to 2pl _while{4}_ cnrs set | change places RH on sides (with loops where appropriate) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10871, '2018-07-01 23:17:27.642281+00', '2018-07-02 06:08:59.603097+00', 16676, 1, 202, 'ace', '1--::
  1c cross RH | cast (2c up) ; Petronella turn | pass Rsh up/down _while{4}_ 2c+3c chase clw 1 place | set pivoting R ½, finishing into lines3 across facing out
9--::
  Lines3 advance{2}, on [10] 1c pull Rsh back, 2c & 3c turn inwards ½ into facing lines3 across | lines3 advance{2} ; 1c pass Rsh up/down _while{2}_ 2c & 3c set, 2W & 3M pivoting R ¾ | all chase clw ¼ (3x,1x,2x)
17--::
  3C S&Link (2,1,3)
25--::
  Reels3, 1c Lsh to 3cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (4581, '2013-08-21 08:30:50.943021+00', '2023-02-17 18:49:46.362417+00', 1059, 3, NULL, 'ace', '1-8::

    1s set & cross down RH to 2nd places, 1s cast round 1st corners to

    face them

9-12::

    1s+1st corners change places RH & 1st corners persons 1/2 turn LH to

    face opposite sides _while_ 2nd corners chase clockwise to change

    places

13-16::

    1st corner persons dance RH across on opposite sides & 1/2 turn LH

    to face original pstns

17-20::

    Original 1st corner persons & 1s change places RH then 1s 1/2 turn

    LH to face own sides _while_ 2nd crnrs chase clockwise back to

    places

21-24::

    1s dance RH across on own sides & 1s end in 2nd places

25-32::

    1s dance reels of 3 on own sides giving RSh to 3rd corner & ending

    in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (10007, '2017-07-13 14:33:01.642085+00', '2017-11-14 06:25:17.044655+00', 14385, 1, 202, 'ace', '1--::

 1c dance down and cast round 2c to 1pl ; 1c dance down and cast round 3c to 2pl (2c up) (2,1,3)

9--::

 ½ Reels3 across, 1c Rsh to 2cnrs to start ; ½ Reels3 on sidelines, 1c Lsh to 1cnrs pos to start, pass Lsh to face 3cnrs pos

17--::

 SetH&G, 1c face 1cnrs pos

25--::

 1c+3cnrs pass, cnrs turn RH ½, and cast away as 1c meet and pass Rsh ; repeat with 4cnrs (2,1,3)

33--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2867, '2012-01-22 19:30:00.797125+00', '2018-03-15 20:06:34.263169+00', 4720, 1, NULL, 'ace', '1–::

  1c+2c+3c set, cross RH ; 1c+2c S&Link, 1W full polite turn and 1c face down and in (2x,1x,3x)

9–::

  2c+1c+3c mirror Reels3{6} on the sides (hands when possible, no final loops) | 1c+3c turn BH ½ ready for:

17–::

  1c+3c ½Poussette ; set, ½ RHA (2x,1x,3x)

25–::

  1W+2c & 1M+3c Rsh ½Reels3 across ; 2c+1c+3c turn BH.



{{explanation}}

After 2nd time through, 1c cast off as 4c dance up to 3pl', 3);
INSERT INTO 'dancecrib' VALUES (9877, '2017-05-21 14:48:13.20431+00', '2019-01-18 19:37:08.09415+00', 17759, 1, 1645, 'ace', '*On 2nd chord, 3c & 4c cross to opposite sides (1,2,3x,4x)*

1-::

  1c & 4c cross RH | cast in (2c & 3c out) ; 1c+4c RHA finish as pairs 1M+4W & 4M+1W facing out in promhold

9-::

  Pairs with 2c+3c &frac12; Reels3 on sides, RSh to 2M/3M, pairs separate to line across: 1W/4W on M/W side, M B2B facing P ; 1c+4c &frac12; LSh Reel4 across finish in promhold with P _while{4}_ 3c & 2c cross RH and set

17-::

  1c & 4c with 3c+2c &frac12; Reels3 on sides, LSh to 3W/2W, 1c & 4c separate to line across: 4M/1M on M/W side, W B2B facing other cpl ; 1c+4c &frac12; RSh Reel4 across _while{4}_ 2c & 3c cross RH and set to face clw

25-::

  All chase &frac12; way clw ; 4c & 1c turn P RH _while{4}_ 3c & 2c continue chase to (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (12441, '2019-12-18 12:54:22.985118+00', '2020-06-27 21:13:10.157632+00', 12924, 1, 1645, 'ace', '1-::

  1c set | cross down, no hands, to 2plx facing out (2c up) ; loop LSh round 2cnr & face 1cnr on sides (2,1x,3)

9-::

  1c+1cnrs turn RH & 1c take LH in centre | 1c &frac12; Spoke to 3cnrs | 1c+3cnrs turn RH to lines across, 1c facing 2cnrs

17-::

  LSh Reels3 across, 1c end facing 2cnrs again

25-::

  1c+2cnrs turn RH & 1c take LH in centre | 1c &frac12; Spoke to 4cnrs | 1c+4cnrs turn RH to sides (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (13808, '2021-03-11 17:02:52.437432+00', '2021-03-13 14:03:52.69896+00', 20255, 1, 202, 'ace', '1--::
  1c set | 1W dances down and faces 3W _while{2}_ 1M casts off to behind 1W (2c up) ; ½ Reel3 on 1diag in tandem (with lead change), 1W leading RSh to 3W. 1M leading faces 2W
9--::
  ½ Reel3 on 2diag in tandem (with lead change), 1M leading RSh to 2W. 1c in 2plx centre face P ; 1c turn P RH ¾ into facing lines3 across. 1M between 3c on top faces down
17--::
  3C S&Link (to 3,1x,2) ; all set | cross LH (3x,1,2x)
25--::
  Diagonal R&L (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (10511, '2018-03-14 14:23:29.795902+00', '2018-03-15 23:19:19.197171+00', 18261, 1, 202, 'ace', '1--::

  1c+3c set advancing to midline with P on R | turn RH ½ moving down and facing P on midline (2c & 4c up) ;  ½ Reel4, ending on midline 1c (1W leading) facing down, 3c (3M leading) facing up

9--::

  3c+2c & 1c+5c Rsh tandem Reels3 across, ending 3c in 2pl centre  facing down with 2W on 2M''s R & 1c in 4pl centre facing up with 1W on 1M''s L

17--::

  3c+4W+1c+4M Circle6 and back

25--::

  3c & 1c set | change places RH with person opposite, all face clw ;  1c (1M leading) cast R to 3pl _while{4}_ 3c (3W leading) cast L to 5pl (4c & 5c up) (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (10698, '2018-04-26 21:17:08.207531+00', '2018-04-26 21:22:48.877857+00', 13805, 1, 202, 'ace', '1--::

  1c set | turn RH | cast _while{2}_ 2c dance up to 1 pl and face out (2,1,3)

9--::

  Reels3 on opposite sides, 1c start Lsh to 1cnrs (2,1x,3)

17--::

  1c set | turn RH | cast down to 3pl _while{2}_ 3c dance up to 2pl and face out and down (2,3,1x)

25--::

  Mirror Reels3 on own sides, 1c start crossing up to 2pl (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11259, '2018-10-09 14:07:20.71226+00', '2022-04-25 20:14:43.531325+00', 18926, 1, 202, 'ace', '1--::

  1c+2c Poussette (1,2)

9--::

  2C Knot (2,1)

17--::

  2C Bourrel. On [23-24] all turn P RH into promhold facing up (1,2)

25--::

  2C Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (10514, '2018-03-16 08:33:00.328721+00', '2018-03-16 08:40:29.791904+00', 15321, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; cross LH | cast L into facing lines of 3 across

9--::

  S&Link3 (to 2x,1x,3x) ; 1c cross RH | cast R _while{4}_ 2c & 3c set | cross R, into lines of 3 across

17--::

  Reels3 across, 1c Lsh to 2cnrs to start, into facing lines of 3 across

25--::

  S&Link3 (to 2x,1x,3x) ; all set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10006, '2017-07-13 06:29:01.842746+00', '2017-07-13 06:34:07.304977+00', 14077, 1, 202, 'ace', '1--::

 1c & 2c face on side and set | change places RH ; 1c turn P LH 1 1/4

9--::

 ½ Reel4 in 1diag ; 1c turn P LH _ while{4}_  2c+3c ½ R&L

17--::

 ½ Reel4 in 2diag ; 1c turn P LH to 2plx _while{4}_ 3c+2c ½ R&L up/dn (3x,1x,2x)

25--::

 3c+1c+2c S&Link ; repeat (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8872, '2015-08-26 22:07:49.899404+00', '2017-10-11 21:48:22.606847+00', 16527, 1, NULL, 'ace', '1--::  1c+2c set | in square cast clw 2 places | cross RH (1c face out) (2,1,3)

9--::  ½ Reels3 on sides, Rsh to 3cnr, at end 1c cross to 2plx ; 1c turn 1cnr (pos) RH (3,1x,2)

17--::  ½ Reels3 on sides, Lsh to 2cnr, at end 1c cross to 2pl ; 1c turn 4cnr (pos) LH and finish BtoB facing opposite side for

25--::  All Set as in DTr | All set, 1c pivoting R to face P ; 1c turn P RH 1½ to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10515, '2018-03-16 19:04:04.656964+00', '2018-12-29 10:57:20.876585+00', 18211, 2, 2703, 'ace', '1-8:: 1c set and dance down the middle NHJ (2c step up) ; cast around 3c and turn LH 3/4 to finish in middle 1M up 1W down

9-16:: 1M+2c & 1W+3c RH across (1c finish 2pl crossed over) ; 2c+1c+3c chase CW halfway

17-24:: 1c dance 1/8 fig8 (1W down, 1M up) | 3c+1c+2c set and turn RH halfway

25-32:: 3c+1c+2c Allemande', 2);
INSERT INTO 'dancecrib' VALUES (11791, '2019-04-17 14:39:17.641081+00', '2019-07-23 17:23:39.237612+00', 19083, 1, NULL, 'ace', '1--::

  1c+2c set | RHA | 1M+2M & 1W+2W change places RH, 1M & 2W face out (2,1,3)

9--::

  Reels3 on the sides, 1c Lsh to 3c, finish 1c facing 1cnr

17--::

  1c set to 1cnr | to 2cnr, finish between cnrs ; All Advance,  1c turning BH ½ on [22], and Retire (2,1,3)

25--::

  Circle6 and back





', 3);
INSERT INTO 'dancecrib' VALUES (10008, '2017-07-13 15:26:53.068591+00', '2017-07-13 18:40:48.154101+00', 14989, 1, NULL, 'ace', '1--::

 1c+2c set | cross RH ; set | turn P BH ¾ to midline

9--::

 Reel4

17--::

 1c & 2c set | turn RH to own sides ; set | turn P BH to centre facing up

25--::

 2C Allemande (2,1) ', 2);
INSERT INTO 'dancecrib' VALUES (10421, '2018-02-07 10:53:43.629602+00', '2019-01-18 19:38:50.005543+00', 18238, 2, 1645, 'ace', '1-::
  All &frac34; turn P RH | W take LH and all BiL ; M chase &frac14; clw _while{2}_ W &frac12; LHA | all BiL
9-::
  All &frac12; turn RH | M &frac12; LHA _while{2}_ W chase &frac14; clw to (2,3,4,1) with M in centre facing out to P ; all dance BtoB with P
17-::
  M &frac34; turn P RH so W face out | M dance across passing RSh _while{2}_ W loop back to plx ; M &frac12; turn opposite W RH | repeat 19-20 to (2x,3x,4x,1x)
25-::
  All circle8 and back (2x,3x,4x,1x). *Repeat with M & W exchanging roles each time.*
', 3);
INSERT INTO 'dancecrib' VALUES (11543, '2019-01-26 05:43:14.042735+00', '2019-01-26 05:43:14.042735+00', 10953, 1, NULL, 'ace', '1--::

  1W+2M turn RH ; chase clw to exchanged places

9--::

  1M+2W repeat (2x,1x)

17--::

  Circle4 and back

25--::

  2c ½ Fig8 round 1c ; 1c ½ Fig8 round 2c (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10674, '2018-04-22 00:21:12.008829+00', '2021-08-02 09:38:24.34169+00', 5438, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

  2c+3c RHA ; 1c+2c & 3c+4c LHA (1,2,3x,4x)

9--::

  1c(4c) NHJ with P dance dn(up) to between nearest cpls into facing lines of 4 across | all set ; 4M+1W & 1M+4W lead out between nearest cpls, cross and cast to sidelines (4x,2,3x,1)

17--::

   4c & 1c cross RH | cast inwards (2c+3c step out), finishing facing dn/up (to 2,4,1x,3x) ; 4c+1c turn RH on sidelines

25--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (12784, '2020-04-29 00:39:38.356397+00', '2020-04-29 00:43:01.713472+00', 19438, 1, 202, 'ace', '1--::

  1M+2W cross RH | chase clw one place _while{4}_ 1W+2M set | turn RH ¾ (to 1W,1M on Mside, 2W,2M on Wside) ; 1c ½ Fig8 across round 2c back to exchanged places on Mside

9--::

  La-Chain into promhold on sides

17--::

  The Tournée, dancing LSh to midline on [17] (1,2)

25--::

  1c+2c set | ½ RHA ; turn P RH ½, face P and cast away (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (1969, '2012-01-22 19:29:12.571175+00', '2015-04-01 21:54:53.171623+00', 12736, 1, NULL, 'ace', '1–::

  1W casts off behind own line and up the middle _while_{8} 1M dances down the middle and up behind own line to join P at the top in the middle (2c step in) for.

9–::

  1c+2c allemande, at the end 1c face down.

17–::

  2c+1c+3c Reels3 in the sidelines, 1c start in and down.  !C finish facing 1cnr as 2c + 3c curve into place.

25–::

  1c set to 1cnr finishing in sideline (as in HG setting) | turn partner RH ¾ to face 2cnr ; . repeat with 2cnr, finishing (2,1,3) 1c finishes in 2nd place own side.

33–::

  All Circle6 and back.', 2);
INSERT INTO 'dancecrib' VALUES (2167, '2012-01-22 19:29:23.540481+00', '2018-10-09 14:06:55.670441+00', 12794, 1, NULL, 'ace', '1–::

  All set | 1c cast _while{2}_ 2c dance to 1pl and face out _while{2}_ 3c touch NH and face out ; 2c+1c+3c ½Reel3 on the sides, 1c starting down and in (3,1,2)

9–::

  1c petronella to between end couples | All set in lines across ; ½Diag R&L to the R (with 3W & 2M) (3M+2W stand, facing across)

17–::

  1c petronella to own sideline, all set in lines facing across ; ½Diag R&L to the R (with 3M & 2W) (2x,1x,3x)

25–::

  All set and turn P RH ; All chase clw halfway, to own side (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (11544, '2019-01-26 06:08:09.677355+00', '2019-01-26 06:08:09.677355+00', 18719, 1, NULL, 'ace', '*Start (1,2,3x,4x)*   

1--::

  1c+2c & 3c+4c S&Link ; Circle4 L (2,1,4x,3x)

9--::

  1c+4c Circle4 R and face other cpl ; S&Link with P (2,1x,4,3x)

17--::

  2c+1c % 4c+3c La-Chain (2,1x,4,3x)

25--::

  1c+4c Espagnole, 1M & 4W crossing to begin (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (8878, '2015-08-26 22:15:34.535234+00', '2021-08-10 18:43:07.092987+00', 16537, 1, 1041, 'ace', '1--::  1c set | dance down (2c up) ; cast up round 3c | set advancing to face 1cnr

9--::  1c turn 1cnr RH, pass Rsh; turn 2cns RH, pass Rsh to face out in 2pl (cnrs dance for {4}) (2,1,3) 

17--::  [3C Chain Progression] 1c cast ¼ clw round set _while_ 2c & 3c Turn RH ¾ | 2M+3W turn LH 1½ _while{4}_ the others promenade clw ½ round set | 3c+2c turn RH ¾ _while_ 1c dance clw to 2pl  (3,1,2)

25--::  all chase ½ way clw ; set | cross RH (2,1,3)



*3C Chain Progression was earlier known as Chaperoned Chain Progression*

', 3);
INSERT INTO 'dancecrib' VALUES (9813, '2017-04-25 23:38:23.659862+00', '2020-12-26 10:01:01.724288+00', 14038, 1, 202, 'ace', '1-- ::

 1c set | cross RH ; cast (2c up) | turn LH to face 1cnrs

9-- ::

 1c+1cnrs change places RH | 1c set _while_ 1cnrs change places LH ; 1W+3W & 1M+2M change places RH | 3W&2M set _while_ 1c turn LH 1 ¼ to face 2cnrs

17-- ::

 1c+2cnrs repeat [9-16], 1c finishing facing 3cnrs (pos)

25-- ::

 1c+3W+2M ½ diagonal Reel4, 1c passing Lsh to face 4cnrs (pos) ; 1c+2W+3M  ½ diagonal Reel4 (2,1,3)

33-- ::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (15283, '2022-12-07 23:33:03.240489+00', '2023-02-17 21:30:09.74586+00', 15145, 1, 1645, 'ace', '{{explanation}}
Strathspey

1--::
  1c+2c &frac12; turn RH | &frac12; RHA ; 1c+3c &frac12; turn LH | &frac12; LHA (2,3,1)
9--::
  2c+3c+1c S&Link3 twice (1x,3x,2x)

{{explanation}}
Reel

17--::
  1c set | &frac12; turn RH ; lead down below 2c (3c up) | cast up round 2c to face 1cnr pos
25--::
  1c+1cnrs &frac12; RSh Reel4 on 1diag, pass RSh ; repeat with 2cnrs & pass RSh to own side (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (13790, '2021-03-05 23:33:33.441666+00', '2021-08-10 18:45:45.092846+00', 19119, 1, 202, 'ace', '1--::

  1c+2c set | 1c & 2c turn P BH ½ opening to face 1c down, 2c up ; 1c & 2c NHJ set advancing passing LSh into BtoB position |  turn P BH ½ to sides. 1c face out (2,1,3)

9--::

  Reels3 on sides, 1c RSh to 3cnrs {6} | 2c+1c change places EH (1,2,3)

17--::

  1c Petronella Turn | set ;  turn P RH 1¼ to sides (1,2,3)

25--::

  3C Slip Knot (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10666, '2018-04-21 11:20:04.742187+00', '2018-04-26 22:40:14.345951+00', 1264, 1, 202, 'ace', '1--::

  1c followed by 2c lead down to 3pl _while{4}_ 3c dance up to 1pl (to 3,2 in centre,1) ; 3c+2c+1c ½ Reels3 on sidelines, 1c start out and up (1,2,3)

9--::

  1c+2c ½ RHA | cross RH ; turn P RH (2,1,3)

17--::

  All set | dance BtoB | set

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2220, '2012-01-22 19:29:26.443722+00', '2018-10-09 14:08:30.570302+00', 12638, 1, NULL, 'ace', '{{explanation}}

Start in diamond formation: M facing M on the sides with their P to their R on the midline.



{{title}}

Strathspey:



1–::

  All petronella to the opposite position

9–::

  ½ RHA | set ; ½ LHA | the M cast ¼ clw round the set _while{2}_ the W continue LH turn, all finish in line of 4 on midline facing P

17–::

  Set to P Highland Schottische

25–::

  Reel4 on midline, On [30-32] the W curve R to the sideline, the M finish on the midline, ending in the diamond shape, all progressed one place cclw from the start.



{{title}}

Reel:



33-64::

  Repeat [1-32], now forming a line across [16]. On [17-24], set using PdB/coupé.', 3);
INSERT INTO 'dancecrib' VALUES (2381, '2012-01-22 19:29:34.553242+00', '2018-10-09 14:14:05.192694+00', 14200, 1, NULL, 'ace', '1–::

  1c+3c turn RH | cast off one (2c+4c up) ; turn LH to face 1cnrs

9–::

  1c+3c ½Reel4 with 1cnrs (pass P Lsh) ; Repeat with 2cnrs

17–::

  Repeat with 3cnrs (1cnr person) ; Repeat with 4cnrs (2cnr person)

25–::

  1c+3c (in 2pl and 4pl) ½ diagonal R&L with their 1 cnrs (positions) ; repeat with 2cnrs (2,1,4,3,5)

33–::

  3c long cast up to 2pl _while{4}_ 1c dance down to 5pl (5c up) ; All turn RH (2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (11545, '2019-01-26 07:20:38.811737+00', '2019-07-24 11:21:09.04379+00', 15512, 1, NULL, 'ace', '1--::

  1c cast behind own lines and (turn outward) back _while{8}_ 2c lead down the middle and back (1,2,3)

9--::

  1c cross down into mirror Reels3 on opposite sides (1x,2,3)

17--::

  1c cross back into mirror Reels3 on own sides (1,2,3)

25--::

  1c cross RH | cast (2c up) ; 1c set | cross RH and face out (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (15097, '2022-09-13 10:42:01.666243+00', '2022-09-13 10:42:16.877557+00', 19668, 1, 1645, 'ace', '1--::

  All dance fwd R{1}, pulling back LSh to pass BtoB with P, M/W facing up/down, then dance fwd L{1}, pulling back RSh to end on opp sides | all set ; all repeat [1-4] to own sides

9--::

  All dance 3C Knot & end facing cclw (3,2,1)

17--::

  All dance &frac12; way cclw (1x,2x,3x) ; all set | cross RH & 2c face out (1,2,3)

25--::

  1c+2c &frac12; turn on sides (M RH, W LH) | 2c turn BH & face down _while{2}_ 1c+3c &frac12; turn on sides (M LH, W RH) & 3c face up NHJ ; 2c+3c Circle4 to L (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (8154, '2014-01-15 10:38:28.747578+00', '2019-08-07 17:29:40.013782+00', 14989, 2, 1358, 'ace', '1-8::   1s+2s Set & Cross RH, Set & 3/4 Turn Both Hands to face each other in the middle (Man facing down, ladies facing up).



9-16:: 1s+2s dance reel of 4 in the middle



17-24::  1s+2s Set to each other in the middle & turn RH to the own Side, Set & 3/4 Turn Both Hands in the middle (facing up), ready for...



25-32::  1s+2s dance Allemande.', 0);
INSERT INTO 'dancecrib' VALUES (10426, '2018-02-13 14:05:32.795542+00', '2018-03-18 15:07:26.082979+00', 17469, 1, 202, 'ace', '1--::
  1c+2c+3c »modified S&Link3« [All set | 1c & 3c link as in S&Link3 _while{2}_ 2c Petronella turn to between 1c or 3c] ; 2W+1M & 3W+2M ½ R&L
9--::
  All »modified S&Link3« ; 1M+2W & 2M+3W ½ R&L, 3W & 1M facing out (3x,2x,1x)
17--::
  Mirror Reels3 on sideline, 2c (then all cpls in 2plx) crossing down, 3c start out and down, 1c out and up (3,2,1)
25--::
  2c+1c »Rose Progression« [2W+1M change place RH | chase 1 place clw ; turn BH ½, face and cast away _while{8}_ 2M+1W set | turn BH ½, face and cast away | chase 1 place clw] (3,1,2)', 4);
INSERT INTO 'dancecrib' VALUES (10518, '2018-03-18 23:21:32.782837+00', '2018-03-18 23:21:32.782837+00', 7039, 1, NULL, 'ace', '1--::

  1M+2W A&R (1+1) | turn RH 1½ and cast clw round the other dancers to own place

9--::

  1W+2M A&R (1+1) | turn LH 1½ and cast cclw round the other dancers to own place

17--::

  1M+2W change places RH | 1W+2M repeat RH ; 1M+3M repeat LH | 1W+3W repeat LH (2x,3x,1)

25--::

  3c+1c ½ R&L ; 2c+1c cross RH and set. (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10874, '2018-07-04 15:28:39.79985+00', '2018-07-04 15:28:39.79985+00', 6028, 1, NULL, 'ace', '1-::

  1c cross RH | cast off (2c up) ; 2c cross RH | cast off _while{4}_ 1c set | lead up &amp; cross retaining RH (1,2x)

9-::

  1c turn RH | cast off ; turn LH moving up (1,2x)

17-::

  1c set | lead down &amp; cross below 2pl ; 1c cast up to 1pl _while_ 2c set | 1c &amp; 2c cross retaining RH ready for

25-::

  1c+2c Allemande (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (3026, '2012-01-22 19:30:07.404065+00', '2021-03-26 22:42:09.420646+00', 7490, 1, NULL, 'ace', '{{explanation}}

1c, 3c etc are dancing couples. (this is written for a 5C set, but can be danced with a set of any odd number of couples)



1–::

  Dancing couples cross down RH (2c+4c up), cast off one ; cross LH, and cast up to face 1cnrs

9–::

  All dancing C turn 1cnr RH ; repeat LH with 2cnr, 1c passing P Lsh into

17–::

  Teapots (RHA) (3HA at top and bottom ; 4HA in the middle(s)) ; dancing couples LH turn and cast off one (4c+5c up)

25–::

  All Circle (10H or more) and back (all dancing C now 2 places lower, the others having moved up)', 2);
INSERT INTO 'dancecrib' VALUES (12191, '2019-09-08 23:31:14.042842+00', '2019-09-08 23:31:14.042842+00', 19636, 1, NULL, 'ace', '1--::

  1c+3c lead down and up (1,2,3,4,5)

9--::

  1c+2c  & 3c+4c+5c progressive promenades, at the end the lead couples cast off one (2,1,4,3,5)

17--::

   1c+3c pass Rsh | turn 1cnr RH ; pass P Rsh | turn 2cnr RH to (2,1x,4,3x,5)

25--::

  2c+1M & 1W+4c+3M & 3W+5c RHA ; 1c+3c cross RH and cast off (4c+5c up) (2,4,1,5,3)

', 3);
INSERT INTO 'dancecrib' VALUES (13809, '2021-03-11 19:42:22.968529+00', '2021-03-11 19:51:26.233065+00', 2491, 1, 202, 'ace', '1--::
  1c & 4c cross RH | 1c+2c & 3c+4c ½ DblFig8, 1c & 4c casting | 2c & 3c cross RH (1,2,3,4)
9--::
  1c+2c & 3c+4c RHA. 2c & 3c are BtoB on sides ; ½ Parallel Reels4 on sides (4,3,2,1)
17--::
  4c+3c+2c Diagonal R&L (2x,3,4x,1)
25--::
  2c & 4c set | turn P RH ½ and face down ; 2c & 4c lead down between next couple and cast up 1 place (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (14455, '2021-11-17 12:41:40.135981+00', '2021-11-17 12:41:59.744809+00', 828, 1, 1645, 'ace', '1-::

  1c+2W & 4c+3M diag Reels3{6}, 1W & 4M start passing P RSh | 1W & 4M return to place

9-::

  1c+2M & 4c+3W diag Reels3{6}, 1M+2M & 4W+3W start passing RSh | 1M & 4W return to place

17-::

  1c & 4c set | cast inwards (2c & 3c out) ; 1c+4c &frac12; RHA | &frac12; turn P RH (2,4,1,3)

25-::

  2c+4c & 1c+3c R&L (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10517, '2018-03-17 11:47:29.687461+00', '2018-03-17 21:51:20.881803+00', 18256, 1, 202, 'ace', '1--::
  All set | 1c+2c & 3c+4c chase clw ¼ (1W,2M,3W & 4M casting) ; 1c+2c & 3c+4c RHA, all finishing facing P on sidelines
9--::
  All set, middles passing back Lsh to face each other on sidelines | top and bottom pairs on M & W sides ½ »Rsh Turn« [Pass Rsh with middles casting to exchanged places] ; repeat [9-12] (to 4W,4M,2W,2M on M side and 3W,3M,1W,1M on W side)
17--::
  All turn P BH | 3c+4c & 1c+2c Circle4 L ½ ; Circle8 L ¼ | all set (to 1M,1W,2W,2M on M side and 3W,3M,4M,4W on W side)
25--::
  1M+3W+4M+2W & 1W+3M+4W+2M »Wedding Chase« [All chase clw, cpls NHJ when crossing the set]
33--::
  1c+3c & 2c+4c ½ RHA, all finishing facing P on sidelines | 1c & 4c ½ »Rsh Turn«  _while{2}_ A&R{1+1} to P ; 3c+1c & 4c+2c chase clw ¼, (3M,1W,2W & 4M casting) | all cross RH (3,1,4,2)

*Note:*

»Rsh Turn« (Right Shoulder Turn) is also known as Gypsy Turn, a term now considered offensive by some.', 5);
INSERT INTO 'dancecrib' VALUES (10519, '2018-03-19 04:39:34.599479+00', '2018-03-19 04:43:14.310683+00', 2558, 1, 202, 'ace', '1-- ::
  All M dance round P Rsh to places | all set
9-- ::
  All W repeat [1-8]
17-- ::
  1c+2c Petronella turn into midline | set ; turn P RH ¾ | ½ RHA (2,1,3)
25-- ::
  Circle6 and back

*Deviser''s note:*

At the end of bar 64 (the end of the second time through) first couple finish in third place.  
On bars 65-66 the original first couple move down while fourth woman moves up and fourth man dances diagonally up to pass his partner by right shoulder.', 2);
INSERT INTO 'dancecrib' VALUES (10520, '2018-03-19 12:32:20.790111+00', '2018-03-19 14:39:58.882065+00', 7825, 1, 202, 'ace', '1--::

  1c+2c set | 6 bars of DblFig8, 1c cross down to start, 1c face out at end (2x,1,3)

9--::

  Mirror Reels3 on sidelines, 1c out and down to start, finish RHJ in centre facing down (2x,1,3)

17--::

  1c cross down and cast up round 3c to 2plx ; 2c+1c ½ R&L (with polite turn) ready for (1,2,3)

25--::

  1c+2c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14457, '2021-11-18 06:13:12.693486+00', '2021-11-18 06:15:32.190737+00', 16729, 1, 202, 'ace', '1--::

  1c+2c Circle4 L, finish NHJ 1c facing down, 2c facing up ; set. On [6] 1c turn inwards | 1c cast to 2pl _while{2}_ 2c dance to top and cast to 1pl facing down (2,1,3)

9--::

  1c turn P RH 1¼ ; 1c dance LSh round 3cnrs[pos] and face 4cnrs[pos] _while{8}_ 2c+3c dance L&R starting on sides (2,1,3)

17--::

  Reels3 on sides, 1c RSh to 4cnrs (2,1,3)

25--::

  1c+3c The Tournée (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3606, '2012-07-21 11:45:44.938896+00', '2018-10-09 14:15:16.217097+00', 14368, 1, NULL, 'ace', '1–::

  1c dance down between 3c, cast up ; cross up LH and cast off (2c up) to (2,1x,3)

9–::

  ½ diag R&L, 1c going R, finish on own side facing 3cnr pos. ; Lsh ½ Reels3 on the sides, 2c+3c finish with loops

17–::

  ½ diag R&L, 1c going R, finish on opposite side facing 1cnr pos. ; Lsh ½ Reels3 on the sides, 2c+3c making loops to face up/down (2x,1x,3x)

25–::

  1c cross RH _while{2}_ 2c+3c change places on side RH | All chase ¼ clw ; 1c cross up/down RH _while{2}_ 2c+3c cross RH | All chase ¼ clw (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11792, '2019-04-17 15:09:05.790464+00', '2019-04-17 15:26:46.809859+00', 19081, 1, NULL, 'ace', '1--::

  1c+2c set | cast one place clw in square ; Circle4 L 

9--::

  1c facing 2c change places RH | chase 1 place clw ; 1c turn 3c LH on the side (2,1,3)

17--::

  Parallel Reels3 on the sides, 1c Rsh to 2c (2,1,3)

25--::

  1c dance up between 2c and cast off ; turn BH and open to face down NHJ | turn 3c ½ EH (2,3,1)





', 3);
INSERT INTO 'dancecrib' VALUES (10128, '2017-09-15 07:36:57.44216+00', '2017-09-16 11:05:44.790036+00', 4192, 2, NULL, 'ace', '*Note: in this dance, whenever dancers advance and retire they join RH for an instant before retiring; unless noted otherwise, all advance & retire movements each use 2 steps.*

1-8::

  1L & 3M advance & retire diagonally, then dance halfway anticlockwise round set to swap places as 1M & 3L adv. & retire diagonally

9-16::

   @#1s 2s & 3s all advance & retire, 2s across set, 1s & 3s on sides; then 2s dance halfway anticlockwise round set to change places WHILE 1s & 3s advance diagonally, retiring on next diagonal to L (¼ clockwise - ends 1, 2, 3 all on opp. sides)

17-24::

  2s advance & retire 1 step each, retiring ¼  clockwise (i.e. M down and L up in centre) WHILE 1s & 3s dance ¼ anticlockwise to next of their 4 current places; then 2s & the others swap roles to regain their Bar 17 places, i.e. 2s dance ¼ anti-clockwise, 1s & 3s advance & retire on next diagonal to L (1 step each). Then 1s cross RH to own sides & cast down to 3rd place WHILE 2s & 3s ½ turn RH to end facing up RHJ, dance up 1 place to end 2, 3, 1 own sides

25-32::

  3s & 1s advance & retire on next diagonal to L (1 step each), and repeat (order now 2 1x 3x); 1s & 3s with partners advance & retire (1 step each), then advance 1 step quickly turning ½ RH and retire to own sides

', 3);
INSERT INTO 'dancecrib' VALUES (12208, '2019-09-14 09:16:38.203102+00', '2019-09-14 09:23:06.93673+00', 1571, 1, 202, 'ace', '1--::

  1c set | cross RH ; cast (2c up) | turn LH to face 1cnrs

9--::

  ½ Reel4 on 1diag, pass LSh ; ½ Reel4 on 2diag, pass LSh to face 3cnrs[pos]

17--::

  Turn Corners (on opposite sides) and Partner. 1c face 3cnrs[pos]

25--::

  ½ Reel3 {3} on sides, 1c LSh to 3cnrs[pos], ½ Reel3 {3} across, 1c LSh to 1cnrs[pos] | 1c cross RH ', 2);
INSERT INTO 'dancecrib' VALUES (3798, '2013-07-13 15:56:08.720149+00', '2021-06-08 20:49:24.260503+00', 9528, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; turn LH to face 1cnr

9–::

  SetH&G, finish 1W with 1M behind, facing 3W

17–::

  ½ Lead-change Reel3 on 1diag, at end 1M+1W behind faces 2W ; repeat on 2diag and face 1M position

25–::

  Repeat ½ lead-change reels on 1diag ; on 2diag, 1c finish NHJ in 2pl facing up

33–::

  1c mirror figs8 on own side (give hands) _while{8}_ 2c+3c R&L, starting along sidelines (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10677, '2018-04-22 11:13:34.247397+00', '2021-08-02 10:04:27.630881+00', 9418, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; 2c+1c+3c set | 2c (1c & 3c following) cast behind own lines (to 3,1,2)

9--::

  Reel4 on 1diag, 1c pass Lsh to start, pass P Lsh to face 2cnrs

17--::

  Reel4 on 2diag, 1c turn P LH into facing lines of 3 across, W between top cpl

25--::

  Reels3 {6} across, 1c start Lsh to 1cnrs position (to 3,1,2) | all turn P RH into Allemande hold

33--::

  3C Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10875, '2018-07-04 15:30:15.932876+00', '2018-07-04 15:30:15.932876+00', 4445, 1, NULL, 'ace', '1-::

  1c+2c &frac12; R&amp;L ; set | cross RH (2,1)

9-::

  2c+1c+3c two hands of GrChain, 2c cross to start (3,2x,1x) ; 3c set | cross RH _while{4}_ 2c+1c set | change pl M RH, W LH (3x,1x,2x)

17-::

  3c+1c+2c &frac12; mirror Reels3, 1c start in and up ; 1c turn RH _while{4}_ 2c &amp; 3c stand | turn RH &amp; all form a circle

25-::

  Circle6 &frac34; to L &amp; drop hands ; chase &frac14; clw (2x,1x,3x) | cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12154, '2019-09-03 09:27:07.771078+00', '2019-09-03 09:39:05.862201+00', 19610, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; turn P RH 1¼ into lines3 across, 1c facing 2cnrs

9--::

  Reels3 across, 1c RSh to 2cnrs

17--::

  1c turn 2cnrs RH | turn P LH ; turn 1cnrs RH | turn P LH to 2pl facing out (2,1,3)

25--::

  1c dance LSh round 4cnrs, change places up/down LH and dance LSh round 3cnrs to 2pl _while{8}_ 2c+3c cross RH | set and face on sides ; change places RH on sides | set and face P (3x,1,2x)

33--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1840, '2012-01-22 19:29:05.231936+00', '2018-04-26 22:43:56.47619+00', 816, 1, NULL, 'ace', '1-16::

  1c facing 2c and 4c facing 5c Rsh Reels4 on the sides around 3c {12} ; same C''s facing turn RH _while_{4} 3c turn LH 1 1/3  into

17–::

  3W+1M+2M & 3M+4W+5W RHA, 3c pass P Rsh ; 3W+4M+5M & 3M+1W+2W LHA, 3c pass Lsh to 3pl facing out (1,2,3,4,5)

25–::

  1M+2M & 4W+5W A&R _while_{4} 3c cast R around them, 3c pass P Rsh ; 1W+2W & 4M+5M A&R _while_{4} 3c dance to end of set and cast R to 3pl.

33–::

  All Circle10 and back

41–::

  1c set advancing and lead down to bottom _while_{4} 2c+3c+4c+5c set and cast up 1 place ; All turn RH. (2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (11546, '2019-01-26 07:35:47.253196+00', '2019-01-26 17:26:27.895885+00', 6582, 1, NULL, 'ace', '*"Variation".  Three dancers in line*

1--::

  Centre dancer Rsh Fig8 round partners

9--::

  Reel3, centre starts Rsh

17--::

  Centre turns P on R ; turns P on L 1½

25--::

  Partners chase ½ cclw to change sides ; Partners A&R to each other as Centre R&A.

', 3);
INSERT INTO 'dancecrib' VALUES (11013, '2018-08-19 16:23:38.546316+00', '2018-08-19 16:31:02.301888+00', 1637, 1, 202, 'ace', '1--::

  1c+2c RHA{3}, LHA{3} and cast to 2pl (2c dance up) (2,1,3)

9--::

  Mirror Reels3 on sidelines, 1c in and down. On [15-16], 1c face 1cnrs, 2c and 3c loop to places (2,*1*,3)

17--::

  SetH&G. On last PdB, 1c travel, turn to 2pl (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (14609, '2022-02-16 08:21:01.952305+00', '2022-02-21 15:59:19.12029+00', 20318, 1, 202, 'ace', '1--::
  1c cross down into DblTr position (2c up) | all set as in DBlTr ; 1c turn 2cnrs LH and face 1cnrs
9--::
  Set to and turn Corners (2,1x,3)
17--::
  Reels3{6} on sides, 1c LSh to 1cnrs | 1c cross RH to 2pl and face out (2,1,3)
25--::
  1c dance RSh round 3cnrs to centre, meet P and pull RSh back. 1M faces up, 1W faces down ; 2c+1M & 1W+3c RHA
33--::
  Circle6 and back (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (9777, '2017-04-08 00:09:57.698076+00', '2022-09-26 22:53:32.702627+00', 15277, 1, 202, 'ace', '1-- ::

 1c+2c progressive DblFig8 (1c cross, cast ; cross up, cast _while{8}_ 2c set, cross up ; cast, cross up) (2,1,3)

9-- ::

  1c set | turn RH ¾ ; LHA to sidelines (2,1x,3)

17-- ::

 1c set | turn RH ¾ ; LHA to sidelines (2,1,3)

25-- ::

 1c+3c Bourrel (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2380, '2012-01-22 19:29:34.49591+00', '2020-07-14 20:24:13.429274+00', 9332, 1, NULL, 'ace', '1–::

  1c+3c R&L, after last pass finish BtoB with P, facing cnrs.

9–::

  2c (promhold) with 3W+1M and 4c (promhold) with 1W+3M Lsh Reels3 (lengthwise)

17-32::

  2c+4c repeat 16 bars, across

33–::

  All C set to P, half turn RH ; all W LHA in middle

41–::

  All W pass P Lsh and chase left, loop Lsh round next M, to finish in opposite M''s place

49–::

  All »mixed pairs« set, half RH turn, all M LHA in the middle

57–::

  All M pass the same W Lsh and chase left, loop Lsh round next W, to finish in opposite M''s place

65–::

  1c+3c full Turn RH (no hands) with person opposite, both M with W following lead out between side couple and cast right to own place

73–::

  2c+4c repeat

81–::

  Circle8 and back

', 2);
INSERT INTO 'dancecrib' VALUES (8673, '2015-02-17 11:50:36.441267+00', '2020-03-05 14:22:22.938802+00', 8578, 2, 1, 'ace', '1–4::

  1L+2M turn RH _while_ 1M+2L chase clockwise to each other''s pl

5–8::

  1L+2M chase clockwise to each others pl _while_ 1M+2L turn RH [to 2x1x]

9–16::

  1c+2c circle4 round and back

17–20::

  1c+2c chase ½ acw to orig pls

21–24::

  1L+2L, 1M+2M turn LH 1½

25–32::

  2c+1c+3c dance parallel reels of 3 on sides (1c give RS to 3c to start)', 3);
INSERT INTO 'dancecrib' VALUES (10876, '2018-07-04 15:31:56.248971+00', '2018-07-04 15:31:56.248971+00', 4594, 1, NULL, 'ace', '1-::

  1c cast off (2c up) | cross RSh to DTr position facing opp side ; all set as in DTr | 1c turn RH in PdB to the sides _while_ 2c &amp; 3c set (2,1,3)

9-::

  1c cast M down, W up | dance up/down touching LH | cast M down, W up &amp; pass LSh to end BtoB in centre facing opp side (2,1x,3)

17-::

  All set as in DTr (without taking hands) |

  2M+1W+3M &amp; 2W+1M+3W &frac12; RHA ; all set as inverted DTr (taking hands) |

  3c &amp; 2c dance R round P to opp sides _while_ 1c set adv passing RSh to end BtoB in centre facing own side (3x,1,2x)

25-::

  All repeat [17-24] from new places but with &frac12; LHA on [27-28] and on [31-32] 1c set to P on the sides (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10683, '2018-04-23 16:53:26.809958+00', '2018-04-23 16:53:26.809958+00', 1751, 1, NULL, 'ace', '1-::

  1c set | cross RH ; cast off (2c up) | turn LH to face 1cnrs

9-::

  Turn CPCP, 1c end facing out (2,1,3)

17-::

  1c cast L, cross, cast L to 2pl _while{4}_ 2c &amp; 3c set | cross RH (2x,1x,3x) ;  &frac12; RSh Reels3 on sides (1M up, 1W down)

25-::

  &frac12; RSh Reels3 across (1M down, 1W up ) ; 1c turn LH 1&frac34; _while{4}_ 2c+3c turn RH 1&frac12; on sides (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10170, '2017-10-12 16:15:41.342551+00', '2018-11-27 16:19:36.04009+00', 17314, 1, 202, 'ace', '

1-4::

    1c cast | set advancing, pivoting R ½ to end in DTr[pos] (2c up on [3-4])

5-12::

    2c+1c+3c DTr. 1c in 2 pl face out (2,1,3)

13-20::

    Parallel Reels3, 1c RSh to 3cnrs into lines3 across, 1W(1M) between 2c(3c) facing down(up)

21-28::

    Reels3 across, 1c RSh to 1cnrs into lines3 across

29-32::

    1c turn P RH 1 ¼ (2,1,3)   



*The surprising phrasing illustrates how stooges must be able to adapt*', 4);
INSERT INTO 'dancecrib' VALUES (10877, '2018-07-04 15:34:24.145737+00', '2018-07-04 15:34:24.145737+00', 1488, 1, NULL, 'ace', '1-::

  1c petronella | set (2c up) ; petronella | turn R about &amp; cast round 1cnr tapping them on RSh

9-::

  1c pass LSh | cast round 2cnrs tapping them on RSh _while{4}_ 1cnrs follow 1c &amp; start turning LH ;

  1c pass LSh &amp; 1M dances down, 1W up  &amp; start dancing R round cnrs _while{4}_ 1cnrs complete LH turn | stand _while{4}_ 2cnr turn R about, follow 1c &amp; turn LH to centre 2W facing up, 3M down

17-::

  Corners petronella | set ; petronella | turn R about _while{8}_ 1c chase &frac14; clw | change pl diagonally RSh ; chase clw to 2pl

25-::

  All Circle6 L to (2x,1,3x) ; 1c turn RH _while{4}_ 2c &amp; 3c cross RH | stand (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11547, '2019-01-26 17:12:43.313591+00', '2019-01-26 17:25:26.692841+00', 6582, 2, NULL, 'ace', '*"Original Version". Three dancers in line, A facing B and C*

1--::

  A Rsh Fig8 round B and C (A,B,C)

9--::

  C Lsh Fig8 round B and A (A,B,C)

17--::

  A+B turn RH ; B+C turn LH 1½ (A,C,B)

25--::

  A+B chase half round cclw, now A faces B and C faces across ; A+B A&R _while_  C R&A (B,C,A)

', 3);
INSERT INTO 'dancecrib' VALUES (10687, '2018-04-23 23:43:56.988649+00', '2018-12-22 23:25:43.809004+00', 18288, 1, NULL, 'ace', '1-::

  1c turn BH | dance down NHJ, out through side cpls ; cast up own side to face P | turn BH & open out

9-::

  All S&Link to face P ; &frac12; interlocking Reels4{3} & &frac12; turn P LH

17-::

  Bourrel-like sequence: set adv passing P LSh | &frac12; turn next person BH & twirl away ; set adv passing LSh | turn P RH ending with W facing out (1,2,3)

25-::

  Triangular Schiehallion (clover leaf) reels to (3,1,2)', 5);
INSERT INTO 'dancecrib' VALUES (3608, '2012-07-21 11:45:46.173126+00', '2020-12-08 22:52:15.190686+00', 3631, 1, NULL, 'ace', '1–::

  1c cross RH, 1c face 2c and set ; 1M+2W turn 1¼ LH _while{2}_ 1W+2M turn ¾ LH | BiL across

9–::

  1M+2W turn ¾ LH _while{2}_ 1W+2M turn 1¼ LH | 1c set to 2c ; 1c cross back to places RH | set

17–::

  1c down the middle and up

25–::

  1c+2c Allemande', 2);
INSERT INTO 'dancecrib' VALUES (10679, '2018-04-22 19:50:24.360408+00', '2018-04-23 13:42:14.841672+00', 18286, 1, 202, 'ace', '1--::
  1W & 3 W followed by P cast off 2 places, cross below 3c/5c to opposite side (2c & 4c up) ; cast up 1 place, cross round 3M/5M to 2pl/4pl, 2W & 4W facing out at end (2,1,4,3,5)
9--::
  1c+4c &3c+5c RHA ; 2c+1c & 4c+3c LHA, 1c & 3c facing 1cnrs at end
17--::
  »Corner Pass and Allemande Right« on 1diag [Turn replaced by Allemande Right] ; repeat on 2diag (2,1,4,3,5)
25--::
  1c & 3c set | cast (4c & 5c up), 3c NHJ facing up at end ; 2c+4c &1c+5c Circle4 L _while{4}_ 3c set | retire to 5pl', 2);
INSERT INTO 'dancecrib' VALUES (2691, '2012-01-22 19:29:53.277599+00', '2020-09-19 10:03:02.71105+00', 3912, 1, NULL, 'ace', '1–::

  1c followed by 2c+3c+4c cast off and lead up the middle to places

9–::

  1c lead down the middle and cast back to places

17–::

  4c lead up the middle to 1pl and cast back to places

25–::

  1c+2c & 3c+4c RHA ; clap and LHA, 1c+2c stay in middle for

33–::

  1c+2c Allemande (2,1,3,4)

41–::

  All turn RH ; turn LH

49–::

  1c dance up one pl NHJ and cast off to 1cnr (2c up) ; set to 1cnr | set to 2cnr

57–::

  Reels3{6} on the sides, Rsh to 2cnr | 1c cross to 2pl (2,1,3,4)



{{explanation}}

On the alternate turns of the dance:  

bars [1-24] are danced as described.  

On [25-32] the middle C dance RHA; LHA while top and bottom C turn RH ; LH.  

On [33-40] the middle C dance the Allemande.  

The set finishes (2,3,1,4); 1c steps to (2,3,4,1), making this a dance 8 x 64 !  

Frans Ligtmans of Eindhoven modified it to 4 x 64 times through by these two changes:  

[49-52] 1c long cast (2c+3c up) to between 3c and 4c, facing 1cnr.  

[63-64] 1c cross to 4pl (4c up) (to 2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (10680, '2018-04-23 16:47:32.653283+00', '2018-04-23 16:47:32.653283+00', 3813, 1, NULL, 'ace', '1-::

  1c turn RH ; 1c+2c RHA

9-::

  1c+2c+3c Reels3 on the sides

17-::

  1W (followed by 1M who crosses first) cast off | cross (2c up) ; cast below 3M | 1W crosses to (2,3,1)

25-::

  1M casts up | crosses ; 1W crosses | casts up (2,1x,3) ; 1c turn 1&frac12; BH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10681, '2018-04-23 16:49:06.182861+00', '2018-04-23 16:49:06.182861+00', 4432, 1, NULL, 'ace', '1-::

  1c &frac12; Fig8 down round 2c ; 1c+2c &frac12; DblFig8, 2c start by casting up (1,2x,3)

9-::

  1c set | cast off 2pl (2c+3c up) ; 1c+3c set | &frac12; RHA (2x,1x,3x)

17-::

  1c cross LH | cast L to face 4cnr ; &frac12; RSh Reels3 across, 1c end facing 1cnr

25-::

  Turn CPCP (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11014, '2018-08-19 17:12:51.899909+00', '2018-08-19 17:49:28.533479+00', 17516, 1, 202, 'ace', '1--::

  All set to P | set to cnrs ; ½ Reels4, Rsh to cnrs. On [8], all pass P LSh to places (3,4,1,2)

9--::

  1W(3W) followed by P dance out between 4c(2c) to 1pl(3pl) ; 1c & 3c turn P LH (1,4,3,2)

17--::

  2c & 4c repeat similar pattern [9-16] (1,2,3,4)

25--::

  All W dance Dbl La-Chain _while{8}_ all M dance ½ La-Chain ; chase cclw 1 place | turn new P LH into promhold

33--::

  Promenade', 2);
INSERT INTO 'dancecrib' VALUES (10682, '2018-04-23 16:50:51.968482+00', '2018-04-23 16:50:51.968482+00', 4489, 1, NULL, 'ace', '1-::

  1c cross down RH below 2c, cast off round 3c &amp; &frac12; turn LH ; cross up, cast up round 2c &amp; cross RH (1,2,3)

9-::

  1c+2c Circle4 to L ; 1c+2c set to P | turn RH, 1c end in centre facing down, 2c face out

17-::

  1c repeat [1-8] _while{8}_ 2c+3c follow path of Reels3 on sides, 2c start out &amp; up, 3c in & up (1,2,3)

25-::

  1c turn BH | cast off _while{4}_ 2c &amp; 3c turn BH twice, 2c moving up to 2pl on [27-28]; all set on sides | all turn P RH (2,1,3)

::

  *At the end of the 1st repeat, 1c may remain in the centre. On 2nd repeat 1c may cast 2pl on [27-28] while both 2c &amp; 3c move up turning BH.*

', 2);
INSERT INTO 'dancecrib' VALUES (10686, '2018-04-23 22:21:16.947349+00', '2018-04-24 03:41:57.30224+00', 13824, 1, 202, 'ace', '1--::

  1c+3c set advancing to midline with P on R | BiL ; set advancing to opposite sides facing in | set (1x,2,3x)

9--::

  1c+3c repeat [1-8] to places (1,2,3)

17--::

  1c lead down (2c up) ; and back to 2pl (2,1,3)

25--::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (10690, '2018-04-24 04:10:17.945559+00', '2018-04-24 04:14:05.241465+00', 13826, 1, 202, 'ace', '1--::

  Mirror Reels4

9--::

  1c lead down ; and up to 1pl facing out

17--::

  1c turn 2c EH ½ | turn 3c EH ½ ; turn 4c EH 1½ (2,3,4,1)

25--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (10429, '2018-02-13 18:36:19.610716+00', '2018-03-09 16:24:45.290865+00', 17473, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; turn LH ¾ into lines of 3 across, 2c facing 3c and 1c facing out the ends | all BiL

9--::

  6 bars of Reels3 across, 1c Rsh to 2cnrs to start (to 2,1,3) | 1c turn P RH ¾ into lines of 3 across

17--::

  6 bars of Reels3 across, 1c Rsh to 4 cnrs to start (to 2,1x,3) | 1c turn P LH ½ into centre facing down LHJ, 2c facing 3c

25--::

  1c lead down between 3c, cast up to 2pl ; dance up between 2c, cast off to 2pl _while{8}_ 2c+3c R&L, starting along the sides (2,1,3)  ', 2);
INSERT INTO 'dancecrib' VALUES (10689, '2018-04-24 04:00:10.136688+00', '2021-06-06 11:57:01.267122+00', 13825, 1, 202, 'ace', '1--::

  1c cast behind own sides ; turn *inwards* and dance up same way to places

9--::

  Mirror Reels3 on sidelines, 1c start in and down

17--::

  1c lead down ; and up to 1pl centre, 2c step in on [24] ready for

25--::

  Poussette', 2);
INSERT INTO 'dancecrib' VALUES (9993, '2017-07-07 20:30:51.160477+00', '2019-02-22 23:20:53.450816+00', 15299, 1, 202, 'ace', '1--::

 1M sets as 1W dances in towards P and cast R to own pl facing out | 1 W followed by P cast off two, 1W crosses below 3c and | casts up to 2M pl _while{2}_ 1M dances up the middle to 2W pl (2c up on [7-8]) and 2c face 1c (2,1x,3)

9--::

 1c ½ Fig8 up ; 1c ½ Fig8 down _while{8}_ 2c+3c R&L up/dn (2,1x,3)

17--::

 1c dance down, on [20-21] 1M crosses below 1W who passes under his R arm, dance up to 2 pl (2,1,3)

25--::

 All set | turn P RH ¾ into midline ; Petronella | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2507, '2012-01-22 19:29:45.538762+00', '2015-04-02 22:04:45.266507+00', 8837, 1, NULL, 'ace', '1–::

  1c cross down below 2c, cast below 3c (2c up) ; cross RH and cast up to 2pl and turn LH ¾ to face 3cnr for

9–::

  Opposing Reels3 across (Lsh to 3cnr), 1c finish with a fast LH turn into

17–::

  Opposing Reels3 across (Lsh to 1cnr), 1c finish with a ¾ RH turn into

25–::

  Opposing Reels3 on own side (Rsh to 4cnr) (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11793, '2019-04-18 15:46:51.920054+00', '2019-04-18 16:01:57.779747+00', 8149, 1, NULL, 'ace', '*Couples in two circles round the room, M inside, facing partner.*

1-4::

  Men (start L foot) retire 4 steps | advance 4 ; 

5-8::

  BHJ 4 steps along circle (M L, W R) (step, cross other foot over, step, point other foot in the air) | Repeat back with other feet)

9-16::

  With PdB , turn away from partner right round | BHJ with P set ; In Ballroom hold Polka 





', 3);
INSERT INTO 'dancecrib' VALUES (10002, '2017-07-11 08:45:01.330504+00', '2020-02-12 16:46:00.582683+00', 11183, 2, 202, 'ace', '1-8::

 1s cast to foot, followed by 2s, 3s and 4s. At foot all promenade up the centre, 1s cast below 2s and 3s cast below 4s, to 2,1,4,3.

9-16::

 2s & 1s, 4s & 3s  RHA and LHA - finish 1s & 4s back to back facing same-sex corners diagonally in ‘Saltire’.

17-24::

 Full double diagonal reels of four, begin centre dancers pass same-sex corners right shldr and turn towards the centre - the corners touch left hands in the centre.

25-32::

 1s & 4s (in centre) turn their same-sex corners BH for 4 bars, then all 4 couples turn their partner BH for 4 bars to finish in sidelines.

33-40::

 Leaving 2s in top place 1s, 3s & 4s dance the Knot to finish 2,3,4,1.', 3);
INSERT INTO 'dancecrib' VALUES (2204, '2012-01-22 19:29:25.667232+00', '2021-06-09 08:40:36.162225+00', 2076, 1, NULL, 'ace', '1–::

  1c cross RH, cast off 2 (2c+3c up) ; cross LH, cast to 2pl (3c down)

9–::

  Teapots R ; and L (1c RHA with C on the R ; LHA with C on the L), finish facing 1cnr

17–::

  Set to and turn corners, finish facing 1cnr

25–::

  Opposing Reels3{6} on the sides (Lsh to 1cnr) | 1c cross RH', 2);
INSERT INTO 'dancecrib' VALUES (10563, '2018-04-01 11:41:38.050796+00', '2018-04-02 15:31:32.016807+00', 4057, 1, 202, 'ace', '1--::

  All set | 1c+2c ½ RHA as 3c cross RH (to 2x,1x,3x) ; all set | 2c & 3c cross RH as 1c Petronella turn to face 1cnrs

9--::

  ½ Reel4 on 1diag, 1c meet in centre, pull Rsh back to face 4cnrs ; ½ Reel4 on 2diag, 1c meet in centre, pull Rsh back to face 3cnrs position

17--::

  ½ Reel4 on 1diag, 1c meet in centre, pull Rsh back to face 2cnrs position ; ½ Reel4 on 2diag, dance in to face 1cnrs

25--::

  Reels3{6} on opposite sides, Lsh to 1cnrs to start | 1c cross RH, to the bottom at end of 2nd time through (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3440, '2012-01-22 19:30:25.619345+00', '2019-01-27 20:09:10.895723+00', 6756, 1, NULL, 'ace', '1–::

  1c+2c S&Link, repeat

9–::

  1M+2W change places RH and set _while_ 2W+1M set and change places ; repeat

17–::

  1c+2c RHA ; LHA into:

25–::

  1c+2c (in centre, women above P) H.Schottische Poussette.', 3);
INSERT INTO 'dancecrib' VALUES (2639, '2012-01-22 19:29:51.084632+00', '2020-12-08 22:55:38.521659+00', 3697, 1, NULL, 'ace', '1–::

  1c set | cross RH and face 2c ; set to 2c | change places LH (2,1x)

9–::

  1c+2c L-Chain, at end 1W+2M & 2W+1M continue turns into the »first diagonal« line, the W in the middle facing the M

17–::

  All dancing 8 PdB, the line turns 180 degrees cclw as follows: PdB (R), PdB (L) passing Rsh into line across, M in middle facing the W | repeat into »2diagonal« line, W in the middle ; repeat into midline, M in middle ; repeat into 1diagonal. W in middle (all face the same person each time)

25–::

  The W dance cclw round that M into (1,2x) ; 1c turn LH ½ and continue the turn moving down _while{4}_ 2c cross LH and cast up (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (10691, '2018-04-24 04:26:33.591437+00', '2019-02-03 21:43:07.031378+00', 12777, 1, 202, 'ace', '1--::

  1c cast behind own sides ; turn outwards and dance up to places

9--::

  1c cross RH | cast (2c up) ; ½ Fig8 up round 2c facing 1cnrs

17--::

  1c turn 1cnr RH | pass Rsh up/dn ; turn 2cnr RH (cnrs dance 4 bars) | cross Rsh to 2pl

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10742, '2018-05-04 07:51:41.123953+00', '2019-04-18 22:44:20.765434+00', 15837, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; 1W dances RSh round 3M _while{4}_ 1M ½ Fig8 R round 2M, 1c ending in 2Mpl

9--::

  1c NHJ dance across to 2Wpl, turn nearest W EH ¾, turn nearest M EH into lines3 across, 1M(1W) between 2c(3c)

17--::

  1c turn P LH ; turn P RH ¾ to 2pl (2,1,3)

25--::

  1c cast off one place (3c up) | all set ; all turn P RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11272, '2018-10-17 19:29:17.181889+00', '2021-08-10 18:46:34.84537+00', 19010, 1, 202, 'ace', '1--::

  1c set | slip down BHJ (2c up) ; set BHJ | cast up to 2pl (2,1,3)

9--::

  Mirror Reels3 on the sides, taking hands when possible, 1c starting in and up, 2c out and down. 2c & 3c loop to places (2,1,3)

17--::

  1c turn 1cnrs RH, pass RSh ; turn 2cnrs RH, pass RSh to 2pl (cnrs dance 4 bars) (2,1,3)

25--::

  Circle6 L ¾ into 2 facing lines3 across ; all pivot R with PdB | chase clw to own side (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11265, '2018-10-13 22:33:02.576505+00', '2019-02-01 15:41:31.690337+00', 18966, 1, NULL, 'ace', '1--::

  1c cross RH, cast off (2c up) ; dance between 3c and cast up to (2,1x,3)

9--::

  1c+3cnrs ½ diag. Reel4, pass Lsh into ; 1c+4cnrs ½  diag Reel4 (3x,1,2x)

17--::

  Diag R&L, at end 1c face 3c in the middle NHJ (2,1,3)

25--::

  1c set to 3c | 1c turn inwards and cast to 3pl _while_ 3c dance up to 2pl ; 1c turn BH (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9838, '2017-05-10 09:12:06.32296+00', '2018-08-20 00:16:47.768295+00', 17744, 1, 202, 'ace', '1--::

 1c turn RH | cast (2c up) ; turn LH to face 1cnrs

9--::

 1c+1cnrs Cnr-Chain with setting, finish facing 2cnr

17--::

 1c+2cnrs Cnr-Chain with setting, 1c finish facing out (2,1x,3)

25--::

 Reels3, 1c start Lsh to 2cnr | on [31-32] 1c cross diag to own side (2,1,3)



*Deviser''s notes: on [25-32]*



- *8 bars for all*

- *Option "high Five" can be given as 1c cross diag to 2pl*', 2);
INSERT INTO 'dancecrib' VALUES (10692, '2018-04-24 04:42:48.953829+00', '2018-04-24 04:46:13.249022+00', 11434, 1, 202, 'ace', '1--::

  1c & 2c A&R ; 1c set | set advancing passing Lsh into BtoB facing opposite sides (2c up)

9--::

  Reel4 across finish as started

17--::

  1c & 2c set | 2c cast round 2c to 2pl ; ½ Fig8 up round 2c

25--::

  1c+2c R&L', 2);
INSERT INTO 'dancecrib' VALUES (10878, '2018-07-07 00:23:20.963776+00', '2018-07-07 00:29:35.322673+00', 13838, 1, 202, 'ace', '1--::

  All pass P Rsh, pivot R to face P and cast away to exchanged places ; chase clw ½ (4,3,2,1)

9--::

  4c+3c & 2c+1c RHA ; chase clw ½ into Reel4 position (1x,2x,3x,4x)

17--::

  ½ Parallel Reels4 (to 4x,3x,2x,1x) ; 4c+3c+2c ½ Parallel Reels3 (2x,3x,4x,1x)

25--::

  All set | ½ DblFig8, 2c(1c) crossing down(up) to start | all set (2,3,4,1)

33--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (10693, '2018-04-24 04:50:05.262094+00', '2018-04-24 04:53:30.045926+00', 13829, 1, 202, 'ace', '1--::

  1c lead down (2c up) ; and back to 2pl

9--::

  2c+1c RHA ; LHA

17--::

  1c lead down (3c up) ; and back to 3pl

25--::

  3c+1c Circle4 and back', 2);
INSERT INTO 'dancecrib' VALUES (10885, '2018-07-11 00:44:38.613082+00', '2019-01-24 15:17:30.765041+00', 13742, 1, 202, 'ace', '1--::

  1c dance down between 3c | cast to 2pl (2c up) ; turn P LH 1¼ to face 1cnrs (2,*1*,3)

9--::

  SetH&G, finish facing 3cnrs

17--::

  Reel4 on 1diag, pass P Lsh to face 2cnrs

25--::

  Reel4 on 2diag (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (9812, '2017-04-25 23:04:00.623022+00', '2020-09-19 11:29:46.824135+00', 13560, 1, 202, 'ace', '1--::

  Parallel Rsh Reels3, 1W finish facing out

9--::

 1W followed by 1M cast off one | cross to 2plx (2c up), 1W pulling Rsh back ; 2c+1c+3c A&R (2,1x,3)

17--::

 1c ½ Fig8 to L ; All turn P RH (2,1,3)

25--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10694, '2018-04-24 06:35:00.705011+00', '2021-01-05 11:58:48.700519+00', 13830, 1, 202, 'ace', '1--::

  1c cast behind own sides ; turn outwards and dance up to places (1,2)

9--::

  1c ½ Fig8 down round 2c ; dance to between 2c BtoB facing opposite sides | all set

17--::

  Reel4 across. On [24] 1c turn LH ½ to face P

25--::

  1c set | turn BH ½ to 2pl (2c up) ; Circle4 L (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (10879, '2018-07-07 00:43:01.264863+00', '2019-02-12 14:27:07.195715+00', 13840, 1, 202, 'ace', '1--::
  1c cross RH | cast (2c up) ; turn LH to face 1cnrs (2,*1*,3)
9--::
  SetH&G. On [15-16], 1c set advancing to centre, BtoB facing 2cnrs (2,*1*,3)
17--::
  Reels3{6} on sidelines, Rsh to 2cnrs | 1c cross RH to 2pl, face out (2,1,3)
25--::
  Parallel Fig8 on sidelines, out and down to start, face out at end (2,1,3)
33--::
  1c cast to 3pl (3c up) | all set ; turn P RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11878, '2019-06-07 21:04:07.580384+00', '2020-03-05 09:50:13.694816+00', 19393, 1, 1645, 'ace', '*3c & 4c start on opposite sides (1,2,3x,4x)*

1-::

  *Double slide poussette:* 1c+2c & 3c+4c poussette but on [3] 1W & 4W briefly face & pass LSh to change partner before the turn on [4],

  1M+4W (top) & 1W+4M (bottom) end with extra &frac12; BH turn to square set facing in, M with new partner on their R

9-::

  All set | 2c & 3c set again & cast to ends _while(4}_ 1c+4c 1&frac14; RHA, ending as longwise set (2,4,1x,3x) | all set

17-28::

  *Co-Orbital Reels of 4 (4W & 1W make 3 loops round the centre, the others dance reels on both sides):*  

  _17-18_: 2M+4W & 1W+3M turn LH to same position on opposite side (W in 1 bar, M in 2 bars) as others start RSh Reels4 on the sides,

           then on bar 18 4W/1W pass 3W/2W respectively LSh in the sidelines  

  _19-28_: repeat pattern 5 more times back to (2,4,1x,3x), but omit final LSh pass on [27-28]

29-32::

  2M+4W & 1W+3M turn LH (2,4,1x,3x)

', 2);
INSERT INTO 'dancecrib' VALUES (2232, '2012-01-22 19:29:27.02184+00', '2021-06-08 09:26:31.569049+00', 2173, 1, NULL, 'ace', '1–::

  1c+2c+3c Rsh ½Reels3 on own sides, at end 1W faces out ; 1W followed by 1M dance up 2 places behind ladies side (3c+2c down) to (1x,3,2), 1W facing out

9–::

  Repeat [1-4] Lsh (opposite side) ; and dance up behind men''s line, finish (1,2,3)

17–::

  3c (leading)+2c+1c lead down the middle ; and up, 3c to 3pl, and 1c+2c ready for

25–::

  1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12785, '2020-04-30 23:14:19.322702+00', '2021-04-02 21:57:53.287349+00', 11760, 1, 202, 'ace', '1--::

  All W ½ LHA | turn opposite M RH ; ½ LHA ; turn P RH into promhold facing centre (1,2,3,4)

9--::

  Reel4, 1c & 3c passing LSh. On [16] 1c face 2c & 3c face 4c, all W on P''s R

17--::

  All set | turn opposite person BH opening into ; Circle 4 L. On [24] all release hands and face clw

25--::

  2M (2W, 1M & 1W following) & 4M (4W,3M & 3W following) chase clw around the square {6} (to 2,3,4,1) | all turn P RH', 2);
INSERT INTO 'dancecrib' VALUES (3684, '2013-01-18 14:46:58.951515+00', '2021-01-23 20:39:49.613227+00', 11523, 2, 1, 'ace', '*2 chords; on second chord 3C&4C change sides*



1–6::

  1c&4c Set | cross R | cast in [2c&3c move out]

7–8::

  1M dances petronella turn between 2c [to face down] _while_ 4M dances petronella turn

  between 3c [to face up] _while_ 1W+4W turn L ¾ to fin in ctr facing ptrs

9–::

  1c+4c Reel4 [finish 1M facing up, 4M facing down, W behind their ptrs]

17–::

  1c+2c & 4c+3c Reels3 across (RS, 1c/4c dancing as one person) [1c&4c fin in ctr ready

  for …]

25–::

  1c+4c RH across [to sidelines, 21x43x] ; 1c+4c face up/down, S and change pl LH

  [241x3x]', 3);
INSERT INTO 'dancecrib' VALUES (3827, '2013-07-13 15:56:16.241333+00', '2020-02-05 15:54:41.995876+00', 14536, 1, NULL, 'ace', '1–::

  1c+2c the Knot, 1c finish facing 1cnrs

9–::

  1c+1cnrs ½ Reel4, pass Rsh ; 1c+2cnrs ½ Reel4 (3x,1x,2x)

17–::

  All set | 1c petronella _while{2}_ 2c+3c cast 1 place clw ; all set in lines across | 1c petronella _while{2}_ 2c+3c cast 1 place clw (2,1,3)

25–::

  All set | all turn BH, finish 2c in 1pl and 1c+3c ready for ; 1c+3c ½ Poussette (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (10881, '2018-07-07 05:57:26.594098+00', '2018-07-07 06:01:31.058502+00', 13843, 1, 202, 'ace', '1--::

  1c+2c Poussette (1,2,3)

9--::

  1c lead down (2c up) ; and up facing 1cnrs (2,*1*,3)

17--::

  SetH&G. On [23-24], 1c set advancing to centre, BtoB facing 2cnrs (2,1,3)

25--::

  Fig8{6} on sidelines, Rsh to 2cnrs | 1c cross to 2pl (2,1,3)

33--::

  Circle6 and back

41--::

  1c long cast to 3pl (3c up) ; all turn P BH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10882, '2018-07-07 07:58:50.099432+00', '2018-07-07 08:04:28.629559+00', 13845, 1, 202, 'ace', '1--::

  1c Parallel Fig8 on sidelines, Lsh to 2c to start, 1M faces out at end (1,2,3)

9--::

  1M followed by 1W casts to 3plx (2c+3c up) ; 1W followed by 1M cast to 2pl (3c down) (2,1,3)

17--::

  Circle6 and back, 1c(3c) facing down(up) ready for

25--::

  3C Gr-Chain (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10883, '2018-07-08 01:30:05.968704+00', '2018-07-08 01:39:54.902215+00', 11298, 1, 202, 'ace', '1--::

  Inveran Reels, 2c facing out (1,2,3)

9--::

  1c+2c DblFig8, 1c cross down to start (1,2,3)

17--::

  1c cross RH | cast (2c up) ; cross LH | cast L into facing Lines3 across

25--::

  All set | A&R | set

33--::

  1c Petronella turn to 2plx | all set ; ½ Fig8 R round 3cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10884, '2018-07-08 10:52:03.359842+00', '2018-07-08 10:52:03.359842+00', 18366, 1, NULL, 'ace', '1-::

  1c cross down as 2c cast up (2,1x,3) | Criss, Cross &amp; Cast: those in 1pl &amp; 2pl cross down 1pl as those in 3pl cast up (3,2x,1) ; repeat twice from new pl back to (2,1x,3)

9-::

  1c set adv | turn &frac34; RH to face 2cnrpos _while{4}_ 2c &amp; 3c set | change pl RH on sides ; 1c+2cnrpos set | turn BH

17-::

  1M+3c (top) &amp; 1W+2c &frac12; LSh Reels3 across ; &frac12; RSh Reels3 on sides (2x,1,3x)

25-::

  2c &amp; 3c petronella to centre line | &frac12; LSh Reel4 | turn &frac34; LH (3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (10886, '2018-07-11 00:57:22.720219+00', '2018-07-11 01:01:27.884076+00', 16128, 1, 202, 'ace', '1--::

  1c & 2c turn P BH ready for ; ½ Poussette (2,1,3)

9--::

  1c turn BH | dance down between 3c ; cast to 2pl | cross RH, 1M facing out (2,1x,3)

17--::

  2c+1c La-Chain (2,1x,3)

25--::

  Circle6 L | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2920, '2012-01-22 19:30:02.966433+00', '2017-07-15 02:04:06.833497+00', 4930, 1, NULL, 'ace', '1–::

  All set | 1c & 4c cast towards middle (2c+3c step to end) ; All ½ R&L (1x,2x,3x,4x)

9–::

  Repeat (no polite turn at the end) (1,2,3,4)

17-28::

  G-Chain (1c+4c cross, 2c with 3c) (12 bars for 8 hands)

29-32::

  2c+3c petronella onto midline and set

33–::

  2c+3c continue (petronella, set, repeat)

41–::

  2c+3c Reel4 on midline

49–::

  2c+3c turn RH, dance out through own places and cast to own end, as 1c+4c step towards middle places out sideways, All A&R in circle NHJ

57–::

  All circle8 and back (2,1,4,3)



{{explanation}}

Note: after twice through all are back in original places.', 3);
INSERT INTO 'dancecrib' VALUES (11016, '2018-08-20 10:10:11.414343+00', '2018-08-20 10:14:24.326212+00', 12759, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; turn BH (2,1,3)

9--::

  1c+2c RHA ; 1c+3c ½ R&L (2,3x,1x)

17--::

  2c+3c LHA ; 3c+1c ½ R&L (2,1,3)

25--::

  Mirror Reels3 on sidelines, 1c in and up (2,1,3) ', 2);
INSERT INTO 'dancecrib' VALUES (14823, '2022-05-09 17:41:02.452301+00', '2022-05-09 17:41:12.459568+00', 20818, 1, 1645, 'ace', '1--::

  All dance towards P{1} & cast away{1} | chase &frac12; way clw (4x,3x,2x,1x)

9--::

  3M+2M & 3W+2W tandem Fig8 round 1c/4c starting RSh to 4M/1W (4x,2x,3x,1x)

17--::

  All W petronella to centre line | set ; petronella to own side | set

  _while{8}_ all M set | petronella to centre line ; set | petronella to own side (4,2,3,1)

25--::

  4c+2c+3c *Moorland progression:* 4c dance down (no hands) to 3pl | cast up

  _while{4}_ 2c set | dance down to 3pl

  _while{4}_ 3c cast up to 1pl | set (3,4,2,1) ;

  3c+4c+2c repeat Moorland progression from new places (2,3,4,1)

33--::

  2c+3c & 4c+1c *Basket reels:* R&L without giving hands (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (8280, '2014-06-11 12:50:48.794334+00', '2018-10-11 14:08:22.522544+00', 14239, 1, 1041, 'ace', '1–::

  Circle4 and back

9–::

  1c lead down the middle and up

17–::

  1c+2c Promenade

25–::

  ¾ R&L {6} | 2c+1c set 

', 3);
INSERT INTO 'dancecrib' VALUES (10887, '2018-07-11 11:17:42.264822+00', '2020-02-02 11:03:43.157817+00', 13837, 1, 202, 'ace', '1--::

  1M followed by 2M & 3M dance across the top and down to behind the W side _while{4}_ all W advance {1}, pivot R (full turn) {2}, dance to M side {1} and face up ; repeat [1-4], W chasing, M advancing (3,2,1)

9--::

  Circle6 and back

17--::

  3c+2c S&Link ; 3c+1c S&Link, 1W faces out (2,1,3)

25--::

  1W followed by 1M cast down ; cross to 3plx (3c up) ; 1c ½ Fig8 up round c (2,3,1)

33--::

  3C Gr-Chain (1c cross to start)', 2);
INSERT INTO 'dancecrib' VALUES (2187, '2012-01-22 19:29:24.636147+00', '2021-06-11 20:30:49.133019+00', 2008, 1, NULL, 'ace', '1–::

  1c cross RH | change pl. LH with 2c ; cross RH | chance pl. LH with 3c (2,3,1)

9–::

  3c+1c set | cross RH ; 3c+1c cast up (3c leading) , cross down between 2c to (2,1,3)

17–::

  2c+1c set | cross RH ; 1c+2c cast off (1c leading), cross up between 3c (1,2,3)  and stay in middle for

25–::

  1c+2c Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10891, '2018-07-13 00:13:32.017881+00', '2020-02-03 09:30:55.033805+00', 1554, 1, 202, 'ace', '1--::
  1c+2c & 3c+4c RHA ; 2c+3c LHA _while{4}_ 1c & 4c chase clw ½ to exchanged places (4x,2,3,1x)
9--::
  Parallel Reels4 on sides (4x,2,3,1x)
17--::
  4c+2c & 3c+1c LHA ; 2c+3c RHA _while{4}_ 1c & 4c chase cclw ½ to original places (1,2,3,4)
25--::
  1c+2c & 3c+4c R&L (1,2,3,4)
33--::
  1c cast to 4pl (2c+3c+4c up on [35-36]) ; all turn P RH (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (11260, '2018-10-12 17:50:14.386185+00', '2018-10-12 17:50:14.386185+00', 18950, 1, NULL, 'ace', '1--::

  1c+2c R&L, omit final polite turns (1,2,3)

9--::

  2c face 3c for Rsh Reels3 on own sides, at end 1M faces out

17-20::

  1M (1W following) cast off and cross to 2plx (2c up) (2,1x,3) 

21-28::

  2c+1c La-Chain, 1c finish facing 4cnr

29-32::

  1c cast Rsh round 4cnr (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3428, '2012-01-22 19:30:25.088948+00', '2020-11-15 13:02:35.792231+00', 6712, 1, NULL, 'ace', '1-16::

  1c+4c cross RH _while_ 2c+3c ½RHA | middle and end Cs change place LH on sides ; repeat 3 times, finish (1,2,3,4) 1c facing down, 2c up

17–::

  1c set to 2c | cross down to face 3c (2c dance up) ; 1c+3c repeat

25–::

  1c+4c repeat ; All A&R, 1c changing sides RH on [30] (2,3,4,1)



{{explanation}}

Note: on [30] the original says »RH«, but »BH« is widely used.', 3);
INSERT INTO 'dancecrib' VALUES (11262, '2018-10-12 20:40:51.252823+00', '2018-10-16 13:03:32.214649+00', 18953, 1, NULL, 'ace', '1--::

  1c long cast to face 1cnr (2c up) ; 1c set to 1cnr and turn BH

9--::

  1c+1cnrs ½ diag. Reel4 ; 1c+2cnrs ½ diag. Reel4, and 1c faces 4cnr (pos)

17--::

  1c+4cnr (pos) set and turn BH ¾ ; 1c dance Rsh round 2cnr (pos) to (3x,1x,2x)

25--::

  All set | turn P RH ; chase clw to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8680, '2015-02-21 20:42:43.713618+00', '2019-07-17 22:01:22.094384+00', 12219, 1, NULL, 'ace', '1--:: 1c cross down RH (2c up) into | BiL with 1cnr + 2cnr ; turn 1cnr RH | turn partner LH to 2pl own side facing out (2,1,3)

9--:: Reels3 on the sides (Lsh to 4cnr), on [15-16] 1c change places LH into

17--:: 2c+1W & 1M+3c RHA ; All chase clw ½ (3x,1x,2x)

25--:: All S&Link3 twice (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (12156, '2019-09-03 19:41:49.362767+00', '2019-09-04 09:10:49.893434+00', 19615, 1, 202, 'ace', '1--::
  1c+2c S&Link ; 2c+1c RHA (2,1,3,4)
9--::
  2c+1c+3c S&Link ; Circle6 L ½ into lines3 across, 1W between 2c in 1plx, 1M between 3c in 3plx
17--::
  1c change places LH and dance LSh round 3cnrs[pos] to 2pl (to 2x,1,3x,4) ; 1c+3c ½ RHA _while{2}_ 2c & 4c cross RH (to 2,3,1x,4x) | 1c+4c ½ LHA (2,3,4,1)
25--::
  2c+3c & 4c+1c Poussette (2,3,4,1)', 5);
INSERT INTO 'dancecrib' VALUES (10892, '2018-07-13 00:38:10.388566+00', '2018-07-13 00:48:21.586955+00', 6677, 1, 202, 'ace', '1--::

  2c+3c RHA ; 2W followed by 2M(3M followed by 3W) cast to 4plx(1plx) (1c & 4c step in), finish 3c&4c(1c&2c) facing down(up) (3x,1,4,2x)

9--::

  3c+1c & 4c+2c Poussette across the set, starting down on M side (3,1x,4x,2)

17--::

  Parallel Reels4 (3,1x,4x,2)

25--::

  1c(4c) lead up(dn), cross and cast to 2pl(3pl) ; all turn P RH (3,1,4,2)

33--::

  Circle8 and back (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (14619, '2022-02-21 13:34:09.381222+00', '2022-02-22 15:53:14.930282+00', 3876, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; ½ Fig8 L round 4cnrs to face 1cnrs
9--::
  Corner Chain with Setting. 1c face 2cnrs
17--::
  Repeat with 2cnrs. 1c finish between ends facing 1cnrs
25--::
  Reels3 across, 1c LSh to 1cnrs (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (8869, '2015-08-26 22:04:50.683473+00', '2022-05-03 11:57:03.036492+00', 16524, 1, 1041, 'ace', '1--::  1c set |  turn RH 1/2 ; lead down, cross below 3c (2c up on [5-6] and cast to 2pl (2,1,3)

9--::  1c set adv to into BtoB facing 1cr while 1cr set | turn 1cnr BH into lines across ; 1c set adv to into BtoB facing 2cr while 2cr set | turn 2cnr BH

17--:: 2c+1M & 1W+3c circle3 L, at end 1c swivels R to face P ; 1c set | 1c Petronella turn (to 2,1,3)

25--:: 1c+2c poussette

', 4);
INSERT INTO 'dancecrib' VALUES (15098, '2022-09-13 10:52:51.881385+00', '2022-09-13 11:02:47.676105+00', 19671, 1, 1645, 'ace', '1--::
  Reels3{6} on side, 2c start up & out | 1c+2c continue reel to change places (2,1,3)
9--::
  1c+3c LHA ; 2c+1c RHA & 1M curves into place
17--::
  1c+3c Petronella in tandem | set facing up/down ; 1c+3c Petronella in tandem to opp sides | cross RH
25--::
  All Circle6 to L ; pivot pulling LSh back & chase back cclw (2,3,1)
', 2);
INSERT INTO 'dancecrib' VALUES (10424, '2018-02-12 19:51:53.692715+00', '2018-03-27 00:38:13.981713+00', 17467, 1, 202, 'ace', '1--::

  1c set to 2c | 1c starting in + 2c change places EH ; 1c set to 3c | 1c starting out turn 3c EH and face out (2,1,3)

9--::

  1c Fig8 on sideline, starting Lsh to 4cnrs, pass Rsh to face 1cnrs

17--::

  1c turn 1cnrs RH, pass Rsh ; turn 2cnrs RH, pass Rsh finishing between end couples facing 4cnrs (corners dance for 4 bars!)

25--::

  1W+2c & 1M+3c 6 bars of Reels3 across, Rsh to 4cnrs (to 2,1x,3) | 1c cross RH, 1M with polite turn to start again', 2);
INSERT INTO 'dancecrib' VALUES (11017, '2018-08-20 10:28:50.61294+00', '2018-08-20 10:33:41.699313+00', 146, 1, 202, 'ace', '1--::

  1W crosses between 1M & 2M, in front of 3M, behind 4M to 4Wpl (2W+3W+4W step up on [3-4])

9--::

  1M repeat mirror pattern (2,3,4,1)

17--::

  2c followed by 3c+4c+1c cast off (to 1,4,3,2) ; all turn P RH into allemande hold

25--::

  4C Allemande (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12159, '2019-09-04 06:54:18.994919+00', '2019-09-04 10:24:09.206188+00', 4286, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; cross LH | dance LSh round 4cnrs into facing lines3 across
9--::
  Circle4 R ½ with H. Schottische step [: H. Schottische R. On [10] all pivot R and face out. H. Schottische L. On [12] all pivot L and face in] ; repeat [9-12]
17--::
  1c turn P RH | turn 3cnrs[pos] LH ; turn P RH | turn 4cnrs[pos] LH and face 1cnrs[pos]
25--::
  ½ Reel4 on 1diag, 1c pass LSh giving hands ; ½ Reel4 on 2diag, 1c cross LH to 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10898, '2018-07-14 05:17:37.093027+00', '2021-06-06 11:25:26.350739+00', 18376, 1, 202, 'ace', '1--::

  Mirror Reels3 on sidelines, 1c starting in (1,2,3)

9--::

  1c lead down ; and up to 1pl centre facing P. On [16], 2c step in ready for

17--::

  1c+2c Poussette. On [23-24], 1c turn RH (or set advancing) to face 1cnrs (2,*1*,3)

25--::

  Corners Pass and Turn (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10894, '2018-07-13 06:27:08.320466+00', '2018-07-13 06:33:41.468208+00', 733, 1, 202, 'ace', '1--::

  1c dance down between 3c | cast up 1 place ; dance up between 1c | cast to 2pl (2c up) (2,1,3)

9--::

  1c Petronella Turn | 1c set ; turn BH ¾ | cast R round 1cnrs into facing lines3 across

17--::

  Reels3{6} on sidelines, 1c passing Lsh to 2cnrs | 1c Petronella Turn (2,1x,3)

25--::

  1c Petronella Turn | 1c set ; turn BH ¾ | cast R round 3cnrs into facing lines3 across

33--::

  Reels3{6} on sidelines, 1c passing Lsh to 4cnrs | 1c Petronella Turn (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10893, '2018-07-13 01:03:59.995189+00', '2018-07-13 01:10:07.037774+00', 1953, 1, 202, 'ace', '1--::

  1c & 4c set | 1c lead down and cast to 3pl _while{4}_ 4c making an arch dance up and cast to 2pl (2c&3c step out) | all set (2,4,1,3)

9--::

  2c+4c & 1c+3c LHA ; RHA (2,4,1,3)

17--::

  2c+4c & 1c+3c Reels4 across, starting from sidelines, 2M+4W & 1M+3W passing Lsh (2,4,1,3)

25--::

  Circle8 and back (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10889, '2018-07-12 21:15:52.347117+00', '2018-12-17 10:49:49.932673+00', 18394, 1, NULL, 'ace', '1-::  1c turn RH | cast to face 1cnrs (2c up) ; 1c turn 1cnrs RH then pass RSh to

9-::  2c+1M & 1W+3c LHA, 1c end facing 2cnrs ; 1c & 2cnrs &frac12; LSh diag Reel4, 1c pass LSh to own side

17-:: 1c turn 2cnrs (in 4cnrpos) LH then pass LSh to ; 2M+3M+1M & 1W+2W+3W RHA, 1c end facing 3cnrs

25-:: 1c & 3cnrs &frac12; RSh diag Reel4, 1c pass RSh to (3x,1x,2x) ; all chase &frac12; way clw to (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (13789, '2021-03-05 22:20:21.010179+00', '2021-08-10 18:55:04.994214+00', 19122, 1, 202, 'ace', '1--::

  Parallel Reel3 on sides, 1c RSh to 2c (1,2,3)

9--::

  1c+2c 4 bars of Set&Rotate ; RHA ½ | 1W+2M turn RH ¾ and face own P _while{2}_ 1M & 2W set diagonally

17--::

  Diagonal Reel4 to sides (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (12563, '2020-02-04 02:37:42.682255+00', '2020-02-06 15:05:38.380273+00', 624, 1, NULL, 'ace', '1--::

  1c set | cast (2c up) ; turn LH 1¼ to face 1cnr

9--::

  CPCP, finish facing 3M in promhold

17--::

  1c +3c ½ Reel3 across, Rsh to 3M ; 1c+2c ½Reel3 across, Rsh to 2W and finish on midline facing M side

25--::

  1c set L{1}while turning to face M down and W up, dance (starting L foot) and cast Lsh round 1cnr to (2x,1x,3x) ; All set and cross RH (2,1,3)











', 3);
INSERT INTO 'dancecrib' VALUES (10895, '2018-07-13 07:50:38.635396+00', '2018-07-13 07:56:45.80669+00', 2062, 1, 202, 'ace', '1--::

  1c set | lead down between 3c (2c up) ; cast up to face 1cnrs (2,*1*,3)

9--::

  Set To And Turn Corners (skip change when turning BH) (2,1x,3)

17--::

  1c set | cross RH ; cast R round 3cnrs into facing lines3 across | all set

25--::

  1c dance to P and join RH | set ; dance between facing ends | cast R round 4 cnrs to 2pl _while{8}_ 2c & 3c set | cross RH ; set | cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10896, '2018-07-13 14:07:36.545671+00', '2018-07-13 14:16:58.02196+00', 6893, 1, 202, 'ace', '1--::

  1c+2c ½ R&L ; 1c+3c ½ R&L (2x,3x,1)

9--::

  1c lead up between 2c | cross and cast to 2plx (3c down) ; 1c ½ Fig8 L round 4cnrs[pos] to 2pl centre BtoB facing own side (2x,1,3x)

17--::

  DTr, 1c face 3cnrs

25--::

  ½ Reel4 on 1diag, pass Rsh ; ½ Reel4 on 2 diag (3,1,2)

33--::

  All chase clw ½ (to 2x,1x,3x) ; set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2984, '2012-01-22 19:30:05.623794+00', '2019-01-28 00:03:54.87866+00', 5159, 1, NULL, 'ace', '*on 2nd chord 2c+4c change sides (1,2x,3,4x)*

1--::

  1W+4W cast to other end of their sideline, the others following (4x,3,2x,1) ; ½ Circle8 L ‑ to (1x,2,3x,4)

9–-::

  1c+2c & 3c+4c RHA ; LHA, finish NHJ, 1c facing 2c & 3c facing 4c.

17–-::

  All set | All set passing facing couple ; Middles set passing _while{2}_ end couples change sides (raise arms, W dances under as M crosses behind her) and face in | All set passing (to 4,2x,3,1x), into

25-–::

  4c+3c (start up) & 2c+1c (start down) Interlocked Opposing Allemandes (danced as 1c+3c of 3c Allemandes) (3,1x,4,2x)', 3);
INSERT INTO 'dancecrib' VALUES (10899, '2018-07-14 05:37:35.855279+00', '2018-10-06 08:41:16.597148+00', 10247, 1, 202, 'ace', '1--::

  1c set | turn BH ; cast (2c up) | advance to face 1cnrs (2,*1*,3)

9--::

  Set To and Turn Corners (2,1x,3)

17--::

  Reels3{6} on sidelines, 1c Lsh to 1cnrs | 1c cross RH (2,1,3)

25--::

  1M+2c & 1W+3c LHA, 1c pass Lsh ; 1M+3c & 1W+2c RHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3756, '2013-06-07 21:51:20.244258+00', '2020-11-15 13:13:27.311784+00', 14393, 1, NULL, 'ace', '1–::

  !c Turn BH | cast (2c up) ; cross RH and cast R round 1cnr to face 1cnr on the diagonal

9–::

  1c set to 1cnr | 1c cast Rsh round each other to 3cnr position _while{2}_ 1cnrs dance into centre, and swivel R to face own cnr ; repeat, 1cnrs finishing in exchanged places, and 1c facing 2cnr

17–::

  Repeat with 2cnrs (to 3x,1x,2x)

25–::

  All Set and Link ; repeat (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10172, '2017-10-12 22:46:10.771963+00', '2021-06-08 09:47:51.693033+00', 17523, 1, 202, 'ace', '1--::

  1c set | cross RH to 2plx facing 1crns (2c up) ; set to 1cnrs | turn 1cnr RH ¾ into facing lines of 3 across

9--::

  1c turn P LH 1 ¼ to 2plx facing 2cnrs ; set to 2cnrs | tun 2cnr LH ¾ into facing lines of 3 across

17--::

  All A&R ; 1c+2W+3M ½ diag R&L

25--::

  All set in lines across | change places with P RH ; chase clw (to 2,1x,3) | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2012, '2012-01-22 19:29:14.927864+00', '2018-07-14 08:10:45.217+00', 1437, 1, NULL, 'ace', '1--::

  1c lead down, cross and cast round 3c to 3plx (2c+3c up) ; 2c repeat (3c+1c up) (3,1x,2x)

9--::

  3c repeat (1c+2c up) ; 1c+2c+3c turn BH 1½ (1,2,3)

17--::

  1c lead down, cross, cast round 3c, lead up to the top, cross and cast to 2pl (2c up) (2,1,3)

25--::

  1c dance down between 3c and cast up to 2pl ; 1c+2c+3c turn BH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10173, '2017-10-13 20:38:49.22217+00', '2019-02-23 19:00:17.093561+00', 18016, 1, 202, 'ace', '*3c & 4c start on opposite sides*



1--::

  1c & 4c set | cross RH ; cast inwards (2c+3c step out) | turn P RH ¾ into midline

9--::

  1c+4c ½ Reel4 ; set | turn P RH ¾ to sidelines (2,4,1x,3x)

17--::

  2c+4M & 1M+3c LHA _while{4}_ 4W+1W turn LH ; 2c+4W & 1W+3c RHA _while{4}_ 4M+1M turn RH and face out

25--::

  4c+1c La-Chain (2,4,1x,3x)', 5);
INSERT INTO 'dancecrib' VALUES (3770, '2013-07-13 15:55:57.18214+00', '2020-09-19 11:34:27.674681+00', 13625, 1, NULL, 'ace', '1–::

  1c+3c cross RH | change places Rsh on sides  _while_{4}   2c set | Turn BH ¾ and face ends ; 3c+1W & 1M+1c RHA, 2c finish on midline facing P up/dn

9–::

  1c+3c change places Rsh on sides | cross RH _while_{4}   2c set | Turn BH ½  and face other end ; 1c+1M & 1W+3c RHA, 2c finish in middle facing own side

17–::

  Lsh ½ Reels 3 on the sides ; 3C turn LH  _while_{4}   2c+1c turn RH (3,2,1)

25–::

  3c+2c Tournee (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (8917, '2015-09-22 19:09:01.116418+00', '2015-09-22 19:09:01.116418+00', 16764, 2, NULL, 'ace', '1-8::  All join hands on the sides, 4s join free hands, 1M2M make an arch and, with 1L leading, all (except 1M) dance under the arch to finish in places, retaining hold;

9-16::  1L2L make an arch and, with 1M leading, all (except 1L) dance under the arch to finish in places, releasing hold;

17-20::  1s2s 3s4s right hands across;

21-24::  1s2s 3s4s left hands across;

25-28::  1s take both hands and slip to 4th place WHILE 2s3s4s step up;

29-32::  2s 3s 4s 1s turn by the left.



', 3);
INSERT INTO 'dancecrib' VALUES (12566, '2020-02-05 16:26:28.306702+00', '2020-02-05 16:31:41.243318+00', 3168, 1, NULL, 'ace', '1--::

  Reels4 on the sides, middles face ends to start (1,2,3,4)

9--::

  2c+3c RHA ; LHA _while{8}_ 1c & 4c Set and Cross RH ; 1W & 4M, both followed by P, cast clw and cross to (4,2,3,1)

17--::

  All set | 2c+3c ½ R&L | 3c+2c cross RH (4,3,2,1)

25--::

  4c+3c+2c Allemande (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (12654, '2020-03-03 18:03:56.933719+00', '2020-03-05 18:51:24.656083+00', 16194, 1, NULL, 'ace', '*Couples form big single circle facing in, M has W on his R*

1--::

  All W A&R ;  All M A&R and all face P

9--::

  All cpls dance BtoB ; Turn P RH and face P

17--::

  Pass Rsh and next person Lsh | turn next person RH ½ and face that person ; repeat [17-20] to join P again.

25--::

  All slip 4 steps L and forward a bit | slip 4 back to circle, finish BtoB with P ; turn next person (New P) LH

33--::

  Circle R and back

 ', 3);
INSERT INTO 'dancecrib' VALUES (12568, '2020-02-07 01:01:28.926336+00', '2020-02-07 12:31:28.925355+00', 19392, 1, NULL, 'ace', '*cpl face cpl RR*

1--::

  Circle4 and back

9--::

  ½ R&L ; Dance BtoB with opposite

17--::

  ½ R&L ; with opposite turn RH ½ and face | cast away R to face next cpl



', 3);
INSERT INTO 'dancecrib' VALUES (11018, '2018-08-20 13:42:34.672774+00', '2018-08-20 13:48:06.250242+00', 12761, 1, 202, 'ace', '1--::

  All turn P RH ½, face P | cast R to exchanged places, finish in Reel4 position ; ½ Parallel Reels4 (4x,3x,2x,1x)

9--::

  4c+3c & 2c+1c RHA, 1W & 4M face out ; 4M & 1W, followed by P, chase clw 2 places (3c & 2c step out) (3x,1,4,2x)

17--::

  ½ 4C Gr-Chain (to 2,4x,1x,3) ; 4c & 1c ½ Fig8 between ends (2,4,1,3)

25--::

  Circle8 and back ', 2);
INSERT INTO 'dancecrib' VALUES (1667, '2012-01-22 19:28:53.941315+00', '2018-04-02 10:28:35.753236+00', 164, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1c set | cast off ; turn 1¼ RH to between end couple (1M up, 1W down), facing out

17–::

  Reels3 across, Rsh to 2cnr, at end 1c pulls Lsh back into lines across

25–::

  1c advance, turn away by their R and cast R round 2cnr to (2,1x,3) ; all turn BH (1 or 1½) to own sides (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2078, '2012-01-22 19:29:18.62683+00', '2020-02-07 21:34:38.5225+00', 1634, 1, NULL, 'ace', '1–::

  1c set, turn RH ; cast off 1pl (2c up), turn ¾ LH, ready for

9–::

  Teapots R (1M+2c & 1W+3c RHA) ; Snake Pass: 1M followed by 2W+2M pass Lsh to 1W followed by 3M+3W to (3,1 in middle,2)

17–::

  Teapots L (3c+1W & 1M+2c LHA) ; Rsh Snake Pass to (2,1x,3)

25–::

  All set | 1c petronella turn (M up, W down) into facing lines across ; all set, 1c petronella turn (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2630, '2012-01-22 19:29:50.726525+00', '2022-02-22 15:52:12.238245+00', 3659, 1, 202, 'ace', '1–::
  1c set | cross RH ; cast off (2c up) | turn P LH to face 1cnrs
9–::
  Corner Chain. 1c face 2cnrs
17–::
  Repeat with 2cnrs, 1c crossing LH to 2pl (2,1,3)
25–::
  2c+1c+3c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (11389, '2018-12-15 12:36:34.04028+00', '2021-08-10 18:59:30.648949+00', 13592, 1, 1645, 'ace', '1-::

  1c+2c Knot, 1c end facing 1cnrs (2,1,3)

9-::

  1c+1cnrs &frac12; turn RH | &frac12; diag RSh Reel4 | &frac12; turn RH, 1c face 4cnrs

17-::

  1c+4cnrs repeat [9-16], 1M ends between 3c in 1pl, 1W between 2c in 3pl

25-::

  All chase &frac12; way clw ; 1c turn 1&frac14; BH (2,1,3)



*After two repeats 1c dance [1-8] again with 4c to end in 4pl own sides.*

', 2);
INSERT INTO 'dancecrib' VALUES (2612, '2012-01-22 19:29:49.921965+00', '2020-03-06 21:07:25.03909+00', 3626, 1, NULL, 'ace', '1–::

  1c+2c circle4 L ; turn BH twice

9-12::

  1c cross RH | 1c+2c change LH on side (2,1x)

13-16::

  both W chase cclw ½, passing P Lsh _while_ M wait | advance diagonally {1} turn away L and dance back facing out (P is on same sideline)

17–::

  L-Chain, end in promhold with P

25–::

  1c+2c Tournée', 3);
INSERT INTO 'dancecrib' VALUES (14199, '2021-08-13 09:32:33.68042+00', '2021-08-14 23:42:49.637972+00', 19965, 1, 202, 'ace', '1--::
  All cast off one place clw | set ; 1M+2W turn RH 1½ (2,1)
9--::
  Reel3 across, 1c in promhold LSh to 2M. 1c finish in 1pl centre, 2c in 2pl centre, both facing up in promhold (1,2)
17--::
  2C Allemande (2,1)
25--::
  All turn P 1½, 2c with RH, 1c with LH and face up/down (to 2x,1x) ; 2C S&Link (2,1)', 5);
INSERT INTO 'dancecrib' VALUES (10696, '2018-04-24 23:31:14.70359+00', '2018-04-27 00:14:16.884348+00', 18285, 1, NULL, 'ace', '1--::

  1c+4c cross RH | set ; cross LH | set (one bar across; then turning to face next cpl)

9--::

  1c facing 2c & 3c facing 4c change place RH | 1c facing 4c set (1 bar up/down, 1 bar across) ; 1c+4c cross LH and set (2,1x,4x,3)

17--::

  2c+1c & 4c+3c RHA ;  1c+4c LHA

25--::

  1c+4c dance Rsh round nearest cnr ; 1c+4c ½ RHA | and set (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10037, '2017-08-02 14:43:05.508837+00', '2019-04-18 17:37:41.269777+00', 17905, 1, 202, 'ace', '1--::

 1c+2c RHA into diagonal line ; ½ Poussette (2,1,3)

9--::

 1c+3c repeat [1-8] (2,3,1)

17--::

 1c dance towards each other and cast to 1pl (2c+3c dn retaining H at end) ; all NHJ as long as possible when advancing dance BtoB (1,2,3)

25--::

 3C Progressive Gr-Chain (2,3,1)



*Progressive Gr-Chain: like Gr-Chain with 2 bars/hand, but when meeting P make full turn to stay on own side (to start, 1c turn RH, 2c+3c change places RH on sidelines)*', 2);
INSERT INTO 'dancecrib' VALUES (11019, '2018-08-20 20:40:44.215483+00', '2018-08-20 20:48:20.620325+00', 3481, 1, 202, 'ace', '1--::

  1c+2c RHA ; LHA (1,2,3)

9--::

  1c lead down ; and up to 1pl centre BHJ. On [16], 2c step in

17--::

  Poussette, 1c BtoB in centre face own side (2,*1*,3)

25--::

  DTr (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10900, '2018-07-14 20:12:56.757989+00', '2018-07-14 20:19:58.862589+00', 18381, 2, 13458, 'ace', '1-8:: 2s step up immediately as 1s cross down RH to face out between 2s and 3s.  1s give hands to each corner and set in a triangle, 1s cast to the right end facing 1st corners 

9-16:: Diagonal reel of 4 with 1st corners.  1s pass each other to face 2nd corners

17-24:: Diagonal reel of 4 with 2nd corners.  1s end taking promenade hold in middle facing down, L on M’s left

25-32:: 1s + 3s dance reel of 3 across, RSh to 3M to start, ending in the middle facing up

33-40:: 1s, in Promenade hold, dance up between 2s, separate and cast round 2s, to 2nd place on opposite side.  All  set and 1s cross by the right to own side

', 3);
INSERT INTO 'dancecrib' VALUES (12786, '2020-05-01 14:47:23.754813+00', '2020-05-01 14:53:23.40246+00', 16941, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 L round 4cnrs (2,1,3)

9--::

  All chase clw ½ (to 3x,1x,2x) ; ½ Reel4 on 2diag, 1c RSh to 3cnrs[pos]. 1c pass P RSh to face 1cnrs[pos]

17--::

  ½ Reel4 on 1diag, 1c RSh to 1cnrs[pos] into facing lines3 across, 1W between 2c facing 1M between 3c ; 1c turn RH 1½ to exchanged places facing out

25--::

  Reels3 across, 1c RSh to 2cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14198, '2021-08-10 20:34:49.356961+00', '2021-08-10 20:35:08.380037+00', 16619, 1, 1645, 'ace', '1-::

  1c lead down ; lead up to 3pl centre | turn &frac34; RH to 1W/1M between 2c/4c (making square shape, with 4 corners and 4 "middles")

9-::

  All &frac12; Schiehallion Reels: corners cross to middle places on R (2W to 3M place) _while_ middles cast R to corners (1W to 2W place) | repeat 3 times

17-::

  All chase &frac12; way clw in square ; 1c turn &frac34; RH (2c+3c up) to (2,3,1x,4) | 1c cast _while_ 4c dance up & face down (2,3,4,1x)

25-::

  1c cross up into mirror Reels4 on sides, 2c & 4c start out and down (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (10902, '2018-07-15 03:35:58.466202+00', '2019-01-31 19:51:25.481994+00', 18382, 1, 202, 'ace', '1--::

  1c turn BH | cast (2c up) ; set | Petronella Turn into facing lines3 across

9--::

  All set | 1c cast R round 4cnrs to 2pl _while{2}_ 2c+3c change places RH (to 3,1,2) ; all set | cross RH, 1c face out (3x,1x,2x)

17--::

  1c cast R round 1cnrs[pos], change places RH up/down, cast R round 2cnrs[pos] to 2plx _while{8}_ 2M+3W pass Rsh and face each other | cast R to exchanged places ; 2W+3M repeat (2,1x,3)

25--::

  1M+2c & 1W+3c RHA ; 1c turn BH ½, face each other | cast R to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8918, '2015-09-22 19:16:31.860075+00', '2015-09-22 19:16:31.860075+00', 16765, 2, NULL, 'ace', '1-16::  Taking hands, all advance for one, retire for one; men pass the woman on their left across to their right in two bars. Repeat three times. Finish facing new partner, holding both hands.

17-24::  All balance towards the center, balance away from the center; turn towards the center to circle away from partner. Finish facing, both hands held. Balance away from the center then twoards the center; turn awayf rom the center to circle away from partner. Finish in ballroom hold.

25-32::  Step-close-step towards the center, step-close-step away from the center. Partners waltz in a small circle for four bars. Finish opened out into a single circle with woman on right side of partner. Repeat.

', 3);
INSERT INTO 'dancecrib' VALUES (10906, '2018-07-17 06:37:40.157318+00', '2018-07-17 06:46:08.459344+00', 9939, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*
1--::
  1c & 4c turn RH 1½ and face out ; cast inwards (2c & 3c step in) | turn LH ½ into promhold facing nearest ends 
9--::
  Reels3 across, 1c(4c) starting Rsh to 2W(3W), finish on M(W) side. On [16], meet new P, 1M+4W & 4M+1W into promhold facing nearest ends
17--::
  Reels3 on sidelines, 1M+4W(4M+1W) starting Rsh to 2W(3W), finish on W(M) side (2,4,1x,3x) 
25--::
  4c(1c) dance out between 2c(3c) and cast to 2pl(3plx) ; all turn P RH (2,4,1x,3x)
 ', 2);
INSERT INTO 'dancecrib' VALUES (2771, '2012-01-22 19:29:56.746179+00', '2020-01-13 10:25:13.808555+00', 4309, 1, NULL, 'ace', '{{explanation}}

On 2nd chord, 1c change sides (to 1x,2). In top or bottom place couples change sides on [31-32] of the next turn. This dance can be done round the room.



1–::

  1M+2W 1½ RH turn to change places on the side ; 1W+2M turn 1¾ LH to face each other across, and 1M steps in to face 2W for

9–::

  1c+2c Reel4 across (to line across)

17–::

  1M+2W set and turn RH ¾ _while_{4} 1W+2M set and turn LH ¾ (to 2,1x) ; 1c turn BH (2,1x)

25–::

  2c+1c ½ circle4 L [{4}, slow!] ; 2c+1c ½ R&L (2,1x)', 3);
INSERT INTO 'dancecrib' VALUES (14499, '2022-01-01 06:03:51.153983+00', '2022-01-01 06:24:06.431031+00', 16040, 1, NULL, 'ace', '1--::

  2c+4c set and turn RH ¾ ; 1c+2W & 2M+3c+4W & 4M+5c LHA, finishing 2c+4c facing P on midline and 1c+3c+5c in own places   

9--::

  2c+4c Reel4 on midline (omit final Lsh pass) _while{8}_ 1c+3c+5c dance parallel Reels 3 on the sides, 3c starting to the R (shorten the length to between 2pl and 4pl), finish (1,2,3,4,5)  

17--::

  2c+3c & 4c+5c S&Link (1,3,2,5,4) ; 1c+2c set and cast off (3c+5c up)  (3,1,5,2,4)

25--::

  Circle 10 and back  (3,1,5,2,4)

', 3);
INSERT INTO 'dancecrib' VALUES (12790, '2020-05-03 05:56:58.678613+00', '2020-05-03 05:59:02.35289+00', 16916, 1, 202, 'ace', '1--::

  1c+2W Reel3 on Wside, 1M RSh to 2W

9--::

  1c+2M Reel3 on Mside, 1M LSh to 2M

17--::

  1M (1W following) dance down the middle (2c up). On [4] 1M turn 1W RH ¾, 1c dance up to 2pl centre

25--::

  1W+3M+2M LHA _while{4}_ 1M+3W+2W RHA ; 1c ½Fig8 up round 2c to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10846, '2018-06-12 14:25:39.704717+00', '2020-09-19 11:38:50.455975+00', 13693, 2, 1, 'ace', '1–4:: 1c dance down | cast up round 3c (3c down)

    _while_ 4c dance up (making arch) | cast off round 2c (2c up)

5–8:: 2c+4c, 1c+3c dance RH across [4c+1c fin in center in 2pl/3pl,

   4W closely behind 4M facing M''s side, 1M closely behind 1W facing W''s side]

9–12:: ½ “dolphin” Reel4 with 2M, 3W (dancing couples pass LS at end)

13–16:: ½ “dolphin” Reel4 with 2W, 3M 

17–18:: 1c+4c LH across nearly halfway round

19–22:: 1c dance ½ Reel3 across w/2c (fin in center in 3rd pl)

   _while_ 4c dance ½ Reel3 across w/3c (fin in center in 2nd pl)

23–24:: 4c+1c ½ RH across to sidelines [3142]

25–32:: 3c+1c, 4c+2c dance Rights and Lefts', 3);
INSERT INTO 'dancecrib' VALUES (10907, '2018-07-17 08:55:41.744014+00', '2018-07-17 08:59:39.098568+00', 9927, 1, 202, 'ace', '1--::

  1c cast behind own side and dance up between 3c to centre ; 1W+2W+3W RHA _while{4}_ 1M+2M+3M LHA 

9--::

  1c dance up and cast to 2pl ; 1W+2c & 1M+3c RHA, 1c finish in centre LHJ facing opposite side

17--::

  1c BiL | Petronella Turn R into facing Lines3 across ; all set | 1c Petronella Turn to 2plx _while{2}_ 2c & 3c set (2,1x,3)

25--::

  Reels3{6} on sidelines, 1c Rsh to 2cnrs | 1c cross to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10500, '2018-03-10 23:03:34.877024+00', '2018-07-17 10:09:13.74962+00', 3101, 1, NULL, 'ace', '1-::

  1c set adv | &frac12; turn BH to face 2c still NH joined ; 1M/1W set to 2W/2M | 1c turn 2c EH (1x,2)

9-::

    2c repeat [1-8] with 1c (on opp sides) to (1x,2x)

17-::

  2c &frac12; Fig8 up round 1c ; 1c &frac12; Fig8 down round 2c (1,2)

25-::

  1W+2M cross RH | 1M+2W cross RH ; 2c &amp; 1c turn P 1&frac12; RH (2,1)

', 4);
INSERT INTO 'dancecrib' VALUES (9341, '2016-10-02 11:59:00.251982+00', '2016-11-06 01:47:42.501593+00', 17392, 1, NULL, 'ace', '1--::

  1c+4c set | 1c lead to bottom _while{4}_ 4c cast to top | 1c+4c cross RH and face out (4x,2,3,1x)

9--::

  1c+4c cast inwards (2c+3c to ends) | Turn LH into a St Andrew''s Cross, Rsh to Rsh with end couple ; All “Olé step” (turn single clw in PdB with RH up and LH on hip) (2,4x,1x,3)

17-20::

  1c+4c LHA, and join NH with cnr, all facing cclw

21-28::

  All in star LHA , finish 4c+1c facing cnrs

29-32::

  2c+4c & 1c+3c (4c & 1c dancing out the ends) turn EH to sidelines | 4c+1c cross RH (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11548, '2019-01-29 17:43:09.719293+00', '2019-01-29 18:41:13.390073+00', 17500, 1, NULL, 'ace', '*Ceilidh dance*

1--::

  Form a chain NHJ from 1W down, across bottom and up to 1M, and, 1W leading, chain dances through arch made by 1M+2M, and cclw round set back to places

9--::

  Repeat, 1M leading chain through arch by 1W+2W, and clw to places

17--::

  All dance BtoB with P ; All turn P RH to places, but 1C stays BHJ(crossed)

25--::

  1c dances to bottom BHJ, turning or birling ad lib, (other cpls up on [31-32])', 3);
INSERT INTO 'dancecrib' VALUES (10176, '2017-10-14 07:50:07.142848+00', '2018-04-08 08:12:36.398106+00', 18011, 1, 202, 'ace', '1--::

  1c Fig8 round 2c

9--::

  2c followed by 1c lead down ; 1c followed by 2c lead up, staying in middle

17--::

  1c+2c Promenade, on [23-24] 1c cast off to 2pl, 2c dance to top (2,1)

25--::

  2c+1c RHA ; LHA (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (11264, '2018-10-13 15:16:05.034442+00', '2018-10-13 15:42:26.4616+00', 11779, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 R to (2,1,3)

9--::

  Reels 3 on the sides, 1c Rsh to 4cnr, at end 2c&3c face out  (2,1,3)

17--::

  1c petronella (in skip-change) to face P on midline _while{2}_ 2c+3c cast to meet on sidelines near 2pl and face P | 1c set to P _while{2}_ 2c+3c cross RH ; All chase clw to own side (M:1,3,2 and W 3,2,1)

25--::

  1M+2W & 3M+1W change places diagonally RH | 2W+1W & 3M+1M (same dancers) change places on sides LH : 1W+3M & 2W+1M (same dancers) change places diagonally RH | All set to P (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (10699, '2018-04-27 06:17:26.876348+00', '2018-04-27 09:50:03.589327+00', 13808, 1, 202, 'ace', '_Reel_

1--::

  1c+2c set | 1c cast (2c up) ; 1c+3c set | 1c cast (3c up) (2,3,1)

9--::

  1c+3c DblFig8 round 2c, 1c cross up to start (2,3,1)

17--::

  Circle6 and back, 3c & 1c staying in centre BHJ for

25--::

  Poussette (2,1,3)



_Strathspey_

33-64::

  Repeat [1-32] from new positions in Strathspey time', 2);
INSERT INTO 'dancecrib' VALUES (10564, '2018-04-02 00:28:41.772647+00', '2018-04-02 06:24:54.155961+00', 18257, 1, 202, 'ace', '1--::
  Mirror Reels3 on sidelines, 1c cast off to start and cross up on [7-8] to 1pl (1x,2,3)
9--::
  1c cross RH | cast (2c up) ; 1c pivot turn with elbow grip into lines of 3 across, 1W(1M) between 2c(3c) facing out
17--::
  Reels3 across, 1c start Rsh to 4cnrs
25--::
  1c cast R to 2pl ; 1c pivot turn with elbow grip to 2pl _while{8}_ 2c+3c R&L up/dn (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10175, '2017-10-14 07:12:04.998747+00', '2018-04-10 11:17:19.600018+00', 18012, 1, 202, 'ace', '1--::

  1c set | turn BH ; dance down between 2c | cast up to 1pl

9--::

  1c & 2c ½ turn and cast away to exchanged places : chase clw ½ (2,1,3)

17--::

  2c+1c Poussette

25--::

  1c+3c Petronella in tandem | change places RH (up/dn) ; Petronella in tandem to sidelines | set (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (10174, '2017-10-13 21:06:21.881161+00', '2018-04-08 08:42:39.031193+00', 18014, 1, 202, 'ace', '1--::

  1c+2c+3c Mirror Reels3 on sidelines, 1c cast off to start

9--::

  1c cast below 2c | cross RH ; cast up to 1plx | turn RH ½ into allemande hold, 2c step in on [15-16]

17--::

  1c+2c Allemande (2,1,3)

25--::

  Circle6 and back (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10700, '2018-04-27 10:01:36.014528+00', '2018-04-27 10:09:56.31331+00', 13809, 1, 202, 'ace', '1--::

  1c & 4c turn BH ; 1c+2c & 3c+4c S&Link (2,1,4,3)

9--::

  1c+4c Circle4 L staying in centre BHJ for ; ½ Poussette (2,4,1,3)

17--::

  2c+4c & 1c+3c Circle4 L staying in centre BHJ for : ½ Poussette (4,2,3,1)

25--::

  4c & 1c turn BH ; 4c+2c & 3c+1c S&Link (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12787, '2020-05-01 17:10:29.207995+00', '2020-05-01 17:14:32.007309+00', 18710, 1, 202, 'ace', '1--::

  1c set | cross RH ; 1c+2c set | cross LH (1,2x,3)

9--::

  La-Chain (1,2x,3)

17--::

  2c cross down between 3c | cast up to 2pl ; 2c turn 1c on sides EH 1½, 2c in and up (2,1,3)

25--::

  All A&R ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14748, '2022-04-07 05:06:24.546532+00', '2022-04-08 15:14:39.938522+00', 20578, 1, 202, 'ace', '1--::
  1M,2W,3M & 4W Advance _while_ P retire | and back ; all chase clw ½ (4x,3x,2x,1x)
9--::
  Repeat [1-8] (1,2,3,4)
17--::
  1c+2c ½ R&L ; 1c+3c ½ R&L (2x,3x,1,4)
25--::
  1c+4c ½ R&L ; all turn P 1½ (2,3,4,1)

*Deviser''s note* : if many dancers are complete beginners, like in a ceilidh, the advancing and retiring part may get into a mess. You may then adapt in two different ways.  
1. Bars 1-4 all men advance for 2 bars while all women retire, then all dance back to place, and bars 9-12 all women advance for two bars while all men retire, then all dance back to place.  
2. Those who start the dance advancing will always advance during the four times through, and those who start retiring will always retire, so that you can keep the shape of waves.', 5);
INSERT INTO 'dancecrib' VALUES (10010, '2017-07-17 23:54:38.181038+00', '2021-10-13 21:26:02.873386+00', 9486, 1, 202, 'ace', '1--::
 1M+2W turn RH ; 1c+2c Circle4 L
9--::
 1W+2M turn LH ; 1c+2c Circle4 R
17--::
 1c lead down {3}, lead up {3} | cast off (2c up)
25--::
 2c+1c R&L (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (8875, '2015-08-26 22:13:03.126007+00', '2018-10-14 06:38:37.488295+00', 16534, 1, NULL, 'ace', '1--::  1c+2c & 3c+4c dance the Rose Progression:  

::  1L+2M change places RH | cast to R ; turn BH ½ & twirl on 1diagonal _while{8)_  

::  1M+2L set | turn BH ½ & twirl on 1 diagonal | cross to own side (2,1,4,3)  

9--::  All chase clw ½ round ; all set | all turn RH ½ into

17--::  3c+4c & 1c+2c 6 bars of Allemande | all turn LH ½ to (4x,3x,2x,1x)

25--::  All chase cclw ½ round ; 1c+2c and 3c+4c circle4 R (1,2,3,4)

33--::  S&Link4 (All set | dancers on L dance, dancers on R cast, ends moving one place, middles moving two places) ; 3c+1c and 4c+2c circle4 L (3,1,4,2)

', 3);
INSERT INTO 'dancecrib' VALUES (9077, '2016-01-20 22:14:04.730626+00', '2018-10-14 06:57:07.096568+00', 16535, 1, NULL, 'ace', '1--::

  1c lead down (2c+3c up) ; lead up to 3pl and turn RH to face out on M side, 1W behind 1M

9--::

  2M+3M & 1c & 4W+5W diag. Rsh Reel3, all pairs lead-change at both ends, finish 1W behind 1M giving Lsh to 4M

17--::

  2W+3W & 1c & 4M+5M diag. Reel3, all pairs lead-change at both ends, 1c finish in 3pl facing down NHJ

25--::

  1c dance between 4c, cast behind 5c (4c+5c up) ; 1c pivot turn with R elbow grip (2,3,4,5,1)

', 3);
INSERT INTO 'dancecrib' VALUES (14620, '2022-02-22 16:32:14.389425+00', '2022-02-22 16:33:14.928606+00', 20669, 1, 1645, 'ace', '1--::

  1c lead down & up

9--::

  1c+2c+3c Set&Rotate (3,2,1,4)

17--::

  3c+2c & 1c+4c petronella in tandem | set ; petronella in tandem | cross RH (2,3,4,1)

25--::

  All Circle8 to L & back (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (12175, '2019-09-05 10:57:18.358912+00', '2019-09-06 00:28:15.419777+00', 15235, 1, NULL, 'ace', '*start (1,2x,3,4x)*  

1-::

  1c+2c & 3c+4c S&Link ; 1W+4M & 1M+4W turn LH (2x,1,4x,3)

9-::

  1c+4c ¾ La-Chain | turn P LH 1½ (2x,4,1x,3) 

17-::

  Reels4 on the sides, but on [23-24] form two diagonal lines, 1c+4c not passing but dancing round R to finish BtoB facing corners (2x,1,4x,3)

25-::

  *"Puffin Reels"* 2c+3c full diag. Reels4 (½LHA in the centre) _while{8}_ 1c+4c dance round their cnr Rsh | all pass Lsh in the middle to next cclw cnr ; dance round that cnr Rsh | all pass Lsh to face next cnr (2x,4,1x,3)

33-::

  2c+4c & 1c+3c RHA ; All turn P 1½ (2,4x,1,3x)

', 4);
INSERT INTO 'dancecrib' VALUES (10011, '2017-07-18 00:25:14.299035+00', '2019-08-20 20:48:50.085515+00', 17900, 1, 202, 'ace', '1--::

 1M+2W A&R ; dance BtoB

9--::

 1W+2M repeat

17--::

 1c cross RH | cast one (2c up) ; 2c cross RH | cast one (1c up) (1x,2x)

25--::

 1c+2c A&R ; 1c+2c ½ R&L', 2);
INSERT INTO 'dancecrib' VALUES (10908, '2018-07-17 21:55:08.682903+00', '2018-07-17 22:00:07.162395+00', 18408, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; turn LH 1¼ to face 1cnrs (2,*1*,3)

9--::

  »Corners Pass And Allemande Turn R« on 1diag [same figure as Corners Pass And Turn, except that cnrs dance an Allemande Turn to the Right and 1c meet P in centre at end] ; all cnrs chase clw ½ _while{4}_ 1c turn LH 1¼ to face 2cnrs[pos] (3x,*1*,2x)

17--::

  Repeat [9-12] on 2diag ; repeat [13-16], 1c finish in centre Lsh to P facing opposite side (2,*1*,3)

25--::

  1W+2c & 1M+3c RHA (to 2,1,3) ; all turn P RH (or birl) (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10909, '2018-07-18 03:14:15.734024+00', '2018-07-18 03:18:12.304235+00', 18410, 1, 202, 'ace', '1--::

  1c+2c Tourbillon (2,1,3)

9--::

  1c+1cnrs set, 1c advancing BtoB to 1cnrs | turn 1cnrs BH into lines3 across ; repeat [9-12] with 2cnrs (2,1x,3)

17--::

  ½ Reel4 on 1diag, 1c passing P Lsh, into lines3 across ; ½ Reel4 on 2diag, 1c passing P Lsh (3x,1,2x)

25--::

  1W+3c & 1M+2c Circle3 L {3}, open (1c leading) into ½ Circle6 L {3} | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10179, '2017-10-14 09:09:54.077825+00', '2018-04-10 17:11:40.261606+00', 16776, 1, 202, 'ace', '1--::

  1c set | turn RH ; cast (2c up) | turn LH 1 ¼ to face 1cnrs

9--::

  1c with 1cnrs Corners pass and turn; repeat with 2cnrs (2,1,3)

17--::

  Parallel Reels3{6}, 1c Rsh to 3 cnrs to start, 1c finish in middline | 1c turn ¾ RH to 1diag

25--::

  BiL on 1diag | turn ¾ RH to 2diag ; BiL on 2diag | turn ¾ RH to 2pl (2,1,3)

33--::

  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (10012, '2017-07-18 22:28:39.617528+00', '2017-07-18 22:34:12.855378+00', 17832, 1, 202, 'ace', '1--::

 1c Fig8 round 2c

9--::

 1c Reels3 on opp side (1x,2,3)

17--::

 1c Reels3 on own sides (1,2,3)

25--::

 1c cross RH | cast one (2c up) ; 1c turn RH 1 ½ to 2pl (2,1,3)

33--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2534, '2012-01-22 19:29:46.613751+00', '2018-07-28 18:07:39.150357+00', 8922, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; dance between 3c and cast to 2pl

9–::

  1c A&R ; 2c+1c+3c A&R

17–::

  1c turn RH | cast off (3c up) ; 2c+3c+1c turn LH

25–::

  3c+1c Poussette (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3561, '2012-01-22 19:30:31.20695+00', '2020-05-15 14:51:22.03428+00', 7227, 1, NULL, 'ace', '1–::

  All Circle8 and back

9–::

  1c+3c ½R&L into line up/down (W in middle) ; set to P, ¼RH turn to promhold facing in, 2c&4c turn back to P

17–::

  1c & 3c start to R for Rsh Reels3 across with the closest persons of the other couples

25–::

  1c+3c ½R&L ; All C set & turn RH.

33–::

  All W Fig8 round P & cnrs passing behind P first, _while{8}_ all M A&R to centre twice.

41–::

  All turn RH ; dance BtoB with P.

49–::

  All M Fig8 round cnrs & P, casting behind cnr first, _while{8}_ all W A&R to centre twice

57–::

  All RH turn with cnr, LH turn with P.

65–::

  Repeat 1-64, side couples leading.



{{explanation}}

(This is Priddey''s simplified version of his own »Fete Champêtre«, a demonstration dance).', 2);
INSERT INTO 'dancecrib' VALUES (9272, '2016-07-14 16:53:57.628753+00', '2018-10-14 11:27:11.616891+00', 17143, 1, 1041, 'ace', '1--::

  1c+3c set | 1W&3W (M following) dance between couple on the R, cast L, and back to places through the middle of the set, passing other couple Lsh  

9--::

  2c+4c repeat (1,2,3,4)  

17--::

  All turn P LH ¾, retain LH, all men join RH | all set ; M RHA 1¼ _while{4}_ L chase ½ cclw round the set  

25--::

  All pass P Rsh (W to next M place, M to next W place) | La Baratte with new partner (M have now moved ½ round clw. W ¾ round cclw)  

33--::

  All pass corner Rsh | La Baratte with next person (W finish in original places, M progressed one place cclw)   

*Note that for [21-40] M only progress clw, W cclw*

', 4);
INSERT INTO 'dancecrib' VALUES (10910, '2018-07-18 09:59:27.819642+00', '2020-08-06 15:13:49.256582+00', 3285, 1, 202, 'ace', '1--::

  1c & 2c turn RH ; turn LH into promhold (1,2)

9--::

  2C Promenade (1,2)

17--::

  1c dance down (2c up on [19-20]) ; and up to 2pl (2,1)

25--::

  Circle4 and back', 2);
INSERT INTO 'dancecrib' VALUES (7910, '2013-08-21 08:31:51.213994+00', '2023-02-04 01:23:11.474945+00', 7079, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s & 3s petronella turn & set (Ladies BtoB facing partner) & dance
    1/2 RSh reel of 4
9-12::
    1s & 3s petronella turn to opposite sides (Lady on Mans left) & set
13-24::
    2s & 4s repeat bars 1-12 _while_ 1s +3s dance 1/2 R&L (RH to partner
    to start) ending in corners & set HS to other partner
25-28::
    1s & 3s adv 2 steps to ptnr, turn right about to BtoB with ptnr &
    set _while_ 2s & 4s cast away from ptnr, turn right about to face
    1s/2s & set
29-32::
    All dance 1/2 reels of 4 across & end in original places
33-64::
    2s & 4s repeat bars 1-32

{{title}}
Reel

1-64::
    Repeat in Reel time but PdB setting instead of HS', 0);
INSERT INTO 'dancecrib' VALUES (10494, '2018-03-08 18:12:42.998015+00', '2020-08-07 03:45:33.573866+00', 4475, 1, 1645, 'ace', '1-::

  1c set | cross RH ; set | cast off (2c up) to (2,1x)

9-::

  1c dance up touching NH | cast off ; set | cross up RH to 1pl _while{8}_ 2c dance as 1c in [1-8] (1,2x)

17-::

  W: set facing | cross RH ; set | cast (1W up above 2M, 2W down below 1M) _while{8}_ M: stand | set facing ; cross RH | set

25-::

  W dance across _while{2}_ M cross LH | both &frac12; turn P RH ; 1c continue &frac12; turn RH | cast off (2c up) to (2,1)

', 4);
INSERT INTO 'dancecrib' VALUES (2031, '2012-01-22 19:29:16.011545+00', '2020-09-19 11:41:02.979895+00', 13696, 1, NULL, 'ace', '1–::

  1W+3M set advancing to face P on 1diag| 1c+3c ½ reel4 | dance on, 1M+3W crossing, to (3,2,1)

9–::

  2c+1c set | ½ RHA ; 1c+2c set | 2c cross RH _while_{2} 1c turn RH to face out opp. side (3,1x,2)

17–::

  1c cast R, pick up 1cnr in promhold into ; ½ RHA, the cnrs to exchanged places | 1c turn LH to 2plx facing out

25–::

  1c cast L, pick up 2cnr in promhold ; ½ LHA, the cnrs to exchanged places | All C turn RH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10664, '2018-04-21 10:09:21.66269+00', '2018-07-18 15:51:06.689858+00', 1840, 1, NULL, 'ace', '*This dance begins with a 20 bar fugal sequence: 1c, 2c, 3c &amp; 4c dance successively shorter variations of it.*



1-8::

  1c BtoB ; 1c turn BH &amp; face out

9-12::

  1c cast, cross down between 3c, cast to below 4pl _while_ 2c BtoB

13-16::

  1c BtoB _while_ 2c turn BH &amp; face in _while_ 3c BtoB

17-20::

  1c cross RH &amp; cast up, 1M(1W) to above(below) 2pl _while_ 2c turn RH, 2M(2W) to below(above) 2pl _while_ 3c turn BH _while_ 4c BtoB

21-24::

  1M+2M turn BH _while{2}_ 1W+2W &frac12; turn BH | 1c+2c+3c advance _while{4}_ 4c turn 1&frac14; RH (1,2,3,4: all RSh to P on centre line)

25-28::

  All adv{1} to R &amp; ret{1} to R past one person | ret{1} to R &amp; adv{1} to R past another person, 1W &amp; 4M (ends) turn about to face own sides

29-32::

  Repeat with 2W &amp; 3M turning about at the ends, end all on centre line W at top (2,3,1,4) M at bottom (1,4,2,3)

33-36::

  All dance 4 bars of Reel8, RSh to person on R, end facing P up/down (4,3,2,1)

37-40::

  All turn P 1&frac14; BH (4,3,2,1)

41-48::

  4c+3c+2c &frac12; circle6 | BtoB | &frac12; turn P BH _while{8}_ 1c BtoB ; turn BH (2,3,4,1)

', 4);
INSERT INTO 'dancecrib' VALUES (9261, '2016-07-13 07:54:19.518029+00', '2018-10-14 14:53:14.877836+00', 17136, 1, NULL, 'ace', '*Part A*  

1--::  1c dance between 3c, divide, and cast back round 3M(3W) into the centre, dance out through side couples and back to places  

9-20::  1c turn P (R elbow grip) | turn next person in the circle (L elbow grip) ; repeat {4} twice, always with next person down on the same side  

21-24::  1c dance back to places and face out | set turning inwards to face in (1,2,3,4)  



*Part B*  

1--::  2 bars of Schiehallion reel (M through middle) | turn new cnr (L elbow grip) ; advance with cnr (M on L) | M retire with the W on the L 

9--::  2 bars of Schiehallion reel (W through middle) | turn new cnr (L elbow grip) ; advance with cnr (W on L)| all retire with P (2,3,4,1)

17--::  Circle 8 and back 

', 3);
INSERT INTO 'dancecrib' VALUES (2057, '2012-01-22 19:29:17.450743+00', '2020-09-19 13:16:24.250553+00', 13697, 1, NULL, 'ace', '1–::

  2c+3c ½ RHA, finish in middle facing »cnrs« | change place with cnr LH ; 1c+4c ½ RHA | Change place with cnrs LH (4x,3xmid,2xmid,1x)

9–::

  2c+3c set to cnrs | dance out the ends and cast to middle places _while_{4} cnrs A&R diag. (4x,3x,2x,1x) | All set

17–::

  Reels4 on the sides

25–::

  All A&R ; 4c+3c & 2c+1c ½ R&L (3,4,1,2)

33–::

  All A&R ; 4c+1c S&Link (3,1,4,2)', 3);
INSERT INTO 'dancecrib' VALUES (2476, '2012-01-22 19:29:41.595308+00', '2022-11-07 19:45:03.515482+00', 3119, 1, NULL, 'ace', '{{explanation}}

Square set with 5c facing 1c and 6c facing 3c.



1–::

  1c+5c+6c+3c parallel Reels4 up/down the set, to places

9–::

  Facing couples (1c+5c & 6c+3c) dance BtoB _while_{4}   2c+4c A&R across ; facing couples half R&L, 1c & 3c end facing side couples

17–::

  2W+1c+4M & 2M+3c+4W parallel Reels4 across

25–::

  Each centre dancer (1c+3c) + his two corners RHA ; 1c+3c LHA in centre _while_{4} corners Circle8 ¾ L (this circle is very quick and must get round in time ; can be replaced in social events by a ¾ clw chase; or by a circle8 ¼ L or R and set or by chase ¼ clw or cclw and set) (finish 2, 6, 4, 5, 1c facing top, 3c facing bottom)



{{explanation}}

Danced 3 x 32 as Strathspey, then again as Reel', 3);
INSERT INTO 'dancecrib' VALUES (11549, '2019-01-29 21:42:50.505174+00', '2019-01-30 16:54:16.979521+00', 9558, 2, 1645, 'ace', '1-::

  1c turn RH | cast off (2c up) ; turn 1&frac14; LH to lines across facing 1cnrs

9-::

  1M followed by 3W & 3M &frac34; fig8 LSh round 3W pos, across to 3M pos, up M side & across to 1W pos ending in line across in 1pl facing down (1M,3W,3M) _while{8}_ 1W+2c dance similarly to line across in 3pl facing up (2W,2M,1W)

17-::

  1M+2W, 3W+2M & 3M+1W turn opposite ; chase &frac12; clw to lines across

25-::

  All repeat [17-24] back to original lines across

33-::

  3W+2W & 3M+2M cross RH | 1M+3M & 2W+1W cross RH ; all chase &frac14; clw (2x,1,3x) | 2c & 3c cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14621, '2022-02-22 17:32:50.290324+00', '2022-02-22 17:57:19.356455+00', 20670, 2, NULL, 'ace', '1-8::

  1s Set, lead down, cross out between 2s & 3s, cast up to top & turn RH

9-16::

  1s (promenade hold) reel of 3 with 2s ( Rsh to M2)

17–24::

  1s (promenade hold) reel of 3 with 3s ( Rsh to M3)

25–28::

 RH across (L1 with 2s & M1 with 3s)  

           (NB. M1 has to turn back on himself – with a flourish!)

29-32::

  LH across (L1 with 3s & M1 with2s)

33–40::

  2s, 1s & 3s circle to Left & back', 5);
INSERT INTO 'dancecrib' VALUES (4717, '2013-08-21 08:30:53.870395+00', '2023-02-17 13:06:50.940113+00', 1242, 3, NULL, 'ace', '1-8::

    1s & 2s set, dance 3/4 double Fig of 8 with 1s casting to start; end

    with 2s in top place & 1s in 2nd place on opposite side   2 (1) 3

9-16::

    1s give LSh to 1st corners & dance 1/2 reel of 3 on sides (1M

    down/1L up), turn 1st corner persons (in 2nd corrner pstn) 2H moving

    into 4H round 1/2 way _while_ 2nd corners chase round anticlockwise

    1/2 way  (2) 1 (3)

17-24::

    1s give LSh to 2nd corner person (in 3rd corner pstn) & dance 1/2

    reel of 3 on sides (1M up/1L down), turn 2nd corner persons (in 4th

    corner pstn) 2H moving into 4H round 1/2 way places _while_ 1st

    corners chase anticlockwise 1/2 way, 1s end in 2nd place on opposite

    side  2 (1) 3

25-32::

    2s+1s+3s set, petronella turn into centre, 1s turn 2H once round as

    2s & 3s turn 2H 1/2 way & all petronella turn to own sides', 0);
INSERT INTO 'dancecrib' VALUES (12177, '2019-09-05 15:58:29.693273+00', '2020-02-16 01:23:37.442584+00', 4625, 1, NULL, 'ace', '1--::

  1c Fig8 down round 2c (1,2)

9--::

  1c lead down ; and up

17--::

  1c cross RH | cast off (2c up) ; 1c ½ Fig8 up (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (12179, '2019-09-05 22:20:13.428445+00', '2020-02-16 01:35:33.10687+00', 15130, 1, NULL, 'ace', '1--::

  NHJ on sidelies all slip R | slip L ; All dance BtoB with P (1,2,3,4)

9--::

  1c turn RH | cast off (2c up) ; cross LH | cast off (3c up) (2,3,1x,4)

17--::

  1c cross RH | cast off (4c up) ; All turn P RH to own side with all W facing down and a bit above their P who face up (2,3,4,1)

25--::

  All slip R passing in front of P | slip back ; All turn P RH (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (12656, '2020-03-08 22:14:04.53837+00', '2020-03-08 22:35:04.480212+00', 19859, 1, NULL, 'ace', '*4 dancers in a line, middles facing ends*

1--::

  Reel4 (1,2,3,4)

9--::

  Each end+middle dance (gypsy) round the other ; Middles turn LH _while{4}_ ends set twice, pivoting clw ¾ (1,2,3,4)

17--::

  BiL | Ends & Middles change place RH ; BiL | Middles change place LH (2,4,1,3)

25--::

  ½ Reel4 ; All pivot once (3,1,4,2)

', 3);
INSERT INTO 'dancecrib' VALUES (12178, '2019-09-05 19:07:19.351489+00', '2021-02-21 19:51:47.647182+00', 19631, 1, 1645, 'ace', '1-::

  Mirror reels3 on sides taking hands where possible, 2c start up and out

9-::

  1c lead down & up, end in centre facing up

17-::

  1c long cast to 2pl (2c up on [19-20]) ; 2c+1c+3c dance BtoB

25-::

  Circle6 & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13811, '2021-03-12 17:51:38.562473+00', '2021-03-12 19:46:02.19661+00', 20266, 1, 202, 'ace', '1--::
  1c ½ Fig8 down round 2c | 1c cross down (no hands) ; turn 2c, RH on Mside, LH on Wside into facing down line4 across in top place, 1c between 2c
9--::
  All dance down. On [12] 1c turn in and 2c meets, all NHJ ; 1c (2c following) dance up and cast off as 2c loop to 1pl (2,1)
17--::
  2c+1c ½ R&L ; set | cross RH (1,2)
25--::
  The Tourbillon (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2610, '2012-01-22 19:29:49.84275+00', '2021-03-13 16:27:48.631502+00', 3615, 1, NULL, 'ace', '1–::

  1W set advancing to 2M | turn 3M BH finishing between 2M and 3M ; 1M set advancing to 2W | turn 3W BH to finish between 3c _while_ 2c steps up and 1W slips between them

9–::

  All set twice in lines across, 1c Petronella into 2plx on [11-12] ; 2c+1c+3c set twice, 1c finishing facing 1cnr

17–::

  Set to and turn corners, finishing between corners

25–::

  2c+1c+3c A&R ; 1c turn BH 1½ to 2pl', 3);
INSERT INTO 'dancecrib' VALUES (2210, '2012-01-22 19:29:25.952464+00', '2020-11-15 13:42:56.614226+00', 2110, 1, NULL, 'ace', '1–::

  1c+2c Set&Rotate (All set | petronella clw one place ; change places RH with P | chase one place clw) (2,1,3,4)

9–::

  ½ diagonal R&L with 1cnrs (W up, M down) _while{4}_ the 2cnrs (2M+3W) set & cross RH, all cnrs face out ; ½ Reels3 on the sides, 1c Rsh to 2cnr pos. (no loops at the end) (2x,1x,3x,4)

17–::

  Repeat figure from these positions with 2cnr persons (in 3cnr positions ; M up, W down) (to 2,1,3,4), 2c+3c finishing with loops into

25–::

  Reels3 across (Lsh to 1cnr) (2,1,3,4)

33–::

  1c cross down RH between 3c | cast Rsh round new 1cnr (4W resp. 3M) ; change places up/dn LH | cast L (3c up) to (2,3,1,4)

41-56::

  3c+1c+4c repeat the figures [9-24] above (2,3,1,4)

57–::

  3c+1c+4c Circle6 and back (optional: 2c join in for Circle8 and back)  (1c step down, to 2,3,4,1)



{{explanation}}

(note by Drewry: This is really two successive 3c dances of 32 bars, the figures of bars 9-24 being similar.', 3);
INSERT INTO 'dancecrib' VALUES (8471, '2014-12-02 14:47:45.629621+00', '2022-01-14 18:10:24.9558+00', 5155, 2, 160, 'ace', '1–::

 1C 2C set, cross over ; Repeat - end facing up ready for...

9–::

 1C 2C Allemande - bars 15-16 1C turn RH to join LH with 1crnr.

17–::

 Balance in line, 1C turn 1crnr LH & reform line of 4 ; Balance, 1C turn RH to join LH with 2crnr.

25–::

Balance, 1C turn 2crnr LH & reform line ; Balance 1C turn RH to end 2pl own sides.', 2);
INSERT INTO 'dancecrib' VALUES (2156, '2012-01-22 19:29:22.996401+00', '2021-03-13 18:46:00.481161+00', 1907, 1, NULL, 'ace', '1–::

  1c cross down RH and cast to 3plx (2c+3c up) ; 1c turn RH (2,3,1x)

9–::

  Circle6 and back

17–::

  »The Swirl«: 3c+1c turn P RH to face other C in allemande hold | couples change places Lsh ; 1c+3c LHA ¾ {3}, on [24] 1c dance to centre and pivot L to face 1cnr _while_ 3c dance to 3pl

25–::

  SetH&G, finish (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11021, '2018-08-21 06:17:26.341528+00', '2018-08-21 06:23:42.621068+00', 12768, 1, 202, 'ace', '1--::

  All A&R ; turn RH, 1c face out (1,2,3)

9--::

  1c cast | cross RH ; cast | lead up (2c up on [15-16]) to face 1cnrs (2,*1*,3)

17--::

  SetH&G (2,1,3)

25--::

  Circle and back', 2);
INSERT INTO 'dancecrib' VALUES (10911, '2018-07-19 03:49:07.788808+00', '2018-07-19 04:23:52.30435+00', 18258, 1, 202, 'ace', '1--::
  1M advances | 1M+1W+2W set ; ½ Circle3 L (2M up on [5-6])| 1M crosses to 2pl _while{2}_ 1W+2W change places BH (2,1)
9--::
  1W repeat [1-9] with 1M & 2M, 2W stepping down on [13-14] (1,2)
17--::
  1c Petronella Turn | A&R to centre {1+1} taking RH briefly ; »Rsh Turn« [Dance Rsh round P to 1pl] (1,2)
25--::
  1c+2c Circle4 L to finish on 1diag facing P : into ½ Poussette (2,1)  

*Note:*  
»Rsh Turn« (Right Shoulder Turn) is also known as Gypsy Turn, a term now considered offensive by some.', 2);
INSERT INTO 'dancecrib' VALUES (10912, '2018-07-20 12:34:50.279115+00', '2018-07-20 12:35:11.166135+00', 2927, 1, 1645, 'ace', '1-::

  1c cross RH | cast into centre (2c up) using slip step on [4] ; 2c+1M &amp; 1W+3c Circle3 to L

9-::

  1c set to 2cnr | set R to 3cnr, turning with slipsteps on [12] to M facing down, W up ; 2c+1W &amp; 1M+3c Circle3 to L

17-::

  1c &frac12; diagonal RSh Reel4 with 1cnrs, pass LSh | repeat with 2cnrs to end facing 3cnrpos

25-::

  1c set to 1cnr (in 3cnrpos) | set R to 2cnr (4cnrpos), dancing out (skip change) on [28] to (3x,1x,2x) ; 2c+3c &frac12; RHA _while_ 1c dance cclw &frac12; way around them (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12789, '2020-05-03 00:18:27.964085+00', '2021-06-08 09:40:37.713975+00', 18905, 1, 202, 'ace', '1--::

  Reel3 in tandem (with lead change) on Wside, 1W (1M following) RSh to 2W. 1M (1W behind) back to 1pl face out

9--::

  Reel3 in tandem (with lead change) on Mside, 1M (1W following) LSh to 2M. 1c in 1pl face out (1,2,3)

17--::

  1c dance behind own sides (2c up on [19-20]) ; turn inwards and dance back through 2pl to face 1cnrs

25--::

  SetH&G (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9978, '2017-06-25 22:45:44.37022+00', '2017-07-20 17:33:44.93929+00', 17879, 1, NULL, 'ace', '1–::

  1M+2W turn RH ; 1c+2W LHA opening into line facing down, 1M in the middle, 1W on own side, 2W on M side

9–::

  In line across dance down the middle, 2M following, all turn right about ; 2M leads the women back up, 1M following. Finish in a diamond, with 2M at the top facing 1M in 2pl, the W in the sidelines.

17–::

  All set | petronella turn ; set | petronella turn, finishing (1x,2).

25–::

  1c turn P RH into Allemande Hold facing down ; dance down | cross to 3pl (lady curves in, man slides in) (2c+3c up)', 2);
INSERT INTO 'dancecrib' VALUES (10953, '2018-08-08 21:02:05.800832+00', '2018-08-08 21:02:05.800832+00', 14327, 2, 963, 'ace', '1-8::
  1s cross below 2s|1W casts up, 1M casts down|meet in middle for LH turn to face 1st corners  
9-16::
  CPCP to dble triangle position   
17-24::
  2s,1s,3s dance dble triangles, 1s end facing each other  
25-32::
  1s turn RH/LH back to 2nd place own side WHILE 2s and 3s chase ccw around the set 
', 4);
INSERT INTO 'dancecrib' VALUES (3190, '2012-01-22 19:30:15.074915+00', '2019-01-31 13:11:07.808537+00', 9408, 1, NULL, 'ace', '1–::

  1c dance down to 4pl, curving R with NHJ to face up (2c+3c+4c up) ; 1c NHJ set to 4c | turn 4c EH, 1c passing between 4c, finish 1c NHJ facing 3c (4c in 3pl)

9–::

  3c+1c repeat set and turn EH ; 2c+1c repeat, finish 1c in 1plx between 2c facing up

17–::

  1c dance up and cast off to 4plx _while{4}_ 2c+3c+4c set and cross RH ; 2c+3c & 4c+1c RHA  (2x,3x,4x,1x)

25–::

  All set | cross LH ; 2c+3c & 4c+1c LHA to (2,3,4,1) 



', 3);
INSERT INTO 'dancecrib' VALUES (10013, '2017-07-21 22:16:58.897116+00', '2017-07-21 22:18:31.849889+00', 17891, 1, 202, 'ace', '1--::

 1c set | dance down ; cast up round 3c (2c up) | all set (2,1,3)

9--::

 1c ½ Fig8 to R ; all set | 1c turn LH to face 1cnrs

17--::

 1c turn 1cnrs RH | pass Rsh ; turn 2cnrs RH | pass Rsh

25--::

 Circle6 and back ', 2);
INSERT INTO 'dancecrib' VALUES (8384, '2014-08-20 12:04:35.395799+00', '2020-02-08 13:13:52.912583+00', 15571, 2, NULL, 'ace', '1–8::

     1s cross over RH, cast one place. (2s up), 1s dance petronella turn, 1M between 2s, 1L between 3s, and all set in lines across.

9–16::

     Opposing Reels of 3 across, 1s give RSh to 3rd corner to start.  

17–24::

     1s petronella to 2nd place own sides, all set on the sidelines, all Adv+Ret.  

25-32::

     Six hands round and back.    



*(Dance Crib compiled by the devisor, Hans Prade)* ', 5);
INSERT INTO 'dancecrib' VALUES (11771, '2019-04-06 22:14:45.478534+00', '2019-04-18 21:29:39.577733+00', 16842, 1, NULL, 'ace', '1--::

  All turn cnr RH ½ | next person LH ; same cnr RH ½ | P LH  (1,2,3,4), M face out

9--::

  Interlocking La-Chain, all W making ½ RHA twice (1,2,3,4)

17--::

  All S&Link with P, finish all M BtoB in middle, facing the next position cclw, and all W outside own position facing in ; All Set to opposite | turn BH 1¼ (All W in P''s place, with the M whom she turned on her R)

25--::

  All pairs S&Link, finish all W BtoB in middle, each facing the next position cclw, and her P outside that new position facing in ; All Set to P | turn P BH 1¼ (2,3,4,1) ', 3);
INSERT INTO 'dancecrib' VALUES (10913, '2018-07-21 14:35:54.090436+00', '2018-07-21 14:43:29.62856+00', 3375, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; ½ Fig8 up round 2c (2,1x,3)

9--::

  3C Gr-Chain (2,1x,3)

17--::

  ½ Circle6 L, finish in circle M facing W on his R ; all set | turn facing person BH

25--::

  ½ Circle6 L to sidelines (to 2,1x,3) ; 1c cross RH | set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14062, '2021-06-12 23:42:22.151473+00', '2021-06-12 23:44:57.137543+00', 7264, 1, 202, 'ace', '1--::

  1c turn RH | cast off (2c up) ; all A&R (2,1,3)

9--::

  1c cross RH | dance RSh round 1cnrs into facing lines3 across ; all A&R up/down

17--::

  1c cross RH | dance RSh round 2cnrs to 2plx ; 1c turn P RH 1½ to 2pl (2,1,3)

25--::

  1c+2c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1647, '2012-01-22 19:28:52.867772+00', '2019-04-18 21:35:52.96718+00', 11158, 1, NULL, 'ace', '1–::

  1c+2c S&Link flowing into ; 2c+1c+3c ½ Reels3 on sides (1c Lsh to 3c) (3,1,2)

9–::

  3c+1c S&Link flowing into ; 1c+3c+2c ½ Reels3 on sides (3c Lsh to 2c) (2,3,1)

17–::

  1W (1M following) cast to top behind W side, 1W crosses and dances down behind M side and 1M down the middle (to 2,3,1x) | 1c set, finish facing 3c

25–::

  3c+1c turn LH 1½ , 1c finish facing M side ; 1W casts round 2M and down _while_{4} 2M casts round 2W and in through the side to meet P in the middle, both facing down

33–::

  1c turn 3c EH, 1c pass between 3c, to (2,1x,3) ; 1c ½ Fig8 down (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11268, '2018-10-16 16:32:43.978946+00', '2018-10-16 16:40:33.994067+00', 10239, 1, 202, 'ace', '1--::

  1c cross down to 2pl (2c up) | cast behind 3c ; cross RH | cast up to 2pl (2,1,3,4)

9--::

  2c+1c & 3c+4c set | turn P BH, opening out into ; Circle4 L into Reels4 position (2,1,3,4)

17--::

  Mirror Reels4, 1c & 4c start in and up, 2c & 3c out and down (2,1,3,4)

25--::

1c+3c ½ RHA | 1c+4c ½ LHA ; 3c & 4c cross RH | all set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11267, '2018-10-16 16:16:50.415892+00', '2018-10-16 16:42:27.156129+00', 10245, 1, 202, 'ace', '1--::

  1c set | lead to 2pl (2c up) ; 1c+3c RHA (2,1,3)

9--::

  1M(1W) loop LSh round 2M(2W) to 2pl ; 2c+1c LHA (2,1,3)

17--::

  Reels3 on the sides, 1c RSh to 3c. 1c face 1cnrs

25--::

  Set H&G (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11376, '2018-12-13 01:47:11.916225+00', '2022-05-10 14:02:21.927774+00', 264, 1, 202, 'ace', '1--::
  1c+2c Circle4 and back (1,2)
9--::
  1M+2W cross RH | set on 1diag  _while{4}_ 1W+2M set on 2diag | cross RH ; all repeat [9-12]. 1W faces out (1,2)
17--::
  [1c Chase round 2c :] 1W (1M following) cast down round 2W, crosses up between 2C and casts down round 2M to 2pl (2c up on [23-24] (2,1)
25--::
  2c+1c R&L (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11266, '2018-10-16 06:49:43.856643+00', '2018-10-16 06:56:58.861931+00', 9569, 1, 202, 'ace', '1--::
  2c & 3c Fig8 round nearest ends to centre BHJ (1,2,3,4)
9--::
  2c+3c Poussette into Reel4 position (1,3,2,4)
17--::
  Reels4 (1,3,2,4)
25--::
  1c+3c & 2c+4c set | ½ RHA ; all set | cross RH (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (1775, '2012-01-22 19:29:01.710055+00', '2018-02-13 22:20:07.460205+00', 570, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c DblFig8, 1c+3c cross to start, 2c+4c finish facing out

9–::

  Mirror Reels4 on the side, to start 1c+3c cross into opposite reel and 2c+4c cast up, and finish facing out (1x,2,3x,4)

17–::

  1c+3c turn RH ½ moving down as 2c+4c cast up | 2c+1c & 4c+3c ½ RHA ; All turn P BH 1½ into

25–::

  1c+2c & 3c+4c ½ Poussette ; 1c+4c ½ Poussette (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11263, '2018-10-12 21:04:04.337337+00', '2018-10-16 22:33:50.584339+00', 18954, 1, NULL, 'ace', '1--::

  1c cross RH and cast (2c up) ; 2c+1c+3c turn RH ½ and cast away (2x,1,3x)

9--::

  Set&Rotate for 3 (3x,1,2x)

17--::

  1c ½ Fig8 L ; All  turn P RH ½ and cast away (3,1,2)

25--::

  All set | cross RH ; chase clw ½ to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11269, '2018-10-16 23:10:00.059522+00', '2018-10-16 23:10:00.059522+00', 11852, 1, NULL, 'ace', '1--::

  1c+3c petronella to midline (2c+4c up) | set to P ; 1c+3c chase ½ way clw inside the set, passing the others Rsh, and finish in (2,3x,4,1x)

9--::

  repeat [1-8] figure from new positions (3x,4x,1x,2x)

17--::

  3c+4c & 1c+2c ½ R&L ; 3c+2c RHA (4,3,2,1)

25--::

  2c&3c dance to ends _while{2}_ 4c+1c dance in diagonally and face each other in the middle (no hands) | All set twice | 4c & 1c (making arch) change places, to sidelines (3,1,4,2) a

', 3);
INSERT INTO 'dancecrib' VALUES (11274, '2018-10-17 22:29:51.81952+00', '2018-10-18 22:10:26.230928+00', 18080, 1, NULL, 'ace', '1--::

  1c set | Turn BH, face up ; Cast off one , cross Lsh and cast R round 1cnr to midline 

9--::

  1W+2c RHA ; LHA _while{8}_ 1M+(4M+3M following)+ (4W+3W following) Tandem Reel3 across (no lead change), 1M starts Lsh to (3M+4M).  Finish (2,3,4) with 1c facing P from ends of midline

17--::

  1c set "Glasgow Highland" _while{4}_ 2c+3c+4c dance BtoB ; 1c dance to meet (2c up) and Turn BH 1¼  to face out on own side (2,1,3,4)

25--::

  1c turn 3c EH ½ | 1c turn 4c EH ½ ; 4c+1c set and turn P BH (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (14623, '2022-02-24 18:50:16.643577+00', '2022-02-24 18:53:15.049899+00', 16724, 1, 202, 'ace', '1--::

  Circle6 and back

9--::

  1c set | cast off (2c up) ; turn P LH 1¼ to face 1cnrs

17--::

  Set To and Turn Corners (2,1x,3)

25--::

  All set | 1c cross RH ; 1c+3c S&Link (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (14750, '2022-04-09 07:14:43.592542+00', '2022-04-09 07:18:04.214827+00', 11302, 1, 202, 'ace', '1--::

  1c turn RH | cast off (2c up) ; turn LH 1¼ into lines3 across, 1c facing 1cnrs

9--::

  ½ Reels3 across, LSh to 1cnrs. On [12] 1c turn P RH to face 2cnrs ; ½ Reels3 across, RSh to 2cnrs[pos]. On [16] 1c turn P LH ½ to face 1cnrs

17--::

  Turn CPCP. 1c face 1cnrs

25--::

  Reels3 on sides, LSh to 1cnrs | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11270, '2018-10-17 11:07:24.168301+00', '2022-04-26 09:16:12.62832+00', 18977, 1, 202, 'ace', '1--::

  All set | cross RH ; repeat [1-4] (1,2,3)

9--::

  1c Mirror Fig8 on the sides taking hands when possible, start between 2c (1,2,3)

17--::

  1c+2c The Bourrel (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10684, '2018-04-23 17:00:44.521407+00', '2018-07-20 18:22:53.605051+00', 6482, 1, NULL, 'ace', '*This dance begins with a 16 bar fugal sequence: 1c, 4c, 2c &amp; 3c dance successively shorter variations of it, starting down, up, down &amp; up the set each 4 bars.*



1-4::

  1c cross RH | cast off (2c up)

5-8::

  1c &frac12; turn LH to promhold facing down | dance down _while_ 4c cross RH | cast up (3c down)

9-12::

  1c cross below 4pl | cast up to 3pl _while_ 4c &frac12; turn LH to promhold facing up | dance up _while_ 2c cross RH | cast off

13-16::

  1c &frac12; turn LH | 1M (1W) dance down (up) centre &amp; each turn L about to face, 1W above 1pl, 1M below 3pl  _while_ 4c cross above 1pl | cast off to 2pl _while_ 2c &frac12; turn LH | dance up &amp; cross to 1pl, 2M (2W) turning R (L) about _while_ 3c cross RH | cast up to 3pl

17-20::

  1c change pl RH | turn R about _while_ 2c+4c+3c set | cross RH

21-24::

  1c change pl LH | turn L about _while_ 4c set | turn &frac34; LH

25-28::

  1W+4M &amp; 1M+4W &frac12; turn RH | 1c dance down in promhold to 4pl _while{2}_ 4M (4W) cast to R round 2W (3M)

29-32::

  1c turn 1&frac12; RH _while_ 4c cross RH | cast off (3c up) to (2,3,4,1)

', 4);
INSERT INTO 'dancecrib' VALUES (11023, '2018-08-21 08:44:26.489539+00', '2018-10-03 02:19:36.084267+00', 18507, 1, 202, 'ace', '1--::

  1c set | turn BH (2c up) ; dance down between 3c and cast to face 1cnrs (2,*1*,3)

9--::

  Set to and Turn Corners, on [15-16] 1c pass RSh to 2pl (2,1,3)

17--::

  2c+1c The Knot (1,2,3)

25--::

  3C Bourrel, finish with new P (to 3M+2W,1M+3W,2M+1W) ', 4);
INSERT INTO 'dancecrib' VALUES (2671, '2012-01-22 19:29:52.464752+00', '2020-12-08 23:01:02.826511+00', 3798, 1, NULL, 'ace', '1–::

  1c+3c set | cast off (2c+4c up) ; Teapots (RHA for 3 at ends, for 4 in middle =1M+4c+3W)

9-24::

  1c+3c each four diagonal ½Reels4 with cnrs (Mairi''s Wedding Reels, but Rsh pass), ending on midline M above and facing W

25–::

  2c+4c+5c chase 4 positions clw round set to 1,3,5 pl {6} and set _while{8}_ 1c+3c Reel4 finishing facing own side for

33–::

  1c+3c DTr with corners, 1c+3c end with petronella to 3pl/5pl _while{2}_ 4c+5c move up in PdB)', 2);
INSERT INTO 'dancecrib' VALUES (2559, '2012-01-22 19:29:47.633047+00', '2021-03-13 18:56:22.889208+00', 3436, 1, NULL, 'ace', '1–::

  1c+2c set adv. | 1c cast off and 2c turn BH moving up into ; 2c+1c circle4 L (2,1,3)

9–::

  1c+3c set adv. | 1c cast off and 3c turn BH moving up ; 3c dance up one, cast off two _while_ 1c dance up 2 (2c down) (1,2,3)

17–::

  Half G-Chain (1c crossing) ; 2c+1c set adv. | 2c cast off _while_ 1c turn BH moving up (3x,1x,2x)

25–::

  1c+2c circle4 left ; 3c+1c+2c ½circle6 to left (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10301, '2017-12-10 16:13:54.167815+00', '2018-04-07 23:21:11.886184+00', 11048, 1, 202, 'ace', '1--::

  1c+2c RHA ; LHA

9--::

  1c+2c »The Roulette«: [Petronella turn into midline | turn BH 1/2 finishing NHJ 1c facing W side & 2c M side ; 1W+2M RHJ, all dance{1} round clw in a line 1 step, drop P''s hand, 1W+2M (inners) turn RH to finish 1W in 2Wpl and 2M in 1Mpl _while{3}_ 1M & 2W (outers) dance round clw to face P] (2,1,3)

17--::

  1W+2c & 1M+3c RHA, pass Rsh ; LHA to face 1cnrs

25--::

  Turn CPCP (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (8920, '2015-09-22 19:28:36.091186+00', '2015-09-22 19:28:36.091186+00', 16767, 2, NULL, 'ace', '1-8::  1s cross RH and cast into 2nd place, cross left and cast to their left, to end with 1m between 3s and 1w between 2s.

9-16::  RS reels of three across the set, ending with lines of three facing the other line.

17-20::  With hands joined, all set.  1s petronella into 2nd place on partner’s side while corners turn ¼ to face partner.

21-24::  All set.  1s dance another petronella to end with 1m between 2s and 1w between 3s, while the corners turn ¼ to face up or down.

25-28::  All dance back to back with opposite person.

29-32::  1s set and turn ¾ RH to 2nd place on their own side, while corners turn their opposite once round by RH and set to partners.

', 3);
INSERT INTO 'dancecrib' VALUES (10189, '2017-10-18 11:52:43.149064+00', '2018-04-09 09:36:31.632466+00', 17947, 1, 202, 'ace', '1--::

  1c+2c S&Rotate (2,1,3)

9--::

  2c+1c+3c S&Link twice (3x,1x,2x)

17--::

  1c dance up, cast round 3c to 2pl ; ½ Fig8 round 2c (3x,1,2x)

25--::

  ½ Diag R&L to the R ; ½ Diag R&L to the L (2,1,3)

33--::

  All circle6 L {3}, cross R foot over and pivot L ; chase cclw to (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2675, '2012-01-22 19:29:52.628793+00', '2020-12-08 23:05:18.316226+00', 3818, 1, NULL, 'ace', '1–::

  1c turn RH 1½ ; cast off one (2c up), turn ¾ LH to face 1cnrs (1M faces down, 1W up)

9–::

  ½ Lsh Reels3 on the sides ; (i.e. out through the ends) to face 2cnr position ; ½Reel4 on the 2nd diagonal, end facing 4cnr position _while{4}_ the 2cnr persons (1cnr positions) chase cclw half round the set

17–::

  ½ Rsh Reels3 on the sidelines, end facing 3cnr position ; ½ Lsh Reel4 on 1st diagonal, 1c end back-to-back on centre line (1M up, 1W down) _while{4}_ 2cnr persons chase back clw half round the set to own places

25–::

  DTr up/dn, finish (2,1,3)



{{explanation}}

All four ½Reels (3,4,3,4) start with the 1c facing their 1 cnr persons, the 2cnrs dance ½Reel {3}, chase cclw, ½Reel {3}, chase clw.  

This dance is quite tricky, even for good dancers', 2);
INSERT INTO 'dancecrib' VALUES (10186, '2017-10-18 10:18:02.936984+00', '2018-04-10 11:12:10.828219+00', 18001, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; turn RH | cast (3c up) (2,3,1)

9--::

  3c+1c S&L, at end 1c face 2c ; 1c+2c turn LH ½ on sidelines (1,2,3)

17--::

  1c+2c The Knot (2,1,3)

25--::

  1c+3c Poussette', 4);
INSERT INTO 'dancecrib' VALUES (10187, '2017-10-18 10:59:28.740662+00', '2018-04-10 11:37:35.757643+00', 17999, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; turn RH 1 ¼ to face 1cnrs

9--::

  SetH&G, on [15-16] All set

17--::

  All A&R ; 1c Petronella turn to 2pl | All set

25--::

  Mirror Reels3, 1c start in and up (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10915, '2018-07-22 16:41:42.313949+00', '2018-07-22 16:48:19.85184+00', 8760, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 up round 2c (2,1,3)

9--::

  Mirror Reels3 on sidelines, 1c in and down, loops for 2c & 3c at end (2,1,3)

17--::

  All set | cross RH ; 1M+3c & 1W+2c LHA (2x,1x,3x)

25--::

  All set | cross RH ; 1M+2c & 1W+3c LHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11022, '2018-08-21 08:10:16.058945+00', '2018-08-21 08:13:46.848631+00', 12766, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; turn LH 1¼ to face 1cnrs (2,*1*,3)

9--::

  Corners Pass and Turn. On [15-16], 1c pull RSh back to finish in centre 1M(1W) facing up(down)

17--::

  Reels3{6} on sidelines, 1c RSh to 2cnrs | 1c cross LH (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11024, '2018-08-21 12:01:29.6991+00', '2019-02-03 21:02:41.020452+00', 12765, 1, 202, 'ace', '1--::

  1c+2c Petronella Turn | set ; repeat [1-4] (1x,2x,3)

9--::

  1c+2c change places EH (1c start out) | 2c+1c ½ Dbl Fig8, 1c crossing up (to 2,1,3) | 1c set advancing to 1cnrs (2,*1*,3)

17--::

  Turn Corners and Partner (2,1,3)

25--::

  2c+1c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10190, '2017-10-18 12:40:54.772318+00', '2017-10-18 12:46:03.050883+00', 1479, 1, NULL, 'ace', '1–::

  1c+3c BHJ slip across (Men BtoB) ; and back (W BtoB)

9–::

  2c+4c repeat

17–::

  1c+3c RHA ; LHA

25–::

  2c+4c repeat

33–::

  1c+3c Basket Swing   (Alt:  all dance ½ Gr.Chain and set)

41–::

  2c+4c repeat     (Alt:  all dance ½ Gr.Chain and set)

49–::

  Circle8 L         (Alt:  Circle8 L and back)

57–::

  All promenade cclw to places.



Repeat once



Basket Swing: W join hands behind the M’s backs; M join hands behind the W’s backs; all lean back and circle L (Alt: M join hands behind W’s backs, W join hands behind the M, arms on top of men''s; all circle L in tulloch step; with sufficient speed the W’s feet can lift off the floor )

', 3);
INSERT INTO 'dancecrib' VALUES (12793, '2020-05-05 09:44:15.989392+00', '2020-05-05 09:52:57.263069+00', 18930, 1, 202, 'ace', '1--::
  »Mirror 2C S&Link« [: same as 2C S&Link with 1c casting on [3]] ; 1c cross down between 3c and cast up to 2plx (2,1x,3)
9--::
  3C S&Link (3x,1,2x)
17--::
  Diagonal R&L (2,1,3)
25--::
  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10373, '2018-01-06 13:20:25.837528+00', '2019-01-28 23:11:23.735408+00', 14817, 1, 202, 'ace', '1--::

  1c dance down between 3c, separate and cast up, dance out between side cpls and cast back to original places

9--::

  All M RHA ; dance out through P places and chase clw ½ to opposite M places _while{8}_ all W chase clw 1/2 to opposite M places ; RHA to opposite W places (3,4,1,2)

17--::

  All »Set and Progressive Link« [set | M dance to next M place cclw and face out _while{2}_ W cast to next W place clw] ; ½ Double La-Chain, on [24], all cpls finish in promhold facing cclw (4,1,2,3)

25--::

  All cpls in Allemande hold dance cclw (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (1622, '2012-01-22 19:28:51.492057+00', '2018-10-08 21:02:24.962362+00', 9542, 1, NULL, 'ace', '1–::

  All W Fig8, passing in front of corner and behind opposite man

9–::

  All C L-Chain, W making ½ RHA in the centre, finish facing cnrs

17–::

  All Reel once round the set, starting with cnr (M clw, W cclw), one step per passing (»G-Chain without hands«)

25–::

  Set to and turn cnr BH, repeat with P

33–::

  1c+3c set, cross RH, cast right and dance to behind 4c/2c, dance to centre, W Rsh round the couple and M between, swivel right to face that couple

41–::

  6 bars of parallel Reels4 across | 1c+3c face right and dance to 3pl/1pl _while{2}_ 2c+4c dance out to own places (1c & 3c have now changed places)

49-64::

  2c+4c repeat last 16 bars, ending (3,4,1,2)

65–::

  All M Fig8, passing in front of cnr and behind opposite woman

73–::

  All C M-Chain, Men making ½ LHA in the centre

81–::

  All C set, turn ¾ RH to promhold, Promenade halfway round clw to own places

89–::

  Circle8 and back (1,2,3,4)', 3);
INSERT INTO 'dancecrib' VALUES (3570, '2012-01-22 19:30:31.61895+00', '2015-09-22 19:49:45.446352+00', 7267, 1, NULL, 'ace', '1–::

  1c set | cross down (2c up) ; cast R (W up. M down) in through ends and cross RH to facing lines of 3 across (1M+2c & 1W+3c) for

9–::

  Reels3 across, Rsh to 3cnr

17–::

  In lines across set | cross RH ; set | 1c cast clw to outside 2pl own side _while{2}_ 2M+3M & 2W+3W turn BH ½, coming in towards the middle (BtoB with partner) and opening into

25–::

  2M+1M+3M & 2W+1W+3W circle3 left {3} breaking (3W and 2M leading) into circle6 L (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11025, '2018-08-21 20:05:06.906316+00', '2018-08-21 20:48:03.847209+00', 13505, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; 1W+2c & 1M+3c RHA, 1c to 2pl facing in and L (2,1,3)

9--::

  1c Fig8 on sidelines, Lsh to 3cnrs (2,1,3)

17--::

  1W+3c & 1M+2c LHA ; 1c turn P RH to face 2cnr 

25--::

  Reels3 across, 1c Rsh to 2cnrs (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11794, '2019-04-18 22:12:46.015558+00', '2019-04-18 22:41:04.503123+00', 3188, 1, NULL, 'ace', '*start (1,2,3x,4x)*

1--::

  1c&4c Full Fig8 round next couple (1,2,3x,4x)

9--::

  1W+1M+2M & 4W+3M+4M RHA, 2M/3M finish at 1M/4M place ; 1c+4c, W leading, meet Lsh, dance LHA, and dance on into

17--::

  2W+4c & 1c+3W RHA (finish 2c/3c in 1pl/4plx) ; 4c+1c dance out the end and cast L round the end M to (2,4,1x,3x)

25--::

  4c+1c ½ RHA _while{2}_ 2c+3x cross RH | All set ; Repeat LH | All set (2,4,1x.3x)

', 3);
INSERT INTO 'dancecrib' VALUES (8385, '2014-08-20 12:14:20.332068+00', '2020-02-08 13:17:11.205561+00', 15572, 2, NULL, 'ace', '1–4::

     1s and 2s dance Back-to-Back.

5–8::

     1s and 2s turn partner RH 1¼, to finish in line of 4 up and down in the middle, keeping RH joined, 1L joining LH with 2M. (Order from the top: 1M ,1L,2M,2L)

9–12::

     Balance-in-Line. 1L and 2M turn LH ¾ , while 1M and 2L chase clockwise round a quarter, to form a line of 4 across the set.

13–16::

     Repeat bars 9 – 12, to finish again in a line up and down the set, joining RH with partner.

17–24::

     1M and 2M lead their ladies down the middle, 1s leading, 2s following, then 2s divide to let 1s pass up between them, and follow them up, ready for

25–32::

     Allemande.



*(Dance Crib compiled by the devisor, Hans Prade)*', 5);
INSERT INTO 'dancecrib' VALUES (11028, '2018-08-21 21:54:10.915117+00', '2020-02-29 23:51:39.918231+00', 15242, 1, 202, 'ace', '1--::

  1c+2c Espagnole. On [5-8] 1c turn LH to face 1cnrs

9--::

  Turn CPCP, 1c face 1cnrs

17--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag to 2plx (3x,1x,2x)

25--::

  3C S&Link twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3616, '2012-07-21 11:45:56.065085+00', '2018-07-23 10:20:30.363801+00', 14403, 1, NULL, 'ace', '1–::

  1c slip down BHJ | cast up ; turn LH 1½ to face 1cnr

9–::

  Corners'' chain: 1c and corners change places RH | corners turn each other LH ; change back RH | 1c turn LH to 2cnrs

17–::

  Repeat with 2cnrs, 1c turning LH to face 1cnr

25–::

  Set H&G, at end 1c turn RH into the middle to begin anew (second time: to sidelines)', 2);
INSERT INTO 'dancecrib' VALUES (3469, '2012-01-22 19:30:26.749783+00', '2018-07-23 19:48:08.328431+00', 8162, 1, NULL, 'ace', '1–::

  A&R ; A&R

9–::

  All turn P RH ; turn LH

17–::

  All turn P BH ; dance BtoB

25–::

  1c slip down ; slip up

33–::

  1c cast, others following ; 1c arch and others pass under (2,3,4,1)



{{explanation}}

Walking step, begin on left foot.  Can also be danced with more couples in the set', 3);
INSERT INTO 'dancecrib' VALUES (10562, '2018-04-01 04:18:58.884012+00', '2018-04-02 15:31:32.016078+00', 4057, 2, 1727, 'ace', '1-4:: First, 2nd and 3rd couples join hands on the sides and set, then 1st and 2nd couples dance right hands across half way, while 3rd couple cross with right hands.



5-8:: Second, 1st and 3rd couples again join hands and set, then 2nd and 3rd couples cross to own sides with right hands while 1st couple dance a petronella turn to finish back to back facing 1st corner.



9-12:: First couple dance a half diagonal reel of four with 1st corners.  At the end, 1st couple dance in to meet, then pull back right shoulder to face partner''s 2nd corner.



13-16:: First couple dance a half diagonal reel of four with 2nd corners.  At the end, 1st couple dance in to meet, then pull back right shoulder to face own 1st corners, now in opposite corner place.



17-20:: First couple dance a half diagonal reel of four with 1st corners.  At the end, they dance in to meet, then pull back right shoulder to face partner''s 2nd corner, now in opposite place.



21-24::  First couple dance a half diagonal reel of four with 2nd corners.  At the end they dance in to face 1st corners.



25-30:: First corner dances a reel of three on opposite sides, passing 1st corners with left shoulder to begin



31-32:: First couple cross with right hands to own sides, crossing to the bottom the second time.', 2);
INSERT INTO 'dancecrib' VALUES (11275, '2018-10-18 14:20:25.18968+00', '2018-10-18 14:20:25.18968+00', 9064, 1, NULL, 'ace', '*3c+4c cross to opposite side (1,2,3x,4x)*  

1--::

  1c+2c & 3c+4c set | ½ DblFig8 (1c cross down, 4c cross up) | set (1x,2x,3,4)

9--::

  1c+4c cross RH | cast inwards (2c+3c to ends) ; 1c+4c RHA (2x,1,4x,3)

17--::

  1W (P following) & 4W (P following) cast Lsh round end M to finish between end cpl ; ½ Rsh tandem Reel3 across (no lead change) 

25--::

  1c/4c (W leading M) dance along W/M side and curve into 3plx/2pl _while{4}_ 2c+3c set twice ; All turn P RH (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (12209, '2019-09-14 09:29:57.37388+00', '2019-09-14 09:31:22.967795+00', 19474, 1, 202, 'ace', '1--::

  1c set | turn P RH 1½ | cast off (2c up) (2,1x,3)

9--::

  Circle6 and back

17--::

  1c set | turn P LH 1½ | cast off (3c up) (2,3,1)

25--::

  Gr-Chain, 1c crossing RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10916, '2018-07-24 00:10:01.736235+00', '2018-07-24 00:19:39.990751+00', 4938, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 L round 4cnrs to centre, Rsh to P facing 2cnrs (2,*1*,3)

9--::

  Reel4 on 2diag, pass P Rsh to face 2cnrs

17--::

  Reels3 across, 1c Rsh to 2cnrs, finish Lsh to P facing 1cnrs

25--::

  *Lsh* Reel4 on 1diag, pass P Lsh to face 1cnrs

33--::

  Reels3 across, 1c Lsh to 1cnrs (2,1,3)

41--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10917, '2018-07-24 21:01:31.191654+00', '2018-07-24 21:08:25.675454+00', 595, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Mirror Reels3 on sidelines, 1c in and down (3,1x,2)

9--::

  1c cross RH | cast to 3pl (2c up) ; ½ Mirror Reels3 on sidelines, 1c in and up (1,2,3)

17--::

  1c+2c set | ½ RHA ; 1c+3c set | ½ LHA (2x,3x,1)

25--::

  1c cross RH | cast to 2plx (3c down) ; all set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11027, '2018-08-21 21:29:54.904419+00', '2018-08-21 21:31:15.866627+00', 12763, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; set | cast back (2c down) (1,2)

9--::

  1c+2c R&L (1,2)

17--::

  1c lead down ; and up to 1pl centre

25--::

  1c+2c Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11026, '2018-08-21 21:14:38.926065+00', '2018-08-21 21:21:16.645389+00', 12764, 1, 202, 'ace', '1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; dance to between nearest end and finish BtoB | all set 

9-24::

  1c+2c & 3c+4c »Celtic Reel« [1c+2c & 3c+4c pass opposite person Rsh | »outers« chase clw ¼  _while{2}_ »inners« turn (no hands) Lsh ¾ to face same person ; repeat 3 times to starting position in lines across]

25--::

  All set | turn opposite person EH ¾ (1c & 4c starting outwards) ; 1c & 4c ½ Fig8 round nearest end (2,1,4,3)

33--::

  1c+4c ½ R&L ; turn P RH 1½ (2,4,1,3)

41--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (12272, '2019-10-05 19:15:40.133827+00', '2020-01-13 16:34:02.510003+00', 19687, 1, 1645, 'ace', '1-::

  1c+2c Chain progression, but on [7-8] 1c &frac12; turn RH & twirl to face 1cnrs

9-::

  1c+1cnrs &frac12; diag RSh Reel4, 1c pass RSh to face 2cnrs ; repeat with 2cnrs to (3x,1x,2x)

17-::

  S&Link for 3 twice (2,1,3)

25-::

  Circle6 & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2176, '2012-01-22 19:29:23.977332+00', '2020-09-19 13:20:00.628417+00', 13698, 1, NULL, 'ace', '1–::

  1c+4c turn RH ; cast to middle (2c+3c step to end) | ½ RHA and face cnrs

9–::

  Set to cnr | change place RH ; 2c+3c ½ LHA to sidelines | all set (4x,3x,2x,1x)

17–::

  Parallel Reels4 on the sides

25–::

  3c+1c Turn RH 1½ ; 4M+2W cast R and with P following chase clw ½ to exchanged places (2,3,4,1)

33–::

  2c+3c RHA ; LHA _while_ 4c+1c LHA ; RHA', 3);
INSERT INTO 'dancecrib' VALUES (14446, '2021-11-11 15:54:50.461446+00', '2022-02-25 18:48:08.966197+00', 2331, 1, 202, 'ace', '1--::

  All set | cross RH ; repeat [1-4] (1,2,3)

9--::

  1c (+ 2c & 3c who dance up to follow) lead down ; all turn inwards and dance up, 3c casting to 3pl, 2c dancing to 1pl and 1c to 2pl (2,1,3)

17--::

  Circle6 and back (2,1,3)

25--::

  Reels3 on sides, 1c RSh to 4cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11029, '2018-08-21 22:39:19.240984+00', '2018-08-21 22:42:20.542871+00', 12762, 1, 202, 'ace', '1--::
  2c & 3c ½ Fig8 round nearest end. On [4] 2c+3c change places LH on sidelines (to 1,3x,2x,4) ; 2c & 3c ½ Fig8 round nearest end, 1c&2c face down, 3c&4c up (1,3,2,4)
9--::
  All H.Schottische ; turn BH on sidelines (1,3,2,4)
17--::
  Parallel Reels4 (1,3,2,4)
25--::
  1c+3c & 2c+4c The Tournée (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (11031, '2018-08-22 09:22:37.431516+00', '2018-08-22 09:30:34.731565+00', 1503, 1, 202, 'ace', '1--::
  Circle4 L ; 1c cast (2c up) and face 1cnrs 
9--::
  1c+1cnrs set | ½ Reel4 on 1diag | dance LSh round P to face 2cnrs
17--::
  1c+2cnrs set | ½ Reel4 on 2diag | dance LSh round P to 2plx (3x,1x,2x)
25--::
  All set | turn P RH ½ into centre facing up ; 3c followed by 1c & 2c dance up and cast down (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11033, '2018-08-23 21:07:14.347478+00', '2018-08-23 21:11:09.128458+00', 17437, 1, 202, 'ace', '1--::

  1c+2c S&Link ; 1c+3c S&Link (2,3,1)

9--::

  1c set | dance to 1pl ; set | cast to 3pl _while{8}_ 2c set | cast to 3pl ; set | dance to 1pl (2,3,1)

17--::

  1c+1cnrs advance {1} and touch RH, retire {1} | repeat [17-20] with 2cnrs ; all turn P BH (2,3,1)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10307, '2017-12-11 18:59:03.428315+00', '2018-07-27 10:02:46.353292+00', 16520, 1, 202, 'ace', '1--::
  1c+2c Espagnole, finish 2c facing out and down, 1c in and up  (2,1,3)
9--::
  Mirror Reels3, 1c in and up to start, finish facing 1cnrs
17--::
  1c set | dance Rsh round P to face 2cnrs ; set | dance Rsh round P to 2pl (2,1,3)
25--::
  1c+3c »The Roulette« [Petronella turn into midline | turn BH ½ finishing NHJ 1c facing W side & 3c M side ; 1W+3M RHJ, all dance{1} round clw in a line, drop P''s hand, 1W+3M (inners) turn{3} RH to finish 1W in 3Wpl and 3M in 2Mpl _while{3}_ 1M & 3W (outers) dance round clw to face P] (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (12182, '2019-09-06 20:41:54.823926+00', '2019-09-06 20:41:54.823926+00', 19633, 1, NULL, 'ace', '1--::

  All set and cross RH ; 1c+2c & 3c+4c RHA (1x,2x,3x,4x)

9--::

  Reels4 on the sides

17--::

  1c+2c ½ R&L ; 1c+3c ½ R&L

25--::

  1c+4c ½ R&L ; All turn P RH (2,3,4,1)



', 3);
INSERT INTO 'dancecrib' VALUES (11276, '2018-10-18 14:59:22.993711+00', '2018-10-18 15:01:32.020638+00', 10605, 1, NULL, 'ace', '1-4::

  1c set | cast off (2c up)   

5-12::

  All set | 1c turn LH to 1cnr _while_ cnrs chase 1 place clw ; 1c+1cnr (position) join RH and turn RH twice, finish cnr dancer in next cnr clw _while{4}_ the other cnrs set and move one place clw 

13-20::

  Repeat [5-12], 1c now turning dancers in 2cnr (pos), 

21-24::

  1c set to P and turn RH to give Lsh to 1cnr

25-32::

  Reels3{6} on opposite sides, 1c crossing to 2pl at end (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11032, '2018-08-23 18:43:39.423178+00', '2018-08-23 18:48:54.182799+00', 6659, 1, 202, 'ace', '1--::

  1c & 4c set | cast inwards (2c & 3c step out) ; ½ Fig8 round nearest end, finish 2c+1c & 4c+3c facing diagonally (2,1x,4x,3)

9--::

  2M+1M (4M+3M) change places RH(LH) _while{2}_ all W set diagonally | 2W+1W (4W+3W) change places LH(RH) _while{2}_ all M set diagonally ; all repeat [9-12] (2,1x,4x,3)

17--::

  1c+4c set twice ; ½ R&L (no polite turn), finish in Reel4 position (2,4,1,3)

25--::

  Parallel Reels4 (2,4,1,3)

33--::

  Circle8 and back (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10567, '2018-04-02 19:07:39.693906+00', '2018-04-03 18:03:54.431466+00', 13897, 1, 202, 'ace', '1--::
  1c cross RH | cast (2c up) ; 1c+3c ½ R&L (2,3x,1)
9--::
  1c cross RH | cast up to 2plx (3c down) ; 2c+1c ½ R&L (1,2x,3x)
17--::
  All set | cross RH (to 1x,2,3) ; all set | 1c cast to 2plx _while{2}_ cross RH to 1plx as 3c cross LH, 2c & 3c finish facing out (2x,1x,3x)
25--::
  Mirror Reels3 on sidelines, to start: 1c cross RH to 1pl as 2c(3c) dance out and down(up), then on reaching 2plx, 2c(3c) cross LH(RH) to 3pl(1pl), all continue reels on own sides (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11034, '2018-08-24 06:38:49.397295+00', '2018-08-24 06:43:40.259355+00', 17436, 1, 202, 'ace', '1--::

  1c turn 2c EH 1½ (1c starts downwards) ; 1c turn 3c EH 1½ (2,3,1)

9--::

  1c lead to top, cross and cast to 2plx (3c down) ; turn LH to face 1cnrs

17--::

  1c set to all cnrs moving cclw on even bars. On [24] 1c pull RSh back to 2pl (2,1,3)

25--::

  All turn P RH ½, face P | cast R to exchanged places ; all set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9990, '2017-07-01 04:39:17.990908+00', '2019-02-07 00:01:45.08419+00', 12771, 1, 202, 'ace', '1-- ::

 1c lead down and up (2c & 3c step in on [8])

9-- ::

 3C allemande (3,2,1)

17-- ::

 All set | cross RH : chase clw ½ (1,2,3)

25-- ::

 1c cross RH | cast (2c up) ; 1c cross LH | cast (3c up) (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (15087, '2022-09-06 16:53:05.006554+00', '2022-09-06 16:54:12.851429+00', 21100, 2, NULL, 'ace', '1-8::  1W + 3W advance and turn RH; turn partner LH.
9-16::  2W + 4W repeat.
17-24::  1C + 3C half ladies'' chain; 2C + 4C repeat.
25-32:: All set, all men half LH across (2 bars, stay in the middle), set to partner and in promenade hold dance 1 place counterclockwise (2 bars).
', 5);
INSERT INTO 'dancecrib' VALUES (11615, '2019-02-25 17:41:53.029194+00', '2019-04-19 09:47:59.743372+00', 2313, 1, NULL, 'ace', '1--::

  All set, pivoting ¼ so that middles face ends | All petronella turn into lines across (1c+2c & 3c+4c, with M facing M and W  facing W ; ½ Lsh Reel4 across 

9--::

  In lines across middles set to ends | All petronella to (opp.) sidelines ; ½ Lsh Reel4 on sidelines (4x,3x,2x,1x)

17--::

  All NHJ set R and balance L | repeat L/R ; 4W+3M+2W+1M ½ Lsh Reel4 on midline, to original places

25--::

  Repeat 17-24, the other four dancers dancing the ½ reel (1,2,3,4)

33--::

  All set to P | All turn P RH {4}, 1c face out and 2c+3c+4c face up NHJ | 1c cast to 4pl as the others dance up (2,3,4,1)  



*Note: The half reel [29-32] flows better Rsh.  The instructions say "repeat [17-24]"*

', 4);
INSERT INTO 'dancecrib' VALUES (11037, '2018-08-26 11:28:25.377531+00', '2018-10-05 22:12:56.264699+00', 18533, 1, 202, 'ace', '1--::

  1c+2c turn EH 1½ on sidelines (1c start outwards) ; 1c+3c turn EH, 1c face 1cnrs

9--::

  SetH&G. On [15-16], 1c set advancing and pivot R to BtoB facing 1M(1W) up(down)

17--::

  1M+2c & 1W+3c RHA, 1c in centre LSh to P facing own side ; 1c dance LSh round P to 2pl and face out _while{4}_ 2c&3c chase clw ½ (3x,1,2x)

25--::

  1c loop R round 3cnrs[pos] to centre _while{4}_ 3c&2c A&R diagonally ; 1c dance LSh round P to 2pl _while{4}_ 2c&3c chase clw ½ (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11035, '2018-08-26 06:54:18.264797+00', '2018-08-26 07:30:08.92086+00', 17438, 1, 202, 'ace', '1--::

  1M+2W & 2M+3W & 3M+4W turn RH ; 1W+4M turn RH (1,2,3,4)

9--::

  1W+2M & 2W+3M & 3W+4M A&R ; 1M+4W A&R (1,2,3,4)

17--::

  1M+2W cross RH | 1W+2M & 1M+3M cross LH ; 1W+3W & 1M+4W cross RH | 1W+4M cross LH (2x,3x,4x,1x)

25--::

  All dance BtoB ; cross RH | set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12655, '2020-03-05 01:17:44.177195+00', '2020-03-09 01:20:50.995021+00', 6910, 1, 202, 'ace', '1--::

  1M+2W & 2M+3W & 3M+4W cross RH | all set ; 1W+3W & 1M+4W & 2M+4M cross LH | all set

9--::

  Bottom 4 Men RHA ; pivot on [13]  then 3 bars of LHA _while{8}_ Top 4 Women LHA ; pivot on [13] then 3 bars of RHA (3W,2W,2M,3M on Mside, 4W,1W,1M,4M on Wside)

17--::

  Circle8 and back into facing lines4 across, with 4 Women on top and 4 Men on bottom (2,3,4,1 across)

25--::

  2c+3c & 4c+1c R&L (2,3,4,1 across)', 2);
INSERT INTO 'dancecrib' VALUES (9265, '2016-07-13 20:32:12.372458+00', '2018-10-14 14:01:22.636052+00', 17138, 1, 1041, 'ace', '1--::  Grand Chain (1,2,3) 

9--::  1W followed by 1M cast off 1pl and cross to 2plx (2c up on 11-12) ; 1M followed by 1W cast off 1pl and cross to 3pl (3c up on 15-16) (2,3,1)  

17--::  All set | turn P RH ½ and twirl R to opposite side | set (2x,3x,1x)  

25--::  ½ circle6 to (1,3,2) | 2c+1c “The Capstan”: 1c (start inwards) + 2c (outwards) dance 1½ times “easy shoulder” round 3c on the side (1c loop into 3pl). (2,3,1)  

', 4);
INSERT INTO 'dancecrib' VALUES (14708, '2022-03-21 19:53:35.235822+00', '2022-03-21 19:53:35.235822+00', 20726, 2, 963, 'ace', '1-4::  
  1C dance in and up, touch nearer hands and cast to 3rd place (2s,3s up 3/4) in the middle with a quick nearer hand touch  2,3,1
5-8::  
  1C turn 3C (men LH, women RH) 1-1/2 times. 1C are in 2nd place facing out 2,1,3  
9-12::  
  1C turn 2C (men RH, women LH) 1-1/2 times 1,2,3  
13-16::  
  All 3C  set then turn prtn BH back to place  
17-24::  
  All 3C cross RH|1M & 3W on the 2nd crn diag set WHILE 1W&2W, also 2M&3M change places LH on the side: All 3C cross RH| 2W & 2M set on 2nd crn diag WHILE 1W&3W also 1M&3M change places LH on the side - order 3M,1M,2M on men''s side, 2W,3W,1W on women''s side*  
25-28::  
  2W with 3M&3W at the top, 2M with 1M&1W at the bottom, circle 3 hands to the left, 2C releasing hands on bar 27 to dance down/up to meet in 2nd pl WHILE 1C dance into 3rd plc facing up NHJ and 3rd couple dance into 1st plc facing up NHJ  (1C is on opp sides, 2C and 3C are on own sides)
29-32::
  All 3C set| 3C cast to 2nd plc while 2C dance up and curl into top plc while 1C link into 3rd place  2,3,1    

  *This is 8 bars of 3C R&Ls with 2nd crn positions setting instead of changing LH on the diag

', 5);
INSERT INTO 'dancecrib' VALUES (10921, '2018-07-25 23:45:26.375856+00', '2018-07-26 07:16:50.843877+00', 5690, 1, 202, 'ace', '1--::

  1c cross RH to 2plx (2c up) | set ; 1c cross RH | set (2,1,3)

9--::

  All dance BtoB ; 1c turn BH ¾ (PdB) _while{4}_ 2c & 3c cross RH | set, into facing lines3 across

17--::

  Repeat [9-16] up/down. On [21-22], 2c+3c change places RH (3x,1x,2x)

25--::

  ½ Reels3 on sidelines, 1c Rsh to 2cnrs ; all set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10924, '2018-07-26 13:57:35.785431+00', '2018-07-26 14:27:27.517728+00', 5275, 1, 202, 'ace', '1--::
  1c+2c set | 1c cast (2c up) ; ½ Fig8 up round 2c (2,1x,3)
9--::
  1c set to 2cnrs | turn 2cnrs RH to 2plx ; all set | cross RH (2x,1,3x)
17--::
  Repeat [9-16] with 1cnrs persons (2,1x,3)
25--::
  Reels3 on sidelines {6}, 1c Rsh to 2cnrs | 1c cross RH (2,1,3)  

*Deviser''s note:  
On [9-10], 1st couple dance into the centre, back to back on the right setting and finish setting to their 2nd comer on the left foot.*', 2);
INSERT INTO 'dancecrib' VALUES (10922, '2018-07-26 00:34:58.133293+00', '2018-07-26 06:31:31.505651+00', 2503, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA ; 1c+3c set | ½ LHA (2x,3x,1)

9--::

  1c cross RH | cast to 2plx (3c down) ; all set, facing ¼ L on second step | slip R to own side (2 slip steps) passing P BtoB, and pivot L to face P (PdB L foot) (2,1,3)

17--::

  Reels3 on sidelines, 1c Rsh to 4cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11277, '2018-10-19 06:59:34.713358+00', '2018-10-21 00:31:02.89221+00', 18514, 1, 202, 'ace', '1--::

  2c & 4c ½ R&L on 1diag ; ½R&L on 2diag

9--::

  2c & 4c ½ R&L on 1diag ; all A&R {1+1} twice (5,2x,3,4x,1)

17--::

  3c + (2c+5c following) + (4c+1c following) Reels3 in tandem on sides (no lead change), 3c RSh to (2c+5c) (2x,5,3,1,4x)

25--::

  All set | 2c & 4c cross RH _as_ 3c turn P RH ; 3c cast (1c up) | all set (2,5,1,3,4)', 5);
INSERT INTO 'dancecrib' VALUES (10923, '2018-07-26 06:55:04.409258+00', '2018-07-26 07:02:17.279567+00', 5469, 1, 202, 'ace', '1--::

  Mirror Reels3 on sidelines, 1c cast off to start, 1c & 2c continuing the reel (to 2,1,3)

9--::

  All A&R{1+1} | set ; turn P BH ½, face P | cast R to exchanged places (2x,1x,3x)

17--::

  Repeat [9-16] (2,1,3)

25--::

  All Petronella Turn | set ; Petronella Turn | cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10918, '2018-07-25 07:30:01.777047+00', '2018-07-26 07:25:04.41834+00', 5682, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; all set | Circle6 L ½ (3x,1x,2x)

9--::

  Reels3 across {6}, 1c Rsh to 4cnrs[pos] | all set (3x,1x,2x)

17--::

  All A&R{1+1} | 1c cross RH _while{2}_ 2c+3c set ; Circle6 L ½ (2,1x,3)

25--::

  Reels3 on sidelines {6}, 1c Lsh to 1cnrs | 1c cross RH (2,1,3) ', 2);
INSERT INTO 'dancecrib' VALUES (11039, '2018-08-26 22:27:45.213319+00', '2019-02-04 10:59:53.018707+00', 2370, 1, 202, 'ace', '1--::

  1c+2W Reel3 across, 2W LSh to 1M (1,2)

9--::

  1c+2M Reel3 across, 2M RSh to 1W (1,2)

17--::

  1c set | cast (2c up) ; 2c+1c RHA (2,1)

25--::

  2c+1c R&L (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (10927, '2018-07-27 08:42:32.984024+00', '2018-07-27 08:55:13.120214+00', 3408, 1, 202, 'ace', '1--::

  1c+2c Chain progression, 1c face 3cnrs (2,*1*,3)

9--::

  »Modified Reel4« on 1diag [1cnrs dance normal Reel4 _while{8}_ 1c dance Reel4 {2} | chase clw ½ {4} | dance Reel4 {2} _while{8}_ 2cnrs chase clw ¼ {2} | join in Reel4 {4} | chase clw ¼ {2}], 1c pass P Rsh to face 2cnrs 

17--::

  Repeat [9-16] on 2diag (2,1,3)

25--::

  Circle6 and back



*Editor''s note:  

Both diagonal Reels4 are like »Weasel Reel« except that cnrs starting the Reel4 dance a normal Reel4.*', 2);
INSERT INTO 'dancecrib' VALUES (10926, '2018-07-27 01:37:22.95376+00', '2018-07-27 01:51:09.532802+00', 7080, 1, 202, 'ace', '1--::
  1c+2c ½ RHA | set ; cross RH | set (2,1,3)
9--::
  All turn P BH ½, face P | cast R to exchanged places ; A&R{1+1} | set (2x,1x,3x)
17--::
  Reels3 on sidelines {6}, 1c Rsh to 2cnrs[pos], 2c & 3c ending with a loop | 1c set _while{2}_ 2c & 3c cross RH and face out (2,1x,3)
25--::
  Reels3 on sidelines {6}, 1c Rsh to 2cnrs, 2c & 3c ending with a loop | 1c cross RH _while{2}_ 2c & 3c set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3163, '2012-01-22 19:30:13.990747+00', '2018-07-28 23:34:28.069145+00', 14122, 1, NULL, 'ace', '1–::

  1c+3c turn RH and cast off (2c+4c up) ; All C set | 1c+3c turn BH to face 1cnr

9–::

  1c+3c »Corners pass and rotate« (set to 1cnr | Cast Rsh round P into 3cnr position _while_{2} cnrs dance in and swivel R to face their starting position ; set to facing person | cnrs dance Rsh round each other to exchanged positions as 1c+3c dance in and swivel R to face 2cnr)

17–::

  1c+3c repeat with 2cnrs and face 2cnr again

25–::

  1c+3c ½diag Reels4, pass LSH and face 1cnr ; ½diag Reels4, pass LSH, to (2,1,4,3,5), 1c+3c facing out

33–::

  1c+4c+3c ½ Lsh Reel3 on sideline (4c starts in and L), at end 1c face out ; 1c cast off (5c up) | All set (2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (10977, '2018-08-13 22:07:25.252367+00', '2018-08-14 08:14:27.158225+00', 2930, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 round 2c and finish in promhold facing 3M

9--::

  ½ Reel3 across with 3c, Rsh to 3M ; ½ Reel3 across with 2c, Lsh to 2W, 1c finish on own side (2x, 1, 3x)

17--::

  Mirror Reels3 on own sides, 1c start out and down

25--::

  1c cross below 3c | and cast up ; All set and cross RH (2,1,3)









', 3);
INSERT INTO 'dancecrib' VALUES (15450, '2023-02-20 00:18:43.302107+00', '2023-02-20 00:21:26.548278+00', 21343, 1, 202, 'ace', '1--::

  1c & 3c Petronella turn | set ; Petronella turn | all set (1x,2,3x)

9--::

  1c+2W & 2M+3c RHA ; all chase clw ½ (3,2x,1)

17--::

  2c ½ Fig8 up round 3c to 2pl centre BHJ. On [19-20] 3c step in ; 3c+2c ½ Poussette (2,3,1)

25--::

  All set | turn P BH | set (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11278, '2018-10-19 10:43:26.064749+00', '2018-10-19 10:57:15.591427+00', 18512, 1, 202, 'ace', '1--::
  1c set to 2c | change places RH ; 2M+1M & 1W+3W set on sides | change places RH (1,2,3 on M side, 2,3,1 on W side)
9--::
  3C Bourrel (3,1,2)
17--::
  All set | Circle6 L (3,1,2)
25--::
  1c cross RH | cast R into two lines3 across __while{4}_ cnrs ½ R&L (no polite turn) ; 1c pass P RSh {1}, retire LSh and pivot R to face opp side {1} _while{2}_ 2c & 3c pass P RSh to centre and face P ; all retire to own side (2,1,3)

*Deviser''s note:  
Bars 29-30: those 1st couples who find it uneasy or uncomfortable to pass back to back while turning by a quarter pulling back right shoulder (setting with the left foot!) can finish facing partner on bar 29 and just turn by a quarter remaining facing partner on bar 30. The most important thing is to be ready to retire at the same time as the other couples for covering.*', 2);
INSERT INTO 'dancecrib' VALUES (8381, '2014-08-20 11:17:22.476345+00', '2020-02-08 13:25:05.686463+00', 15567, 2, NULL, 'ace', '1–8::

   1s dance down the middle, cast up round 3s back to their places, and set to each other.

9–16::

   1s, 2s and 3s dance mirror Reels of 3 on the sidelines, 1s starting in.

17–24::

   1s and 3s turn partner RH; repeat LH.

25–28::

   1M and 2L change places, giving RH, 1L and 2M repeat;

29–32::

   1s and 2s set and cross over RH.



*(Dance Crib compiled by the deviser, Hans Prade)*', 5);
INSERT INTO 'dancecrib' VALUES (10931, '2018-07-29 23:52:34.199652+00', '2021-01-20 18:44:39.465028+00', 11704, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 up round 2c (2,1,3)

9--::

  All set | dance BtoB | set (2,1,3)

17--::

  1c cross LH | cast up to 1plx (2c down) ; ½ Fig8 down round 2c (1,2,3)

25--::

  1c+2c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10193, '2017-10-20 13:31:06.327854+00', '2017-10-20 19:23:07.32366+00', 17406, 1, 202, 'ace', '1--::

  1c set | cross (no H) to centre ; 1W+2c LHA _while{4}_ 1M+4c RHA

9--::

  1c cross between 3c, cast out (W clw, M cclw) to original place | set to P

17--::

  All advance to centre | retire with cnr ; All S&Link

25--::

  All advance to centre | retire with next person ; All S&Link (4M+2W,1M+3W,2M+4W,3M+1W)

33--::

  Cpls in 1pos & 3pos ½ R&L ; ½ La-Chain

41--::

  Cpls in 2pos & 4pos repeat [33-40]', 5);
INSERT INTO 'dancecrib' VALUES (10375, '2018-01-12 01:34:03.739539+00', '2018-01-12 01:52:07.028777+00', 15453, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; 1c cross LH | cast (3c up) (2,3,1)

9--::

  1c cross RH | turn BH ending in centre facing up NHJ, 3c step in facing down NHJ ; 3c+1c set | change places EH, 1c in to start, ending with polite turn in centre facing up NHJ, 2c step in facing down NHJ

17--::

  2c+1c set | change places EH, 1c in to start (to 1x,2,3) ; 1c cross RH | turn RH, 2c step in for

25--::

  1c+2c Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12788, '2020-05-02 21:35:39.395059+00', '2020-05-04 14:59:45.342203+00', 8917, 1, NULL, 'ace', '1--::

  1c+2c R&L (1,2)

9--::

  1W+2M petronella to midline | set, advancing on 2nd step to face P across ; All turn P RH ¾, finishing in the square, all 1 place cclw from (1,2), and facing across [1c on M side, 2c on W side, both W above M]

17--::

  2W+1M petronella to midline | set, advancing on 2nd step to face across M to M and W to W ; All turn opposite RH ¾, finishing (2x,1x)

25--::

  All set | Cross RH ; 2c+1c LHA (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (14332, '2021-09-23 22:01:57.307118+00', '2021-09-23 23:27:36.162975+00', 20494, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; ½ Fig8 L round 4cnrs to face 1cnrs
9--::
  1c+1cnrs set | changes places RH, 1cnrs passing LSh into Reel4 position on 2diag ; ½ Weasel Reel on 2diag. 1c face 2cnrs[pos]
17--::
  1c+2cnrs[pos] set | change places RH, 2cnrs[pos] passing LSh into Reel4 position on 1diag ; ½ Weasel Reel on 1diag. 1c finish in 2plx centre, LSh to P, 1M facing up, 1W facing down (3x,1x, 2x)
25--::
  1M+2M+3M & 1W+3W+2W RHA ; 1c turn P RH to 2pl _while{4}_ 3c+2c chase clw ½ (2,1,3)

*Editor''s note for ½ Weasel Reel* : ½ diagonal Reel4, dancers who reach the end chase clw one place, dancers in the other diagonal chase clw one place to enter the reel. Dancers entering and leaving the reel pass RSh.', 2);
INSERT INTO 'dancecrib' VALUES (11040, '2018-08-26 23:29:38.39859+00', '2020-12-28 20:51:24.321838+00', 18535, 1, 202, 'ace', '1--::

  1c & 2c turn BH into ; ½ Poussette, 1c end in allemande hold facing down. On [7-8], 3c turn RH ½ into allemande hold

9--::

  1c+3c last 6 bars of 2C Knot | set (2,3,1,4)

17--::

  3c+1c RHA ; 2c+3c & 1c+4c LHA (2,3,1,4)

25--::

  1c+4c Petronella in tandem | change places with P RH ; Petronella in tandem | set (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (10928, '2018-07-29 03:59:17.42352+00', '2019-03-17 23:15:28.129941+00', 1621, 1, 202, 'ace', '1--::

  1c+3c dance Rsh round P to midline, M(W) facing up(dn) ; set | turn P RH into promhold, 1c(3c) facing 2M(4W)

9--::

  Reels3 across, 1c(3c) starting Lsh(Rsh) to 2M(4W) (1,2,3,4)

17--::

  1c+2c+3c 3C Knot (3,2,1,4)

25--::

  3c+2c & 1c+4c ½ R&L ; all set | cross RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11041, '2018-08-27 12:53:12.081876+00', '2018-08-27 19:42:24.386976+00', 17370, 1, 202, 'ace', '*Large circle round the room, M has P on his R*

1--::

  All circle R and back

9--::

  All W RSh Fig8 starting in front of M on her R

17--::

  All M Rsh Fig8 starting in front of P

25--::

  All W A&R ; all M A&R



*Deviser''s note:  

To make the dance progressive, W move one place to the R as M advance and retire*', 4);
INSERT INTO 'dancecrib' VALUES (10374, '2018-01-12 01:02:45.303109+00', '2018-01-13 01:35:55.119976+00', 15452, 1, 202, 'ace', '1--::

  1c set | cross LH _while{4}_ 2c+3c ½ R&L (to 1x,3x,2x) ; 1c+3c ½ R&L up/dn, 1c ending facing out _while{4}_ 2c set | cross LH (3,1,2)

9--::

  1M casts down into Fig8 around 2c _while{8}_ 1W casts up into Fig8 around 3c (3,1,2)

17--::

  3c+1c+2c ½ Reels3, 1c Rsh to 3cnrs position ; 1c turn P LH (2,1,3)

25--::

  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (9329, '2016-09-26 16:49:25.809189+00', '2019-09-10 00:52:23.003014+00', 14921, 2, 160, 'ace', '1-8::
  1C 2C Rights & Lefts.
9-16::
  1C mirror Fig. 8 on own sides (begin in + down).
17-20::
  1C 1/2 mirror Fig. 8 to the bottom - (begin in + down)
21-24::
  3C 1C RH Across.
25-32::
  1C Fig. 8 round 3C - begin by crossing up.', 0);
INSERT INTO 'dancecrib' VALUES (9705, '2017-04-04 21:13:48.702653+00', '2017-04-04 21:22:38.438279+00', 17705, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; cross down between 3c and cast up to 2pl (2,1,3)

9--::

  Reels3 on the sides (1c dance in and up) 

17--::

  All set and cross RH ; set | Turn P RH into Allemande hold

25--::

  3C Allemande (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (8873, '2015-08-26 22:08:36.195595+00', '2021-01-01 18:45:25.668486+00', 13648, 1, 1041, 'ace', '1--::  1c long cast to 2pl (2c up) ; turn RH (2,1,3)

9--::  1c set passing Lsh while others set facing diagonally in | 2cnrs set while 1c ½ turn 1cnrs BH and flow into ; circle 6 L into lines across (1W between 2c and 1M between 3c)

17--::  1c set passing Lsh while others set facing diagonally in | 1cnrs set while 1c ½ turn 2crns BH and flow into ; circle 6 L (2,1x,3)

25--::  Circulating Knot: all dance as in a normal 3c Knot, but 1c starting up (to 3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (10428, '2018-02-13 17:27:23.790048+00', '2021-01-01 20:20:24.281099+00', 17472, 1, 202, 'ace', '1--::

  1M+2W & 3M+4W turn BH 1 ½ to exchanged places ; 1W+2M & 3W+4M repeat (2x,1x,4x,3x)

9--::

  1c & 4c Fig8 round next cpl

17--::

  All NHJ dance down | turn P BH 1 ½ | all NHJ dance up to sidelines (2,1,4,3)

25--::

  1c+4c+3c The Knot (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13813, '2021-03-13 11:08:34.139587+00', '2021-03-14 00:42:45.440978+00', 9197, 1, 202, 'ace', '1--::
  1c set | turn LH ½ to 2plx centre facing down ; lead down between 3c (2c up) | cross and cast up into lines3 across 1W between 2c, 1M between 3c both facing 1cnrs
9--::
  ½ Reels3 across, 1c LSh to 1cnrs. On [12] 1c turn P RH ½ into the other lines3 across ; ½ Reels3 across, 1c LSh to 3cnrs. 1c finish BtoB on midline, 1M facing up
17--::
  DTr up/down (2,1,3)
25--::
  2c+1c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11042, '2018-08-27 13:49:42.970334+00', '2018-08-27 15:22:10.088845+00', 1015, 1, 202, 'ace', '1--::

  1W followed by 1M cast off 2 and cross to 3plx (2c+3c up) ; 3c+1c RHA, 1 W faces out (2,3,1x)

9--::

  1W followed by 1M cast up and cross to 2pl (3c down) ; 2c+1c LHA (2,1,3)

17--::

  1c set to 2c and turn RH on sidelines ; 1c turn P LH 1¼ to face 1cnrs

25--::

  1c+1cnrs Corner Chain, face 2cnrs

33--::

  1c+2cnrs Corner Chain, 1W face out



*Deviser''s note:  

 At the end of the second turn of the dance, the original lst couple stay facing out, to cast off to fourth place on first two bars as the new dancing couple begin.*', 2);
INSERT INTO 'dancecrib' VALUES (9784, '2017-04-08 12:40:21.076809+00', '2018-07-29 22:46:45.473208+00', 9898, 1, 202, 'ace', '1--::

 1c+3c progressive Fig8 (1c cross, cast ; cross up, cast _while{8}_ 3c set, cross up ; cast, cross up), 3c facing out (3,2,1)

9--::

 3c cast (2c up) | dance down NHJ and face P ; set | 3c lead up LH to face 1cnrs (pos)

17--::

 3c set to 1cnrs (pos) | spiral R to face 2cnrs (pos) ; 3c set to 2cnrs (pos) | spiral R to 2pl (2,3,1)

25--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10932, '2018-08-01 09:43:23.979118+00', '2018-08-01 09:58:11.945595+00', 3216, 1, 202, 'ace', '1--::

  1c lead down up {3} (2c up), turn RH ½ {3] | cast to 2plx and face out (2,1x)

9--::

  2c+1c ½ DblFig8 ; 2c turn 1c EH, 2c starting in (2x,1)

17--::

  1W+2M dance between P, split and dance round P to places ; 1c dance up and cast to 2pl (2x,1)

25--::

  1M+2W repeat [17-20] ; 2c dance down between 1c, cross and cast to 2pl (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (10937, '2018-08-05 11:17:02.213449+00', '2020-09-27 20:14:27.296904+00', 14376, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; 3C S&Link into lines3 across

9--::

  1c change places RH | cast R to 2pl ; ½ Reels3 across, 1c Lsh to 1cnrs[pos] (3x,1x,2x)

17--::

  ½ Reels3 on sidelines, 1c Rsh to 2cnrs[pos] ; all turn P RH 1½ into promhold

25--::

  3C Promenade', 2);
INSERT INTO 'dancecrib' VALUES (2683, '2012-01-22 19:29:52.949774+00', '2020-12-08 23:10:30.444906+00', 3885, 1, NULL, 'ace', '1–::

  1M+2M & 3W+4W pass P Rsh and cast R two places ; All W RHA _while{4}_ All M RHA

9–::

  ½Reels4 on the sides, omit final Lsh pass and finish facing P up/dn ; all set to P | turn P BH ½, opening to face across NHJ, chase one place clw in each square (to 4,2,3,1)

17–::

  4c+2c & 3c+1c Circle4 L, face dn/up ; All set, 4c & 1c turning inwards to face out the end touching NH | 4c & 1c cast to the middle _while{2}_ 2c+3c dance to the ends (2,4,1,3)

25–::

  4c+1c cross NHJ, M making arch | 4c turn 1c in sideline BH and face P ; ½Fig8, 4c up and 1c down (2,4,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (10940, '2018-08-05 18:11:36.588966+00', '2018-08-05 18:11:58.836695+00', 14375, 1, 202, 'ace', '1--::

  1c & 2c turn P LH ¾ ; ½ *Lsh* Reel4

9-24::

  2c & 1c turn P LH ¾ ; 3C R&L, 2c & 3c face out, 1W(1M) face up(dn) (2,1,3)

25--::

  Reels3 on sidelines, 1c Rsh to 4cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14624, '2022-02-26 10:49:40.392689+00', '2022-02-26 10:52:52.51364+00', 20671, 1, 202, 'ace', '1--::

  Espagnole  (2,1)

9--::

  1c lead down ; lead up to 1pl centre facing down NHJ _while{4}_ 2c step down | step in to 2pl centre facing up NHJ

17--::

  Rondel (2,1)

25--::

  Circle4 L and stay in centre ; RHA (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (12185, '2019-09-06 21:49:43.577475+00', '2019-09-08 06:23:04.600031+00', 19549, 1, NULL, 'ace', '1--::

  1c set to 2c and turn 2c EH ½, 1c start outwards ; 1c (start inwards) turn 3c EH, 1c  (2,1,3)

9--::

  1c+2cnrs change places LH | 2cnr persons (in middle facing own side) + 1cnrs repeat RH ; 1cnr persons (in middle facing own side) +1c repeat LH | All cross RH to (3x,1x,2x)

17--::

  S&Link3 : repeat (2,1,3)

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10194, '2017-10-20 16:17:35.569576+00', '2019-03-11 11:57:48.682917+00', 5502, 2, 1824, 'ace', '1-8::

  All 4 women ADVANCE to partners; RH with partners 2 PAS DE BASQUE face down in Promenade hold on Men''s side; dance last half of PROMENADE.

9-16::

  All SET once to partners, 1s face 2s and 3s face 4s set once; HALF REEL of four on sides to original places.

17-32::

  1s and 4s petronella (4 bars); 1s and 4s HALF REEL of four finish in middle [4M 4L 1M 1L]; 4s+2s and 1s+3s RH across and LH back

33-40::

  1s and 4s HALF REEL of four; 1s and 4s SET to partners once then TURN LH to original places

41-48::

  1c CROSS RH, CAST one place, CROSS LH, CAST to 4th place while 2s+3s+4s joining hands move up on bars 7 & 8 

', 0);
INSERT INTO 'dancecrib' VALUES (2088, '2012-01-22 19:29:19.119896+00', '2018-08-06 20:06:21.785745+00', 13965, 1, NULL, 'ace', '1–::

  1c set | Turn RH ½ into 2plx (2c up) ; 1c set | turn LH to face 1cnr

9–::

  1c+1cnrs ½ Diag Reel4, pass Lsh ; 1c+2cnrs ½ Diag Reel4, finish facing 3cnr[pos]

17–::

  1c set to and turn 3cnr[pos], repeat with 4cnr[pos] (3x,1,2x)

25–::

  3c+1W & 1M+2c Circle3 L {3}, open (1c leading) into ½Circle6 L {3} | 1c cross RH to (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10431, '2018-02-14 13:34:33.343482+00', '2018-02-14 13:44:13.806875+00', 17468, 1, 202, 'ace', '1--::
  1c dance down between 3c, cast up to 2pl (2c up) ; 1c cross LH, cast L round 2cnrs into lines of 3 across, 1c facing 3cnrs
9--::
  1M+2c & 1W+3c ½ Reels3 across, 1c Rsh to 3cnrs to start (to 2x,1x,3x) ; 2M+1M+3M & 2W+1W+3W ½ Reels3 on sidelines, 1c Rsh to 1cnrs position
17--::
  1W+3c & 1M+2c ½ Reels3 across, 1c Lsh to 4cnrs position to start (to 3,1x,2) ; 3W+1M+2W & 3M+1W+2M ½ Reels3 on sidelines, 1c Lsh to 2cnrs position to start, finishing in centre LHJ facing 1cnrs
25--::
  1c set to 1cnrs, turn inwards RHJ | set to 3cnrs _as_ 3cnrs set advancing ; 1c+3cnrs RHA, 1c finishing RHJ facing 2cnrs
33--::
  1c set to 2cnrs, turn inwards LHJ | set to 4cnrs _as_ 4cnrs set advancing ; 1c+4cnrs LHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11043, '2018-08-27 20:22:31.807073+00', '2018-08-30 11:28:11.217802+00', 18536, 1, 202, 'ace', '1--::

  1c set | 1W followed by 1M cast off below 3c (2c up) and dance up NHJ to face 1cnr (2,1,3)

9--::

  Reels3 on sidelines, 1c RSh to 1cnrs, 1c face 1cnrs

17--::

  6 bars of SetH&G | 1c turn P RH ¾. On [24], 2c & 3c dance in into

25--::

  2c+1c+3c Allemande (3,1,2)

', 4);
INSERT INTO 'dancecrib' VALUES (14936, '2022-07-03 09:14:21.033304+00', '2022-10-27 07:37:09.387962+00', 20734, 1, 202, 'ace', '1--::

  1M+2W set | cross RH ; 2M+1W & 3M+1M set | cross LH

9--::

  1W+3W & 1M+4W set | cross RH ; 4M+1W set | cross LH (2x,3x,4x,1x)

17--::

  All set | 2c cast off _as_ 3c cross RH to 1pl _while{2}_ 4c cast off _as_ 1c cross RH to 3pl : repeat [17-20] from new positions (2,3,4,1)

25--::

  All set | turn P BH opening for ; 2c+3c & 4c+1c Circle4 L (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10376, '2018-01-12 10:53:26.577375+00', '2018-01-13 01:34:26.660826+00', 15454, 1, 202, 'ace', '1--::

   1c & 4c set | cross LH _while{4}_ 2c+3c ½ R&L (to 1x,3x,2x,4x) ; 1c+3c & 2c+4c change places RH | all cross LH (3,1,4,2)

9--::

   1c+4c set advancing | hold hands in circle and set ; pull Rsh back to sidelines | 1c+4c touching H briefly chase clw 1 place _while{6}_ 3c & 2c cross RH | chase clw ½ to exchanged places

17--::

  1c & 4c in promhold (4M on 4W''s R) cast R into Fig8 around end cpls ending between ends

25--::

  4c dance under arch made by 1c to 4pl (3c up) _while{4}_ 1c dance up making arch, separate and cast up behind 2c to 1pl (2c down) ; 1c BHJ slip to 4pl (2c+3c+4c up) (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (10936, '2018-08-05 10:54:14.612447+00', '2020-12-31 11:48:45.896+00', 14340, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; all A&R (2,1,3)

9--::

  ½ Reels3 on sidelines, 1c Lsh to 1cnrs, cnrs looping at end ; 1c cross RH | cast R into facing lines3 across

17--::

  All A&R ; ½ Reels3 across, 1c Lsh to 2cnrs[pos], finishing BtoB facing 3cnrs[pos]

25--::

  ½ Reel4 on 1diag, pass Lsh to face 4cnrs[pos] ; ½ Reel4 on 2diag to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10930, '2018-07-29 10:26:58.28436+00', '2021-01-05 12:16:37.304493+00', 12962, 1, 202, 'ace', '1--::

  1c+2c ½ Poussette ; Circle4 L (2,1,3)

9--::

  3C S&Link ; repeat [9-12] (3x,1x,2x)

17--::

  1c cross RH | loop Rsh round 3cnrs[pos] into lines3 across, 1c face 2cnrs[pos] ; ½ Reels3 across, 1c Lsh to 2cnrs[pos] into facing lines3 across

25--::

  1c cross RH up/down | loop Rsh round 4cnrs[pos], 1c face 3cnrs[pos] (to 3,1,2) ; ½ Reels3 on sidelines, 1c Lsh to 3cnrs[pos] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13224, '2020-10-06 02:01:22.83941+00', '2021-09-27 16:01:35.42628+00', 19677, 1, 202, 'ace', '1--::
  1c set | 1c (1W leading) cast off ; 1c cross to 2plx (2c up) | set (2,1x,3)
9--::
  1c cast RSh round 1cnrs, meet in centre, pull RSh back to dance RSh round 4cnrs to 2pl (2,1,3)
17--::
  ½ Reels3 across, 1c LSh to 1cnrs (to 2x,1x,3x) ; 1c A&R _while{4}_ 2c & 3c A&R on sides (2x,1x,3x)
25--::
  ½ Reels3 across, 1c LSh to 3cnrs[pos] (to 2,1,3) ; all repeat [21-24] from new positions (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (12186, '2019-09-06 23:10:10.331312+00', '2019-09-06 23:12:07.612444+00', 17575, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; All turn P RH (2,1,3,4)

9--::

  All chase clw half round (4x,3x,1x,2x)

17--::

  4c+3c dance BtoB _while{4}_ 1c+2c  turn P RH ½ into | ½ RHA (4x,3x,2x,1x) ; All set | 1c cross RH to 1pl as 4c+3c+2c turn P RH ½ into 

25--::

  4c+3c+2c Allemande ("meanwhile" option: 1c turn RH ½ and cast to other side ; repeat) (2,3,4,1)  



*there is probably an error in [9-16]*





', 1);
INSERT INTO 'dancecrib' VALUES (10197, '2017-10-21 18:07:43.699588+00', '2018-04-09 00:11:16.155131+00', 17944, 1, 202, 'ace', '1--::

  1c+2c Mirror S&Link (1c cast off, 2c dance up) ; 1c dance up round 2c and cast off to 2pl (2,1,3)

9--::

  2c+1c+3c set | cross RH ; chase clw ½ (3,1,2)

17--::

  1W+3c & 1M+2c RHA, finish Lsh to Lsh facing 2cnrs ; Lsh Snake Pass (unwind the RHA, 1c leading, pass other snake Lsh through 2plx and chase clw) (2,1,3)

25--::

   1c lead down, crossing over ; 1c lead up to 2pl, crossing over (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10199, '2017-10-22 09:06:46.811985+00', '2018-04-08 10:22:37.389512+00', 17946, 1, 202, 'ace', '1--::

  1c cross down RH, cast down behind 3c, cross up RH, cast up behind 2c to 1pl

9--::

  1c+2c+3c Reels3{6}, 1c start inwards | 1c & 2c turn P BH ¾ to midline

17--::

  1c+2c H. Schottische poussette (2,1,3)

25--::

  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (10942, '2018-08-06 15:58:42.331494+00', '2018-08-07 10:41:03.207051+00', 16032, 1, 202, 'ace', '1--::
  1c+2c set | RHA | 1c cast to 2pl _as_ 2c dance up to 1pl (2,1,3)
9--::
  1c+3c set | LHA | 3c cast to 2pl _as_ 1c dance down to 3pl and face out (2,3,1)
17--::
  Mirror Reels3 on sidelines, 3c start in and up, each cpls can take hands (2,3,1)
25--::
  1c set | cast to 2pl (3c down) ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12187, '2019-09-07 18:19:26.70487+00', '2019-09-07 18:26:01.78452+00', 13961, 1, 202, 'ace', '1--::

  1M+2W cross RH | set _while{4}_ 1W+2M set | cross RH ; repeat [1-4] (1,2)

9--::

  1c+2c dance BtoB ; turn RH into allemande hold (1,2)

17--::

  2C Allemande (2,1)

25--::

  Circle4 and back (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (10946, '2018-08-07 18:56:27.010152+00', '2018-08-07 19:01:10.471072+00', 16035, 1, 202, 'ace', '1--::
  All NHJ set advancing, face P | cast R to places and face clw ; chase clw ½ (3x,2x,1x)
9--::
  Repeat [1-8] (1,2,3)
17--::
  1c set | cross RH between 2c, cast round 3c, dance up to face 1cnrs (2c up on [23-24])
25--:: 
  6 bars of SetH&G into facing lines3 across | all set
33--::
  Reels3 on sidelines, 1c Rsh to 1cnrs (2,1,3)
41--::
  1c cast R round 4cnrs, meet, turn LH ¾ to 2pl and face out _while{4}_ cnrs A&R {1+1} diagonally | set diagonally ; 1c loop down to 3pl _as_ 3c dance up to 2pl | all set (2,3,1)

*Editor''s note:  
Couples can retain hands ready to begin again from their new positions.*', 2);
INSERT INTO 'dancecrib' VALUES (12181, '2019-09-06 20:25:28.266717+00', '2020-02-16 01:33:53.027504+00', 13985, 1, NULL, 'ace', '1--::

  1c cross RH | cast off ; cross LH below 2c and cast up to (1,2)

9--::

  1c+2W Reel3, 1W Rsh to P (1,2)

17--::

  1c+2M Reel3, 1M Lsh to P (1,2)

25--::

  All set | ¾ R&L (2,1)

33--::

  Circle4 and back *(Last time through Circle8 and back)*

', 4);
INSERT INTO 'dancecrib' VALUES (15155, '2022-10-05 00:22:22.808622+00', '2023-02-04 01:23:04.893986+00', 21026, 3, NULL, 'ace', '1-8::
    2s dance reels of 3 across (to start 2s pull RSh back, cast 2M up/2L
    down), _while_ 1s & 3s pass partner LSh. End 1M in middle at top
    facing down, 3L in the middle at bottom facing up, 2M in 1M''s place,
    2L in 3L''s place)
9-16::
    1s+2L & 3s+2M dance reels of 3 on sides (To start 1M passes 2L (1st
    corner) RSh & 3L passes 2M (1st corner) RSh) At the end 1M & 3L
    curve into 2nd place on opposite sides
17-20::
    2s (1st corners) pass RSh, dance round to 2nd place own sides
    _while_ 1s+3s NHJ set & chase clockwise to own sides. 3 2 1
21-24::
    All turn RH to finish 2H joined in middle of set ready for….
25-32::
    3s+2s+1s dance Poussette.

{{explanation}}
3rd, 5th & 7th time through new 3rd couple cross up into reels of 3, couple in 3rd place dance down to 4th place', 0);
INSERT INTO 'dancecrib' VALUES (10950, '2018-08-08 09:29:40.604441+00', '2018-08-08 20:09:51.376704+00', 18493, 1, 202, 'ace', '1--::

  1c dance Rsh round 2c on sides, 1W face out ; 1W followed by 1M cast | cross to 2plx (2c up) (2,1x,3)

9--::

  1c turn 3c EH on sides | ½ Parallel Reels3 on sidelines, 1c Rsh to 2c | 1c turn 2c EH on sides (3,1x,2)

17--::

  All chase clw ½ (to 2x,1,3x) ; 1c turn RH _while{4}_ 2c & 3c turn RH ½, face each other | cast R to exchanged places (2,1,3)

25--::

  ½ Reels3 across, 1c Rsh to 2cnrs (to 2x,1x,3x) ; ½ Reels3 across, 1c Rsh to 4cnrs[pos] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10944, '2018-08-07 08:26:36.473768+00', '2018-08-08 16:05:30.004486+00', 16036, 1, 202, 'ace', '1--::
  1c+4c cross RH | cast (2c&3c step out) ; 2c & 3c turn BH _while{4}_ 1c+4c set | turn P RH ½ into promhold, 1c(4c) face up(dn), 4W on 4M L (2,*1*,*4x*,3)
9--::
  Reels3 across, 1c(4c) Rsh to 2W(3M), finish 1c(4c) on the M(W) side
17--::
  1c+4c set | Petronella Turn in tandem ; RHA _while{8}_ 2c+3c Petronella Turn | set ; turn P BH 1¼, all face clw (2,4,1,3)
25--::
  All chase ½ ; ½ Circle8 L (2,4,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (10951, '2018-08-08 19:23:44.488907+00', '2018-08-08 20:04:55.643642+00', 7972, 1, 202, 'ace', '_Strathspey_
1--::
  1c set | cast (2c up) ; ½ Fig8 R round 1cnrs, face 1cnrs (2,*1*,3)
9--::
  SetH&G. On [15-16], 1c pass P Lsh to 2plx, face out (2,1x,3)
17--::
  Reels3 on sidelines, 1c Lsh to 2cnrs. On [23-24], 1c turn LH, face up (3c finish the reel in centre behind 1c)
25--::
  2C Allemande (2,3,1)

_Reel_
33-64::
  Repeat the same figures in reel time, a new top couple leading.  
  
*Repeat the Strathspey and Reel twice, a new top couple leading each time.*', 2);
INSERT INTO 'dancecrib' VALUES (13853, '2021-03-27 02:52:01.381137+00', '2021-03-27 02:55:41.013578+00', 20080, 1, 202, 'ace', '1--::

  Double R&L, 2c+4c start RH with partners

9--::

  All chase 1 place clw | turn P BH ; turn cnrs RH (4,1,2,3)

17--::

  Double L-Chain

25--::

  All circle8 L {3}, cross R foot over and pivot L ; chase cclw to places (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (13812, '2021-03-13 00:04:00.855957+00', '2021-04-07 07:06:58.415633+00', 9019, 1, 202, 'ace', '*On 2nd chord, 2c cross to opposite side (1,2x,3)*



1--::

  1c+2c Petronella in tandem | set ; repeat [1-4] 1c advancing to between 2c into Reel4 position

9--::

  Reel4 across. On [15-16] 1c pass P RSh, 1W in centre facing 2M, 1M behind 1W in tandem

17--::

  ½ Reel3 in tandem (with lead change) on 1diag, 1W RSh to 2M ; ½ Reel3 in tandem (with lead change) on 2diag, 1M RSh to 3M

25--::

  Repeat [17-24] with 2M on 1diag & 3M on 2diag (2,1x,3)

33--::

  1c+3c Petronella in tandem | set ; repeat [33-36] 1c advancing to between 3c into Reel4 position

41--::

  Reel4 across. On [47-48] 1c pass P RSh to own sides (2,3x,1)', 2);
INSERT INTO 'dancecrib' VALUES (10945, '2018-08-07 09:08:37.700972+00', '2021-02-21 11:45:22.793181+00', 3568, 1, 202, 'ace', '1--::

  All Highland Schottische step to P ; all dance BtoB (1,2)

9--::

  1c lead down ; and up (1,2)

17--::

  2C Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (14337, '2021-09-27 17:24:54.215535+00', '2021-09-27 17:25:04.235552+00', 20496, 1, 1645, 'ace', '*3c & 4c start on opposite side (1,2,3x,4x)*

1--::

  2c+3c RHA ; 2c & 3c lead out nearest end & cast back to place (1,2,3x,4x)

9--::

  1c+2c & 3c+4c turn 1&frac12; EH on sides, 2c/3c starting between 1c/4c ; 1c & 4c petronella to centre line | set

17--::

  1c+4c &frac12; Reel4 ; set | petronella to sides (2,4x,1,3x)

25--::

  2c+4c & 1c+3c LHA ; 4c & 1c &frac12; Fig8 out nearest end (2,4,1x,3x)

::

  *NB crib derived from the video*

', 0);
INSERT INTO 'dancecrib' VALUES (2680, '2012-01-22 19:29:52.829542+00', '2020-12-08 23:07:15.083462+00', 3857, 1, NULL, 'ace', '1–::

  1c+3c cross RH, cast off one (2c+4c up) ; ½ Fig8 up (2,1,4,3,5)

9–::

  dancing couples with couple to the R (i.e. 2c+1W & 1M+4c+3W & 3M+5c) Circle3,4,3  L and back, end facing 1cnrs

17–::

  Set to 1cnr, set to 2cnr, pulling Rsh back to end between corners ; cross RH and cast up _while{4}_ 2c+4c set and dance down, (1,2,3,4,5)

25–::

  8 bars Rsh Mirror Reel of 5 on the sides, 2c+4c start out and down, 3c+5c in and up. 1c in (to 2,4,1,5,3: on each bar pass one person or loop at the end)', 2);
INSERT INTO 'dancecrib' VALUES (10952, '2018-08-08 20:43:46.221583+00', '2018-08-08 22:06:03.166279+00', 12036, 1, NULL, 'ace', '1--::

  1c cross RH and cast off (2c up) (2,1x) ; 2c+1c RHA, the W finish normally as the M add ½RH turn to finish 1c on W side facing 2c on M side 

9--::

 Pass Rsh into Reel4 on 2diag. On [16] the M turn LH to sideline on L of P, facing out

17--::

  L-Ch, finish in promhold facing cclw, M in middle

25--::

  All promenade ¾ cclw into : 1c (M side) + 2c (W side) ½ Poussette (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (10568, '2018-04-02 19:36:06.395333+00', '2018-04-15 10:45:17.513952+00', 12095, 2, 1, 'ace', '1–:: 2c+3c RH across ; 1c+2c & 3c+4c LH across

9–12:: 2c+3c RH across _while_ 1M (followed by 1L) casts off to 4plx

   _while_ 4L (followed by 4M) casts up to 1plx

13–14:: 4c+2c & 3c+1c ½ LH across

15–16:: 4c & 1c (keeping LH) cross to opp sides [to 2x,4x,1x,3x]

17–32:: “Lindisfarne Knot”:

   2c  (at top) set to ptr | cross to 2pl (face out)

   _while_ 4c (in 2pl) cast to 3pl | cross to 4pl (face ptr)

   _while_ 3c (in 4pl) set to ptr | cast into 3pl

   _while_ 1c (in 3pl) cross to 2pl | cast up to top ;

   continue pattern to 2413.

   [No actual casting except in 4pl, and 2pl at the start of the formation.

   No hands.]', 3);
INSERT INTO 'dancecrib' VALUES (12188, '2019-09-07 20:29:16.988315+00', '2019-09-08 13:12:49.07639+00', 1795, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; cross LH | cast Lsh round 4cnr to finish in lines across (1M below.  1W above) 

9--::

  1W+2M+3M & 1M+2W+3W RHA ; 1M+2M+3M & 1W+2W+3W LHA, 1c pass Lsh to face 2cnr

17--::

  1c turn 2cnr RH | turn P LH ; turn 1cnr RH | pass P LH

25--::

  2c+1M & 1W+3c Reels3{6} across (Lsh to 3cnr) | 1c cross RH to (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (10200, '2017-10-22 09:52:35.549509+00', '2017-10-22 15:59:13.577645+00', 18022, 1, NULL, 'ace', '1--::

  1c+2c S&Rotate, 1c dance Rsh round P to face 1cnr (2,1,3)

9--::

  1c+1cnrs Pass & Turn, 1c pass Rsh to face 2cnr ; 1c+2cnrs ½ diag. Reel4, 1c pass Rsh to face 3cnr

17--::

  1c+3cnrs ½ diag Reel4, 1c pass Rsh to face 4cnr ; 1c+4cnrs Pass & Turn, finish in DTr position, 1c facing own side (3x,1,2x)

25--::

  Modified DTr: on [27-28] 3c+2c change place on the sides (polite turn) ; on [31-32] 2c+3c cross RH to own side (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8205, '2014-03-01 12:32:13.179128+00', '2018-01-13 15:06:02.47827+00', 14597, 1, NULL, 'ace', '{{explanation}}

Dance three times, as Jig, Strathspey, Reel



1–::

  1c+3c petronella to midline and set to P ; ½ Reel4 on midline, at end 1M+3W pass LH to flow into

9–::

  3W+2c+1M LHA (3M+1W stand and face on midline) ; 3c+1c turn P RH ¾ and 3c face 1c NHJ | All set (3,2,1)

17–::

  All Circle6 and back (3,2,1)

25–::

  2c set | cast up (3c down) ; All turn P RH (in strathspey time: BH) (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2714, '2012-01-22 19:29:54.231873+00', '2020-12-08 23:19:48.974635+00', 3988, 1, NULL, 'ace', '1–::

  1c cross down RH between 2c | cast behind 3c ; lead to top | cross and cast to 2pl (2c up) (2,1,3,4)

9–::

  2c+1c cross down | cast behind 3pl/4pl _while{2}_ 3c+4c step up ; lead up to 1pl/2pl | cross and cast off 2 to 3pl/4pl _while{2}_ 3c+4c step up (3,4,2,1)

17–::

  3c repeat [1-8] _while{8}_ 4c wait{2} | cross RH ; follow 3c, end on own side in 1pl (4,3,2,1)

25–::

  1c+4c (»ends«) ½RHA (3c+2c step to »ends«) | 1c cast up round 3c _while{2}_ 4c cast down round 2c ; 4c+1c dance in into ½LHA (to 3,4,1,2)

33–::

  Repeat from new positions (4,3,2,1)

41–::

  1c lead to top _while{2}_ 4c+3c+2c dance down 1 place, join P RH and face up | 1c (other C following) cross at top and dance down the sides (2x,3x,4x,1x) | All cross RH to new places (2,3,4,1)



{{explanation}}

(This dance is a »fugue«, the pattern of 1c in [1-8] is repeated in [9-16] and [17-24]', 3);
INSERT INTO 'dancecrib' VALUES (11045, '2018-08-27 23:26:17.633171+00', '2018-08-27 23:36:44.606031+00', 1873, 1, 202, 'ace', '1--::

  1c lead down and cast up round 3c to 1pl | all set (1,2,3)

9--::

  1c & 3c Petronella turn | set ; ½ Reel4

17--::

  3c & 1c turn P BH 1¾, stay in centre opening hands into ; 3c+2c+1c Circle6 L ½ (1x,2x,3x)

25--::

  All set | cross RH ; set | 1c cast to 2pl (2c up) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10954, '2018-08-09 00:38:55.175167+00', '2018-08-09 00:43:38.053673+00', 13359, 1, 202, 'ace', '1--::

  1c+2c ¾ R&L | all set (2,1,3)

9-20::

  3C R&L (2,1,3)

21-24::

  All set | 2c&3c set _while{2}_ 1c set advancing to face 1cnrs

25--::

  Corners Pass And Turn (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10960, '2018-08-09 15:10:25.225823+00', '2018-09-04 06:23:32.772689+00', 9676, 1, 202, 'ace', '1--::

  1c+2c R&L

9--::

  1c cross RH | cast (2c up) ; ½ Mirror Reels3 on sidelines, 1c start in and down, pass P Rsh to end BtoB facing 1M(1W) down(up) (3,1,2)

17--::

  »Petronella DTr« up/dn [same as DTr up/dn except that 2c & 3c Petronella Turn 1 place cclw when 1c change places] (2x,1,3x)

25--::

  ½ Reels3 across, 1c Rsh to 4cnrs[pos] (to 2,1,3) ; all turn P LH', 2);
INSERT INTO 'dancecrib' VALUES (10961, '2018-08-09 17:04:44.226684+00', '2018-09-04 06:25:01.879167+00', 13366, 1, 202, 'ace', '1--::

  1c dance down between 2c, cast behind 3c, meet into promhold and face up (2c up) ; dance out between 2M & 3M, cast up between 2c, 1M(1W) facing 2W(2M)

9--::

  Reel3 across. On [15-16], 1c pass Rsh to face 1cnrs (2,1,3)

17--::

  »Modified Corner Chain« on 1diag [same as Corner Chain except cnrs change place LH instead of turn LH in centre]

25--::

  Repeat [17-24] on 2diag (3x,1x,2x)

33--::

  All set | chase clw ½ | set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10958, '2018-08-09 08:27:07.284035+00', '2018-08-09 11:44:06.966594+00', 6854, 1, NULL, 'ace', 'This dance is too complicated for a crib to be of use.  



The dance has six 8-bar phrases, partially overlapping:



1--::

  Diagonal Cross  Finish (1x,2x,3x,4x)

9--::

  Reverse Snowball Reel4

17--::

  Circle Chase

25--::

  6-2 Circle

33--::

  Turn and Chase

41--::

  Half Circle Chase and BtoB (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (10955, '2018-08-09 01:01:18.222104+00', '2018-08-09 01:05:05.498665+00', 14324, 1, 202, 'ace', '1--::

  1c+2c turn P BH ¾ into midline | ½ Reel4 | 2c+1c turn P BH ¾ (2,1,3)

9--::

  1c set advancing to face 1cnrs | turn 1cnrs BH into facing lines3 across ; 1c repeat [9-12] with 2cnrs (2,1x,3)

17--::

  Reels3 {6} on sidelines, 1c Lsh to 1cnrs | 1c cross RH (2,1,3)

25--::

  1c+3c The Tournée (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12777, '2020-04-25 08:19:50.1575+00', '2020-05-04 21:34:46.694368+00', 19960, 1, 1645, 'ace', '1-::

  1c long cast to 2pl (2c up) ; &frac12; Reels3 across, LSh to 1cnrs (2x,1x,3x)

9-::

  All &frac12; Reels3 on sides, 1c RSh to 2cnr[pos] ; 1c dance BtoB _while_ corners dance LSh BtoB on sides (3x,1x,2x)

17-::

  1c petronella to centre | set adv passing LSh ; dance 1&frac14; round each other passing LSh

  _while{8}_ corners chase &frac12; way clw, pull LSh back ; chase back cclw (3x,1x,2x)

25-::

  All advance{1} & retire{1} | turn &frac34; BH to centre line ; set to P | turn &frac34; BH (3,1,2)  

  *Bars 25-32 may be done without taking hands*

', 5);
INSERT INTO 'dancecrib' VALUES (1653, '2012-01-22 19:28:53.170449+00', '2017-10-22 19:13:08.506912+00', 13629, 1, NULL, 'ace', '1–::

  1c dance between 2c and cast up ; ½ Fig8 down round 2c,

9–::

  1c dance down between 3c (2c up) ; cast up, ½ Fig8 down round 3c (2,1,3)

17–::

  1c turn 1cnr RH, pass Rsh, turn 2cnr RH, pass Rsh into

25–::

  Circle6 and back (2,1,3)



{{explanation}}

Deviser''s Note: 1c can choose handing freely ; the timing is fluid, the barring only an approximation', 3);
INSERT INTO 'dancecrib' VALUES (10435, '2018-02-21 15:10:52.418974+00', '2018-02-21 15:21:00.557417+00', 17007, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; turn RH to 2pl, 1c facing 3cnrs (2,1,3)

9--::

  ½ Reels3 on sidelines, 1c Rsh to 3cnrs (3,1,2) ; 1W+2W & 3M+1M S&Link

17--::

  3C Bourrel (2,1,3)

25--::

  1c+3c S&Rotate (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10959, '2018-08-09 10:13:46.693109+00', '2018-08-09 10:21:07.349209+00', 14326, 1, 202, 'ace', '1--::

  1c lead down between 3c, cross and cast to 2plx (2c up) ; lead up to top, cross and cast to 2pl (2,1,3)

9--::

  1W+2c & 1M+3c RHA ; 1W+3c & 1M+2c LHA (2,1,3)

17--::

  1c cross RH | cast R round 1cnrs ; turn P BH 1¼, dance up to 1pl centre _while{4}_ 2c&3c set diagonally | 3c dance up to 2pl centre behind 1c _as_ 2c dance down outside to 3pl (*1*,*3*,2)

25--::

  1c set _while{2}_ 2W(2M) turn 3W(3M) RH(LH) ½, 2c dancing up to 2pl _as_ 3c cast to 3pl | 1c cast off 2, meet below 3c, dance up to top, long cast to 2pl (2c up on [29-30]) (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10956, '2018-08-09 01:23:28.323625+00', '2018-08-09 01:27:57.564612+00', 14325, 1, 202, 'ace', '1--::

  1c set | cross RH ; cast | turn RH ¾ _while{4}_ 2c dance up turning RH 1¼ into midline

9--::

  Reel4 (*2*,*1*,3)

17--::

  2c+1c turn P RH ¾ and face down | 1c followed by 2c dance down between 3c, cast up, dance up between 1pl, cast into 2pl, 2c looping to 1pl (2,1,3)

25--::

  Circle6 and back

  ', 2);
INSERT INTO 'dancecrib' VALUES (8924, '2015-09-23 08:42:00.932244+00', '2021-05-23 11:00:10.689862+00', 16752, 1, NULL, 'ace', '1--::  All S&Link into facing lines across ; top line with NHJ sets twice _while{4}_ bottom line NHJ dance up, pivot R and dance down

9--::  Both lines dance down, and pivot R to face up ; both lines dance up, top line pivots R into facing lines across

17--::  All S&Link (3x,2x,1x) ; All turn P RH ¾ to midline | all set to P

25--::  All turn P RH ¾ | All set ; 3c (starting outwards) turn 2c on sides 1½ (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (11554, '2019-01-30 22:37:07.85792+00', '2019-03-23 21:01:50.196986+00', 19177, 1, NULL, 'ace', '1--::

  All clap. 2c, 1c following, Fig8 round 3c, finish (2,1,3)

9--::

  1c Pass P Rsh and pivot R to face P, and retire _while{4}_ 2c+3c dance BtoB (2,1x,3) ; 1c Turn RH to finish with backs to 1cnrs.

17--::

  1c cross Rsh to 3cnr place, face in and set _while{4}_ 1cnrs pass Rsh, turn RH and finish with backs to 3cnr ; repeat figure, finishing with 1cnrs  in own place and setting, and 1c with backs to 2cnr 

25--::1c

  Repeat [17-24] with 2cnrs, and finish (2,1,3)  



*On second time 1c finish in 4pl (4c up)*', 4);
INSERT INTO 'dancecrib' VALUES (1712, '2012-01-22 19:28:57.891645+00', '2019-09-08 10:40:10.854671+00', 8702, 1, NULL, 'ace', '1–::

  1c+2c set | ¾ R&L, all C (3c stepping in) finish ready for

9–::

  2c+1c+3c Allemande, 1c finish facing 1cnr pos.

17–::

  1c turn cnr RH ½  | with cnr following dance R to meet P and form a line of 4 on midline, 1c BtoB facing the cnrs at the ends ; ½Reel4 on midline, cnrs dance to 3cnr pos and 1c pass Rsh to face 2cnr pos.

25–::

  Repeat 8 bars mirrored (½LH turn, Lsh Reel4) (to 2x, 1, 3x)

33–::

  Diagonal R&L (to 3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (10570, '2018-04-02 20:29:21.52313+00', '2018-07-17 00:10:24.111782+00', 18272, 2, 1, 'ace', '1–:: 1c+2c 4H round and back

9–:: 1c+2c set & link ; 1c+3c set & link

17–:: [2c start from top as 1c] 1c+4c+5c mirror reels3 on sides

25–:: 1c set | cross down RH to 4pl [4c up] ; 

   1c set | cross down LH to 5pl [5c up]



Repeat pattern until 1c are back at top but allow 5c to finish their turn [96 bars total]', 3);
INSERT INTO 'dancecrib' VALUES (10478, '2018-03-03 08:13:06.926119+00', '2019-09-08 10:42:19.399911+00', 17677, 1, 202, 'ace', '1--::

  1c Fig8 down round 2c, 1c (1W behind 1M) facing 2M at end

9--::

  1c+2c Tandem Reel3 across with lead change, 2c Rsh to 2M to start, 2c ending in 1pl & 1c in centre facing down _while{8}_ 3c+4c Circle4 and back

17--::

  1c cross to 2plx, turn 3c EH 1 ½ (to 2,3,1x,4) ; 1c ½ Fig8 down round 4c (2,3,1,4)

25--::

  2c+3c R&L _while{8}_ 1c+4c ¾ R&L | set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10964, '2018-08-09 22:36:04.290693+00', '2018-10-11 08:58:33.184772+00', 18495, 1, NULL, 'ace', '1--::

  All advance | 1c dance down one _while_ 2c/3c retire to 1pl/3pl ; 1c turn BH 1½ to face 1cnr _while_ 2c+3c A&R

9--::

  1c+1cnrs Pass & Turn ; 1c repeat with 2cnrs and face out own side (2,1,3)

17--::

  Reels3 on own sides, 1c Lsh to 4cnr (2,1,3)

25--::

  1c+3c Poussette (2,1,3)

33--::

  1c ½Fig 8 round 3c ; cross RH and cast off (3c up) (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10703, '2018-04-28 17:55:22.695165+00', '2018-04-28 18:02:04.267967+00', 16694, 1, 202, 'ace', '1--::
  1c & 2c A&R[1+1] twice, touching P RH ; dance BtoB
9--::
  1c Fig8
17--::
  1c turn BH, dance down 2 small steps and face P (2c up) ; set | joining NH briefly, dance up and loop to 2pl (2,1)
25--::
  R&L', 2);
INSERT INTO 'dancecrib' VALUES (11044, '2018-08-27 23:25:29.710124+00', '2018-08-28 10:15:57.435337+00', 18537, 1, NULL, 'ace', '1--::

  1c long cast to 2pl (2c up), dance between 3c and cast up to face 1cnr

9--::

  1c+1cnrs: centres set to cnr | centres cast away to cnr behind as cnrs dance in and face back ; repeat and 1c turn R about to face 2cnr

17--::

  1c+2cnrs repeat (3x,1x,2x)

25--::

  3W with 1W+2W following cast down _while{4}_ 2M with 1M+3M following cast up (2x,1x,3x) ; 2c cross RH as 1c+3c ½RHA | All set (2,3,1)



*repeat 2 times more in Strathspey time, 3 times in Reel time.*

', 3);
INSERT INTO 'dancecrib' VALUES (11046, '2018-08-28 09:16:28.434914+00', '2018-08-28 10:38:05.545057+00', 18538, 1, 202, 'ace', '1--::

  1c+2c Dbl Fig8, 1c crossing down, 2c face out (1,2,3)

9--::

  Mirror Reels3 on sidelines taking hands, 2c start out and up (1,2,3)

17--::

  1c cross RH | cast (2c up) ; ½ Fig8 down round 3c (2,1,3)

25--::

  2c+1c Poussette (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10962, '2018-08-09 21:30:13.45195+00', '2020-09-11 08:49:01.433191+00', 10641, 1, NULL, 'ace', 'Couples form a big circle, men inside and facing P.

1--::

  All face R and dance 4 steps ; repeat back and face P

9--::

  Turn P RH ; turn P LH 

17--::

  All A&R ; dance BtoB with P and move one position R to new P

25--::

  All A&R ; turn P LH 

', 3);
INSERT INTO 'dancecrib' VALUES (10914, '2018-07-22 11:47:21.421934+00', '2022-11-07 19:45:42.006754+00', 2410, 1, 202, 'ace', '1--::

  All set | 1c+2c & 3c+4c Circle4 L, finish in centre NHJ with P in Reel4[pos] | all set (1,2,3,4)

9--::

  Parallel Reels4 on sidelines

17--::

  1c+2c & 3c+4c Poussette

25--::

  1c & 4c turn RH ½ _while{2}_ 2M+3W cross LH and face out | 1c+3W & 4c+2M ½ RHA ; 1c+3W & 4c+2M ½ LHA _while{2}_ 2W+3M cross RH (to 1x,3x,2x,4x) | 1c+3c & 2c+4c ½ LHA (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (10963, '2018-08-09 22:08:27.881999+00', '2021-03-27 16:06:50.175733+00', 7312, 1, NULL, 'ace', '1--::

  1c+2c dance BtoB ; 1c facing 2c dance BtoB

9--::

  All advance, pass P Rsh and turn R about to face P ; retire to (1x,2x,3x) | 1c cast off and face 1cnr _while_ 2c cross up RH and 3c cross RH 

17--::

  1c turn 1cnr LH | turn P RH ; turn 2cnr LH | P RH (2,1x,3)

25--::

  All Circle6 L {3} and pivot L ; chase cclw to places, 1c passing Lsh on [31-32] to own side (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2720, '2012-01-22 19:29:54.52825+00', '2020-12-10 00:00:19.678217+00', 4032, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; 1c+3c RHA

9–::

  1c set | cast up (2c down) ; 1c+2c LHA

17–::

  1c followed by 2c dance between 3c, cast up round them, dance up, 1c cast off to 2pl, _while_ 2c dance into 1pl (no loops)

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (3454, '2012-01-22 19:30:26.185066+00', '2021-06-08 10:10:43.478793+00', 9899, 1, NULL, 'ace', '1–::

  1W followed by 1M cast off, up between 2c, cast off and cross to 2pl (2c up) (2,1,3)

9–::

  1c lead down the middle and up to face 1cnr, 1M passing 1W under his right arm

17–::

  SetH&G , 1c clap on [23] as they petronella to 2pl

25–::

  2c+1c+3c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (11038, '2018-08-26 18:43:16.843229+00', '2018-08-28 16:19:50.719222+00', 18534, 1, 202, 'ace', '1--::

  1c+4c turn RH ½ and cast R to exchanged places | cast inwards (2c & 3c step out) ; 1c+4c RHA. On [8], 1c & 4c pull RSh back to face nearest cnr

9--::

  1c & 4c turn cnr BH, opening into | 2c+1c & 4c+3c Circle4 L ½ (to 1,2x,3x,4) ; 1c & 4c turn P BH 1½ _while{4}_ 2c & 3c turn P BH, finish 1c in promhold facing down and 2c & 3c & 4c NHJ facing up (1x,2x,3x,4x)

17--::

  »The Lazlo« [all set, 1c into allemande hold on [17] | 1c dance down {1} _while_ 2c separate to 1pl, 1c repeat with 3c{1} ; and with 4c {1}, 1c turn P LH {3} to 4plx] (2x,3x,4x,1x)

25--::

  2c+3c & 4c+1c S&Link ; all pass P LSh | 3c+2c & 1c+4c change places RH (polite turn) (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (10965, '2018-08-10 09:44:20.375446+00', '2018-08-10 09:54:35.95513+00', 12841, 1, NULL, 'ace', '1--::

  All turn P RH ¾ to midline | dance to own side and chase clw to (3x,2x,1x)

9--::

  All set | 3c facing 2c set advancing, passing Lsh ; 3c+1c repeat | All turn P RH into promhold facing up (order 2,1,3)

17--::

  Dance 6 bars of 3C Allemande | All cast R to own sideline (3,1,2)

25--::

  Circle6 and back (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (10966, '2018-08-10 10:31:18.513742+00', '2018-08-10 10:31:18.513742+00', 18497, 1, NULL, 'ace', '1--::

  1W followed by 2W+3W+4W cross, cast behind opposite line, cross at bottom and cast up to places

9--::

  1M+2M+3M+4M repeat 

17--::

  1c slip down the middle ; and up to 4pl (2c+3c+4c up) (2,3,4,1)

25--::

  All slip down and back (2,3,4,1)



', 3);
INSERT INTO 'dancecrib' VALUES (10975, '2018-08-13 17:07:49.639681+00', '2020-10-13 19:57:45.924255+00', 15301, 1, 202, 'ace', '*3c & 4c start on opposite sides*

1--::

  1c+2c & 3c+4c Circle 4 L ; 2C S&Link, finishing in centre with P, 2c&4c face down, 1c&3c up (2,1,4x,3x)

9--::

  All S&Link across (to 2x,1x,4,3) ; 2c+1c & 4c+3c Circle 4 L (2x,1x,4,3)

17--::

  All set | cross RH (to 2,1,4x,3x) ; 1c+4c ½ R&L (no polite turn) (2,4,1x,3x)

25--::

  Parallel Reels4

33--::

  2c+4c & 1c+3c RHA ; all set twice (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (11769, '2019-04-06 00:34:37.969017+00', '2019-04-20 21:40:48.414761+00', 19258, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c 2C Bourrel, at end turn RH into Allemande hold facing up (2,1,4,3)

9--::

  2c+1c & 4c+3c 2C Allemande (1,2,3,4)

17--::

  1c+4c Gypsy turn round P | cast to middle _while{2}_ 2c+3c dance to end ; 1c+4c RHA (2,1,4,3)

25--::

  1c+4c Poussette

33--::

  2c+1c & 4c+3c R&L (2,1,4,3)   



*danced twice only*

', 4);
INSERT INTO 'dancecrib' VALUES (3707, '2013-02-09 07:47:14.033875+00', '2017-10-25 13:00:02.650319+00', 12278, 1, NULL, 'ace', '1–::

  1c+2c S&Rotate, 1M and 2W face out (2,1)

9–::

  Reel4 across, 2M & 1W pass Lsh to start, finish (2,1)

17–::

  2M+1W turn LH ¾ _while_{2} 2W+1M cast one place on sideline | All turn P RH ½ ; repeat (i.e. nearly the M-Chain pattern)

25–::

  2c facing 1c set | all set to P ; Turn or spin P RH (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (10967, '2018-08-10 20:15:22.027826+00', '2018-08-10 23:40:51.041055+00', 1384, 1, NULL, 'ace', '1--::

  1M+2W turn RH ¾ and face out _while_ 1W+2M cast R to the other position on own side | 1M+2W cast to own places _while_ 1W+2M turn RH ¾ and face out (1,2) ; ½ Reel4 across (1M+2W start Lsh as 1W+2M cast clw (to 2x,1x) with 1W+2M facing out

9--::

  Repeat [1-8] from new positions (1,2)

17--::

  1c facing 2c S&Link with P ; 1c facing 2c set | ½ RHA (2,1)

25--::

  2c+1c R&L (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (13814, '2021-03-13 12:20:11.989323+00', '2021-03-13 12:22:59.061626+00', 9199, 1, 202, 'ace', '1--::

  1c ½ Fig8 down round 2c to 1pl centre NHJ ; 1c dance down between 3c | cast up to 2plx (2c up) (2,1x,3)

9--::

  Reels3 on sides, 1c crossing to 1pl, 2c out and down, 3c out and up. On [13] 1c cross down to 3plx. No loops except 2W. 2M faces out ready for (2,1x,3)

17--::

  2c+1c L-Chain. 1c face 1cnrs

25--::

  Set H&G. On [31-32] Petronella turn to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2969, '2012-01-22 19:30:05.010956+00', '2017-10-25 13:17:58.24808+00', 12277, 1, NULL, 'ace', '1–::

  All A&R ; Turn P RH ½ into the middle facing P | Cast R to opposite side

9–::

  All chase clw half way ; dance BtoB (4,3,2,1)

17–::

  G-Chain, 4c+1c cross to start

25–::

  1c dance to top NHJ, 1c dance down making arch over the others who dance up and follow, likewise making arches (2,3,4,1) (phrase this to flow, your choice; roughly 3 bars up, 5 down probably works best)', 3);
INSERT INTO 'dancecrib' VALUES (2500, '2012-01-22 19:29:45.2652+00', '2017-10-25 22:16:01.762552+00', 3231, 1, NULL, 'ace', '1–::

  1c+2c+3c set | cross RH ; repeat & 2c face out

9–::

  1c+2c DblFig8 (1c cross down), at end 2c face out and up (1,2,3)

17–::

  1c+2c+3c Inveran reels (1c cross down, and cross up from the bottom, 2c+3c full reel3 on own side) (1,2,3)

25–::

  1c with 2c following lead down {3}, turn RH ½ {1} ; turn on ½ moving upwards | 2c+1c lead up (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10971, '2018-08-11 04:17:50.710325+00', '2018-08-11 04:38:34.404221+00', 10755, 1, 202, 'ace', '1--::

  1c+2c S&Rotate, 2c face out at end (2,1,3)

9--::

  Reels3 on sidelines, 1c Lsh to 3cnrs (2,1,3)

17--::

  1c+1cnrs Corner Chain, face 2cnrs

25--::

  1c+2cnrs Corner Chain (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9118, '2016-03-16 19:50:05.396802+00', '2017-10-26 13:58:37.268957+00', 16905, 2, 160, 'ace', '1-8::
  1C set, cross RH ; cast to 2pl , turn RH (gently) to face 2corner.
9-12::
 2corners Pass&Turn *while* 1C dance round 2corner position and pass by Right shoulders to face 3corner;
13-16::
  1corners Pass&Turn *while* 1C dance round 3rd corner positions and turn with RH (zesty)  to face 2corners.
17-24::
  1C and 2corners dance 8-bar reel of 4 on diagonal - 1C pass by _Left_ shoulders to face 1corners.
25-32::
  1C and 1corners dance diagonal reel of four - 1C pass _Left_ shoulders to end in 2pl own sides.', 2);
INSERT INTO 'dancecrib' VALUES (2098, '2012-01-22 19:29:19.966706+00', '2019-01-30 23:41:37.465603+00', 12429, 1, NULL, 'ace', '1–::

  1c+4c cross RH | cast in (2c+3c step to ends) ; 1c+4c ½Fig8 round closest end C, finish in middle own side facing end C on the diagonal

9–::

  Intersecting Diag. Reels4 (brief LHA in the middle), finish as at start

17–::

  All turn facing person twice RH ; 1c+4c LHA to sidelines (2,1,4,3)

25–::

  1c+4c Bourrel [1M+4W set advancing | turn BH ¾ and swivel R into BtoB, 1M facing down, 4W up _while_{4} 1W+4M dance cclw round them to face P on midline ; 1c+4c set | turn BH ¾] to (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10204, '2017-10-25 21:11:30.926487+00', '2020-10-15 21:38:51.839682+00', 16558, 2, 2847, 'ace', '1-6:: 1s+2s set, hands joined on the sides, and dance RHA

7-8:: 1s cast off one place while 2s dance up NHJ and face out

9-16:: 2s+1s+3s dance reflection reels of 3 on own sides, 1s starting in and down, 1s finish in 2nd place facing down

17-20:: 1s+3s dance LHA

21-24:: 1s dance down between 3s and cast up one place

25-32:: 2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (10972, '2018-08-11 18:17:23.723739+00', '2020-11-12 10:27:56.183087+00', 18067, 2, 160, 'ace', '1-8::  1C cross, cast; half fig. 8  around 3C.

9-16::  1M 2C, 1W 3C dance Reel3 across the dance  - to begin 1C pass by R shoulder then give L shoulder to 2nd corner - 1C end passing Rsh to face 1st corners.

17-24::  Reel3 on sides - pass 1st corner by the right to begin

25-32::  Turn Corner Partner Corner Partner.', 3);
INSERT INTO 'dancecrib' VALUES (15088, '2022-09-06 17:13:32.200681+00', '2022-09-06 17:15:30.192954+00', 19618, 1, 1645, 'ace', '1--::

  All W RHA ; pass P LSh & cast back to place

9--::

  1c & 3c alternating tandem Figs of 8 round 4c/2c, W lead to start, M lead back to place

17--::

  All M LHA ; pass P RSh & cast back to place

25--::

  2c & 4c alternating tandem Figs of 8 round 3c/2c, M lead to start, W lead back to place

33--36::

  1c & 3c set | turn P &frac34; RH

37--44::

  1c+3c Reel4

45--48::

  1c & 3c set | turn P &frac34; LH

49--64::

  2c & 4c repeat [33--48] & all face corners

65--::

  Two changes of Gr-Chain (2 bars per hand, starting RH) ; turn 3rd person RH to face the way they came

73--::

  Two changes of Gr-Chain (2 bars per hand, starting LH) ; turn P 1&frac14; LH to end with W BtoB in centre

', 2);
INSERT INTO 'dancecrib' VALUES (10377, '2018-01-13 02:21:48.61719+00', '2018-01-13 15:43:14.098213+00', 15445, 1, 202, 'ace', '*Strathspey*
1--::
  1c+2c & 3c+4c Mirror S&link, 1c & 3c dancing inside, 2c & 4c casting up ; 2c+1c & 4c+3c set | 1c & 3c cross RH (2,1x,4,3x)
9--::
  Mirror Reels4, Lsh on W side
17--::
  1c+4c ½ R&L (to 2,4x,1,3x) ; 2c+4c & 1c+3c ½ R&L (4,2x,3,1x)
25--::
  4M+2M & 3m+1M cross RH | 4W+2W & 3W+1W cross LH (to 2,4x,1,3x) ; 4c & 3c turn P BH (RH in reel time) 1 ½ (2,4,1,3)

*Repeat in Reel Time from new positions.*

Note from deviser

*Ending of the dance "The Bug" variation (last time through in Reel Time)*
29-30:: 4c & 3c cross RH
31-32:: All step in with R foot in 2 Circle4 formations and freeze
:: Finish 1,2,3,4 holding hands in 2 Circle4 formations', 2);
INSERT INTO 'dancecrib' VALUES (11746, '2019-03-26 08:29:56.575661+00', '2022-02-22 18:37:48.596469+00', 12166, 1, NULL, 'ace', 'Intro for Bow & Curtsey  



*First Figure {64}*

1-16::

  All dance full Petronella, facing P

17--::

  Double La-Chain (W start ½ RHA)

25--::

  All W fig8, Rsh to cnr, Lsh to P

33--::

  All turn cnr LH ; P RH

41--::

  Double M chain (M start ½ LHA)

49--::

  All M fig8, Lsh to cnr, Rsh to P

57--::

  All turn cnr RH ; P LH   

   

  

*Second Figure {32}*

65-80::

  Schiehalliion Reel to the Left

81--::

  All Set to P | change place RH and pivot R to face next person ; Set to new P | pass LH (no pivot)

89--::

  Repeat [81-88] (3,4,1,2)    

    

  

*Third Figure {32}* 

97--::

  Facing P, all Set with Coupé/PdB ; All turn P RH

105--::

  1c+3c NHJ lead out in PdB | Set to P ; turn P RH _while{8}_ 2c+4c set NHJ | Advance in PdB ; RHA, forming a longwise set

113--::

  Reels4 on both sides, 1c start inwards and 4c outwards, at the end 2c & 4c pass with the other shoulder in the middle

121--::

  All turn cnr LH ; Turn P RH, retaining hand for Bow/Curtsey





', 3);
INSERT INTO 'dancecrib' VALUES (10705, '2018-04-28 19:59:51.46658+00', '2018-10-30 22:28:00.664174+00', 18309, 1, 106, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 up (2,1,3)

9--::

  2c+1W & 1M+3c 1½ RHA | 1c cast to 2pl (2x,1,3x)

17--::

  1c ½ diag. Reel4 (Rsh to 1cnr[pos]), 1c pass Rsh ; ½ diag. Reel4 (Rsh to 2cnr) (3,1x,2)

25--::

  3c+1W & 1M+2c 1½ LHA | 1c cast to 2plx (3x,1x,2x)

33--::

  1c ½ diag. Reel4 (Rsh to 3cnr), 1c pass Rsh ; ½ diag. Reel4 (Rsh to 4cnr) (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (8038, '2013-09-16 16:20:50.819211+00', '2019-04-20 22:08:45.098445+00', 15056, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  ½ G-Chain and all give P RH, W pass under arm to Allemande hold facing cclw : promenade cclw to places, at end W pass ahead to make single circle facing cclw

9–::

  All chase ½ round cclw , on [12] all pivot R, M making full turn, W ½ turn ; ladies chase outside clw to places _while_{4} the M chase cclw 1¼ inside, finishing BtoB in centre facing next W

17–::

  All pairs dance BtoB ; All W Glasgow Highlanders step R and L _while_{4} all M dance Rsh round W on R and into centre to face following W on the R

25–::

  repeat [17-24], finish facing P

33–::

  All set to P | turn P BH ¾ ; All pivot R and dance once round P (no hands), finish in places W facing out

41-56::

  Schiehallion Reel

57–::

  Circle8 and back



{{title}}

Reel



{{explanation}}

Repeat in Reel time, with the W using PdB+Spring points on [17-32] and all dancing Tulloch turns for [33-40]', 3);
INSERT INTO 'dancecrib' VALUES (12190, '2019-09-08 12:30:13.261857+00', '2019-09-08 12:47:07.190252+00', 3838, 1, 202, 'ace', '1--::

  1M set to 2W | cast off (2M up) ; 1W set to 2M | cast off (2W up) (2,1,3)

9--::

  1c set advancing to 1cnrs | turn 1cnrs RH into facing lines3 across ; 1c set advancing to 2cnrs | turn 2cnrs RH to (2,1x,3)

17--::

  1c lead down LH between 3c | cross and cast up round 3c ; dance up to top | cast off to 2pl (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3276, '2012-01-22 19:30:18.638758+00', '2019-04-20 22:31:25.515438+00', 10395, 1, NULL, 'ace', '1–::

  1c cross down (no hands) into Mirror Reesl3 on opposite sides

9–::

  1c cross down (no hands) into Mirror Reesl3 on own sides, 2c finish in 1pl as 1c flows into

17–::

  1c turn RH, moving to 2pl, cast out on own side and dance clw half round the set _while{8}_ 2c+3c set, cross RH into RHA

25–::

  1c turn LH, cast out on opposite side and dance cclw half round the set _while{8}_ 2c+3c set, cross LH into LHA (2,1,3)



{{explanation}}

Deviser''s alternative: on [25-32] 1c again turn RH and cast clw half round the set.  The phrasing of bars 17-24 and 25-32 is deliberately left ambiguous (particularly for 1st couple)', 3);
INSERT INTO 'dancecrib' VALUES (9682, '2017-03-27 12:17:29.478249+00', '2021-06-13 08:31:18.845806+00', 1830, 2, 3069, 'ace', '1-8:: 1,2,3C dance mirror reels of 3 to finish for Double triangles

9-16:: 1,2,3 C dance Reverse Double Triangles, 1st C dancing to their L, finish 1st man facing up, 1st Woman facing down

17-19:: 1st M with 2nd C and 1st W with 3rd C dance R hands across, 1st pass R sh

20-22:: 1M with 3rd C and 1st W with 2nd C dance L hands across, 1st C opposite sides

23-24:: 1,2,3 C Set

25-28:: 1st C dance half figure 8, 1st M up 1st W down to own sides.

29-32:: 1st C turn R hand into 2nd place



', 0);
INSERT INTO 'dancecrib' VALUES (3665, '2012-12-14 13:59:30.390548+00', '2018-08-12 14:22:59.064671+00', 14528, 2, 1294, 'ace', '1-4::

 1s & 4s turn RH, cast in one place

5-8::

  1s & 4s turn LH and 3/4 LH star to face corners - men at the top of the set, ladies at the bottom

9-24::

  Interlocking diagonal reels - 2s+3s forming a LH star in the middle, 1s+4s passing RSh and turning R in the middle. On the last change 1s and 4s pass partner LSh to face a person of the same sex, 4s at the top of the dance, 1s at the bottom

25-32::

  4s dance reel of 4 across with 2s & 1s dance reel of 4 across with 3s. Finish by turning 1/2 RH back to their own sides in the order 2,4,1,3



33-40::

  2s+4s+1s+3s circle 8H round & back



{{explanation}}

[When used as part of a display by Cambridge University Strathspey & Reel Club, we found it impractical for the dancing couples to pass RSh in the middle (i.e. going the long way around the other three dancers), as the deviser specified. We passed LSh, as you can see in the video.]', 3);
INSERT INTO 'dancecrib' VALUES (10978, '2018-08-13 22:34:41.430496+00', '2018-08-13 22:34:41.430496+00', 9938, 1, NULL, 'ace', '1--::

  1c set | lead down (2c up) ; change sides (1M crosses below 1W, who dances under joined arms | 1c lead up to between 2c who face down

9--::

  1c+2c set NHJ | 2M+1W & 1M+2W turn EH 1½ {6}

17--::

  Reels3 on opp. sides, 1c start down and in (2,1x,3)

25--::

  1c lead down, cross and cast up ; All turn P RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10974, '2018-08-13 13:03:12.447993+00', '2018-08-13 13:06:25.404775+00', 10852, 1, NULL, 'ace', '*Strathspey*



1--::

  1c+2c+3c set | 1c set adv to face 1cnr (2c up) ; 1c set to and turn 1cnr and face 2cnr

9--::

  1c set to and turn 2cnr ; 1c turn BH to (2,1x,3,4)



*Reel*



17--::

  1c 1cpl Poussette [¼ turn, down, ¼ turn, ¼ turn, down, ¼ turn, ½ turn, retire] (3c+4c up) (2,3,4,1)

25--::

  4c+1c R&L (2,3,4,1)





', 3);
INSERT INTO 'dancecrib' VALUES (10976, '2018-08-13 21:36:21.092708+00', '2018-09-04 06:50:31.976946+00', 2835, 1, NULL, 'ace', '1--::

  1c, 2c+3c following, cross and cast off behind opposite line ; cross back in 3pl and dance up to (1,2,3)

9--::

  1c cast off (2c up) | set advancing ; turn RH 1¼, finish facing 4cnr  

17--::

  1c ½ Reel3 on own side, Rsh to 4cnr ; ½ Reel3 across, Lsh to 1cnr [pos] (3x,1x,2x)

25--::

  1c ½ Reel3 on opp. side, Rsh to 2cnr ; ½ Reel3 across, Lsh to 3cnr (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14933, '2022-07-01 22:27:56.1682+00', '2022-07-01 22:31:54.713255+00', 5604, 2, 1, 'ace', '1–::

  1c set | cast off [2c up] ; turn ¾ RH to fin RS to RS facing own sides | set turning R about to fin facing 1crnrs

9–12::

  1c dance ½Reel4 w/1crnrs, at end dancing round ptr LS to fin facing 4crnrs

13–16::

  ½Reels3 on sides (1c LS to 4crnrs, fin in 2pl own sides, 1M facing 3M, 1W facing 2W)

17–20::

  1c dance ½Reel4 w/2crnr persons (on 1crnr diagonal), at end dancing round ptr LS to fin 1M facing 2M, 1W facing 3W (in 2crnrs'' places)

21–24::

  ½Reels3 across (1c LS to 2crnrs'' places, fin in 2pl own sides facing out; 2c curve up and in to face down, 3c down and in to face up)

25–::

  1c cast to L, cross over, cast to L again, cross LH _while_ 2c+3c dance R&L starting up and down [all fin crossing LH together]', 3);
INSERT INTO 'dancecrib' VALUES (3808, '2013-07-13 15:56:11.828823+00', '2018-08-13 19:56:08.520744+00', 11896, 1, NULL, 'ace', '1–::

  1c set | 1W with 1M following cast off one, cross, cast off and cross (1c now below 3c)

9–::

  1W+1M following cast up, cross, cast up and cross | All set (1,2,3)

17–::

  Rsh Parallel Reels3 on the sides (1,2,3)

25–::

  1c set | lead down below 3c ; Turn RH | cast up behind 3c (2c up) to (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10205, '2017-10-26 14:19:57.082835+00', '2017-10-26 14:19:57.082835+00', 18034, 2, 160, 'ace', '1-8::  1s+2s  4hands  round&back.
9-16::  1s cross, cast; half figure 8 up round 2s.
17-24::  turn 1corner RH; turn 2corner RH - finish in middle facing down RHJ.
25-32::  lead down the middle & up to 2place.', 5);
INSERT INTO 'dancecrib' VALUES (2764, '2012-01-22 19:29:56.464695+00', '2017-10-26 19:18:09.785035+00', 4257, 1, NULL, 'ace', '1–::

  1c cross RH, cast off one (2c up) ; 2c+1c+3c circle6 half round (to 3x,1,2x)

9–::

  1c+2c ½ R&L (man full polite turn) ; 2c ½ Fig8 up ; (3x,2x,1x)

17–::

  3c+2c+1c turn RH ; circle6 half round (to 1,2,3), 1c & 2c finishing in middle for

25–::

  1c+2c Allemande', 2);
INSERT INTO 'dancecrib' VALUES (10979, '2018-08-14 08:25:56.180965+00', '2018-08-14 08:40:10.899895+00', 15295, 1, 202, 'ace', '1--::

  1c lead down (2c up) ; and up to 1cnrs (2,*1*,3)

9--::

  ½ Reel4 on 1diag, pass Rsh ; ½ Reel4 on 2diag, 1M pull Rsh back fo face 3M, 1W on 1M L (3x,*1*,2x)

17--::

  1c NHJ set to 3M (swivel ½ inwards), set to 2W (veer L together), set to 2M (swivel ½ inwards), set to 3W and face P

25--::

  2c+3c chase clw ½ _while{4}_ 1c turn RH 1½ to 2pl ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11280, '2018-10-20 10:26:05.861654+00', '2018-10-20 10:31:44.031584+00', 19013, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c RHA ; LHA (1,2,3,4)

9--::

  All set | cross RH ; set | cross LH (1,2,3,4)

17--::

  1c+2c set | change places RH ; 1c+3c set | change places LH (2,3,1,4)

25--::

  1c+4c set | change places RH ; 1c turn P RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10981, '2018-08-14 10:21:04.035545+00', '2018-08-14 10:27:21.596981+00', 13984, 1, NULL, 'ace', '1--::

  1W cast off, dance Rsh round 3W _while{4}_ 1M cross and dance Rsh round 2W, 1c finish on midline facing up ; 1M casts round 2M and dances Lsh round 3M _while_ 1W dance up, and Lsh once round 2M (2c up), 1c finish on midline facing up, 1W leading

9--::

 1c+2cnrs Diagonal lead-change Reel3, Rsh to 2W, 1c finish facing 1cnrs

17--::

  [Set and Swap cnrs, RH]  All set | 1c+1cnrs turn RH ½ _while_ 2cnrs set turning R about ; 1c chase ¼ clw and turn P RH to face 4cnr [pos] _while_ 1cnrs turn LH ½ and dance to other end of diagonal facing in (Rsh back) _while_ 2cnrs chase ½ clw

25--::

  [Set and Swap cnrs, LH]  All set | 1c+4cnrs turn LH ½ _while_ 2cnrs set turning L about ; 1c chase ¼ cclw and turn P LH to 2pl _while_ 1cnrs turn RH ½ and dance to own end of diagonal facing in (Lsh back) _while_ 1cnrs chase ½ cclw (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10982, '2018-08-14 10:59:55.681354+00', '2018-08-14 10:59:55.681354+00', 13206, 1, NULL, 'ace', '1--::

  1W+2M & 3W+4M cross RH and cast Rsh round P to places ; 1c+2c & 3c+4c RHA

9--::

  1M+2W & 3M+4W cross LH and cast Lsh round P to places ; 1c+2c & 3c+4c LHA (1,2,3,4)

17--::

  1c+3c & 2c+4c Interlocking DblFig8, 1c+2c cross down & 3c+4c cast up to begin (1,2,3,4)

25--::

  ½ Reels 4 on the sidelines (4,3,2,1) ; top three W and bottom three M ½ Reels3 on sideline (to W: 2,3,4,1 and M: 4,1,2,3)





', 3);
INSERT INTO 'dancecrib' VALUES (10983, '2018-08-14 12:43:46.557345+00', '2018-08-14 12:43:46.557345+00', 11827, 1, NULL, 'ace', '1--::

  All set | Cross RH ; S&Link for 5C [2c+3c+4c normal S&Link3 into lines across in 2pl+4pl _while_ 1c+5c form line across in 3pl, 1M+5W (at LH end of the lines) cast clw to the ends and 1W+5M dance to the middles, all facing P]

9--::

  1c+5c ½ Reel4 across ; 1M+5M & 1W+5W turn RH 1½ to join ends of lines across on own side, 5c in 2pl and 1c in 4pl

17--::

  Repeat [5-8] from new positions. The centre dancers finish (4,3,2), with 5c+1c on midline facing P, M  above W ; 1c/5c turn P RH ½ moving to the end, and cast into 4pl/2pl (2c+4c step to end) _while_ 3c Turn P BH 1½ and face up in the middle (4,5,3x,1,2)

25--::

  3c dance to top | cast off 2 ; cross RH | cast off two (1c+2c up) (4,5,1,2,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10984, '2018-08-14 14:00:14.142358+00', '2018-08-14 18:15:42.364434+00', 15479, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; 2c+1W & 1M+3c RHA, 1c face 1cnr

9--::

  1c dance pattern of Reel4 on 1diag _while{8}_ 2c+3c R&L, 1c finish facing own side for

17--::

  DTr, 1c finish on own side facing down

25--::

  1c dance between 3c and cast up ; dance between 2c and cast off (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11281, '2018-10-20 10:38:27.547188+00', '2018-10-20 10:43:59.442933+00', 19014, 1, 202, 'ace', '1--::

  All A&R ; cross RH (1x,2x,3x)

9--::

  Repeat [1-8] (1,2,3)

17--::

  1c cross | cast (2c up) ; ½ Fig8 up round 2c (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (8099, '2013-10-25 23:18:31.887456+00', '2022-11-08 12:31:10.869155+00', 15219, 1, NULL, 'ace', '1–::

  1c+2c S&Link »mirrored« for the M : 1M cast, 2M dances up ; ½ Fig8 R between end couple, finish in middle facing 1cnr

9–::

  1c+1cnrs »set and cast away« (set to cnr | cnrs dance to middle to face own place as middles cast R round each other to the diagonally opposite corner ; repeat from new positions, and 1c face 2cnr

17–::

  1c+2cnrs repeat [9-16], 1c finish on own side (3x,1,2x)

25–::

  1c+2c ½ RHA _while_{2} 3c cross RH | 1c cross LH _while_{2} 3c+2c change LH on sidelines ; All turn P BH', 3);
INSERT INTO 'dancecrib' VALUES (2734, '2012-01-22 19:29:55.160724+00', '2021-03-13 15:53:11.683915+00', 2387, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  All set | turn BH into ; circle4 Left

9–::

  Slipknot (6 bars »Knot« ; finish with ½ LHA to original places)



{{title}}

Reel



17–::

  (»Red House Reels«) On M sideline, 2M Lsh reel3 with 1M and 1W who crosses down to the bottom of the reel.  At the end, the men loop to change places _while_ 1W returns to 1pl.

25–::

  On W sideline, 2W Rsh reel3 with 1W and 1M who crosses down to the bottom of the reel.  At end, the women  loop to change places _while_ 1M returns to 2pl', 2);
INSERT INTO 'dancecrib' VALUES (14625, '2022-02-26 11:50:57.845128+00', '2022-02-26 11:54:05.630477+00', 5678, 1, 1645, 'ace', '*3c & 4c start on opposite sides (1,2,3x,4x)*

1--::

  1c & 4c cross RH | cast inwards (2c & 3c out) ; 1c+4c RHA, 1M+4W & 4M+1W face out in promhold

9--::

  1M+4W (W side) & 4M+1W (W side) &frac12; RSh Reels3, end in promhold with P ;

  1c (M side) & 4c (W side) &frac12; LSh Reels3, end in lines across 2W+4M+4W+2M facing down to 3M+1W+1M+3W

17--::

  All set facing up/down | change pl RH up/down ; repeat

25--::

  2c+4c & 3c+1c Reels4 across, 4c & 1c end passing P RSh and join RH

33--::

  4c+1c &frac12; RHA | dance LSh round corners{4} | change pl RH on sides (2,4,1x,3x)

41--::

  All circle8 to L & back (2,4,1x,3x)



', 2);
INSERT INTO 'dancecrib' VALUES (12192, '2019-09-09 11:23:51.775281+00', '2019-09-09 11:40:06.295157+00', 14921, 1, 202, 'ace', '1--::
  1c+2c R&L (1,2,3)
9--::
  1c Mirror Fig8 on sides, starting in and down, taking hands when possible (1,2,3)
17--::
  1c continue ½ Mirror Fig8 on sides (2c up on [17-18], 3c up on [19-20]) ; 3c+1c RHA (2,3,1)
25--::
  1c Fig8 up round 3c (2,3,1)

*Deviser''s note:*  
To dance this in a 4C set:
25-28::
   First couple crosses with right hands and casts up one place. Third couple steps down.
29-32::
  First couple dances a half figure of eight around third couple, crossing down to
begin.', 2);
INSERT INTO 'dancecrib' VALUES (10706, '2018-04-29 04:20:53.802268+00', '2018-04-29 04:33:38.488956+00', 16689, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; 1c ½ Fig8 R round 1cnrs and face 1cnrs

9--::

  1c+1cnrs pass, cnrs turn RH and change places as 1c meet and pass Rsh ; repeat with 2cnrs (to 3x,1,2x)

17--::

  Diagonal R&L (2,1,3)

25--::

  1c dance Rsh round P to 2pl ; A&R[1+1] long step | A&R[1+1] short step', 2);
INSERT INTO 'dancecrib' VALUES (14826, '2022-05-12 11:58:40.056363+00', '2022-05-15 18:50:08.581839+00', 282, 1, 202, 'ace', '1--::
  Mirror Reels3 on sides, 1c in. 1c & 3c slightly in centre face up/down (1,2,3)
9--::
  1c & 3c both NHJ A&R back to original places on sides facing P ; 1c & 3c dance BtoB (1,2,3)
17--::
  1c+2c S&Link (4 PdB) ; 1c+3c S&Link (4 PdB)  (2,3,1)
25--::
  Circle6 and back (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (10901, '2018-07-14 20:23:12.199271+00', '2019-01-31 19:51:25.479069+00', 18382, 2, 13458, 'ace', '1-8:: 1s turn with both hands and cast to 2nd place, 2s step up at bars 3-4. 1s set and petronella into the centre in lines of 3 across. 1M + 3s facing up and 1L + 2s facing down



9-16:: All set.  1s cast to 2nd place own side WHILE 2s + 3s change places RH.     All set and cross RH, 1s end facing out 



17-24:: 1s cast right round 1st corner position, dance into the middle of the set, giving right hand as they pass and cast right around 2nd corner position ending in 2nd place opposite side WHILE 2M + 3L dance in towards each other, not giving hands, passing right shoulder, turn about to face each other, turn away and dance to other corner on own side. 3M + 2L repeat the “Dance in and Pass” figure to own side (21x3)

  

25-32:: 1M with 2s (up) and 1L with 3s (down), dance right-hand across.  1s ½ turn both hands.  Pause, pull right shoulder back and dance out to own side in 2nd place

', 3);
INSERT INTO 'dancecrib' VALUES (10986, '2018-08-15 00:07:21.81188+00', '2018-08-15 00:13:19.144314+00', 15289, 1, 202, 'ace', '1--::
  1c cross RH between 2c and face P | 1c set (2c up) ; 1c pulling RSh back cast R through 2pl round 1cnrs into facing lines3 across
9--::
  3C S&Link twice, at end 3M(2W) face up(down)
17--::
  ½ Reels3 across, 1c Lsh to 2cnrs[pos] ; ½ Reels3 on sidelines, 1c Lsh to 4cnrs[pos], into facing lines3 across (1W between 2c facing down, 1M between 3c facing up)
25--::
  1c cross RH up/dn and cast R round 2cnrs to 2plx ; 1c set | cross RH (2,1,3)
33--::
  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (14338, '2021-09-27 20:45:34.052961+00', '2021-09-27 20:45:45.69676+00', 5773, 1, 1645, 'ace', '1--::

  1c lead down & up, crossing to face out opp side (1x,2,3)

9--::

  1c+2c DblFig8 giving hands, 2c start crossing up as 1c cast off

  _while{8}_ 3c &frac12; turn RH | dance to top following 1c ; cast off | cross to face out (1x,2,3)

17--::

  2c+3c &frac12; DblFig8 giving hands, 2c start crossing down as 3c cast up _while{4}_ 1c set | dance down NHJ following 3c ;

  all M LHA on W side as W RHA on M side

25--::

  1c, 2c & 3c cross to other wheel, W before P, dance up sides & 1c face out (1,2,3) ; 1c+2c turn 1&frac12; EH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (6046, '2013-08-21 08:31:18.419423+00', '2023-02-04 01:23:04.93716+00', 3631, 3, NULL, 'ace', '1-8::
    1s cross RH, set to 2s on sides & turn LH into line of 4 across with
    1s in centre holding RH & Balance-in-Line
9-16::
    1s turn 2s LH onto sides (1s into 1st place) & set to 2s on sides,
    1s cross RH & set to partner
17-24::
    1s lead down the middle & back to top
25-32::
    1s+2s Allemande', 0);
INSERT INTO 'dancecrib' VALUES (12193, '2019-09-09 21:20:02.236521+00', '2019-09-09 23:18:08.150148+00', 19637, 1, NULL, 'ace', '1--::

  1c dance down (2c up) | cast behind 3c as 3c dance up ; 2c+3c+1c ½Reels4 on the sides, 3c starts out and up (1,3,2)

9--::

  1c+3c DblFig8 (1c cross down) (1,3,2), 

17--::

  1c+3c+2c ½Reels3 on the sides, 3c starts out and up ; 1c cross RH and cast up (3c down) (2,1x,3)

25--::

  1c ½ Fig8 R ; All Turn P RH and set (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12194, '2019-09-09 21:21:07.19169+00', '2019-09-10 13:15:56.136181+00', 19638, 1, NULL, 'ace', '1--::

  1c+2c+3c S&Link ; repeat (3x,2x,1x,4)

9--::

  All set | ½ Circle6 L ;  All set | 1c cast off (2c up) (2,1,3,4) 

17--::

  1c+3c+4c Inveran Reels (2,1,3,4)

25--::

   1c dance to bottom and cast up (3c up) ; 1c+4c turn P BH ½ |Circle4 L ½ (2,3,4,1)  



*Can be danced in a 7C (even a 10C) set, 1c & 4c (& 7c) starting*', 3);
INSERT INTO 'dancecrib' VALUES (10980, '2018-08-14 08:50:40.462672+00', '2018-08-16 23:04:21.916546+00', 15288, 1, 202, 'ace', '1--::

  1c lead down (2c up) ; and up to 1cnrs (2,*1*,3)

9--::

  ½ Reel4 on 1diag, pass Rsh ; ½ Reel4 on 2diag, 1M pull Rsh back fo face 3M, 1W on 1M L (3x,*1*,2x)

17--::

  1c NHJ set to 3M (swivel ½ inwards), set to 2W (veer L together), set to 2M (swivel ½ inwards), set to 3W  (3x,*1*,2x)

25--::

  1c cast off through 2plx to 3plx | cross RH to 3pl _while{4}_ 2c lead up and cross to 1pl with a loop _while{4}_ 3c cast to 2plx and cross RH ; all turn P RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10989, '2018-08-15 07:03:36.331411+00', '2018-08-15 07:54:40.670441+00', 15291, 1, 202, 'ace', '1--::
  All W dance Rsh round P and face P ; all set | all W cast away to original places _as_ all M set (1,2,3,4)
9--::
  All repeat [1-8] but all M dancing Rsh round P. On [16], all pivot  to face clw, M(W) up(down) (1,2,3,4)
17--::
  All chase clw ½ (to 4x,3x,2x,1x) ; 4c+3c+2c ½ Reels3 on sidelines, 3M(3W) Rsh to 2M(4W) (2x,3x,4x,1x)
25--::
  All Petronella Turn | set ; repeat [25-28] (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10991, '2018-08-17 02:57:21.428902+00', '2018-08-17 03:05:17.903344+00', 13361, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; ½ Fig8 up between 2c (2,1x,3)

9--::

  3C S&Link twice (3x,1,2x)

17--::

  ½ Reels3 across, 1c Lsh to 1cnrs[pos] ; ½ Reels3 on sidelines, 1c Rsh to 2cnrs[pos] (2,1x,3)

25--::

  1c ½ Fig8 down between 3c ; dance down between 3c and cast to 2pl (2,1,3)



*Deviser''s note:  

It this dance is being done in a 3 couple set, on bars 29-32, 1st couple gives nearer hands to dance down between 3rd couple, then makes a long turn into 3rd place on the last 2 bars, as 3rd couple steps up into 2nd place.*', 2);
INSERT INTO 'dancecrib' VALUES (11494, '2019-01-04 14:46:59.740384+00', '2020-09-19 20:03:18.814942+00', 19133, 1, 1645, 'ace', '1-::
  1c set | cast off (2c up) ; &frac12; fig8 (2,1x,3)
9-::
  1c cross down into mirror Reels3 own sides & end facing 2cnrs as cnrs end with loops (2,1,3)
17-28::
  Dance to each corner & set, 1M/1W end facing P down/up in centre, cnrs face clw (3x,1,2x)
29-32::
  1c set | turn &frac34; RH _while{4}_ cnrs chase &frac12; way clw (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (10207, '2017-10-26 19:53:48.86788+00', '2021-01-08 11:46:51.438875+00', 12862, 2, 160, 'ace', '1-8::  1s dance full fig. 8 round 2s.  (cross down to begin)

9-16:: 1s cross, cast ; turn RH 1_1/4 - 1W end btwn 2s facing up, 1M btwn 3s facing down.

17-24::  Rshoulder reel3 across the dance [6] - end 2place on opp. sides. 1s set.

25-32::  1s dance half fig. 8 round 3s ; all turn RH once round.', 3);
INSERT INTO 'dancecrib' VALUES (13461, '2020-12-09 00:51:49.377939+00', '2020-12-09 00:55:03.135828+00', 20153, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 2c+1c ½ R&L (1,2x,3)

9--::

  Mirror Reels3 on sides, 1c in and down (1,2x,3)

17--::

  3C S&Link twice (3x,2,1x)

25--::

  All chase clw ½ (to 1,2x,3) ; 1c+2c change places RH on sides | 2c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12195, '2019-09-09 21:23:13.780034+00', '2019-09-09 23:50:39.294945+00', 19639, 1, NULL, 'ace', '1--::

  1c Fig8 round 2c, finish BtoB on own side facing 2c

9--::

  1c+2c Reel4 across, 2c finish in 1pl facing inand 1c in 2pl facing out (2,1,3,4)

17--::

  2c+1c+3c ½ Reels3 on sides, 1c start out and down (3,1,2,4) ; ½ Reels4 on sides, 3c+2c start in and down (4,2,1,3)

25--::

  4c+2c & 1c+3c turn opposite EH (M RH, W LH) 1½ on the sides ; 4c+1c turn opposite 1½ on sides (M LH, W RH) (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (11974, '2019-07-23 16:32:05.494247+00', '2021-03-13 20:09:34.740745+00', 19061, 1, 202, 'ace', '1--::

  All W RHA ; dance LSh round P to places | All C NHJ set (1,2,3,4)

9--::

  All M LHA ; dance RSh round P to places | All C NHJ set (1,2,3,4)

17--::

  All W Petronella Turn one place cclw | All C NHJ set ; All M repeat [17-20] (2,3,4,1)

25--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (11555, '2019-01-31 22:35:52.166934+00', '2019-01-31 22:36:14.596362+00', 19179, 1, NULL, 'ace', '1--::

  1W, 1M following, castoff cross (2c up) cast off to face 1cnr

9--::

  1c+1cnrs ½ diag Reel4 pass Lsh ; 1c+2cnrs ½ diag Reel4 (3x,1x,2x)

17--::

  3W+2M half turn and cast away ; 3M+2W rwpw (2,1x,3)

25--::

  All A&R ; 1c turn BH 1½ (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (14626, '2022-02-27 23:53:39.578614+00', '2022-02-27 23:56:15.684677+00', 17559, 1, 1645, 'ace', '1--::

  1c+2c set | &frac12; RHA ; set | cross LH ((2,1,3)

9--::

  1c+3c set | &frac12; RHA ; set | cross LH ((2,3,1)

17--::

  1c set | cast up (3c down) ; lead up | cast off round 2c (2,1,3)

25--::

  All Circle6 & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11283, '2018-10-20 11:08:54.457256+00', '2018-11-08 14:45:21.575112+00', 19016, 1, 202, 'ace', '1--::

  1c+2c RHA ; LHA (1,2,3)

9--::

  1c turn RH | cast ; turn LH (2,1,3)

17--::

  1W+2c & 1M+3c Fig8 R (2,1,3)

25--::

  1c lead down {3}, up to 2pl {3}, cast to 3pl (2,3,1)



*Deviser''s note:  

For more experienced dancers Bars 17 – 24 may be danced as Reels of 3 across.*', 2);
INSERT INTO 'dancecrib' VALUES (10378, '2018-01-14 01:34:12.427285+00', '2018-01-14 01:40:43.557957+00', 15446, 1, 202, 'ace', '1--::

  1W followed by 1M casts off and chase clw to 4plx _while{4}_ 4M followed by 4W casts up and chase clw to 1plx _while{4}_ 2c+3c LHA ending LHJ in centre and RHJ with cnrs in a St. Andrew’s Cross ; all set | all release LH and change places RH (2,4x,1x,3)

9--::

  Repeat [1-8] from new positions to sidelines (4x,3x,2x,1x)

17--::

  1c+2c ½ Reel4 across, 1c passing Lsh to start then 1M(1W) Rsh to 2W(2M), 2c ending in 4pl ; 1c+3c ½ Reel4 across, 1c passing Lsh in centre then 1M(1W) Rsh to 3M(3W), 3c ending in 3pl

25--::

  1c+4c ½ Reel4 across, 1c passing Lsh in centre then 1M(1W) Rsh to 4W(4M), 4c ending in 2pl ; 1c turn RH | 1c lead down to 3pl (4c+3c up) (4,3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (11282, '2018-10-20 10:58:31.435539+00', '2019-03-03 09:37:57.695671+00', 19015, 1, 202, 'ace', '1--::

  1W followed by 2W+3W chase cclw behind M side to places

9--::

  All M, 1M leading, repeat same pattern clw

17--::

  1c dance down {3}, up {3} and cast to 2pl {2} (2,1,3)

25--::

  All turn P RH ; turn P LH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8221, '2014-03-24 17:17:15.588887+00', '2017-10-26 20:40:15.846739+00', 10478, 2, 160, 'ace', '1-2::  1s  turn RH 1/2 way moving down to 2pl & face up nhj  _while_ 2C dance up to 1pl and  face down nhj  (2 1x)
3-4::  2s+1s set to each other ; 
5-8::  2C+1C set and cross link - end on sidelines (2x 1 3)
9-16::  1s and 3s repeat bars 1-8  (2x 3x 1)
17-24::  1s turn RH, cast up 1place (3s down) ; 1s pass Rsh+ face ptnr momentarily, cast R about to face out in 2 pl on opp.side  (i.e. a 1/2 Turn+Twirl no hands). (2x 1x 3x)
25-28::  1s cast round 1st crnr to meet in middle+pull Rsh back (end back-to-back : 1L face up, 1M face down) _while_ 1corners pass Rsh + curl to face, cast into dia. opp. place;
29-32::  1C cast round 4th corner to end in 2pl own sides _while_ 2nd crnrs pass Rsh + curl to face, cast into dia. opp. place.', 5);
INSERT INTO 'dancecrib' VALUES (11287, '2018-10-20 23:59:14.167781+00', '2018-11-08 15:27:44.359154+00', 19030, 1, 202, 'ace', '1--::

  1c lead down {3}, up {3} | cast (2c up) (2,1,3)

9--::

  ½ Reel3 across, 1c RSh to 2cnrs ; ½ Reel3 across, 1c RSh to 4cnrs. 1c pass RSh to face 1cnrs

17--::

  »modified Corners Pass and Turn« [same as Corners Pass and Turn except that cnrs turn RH ½, face each other and cast away to exchanged places]. 1c to 2plx (3x,1x,2x)

25--::

  All turn P RH ; chase clw ½ (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (8386, '2014-08-20 12:25:29.219426+00', '2020-02-08 13:49:45.548579+00', 15573, 2, NULL, 'ace', '1–4::

    1s cross down RH to 2nd pl on opp. sides to face in (2s move up on [1-2]) | all set.

5–16::

    R&L for 3 couples

17–20::

    1L+2M+1M dance half diag Reel3 (1L LSh to 2M to start, fin 1M in orig pl, 2M in 2W''s pl, 1L in 2M''s pl)

21–24::

    1L+2M+3M dance half diag Reel3 (1L RSh to 3M to start, fin 1L in 2W''s pl, 2M in 3M''s pl, 3M in 2W''s pl)

25–28::

    1s change places diagonally with 3s RH | all set on the sidelines

29–32::

    1M with 3L (middle places) change places LH | all set on the sidelines



At the end, all have a new partner (3M+2L, 1M+3L, 2M+1L)



*Note:* During bars 17–24, 1L dances the track of a complete reel of 3 on the men''s sideline.



(Dance Crib compiled by the devisor, Hans Prade, and radically abridged by Anselm Lingnau.)', 3);
INSERT INTO 'dancecrib' VALUES (11284, '2018-10-20 17:14:50.219246+00', '2018-10-20 17:18:59.825391+00', 19019, 1, 202, 'ace', '_Strathspey_  

1--::

  1c+2c RHA ; LHA (1,2,3)

9--::

  1c cross (no hands) to 2pl | dance round 3c ; meet and dance up | 1c turn 2c EH to 2plx (2,1x,3)  



_Reel_

1--::

  Reels3 across, 1c RSh to 4cnrs (2,1x,3)

9--::

  Reels3{6} on sides, 1c RSh to 2cnrs | 1c cross RH', 2);
INSERT INTO 'dancecrib' VALUES (11285, '2018-10-20 17:22:12.861852+00', '2018-10-20 17:30:09.857347+00', 19017, 1, 202, 'ace', '_Strathspey_  

1--::

  1c+2c & 3c+4c set | chase clw ½ ; repeat to places (1,2,3,4)

9--::

  1c & 3c Fig8 down round 2c/4c (1,2,3,4)

17--::

  2c & 4c Fig8 up round 1c/3c (1,2,3,4)

25--::

  1c+2c & 3c+4c R&L (1,2,3,4)



_Reel_

1-24::

  Repeat [1-24] (1,2,3,4)

25--::

  1c+2c & 3c+4c Poussette (2,1,4,3)', 2);
INSERT INTO 'dancecrib' VALUES (11289, '2018-10-21 00:14:55.186635+00', '2018-10-21 00:21:35.017594+00', 19022, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c DblFig8, 1c & 4c crossing down/up to start (1,2,3,4)

9--::

  Circle8 and back (1,2,3,4)

17--::

  All dance BtoB ; turn P RH (1,2,3,4)

25--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 1c+4c ½ R&L (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11288, '2018-10-21 00:08:19.496606+00', '2018-10-21 00:25:03.880596+00', 19025, 1, 202, 'ace', '1--::

  2c+3c RHA ; LHA (1,2,3,4)

9--::

  1M+4W turn BH ; 1w+4M turn BH (1,2,3,4)

17--::

  1c+2c & 3c+4c Circle4 L. 1c & 3c face down, 2c & 4c face up ; all set | 1c & 4c cast inwards (2c & 3c dance out to ends) (2,1,4,3)

25--::

  Circle8 and back (2,1,4,3)', 2);
INSERT INTO 'dancecrib' VALUES (11290, '2018-10-22 04:17:05.906578+00', '2018-10-22 04:20:56.978651+00', 19028, 1, 202, 'ace', '1--::

  2c+3c RHA ; LHA (1,2,3,4)

9--::

  1c+2c & 3c+4c Circle4 and back (1,2,3,4)

17--::

  1c lead down ; and back (1,2,3,4)

25--::

  1c cast to 4pl (2c+3c+4c up) ; all dance BtoB (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (7837, '2013-08-21 08:31:49.573393+00', '2023-02-04 01:23:04.968189+00', 9505, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance double Fig of 8 (1s & 3s cross down to start)
9-16::
    1s & 3s lead down for 3 steps, turn RH cast up round 4s/5s to face
    1st corners
17-24::
    1s & 3s set to & turn 1st corners 2H, set to & turn 2nd corners 2H
25-32::
    1s & 3s dance RH across (1M with 2s, 1L+3M with 4s & 3L with 5s),
    pass ptnr LSh to face own side (as double triangle), all set, 1s &
    3s cast 1 pl', 0);
INSERT INTO 'dancecrib' VALUES (14339, '2021-09-27 23:06:32.222249+00', '2021-09-27 23:10:20.574622+00', 10261, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; cross down between 3c into BiL on 1diag, LSh to P 

9--::

  Bil | 1c set advancing into BiL on 2diag ; BiL | 1c turn LH to 2plx and face out

17--::

  Reels3 on sides, 1c LSh to 2cnrs. 1c face 1cnrs

25--::

  Corners Pass and Turn (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12196, '2019-09-09 21:24:55.683572+00', '2019-09-10 00:13:46.893366+00', 19640, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c Poussette (1,2,3,4)

9-12::

  1c+3c turn P RH ¾ and face own side | all cast R round 1 person (and 2W+4W step up), (M: 1,2,3,4 ; W: 2,1,4,3)

13-16::

  1c+2c & 3c+4c S&Link (M: 2,1,4,3 ; W: 1,2,3,4)

17--::

  Reel4 on the sides, _middle dancers_ pass Lsh to start (to same positions)

25--::

  1M+3M (start up) & 1W+3W (start down) dance Rsh round next dancer,  and turn P BH ¾ and face down NHJ (2W+4W up) ; 1c dance to 4pl and 3c cast up to 2pl (2,3,4,1)  ', 3);
INSERT INTO 'dancecrib' VALUES (11291, '2018-10-22 04:24:42.417989+00', '2018-12-09 13:46:48.862317+00', 18967, 1, 202, 'ace', '1--::

  1c Parallel Reels3 on sides, 1c RSh to 2c (1,2,3)

9--::

  1c+2c RHA ; LHA (1,2,3)

17--::

  1c lead down {3}, up {3} | cast (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3562, '2012-01-22 19:30:31.251236+00', '2022-10-23 20:45:01.539569+00', 7233, 1, NULL, 'ace', '1–::

  1M+2W set | 1M casts to 2pl (2M up) ; 1Wsets to 2M | 1W casts to 2pl (2W up) (2,1,3)

9–::

  1c cross RH and cast round 1cnr into lines across ; all turn person opposite RH, 2c+3c remain facing out the ends and 1c face P

17–::

  1W+2c & 1M+3c Reels3 across, Rsh to 1cnr, all finish facing P

25–::

  1c cross up/down LH, cast L round 3cnr to 2pl ; all turn P LH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12210, '2019-09-14 18:15:27.102353+00', '2019-09-14 18:22:03.44593+00', 14461, 1, 202, 'ace', '1--::

  All set | 1c+2c ½ RHA _as_ 3c cross RH. 1W faces out ; 1W followed by P dances RSh round 2W, down the middle into lines3 across all facing down

9--::

  All dance down ; and up. On [16] 1M+2c pivot R to face down

17--::

  All set | all change places RH with opposite person ; 1c dance RSh round 4cnrs[pos] to 2pl | all set (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12197, '2019-09-10 21:13:44.727514+00', '2019-09-12 00:38:48.918412+00', 17417, 1, 202, 'ace', '1--::

  1c cast off (2c up) | ½ Fig8 R LSh round 1cnrs ; turn LH and finish in centre LSh to P facing 2cnrs

9--::

  ½ Reel4 on 2diag, pass P LSh ; ½ Reel4 on 1diag, 1c finishing in centre LSh to P, 1M(1W) facing up(down) (3x,1x,2x)

17--::

  »Weasel Reel« [: ½ Reel4 on midline.  Dancers entering (3W & 2M to start) and leaving the reel (1M & 1W to start) pass RSh, on reaching the end each dancer chases clw to the other end, and is replaced in the reel4 by a dancer finishing that chase]. Finish as started except 1c who finish as on [8]

25--::

  Repeat same pattern [9-16] to sides (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14334, '2021-09-26 10:10:26.459045+00', '2021-09-26 11:08:34.69416+00', 16845, 1, 202, 'ace', '1--::

  1c & 2c Petronella turn | set advancing passing P LSh. On [4] 1M & 2M pivot L (travelling step L) to finish behind P. All face up 2W leading ; 2c dance down, cast to 1pl _while{4}_ 1c following 2c cross and cast to 2plx (2,1x,3,4)

9--::

  2c+1M RHA _while{4}_ 1W+3c ½ Reel3 across, 1W RSh to 3M and 3c casting (to 2,1x,3x) ; 2c+1W LHA _while{4}_ 1M+3c ½ Reel3 across, 1M LSh to 3M (2,1x,3,4)

17--::

  1c+3c R&L (2,1x,3,4)

25--::

  2c+1c+3c NHJ set advancing. End of [26] all face up, 2c & 3c NHJ | 2c dance up and cast to 1pl _while{2}_ 1c cast to 3plx _while{2}_ 3c dance up to 2pl (to 2,3,1x,4) ; 1c+4c turn EH | 1c cross down to 4pl _while{2}_ 4c dance up to 3pl (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12200, '2019-09-12 16:41:27.234568+00', '2019-09-12 16:41:27.234568+00', 3590, 1, NULL, 'ace', '1--::

  1c+2c A&R ; ½ R&L (2x,1x)

9--::

  Repeat [1-8] (1,2)

17--::

  1c cast off as 2c lead up | 2c+1c set ; 2c cast off as 1c lead up | All set (1,2)

25--::

  1c lead down {3} and up {3} | 1c cast off (2c up) (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (12201, '2019-09-12 18:16:39.101068+00', '2019-09-12 18:21:43.890354+00', 11491, 1, 202, 'ace', '1--::

  1c dance down {3}, cast up round 3c {3} to 1pl | cross into DTr position (2c up) (2,1,3)

9--::

  DTr, 1c finishing facing 1cnrs[pos] _while{8}_ 2c & 3c set | cross RH ; set | change places LH on sides (3x,1,2x)

17--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag, pass RSh to 2pl (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12202, '2019-09-12 18:31:48.82962+00', '2019-09-12 18:35:33.077153+00', 883, 1, 202, 'ace', '1--::

  1M sets to P | casts off (2M up) ; 1W sets to 2M | casts off (2W up) (2,1,3)

9--::

  All dance BtoB ; all NHJ A&R (PdB) (2,1,3)

17--::

  1c turn RH 1¼ into facing lines3 across (1M between 2C facing 1W between 3c) ; all NHJ A&R (PdB)

25--::

  All change places RH | set ; 2c & 3c repeat _while{4}_ 1c turn RH to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12203, '2019-09-12 23:51:02.863705+00', '2019-09-13 00:25:18.571722+00', 14469, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c crossing down. On [8] 1c & 3c finish slightly inside the set (1x,2,3)

9--::

  1c+3c R&L up/down. 1c in 1plx face out (1x,2,3)

17--::

  1c+2c ¾ DblFig8, 1c casting | 1c turn P LH ½ to centre LHJ facing 1M(1W) facing 2c(3c) (2,1x,3)

25--::

  All set | all set to P, 1c releasing hands on [27] ; 1c joining RH on [29] with 1M(1W) facing 3c(2c), all set | 1c turn P RH ½ to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12204, '2019-09-13 00:28:23.842429+00', '2019-09-13 00:33:21.879073+00', 7598, 1, 202, 'ace', '1--::

  All cross RH | set ; turn P RH into promhold facing up | set (1,2,3,4)

9--::

  4C Promenade (1,2,3,4)

17--::

  1c & 3c Petronella Turn | set (2c & 4c up) ; 1c+2c & 3c+4c RHA

25--::

  ½ Reel4 on midline ; 3c & 1c turn P RH ¾ to sides | all set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12504, '2020-01-13 02:10:52.004556+00', '2020-05-17 01:24:18.617697+00', 16656, 2, 963, 'ace', '1-8::

  1c dance down. 1w pass under 1m left arm to change places. 1c dance up to face 1st corner  

9-16::

  1c dance track for corner pass and turn while corners 1/2 turn RH and dance out to opposite corner.  1c face 3rd corner position  

17-24::

  1c dance Hello/Goodbye with pet turn into 2nd place opp side  3x,1x,2x  

25-32::  

  3,1,2 chase clkwise halfway and turn partner RH  2,1,3



*NB. There''s a misprint in the book in bars 9–16; this crib was provided by the author in correction.*', 3);
INSERT INTO 'dancecrib' VALUES (11297, '2018-10-23 00:17:12.740585+00', '2019-03-07 22:07:14.76191+00', 7940, 1, 202, 'ace', '1--::

  1c+2c DblFig8, 1c crossing down _while{8}_ 3c+4c Circle4 and back (1,2,3,4)

9--::

  1c+2c Circle4 and back _while{8}_ 3c+4c DblFig, 4c crossing up (1,2,3,4)

17--::

  1c+2c & 3c+4c Mirror S&Link, the end couples casting and the middles dancing inside ; 2c+1c & 4c+3c RHA. On [24] 1c & 4c dance out to sides and turn inwards to meet P in centre (2,1,4,3)

25--::

  1c+4c Allemande (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1707, '2012-01-22 19:28:57.657932+00', '2019-09-13 21:45:34.647341+00', 328, 1, NULL, 'ace', '{{explanation}}

On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)



1–::

  1c+2c & 3c+4c S&Link ; 1c facing 2c & 3c facing 4c set | change places LH on sides and form a square set, still facing the same way

9–::

  Interlocking Rsh Reels4 round the set, the last Rsh pass becoming a turn BH ½ into

17–::

  All circle8 L | set in the circle ; dropping hands continue circle L {1} and then all cast L and chase to original places (1,2,3x,4x), 1M+4M stay facing out

25–::

  1M+4M followed by P cast L round adjacent M and across to 3plx / 2pl resp., (2W+3W step or dance to end on [25-26], 2M+3M step to end on [27-28] ; 2c+4c & 1c+3c RHA (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (10211, '2017-10-28 23:35:27.0901+00', '2022-10-01 18:11:56.274165+00', 16774, 1, 202, 'ace', '1--::

  1c & 3c dance down, turn BH ; dance up, turn BH to original places facing out (1,2,3,4)

9--::

  Mirror Reels4, 1c & 3c start out and down (1,2,3,4)

17--::

  1c+2c & 3c+4c S&Link ; 1c & 3c Petronella turn to midline | 1c & 3c set

25--::

  1c+3c ½ Reel4 ; 3c & 1c turn RH ¾ to sidelines | 2c+3c+4c+1c set', 4);
INSERT INTO 'dancecrib' VALUES (13462, '2020-12-09 01:03:15.242855+00', '2021-03-05 09:40:08.587587+00', 20196, 1, 202, 'ace', '1--::

  1c lead down {3}, lead up {3} | cast off (2c up) (2,1,3)

9--::

  Mirror Reels3 on sides, 1c in and down, all taking hands in centre when appropriate (2,1,3)

17--::

  Diagonal R&L (3x,1,2x)

25--::

  All chase clw ½ ; all set | 1c cross RH (2,1,3)



*E-crib derived from the video*', 2);
INSERT INTO 'dancecrib' VALUES (14341, '2021-10-01 21:01:01.416397+00', '2021-10-01 21:03:59.999974+00', 18389, 1, 1645, 'ace', '1--::

  Top three W & bottom three M Reels3 on sides, 1W+2W & 3M+4M start passing RSh

9--::

  Top three M & bottom three W Reels3 on sides, 1M+2M & 3W+4W start passing RSh

17--::

  Snowball chain, 2 bars per hand, 1c & 4c cross RH to start (4x,2x,3x,1)

25--::

  All set | 4c+2c & 3c+1c &frac12; RHA ; all turn P RH (2,4,1,3)

33--::

  All circle8 to L & back (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11049, '2018-08-30 09:21:44.825731+00', '2018-09-04 14:05:24.212231+00', 18549, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; set | cast (3c up) (2,3,1)

9--::

  3c+1c Circle4 L ; 1c dance up to 2pl centre _as_ 3c cast to 3pl into DTr position | all set as in DTr (2,1,3)

17--::

   1c change places RSh round P _as_ 2c & 3c cross RH (to 2x,1x,3x) | all set as in DTr ; all set advancing into Inverted DTr position (1c in 2plx, 2c & 3c BtoB facing opposite sides) | all set releasing hands on [24] to finish with 2c(3c) in centre side by side facing down(up)

25--::

  1c Petronella turn to midline _as_ 2c & 3c Petronella in tandem to sidelines (to 1M in 1pl centre, 3c in 2pl on W side, 2c in 2pl on M side, 1W in 3pl centre) | all set ; 1c set _as_ 2c+3c cross RH | all chase clw to sidelines (3x,1x,2x)

33--::

  Reels3 across, 1c RSh to 4cnrs[pos] ; Reels3 on sidelines, 1c LSh to 3cnrs[pos] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10214, '2017-10-29 06:34:42.663965+00', '2019-02-03 22:31:13.923447+00', 18010, 1, 202, 'ace', '1--::

  2c diagonal Reel4 with 1cnrs (1,2,3)

9--::

  1c+2W & 2M+3c RHA (Teapots R), 2c pass Rsh ; Teapots L, finish facing 2cnrs

17--::

  2c+2cnrs Lsh diagonal Reel4 (to 1,2,3)

25--::

  All cross RH | 1c+2c change places LH ; 1c+3c change places RH | all cross LH (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (1672, '2012-01-22 19:28:54.211634+00', '2020-05-15 14:54:34.116502+00', 212, 1, NULL, 'ace', '{{explanation}}

3c+4c start on opposite sides



1–::

  1c+4c Fig8 on own sides round 2c+3c (start inwards)

9–::

  1c+2c & 3c+4c half Espagnole (»inverted« for 3c+4c) ; 2c & 3c Turn RH _while{4}_  1c+4c LHA, finish in the middle facing the four cnrs

17–::

  Crossing double Reels4 (swift ½LHA in the middle), at end 1c+4c no LHA but curve in (2,4,1x,3x)

25–::

  Couples facing couples on sides: all set and turn person facing RH ; 4c+1c circle4 R (to 2,4,1x,3x)



{{explanation}}

Espagnole: both W lead RHJ to M side, cross and cast back to exchanged places while Men cross to W side, lead RHJ back to M side and cross to exchanged places ; all turn P EH (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (10213, '2017-10-29 06:08:04.393761+00', '2018-04-09 13:21:53.927643+00', 18015, 1, 202, 'ace', '1--::

  3c followed by 2c & 1c lead down ; 1c followed by 2c & 3c lead up crossing over, finish facing up RHJ, W on L

9--::

  Mirrored Allemande (start to L, curve to R) (3x,2x,1x)

17--::

  3C S&Link twice (1,2,3)

25--::

  1c+2c ½ R&L ; turn BH ½ | Retire{2} with 4 PdB (2,1,3)



Note from deviser:



*At the end of the 2nd, 4th and 6th times through, as 1c step down, 4c, instead of stepping up, immediately lead down followed by 2c & 1c.*', 4);
INSERT INTO 'dancecrib' VALUES (11294, '2018-10-22 09:26:13.916299+00', '2018-10-22 09:26:27.713742+00', 18354, 1, 1645, 'ace', '1-::

  1c set | long cast to 2pl (2c up on [5-6]) | turn RH into promhold facing 2M

9-::

  1c RSh Reel3 on M side, 1c end crossing up to face 2W

17-::

  1c LSh Reel3 on W side, 1c end between 3c

25-::

  1c dance up between 2c | cast to 2pl facing in ; 1c+3c turn 1&frac12; EH to (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (10379, '2018-01-14 21:51:55.031859+00', '2018-01-14 23:34:23.42158+00', 17100, 2, NULL, 'ace', '1-4  ::  

  1st and 2nd couples, also 3rd and 4th couples, set and link. (Finish on sidelines 2M facing 1M, 4M facing 3M and 2L facing 1L, 4L facing 3L)  

5-12 ::  

  Reel of 4 on own sides. (Passing RS to start)  

13-16::  

  1st and 4th couples set and link (end order 2,4,1,3)  

17-20::  

  4th and 1st couples dance 1/2 figs of 8 (4th couple cross up between 2nd couple to begin, 1st couple cross down between 3s to begin)  

21-24::  

  4th and 1st couple turn partner with right hand, one and half times  

25-32::  

  All circle 8 hands round and back  ', 4);
INSERT INTO 'dancecrib' VALUES (11293, '2018-10-22 04:46:35.637146+00', '2018-10-22 04:50:34.328552+00', 19026, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c Poussette (1,2,3,4)

9--::

  1c+2c & 3c+4c Espagnole. On [13-16] 1c(4c) turn LH(RH) 1½ to 2plx(3plx) (2,1x,4x,3)

17--::

  1c lead up, cross over and cast to 2pl _while{4}_ 4c lead down LHJ, cross over and cast to 3pl _while{4}_ 2c & 3c set | cross RH (to 2x,1,4,3x) ; 1c+4c Circle4 L _while{4}_ 2c & 3c set | cross RH (2,1,4,3)

25--::

  [En Rond:] 1W+4W & 1M+4M change places LH | 4c & 1c set ; Circle4 R (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11295, '2018-10-22 09:52:32.638479+00', '2018-10-22 10:02:46.98207+00', 19024, 1, 202, 'ace', '1--::

  Mirror Reels3 on opposite sides, 1c crossing down to 2pl. On [7-8] 1c dance to face 1cnrs _as_ 2c continue the reel to 1pl (2,*1*,3)

9--::

  Corners Pass and Turn on 1diag. On [12] 1c pivot R BtoB in centre facing 1W(1M) 2c(3c) ; Corners Pass and Turn on 2diag, 1c RSh to 4cnrs. On [16] 1c finish in centre LSh to P facing opp side (2,*1*,3)

17--::

  1W+2c & 1M+3c RHA ; LSh »Snake Pass« [unwind the RHA, 1c leading, pass other snake LSh through 2plx and chase cclw], 1c finish as bar [16], 3W&2M face out (3,*1*,2)

25--::

  1c turn LH 1¾ {6} to 2pl | 1c set to P _while{8}_ 2c+3c change places | PdB R on sides, ¼ turn and PdB L to P ;  turn P RH. 3c face out (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11292, '2018-10-22 04:29:11.204762+00', '2018-10-22 14:00:59.309303+00', 18969, 1, 202, 'ace', '1-::

  1c+2c set | ½ RHA ; set |½ LHA (1,2,3)

9--::

  1c cross RH | cast off (2c up) ; cross LH | cast off and lead up to 1cnrs

17--::

  Set to and Turn Corners (2,1x,3)

25--::

  All A&R ; 1c turn P RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10388, '2018-01-19 01:29:47.547598+00', '2020-12-11 07:52:46.460117+00', 17957, 2, 963, 'ace', '1-4::

  1c+2c+3c half a mirror R3 on side  1c cross down to begin  

5-8::

  1c+2c turn 1-1/2, 1M RH, 1W LH, 1c face 1st cnr  

9–16::

  1c set to 1cnr | 1c cast Rsh round each other to 3cnr position while 1cnrs dance into centre, and swivel R to face own cnr position ; repeat, 1cnrs finishing in exchanged places, and 1c facing 2cnr  

17–24::

  1c repeat with 2nd cnrs 1c finish Rsh/Rsh facing opp side  

25–32::

  1c LHA on sides, 1W with 2W+3W, 1M with 2M+3M; 2nd cnr position leading (3W,2M) chase ccw to own side (M1,3,2  W3,2,1)  

33-40::

  6 bars of 3 couple bourell, all petronella to own sides  2,1,3  

', 5);
INSERT INTO 'dancecrib' VALUES (11048, '2018-08-30 00:13:11.480071+00', '2018-08-30 16:18:55.62596+00', 18548, 1, 202, 'ace', '1--::

  All set to P | all W cast R and chase cclw 1 place ; all set to cnr (new P) | turn BH and face new P

9--::

  RSh interlocking Reels4. On [16], turn new P RH ¾ into

17--::

  All M LHA 1+1/3 and face original P on sides ; All cpls dance LSh BtoB (2,3,1)

25--::

  All S&Link ; All W followed by P chase clw 2 places. On [32], All cpls change places RSh (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (8926, '2015-09-27 20:38:14.302995+00', '2015-09-27 20:38:14.302995+00', 16772, 1, NULL, 'ace', '1--::  1M+2c+3W & 3M+4c+5W diagonal Reels4, 2c & 4c pass Lsh to begin, and at the end pass Lsh to face 2cnr 

9--::  Repeat on 2diagonals (1,2,3,4,5)

17--::  Snowball chain, 2bars per hand : to start 1c cross RH (3,2x,4,1x,5)

25--::  2c+4c & 1c+5c ½ R&L (3,4x,2,5x,1) ; 4c & 5c ½ Fig8 R (M up, W down) (3,4,2,5,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10573, '2018-04-03 11:58:51.129762+00', '2022-08-14 08:27:45.752473+00', 13899, 1, 202, 'ace', '1--::

  1c+2c RHA ; LHA

9--::

  Parallel Reels3{6} on sidelines, 1c start Lsh to 2c, 3c finish facing up | 1c continue to 2pl and face down _while{2}_ 2c continue to 1pl and face P (2,1,3)

17--::

  3C Gr-Chain, 2c cross to start

25--::

  1c turn P RH ¾ _while{2}_ 2c & 3c cross LH | 1M+3c & 1W+2c LHA (to 2x,1x,3x) | all cross LH', 4);
INSERT INTO 'dancecrib' VALUES (11299, '2018-10-23 22:55:51.519619+00', '2018-10-31 08:32:34.321404+00', 19031, 1, 202, 'ace', '1--::
  1c cross RH | cast (2c up) ; turn LH to 2plx facing 2cnrs (2,1x,3)
9--::
  Reels3 on sides, 1c LSh to 2cnrs into 2 facing lines3 across, 1M(1W) between 3c(2c)
17--::
  All set | A&R | set
25--::
  1c cross LH up/down | loop L to 2pl ; all turn P RH (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (10216, '2017-10-29 17:21:57.010167+00', '2017-10-29 17:43:20.202292+00', 18039, 2, 160, 'ace', '1-8::  1s+2s set, RHA half ; 2s+1s Set, cross over RH.

9-16::  1s turn RH, cast 1pl (3s up) ; 1s turn LH.

17-24::  1s lead down the middle (4s up) & lead up to 4pl.

25-32::  8 hands round & back.', 5);
INSERT INTO 'dancecrib' VALUES (11298, '2018-10-23 14:07:18.080035+00', '2020-07-26 19:44:33.002854+00', 18578, 1, 202, 'ace', '1--::
  All set | cross RH ; Circle6 L ½ (3,2,1)
9--::
  2c+1c The Knot (3,1,2)
17--::
  3C S&Link ; all set in lines3 across | 2c & 3c set _while_ 1c Petronella Turn to 2pl (2,1,3)
25--::
  2c+1c Poussette', 4);
INSERT INTO 'dancecrib' VALUES (8096, '2013-10-18 18:40:45.210571+00', '2018-04-03 19:29:45.779567+00', 13900, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; turn LH 1½ to face 1cnrs

9–::

  1c+1cnrs diagonal Reel4, 1c finish in 2pl Lsh to Lsh

17–::

  1M+2M+3M & 1W+2W+3W RHA , 1c pass Rsh ;1M+2W+3W & 1W+2M+3M LHA, 1c finish RHJ, and LHJ with 2cnr

25–::

  BiL twice ; 1c turn RH ¼ and dance Rsh round 4cnr to (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10202, '2017-10-24 01:46:31.875785+00', '2018-04-10 11:35:38.299171+00', 18005, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c Poussette. On [8], 1c cross RH, 1W finishing in front of 2M, 1M above 2W ready for

9-24::

  The Spurtle. On [21-24] 2c+3c+4c+1c turn P BH 1/2 and cast away R to own sides (2,3,4,1)

25--::

  2c+3c & 4c+1c Circle4 L ; All dance BtoB', 4);
INSERT INTO 'dancecrib' VALUES (7838, '2013-08-21 08:31:49.581545+00', '2023-02-04 01:23:05.003142+00', 9015, 3, NULL, 'ace', '1-8::
    1s cross (no hands) down to 2nd place opp sides, 1s change places
    with 3s (LH Men''s side & RH Ladies side), 2s+3s also 1s+4s change
    places on sides (RH Men''s side & LH Ladies side) & all Bal-in-Line.
    3 2 4 (1)
9-16::
    All dance reels of 4 on sides (RSh Men''s side & LSh Ladies side)
17-24::
    3s+1s dance a Double Capstan :
::
    3L & 1M dance LSh 1.1/2 times round standing 2s+4s _while_ 3M & 1L
    dance RSh round 2s/4s - to change places
25-32::
    1s cross RH, cast to 3rd place & all turn partner RH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12207, '2019-09-14 08:12:43.676015+00', '2019-09-14 17:52:57.264104+00', 19023, 1, 202, 'ace', '1--::

  All dance across, RSh to P, W under M''s arches, looping to opposite places ; repeat [1-4] (1,2,3)

9--::

  3C Promenade. On [15-16] 1c face 1cnrs _as_ 2c dance to 1pl

17--::

  Corner Chain with 1cnrs

25--::

  Corner Chain with 2cnrs to 2pl (2,1,3)

33--::

  1c Fig8 R, LSh to 1cnrs (2,1,3)

41--::

  1c turn RH | cast to 3pl (3c up) ; all turn P RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12211, '2019-09-14 18:29:37.024066+00', '2019-09-14 18:33:22.090589+00', 139, 1, 202, 'ace', '1--::

  All turn P RH ; all set twice (1,2,3)

9--::

  1c+3c DblFig8, 1c crossing down (1,2,3)

17--::

  1c lead down ; and up (1,2,3)

25--::

  1c+2c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12212, '2019-09-14 22:52:55.699642+00', '2019-09-14 22:52:55.699642+00', 8329, 1, NULL, 'ace', '1--::

  All set and cross RH ; repeat (1,2,3)

9--::

  1c set | cross down RH (2c up) ; cast behind 3c and cross up to (2,1,3)

17--::

  Mirror Reels3 on the sides, 1c start out and up, 1c finish BtoB in 2pl 

25--::

  2c+1c+3c DTr.  On second time through, 1c finish in 4pl as 4c step up

', 3);
INSERT INTO 'dancecrib' VALUES (12214, '2019-09-14 23:50:58.220146+00', '2019-09-14 23:50:58.220146+00', 19553, 1, NULL, 'ace', '1--::

  1c+2c+3c Inveran Reels3 (1,2,3)

9--::

  1c+2c Poussette (1,2,3)

17--::

  1c lead down and up (1,2,3)

25--::

  1c+2c Allemande (2,1,3)



', 2);
INSERT INTO 'dancecrib' VALUES (12213, '2019-09-14 23:15:57.030903+00', '2019-09-14 23:34:17.365415+00', 19642, 1, NULL, 'ace', '1--::

   1c turn BH | Mirror Rels3{6}, 1c in and down to start (1,2,3)

9--::

   1c long cast (2c up) ; ½ Fig8 R (Lsh to 1cnr), end on 2diag, LHJ to P and RHJ with 2cnr

17--::

   1c+2cnr Strathspey Balance in line and Turn cnr [all set R {1} and 1c turn cnr LH ½ | 1c set R to P {1} and turn P LH ½ {1] _while{2}_ 2cnrs set ; turn cnr RH | turn P LH ¾ to 1diag]

25--::

   1c+1cnrs repeat [17-24], finish (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (12215, '2019-09-15 00:14:07.710408+00', '2019-09-15 00:14:07.710408+00', 16919, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 L (Rsh to 4cnr)

9--::

  1c+3cnr make arches (1c on inside) and all chase once round, 2cnrs cclw, and arches clw, all finish on midline in line of 6 M above P (2,1,3)

17--::

  ½ Rsh Reel6 on midline {6} | Turn P RH 1¼ into

25--::

  3c+1c+2c Allemande (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11286, '2018-10-20 19:38:42.268721+00', '2018-10-24 00:33:40.679457+00', 19011, 1, NULL, 'ace', '1--::

  All circle8 R and back

9--::

  Intersecting Men''s Chain (M half LHA in middle), W face out

17--::

  8 bars Schiehallion reel, at end turn RH ¼ into promhold facing cclw

25--::

  In allemande hold all Promenade 3 places cclw, at end M bring W round into BtoB in centre | All set to P, and face clw 

33--::

  In big wheel dance 1 place clw | All Set (hands stay joined) ; Link with P, all M (pass Lsh) moving 1 place cclw in the middle to | turn new P RH to form circle.  

41--::

  All circle8 {3}, pivot L and dance back (all W return to original positions, M have moved 1 place cclw)









', 5);
INSERT INTO 'dancecrib' VALUES (11300, '2018-10-23 23:28:33.578537+00', '2018-10-24 08:31:37.471465+00', 2794, 1, 202, 'ace', '1-12::
  3C R&L (1,2,3)
13-16::
  Circle6 L ½ (3x,2x,1x)
17--::
  2c+1c ½ R&L ; 3c+1c ½ R&L (1x,3,2)
25--::
  3c+2c ½ R&L ; 1c+2c ½ R&L (2,1,3x)
33--::
  Mirror Reels3, 3c cross up to start, 1c out and down, 2c in and down (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (8161, '2014-01-26 22:18:30.306001+00', '2018-10-24 16:12:50.336736+00', 9166, 1, NULL, 'ace', '1–::

  1c cross down | cast behind 3c ; cross up between 3c | cast up behind 2c (on [8] 2c+3c step in) for

9–::

  1c+2c+3c Allemande (3,2,1)

17–::

  1c set | cross RH ; 1c+2c set | ½ RHA (3,1,2x)

25–::

  All set and cross RH ; 3c+1c set | ½ RHA (1,3,2)

33–::

  1c cross RH | cast off (3c up) ; ½ Fig8 up  (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (11301, '2018-10-24 23:21:53.892801+00', '2018-10-24 23:21:53.892801+00', 19038, 1, NULL, 'ace', '1--::

  1c+2c set twice ; turn P RH

9--::

  1c+2c set twice ; turn P LH

17--::

  1c cross RH | cast off (2c up)  ; ½ Fig8 up (2,1)

25--::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (11302, '2018-10-25 00:36:16.474156+00', '2018-10-25 00:40:51.763155+00', 17264, 1, NULL, 'ace', '1--::

  1c cross down (no hands) into Fig8 round 3c (2c up on [3-4])  (to 2,1,3)

9--::

  1c "Assisted Fig8" round 2c (1c turn the standing couple EH instead of dancing round them), 

17--::

  2c+1W & 1M+3c Reels3 across, Lsh to 1cnr, 1c finish on midline, W above M, LHJ, facing P''s side

25--::

  1c set | dance out between corners , cast R and meet in middle {3}, Turn LH ¾ {3} to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11303, '2018-10-25 00:38:33.59393+00', '2018-10-25 00:49:10.677625+00', 17047, 1, 202, 'ace', '1--::

  1c+2c ½ RHA | 1c+3c ½ LHA | 1c+4c ½ RHA | all set (2x,3x,4x,1x)

9--::

  ½ 4C Gr-Chain (to 1,4,3,2) ; all set | cross RH (1x,4x,3x,2x)

17--::

  ½ Reels4 (2x,3x,4x,1x) ; all set | cross RH (2,3,4,1)

25--::

  All Petronella Turn | set ; turn P RH 1¼ (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11304, '2018-10-25 00:59:30.22112+00', '2018-10-25 01:05:52.65237+00', 17046, 1, 202, 'ace', '1--::

  3C Gr-Chain (1,2,3)

9--::

  1W+2M cross RH | 1M+2W cross RH ; 1W+3W cross RH | 1M+3M cross RH (2x,3x,1)

17--::

  1W (P following) cast up and cross to 2plx (3c down) ; cast up and cross to 1pl (2c down) (1,2x,3x)

25--::

  Circle6 and back

33--::

  1c+2c ½ RHA | set ; 1c+3c ½ LHA | set (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11306, '2018-10-25 09:32:17.322442+00', '2018-10-25 09:58:43.350297+00', 17045, 1, 202, 'ace', '1--::

  1c set | lead down ; cast behind 3c, meet and lead up to 2pl centre BtoB facing own side (2,1,3)

9--::

  1c set | Circle3 L | cast R round 3cnrs

17--::

  ½ Reels3 across, 1c LSh to 2cnrs ; 2c+1M (above) & 3c+1W (below)  ½ LHA | 1c turn RH to 2pl (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11305, '2018-10-25 08:40:46.623273+00', '2018-10-25 09:01:43.896823+00', 17043, 1, 202, 'ace', '1--::

  1c set | all A&R | 1c cast (2c up) (2,1,3)

9--::

  1W+2c & 1M+3c RHA, pass RSh ; 1W+3c & 1M+2c LHA (2,1,3)

17--::

  All step in {1}, 2c followed by 1c & 3c lead up, cast (2c on [20], 1c on [21], 3c on [22], lead down (3,1,2)

25--::

  6 bars of 3C Gr-Chain (3c crossing, 2 bars per hand)  | cross LH (2,1,3)

33--::

  Circle6 L. On [38], all loop R to places (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10688, '2018-04-23 23:50:47.62225+00', '2018-10-25 15:10:01.874602+00', 18287, 1, NULL, 'ace', '1-8::  1c cross RH | cast (2c up) ; turn 1&frac14; RH to lines across 1M/1W between 3c/2c

9-12::  All set  | 2c & 3c pull RSh back & rotate clw _while_ 1c set adv to P & twirl away to face 4cnrpos

13-16:: 1c+4cnrs set | 1c cast away to 2cnrpos _while_ 4cnrs dance in & twirl away to face P in 1cnrpos

17-20:: 4cnrs (3W+2M) repeat [13-16] with 1cnrs (3M+2W) who end facing 1c

21-24:: 1cnrs (3M+2W) repeat [13-16] with 1c who end passing RSh to (2,1,3)

25-32:: All Circle6 round to L & twirl pulling LSh back ; Circle6 back to R (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (11309, '2018-10-25 15:15:25.460757+00', '2018-10-25 15:59:33.491464+00', 17042, 1, 202, 'ace', '_Strathspey_

1--::

  1W+4c & 3W+2c RHA ; 1c+3c LHA

9--::

  2W + 3W(+3M following) + 1W(+1M following) + 4W ½ RSh Reel4 in tandem (no lead change) ; 2M + 1W(+1M following) + 3W(+3M following) + 4M ½ RSh Reel4 in tandem (no lead change) to places (1,4,3,2)

17--::

  1c+3c set | ½ R&L | set (1,4,3,2)

25--::

  All W Petronella Turn 1pl cclw | all set ; All M Petronella Turn 1 place cclw | all set (4,3,2,1)  



*Repeat [1-32] once more in Strathspey time then twice in Reel time.*', 2);
INSERT INTO 'dancecrib' VALUES (11307, '2018-10-25 11:19:14.831443+00', '2018-10-25 17:03:59.147481+00', 17044, 1, 202, 'ace', '1--::

  All set | 2W+1c & 2M+3c RHA | all set (1,2,3)

9--::

  Circle6 and back (1,2,3)

17--::

  1c+2c R&L (one step per hand) ; 2c+3c R&L across (one step per hand, starting RH on sides) (1,2,3)

25--::

  1c+2c ½ Poussette ; 1c+3c ½ Poussette (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12250, '2019-09-27 23:37:42.8824+00', '2019-09-27 23:42:27.163754+00', 18858, 1, 202, 'ace', '1--::

  All cross RH | 1c cast off (2c lead up) ; 1c dance down between 3c | cast up to 2plx (2x,1x,3x)

9--::

  Pick-up Chain, 2c crossing RH (3x,1,2x)

17--::

  Parallel Reels3 on sides, 1c RSh to 2c (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15363, '2022-12-21 00:13:54.369718+00', '2022-12-22 14:29:01.453837+00', 21215, 1, 1645, 'ace', '*4c, 5c & 6c start on opposite sides (1,2,3,4x,5x,6x)*



{{explanation}}

Strathspey



1--::

  1c+2c+3c & 4c+5c+6c S&Link3 ; All &frac12; Reels4 up/down sides & centre

9--::

  All S&Link3 to sides ; all &frac12; turn RH & twirl to opp sides (4x,5,6x,1,2x,3)

17--::

  4c+5c, 6c+1c & 2c+3c reverse S&Link2 ; LHA (5,4x,1,6x,3,2x)

25--::

  4c & 3c cross RH into &frac12; Fig8 out nearest end ; all turn P 1&frac12; BH (5x,4x,1x,6,3,2)



{{explanation}}

Jig



1--::

  5c+4c+1c & 6c+3c+2c S&Link3 ; All &frac12; Reels4 up/down sides & centre

9--::

  All S&Link3 to sides ; 6c & 1c (ends) turn RH _while{4}_ 3c, 2c, 5c & 4c &frac12; turn RH & twirl to opp sides (6x,3x,2,5x,4,1)

17--::

  6c+3c, 2c+5c & 4c+1c reverse S&Link2 ; LHA (3x,6x,5x,2,1,4)

25--::

  All set | La Baratte (3,6,5,2x,1x,4x)

', 2);
INSERT INTO 'dancecrib' VALUES (2748, '2012-01-22 19:29:55.813349+00', '2020-12-12 10:40:25.246404+00', 4175, 1, NULL, 'ace', '1–::

  1c cross down (2c up) | cast R round 1cnr : turn LH to face 1cnr

9-32::

  »Marigold reels«: 1c change place Rsh with 1cnrs, who pass Rsh to face cnr on the R | repeat along 2diag _while{2}_ other dancers stand | repeat along 1diag (1c is back in the middle facing 2cnr position ; all corners have moved one place cclw).  Repeat this 6-bar figure 3 more times, to starting positions, with 1c now facing 2cnr.

33–::

  1c turn 2cnr RH | turn 1cnr LH ; ½ Fig8 to L (round 4cnr) to (2,1,3)



{{explanation}}

the Marigold Reels are »dance to each corner and set«, with the setting omitted', 3);
INSERT INTO 'dancecrib' VALUES (11977, '2019-07-23 20:21:50.500058+00', '2021-03-13 20:30:12.388008+00', 19076, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; ½ Fig8 L round 2cnrs (2,1,3)

9--::

  ½ Reels3 across, 1c RSh to 4cnrs ; ½ Reels3 on sides, 1c LSh to 3cnrs[pos]. On [16] 1c turn P RH into 1diag (3x,1,2x)

17--::

  1c+1cnrs[pos] LHJ BiL | change places LH ; 1cnrs change places RH _as_ 1c set | 1c+1cnrs turn LH ½ and 1c pass P RSh to face 2cnrs[pos]

25--::

  ½ Reel4 on 2diag, 1c dance in and pull RSh back into lines3 across, 1M(1W) between 2c(3c) facing down(up) ; 1c set | turn RH ¾ to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11310, '2018-10-26 17:10:06.318914+00', '2018-10-26 17:10:06.318914+00', 9878, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c Circle4 and back

9--::

  All set | 1c+4c cast inwards _as_ 2c+3c dance to ends ; 1c+4c ½ Fig8 round end cpl (2,1x,4x,3)

17--::

  Repeat [9-16] from new places (1x,2x,3x,4x)

25--::

  1c+2c ½ R&L, start up/down ; 1c+3c repeat (2,3,1x,4x)

33--::

  1c+4c repeat ; All turn P BH (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2161, '2012-01-22 19:29:23.28745+00', '2019-09-15 22:24:26.033962+00', 9107, 1, NULL, 'ace', '1–::

  1c lead down the middle and up, on [8] 2c+3c step in for

9–::

  1c+2c+3c Promenade, at end 1c cast off (to 2,1,3)

17–::

  1c cross Rsh | turn 1cnr RH ; cross up/dn Rsh | turn 2cnr RH (2,1x,3) |

25–::

  2c+1M & 1W+3c RHA ; 1c ½Fig 8 Rsh round 4cnr (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11020, '2018-08-20 22:32:51.067588+00', '2018-09-19 09:45:27.742615+00', 17339, 1, 202, 'ace', '1--::

  Circle8 and back

9--::

  1c+3c ½ R&L, all face cclw ; 1c & 3c, W leading, chase cclw to original places _while{4}_ 2c & 4c A&R (1,2,3,4)

17--::

  2c&4c repeat similar pattern (1,2,3,4)

25--::

  Dbl La-Chain. On [31-32], all M turn P LH, retain LHJ with P and join RH in centre 

33--::

  All BiL | all W turn P LH, retain LHJ with P and join RH in centre ; BiL | all turn P LH to face cnrs

41--::

  Interlocking Reels4, RSh to cnrs, face P at end

49--::

  All set twice ; turn P RH into allemande hold facing cclw

57--::

  All chase cclw to original places. On [63], all release RH, M turn P LH to bring W into the middle', 2);
INSERT INTO 'dancecrib' VALUES (8650, '2015-02-13 12:48:24.576646+00', '2023-02-04 01:23:05.031588+00', 15649, 3, NULL, 'ace', '1-8::
    1s+3s set. 1L dances down, casts up round 2M into middle facing down
    as 1M dances across, casts round 2L  into middle facing up _while_
    3s dance same round 4s. 1s+3s change places RH with partner into
    line of 4 in middle (M face down, L face up)
9-16::
    1s+3s dance reel of 4 in middle
17-20::
    1s+2s also 3s+4s dance RH across
21-24::
    1M followed by 1L casts round 2L to 2nd place own sides as 3M
    followed by 3L casts round 4L to 4th place (2s+4s step up 23-24)
25-32::
    1s+4s (middle couples) dance Espagnole
::
    _25-26_   1s+4s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _27-28_   1s+4s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _29-32_   4s turn RH as 1s turn LH', 0);
INSERT INTO 'dancecrib' VALUES (12222, '2019-09-16 01:13:58.746548+00', '2019-09-16 22:48:44.109439+00', 19651, 1, 202, 'ace', '1--::

  1c lead down {3}, lead up {3} | cast off (2c up) (2,1,3)

9--::

  All NHJ set | all La Baratte (2x,1x,3x)

17--::

  All chase cclw ½ ; all turn P LH into promhold (3,1,2)

25--::

  3C Allemande (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (12224, '2019-09-16 08:51:16.618363+00', '2019-09-18 06:25:18.291607+00', 19646, 1, 202, 'ace', '1--::
  1c Fig8 down round 2c, giving EH when crossing (1,2)
9--::
  1c & 2c turn P BH ½ | all chase clw one place ; all repeat [9-12] (2x,1x)
17--::
  2C Knot facing up on [18]. On [23-24] all turn P LH ¾ into midline, M(W) facing down(up)
25--::
  ½ Reel4 on midline, LSh to P ; all turn P LH ¾ to sides (2,1)', 5);
INSERT INTO 'dancecrib' VALUES (12509, '2020-01-15 01:00:03.808176+00', '2020-01-15 01:07:40.441019+00', 2477, 1, NULL, 'ace', '1--::

  1W, other W following, cross, dance behind opposite side, cross back at bottom and up own side, to places

9--::

  The M repeat, (1,2,3,4)

17--::

  1c+2c & 3c+4c R&L

25--::

  All A&R; dance BtoB

33--::

  1c lead down (2c+3c+4c up on [35-36] ; All turn P RH (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2127, '2012-01-22 19:29:21.529422+00', '2021-06-13 08:33:51.217955+00', 1829, 1, NULL, 'ace', '{{explanation}}

Canon.  A new top couple starts dancing every 16 bars, and each continues dancing until they reach their original positions, so that the dance starts from the top, and ends from the top. 1c face out after the chord.



1–::

  1c+2c with EH joined set | turn EH ½ ; 1c ½ Fig8 up round 2c (2,1x,3,4,5)

9–::

  1c mirror Reels3 on opposite sides with 2c+3c, 1c starts in and down, at end, 1c turn 3c EH ½ (2,3,1x,4,5, with 2c & 1c facing out

17–::

  2c+3c+1c+4c BiL | 2c continues as above _while_{6} 1c turn 4c EH ½ , cross RH and cast to 5pl (5c up)

25–::

  5c+1c R&L (3,4,2x,5,1).



{{explanation}}

On bar 48 the order will be 4,5,3x,1,2.  

On bar 64 the order will be 5,1,4x,2,3.  

On bar 80 the order will be 1,2,5x,3,4 and 1c and 2c stop.  

On bar 96 the order will be 1,2,3,4,5, all stopped.', 2);
INSERT INTO 'dancecrib' VALUES (12220, '2019-09-15 23:47:52.137364+00', '2019-09-16 23:37:55.168171+00', 19644, 1, 202, 'ace', '1--::

  2C S&Link ; 2c+1c NHJ Advance {1}, release H and pass P LSh, face P in centre {1} | 2c+1c Retire (2x,1x)

9--::

  1W+2M turn LH ; chase cclw around P into 1diag, 1W facing 2W and 1M behind 1W

17--::

  Tandem Reel3 on 1diag with lead change, 1W RSh to 2W. All finish on sides as on [8] (2x,1x)

25--::

  1c & 2c turn P LH ; 1c+2c repeat [5-8] (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (12223, '2019-09-16 08:07:23.952184+00', '2019-09-24 14:11:19.765511+00', 19645, 1, 202, 'ace', '1--::
  Circle6 and back (1,2,3)
9--::
  1c set | cast off (2c up) ; turn P LH to 2pl (2,1,3)
17--::
  All chase cclw. 1c pass LSh to face 1cnrs
25--::
  Turn CPCP (starting LH) to  2pl (2,1,3)
33--::
  All chase clw (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1703, '2012-01-22 19:28:57.510976+00', '2019-10-11 21:42:41.792757+00', 13127, 1, NULL, 'ace', '1–::

  1M+2W turn RH ½ _while{2}_  1W+2M set | 1W+2M join into ½RHA ; 1c+2c face in diagonally and set | all cast one place cclw (2,1,3)

9–::

  2c+1c+3c parallel ½ Reels3 on the sides (1c Rsh to 3c) ; 1c+3c Circle4 R, 1c finish facing W side 1W leading (3,1,2)

17–::

  1c with 3M+2W (= 1diag.) ½ Rsh Reel3 (change lead) ; 1c (1M leading) with 3W+2M ½ Rsh Reel3, 1c finish in middle W above M, facing M side

25–::

  1c lead out between the W, split and cast (1W up, 1M dn) into facing lines across ; S&Link3 (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (12221, '2019-09-16 00:30:49.266901+00', '2019-09-18 09:17:36.12631+00', 19649, 1, 202, 'ace', '1--::
  1c+2c Set&Rotate (2,1,3)
9--::
  Parallel Reel3 on sides, 1c RSh to 2c into promhold (2,1,3)
17--::
  3C Promenade (2,1,3)
25--::
  1c+3c the Knot (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (8916, '2015-09-22 18:59:17.068633+00', '2015-09-22 19:01:44.292808+00', 16763, 2, NULL, 'ace', '1-4::  

  1st and 2nd couples, joining nearer hands on the sides, set, and dance right hands across halfway.

5-8::  1st and 2nd couples, joining nearer hands on the sides, set, and dance left hands across halfway to original places.

9-12::  2nd couple, followed by 1st couple, lead down the middle for four steps.

13-16::  1st couple lead up to the top while 2nd couple turn halfway around and lead up to between 3rd couple, facing up.

17-18::  1st couple, giving both hands and using pas de basque, turn halfway around moving down to finish with both hands still joined, in 2nd place. Meanwhile, second couple set.

19-20::  1st couple make an arch, 2nd woman dance under the arch to first place, own side.

21-22::  1st couple, with both hands still joined, turn halfway around, using pas de basque as before. Meanwhile, second man set.

23-24::  1st couple make an arch, 2nd man dance under the arch to first place, own side.

25-32::  2nd, 1st, and 3rd couples dance six hands around and back. Repeat having passed a couple.



*Note: This is a variant of The De’il Amang the Tailors.*

', 3);
INSERT INTO 'dancecrib' VALUES (11311, '2018-10-27 01:22:01.150242+00', '2018-10-27 01:26:01.727403+00', 12054, 1, 202, 'ace', '1--::

  1c & 3c set | cast (2c & 4c up) ; 1c & 3c turn P LH 1½. 1W & 3W with P behind face 1cnrs

9--::

  ½ Parallel RSh Reels3 in tandem (with lead change) on 1diag. M leading face 4cnrs ; repeat on 2diag. W leading face 4cnrs[pos]

17--::

  Repeat on 1diag. M leading face 2cnrs[pos] ; repeat on 2diag. 1c(3c) to 2plx(4plx)

25--::

  1c+3c LHA _while{4}_ 2c+4c+5c chase cclw two places (to 2,1x,4,3x,5) ; 1c & 3c cross LH | cast (4c & 5c up) (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (11312, '2018-10-27 21:55:41.560837+00', '2018-10-27 21:55:41.560837+00', 19040, 1, NULL, 'ace', '1--::

  1c lead down and up

9--::

  1c+2c Allemande, and face 1cnr

17--::

  Turn 1cnr RH, pass Rsh ; turn 2cnr RH, pass Rsh to (2,1,3)

25--::

  Circle6 and back

', 2);
INSERT INTO 'dancecrib' VALUES (10436, '2018-02-21 22:29:59.535274+00', '2018-02-22 01:52:01.413748+00', 16472, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

  1c & 4c turn RH | cast inwards (2c & 3c step to end) ; 1c+4c LHA, finishing LHJ facing nearer end (2,1,4x,3x)

9--::

  1c lead up between 2c, cross and cast to 2plx _while{4}_ 4c lead down between 3c, cross and cast to 3pl (to 2,1x,4,3x) ; 1W+4M & 1M+4W turn RH, finish as pairs in promhold facing out

17--::

  Pairs+2c+3c ½ Rsh Reels3 on sidelines ; pairs meet, take P in promhold for ½ Lsh Reels3 on sidelines, finishing 4c in 2pl BtoB, 1c in 3pl BtoB (2,4x,1,3x)

25--::

  4c & 1c turn cnrs EH, finishing NHJ facing in ; 4c & 1c S&Link to sidelines (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (11314, '2018-10-28 14:45:36.320865+00', '2018-10-28 14:52:26.744191+00', 11274, 1, 202, 'ace', '1--::
  1c set | cast (2c up) ; 1W+2c & 1M+3c RHA (2,1,3)
9--::
  Reels3 across with 1c RSh to 2cnrs (2,1,3)
17--::
  1M sets advancing to 2W | turn 2W BH ; sets advancing to 2M | turn 2M BH back to 2pl facing out _while{8}_ 1W dances across between 3M & 4M | loop LSh round 4M ; cross and cast to 3pl (3W up)
25--::
  1W sets twice _while{4}_ 1M loop RSh round 2M and dance down the middle to 3pl (3M up) ; 1c set | turn BH to 4pl (4c up) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11315, '2018-10-29 01:05:47.937903+00', '2018-10-29 01:06:37.535398+00', 8389, 1, NULL, 'ace', '1--::

  1c cast behind own lines (2c up on[3-4] ; and back to 2pl, BtoB on midline, 1W facing up, 1M down, 

9--::

  2c+1W & 1M+3C Circle3 and back

17--::

  1c turn 1cnr RH ; 1c turn P RH 1½ to face 2cnr _while{4}_ cnrs set twice facing diagonally in

25--::

  1c turn 2cnr LH ; 1c turn P LH 1¼ to own side _while{4}_ cnrs set twice facing diagonally in  (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (14627, '2022-03-01 00:22:47.296956+00', '2022-10-09 11:08:57.971865+00', 20674, 1, 1645, 'ace', '*1c & 3c start on opposite sides (1x,2,3x,4)*

1-::

  1c+2c & 3c+4c RHA ; LHA back, 2M & 3M end facing in centre, 2W & 3W face out on sides

9-::

  2c+3c Reel4 across, 2M+3M start passing LSh as 2W & 3W loop R.

  2W+3W end dancing round &frac34; LSh & take P in promhold, 2c/3c facing up/down

17-::

  2c/3c in promhold &frac12; RSh Reels3 across with 1c/4c ; &frac12; LSh Reels3 on M/W sides

25-::

  2c+3c &frac12; M-Chain, W casting into loops (4x,2,3x,1) ; 4c+2c & 3c+1c set adv NHJ | Circle4 &frac12; way L (2x,4,1x,3)

', 5);
INSERT INTO 'dancecrib' VALUES (11317, '2018-10-29 01:56:21.11185+00', '2018-10-29 02:01:09.80797+00', 11273, 1, 202, 'ace', '1--::

  1c set | turn RH 1½ | cast _while{8}_ 3c stand still | set ; turn RH 1½ (2,1x,3x)

9--::

  1c+3c set | cross RH ; chase clw ½ | ½ RHA (2,1,3)

17--::

  1c+3c Poussette (2,3,1)

25--::

  1c cast up one place ; 1c turn 2c EH, 1c in and up (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14340, '2021-09-29 05:58:57.989405+00', '2021-09-29 06:47:26.337533+00', 13744, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; 1c+2c turn EH on sides. 1c finish in tandem (1M leading) between 2c and face up
9--::
  1c+2c Reel3 across in tandem (with lead change), 1M RSh to 2W
17--::
  1c+3c Reel3 across in tandem (with lead change), 1M LSh to 3W. 1c finish in 2pl centre and face down
25--::
  1c+3c turn EH. 1c finish in 2pl centre (to 2,1x,3) ; 1c turn P RH 1½ (2,1,3)

*Deviser''s note*. Bars 9-24: The dolphin reels need careful phrasing - dancers should make fairly wide loops.', 3);
INSERT INTO 'dancecrib' VALUES (12219, '2019-09-15 22:43:01.177125+00', '2022-01-29 20:53:17.778478+00', 19555, 1, 202, 'ace', '1--::

  1c cast off | set ; cast back to 1pl | set _while{4}_ 2c+3c ½ R&L (no polite turn) (1,3x,2x)

9--::

  1c+3c L-Chain (1,3x,2x)

17--::

  1c cross RH | set _while{4}_ 3c+2c ½ R&L ; 1c turn P RH 1½ to 1pl centre. On [24] 2c step in ready for

25--::

  1c+2c Poussette (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11319, '2018-10-29 08:05:24.385888+00', '2018-10-29 08:10:49.959387+00', 16788, 1, 202, 'ace', '1--::

  1c lead down {3}, up {3}, cross and cast to 2plx (2c up) (2,1x,3)

9--::

  Gr-Chain (2,1,3)

17--::

  1c cross down, cast to 2pl ; dance to top and cast to 2pl (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14458, '2021-11-19 02:14:32.738009+00', '2022-08-14 10:58:33.853148+00', 15222, 1, 202, 'ace', '1--::

  1c & 3c cast off (2c & 4c up) | turn P RH | 1c cast off to 4pl _while{2}_ 3c lead up to 2pl (2,3,4,1)

9--::

  2c & 4c repeat same pattern [1-8]. All face on sides as for a Reel4 (3,4,1,2)

17--::

  3c+4c & 1c+2c set advancing passing LSh (to 4,3,2,1) | 3c+2c set advancing passing LSh _while{2}_ 4c & 1c set and face in (to 4,2,3,1) ; 4c+2c & 3c+1c RHA (4,2,3,1)

25--::

  4c cross RH | cast off (2c up) ; repeat [25-28] (3c up) (2,3,4,1)

33--::

  Circle8 L {3}, cross R foot over and pivot L ; chase cclw (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (15449, '2023-02-18 12:05:52.771704+00', '2023-02-18 12:08:21.231089+00', 9426, 1, 1645, 'ace', '*Large circle round the room (or a tree!) M with P on his R*

1--::

  All W adv, pull RSh back | set to P _while{4}_ M set twice (or PdB coupé) ;

  W dance out _while{2}_ M adv & pull RSh back | all set to P

9--::

  All turn P 1&frac12; RH to M on outside facing clw, W inside facing cclw ;

  all chase passing 4 people

17--::

  All turn 5th person 1&frac12; RH to M inside & W outside facing other way ;

  all chase back & join RH with original P & LH with person on their L to form circle with M facing out & W facing in

25--::

  All set | &frac12; turn P RH & reform circle ; set | &frac12; turn LH person (new partner) & all face in

33--::

  All circle round to L & back. Repeat with new partner

', 2);
INSERT INTO 'dancecrib' VALUES (4544, '2013-08-21 08:30:50.288697+00', '2023-02-21 12:32:14.515165+00', 998, 3, NULL, 'ace', '{{explanation}}

3s & 4s on opp sides



1-8::

    1s & 4s cross RH & cast in 1 place, set & dance 1/2 LH across end

    giving RH to nearest corner

9-16::

    All Balance in St Andrews cross formation & 4s also 1s turn corners

    into centre, balance & turn corners back to places & end facing

    corners

17-24::

    4s & 1s dance DoSiDo with corners, 4s & 1s dance RSh round corner

    back into middle

25-32::

    4s+1s dance RH across & end 1s facing down & 4s up, dance out ends

    crossing & cast in 1 place.  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (11313, '2018-10-28 00:11:25.482003+00', '2018-11-24 04:55:28.792001+00', 19041, 1, NULL, 'ace', '1--::

  1c cast off (2c up) | All set ; 1c ½ Fig8 round 2c (2,1x,3)

9--::

  "Arandel":  All cross RH | 2M sets to 3W _while{2}_  1c change place LH with 3cnr (pos) ; All cross RH with opposite | Same dancers as before set and change places back (with polite turn).  1c finish RHJ in diagonal line, LHJ with 1cnrs.

17--::

  1c+1cnrs BiL | 1c turn RH to 2cnrs ; BiL | turn RH to face out own side

25--::

  Reels3 on own side, Rsh to 3cnr.

*After 2nd time, 1-4: 1c cast off (4c up) and set*

', 5);
INSERT INTO 'dancecrib' VALUES (11320, '2018-10-29 09:31:00.498383+00', '2018-10-29 14:03:31.085286+00', 6520, 1, NULL, 'ace', '*All dance all figures*

1--::

  Circle10 and back

9--::

  Set twice, facing out on [11] ; dance straight out | dance towards P

17--::

  Set twice to P ; A&R to P

25--::

  Dance BtoB ; Turn P RH 1¼ into promhold cclw (M inside)

33-48::

  Promenade cclw {12} ; dance in to original circle

49--::

  RHA in big wheel, W in middle, NHJ with P, at end W dance out (all to P''s original place)

57--::

  Turn P RH 1½ ; Turn P LH to own places  



*dance once more*

', 4);
INSERT INTO 'dancecrib' VALUES (8927, '2015-09-27 21:11:31.508003+00', '2016-03-22 22:06:19.268721+00', 8775, 1, NULL, 'ace', '1--::  1c set | turn RH ½ ; slip down | and up to (1x,2,3,4)

9--::  1c+2c set | 2c+3c set _while{2}_ 1c cross RH ; 1c cast to 3pl (2c+3c up) | All turn RH ½ into BHJ (2x,3x,1x,4)

17--::  3C Poussette: 2c progresses down 2 places as 3c+1c progress up (3x,1x,2x,4)

25--::  Corner Chase: 1c+3cnr (1cnr person) turn RH ¼ | cnrs cross through 2pl to original positions as 1c follows to 2plx ; 1c+4cnr (2cnr person) turn LH ¼ | cnrs cross through 2pl to original positions as 1c follows to 2plx in the middle LHJ facing cclw (2,1x,3,4)

33--::  1c set and face clw RHJ | set ; 1c dance out ends (M down W up) and cast R to (2,1,3,4)

41--::  1c approach, dance down and curve to 4pl (3c+4c up) ; All turn P RH (2,3,4,1)



', 4);
INSERT INTO 'dancecrib' VALUES (3134, '2012-01-22 19:30:12.746681+00', '2020-02-08 19:47:55.756606+00', 9944, 1, NULL, 'ace', '{{explanation}}

On 2nd chord 3c+4c change sides



1–::

  All dance G-Chain, 1c & 4c cross to begin

9–::

  1c+4c cross, cast to middle (2c+3c to end) ; 1c+4c RHA for {3}, on 4th step they turn partner ½ round to finish in promhold, 1c facing M side, 4c facing W side.

17–::

  Reels3 on the sides, giving Lsh to W on the L, and finishing 1c facing 4c down and up the dance

25–::

  1c+4c set to each other, set advancing to finish BtoB ; 1c+4c turn corner positions (W with RH, M with LH) to finish in order 2,4,1,3', 2);
INSERT INTO 'dancecrib' VALUES (10111, '2017-09-08 20:37:17.327454+00', '2018-02-22 09:05:42.79237+00', 17922, 1, NULL, 'ace', '1-4::

  1c cast (2c up) | set advancing to face 1cnr

5-16::

  Dance to each corner and set, finish (3x,1x,2x) 

17--::

  Middles (1c) change places RH to cnrs on the R | new middles change LH to cnrs on the L ; repeat to the R | All cross RH (2,1,3)

25--::

  1c+3c Chain Progression (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (12226, '2019-09-16 22:10:42.245964+00', '2019-09-25 03:52:41.642911+00', 19650, 1, NULL, 'ace', '1--::

  1c+2c cross Rsh | change places Lsh on sides ; repeat (1,2)

9--::

  1c+2c R&L

17--::

  1c lead down {3}, up {3} | 1c cast off (2c up)

25--::

  Circle4 and back

', 4);
INSERT INTO 'dancecrib' VALUES (10437, '2018-02-22 06:00:06.633399+00', '2018-02-22 06:07:55.332997+00', 16470, 1, 202, 'ace', '1--::

  1W+2M cross RH | 1c & 2c turn P RH ¾ into line of 4 across ; ½ Reel4 across (to 1W,1M,3W on W side, 2W,2M,3M on M side, 1c(2c) facing dn(up))

9--::

  Parallel Reels3 on sidelines, 1M & 2M Lsh to 3c

17--::

  1c+2c RHA 1 ¼ ; 2c+1c+3c turn P RH (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (12230, '2019-09-17 16:07:48.707407+00', '2021-01-28 14:04:36.549466+00', 11220, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 1c set | turn BH opening to face down NHJ _while{4}_ 2c & 3c turn P BH opening to face up/down NHJ (2,1x,3)

9--::

  Mirror PushMe-PullYou Reels3 on sides, all joining hands when possible [: 1c Mirror Fig8 on sides, starting out and down _while{8}_ 2c+3c Mirror BtoB on sides twice (on [9-10] LSh on Wside, RSh on Mside then on [13-14] RSh on Wside, LSh on Mside)]. 2c & 1c face down, 3c face up (2,1x,3)

17--::

  ½ 3C Rondel  

[: 3c making arch dance to top, cross and cast to 1plx  

_while_ 1c dance under 3c arch, cast up to 2plx  

_while_ 2c following 1c dance under 3c arch to bottom, cross and cast to 3plx] (to 3x,1x,2x) ; 4 bars of 3C Set& Rotate into lines3 across

25--::

  Men making arches A&R, 1c dancing BtoB ; 4 bars of 3C Set&Rotate to sides (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12229, '2019-09-17 11:58:00.998065+00', '2019-09-17 12:01:06.35713+00', 19659, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c Chain and Turn (2,1,4,3)

9--::

  1c cast off and dance RSh round 3cnrs, cross LH on midline, dance LSh round 1cnrs to 2plx (2,1x,4,3)

17--::

  1c lead up to top, cross and cast to 2pl _while{4}_ 4c dance down between 3c and cast to 3pl ; 1c+4c RHA (2,1,4,3)

25--::

  All turn P BH. 1c and 4c stay in the middle ready for ; ½ Poussette (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14342, '2021-10-02 04:31:20.955006+00', '2021-10-20 11:06:23.43875+00', 20497, 1, 202, 'ace', '1--::
  1M & 2M Fig8 round P and dancer to the R (dance across between them, RSh round that dancer, LSh round P) back to places and face down (1,2,3)
9--::
  All chase cclw ½ ; all turn P LH (3x,2x,1x)
17--::
  2W & 1W Fig8 round P and dancer to the L (dance across between them, LSh round that dancer, RSh round P) back to places and face up (3x,2x,1x)
25--::
  All chase clw ½ (to 1,2,3) ; 1c+2c ½ RHA | cross RH _while{4}_ 3c turn P RH (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (12232, '2019-09-20 08:16:16.80703+00', '2019-09-20 16:30:12.792721+00', 19660, 1, 202, 'ace', '1--::
  1c set | cast off (2c up) ; ½ Fig8 L RSh to 2cnrs finishing on midline RSh to P facing own sides
9--::
  2c+1W & 1M+3c ½ LHA | 1c chase cclw ½ to exchanged places _while{4}_ 2c+3c RHA | 2c+1M & 1W+3c ½ LHA to sides (2,1,3)
17--::
  1c+3c »Progressive DblFig8« [: 1c cross | cast ; cross up | cast _while{8}_ 3c set | cross up ; cast | cross up] (2,3,1)
25--::
  All dance BtoB ; turn P RH (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (12233, '2019-09-20 22:05:03.559671+00', '2019-09-21 07:52:46.130147+00', 2949, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; 1c turn BH (2,1)

9--::

  2c repeat [1-8] (1,2)

17--::

  1c+2c RHA ; LHA (1,2)

25--::

  1c cross | cast off (2c up) ; 1c ½ Fig8 up round 2c (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (11333, '2018-11-10 13:25:42.808264+00', '2018-11-10 13:25:42.808264+00', 19049, 1, NULL, 'ace', '1--::

  1c+3c DblFig8, 3c cast to begin (1,2,3)

9--::

  All set | cross RH; set | cross RH (1,2,3)

17--::

  All 3C Set and Rotate (3,2,1)

25--::

  2c+1c Tourbillon (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (12236, '2019-09-23 00:48:10.75398+00', '2019-09-23 00:48:10.75398+00', 10740, 1, NULL, 'ace', '1--::

  1c+3c DblFig8 round 2c, 1c cast off to begin (1,2,3)

9--::

  2c leads down and up to 1pl _while{8}_ 1c cast behind own lines, and follow 2c up the middle to (2,1,3)

17--::

  1c Fig8 on own side round 2c and 3c, 1c start in and up (2,1,3)

25--::

  1M+3c & 1W+2c Reels3 across, Lsh to 1cnr (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8928, '2015-09-28 19:41:58.668651+00', '2015-09-28 19:41:58.668651+00', 12845, 1, NULL, 'ace', '1--::  1c+2c set | La Baratte and face out and L

9--::  All chase cclw 1/2 round and pivot L in place ; LHA (2,1)

17--::  1c Fig8 round 2c

25--::  2c+1c Slipknot (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8889, '2015-09-03 18:36:10.956311+00', '2019-04-03 20:17:53.913488+00', 15338, 2, 2653, 'ace', '1-8::

  1s dance in & cast to 2nd place ; set advancing towards partner & turn BH ½ way, pivoting on last bar pulling RSh back to  face 1st corners. 2s step up on 3&4.

9-16::

  1s set to 1st corners & dance by the right around each other (gypsy) to face 2nd corners ; 1s set to 2nd corners & dance around each other to 2nd place own sides, facing out.

17-20::

  1s dance a loop around 3rd corners & pass RSh in middle to face 4th corners;  *meanwhile* 3rd corners ½ turn and twirl to change places ;

21-24::

  1s dance a loop around 4th corners & pass RSh in middle to 2nd place opposite side; *meanwhile*, 4th corners ½ turn and twirl to change places

25-32::

  3s+1s+2s chase clockwise half way ; & turn partner BH once round.

', 0);
INSERT INTO 'dancecrib' VALUES (11322, '2018-10-29 23:36:24.443712+00', '2018-10-29 23:47:33.742563+00', 19043, 1, 202, 'ace', '1--::

  1c turn 2c EH, 1c in and down | 1c dance down (2c dance up to 1pl) ; 1c turn 3c EH and face 1cnrs (2,1,3)

9--::

  6 bars of SetH&G | set advancing to midline facing M side

17--::

  1M+2c RHA _as_ 1W+3c LHA. 1c to midline facing up, M leading ; 1c dance to 1pl (2c down). Both face each other on sides | 1c & 2c PdB R on sides, PdB L advancing towards P (1,2,3)

25--::

  1c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (11324, '2018-11-03 00:10:52.130778+00', '2018-11-03 00:16:56.237824+00', 17120, 1, 202, 'ace', '1--::
  All set to P | turn P RH ; all M LHA
9--::
  All set to P | turn P LH ; all W RHA
17--::
  All W pass P RSh {1}, next person LSh {1} ; turn next person BH {2} ; all W repeat [17-20] from new places (all W have progressed one place clw)
25--::
  Set in circle | Circle6 {2} L ; all dance into centre, loop R and chase clw to places (all M to original places, all W having progressed)', 2);
INSERT INTO 'dancecrib' VALUES (10203, '2017-10-24 21:02:31.638385+00', '2019-03-03 10:35:38.991379+00', 12014, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; dance down between 3c and cast up to 2pl (2,1,3)

9--::

  1c cross RH | dance RSh round 1cnr[pos] ; chase clw ¾ into facing lines3 across (M/W between 2c/3c) _while{8}_   2c+3c R&L

17-28::

  3C R&L starting up/down

29-32::

  All set. On (30] 2c & 3c face P | 1c Petronella turn to 2pl _while{2}_ 2c & 3c cross RH (2x,1,3x)

33--::

  Diagonal R&L (3,1,2)', 4);
INSERT INTO 'dancecrib' VALUES (11323, '2018-10-30 00:09:11.450187+00', '2018-10-30 04:46:10.637976+00', 1069, 1, 202, 'ace', '1--::

  1c+2c R&L (1,2,3)

9--::

  1c set | cast (2c up) ; 1c cross RH and loop RSh round 1cnrs to face 1cnrs (2,1,3)

17--::

  1c set to 1cnrs | set to 2cnrs ; 1c dance Rsh round P 1½ times to face 4cnrs

25--::

  Reels3{6} across, RSh to 4cnrs (to 2,1x,3) | 1c cross RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10572, '2018-04-03 08:21:14.885387+00', '2018-04-07 07:00:23.518971+00', 13896, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; dance down between 3c and cast up to 2pl (2,1,3)

9--::

  2c+1c ½ DblFig8, 1c start crossing up ; 1c+3c ½ DblFig8, 1c start crossing down (2x,1,3x)

17-20::

  1W+2c & 1M+3c ½ RHA | 1c chase clw to 2pl (to 2,1,3)

21-32::

  3C R&L  ', 4);
INSERT INTO 'dancecrib' VALUES (10872, '2018-07-03 02:10:08.579574+00', '2019-02-03 21:42:10.892265+00', 18307, 1, 202, 'ace', '1--::

  2c cross RH | cast R round 1cnrs into facing lines3 across ; all set | 2c cast R round 4cnrs to 2pl (1,2,3)

9--::

  3C Knot, 2c finishing facing 1cnrs[pos] (3,*2*,1)

17--::

  Corners Pass and Turn (3,2,1)

25--::

  3c+2c S&Rotate (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (11325, '2018-11-03 00:46:21.715161+00', '2019-02-23 19:10:56.729415+00', 17104, 1, 202, 'ace', '1--::

  1c & 4c Fig8 on sides, starting in (1,2,3,4)

9--::

  All set | cross RH ; set | turn P RH ½. 1c & 3c face down, 2c & 4c face up, all NHJ

17--::

  1c & 3c dance down _as_ 2c & 4c dance up making arches (to 2,1,4,3) | 2c & 3c set and turn inwards _while{2}_ 1c making arch dance down _as_ 4c dance up (to 2,4,1,3) ; 2c & 1c dance down _as_ 4c & 3c dance up making arches (to 4,2,3,1) | 4c & 1c set and turn inwards _while{2}_ 2c making arch dance down _as_ 3c dance up (4,3,2,1)

25--::

  4c+3c & 2c+1c RHA. 4c & 2c in centre face up ; 4c cast to 3pl _as_ 2c dance up to 1pl | all set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10708, '2018-04-29 08:16:50.306231+00', '2019-04-20 08:47:11.737614+00', 16690, 1, 202, 'ace', '1--::

  1W followed by 1M cast round 2W, crosses to M side, cast up to 1pl (1,2,3)

9--::

  1W+2M set | turn RH ; 1M+2W set | turn LH ¾ and face P on 2diag

17--::

  Reel4 on 2diag (1,2,3)

25--::

  1M followed by 1W cast round 2M, crosses to 2plx (2c up) ; 1c set | Petronella turn

33--::

  1c set | Petronella turn (to 2,1,3) ; 1M set twice pivoting R _while{4}_ 1W set using PdB-Coupé ', 2);
INSERT INTO 'dancecrib' VALUES (11329, '2018-11-04 12:59:43.637626+00', '2018-11-04 13:04:24.486456+00', 18695, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; dance down between 3c | cast up (2,1x,3)

9--::

  2c+1c La-Chain (2,1x,3)

17--::

  All set | turn P RH ; chase clw ½ (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11328, '2018-11-04 12:47:22.842297+00', '2018-11-04 12:54:15.328774+00', 17113, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA ; set | cross RH (2,1,3)

9--::

  3C S&Link ; ½ Reels3 across, 1c LSh to 2cnrs[pos]

17--::

  3C S&Link ; ½ Reels3 on sides, 1c LSh to 1cnrs[pos] (2,1x,3)

25--::

  1c ½ Fig8 R ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8929, '2015-09-28 19:54:36.350722+00', '2016-04-18 07:13:33.409242+00', 13362, 2, 106, 'ace', '1-4 ::

  1s+4s xRH, cast down/up, 2s step up, 3s down

5-8 ::

  1s+4s turn RH to prom hold, btob, 1s up, 4s down (W on M''s left)

9-16::

  1s with 2s, 4s with 3s, Rsh R3 across

17-20 ::

  1W/2M, 4W/3M turn LH, 1M/2W, 4M/3W turn RH

21-24 ::

  1s x up, cast dn as 4s x dn, cast up 2,1,(4),(3)

25-32::

  All set, 1s/4s petronella twice in tandem, all set 2,4,(1),(3) 



', 5);
INSERT INTO 'dancecrib' VALUES (9340, '2016-10-01 22:11:43.291539+00', '2016-10-04 13:45:51.756972+00', 17391, 1, NULL, 'ace', '1--::

  1c+4c set adv. | turn BH and face out the end ; cast to middle (2c+3c to end) | Turn P RH and face the end in promhold 

9--::

  2c+1c (promhold) & 4c(promhold)+3c ½ Rsh reels3 across, 1c & 4c change ends ; 2c+4c & 1c+3c ½ Rsh Reels3 across, at end 4c+1c turn inwards (M on the R) into lines across 4c between 2c facing 1c between 3c, 

17--::

  4c+1c RHA (finish in same lines across) ; LHA  (+ _optional{8}_: 2c+3c R&L starting on the sides) (2,4,1x,3x)

25--::

  1W+4W+1M & 4M+1W+3W Rsh Reels3 (4W & 1W start in and R) (2M+3M stand{8}) (2,4,1x,3x)

', 5);
INSERT INTO 'dancecrib' VALUES (11332, '2018-11-09 23:11:33.53069+00', '2021-04-08 12:10:17.062754+00', 12451, 1, 1645, 'ace', '{{explanation}}

Strathspey



1-4::

  All set to P | turn RH & face P

5-12::

  Interlocking Reels4, end turning P RH retaining RH & M take LH in centre

13-16::

  Balance in crossing lines with Highland Schottische: HS set R, M drop LH and take LH with P as W take RH in centre |

  HS set L, W drop RH and take RH with P

17-24::

  Double M-chain

25-32::

  1W+4M facing 2M+3W R&L

33-40::

  1M+2W facing 4W+3M R&L omitting polite turn

41-56::

  Schiehallion reels

57-64::

  All circle8 & back



{{explanation}}

Reel



1-12::

  As in Strathspey

13-16::

  Balance in crossing lines | turn P RH

17-64::

  As in Strathspey

', 2);
INSERT INTO 'dancecrib' VALUES (9022, '2015-11-30 09:00:02.929529+00', '2023-02-04 01:21:24.814312+00', 12751, 3, NULL, 'ace', '1-8::
    All join hands on sides, set, cross RH, set cross back RH
9-16::
    1s lead down (3 steps), lead up (3 steps) & cast to 2nd place (2s
    step up bars 15-16)
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & cross LH to 2nd
    place own side
25-32::
    1s turn 2H (2 bars), cast to 4th place (3s+4s step up) & 1s turn 2H
    (4 bars)', 0);
INSERT INTO 'dancecrib' VALUES (12234, '2019-09-22 16:33:44.123036+00', '2019-09-23 09:28:46.182603+00', 19662, 1, NULL, 'ace', '1--::

  1c+2c 6 bars of the Tourbillon | 2c cross RH _as_ 1c turn RH ½ and face down NHJ (2,1,3)

9--::

  Reels3 on the sides, 1c start down and in, 2c cast.  Take NH when meeting P, 2c+3c finish with loops and 1c face up NHJ (2,1,3)

17--::

  1c+3c dance up and cast off to (2,3,1) ; All turn P BH

25--::

  Circle6 and back (2,3,1)

', 4);
INSERT INTO 'dancecrib' VALUES (10992, '2018-08-17 03:23:40.01673+00', '2018-11-23 23:48:17.709294+00', 13358, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; turn LH (2,1,3)

9--::

  Reels3 across, 1c Lsh to 1cnrs, face 1cnrs (2,1,3)

17--::

  1c Set To And Turn Corners (2,1x,3)

25--::

  Reels3{6} on sidelines, Lsh to 1cnrs | 1c cross (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14827, '2022-05-15 23:58:13.216041+00', '2022-05-15 23:59:45.534009+00', 20825, 1, 202, 'ace', '1--::

  All set | dance BtoB | set (1,2,3)

9--::

  1c & 3c turn P RH ¾ | ½ Reel4 on midline | turn P RH ¾ (3,2,1)

17--::

  3c+2c Set&Rotate, setting diagonally (2,3,1)

25--::

  Circle6 and back (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (4531, '2013-08-21 08:30:50.15183+00', '2023-02-21 12:38:46.357869+00', 977, 3, NULL, 'ace', '1-8::

    1s set, cross RH, 1s+2s set & 1L & 2L cast 1 place (1L down & 2L up)

    _while_ 1M & 2M cross to partners place

9-16::

    1s+2s dance Ladies'' Chain

17-24::

    1s+2s set to partners (on sides) twice & turn RH 1.1/2 times

25-32::

    1s followed by 2s slip step down centre of dance & back (2s to top

    place', 0);
INSERT INTO 'dancecrib' VALUES (10576, '2018-04-03 23:37:48.642191+00', '2018-04-07 23:52:49.722787+00', 13902, 1, 202, 'ace', '1--::

  1c & 2c Mirror S&Link, 1c casting ; 1c turn LH 1¼ ending on midline

9--::

  1M+3c & 1W+2c RHA ; Lsh Snake Pass [unwind the RHA, 1c leading, pass other snake Lsh through 2plx and chase clw] (3,1,2)

17--::

  1c ½ Fig8 R to 2plx ; ½ Reels3 across, 1c start Rsh to 4cnrs position (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (12231, '2019-09-17 21:42:35.727432+00', '2019-09-23 16:50:16.082704+00', 11756, 1, 1645, 'ace', '*Start (1,2,3x,4x)*
1-::
  All set twice ; dance towards P | 1c & 4c cast in as 2c & 3c dance to ends & face out (2,1,4x,3x)
9-::
  2c+1c & 4c+3c DblFig8, 1c & 4c start by crossing to ends
17-::
  1M+4W & 4M+1W take promhold for RSh Reels3 on sides
25-::
  1M+4W (down) & 4M+1W (up) &frac12; Fig8 out through ends ; turn LH to sides (2,4,1x,3x) for
33-::
  RSh Reels4 on sides, 1c & 4c end passing RSh for
41-::
  All circle8 to L, pivot & chase back (2,4,1x,3x)
::
*Crib derived from the video.*
', 2);
INSERT INTO 'dancecrib' VALUES (2819, '2012-01-22 19:29:58.698484+00', '2020-12-13 12:04:18.68568+00', 4518, 1, NULL, 'ace', '1–::

  1c+2c set | cross RH ; repeat

9–::

  1c+2c RHA {3}, LHA {3} | 1c cast off _while{2}_ 2c dance up (2,1,3)

17–::

  1c cross RH, cast up one, cross LH, cast off one.

25–::

  1c+2c R&L', 3);
INSERT INTO 'dancecrib' VALUES (12240, '2019-09-23 19:21:15.503019+00', '2019-09-23 19:30:58.011475+00', 19557, 1, NULL, 'ace', '1--::

  1c set | dance down to between 3c ; turn 3c EH to (2,1,3) | all set

9--::

  Reels3 on the sides, 1c start in and up as 3c cast, 1c finish facing 1cnr

17--::

  1c set to and turn 1cnr RH to between end couples ; into ½ Reels3 across (Lsh to 4cnr), finish in lines aross

25--::

  All S&Link (2,1,3) ; All turn P RH

', 3);
INSERT INTO 'dancecrib' VALUES (12241, '2019-09-23 19:34:24.519277+00', '2019-09-23 20:10:31.90803+00', 16789, 1, NULL, 'ace', '1--::

  1c+2c set | cross RH ; set | cross LH, finishing BHJ with P for (1,2,3)

9--::

  1c+2c *Borders'' Poussette* (all PdB): dance 5 bars of normal Poussette (M start on R foot), turn P BH ¼ to midline{1} | 2c+1c cast R to own sides [like end of DTr] to (2,1,3), 1c facing out

17--::

  Reels3 on the sides, 1c start Rsh to 3cnr, with loops at end (2,1,3)

25--::

  1c+2cnrs L hand Cnrs Pass and Turn, 1c pass Lsh to face 1cnrs ; 1c+2cnrs repeat, 1c pass Lsh to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12238, '2019-09-23 08:49:20.508663+00', '2019-09-23 22:04:25.889533+00', 19663, 1, 1645, 'ace', '1-::
  1c set | cross down RH (2c up) ; cast off below 3c | dance up to end BtoB facing opposite side (2,1x,3)
9-::
  All set as in DTr | set advancing & pull RSh back to invert triangles ; 1c (outside opposite sidelines)+cnrs RHA , end in same places
17-::
  All set as inverted DTr | set advancing & pull RSh back to DTr position ; 1c (in middle, opposite side)+cnrs RHA & 1c cross RSh to own sides (2,1,3)
25-::
  All circle6 & back (2,1,3)
::
  *NB crib derived from the video.*
', 2);
INSERT INTO 'dancecrib' VALUES (12239, '2019-09-23 15:37:45.944861+00', '2019-09-23 22:07:11.389328+00', 19664, 1, NULL, 'ace', '1--::

  1c cross | cast off (2c up) ; ½ Fig8 round 2c to face 1cnrs

9--::

  1c set to and turn 1cnrs ; set  to and turn 2cnrs, finish on sideline facing 1cnr (2,1x,3)

17--::

  Reels3{6} on the sides, Lsh to 1cnr | 1c cross RH (2,1,3)

25--::

  1c+3c Espagnole (2,3,1)

', 4);
INSERT INTO 'dancecrib' VALUES (11331, '2018-11-09 09:19:17.475613+00', '2018-11-09 10:52:58.169686+00', 18911, 1, 202, 'ace', '1--::

  1c set | cross RH ; 1c+2c S&Link (2,1x,3)

9--::

  2c+1c M-Chain (2,1x,3)

17--::

  1c set | turn RH ¾ ; 1M+2c & 1W+3c LHA

25--::

  Reels3 on sides, 1c RSh to 4cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10484, '2018-03-04 23:06:25.912323+00', '2018-11-09 20:10:49.730159+00', 13975, 2, 2220, 'ace', '1–:: 1c and 2c dance back-to-back; dance in to face up

   and 1c cast to 2nd place while 2c dance to top and cast into place

9-:: 1c dance adv and ret, with 1st cnrs; repeat with 2nd cnrs

17-:: 1c pass Lsh and dance Rsh round first cnr,

   pass Lsh up and down and dance Rsh round 2nd cnr, passing Lsh to own sides

25-:: 1c pass Lsh with dancer on Left for Left sh reels on own sides;

   at end 1s pull back Rsh to finish progressed

   (1c may pass each other by the Rsh, if time allows) 

', 0);
INSERT INTO 'dancecrib' VALUES (8930, '2015-09-29 10:35:30.870791+00', '2016-06-03 14:03:21.462582+00', 16773, 2, 1, 'ace', '1–::

  1c+2c poussette [on bar 8, keep turning to fin facing down, W on M''s right]

9–::

  1c&2c dance down | turn BH ; dance up | 1c cast off into 2plx

  _while_ 2c dance up and loop into 1plx

17–::

  1M+2W advance past each other RS, pivot R to face, continue

  turning R about and cast to orig pl ; 1W+2M repeat

25–::

  1c+2c dance a tourbillon', 3);
INSERT INTO 'dancecrib' VALUES (11551, '2019-01-29 22:23:07.138018+00', '2021-04-14 11:35:09.167155+00', 6131, 1, 1645, 'ace', '1-::

  1c set adv | dance RSh round P ; cast off (2c up) | set adv to 1cnrs

9-::

  CPCP to face 1cnrs again

17-::

  1c+1cnrs &frac12; RSh diagonal Reel4, pass LSh ; repeat with 2cnrs, pass LSh

25-::

  1M+3W+2W & 1W+3M+2M RHA, 1c pull back RSh to face P ; 2c+3c chase &frac12; clw _while{4}_ 1c turn BH | cast, RSh back, to sides (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14344, '2021-10-02 22:13:45.516038+00', '2021-10-03 19:32:34.305776+00', 10056, 1, 202, 'ace', '1--::
  1c cross RSh | turn 2c EH ½ on sides ; cross LSh | turn 3c EH ½ on sides (2,3,1)
9--::
  1c dance up to top and cast off (3c down) ; turn P RH and face 1cnrs
17--::
  Corners Pass and Turn (2,1x,3)
25--::
  Reels3 {6} on sides, 1c LSh to 1cnrs | 1c cross RH (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (9343, '2016-10-04 14:42:32.148145+00', '2016-10-04 14:42:32.148145+00', 17394, 1, NULL, 'ace', '1--::

  1c+2c The Knot

9--::

  1c turn 1cnr RH | pass Rsh ; turn 2cnr RH into line across, 1c in middle facing ends

17--::

  Reel4 across, 2cnrs finish in place as 1c face 1cnr

25--::

  Rsh Reels3{6} on the sides, at end 1c face P up/down | 1c petronella to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11341, '2018-11-12 00:31:32.708054+00', '2018-11-12 00:31:32.708054+00', 19053, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c S&Rotate (2,1,4,3)

9--::

  1c+4c set | cross RH ; Petronella to midline | Turn P BH 1½ 

17--::

  Reel4 on midline, finish in Poussette hold with P

25--::

  1c+4c HS Poussette (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11335, '2018-11-10 16:55:27.796426+00', '2019-03-03 09:37:12.69854+00', 19032, 1, 202, 'ace', '1--::

  1c+2c »En rond« [All change places LH on sidelines (polite turn) | set to P ; Circle4 R] (2,1,3)

9--::

  1c cross RH | cast R into facing lines3 across ; all set twice. On [15-16] 1c set pivoting R to face 1cnrs

17--::

 1c turn 1cnrs RH, pass RSh ; turn 2cnrs RH, pass RSh to 2pl (cnrs dance 4 bars) (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11799, '2019-04-22 11:25:56.288572+00', '2019-04-22 11:25:56.288572+00', 9431, 1, NULL, 'ace', '1--::

  1c, with 2c casting up and following, dance down between 3c, cast up, dance to top and 1c cast off, 2c stay facing out (2,1,3)

9--::

  Mirror Reels3 on the sides, 1c starting in and down.  Take hands when possible, loop at the end (2,1,3)

17--::

  2c+1c (leading) lead down ; 1c lead up (2c split and follow), into

25--::

  1c+2c Allemande (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (2787, '2012-01-22 19:29:57.387685+00', '2020-12-12 10:49:04.251043+00', 4394, 1, NULL, 'ace', '1–::

  1c lead up | set ; turn BH ½ | dance down _while{8}_ 2c lead down | set ; turn BH once | dance up

9–::

  1c facing 2c NHJ set | turn person opposite BH ; 1c+2c with NHJ on sides set to P | turn P BH (1x,2,3)

17–::

  1c lead down the middle and cast up (2c up) to 2plx ; ½ Fig8 round 3c (2,1,3)

25–::

  G-Chain, 2c cross to start.', 3);
INSERT INTO 'dancecrib' VALUES (14460, '2021-11-22 01:01:31.727306+00', '2021-11-22 01:07:40.3662+00', 20515, 1, 202, 'ace', '1--::
  2c+3c Petronella Turn in Tandem | set ; Circle4 L and face nearest cnrs
9--::
  All set | change places RH with nearest cnrs ; 1c+4c LHA and face same nearest cnrs[pos] _while{4}_ 2c & 3c chase clw ¼. 2c face down, 3c face up (2,1,4x,3x)
17--::
  Reels4 on sides (2,1,4x,3x)
25--::
  2c & 3c turn P BH ½ opening to face down | 2c dance down to 4pl _while{4}_ 3c cast up to 1pl | all set (3,1,4x,2x)', 2);
INSERT INTO 'dancecrib' VALUES (3253, '2012-01-22 19:30:17.662488+00', '2021-04-14 21:25:52.128201+00', 6058, 1, NULL, 'ace', '1–::

  1c set, cast off one ; set, cast back to 1pl

9–::

  1c dance down the middle {1}, up {1}, cast off to 1cnr (2c up) ; 1c set to 1cnr, set to 2cnr

17–::

  1c lead down between 3c, cross, cast up between 2c, cast off (to 2,1,3)

25–::

  1c+3c RHA ; 2c+1c LHA

33–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (11338, '2018-11-11 02:41:11.004675+00', '2018-11-11 02:47:23.961912+00', 17106, 1, 202, 'ace', '1--::

  1c set | 6 bars of Fig8 (2c up on [7-8]) (2,1,3)

9-20::

  3C R&L (2,1,3)

21-24::

  1c set | turn LH ¼

25--::

  1M+3c & 1W+2c RHA, pass RSh ; 1M+2c & 1W+3c LHA into promhold facing up (2,1,3)

33--::

  3C Promenade (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11339, '2018-11-11 03:06:08.155795+00', '2018-11-11 03:14:01.885363+00', 17107, 1, 202, 'ace', '1--::

  1c pass RSh to 2pl centre BtoB 1M(1W) face down(up) (2c up) | 6 bars of DTr, 1M(1W) face up(down)

9--::

  ½ Reels3 across, 1c RSh to 2cnrs (to 2x,1x,3x) ; ½ Reels3 on sides, 1c LSh to 1cnrs, 1c in 2plx centre face up (3x,1x,2x)

17--::

  1c dance to top, cast ; cross down between 2c, cast to 2pl _while{8}_ 3c+2c set | cross RH ; set | change places RH on sides (2,1,3)

25--::

  Circle6 L {3}, cross R foot over and pivot L ; chase cclw to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11340, '2018-11-11 07:30:35.585602+00', '2018-11-11 07:41:05.239387+00', 17108, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c Poussette. On [8] 1c pass RSh

9-24::

  The Spurtle (2x,3x,4x,1x)

25--::

  All turn P BH 1½ opening into ; 2c+3c & 4c+1c Circle4 L opening into

33--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (11334, '2018-11-10 13:36:52.612282+00', '2018-11-11 11:05:50.065305+00', 19050, 1, NULL, 'ace', '1--::

  Reels3 on both sides, 2c start inwards and to their R (1,2,3)

 9--::

  Reels3 across, 2c give Lsh to 1cnr, 1c & 3c cast into the reels (1,2,3)

17--::

  2c (dancing in) +1c turn ½ EH | All set  (2,1,3) ; All turn P RH to finish on midline for

25--::

  3C Allemande (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (9344, '2016-10-04 15:21:53.133122+00', '2016-10-04 15:21:53.133122+00', 17395, 1, NULL, 'ace', '1--::

  1c+2c Circle4 L ; 1c Petronella turn | turn RH to (1x,2,3)

9--::

  1c+2c Circulating Knot (1c loops up, 2c down, 1c finishes facing 3cnr, 2c in 1pl)

17--::

  Lsh Corners Pass and Swirl with 3cnrs ; with 4cnrs (like Corners pass and Turn, but all Lsh, no hands), 1c finish on midline, M below W 

25--::

  2c+1W & 1M+3c RHA into ; 1c+3c ½ Poussette (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (3753, '2013-06-05 09:41:38.967183+00', '2018-11-16 15:03:44.607767+00', 14941, 2, NULL, 'ace', 'Original description placed here at the request of the deviser.

1-2::

  1st and 4th couples cross giving right hands as 2nd and 3rd couples set.

3-6::

  1st and 4th couples cast up or down one place face their partners and dance towards them pulling back right shoulder to end back to back with partners (1st and 4th men facing the ladies’ side, and 1St and 4th ladies facing the mens’ side with near hands joined), as 2nd and 3rd couples, taking two hands, turn moving up or down one place (3rd couple ends in 4th place, 2nd couple ends in 1st place on own sides).

7-8::    All set (2nd and 3rd couples face their partners, 1st and 4th couples face the sidelines).





Sleepwalking figure [16 bars]:

9-10::    1st and 4th couples face the corner nearest them and change places with them giving the convenient hand (left hands for 1st man and 4th lady with 2nd lady and 3rd man, right for the others).

11-12::

  2nd and 3rd couples in the middle circle halfway around to the left, as 1st and 4th couples dance towards their partners then dance up or down towards the center of the set. (To finish the circle 2nd and 3rd couples pull back right shoulder to end on the sidelines facing out)

13-14::

  2nd and 3rd couples cast one place up or down to end in the corner position nearest them as 1st and 4th couples circle half way around to the left and pull back right  shoulders to end facing corners.

15-16::

  All set facing diagonally.

17-24::

  Repeat bars 9-16, but on the last 2 bars of the phrase, instead of setting to corners 1st and 4th couples dance out to sidelines on opposite sides pulling back right shoulder (1st couple ends in 2nd place, 4th couple ends in 3rd place).

25-28::

  1st and 4th couples dance half rights and lefts.

29-32::

  1st and 4th couples taking two hands turn twice around.

', 5);
INSERT INTO 'dancecrib' VALUES (12245, '2019-09-24 14:49:18.28474+00', '2019-09-24 15:34:15.133977+00', 19558, 1, 202, 'ace', '1--::
  1c set advancing LSh to P to 1plx facing out | 1c turn 2c EH ½ (to 2,1x,3) ; 1c+2c ½ DblFig8, 1c crossing up (2x,1,3)
9--::
  1c set advancing LSh to P and face 1cnrs[pos] | turn 1cnrs[pos] BH and face 1cnrs[pos] ; 1c dance RSh round 1cnrs[pos] into lines3 across _while{4}_ cnrs on 1diag dance in, turn BH to places
17--::
  1c repeat [9-16] with 2cnrs[pos] (2x,1x,3)
25--::
  2c+1c set | cross P RH ; 1c+3c Circle4 L', 2);
INSERT INTO 'dancecrib' VALUES (12249, '2019-09-26 21:41:35.642876+00', '2019-09-26 21:46:08.534411+00', 8050, 1, 202, 'ace', '1--::

  1M+3W A&R ; turn RH (1,2,3)

9--::

  1W+3M A&R ; turn LH (1,2,3)

17--::

  1c cross RH | cast off 2 places (2c+3c up) ; 1c ½ Fig8 down round 3c (2,3,1)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (12510, '2020-01-15 02:05:54.683631+00', '2020-01-15 02:05:54.683631+00', 8724, 1, NULL, 'ace', '1--::

  1c cross RH | cast (2c up) ; 1c ½ Fig8 round 2c (2,1x,3)

9--::

  2c+1W & 1M+3c RHA ; 1c dance Rsh round 1cnr and pass P Rsh in middle

17--::

  2c+1M & 1W+3c LHA ; 1c dance Lsh round 2cnr and pass P Lsh in middle

25--::

  All M & All W RHA ; 1c turn P LH to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (4517, '2013-08-21 08:30:50.003216+00', '2023-02-21 13:05:33.345697+00', 954, 3, NULL, 'ace', '1-8::

    1L followed by partner dances a Fig of 8 round 2M+3M (LSh to 3M to

    start)

9-16::

    1s+2s dance RH across & LH back

17-24::

    1M followed by partner dances a Fig of 8 round 2L+3L (RSh to 3L to

    start)

25-32::

    1s+2s Set & Rotate :

::

    Set (facing diagonally opp dancer), rotate singly & dance on 1 place

    clockwise, change places RH on sides & dance on 1 place to own sides

    (1s in 2nd pl)', 0);
INSERT INTO 'dancecrib' VALUES (12247, '2019-09-25 08:29:50.71333+00', '2019-09-25 08:33:46.015628+00', 11716, 1, 202, 'ace', '1--::

  Circle8 and back

9--::

  All turn P RH ; LH

17--::

  1c+4c in promhold dance RSH round each other to exchanged places ; 2c+3c repeat [17-20] (4,3,2,1)

25--::

  2c+4c repeat [17-20] ; all set to P | all turn P RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (1828, '2012-01-22 19:29:04.558968+00', '2020-04-21 16:33:18.439358+00', 769, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; ½ Fig8 to R around 1cnr (to 2,1x,3)

9–::

  ½Reel3 on sides (Rsh to 2cnr) ; ½Reel3 across (Lsh to 3cnr position), finish on sides (3x,1,2x)

17–::

  1c turn ¾ LH, Turn 1cnr person (3cnr position) RH ; pass Rsh, turn 2cnr person (4cnr position) ¾ RH to promhold (cnr on the right)

25–::

  These pairs change places Rsh | drop LH and turn RH ½  to sidelines ; half diagonal R&L (1st diagonal direction)



{{explanation}}

Note: [27-28] was originally 2 PdB in promhold. ', 4);
INSERT INTO 'dancecrib' VALUES (2555, '2012-01-22 19:29:47.476276+00', '2020-05-15 14:57:09.867466+00', 3422, 1, NULL, 'ace', '1–::

  1c+3c+5c cross RH | cast off one (2c+4c+6c up) ; 1c+3c+5c ½ Fig8 L (round 4cnr, M down, W up, pass Lsh between middle two couples) _while{4}_ 2c+4c+6c+7c set and cross RH. 1c+3c+5c finish Rsh to P facing 2cnr positions

9-24::

  Four ½diag Reels4, dancing couples (1c+3c+5c) passing P Rsh in the middle, and finish on midline facing P, M above W (7,1,6,3,4,5,2)

25–::

  1c+3c+5c turn ¾ RH and face up in the middle | lead to the top and cast off to 6pl, 4pl, 2pl (7,5,6,3,4,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (12248, '2019-09-26 07:59:30.1734+00', '2019-09-27 22:24:04.232883+00', 18881, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c in and down (1,2,3)

9--::

  All set | all turn P BH ; 1M casts 2 places (2M+3M up) | all set (2,3,1 on Mside, 1,2,3 on Wside)

17--::

  3C Knot with opposite person (1,3,2 on Mside, 3,2,1 on Wside)

25--::

  3C Bourrel (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10710, '2018-04-29 22:56:49.761763+00', '2019-09-08 10:58:35.153444+00', 17123, 1, 202, 'ace', '1--::
  1c & 4c turn RH | cast inwards (2c & 3c step out) ; 1c+4c LHA and face dn/up (2,1,4,3)
9--::
  2c+1c+4c Gr-Chain, 1c cross to start, 1W omits polite turn
17--::
  1c+4c+3c Parallel Reels3 on sidelines, 1c start Rsh to 4c
25--::
  1c+4c set | ¾ R&L (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2628, '2012-01-22 19:29:50.647388+00', '2015-09-28 20:10:51.495498+00', 14364, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; ½ Fig8 up (2,1,3)

9–::

  S&Link3 ; Repeat, but on [15-16] 1c cast to 2plx _while{2}_ 2M+3W (»left-enders«) turn LH ¾ to midline facing ends _while{2}_ 3M+2W (»right-enders«) cast to form line of 4 on midline, 3M facing 2M (above) and 3W facing 2W (below)

17–::

  »Weasel Reel4«: 3M+2W dance normal Reel4 _while{8}_ 2M+3W dance reel {2}| chase clw half round {4}| Dance reel {2} _while{8}_ 1c chase clw ¼ | join in reel {4} | chase clw ¼ , all finish in the starting places

25-30::

  3M+2M & 3W+2W turn ½ RH to face the other | set 3M+2W (»the middles«) changing places as in DTr ; 2c+3c petronella turn to sidelines {2} _while{8}_ 1c chase clw to 2pl, passing between the setting Cs {6}, (to 2,1,3)

31-32::

  All set', 3);
INSERT INTO 'dancecrib' VALUES (11558, '2019-02-02 20:00:17.512901+00', '2019-02-02 20:03:26.244763+00', 1784, 1, 202, 'ace', '1--::

  1c set | ½ Fig8 round 2c | cross down into DTr[pos] facing own sides (2c up)

9--::

  All set as in DTr | 1c turn 3cnrs RH into facing lines3 across ; ½ Reel4 on 1diag (RSh to 1cnrs) into DTr[pos] facing opp sides

17--::

  All set as in DTr | 1c turn 2cnrs LH into facing lines3 across ; ½ Reel4 on 2diag (LSh to 4cnrs) to 2plx facing out (3x,1x,2x)

25--::

  ½ Reels3 on sides, 1c LSh to 2cnrs[pos] (to 2x,1x,3x) ; all set |cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12798, '2020-05-06 22:30:58.060166+00', '2021-05-21 05:05:43.972263+00', 19923, 1, 202, 'ace', '1--::

  1c+2c »Modified Helix« [: Both couples set passing LSh to BtoB | cast R to original places ; ½ RHA | cross RH] (2,1,3)

9--::

  1c+3c repeat [1-8] (2,3,1)

17--::

  1c dance up to 2pl (3c cast off to 3pl) | 1c set ; ½ reels3 across, 1c LSh to 1cnrs (2x,1x,3x)

25--::

  ½ reels3 on sides, 1c RSh to 2cnrs[pos] (to 3x,1x,2x) ; all chase clw ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1659, '2012-01-22 19:28:53.490537+00', '2021-12-18 14:24:45.494787+00', 153, 1, NULL, 'ace', '{{explanation}}

When setting in the centre, the turn is on the second PdB



1–::

  2c+3c (called »centres«) dance in and face diagonally in | set NHJ with turn R to face 1c+4c (= »cnrs«) ; all pass Rsh and face in diagonally | all set, cnrs swiveling R to face out

9–::

  All pass Rsh and face in diagonally | all set, centres turning R about ; cnrs turn centres RH

17-32::

  Centres LHA to face own cnrs again ; intersecting diagonal Reels4{12} (use ½ LHA in {2} to pass in the middle)

33–::

  Centres change places with P LH (2W & 3M polite turn) to face new cnrs, set to cnrs ; turn that cnr by outside hand (centres pass through top/bottom of the set) back to centre facing each other diagonally

41–::

  Centres set and 4 spring points ; repeat

49–::

  Centres dance (NHJ) out at own ends and cast round to centre again facing diagonally in ; set and 4 points

57–::

  Centres dance (NHJ) out at opposite ends (3c make arch for 2c) | cast L (NHJ) (2c round 4W and 3c round 1M), and on to own end of set (cnrs step in to centre places, to order 2,1,4,3)



{{explanation}}

Repeat once with new centres and cnrs  

In some areas the inner dancers who pass to corners stay facing out, and swivel to face inwards during the setting.', 3);
INSERT INTO 'dancecrib' VALUES (12797, '2020-05-06 19:39:14.767001+00', '2020-05-06 19:39:14.767001+00', 19957, 2, 13458, 'ace', '1-8:: 1s + 2s dance the Knot for 6 bars. 2s continue to the side while 1s retain left-hand hold and turn to end facing up. 1M on the left of 1L

9-16:: 1s cross up and cast round the 2s, cross down below the 3s giving left hand and end in the centre of the dance facing up.  2s + 3s join in above and below the 1s, all in Promenade hold

17-24:: 2s + 1s + 3s dance the modified Promenade:

17-20:: as in normal Promenade facing down on the men’s side
21-22:: 2s + 1s + 3s ¼ turn into a line on the men’s side, as in an Allemande, dance into the middle and M bring partners in front   
23-24:: all let go of hands. 1s retire to own side while 2s and 3s pass by the right to opposite side, 3x 1 2x

25-32:: 3L + 2M cross by the right diagonally and turn 1s by the left. 3M + 2L cross by the left diagonally and turn 1s by the right, ending in 2, 1, 3

', 3);
INSERT INTO 'dancecrib' VALUES (2790, '2012-01-22 19:29:57.506569+00', '2020-12-13 11:54:58.985719+00', 4404, 1, NULL, 'ace', '1–::

  1c+2c+3c set | cross RH ; Set | 1c+3c turn P RH ¾ _while{2}_ 2c cross RH to 2pl

9–::

  1c+3c Reel4 on the midline, at the end 1W+3M take LH in passing and begin to turn _while_ 1M+3W return to places

17–::

  1W+3M turn to face own sides | both cast L (1W round 2W and 3M round 2M) to own places ; 1c+2c+3c turn LH into:

25–::

  1c+2c Poussette. (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14461, '2021-11-22 18:04:07.407062+00', '2021-11-22 18:04:20.287849+00', 20560, 1, 1645, 'ace', '1--::

  1c &frac12; Fig8 ; spiral 1&frac12; times RSh round P moving down 1pl (2c up on [7-8])

9--::

  2c+1c Slip Knot: 6 bars of 2C Knot | &frac12; LHA (2,1)

17--::

  2c+1c S&Link ; RHA (1,2)

25--::

  1c+2c Allemande (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11344, '2018-11-18 20:19:44.169647+00', '2018-11-19 23:36:23.25098+00', 19055, 1, 1645, 'ace', '1-::

  1c+2c & 3c+4c starting from sides pass P RSh into &frac34; reels4 on 1cnr diagonal | 1W, 2M, 3W & 4M cross to opp side _while_ 1M+2W & 3M+4W turn &frac34; LH to face P

9-::

  1c+2c & 3c+4c &frac34; reels4 on 2cnr diagonal | 1W, 2M, 3W, 4M (original ends) complete reels _while_ 1M, 2W, 3M & 4W cast R (2x,1x,4x,3x)

17-::

  1c+4c+3c set & rotate (2x,3x,4x,1x)

25-::

  All set | &frac12; turn RH & face P | cast away to own side | set (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (2526, '2012-01-22 19:29:46.294879+00', '2018-11-20 03:50:09.674779+00', 3326, 1, NULL, 'ace', '1-16::

  4 progressive ½Reels3 across, as follows: 1c+2W (1c start Rsh to P) ; 1c+2M (start Lsh) ; 1c+3W (Rsh) ; 1c+3M (Lsh), 1c finish in 3pl a bit in from the sidelines (2c & 3c finish their reels in 1plx and 2plx)

17–::

  1c turn RH, cast up one place on own sides (3c down) ; 1c ½ Fig8 round 2c (2x,1x,3x)

25–::

  All turn P ¾ RH to face P along the midline | All Set retaining RHJ ; all turn P ¾ RH | All Set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11607, '2019-02-25 13:03:56.246486+00', '2021-02-20 13:14:09.613387+00', 19201, 1, 202, 'ace', '1--::

  1c cross down RH (2c up) | dance RSh round 1cnr into lines3 across ; all set | 2c & 3c cross RH _while{2}_ 1c turn RH to face 1cnrs[pos] (3,1,2)

9--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag to 2plx (2x,1x,3x)

17--::

  All A&R ; all set | 3c cross RH _while{2}_ 2c+1c ½ RHA ready for (1,2,3)

25--::

  Allepousse [: 1c dance as 2C Allemande _while{8}_ 2c dance as 2C Poussette] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2696, '2012-01-22 19:29:53.477344+00', '2018-11-20 23:12:28.713704+00', 3923, 1, NULL, 'ace', '1–::

  All circle8 and back

9–::

  All A&R ; A&R

17–::

  1c+2c & 3c+4c RHA ; LHA

25–::

  1c turn RH and face down, the others step in on [28] and form arches ; 1c lead under arches to 4pl, 2c+3c+4c retiring to sidelines one place up on [32] (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12073, '2019-08-30 09:53:53.714305+00', '2023-02-21 13:16:58.166551+00', 850, 3, NULL, 'ace', '1-8::

    1M+2L set & change places RH; 1L+2M set & change places RH

9-16::

    Reels of 3 on sides, 2s cross down, 1s out/up &  3s in/up to start.

    End 2s in 1st place own side, 1s in 2nd place opp sides, 3s in

    original places

17-24::

    1M casts behind 3L, dances up middle approaches 1L & pulls back RSh,

    dances down, casts up round 3M to 2nd place own side _while_ 1L

    dances similar, casting up round 2M, down middle, pulls back RSh,

    dances up, casts off round 2L to 2nd place own side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14751, '2022-04-10 02:14:23.65048+00', '2022-04-10 02:18:46.100087+00', 4652, 1, 202, 'ace', '1--::

  1c+2c set | 1c cross down RH to 2pl (2c up) ; 1c+3c turn EH on sides (2,1x,3)

9--::

  Mirror Reels3 on sides. On [11-12] 1c cross down to 2pl (2,1,3)

17--::

  1c+3c Chain Progression (2,3,1)

25--::

  All set | turn P RH 1¼ to midline | Petronella turn (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11347, '2018-11-24 05:07:36.497768+00', '2018-11-24 05:13:31.693706+00', 17536, 1, 202, 'ace', '1--::

  1c lead down and up | cross to 1plx and face down, 2c face up (1,2,3)

9--::

  1c & 2c set | change places EH, 1c starting outwards ; 1c turn LH ¾ into lines3 across and face 1cnrs

17--::

  Reels3 across, 1c LSh to 1cnrs, 2c & 3c giving hands when possible (2,1,3)

25--::

   Circle6 L {3}, cross R foot over and pivot L ; chase cclw to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12251, '2019-09-27 23:52:35.363291+00', '2019-09-27 23:56:26.817124+00', 18865, 1, 202, 'ace', '1--::
  All turn P RH ½, face each other | cast R to exchanged places ; repeat [1-4] (1,2,3,4)
9--::
  1M+3W & 2M+4W set | cross RH ; 1W+3M & 2W+4M set | cross LH (3x,4x,1x,2x)
17--::
  All turn P BH and chase clw ½ (2,1,4,3)
25--::
  1c+4c The Knot (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12252, '2019-09-28 20:50:44.370005+00', '2019-09-28 21:07:43.27958+00', 19682, 1, NULL, 'ace', '1--::

  Mirror reels3 on the sides 1c starts in and down (1,2,3)

9--::

  1M+2W turn RH ¾ and join hands in diagonal line | middles turn ends LH ½ ; 1W+2M turn RH 1¼ (to 2x,1x,3) | 2c set as 1c sets adv. to 1cnr

17--::

  1c+1cnrs Cnrs Chain, finish facing 2cnr

25--::

  1c+2cnrs Cnrs Chain, finish (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12253, '2019-09-28 22:29:36.436011+00', '2019-09-28 22:29:36.436011+00', 19684, 1, NULL, 'ace', '1--::

  1c set, 1W advancing and 1M pivots R | 1M+1W following cast off one to midline in 2pl, 1W above 1M (2c up) ; Mirror ½ Reels3 across, 1c start between 2W and 3W and finish facing M side 

9--::

  2c+1W RHA _while{4}_ 1M+3c LHA ; repeat the wheels, each pair (1W/1M, 2M/3M, 2W/3W) when meeting changes into the opposite wheel, finish (3x,1,2x) with 1W (with 1M behind) facing 3W (in 1Mpl)

17--::

  2W+1c+2M ½ Rsh lead-change Reel3 on 1diag, and 1c (1M leading) facing 2W ; 3M+1c+3W ½ Rsh lead-change Reel3 on 2diag (2,1,3) 

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2690, '2012-01-22 19:29:53.235574+00', '2016-10-04 22:52:41.529669+00', 8992, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  1c lead down the middle and up to face 1cnrs _while{8}_ 2c keeping in line with 1c, cast off {4}, turn inwards and dance up to 1pl

9–::

  1c set to 1cnr | P | 2cnr | turn to promhold as 3c+4c step in

17–::

  1c+3c+4c promenade, at end 1c face out, 4c in middle

25–::

  1c+4c ¾ DblFig8, 4c crossing up LH | 4c cast off one _while{2}_ 3c step up _while{2}_ 1c cross RH (2,3,4,1)



{{explanation}}

Repeat 3 times from progressed positions  

Repeat [1-128] in Reel time', 3);
INSERT INTO 'dancecrib' VALUES (12255, '2019-09-29 09:22:26.577779+00', '2019-09-29 09:38:16.757166+00', 9499, 1, NULL, 'ace', '1--::

  1c+2c RHA ; LHA, 1M faces out

9--::

  1c pivot R and cast off on W side, 1W leading, to 2plx (2c up) ; 1c turn RH 1¾ into promhold facing W side _while{4}_ 2c+3c chase clw ½

17--::

  1c (promhold) +3W+2M ½ Rsh Reel3 on 1diag ; 3M+2W dance track of ½ Reel3 on 2diag _while{4}_ 1c dance to top, cross and cast to 2plx (2,1x,3)

25--::

  1c ½ Fig8 L (round 4cnr) ; All turn P RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11559, '2019-02-03 00:15:24.792649+00', '2019-02-03 06:59:17.793805+00', 3241, 1, 202, 'ace', '1--::
  1c+2c »Progressive DblFig8« [1c cross, cast ; cross up, cast while{8} 2c set, cross up, cast, cross up]  _while{8}_ 3c+4c »Reverse Progressive DblFig8« [4c cross, cast ; cross down, cast while{8} 3c set, cross down, cast, cross down] (2,1,4,3)
9--::
  1c+4c The Tournée into Reel4[pos] (2,4,1,3)
17--::
  All set on sides | turn facing person RH ; 4c & 1c set on sides | turn facing person LH into Reel4[pos] (2,4,1,3)
25--::
  Reels4 on sides (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11800, '2019-04-22 14:42:30.907251+00', '2019-04-22 15:05:52.510267+00', 19276, 1, NULL, 'ace', '1--::

  1c+3c lead down (2c+4c up) ; change sides (M below W, W passing under joined arms) and lead up to face 2W / 4W 

9--::

  1c+3c in promhold (W on the L)  2cnrs Pass & Turn, and face 2M / 4M ; 1c+3c 1cnrs Pass & Turn 

17--::

  1c+3c (W on L) dance down between 3pl/5pl | cast up ; dance between 1pl/3pl | cast off (2,1,4,3,5)

25--::

  2c+1W & 1M+4c+3W & 3M+5c RHA ; 1c+3c turn LH ¾ and cast off (4c+5c up) (2,4,1,5,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12799, '2020-05-07 08:26:35.722726+00', '2020-05-07 08:34:38.020869+00', 12052, 1, 202, 'ace', '1--::

  All set | 1c & 4c cast inwards (2c & 3c step out) ; 2c+1c & 4c+3c RHA, ending in reel4 position on sides (2,1,4,3)

9--::

  Reels4 (2,1,4,3)

17--::

  All set | 3c cast up to 1pl _while{4}_ 2c,1c & 4c turn P BH to next place down | all set, advancing into centre on last set NHJ ready for (3,2,1,4)

25--::

  3c+2c & 1c+4c the Rondel (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12258, '2019-09-30 01:09:44.934781+00', '2022-08-15 13:29:37.044278+00', 19686, 1, 202, 'ace', '*3c & 4c start on opposite sides*

1--::

  1c & 4c long cast inwards (2c & 3c step out) ; 1M+4W in promhold + 3c & 1W+4M in promhold +2c ½ LSh Reels across

9--::

  1M+4W & 1W+4M ½ RSh Reels3 on Wside/Mside (to 3,4,1x,2x) ; all turn P RH (3,4,1x,2x)

17-32::

  All repeat [1-16] from new positions (1,2,3x,4x)

33--::

  1c & 4c chase clw ½ (to 4,2,3x,1x) ; 4M+2M &  4W+2W & 3M+1M & 3W+1W turn RH 1½ (2,4,1x,3x)

41--::

  Circle8 and back', 4);
INSERT INTO 'dancecrib' VALUES (11798, '2019-04-21 12:58:15.263783+00', '2019-04-22 15:16:55.538976+00', 18282, 1, NULL, 'ace', '1--::

  Circle8 and back

9--::

  1c+3c R&L

17--::

  2c+4c R&L

25--::

  1c+3c turn P RH, and, M leading pass through side couple on the R and cast clw to place

33--::

  2c+4c turn P LH, and, W leading pass through head couple on the L and cast cclw to place

41--::

  All W RHA ; all M LHA

49--::

  1c+3c La-Chain

57--::

  2c+4c M-Chain

65--::

  Gr-Chain (face P, 1 bar/hand) 

73--::

  All in promhold dance once round, finish W BtoB in centre

', 3);
INSERT INTO 'dancecrib' VALUES (2801, '2012-01-22 19:29:57.969221+00', '2020-12-12 10:53:32.892589+00', 4444, 1, NULL, 'ace', '1–::

  1c lead down, cross below 3c, cast up (2c up) ; turn BH 1½ _while{4}_ 2c+3c turn BH

9–::

  1c dance up | set ; dance down | turn BH to 1cnrs

17–::

  1c set to 1cnr, travel Rsh round P to face 2cnr ; set to 2cnr, travel Rsh round P to finish 1W facing up, 1M facing down

25–::

  Opposing ½Reels3{6} across, Rsh to 4cnr, repeat with other end couple (Rsh to 2cnr position, i.e. 1c makes »the loop«) | 1c cross RH', 2);
INSERT INTO 'dancecrib' VALUES (12256, '2019-09-30 00:09:31.236363+00', '2019-09-30 00:09:45.952801+00', 19144, 1, 202, 'ace', '1--::

  1W (2W following) dance RSh to 1M, across the set and down Wside ; 1c+2c RHA

9--::

  1M (2M following) dance LSh to 2W, across the set and down Mside ; 2c+1c LHA. 1c face down (2,1,3)

17--::

  Parallel Reels3, 1c RSh to 3c. 1W faces out (2,1,3)

25--::

  1W (1M following) dance RSh round 3W, up on midline, LSh to 2M and cast off to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12257, '2019-09-30 00:21:36.156496+00', '2019-09-30 00:24:51.51289+00', 16288, 1, 202, 'ace', '1--::

  2C Knot (2,1,3)

9--::

  All set | 1c turn BH and face out ; 1W turn 3W RH ½ | 3W turn 2W ½ _while{4}_ 1M turn 2M RH ½ | 2M turn 3M ½ (3,2,1 on Wside, 1,3,2 on Mside)

17--::

  3C Bourrel (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (7854, '2013-08-21 08:31:49.833467+00', '2023-02-04 01:23:06.734828+00', 10304, 3, NULL, 'ace', '1-8::
    1L+2L also 3L+4L cross between ptnrs & change places on opp sides
    _while_ ptnrs cross & set, repeat with Men crossing between ptnrs.
    2 1 4 3
9-16::
    All RSh reel of 4 on sides
17-24::
    1s+4s Set+Link to face end person & dance Grand Chain 1/2 way.  3 1
    4 2 (all on opp sides)
25-32::
    All 1/2 reel of 4 on sides, 1/2 turn partners RH & twirl to places.
    2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12254, '2019-09-28 23:40:15.025034+00', '2019-10-20 22:25:28.543983+00', 19685, 1, NULL, 'ace', '1--::

  1W+3W advance | 1c+3c set ; 1W+3W cast R to own place | 1c+3c set  

9--::

  2M+4M advance | 2c+4c set ; 2M+4M cast R to own place | 2c+4c set

17--::

  Rsh Reels4 on both sidelines (1,2,3,4)

25--::

  1c change places RH with 2c | 1c+3c repeat LH ; 1+4c repeat RH | All set', 3);
INSERT INTO 'dancecrib' VALUES (7909, '2013-08-21 08:31:51.20585+00', '2023-02-04 01:23:11.444593+00', 13068, 3, NULL, 'ace', '1-8::
    1s cross down to dance reels of 3 on opposite sides ending in 1st
    place opposite sides
9-16::
    1s dance down the middle, 1L turns under partners arm to change
    places & 1s dance up to original places
17-20::
    1s cast 1 place & all set
21-32::
    All dance 3 couple R&L', 0);
INSERT INTO 'dancecrib' VALUES (11348, '2018-11-24 12:59:04.132416+00', '2019-09-08 10:59:26.46045+00', 17530, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opp side (1,2,3x,4x)*
1--::
  All set | cross RH. 1c & 3c face down, 2c & 4c face up ; all set | change places LH on sides (2x,1x,4,3)
9--::
  All set | cross RH. 1c & 4c face on sides ; 1c+4c set | change places LH on sides into Reel4 position (2,4x,1,3x)
17--::
  Reels4. On [24], 1c & 4c pass RSh (2,4x,1,3x)
25--::
  All set | 2c & 3c (W leading) chase clw to exchanged places _while{6}_ 4c+1c ¾ R&L (3,1,4x,2x)', 2);
INSERT INTO 'dancecrib' VALUES (11560, '2019-02-03 07:37:37.632196+00', '2019-02-03 07:46:43.186773+00', 2797, 1, 202, 'ace', '1--::
  1c & 4c cross RH | set _while{4}_ 2c & 3c set | ½ RHA (to 1x,3x,2x,4x) ; 1c & 4c cross LH | set _while{4}_ 2c & 3c set | ½ LHA (1,2,3,4)
9--::
  1c+2c & 3c+4c »Progressive DblFig8« [1c(3c) cross, cast ; cross up, cast while{8} 2c(4c) set, cross up, cast, cross up] (2,1,4,3)
17--::
  1c+4c ½ RHA ; 4c & 1c cross RH | set into Reel4[pos] (2,4,1,3)
25--::
  Reels4 on sides (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14343, '2021-10-02 20:22:59.849292+00', '2021-10-02 20:26:11.53068+00', 20498, 1, 202, 'ace', '1--::
  1c set | cast off (2c up) ; 1c dance down between 3c | cast up to 2pl centre into promhold. On [8] 2c & 3c step up into promhold, all facing up (2,1,3)
9--::
  3C Allemande. On [15-16] all set facing up NHJ (3,1,2)
17--::
  3c+1c+2c dance up and cast off ; all turn P RH (2,1,3)
25--::
  Circle6 and back

*Deviser''s note*. Bars 15-16: Possibilities could include man turning woman under his right – or maybe left – arm, or both turning about, right or left, whatever, or just setting in place, or whatever twiddling suits your fancy, Just do it in two bars.', 2);
INSERT INTO 'dancecrib' VALUES (2016, '2012-01-22 19:29:15.1069+00', '2018-11-24 21:01:32.117875+00', 8165, 1, NULL, 'ace', '1–::

  1c cross down into Mirror Reels3 on opposite sides with 2c+3c, 1c finish in promhold facing down between 2c in 1pl

9–::

  1c+2M+2W Reel3 across (Rsh to 2M) (at end 1c start downwards)

17–::

  1c (promhold) dance between 3c, cross LH and cast up to 2pl ; turn RH and face out (see note)

25–::

  2c & 3c petronella {8} _while_ 1c casts R (1M up, 1W down) | cross between setting end couples ; cast to 2plx | set (all together) (2x,1x,3x)



{{explanation}}

The set is now inverted ; repeat using the bottom (3c) as new top. In 6 times through each couple dances once as 1c from »each hemisphere«.  

Note: On [24], some dancing couples choose to face in after the RH turn and then cast into the next figure.', 3);
INSERT INTO 'dancecrib' VALUES (10663, '2018-04-21 10:04:39.721823+00', '2018-11-25 13:19:41.211096+00', 2671, 1, NULL, 'ace', '1-::

  1c &amp; 2c cross RH | &frac12; Circle4 to L ; cross LH | &frac12; Circle4 to R (1,2,3,4)

9-::

  1c+2c R&amp;L _while{8}_ 3c &amp; 4c dance [1-8]

17-::

  1c &amp; 3c cross RH | 1c+2c &amp; 3c+4c &frac12; Circle4 to L ; all &frac12; GrChain, 2c &amp; 3c cross to start (3x,4,1x,2)

25-::

  1c &amp; 4c change pl RH | 1c &amp; 4c &frac12; Circle4 to L _while{2}_ 2c &amp; 3c cross RH ; all &frac12; Circle8 to L (2,1x,4,3x)

33-::

  1M &amp; 2M also 3M &amp; 4M set to each other _while{2}_ 1W+2W also 3W+4W cross RH diagonally | 1c+2c also 3c+4c &frac12; Circle4 to L ;

  repeat with M crossing LH as W set &amp; &frac12; Circle4 to R (1,2x,3,4x)

41-::

  1c &amp; 3c set | cross RH _while{4}_ 2c &amp; 3c turn RH ; all &frac12; Circle8 to L (4,3,2,1)



*Repeat once*', 4);
INSERT INTO 'dancecrib' VALUES (12264, '2019-10-02 12:26:52.290075+00', '2019-10-02 15:11:20.118947+00', 15234, 1, NULL, 'ace', '1--::

  1c set | cast to face 1cnr (2c up) ; 1c set to and turn 1cnr RH, 1c face 2cnrs  

9--::

  1c set to and turn 2cnrs LH, into Lines of 3 across ; S&Link3 (2x,1x,3x)

17--::

  Reels3{6} on the sides, 1c Lsh to 1cnr | 1c turn P RH 1¼ 

25--::

  1c set to and turn 4cnr LH into lines across ; S&Link3 (2,1,3)

33--::

  1c ½ Fig8 L ; 1cross RH | cast off (3c up) (2,3,1)

41--::

  Circle6 and back (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10579, '2018-04-04 09:21:55.310402+00', '2018-04-04 12:04:16.723147+00', 13905, 1, 202, 'ace', '1--::
  1c ½ Fig8 round 2c ; 2c step up as 1c turn BH to face P between them in line of 4 across | 1c & 2c set, 1c advancing and passing Lsh
9--::
  Reel4 across to sidelines (2,1)
17--::
  2c+1c Slip Knot (2,1)
25--::
  1c set | cross RH ; cast up round 2c | cross to 2pl (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (11805, '2019-04-24 23:05:02.435631+00', '2019-04-24 23:12:43.356924+00', 19234, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c & 5c+6c R&L

9--::

  1c cast to bottom and turn P RH _while{8}_ 2c dance down and up to 1pl (others up on [3-4]) (2,3,4,5,6,1)

17--::

  Repeat [9-16] from new places (3,4,5,6,1,2)

25--::

  3c+4c & 5c+6c & 1c+2c RHA ;  LHA (3,4,5,6,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (2802, '2012-01-22 19:29:58.018816+00', '2020-12-12 10:56:00.53772+00', 4447, 1, NULL, 'ace', '1–::

  1c+2c ½ R&L ; 1c turn RH into the middle _while{2}_ 2c cross RH and swivel R to join LH with 1c (M face down, W up) | BiL across, W swiveling R on [8] to face down

9–::

  In line across dance down the middle and up, 2c to 1pl, 1c to BtB between them

17–::

  Reel4 across, 1c finish facing 1cnr

25–::

  Turn CPCP (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12260, '2019-09-30 09:22:28.989667+00', '2019-09-30 18:25:50.635856+00', 18471, 1, 202, 'ace', '1--::

  1M+3W & 1W+3M Fig8 round 2c /4c (W crossing in front of M), to own places (1,2,3,4)

9--::

  2c & 4c repeat [1-8] (1,2,3,4)

17--::

  1c+3c turn opposite person RH ½, face that person | cast R to exchanged places ; 2c+4c repeat [17-20]

25--::

  All set to P | turn P RH ½ and face clw ; chase clw ¼ and face in | all NHJ with P set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11561, '2019-02-03 07:51:23.499312+00', '2019-02-03 07:54:21.823268+00', 3851, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; set | cast (3c up) (2,3,1)

9--::

  2c+1c »Progressive DblFig8« [2c cross, cast ; cross up, cast while{8} 1c set, cross up, cast, cross up] (1,3,2)

17--::

  1c cast (3c up) | all set ; all turn P RH into promhold (3,1,2)

25--::

  3C Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3845, '2013-07-13 15:56:21.249835+00', '2018-11-25 22:58:25.136456+00', 9609, 1, NULL, 'ace', '1–::

  1c in promhold+2m+3m & 4c in promhold +3W+2W Lsh Reels3 on the sides, 1c&4c finish in middle at top/bottom

9–::

  1c&4c repeat the reels (now Rsh) on opposite sideline.  Finish 2c at top, 3c at bottom, and in the middle 1c NHJ facing M side BtoB with 4c NHJ facing W side

17–::

  All A{1}&R{1}|  1c+4c chase ½ clw to face other side ; repeat the A{1}&R{1} | 1c+4c chase ¼ clw and stay in middle (2,4,1,3)

25–::

  1c+4c RHA ; LHA  _while_{8}    2c+3c chase clw round the set (2,4,1,3)



{{explanation}}

Note: Both in promhold and when NHJ, 1c has M on the R, 4c has M on the L.', 2);
INSERT INTO 'dancecrib' VALUES (10711, '2018-04-29 23:15:44.541156+00', '2019-09-08 11:00:28.571259+00', 17124, 1, 202, 'ace', '1--::
  1c turn RH | cast (2c up) ; 1c turn LH 1¼
9--::
  1W+2c & 1M+3c RHA, 1c face 3cnrs ; 2c+1c+3c ½ Reels3 on sidelines, 1c start Lsh to 3cnrs, ending in centre, Rsh to P facing opposite sides, 3M & 2W facing out (3,1,2)
17--::
  1M+3c & 1W+2c LHA, 1c face 4cnrs, 2c & 3c face out ; 3c+1c+2c ½ Reels3 on sidelines, 1c start Rsh to 4cnrs (2,1,3)
25--::
  1c+3c ¾ R&L | all set (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12261, '2019-10-01 13:23:56.247912+00', '2019-10-01 13:38:10.193463+00', 19688, 1, NULL, 'ace', '1--::

  1c lead down | and up ; cast off (2c up) | 1c+3c set adv. to face up in promhold

9--::

  1c+3c Allemande (2,3,1)

17--::

  2c+1c DblFig8 round 3c, 2c crossing down, at end 1c cross down to 2pl (3c down) (2,1,3)

25--::

  All Circle6 L {3}, pivot L ; and chase back to (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (1900, '2012-01-22 19:29:08.846364+00', '2020-02-08 20:27:40.81261+00', 1001, 1, NULL, 'ace', '{{explanation}}

3c+4c start on opposite sides.  (1,2,3x,4x)



1–::

  1c+4c set and cast in (2c & 3c step to end and become »corners«), 1½ LH turn, finish W facing 1cnr with M behind (1c face 2M, 4c face 3M)

9-24::

  Four ½ Lead-change Reels4 with 1st, 2nd, 3rd, 4th corners in turn, each dancing couple dance as one dancer. Pass Lsh in the middle, at each end loop the other P takes the lead (to 2,1x,4,3x)

25–::

  1c+4c Turn RH ½ flowing into ½RHA ; 2c+4c & 1c+3c LHA (to 2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (11801, '2019-04-22 19:29:59.547078+00', '2019-04-22 19:29:59.547078+00', 15967, 2, NULL, 'ace', '1-8::

  1s & 2s dance the Espagnole to change places, 1s finish facing 1st corners.

9-12::

  1s dance ‘Pass & Turn’ with 1st corners & pass by the L to face 2nd corners. 

13-16::

  1s dance ‘Pass & Turn’ with 2nd corners & pass by the L to face  their partners 1st corners.

17-24::

  1s dance half diagonal reel of 4 with their 1st corners, pass R to dance half diagonal reel of 4 with their partners 2nd corners,   to end 1s in 2nd place own sides, 3s in 1st place opp. sides and 2s in 3rd place opp. sides.

25-32::

  1s cross RH while 2s &3s change places on the sidelines RH.  2s, 1s & 3s set, cross RH and set again.

', 3);
INSERT INTO 'dancecrib' VALUES (11564, '2019-02-03 10:10:16.479819+00', '2020-08-25 19:15:32.965981+00', 14162, 1, 202, 'ace', '1--::

  Reels3 on opp sides, 1c crossing down (1x,2,3,4)

9--::

  3C Pick-up Chain (3,2x,1x,4)

17--::

  2c & 1c ½ Fig8 round ends into Reel4[pos] ; all M set | change places RH _while{4}_ all W set | change places LH, all ending as on [20] (2,3,4,1)

25--::

  Mirror Reels4 on sides, M RSh, W LSh (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12263, '2019-10-02 00:10:43.512945+00', '2019-10-02 00:15:06.891388+00', 19446, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; ½ Fig8 R LSh to 1cnrs (2,1x,3)

9--::

  ½ Reels3 across, 1c LSh to 3cnrs (to 2x,1,3x) ; ½ diagonal R&L, 1c crossing RH with 1cnrs[pos] (3,1x,2)

17--::

  ½ Reels3 across, 1c RSh to 4cnrs[pos] (to 3x,1,2x) ; ½ diagonal R&L, 1c crossing RH with 2cnrs[pos] (2,1x,3)

25--::

  1c dance up to top, cast off round 2c to 1plx ; cross down, cast up round 3c to 1pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11053, '2018-09-01 00:33:56.482059+00', '2018-09-01 00:37:30.446237+00', 14115, 1, 202, 'ace', '1--::

  1c+2c Espagnole, 1M & 2W face out (2,1,3)

9--::

  Reels3 on sidelines, 1M(1W) LSh(RSh) to 4cnrs, 1M & 2W face out (2,1,3)

17--::

  1M turn 3M LH _while{4}_ 1W turn 2W RH ; 1M turn 2M RH _while{4}_ 1W turn 3W LH (2,1,3

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11562, '2019-02-03 10:08:29.705076+00', '2020-08-29 11:47:40.057385+00', 177, 1, 202, 'ace', '1--::

  1c+2c »Progressive DblFig8« [1c cross, cast ; cross up, cast while{8} 2c set, cross up, cast, cross up] (2,1,3)

9--::

  Mirror Reels3 on sides, 1c in and down, 3c out and up. On [16] 1c pass LSh to face 1cnrs

17--::

  1c SetH&G. 1c face 2cnrs

25--::

  Reels3{6} on sides, 1c RSh to 2cnrs | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2804, '2012-01-22 19:29:58.107196+00', '2021-05-08 09:32:20.238022+00', 4455, 1, NULL, 'ace', '1–::

  1c+2c Reel4 on W side (1W+2W pass Lsh as 1M+2M cross to above partner''s place, 1M giving Rsh to 2W and 2M leaving 1W on his right | the M pass Lsh in the middle ; the W pass in the middle | the M cross to own places, 2M passing Lsh in front of 1M)

9–::

  1c+2c Reel4 on M side.  (Same Reel, inverted.  The M pass Lsh to start, the W cross to below partner''s place)

17–::

  1c lead down the middle and up

25–::

  1c+2c Allemande



{{explanation}}

Note: with normal size 4c sets there is no space for both 1c+2c and 3c+4c to dance their reels.  TacTalk 25 #3/4 (March 2001) says »this dance should never be placed on a programme«.  However, if a 3c set is used there is no lack of space', 3);
INSERT INTO 'dancecrib' VALUES (8877, '2015-08-26 22:14:41.3284+00', '2022-04-10 10:59:59.922569+00', 16536, 1, 1041, 'ace', '1--::

  1c+3c ¾ R&L to BtoB facing sides | all set

9--::

  Parallel Reels4 across, 1c+3c only do half the last Lsh pass, to end in a line up and down the set

17--::

  1c+3c Lsh Reel4, 1W+3W pass Rsh in middle to start, to finish in original places

25--::

  All set to P | all turn P RH 1¼ | all in promhold chase cclw ¼ (2,3,4,1)



*The first two turns are in Strathspey time, the second two are in Reel time.*

', 3);
INSERT INTO 'dancecrib' VALUES (14630, '2022-03-02 00:50:39.060178+00', '2022-03-02 00:51:08.42415+00', 7475, 1, 202, 'ace', '1--::

  1c+2c+3c A&R ; turn P RH into promhold facing up (1,2,3,4)

9--::

  3C Promenade (1,2,3,4)

17--::

  1c dance down to 4pl (2c+3c+4c up on [19-20]) ; 1c dance up between 4c and cast off (2,3,4,1)

25--::

  Circle8 and back (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10577, '2018-04-04 00:56:31.58372+00', '2018-04-08 08:22:17.446564+00', 13903, 1, 202, 'ace', '1--::

  All set | Circle6 L ½, 1W facing out at end (to 3x,2x,1x) ; 1W followed by 1M cast up 1 place, dance down ending BtoB with P between 2c, 1W facing 2M (2c down)

9--::

  1c+2c »Isobirl« [All set adv passing Lsh | 1c chase clw ¼ _while{2}_ 2c turn BH ¾ and twirl into midline ; repeat [9-12] into original line of 4 across]

17--::

  1c+2c Reel4 across, 1c finish between 2c on own side LHJ

25--::

  1c lead up LHJ to top, cross and cast to 1plx (3c down) (to 1x,3x,2x) ; all set | Circle6 L ½ (2,3,1) ', 4);
INSERT INTO 'dancecrib' VALUES (12658, '2020-03-09 22:27:19.256618+00', '2020-03-09 22:52:05.755752+00', 19878, 1, NULL, 'ace', '1--::

  1c long cast up (2c up), dance up (no hands), cast off and face 1cnr

9--::

  Corners Pass & Gipsy Turn, at end 1c face out (2,1,3)

17--::

  Reels3 on the sides, 1c Rsh to 3cnr, 1c crossing to other side on [19-20], 1c finish facing 1cnr

25--::

  Set H&G, at end 1c petronella to (2,1,3)





', 3);
INSERT INTO 'dancecrib' VALUES (8147, '2014-01-05 23:57:36.90514+00', '2018-11-26 03:42:14.180003+00', 11360, 1, NULL, 'ace', '1–-::

  1c in promhold promenade clw (passing between the other couples), at end turn ½ RH _while{8}_  

2c Petronella | set ; Petronella | turn RH ¾ _while{8}_  

3c set | Petronella ; set | turn RH ½  

all to own position, the M BtoB in the middle (»insides«), facing the W (»outsides«)  

9-20::

  Clover Leaf Reel6: All pass person opposite Rsh, the »insides« ending »outside«, and the »outsides« ending »inside« facing the next »outside« position to the R. | repeat 5 times. to starting places

21-24::

  All set to P | turn BH ¾ to places (1,2,3)

25–-::

  1c+2c ½ R&L ; 1c+3c ½ R&L (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (9954, '2017-06-12 00:54:19.642639+00', '2019-02-03 21:15:31.871006+00', 7074, 1, 202, 'ace', '1--::

 1c cross RH | cast (2c up) ; ½ Fig8 L (2,1,3)

9--::

 ½ Reels3 across, 1c start Rsh to 2cnrs (to 2x,1x,3x) ; 1c+1cnrs (pos) ½ diag. R&L _while{4}_ 2M+3W (= other cnrs) chase ½ round clw (3,1,2)

17--::

 ½ Reels3 across, 1c start Rsh to 2cnrs pos (to 3x,1x,2x) ; 1c+2cnrs (pos) ½ diag R&L _while{4}_ 3W+2M (= other cnrs) chase ½ round clw (2,1,3)

25--::

 All set | cross RH ; chase clw ½ (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (2824, '2012-01-22 19:29:58.927287+00', '2020-12-13 12:37:27.794526+00', 4552, 1, NULL, 'ace', '1–::

  1c+3c set | turn ¾ RH to midline, moving down ½ place (2c+4c step up ½) ; 1c+3c set | turn RH into

9–::

  2c+1c & 4c+3c RHA ; LHA, on last bar 2c & 4c cast R on own side _while_ 1c & 3c turn on to form line across for

17–::

  Reels4 across, on last 2 bars 1M+2M & 1W+2W & 3M+4M & 3W+4W turn ¾ RH, 2c+3c+4c to places, and 1c to centre RHJ starting down for

25–::

  1c lead to 4pl _while{2}_ others step up, 2c+3c+4c+1c set ; all turn RH', 2);
INSERT INTO 'dancecrib' VALUES (11541, '2019-01-25 16:08:53.138429+00', '2023-02-21 13:26:08.357536+00', 834, 2, 1, 'ace', '1–2::

  1c cross over RS _while_ 2L+3L change pl RH _and_ 2M+3M change pl LH.

3–4::

  1M+3L change pl LH _while_ 1L+3M change pl RH _and_ 2c set to ptr.

5–6::

  1M+2L change pl RH _while_ 1L+2M change pl LH _and_ 3c cross over RS

7–8::

  3M+2L change pl LH _while_ 3L+2M change pl RH _and_ 1c set to ptr.

  [2,3x,1x]

9–12::

  1c (with 2c&3c) dance half Inveran reels starting from 3pl.

13–20::

  Mirror reels of three on the sides (continuing from the Inveran reels)

21–24::

  1c (from 1pl) dance half Inveran reels [2,3x,1x] (During bars 9-24, corners

  effectively dance two reels of three on the sides)

25–::

  1c+3c ½RL ; 1c dance up and cast off to 2pl.', 3);
INSERT INTO 'dancecrib' VALUES (8178, '2014-02-10 10:26:22.258666+00', '2020-02-08 13:20:13.280809+00', 15331, 2, NULL, 'ace', '1–4::

 1M and 2L turn RH once round, back to their places.

5–8::

 1L and 2M turn LH, to finish back to back in the middle, facing their partners.

9–16::

 Diagonal Reel of 4.

17–20::

 1s and 2s change places with their partners giving RH, then 1M and 2L (now in the middle) turn LH ¾, to finish on the sidelines in partner''s place.

21–24::

 1s and 2s set and cross over RH, stay together joining both hands, ready for

25–32::

 Poussette.



*(Dance Crib compiled by the devisor, Hans Prade)*', 5);
INSERT INTO 'dancecrib' VALUES (1896, '2012-01-22 19:29:08.620202+00', '2019-02-03 21:24:21.423205+00', 8104, 1, NULL, 'ace', '*Large circle round the room, M has P on his R* 

1--::

  All circle L and back

9--::

  All M Rsh Fig8 round P and the W to his L

17--::

  All W Lsh Fig8 round P and the M on her R

25--::

  With NHJ in large circle all A&R ;  All advance NHJ | W swivel L and join BH with P, chasing him as he retires to smaller circle (M face in, W out)

33--36::

  All C dance BtoB, men making arches

37--40::

  All look R, join that new partner (with whom they just passed Rsh) and birl, finishing in the large circle.



*(Devisers’ note: as originally published the M moved inside on [29-32].  Then they can’t hold the arches for [33-36])*

', 3);
INSERT INTO 'dancecrib' VALUES (10714, '2018-04-30 06:42:36.466664+00', '2018-09-04 13:20:34.056895+00', 17130, 1, 202, 'ace', '1--::

  1c+2c+3c set | cross RH ; repeat [1-4]

9--::

  1c cross RH | cast (2c up) ; ½ Fig8 up round 2c (2,1,3)

17--::

  1c turn 1cnrs RH, pass P Rsh ; turn 2cnrs RH, pass P Rsh to 2pl (cnrs dance for 2 bars!) (2,1,3)

25--::

  Circle and back', 5);
INSERT INTO 'dancecrib' VALUES (10713, '2018-04-30 06:18:48.171477+00', '2018-04-30 06:23:29.770151+00', 17132, 1, 202, 'ace', '1--::
  1c cross RH | cast (2c up) ; 2c+1c+3c ½ Reels3 on sidelines, 1c start in and down, 2c+3c loop to place (3,1x,2)
9--::
  1c dance down {3}, change sides (W crossing above, under M’s R arm) and face up {2}, dance to 2pl (3,1,2)
17--::
  2c+3c Set&Rotate _while{8}_ 1c set | La Baratte, at end 1c turn LH 1¼ to face 1cnrs (2,1,3)
25--::
  Corners Pass and Turn (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3210, '2012-01-22 19:30:15.830469+00', '2018-04-04 11:10:42.857263+00', 5898, 1, NULL, 'ace', '*Start (1,2,3x,4x). The dance is centro-symmetric.*  

1–::

  1c+4c Petronella to midline _while{2}_ 2c&3c step to ends | 1c+2c & 3c+4c set ; RHA

9–::

  1c+4c ½Reel4 on midline ; pass P Rsh and veer R to | turn cnr person BH into two lines across, 4c & 1c BtoB in the middle facing 2c & 3c respectively

17–::

  ½Reels4 across ; 2c & 3c pass middle person and P Rsh into 1pl & 3pl of a square set, M on the R of W _while{2}_ 1c+4c dance to the side positions of the square, 4W+1M in 2pl, 4M+1W in 4pl (if seen as a longwise set, order 2,4,1x,3x) | all set

25–::

  All C dance in, touch H and swivel R {1} dance out {1} | chase clw into ; ½ circle8 L to form longwise set (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (2889, '2012-01-22 19:30:01.707367+00', '2020-12-13 19:08:51.703264+00', 4827, 1, NULL, 'ace', '1–::

  1c lead down to 3pl, cross and cast to 2pl, _while{4}_ 2c set and cross RH into 3pl, _while{4}_ 3c cast to top and cross RH ; all C set (may advance a bit) and turn BH to own side (3,1,2)

9–::

  Repeat [1-8] from new positions (2,3,1)

17–::

  1c lead to top (2c+3c down) ; 1c set | 1c+2c set advancing

25–::

  1c+2c Poussette (2,1,3).



*Unofficial: On 2nd turn, 4c has an easier next start if 1c+3c+4c dance a 3C Poussette*', 3);
INSERT INTO 'dancecrib' VALUES (3333, '2012-01-22 19:30:20.929622+00', '2020-04-14 21:37:00.711427+00', 6368, 1, NULL, 'ace', '1--::

  1c cross RH | cast off ; cross LH | cast up (1,2)  

9--::

  2c cross LH | cast up (1c down) ; 2c+1c turn P BH (2c 1½ times, 1c once round) to (2,1)  

17--::

  2c+1c Reel4 across the dance, 2W+1M giving Lsh in the middle to start, finish (2,1)  

25--::

  2c+1c ½ RHA | cross RH ; ½ LHA | cross LH (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (2921, '2012-01-22 19:30:03.008745+00', '2020-12-14 09:30:04.06137+00', 4931, 1, NULL, 'ace', '1–::

  1c+3c set and cross over RH, 1c face 2c and 3c face 4c ; all set to the person facing and turn RH

9–::

  Starting with same person, Reels4 on the sides

17–::

  Circle8 and back (1x,2,3x,4)

25–::

  G-Chain (to start 1c+4c cross and 2c face 3c) (1x,2,3x,4)

33–::

  1c turn RH to face 2c _while_ 3c cross RH to own sides | 1c change with 2c LH, with 3c RH, with 4c LH, 1c turn RH 1½  (to 2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11920, '2019-06-28 11:05:31.57252+00', '2020-05-09 07:22:15.023939+00', 14010, 1, 1645, 'ace', '1-::

  1c long cast to 3pl (2c+3c up) (2,3,1)  ; all set | All turn P RH ½ into allemande hold facing down 

9-::

  Inverted 3C allemande, start facing down (1x,3x,2x)

17-::

  1c turn P RH ½ to face 3c ; half spurtle: 1c+3c ½ Reel4 & 1c turn RH½  to face 2c, 3c end in 1pl

25-::

  1c+2c ½ Reel4, 2c end in 3pl ; 1c turn RH (3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (3745, '2013-05-23 12:03:12.954706+00', '2018-11-26 00:29:58.745025+00', 14890, 2, 106, 'ace', 'Original description added at the request of the author

1- 4::

  1st couple turn with the right hand once round

5- 8::

  2nd and 1st couple dance down and round 3rd couple to the top (finish 2-1-3-4)

9-12::

  1st couple turn with the right hand once round

13-16::

  1st and 3rd couple dance up and cast off (finish 2-3-1-4)

17-20::

  All four couples advance and retire

21-24::

  1st and 4th couple dance up and round 3rd couple finish 2-3-4-1)

25-32::

  All four couples dance eight hands round and back

33-40::

  (Solo for the 1st couple Farewell) 1st couple dance behind own line to the top, meet and dance down to the bottom waving good-bye

', 5);
INSERT INTO 'dancecrib' VALUES (11802, '2019-04-22 19:36:29.267982+00', '2019-04-22 19:39:51.384693+00', 15967, 1, NULL, 'ace', '1--::

  1c+2c Espagnole, 1c finish facing 1cnr

9--::

  1c+1cnrs Pass &Turn, 1c pass Lsh ; 1c+2cnrs Pass & Turn, pass Lsh to face 3cnr

17--::

  1c+1cnrs ½ diag. Reel4, pass Rsh ; 1c+2cnrs ½diag Reel4 (3x,1,2x)

25--::

  1c cross RH as 2c+3c change places RH on the sides | All set ; All cross RH | All set



', 2);
INSERT INTO 'dancecrib' VALUES (2967, '2012-01-22 19:30:04.932402+00', '2019-02-03 21:45:47.692306+00', 5093, 1, NULL, 'ace', '{{explanation}}

A new couple starts Part 1 every 32 bars, and dances Part1+Part 2 (= 64 bars); music 5 x 32.  

Part 1  

1-::

  1c cross RH | cast off two (2c up) ; cross RH | cast up to 2pl (2,1,3,4)

9–::

  top two couples RHA ; middle two couples LHA, finish facing nearest end

17–::

  All Reels4 on own sides (2,1,3,4)

25–::

  Top two couples turn RH on side | Mid two couples LHA | 1c cast to 3pl (3c dance up, see Note) (2,3,1,4)



{{explanation}}

At this point 2c start to dance Part 1 from the top and the dance continues as follows:  

Part 2



33–::

  2c dance as [1-8] _while_{8} 1c+4c (bottom couples) R&L (new dancing couple passing through the middle on [5-6] (3,2,1,4)

41–::

  Top two and bottom two couples RHA ; middle two couples LHA

49–::

  All Reels4 on own sides (3,2,1,4)

57–::

  3c+2c & 1c+4c (both end pairs of couples) turn RH on sides | 2c+1c (mid couples) LHA | 2c+1c (mid couples) cast off one as 4c dances up 2 (to 3,4,2,1) (See Note)



{{explanation}}

Repeat Part 2 twice from new positions [65-128].The order is now (1,2,4,3)  

Then dance Part 2 again, but 1c stands in 1pl except for the reels [49-56]  At end 3c dances up one to finish (1,2,3,4)', 3);
INSERT INTO 'dancecrib' VALUES (10715, '2018-04-30 08:41:09.245805+00', '2018-04-30 08:46:18.178985+00', 17127, 1, 202, 'ace', '1--::

  1c dance down, cast off behind 3c ; lead up LH, cross and cast off to 2plx (2c up) (2,1x,3)

9--::

  All set | cross RH ; set | turn RH ½ into allemande hold, 2c & 3c facing up, 1c facing down

17--::

  Circulating Allemande. On [23-24], 1c turn LH to face 1cnrs[pos] (3,1,2)

25--::

  Corners Pass and Turn (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (10718, '2018-05-01 00:51:15.445827+00', '2018-05-01 00:59:28.64446+00', 15825, 1, 202, 'ace', '1--::

  1c+2c RHA _while{4}_ 3c+4c LHA ; 1c & 4c cast inwards (2c & 3c dance up/down NHJ) | all set (2,1,4,3)

9--::

  All pass P Rsh, face P | cast R to exchanged places ; chase clw ½ (3,4,1,2)

17--::

  Circle8 and back

25--::

  2c cast up to 1pl _while{4}_ 3c+4c+1c dance down NHJ one place | set ; all turn P RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3878, '2013-08-10 22:27:54.883654+00', '2018-11-26 00:31:56.35352+00', 5060, 1, NULL, 'ace', '{{explanation}}

To start 3c+4c cross (1,2,3x,4x)



1--::

  1c+2c & 3c+4c RHA, finishing RHJ facing the end ; dance forward a bit, cast to middle positions, meet and lead to finish RHJ in own places ready for

9--::

  1c+2c (start up) & 3c+4c (start down) interlocking allemande, (1c & 4c pass each other to finish 2,4x,1,3x)

17-20::

  All set | turn BH and all W pivot R to face out with P behind ;

21-32::

  Reel4 {12} on midline, couples in tandem W leading M, 1c & 4c pass end couple Rsh to start, finish (2,4x,1,3x) again with W facing out

33--::

  2c+4c & 1c+3c Circle4 L ; 1c&4c ½ Fig8 round end cpl (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (8655, '2015-02-13 15:07:28.946782+00', '2019-09-08 11:02:59.894606+00', 16052, 1, NULL, 'ace', '1--::

  2c+3c Turn RH and face out ; 2c+3c cast to end and face P as 1c+4c cross inwards (no hands) and face each other in 2plx/3plx | All set (2,1x,4x,3)

9--::

  1c+4c ¾ R&L (start up/down) and face end couple | All set (2,1,4,3)

17--::

  2c+1c & 4c+3c RHA ; LHA 

25--::

  1c+4c Circle4 and back 

33--::

  1c+4c S&Link ; dance BtoB (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11350, '2018-11-26 00:46:13.35661+00', '2018-11-26 00:48:53.982099+00', 16506, 1, 202, 'ace', '1--::

  1c lead down {3}, up {3} and cast (2,1,3)

9--::

  1W turn 1cnr RH, turn 2cnr RH to 2pl

17--::

  1M repeat [9-16]

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (1980, '2012-01-22 19:29:13.169619+00', '2018-11-26 03:14:36.539203+00', 11192, 1, NULL, 'ace', '1–-::

  1c lead down and change sides (W crossing above, under M''s arm) ; lead up to 3pl on sidelines | cross up RH _while{8}_    

2c stand {2} | cross RH ; cast off to sidelines below 4c | cross up RH _while{8}_    

3c stand {4} ; dance up one place on sidelines, | cross up LH _while{8}_  

4c stand {6} | cross up LH	(to 3x,1,4x,2)  (All cover on [7-8])

9–-::

  G-Chain, starting along the sides, hold onto final LH, each M swiveling ½L, into promhold, facing cclw

17–-::

  All promenade cclw once round and face in (to 3x,1,4x,2), flowing into

25–-::

  top 4 and bottom 4 circle4 L ; breaking into ; all ½ circle8 L (to 2x,4,1x,3)

33–-::

  2c+1c ½Fig8 down ; all C turn partner RH (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2311, '2012-01-22 19:29:31.046406+00', '2018-11-26 03:36:02.308463+00', 2432, 1, NULL, 'ace', '{{explanation}}

Note: »Change Under R(L)« means M and W change places Rsh(Lsh) in 2 bars, W giving LH(RH) to M''s RH(LH), and dancing under their joined arms.



1--::

  1c set | change under R ; 1c+2c circle4 L, at end M keep hold of Won L

9--::

  (Progressive 3c chain:) 1M+2W & 2M+1W change under L | (3c face up) all three M face W and change under R ; repeat L | repeat R (3x,1,2x,4)

17-18::

  (Arches:) 3c+4c dance in to face each other NHJ _while{2}_ the Side Pairs (1M+2W & 1W+2M) cross NHJ, M side making the arch

19-20::

  Side Pairs Change Under R _while{2}_ 4c dance up under 3c who dance down making arch

21-22::

  3c+4c Change Under R _while{2}_ Side Pairs cross (M side making arch)

23-24::

  Side Pairs Change Under R _while{2}_ 3c dance up under 4c who dance down making arch

25-26::

  3c+4c Change Under R _while{2}_ Side Pairs set advancing to P (3x,1,2x,4)

27-28::

  1c+2c ½ RHA _while{2}_ 3c face 4c NHJ and set (3x,2,1x,4)

29-32::

  1c dance down under 4c making arch and change under to 4pl _while{4}_    

4c dance up to 3pl and set _while{4}_  

2c dance to 1pl under 3c making arch and set _while{4}_  

3c dance down to 2pl and change under (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12801, '2020-05-07 22:53:31.451872+00', '2020-05-07 22:57:20.508582+00', 12058, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; cross LH | dance LSh round 4cnrs into facing lines3 across

9-12::

  All A&R

13-24::

  3C R&L

25--::

  1c cross RH | Reels3 across, 1c RSh to 2cnrs (2,1,3)

33--::

  1c turn P LH crossing up between 2c | cast off to 2plx ; cross down RH beween 3c | cast up to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2060, '2012-01-22 19:29:17.597371+00', '2019-02-04 02:31:11.275632+00', 12790, 1, NULL, 'ace', '1–10::

  1c+2c set, pivoting R to face out | chase clw 1 place in square | change places on sidelines | chase clw 2 places in square {4} (1W & 2M now in exchanged places)

11–20::

  1c+2c R&L, starting across {8}| 1W+2M change places RH (1,2,3)

21–30::

  1c+2c+3c S&Link twice {8} | 3c Cross RH _while_{2} 2c+1c ½ RHA (3,1,2)

31–40::

  »Red House« Reels on opposite sides (2c+3c start Rsh, _while_ 1W enters Lsh to 3M and 1M Lsh to 2W) {8} | 1c cross RH and 2c+3c exchange places up/dn (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2942, '2012-01-22 19:30:03.876178+00', '2020-12-14 09:37:50.80384+00', 4982, 1, NULL, 'ace', '1–::

  1c turn RH ½ (2c up) | BiL with 2c ; 1c turn RH ½, dance Rsh round 2M/2W on own side and pass P Lsh into

9–::

  2c+1c reel4 across

17–::

  1c dance out to 2plx | set ; turn RH 1½ moving up _while{8}_ 2c dance in | turn RH ; lead up | cast to 2pl, all finish ready for

25–::

  1c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (12802, '2020-05-08 07:52:23.434058+00', '2020-05-08 08:06:53.541342+00', 10270, 1, 202, 'ace', '_Strathspey_
1--::
  1c+2c set | ½ RHA ; set | ½ LHA (1,2,3)
9--::
  1c dance down (2c up on [11-12]) ; turn BH | dance up to face 1cnrs

_Reel_
17--::
  All clap and ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag, pass RSh to face 3cnrs[pos]
25--::
  Repeat [17-24] no clap with 3cnrs[pos] then 4cnrs[pos] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10862, '2018-06-23 10:59:51.917773+00', '2019-02-26 00:05:53.660634+00', 15664, 1, 202, 'ace', '1--::

  All set | cross RH ; set | turn LH ½ to centre into promhold facing up (1,2,3)

9--::

  3C Promenade, 2c facing out

17--::

  Mirror Reels3{6} on sidelines, 1c start in and down, 2c finish facing out | 1c dance to 2pl centre _while{2}_ 2c(3c) continue the reel to 1pl(3pl centre) for

25--::

  1c+3c Rondel (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10717, '2018-04-30 16:37:09.553679+00', '2018-04-30 20:58:32.615059+00', 12245, 1, NULL, 'ace', '1--::

  All turn P RH ½ and twirl to opposite side ; All chase clw half round, 1M+3W face out (3,2,1)

9--::

  3W+1M cast clw to exchanged places as 3M+1W turn BH 1½ to finish opposite and facing P ; 1c+3c turn P BH 1½, finish NHJ facing the other cpl up/down (1,2,3)

17--::

  All circle6 L and back, to sidelines (1,2,3)

25--::

  1c+2c set | turn P BH and face down NHJ ; dance down between 3c and cast up to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10580, '2018-04-04 12:30:50.627955+00', '2019-06-30 10:33:22.572198+00', 18273, 1, 202, 'ace', '1--::
  1c set | cast (2c up) ; 1c turn 3c EH 1¼ into line4 across facing down
9--::
  1c+3c dance down ; and up, 3c to 3pl, 1W (1M behind) facing 3W
17--::
  Reel3 across in tandem (with lead change), 1c to 2pl facing out and up (2,1,3)
25--::
  Mirror Reels3 on sides, 1c out and up (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12267, '2019-10-04 01:37:53.649637+00', '2019-10-04 01:43:51.349569+00', 9928, 1, 202, 'ace', '1--::

  All turn RH ½, face P | cast R to exchanged places ; all chase clw ½ (3,2,1)

9--::

  1c set | lead to top ; cast round 3c to 2pl (2c down) | turn P LH ¾ (3,1,2)

17--::

  3c+1M & 1W+2c RHA ; 3c+1M (3W leading) & 1W+2c (2M leading) chase clw ½ (2x,1x,3x)

25--::

  ½Reel4 on 1diag, pass RSh ; ½Reel4 on 2diag (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (12268, '2019-10-04 08:17:19.970163+00', '2019-10-04 20:55:38.392473+00', 19689, 1, NULL, 'ace', '1--:: 

  1+2c & 3c+4c Circle4 L, finish 1c facing 2c and 3c facing 4c all NHJ ; All set adv., passing facing couple | 2c & 3c turn BH to 1pl/4pl _while{2}_ 1c+4c nearly ½ RHA, 1W+4M pulling Rsh back for 1c+4c, NHJ, to finish BtoB facing cnrs (2M & 3W) on 1diag

9--::

  1c/4c set to 3W/2M respectively, and face R into | 1c+4c ¾ RHA (tight together) to face 2W/3M (2cnrs) (1W & 4M pivot R if possible) ; 1c/4c set to their corner | 1c+4c petronella in tandem to sideline (1c/4c on W/M side) and face clw _while{2}_ 2M+3W set 

17--::

  1c+4c chase clw ½ round set _while{4}_ 2c+3c advance to centre and cast R back ; 1W/4M (P following) chase on across set to 2pl/3pl  | All set (2,1,4,3)

25--::

  1c+4c Tourbillon (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12269, '2019-10-04 23:44:15.773439+00', '2019-10-04 23:44:15.773439+00', 17164, 1, NULL, 'ace', '1--::

  1c facing 2c  A&R ; dance BtoB

9--::

  1c Fig8 round 2c

17--::

  2c Fig8 round 1c

25--::

  All dance forward, 1c under arch by 2c | all dance backwards, 1c make arch ; All dance forward, 2c make arch | dance on to meet next cpl.

', 3);
INSERT INTO 'dancecrib' VALUES (10719, '2018-05-01 01:14:42.497104+00', '2018-05-01 01:21:21.375407+00', 15826, 1, 202, 'ace', '1--::

  Inveran Reels3 (1,2,3)

9--::

  1c turn LH 1¼ moving down to face 1cnrs _while{2}_ 2c continue the reel to 1pl ; ½ Reel4 on 1diag, 1c passing Lsh in centre to face 1W(1M) up(dn)

17--::

  1W+2c on W side & 1M+3c on M side RHA, 1c facing 4cnrs at end ; ½ Reel4 on 2diag, 1c passing Rsh to 2plx (3x,1x,2x)

25--::

  3c+1c+2c chase clw ½ ; turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2993, '2012-01-22 19:30:05.983483+00', '2020-12-14 09:40:29.201332+00', 5200, 1, NULL, 'ace', '1–::

  1c NHJ set to 2W | 1c+2W circle3 L ; 1c+2c circle4 L

9–::

  1c+2c+3c circle6 L ; 1c+2c+3c+4c ½ circle8 L (4x,3x,2x,1x)

17–::

  1c set twice ; turn RH ½ | lead to 2pl between 3c

25–::

  1c turn RH 1½ _while{4}_ the other couples chase round them ½ clw to own places ; 1c birls to 4pl (2c+3c+4c up) (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (3511, '2012-01-22 19:30:28.515486+00', '2019-02-04 10:04:39.214323+00', 13225, 1, NULL, 'ace', '1–::

  1c set | cross RH ; cast off one (2c up) | face down and set to 3c.

9–::

  2c+1c+3c G-Chain (2,1x,3)

17–::

  1c set | cross RH ; cast off one (3c up) | face up and set to 3c (2,3,1)

25–::

  3c+1c ½R&L starting along the sideline ; 1c+3c set | cross RH. (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10180, '2017-10-15 20:43:23.845596+00', '2018-07-23 10:12:07.150619+00', 18007, 1, 202, 'ace', '1--::

  Mirror Reels3 on sidelines, 1c start in and down

9--::

  1c cross RH | cast (2c up) ; ½ Fig8 to R (2,1,3)

17--::

  2c+1c+3c A&R ; cross Rsh, M making arches

25--::

  Repeat [17-24], W making arches', 4);
INSERT INTO 'dancecrib' VALUES (3064, '2012-01-22 19:30:08.987436+00', '2018-11-27 02:02:17.460459+00', 5440, 1, NULL, 'ace', '{{title}}

Strathspey  

1–::

  1c set | cast (2c up) ; Mirror ½ Reels3 on the side, 1c starts in and down, ends facing 1cnr

9–::

  1c+1cnrs ½ Diag Reel4, pass Rsh ; 1c+2cnrs ½ Diag Reel4 to (2x,1x,3x)



{{title}}

Reel  

17–::

  All set | ½ Reels3 across, 1c Rsh to 4cnr (to 2,1,3) | 1c petronella into centre, BtoB

25–::

  DTr (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10162, '2017-10-08 09:25:10.850698+00', '2018-11-27 02:32:36.585223+00', 17980, 1, 202, 'ace', '1--::

  All M RHA to pl ; All M chase clw ½

9--::

  All M LHA ; All M chase cclw ½ to pl

17--::

  All W LHA to pl ; All W chase cclw ½

25--::

  All W RHA ; All W chase clw ½ to pl

33--::

  1c+3c The Spiral Progression _while{8}_ 2c & 4c turn RH ; chase clw ½, M leading (3,1,4,2)

41--::

  All repeat [33-40] with exchanged formations (1c+3c turn RH, etc., 2c+4c The Spiral)

49-64::

  Schiehallion reel

65--::

  All M set advancing to middle, swivel R | dance to places ; All W repeat [57-60] pivoting R to face crns

73--:: All BtoB with cnrs ; All turn cnrs RH

81--::

  Circle8{4} L, pivot L on [84] to face cclw ; All chase to places.

  

*Note. Spiral Progression in a square set: 1W+3W turn RH to join LH with opposite M | BiL on 1diag , on 2nd PdB 1M+3M swivel L to face clw, NHJ ; line turns ¼ clw | “outers” (1M+3M) dance to next place _while{2}_ “inners” (1M+3W) continue turn to finish having changed places.*', 2);
INSERT INTO 'dancecrib' VALUES (9268, '2016-07-14 09:07:58.080368+00', '2019-02-05 11:26:07.507304+00', 17144, 1, 1041, 'ace', '1--::

  1c 1¼ turn LH, moving down to face M side in 2pl, W above M (2c up on [3-4]) ; 1W+2c RHA _while{4}_ 1M+3c LHA, all cpls finish in middle, M behind P, 1c facing M side, 2c+3c facing W side

9--  ::

  Tandem (no lead change) Reel3 on midline, 1c Rsh to 2c, finish on the sides (2,1x,3) (1W face out)

17--::

  ½ Reels3 on sides, 1c Rsh to 2c ; all set | 1c cross RH (3,1,2)

25--::

  Circle6 and back (3,1,2)

', 4);
INSERT INTO 'dancecrib' VALUES (11352, '2018-11-27 18:02:59.290694+00', '2018-11-27 19:58:50.060311+00', 19058, 1, 1645, 'ace', '1-::

  1c cross RH | cast off (2c up) ; &frac12; Fig8 up round 2c (2,1,3)

9-::

  Mirror reels3 on the sides, 1c start in and down (2,1,3)

17-::

  1c cross RH | cast off (3c up) ; &frac12; Fig8 up round 3c (2,3,1)

25-::

  Circle6 & back (2,3,1)

', 4);
INSERT INTO 'dancecrib' VALUES (14456, '2021-11-17 18:39:28.123827+00', '2021-11-22 13:14:36.454671+00', 20559, 2, 963, 'ace', '1-4::  

  All 3C adv/retire  

5-8::  

  All 3C dance b/b - 1C stay close in the middle  

9-12::  

  1C dance Lsh round each other to face out own side:  

  1C, giving handy hand to 2C, 1/2 turn and face in    2,1,3

 13-16::

  1C, giving handy hand to 3C, turn once round 

17-24::  

  1C, lady up, man down, Rsh R3 on the side to finish Lsh to Lsh in the middle facing opp side - corners curve into place  

25-32::  

  1M with 3C, 1W with 2C RHA into a snake pass (1M flwd by 3M & 3W; 1W flwd by 2W & 2M, all passing Lsh in the middle, dance out to opp side, up to 1st place/down to 3rd place, across to own side, cast down/up to 2nd place) 3,1,2  

  ', 5);
INSERT INTO 'dancecrib' VALUES (11803, '2019-04-22 21:21:18.773904+00', '2019-04-22 21:28:39.397331+00', 19078, 1, NULL, 'ace', '1--::

  1c+4c set | 1c+4c cast inwards (2c+3c step to ends) ; 1c & 4c ½ Fig8 round end cpl (2,1x,4x,3)

9--::

  1c+4c RHA, finish in middle facing cnr ; middles turn cnrs LH 1½ to change places *(option: Birl)* 

17--::

  2c+3c RHA, finish in middle facing cnr ; middles turn cnrs LH 1½ *(option: Birl)*, finish on sides (2,1x,4x,3)

25--:: 

  1c+4c S&Link ; 4c & 1c dance ½ Fig8 round end cpl (2,4,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (11353, '2018-11-28 11:46:47.244775+00', '2018-11-28 11:47:05.820584+00', 16501, 1, 202, 'ace', '1--::

  All A&R (no hands) ; RHA (1,2)

9--::

  All A&R (no hands) ; Circle4 L (1,2)

17--::

  1c followed by 2c dance down. 2c make an arch ; 1c followed by 2c dance up (1,2)

25--::

  2C Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (12026, '2019-08-19 06:20:07.884837+00', '2020-03-09 10:57:04.002438+00', 4098, 1, 202, 'ace', '1--::

  1c & 3c turn RH | cast (2c & 4c up) ; turn LH to face 1cnrs (2,1,4,3,5)

9--::

  ½ Reels4 on 1diag ; ½Reels4 on 2diag. 1c & 3c face 3cnrs[pos]

17-20::

  ½ Reels4 on 1diag into DDTr facing own sides (5,1,4,3,2)

21-28::

  DDTr (5,1,4,3,2)

29-36::

  2c+1M & 3W+5c Reels3 across, RSh to 2cnrs _while{8}_ 1W+3M+4c Reel4 across, 1W+3M passing LSh then RSh to 2cnrs (5,1,4,3,2)

37-40::

  1c+4c+3c Mirror Reels3 on sides, 4c out and down, 1c in and up (5,3,4,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (13956, '2021-04-15 14:01:45.309018+00', '2021-07-07 08:33:07.640404+00', 20324, 1, 202, 'ace', '*All sets are scattered around the room*

1--::

  All turn opposite person RH with polite turn to face P ; all turn P LH. All M face out

9--::

  L-Chain. All face P

17--::

  All dance BtoB with P ; RHA. On [24] all retain RH with opposite person into promhold

25--::

  All Promenade round the room. On [31-32] all join another couple ready to start again.', 2);
INSERT INTO 'dancecrib' VALUES (11355, '2018-11-30 16:39:25.877685+00', '2018-12-04 15:42:40.162628+00', 18118, 2, 21455, 'ace', '1 - 4::

   1s + 2s petronella into centre and set

5-12::

  1s + 2s dance 1/2 celtic reel

13-16::

   2s + 1s 3/4 turn partners 2H to sidelines; all set

17-20::

  1s pass Rsh and dance corners pass and turn with 1st corners

21-24::

  1s pass Rsh and dance corners pass and turn with 2nd corners, ending in 2nd place on own side

25-32::

  All chase half way clockwise, half turn partner 2H and twirl to sidelines ending 3, 1, 2', 3);
INSERT INTO 'dancecrib' VALUES (11354, '2018-11-29 05:14:35.106165+00', '2018-11-29 05:28:22.173398+00', 16504, 1, 202, 'ace', '1--::
  1M cast behind M side _while{4}_ 1W dance down the middle ; 1c pivot R back to places. W faces out (1,2,3)
9--::
  Parallel Reels3, RSH to 2c. 1c(2c) face down(up) (1,2,3)
17--::
  1c+2c BtoB ; turn RH 1½ on sides (2,1,3)
25--::
  1c set to the persons they just have turned | 1c set to P ; turn P LH (2,1,3)  

*Deviser''s note:  
In a 3-couple set: replace [21-24] with*  
21-24::
  1c+2c change places RH | 1c+3c change places LH (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (11356, '2018-12-02 01:20:27.07129+00', '2018-12-02 01:26:43.345068+00', 17434, 1, 202, 'ace', '1--::

  1c & 4c Fig8 round nearest cpls (1,2,3,4)

9--::

  2c+3c RHA ; LHA (1,2,3,4)

17--::

  Circle8 and back (1,2,3,4)

25--::

  1c dance down behind 2c, between 3c, behind 4c ; turn RH to 4pl (2c+3c+4c up on [31-32]) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10725, '2018-05-01 11:29:27.052429+00', '2020-12-31 11:39:40.421645+00', 15833, 1, 202, 'ace', '1--::

  Circle8 and back

9--::

  1M dance down, cast round 4M back to place _while{8}_ 1W dance down behind W side and up the middle to place (1,2,3,4)

17--::

  Parrallel Reels4 on sidelines

25--::

  1c cast off to 4pl (2c+3c+4c up) ; all turn P RH', 2);
INSERT INTO 'dancecrib' VALUES (1947, '2012-01-22 19:29:11.356757+00', '2022-02-21 22:04:02.48141+00', 13847, 1, NULL, 'ace', '1–::

  1c ½ Fig8 round 2c ; 1c turn 2c EH 1¼ into line across, 1c in the middle

9–::

  1c+2c Reel4, finish 2c in 1pl and 1c (last pass is Lsh) facing 1cnr

17–::

  1c set to 1cnr | set to 2cnr, dancing R into sideline (2,1x,3) ; All set | 1c cross RH

25–::

  1c+3c Espagnole (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (11357, '2018-12-02 01:54:02.650155+00', '2018-12-02 14:39:41.516117+00', 17441, 1, 202, 'ace', '1--::
  1c+2c set | cross RH ; Turn Halfway and Cast (1,2,3)
9--::
  1c set | cast (2c up) ; 1c turn LH into promhold with 1cnrs facing cclw
17--::
  1c promenade{2} own 1cnr to exchanged places on 1diag | 1c turn LH into promhold with 2cnrs facing cclw _while{2}_ 1cnrs A&R{1+1} ; 1c promenade{2} own 2cnr to exchanged places on 2diag | 1c turn LH to midline, 1M(1W) facing down(up) _while{2}_ 2cnrs A&R{1+1}
25--::
  1c set to P | Petronella Turn to 2pl _while{4}_ 2c & 3c chase clw ½ ; all turn P BH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10721, '2018-05-01 05:57:40.356659+00', '2020-10-12 12:05:09.877981+00', 15829, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA ; set | ½ LHA (1,2)

9--::

  Circle4 and back

17--::

  1c lead down and up | cast off (2c up) (2,1)

25--::

  R&L (2,1)

', 4);
INSERT INTO 'dancecrib' VALUES (12271, '2019-10-05 06:06:34.400809+00', '2019-10-05 06:10:19.984739+00', 19510, 1, 202, 'ace', '1--::

  The Espagnole. 1c face out (2,1,3)

9--::

  1c Fig8 on sides, 1M(1W) LSh round 3M(2W) (2,1,3)

17--::

  1c turn 2c on sides, 1c out and up ; 1c+3c change places EH | all set (2,3,1)

25--::

  1c+3c Poussette (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12270, '2019-10-05 05:52:02.160389+00', '2019-10-05 05:57:15.984546+00', 18343, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c in and down (1,2,3)

9--::

  1c dance down, cast up round 3c, dance up between 2c and cast off facing 1cnrs (2c up on [15-16])

17--::

  Corners Pass and Turn on 1diag, pass RSh ; 2c+1M and 1W+3c LHA, pass RSh

25--::

  »Modified Corners Pass and Turn« on 2diag [: same as Corners Pass and Turn but passing LSh and turning LH], pass LSh ; 2c+1W & 1M+3c RHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1768, '2012-01-22 19:29:01.352892+00', '2020-02-08 20:36:44.050897+00', 551, 1, NULL, 'ace', '{{explanation}}

3rd and 4th couples start on opposite side: (1,2,3x,4x).



1–::

  All set | turn BH opening into ; 1c+2c & 3c+4c, circle4 L to places

9–::

  1M+2W+3W+4M ½ Rsh diag. Reel4 (2W & 3W start towards own end and return straight to own places) ; 1W+2M+3M+4W ½ Rsh diag. Reel4 (2M & 3M start towards own end and return straight to own places) (4,2,3x,1x)

17–::

  4c+2c & 3c+1c, R&L starting up/down, finish NHJ facing the other couple

25–::

  4c+2c & 3c+1c Rondel ‑ 2c & 3c making the arches (to 2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (10724, '2018-05-01 10:11:13.492219+00', '2020-12-30 21:32:18.353797+00', 15832, 1, 202, 'ace', '1--::

  All A&R ; dance BtoB (1,2,3,4)

9--::

  1c BHJ slip down, cast up round 4c to 1pl

17--::

  1c+2c ½ R&L ; 1M+3M cross RH | 1W+3W cross RH (2x,3x,1,4)

25--::

  1c+4c ½ R&L (to 2x,3x,4x,1x) ;  all turn P 1½ (2,3,4,1) ', 2);
INSERT INTO 'dancecrib' VALUES (14462, '2021-11-22 18:36:36.765483+00', '2021-11-22 18:36:48.097545+00', 6587, 1, 1645, 'ace', '1-::

  1c+2c+3c &frac12; Reel3 on sides, 2c out & up, 3c cast to start ; all singly dance up centre line, W above M

9-::

  All W set _while_ M advance{1} & set L{1} NHJ with P | all set & face P ; all set twice

17-::

  All turn P BH, 1c & 2c staying in centre for ; 1c+2c &frac12; poussette, 3c dance in on [24]

25-::

  1c+3c &frac12; poussette 1c+3c, 4c dance in on [28] ; 1c+4c &frac12; poussette (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15181, '2022-10-23 21:36:23.110109+00', '2022-10-23 21:51:06.326427+00', 21020, 2, 2899, 'ace', ' _1  -    8_  | 1C and 3C dance double figures of 8, 1C crossing down to begin.  
_9 - 16_ | 1C and 2C dance the knot. 1C end facing 1st corners.  
_17-24_  | 1C turn 1st corner RH, partner LH, 2nd corner RH. On the last 2 bars, 1C turn LH to end LS to LS in the center, 1W facing up and 1M facing down.  
_25-32_  | Reels of 3 across the dance, 1C giving LS to 1st corners to begin.  
*Named for a favorite Gordon Lightfoot song. Note that this could be a 3-couple set dance if the last figure is 6-bar reels across the set, then 1C dance down the center and face out to begin the double figure of 8.*', 4);
INSERT INTO 'dancecrib' VALUES (10723, '2018-05-01 09:24:17.800689+00', '2018-05-01 09:24:37.338866+00', 15831, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; cross LH | cast (3c up) (2,3,1)

9--::

  3W+2c & 3M+1c RHA ; 2c+3c+1c set | turn RH ½ into allemande hold facing down

17--::

  3C Allemande down (1x,3x,2x)

25--::

  3C ½ Gr-Chain with polite turn, 1c cross to start ; all turn P BH (2,3,1)



', 2);
INSERT INTO 'dancecrib' VALUES (10722, '2018-05-01 07:22:44.326005+00', '2018-05-01 07:30:21.171736+00', 15830, 1, 202, 'ace', '1--::

  1c+2c+3c cross RH | set ; turn P RH to centre facing up RHJ

9--::

  1c cast off, dance down opposite sides to 3plx _while{4}_ 2c & 3c lead up to top, cross and cast to 2pl/1pl (to 3,2,1x) ; 1c ½ Fig8 up round 2c (3,2,1)

17--::

  3c+2c Espagnole (2,3,1)

25--::

  Circle6 and back (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (8234, '2014-04-03 01:04:32.989692+00', '2019-02-18 17:07:33.305241+00', 14999, 2, 160, 'ace', '1–::
 1C lead down and up to face 1st corners.
9–::
 Set to & turn corners - end in middle facing own sides
17–::
 Reel of 3 on own sides, 1C out and down to begin.
25–::
 1C+3C Rondel.', 4);
INSERT INTO 'dancecrib' VALUES (1792, '2012-01-22 19:29:02.558746+00', '2020-05-09 07:52:18.735587+00', 633, 1, NULL, 'ace', '1-16::

  All four C petronella right round

17-32::

  1W set advancing to 1M and turn him BH _while_{4} 2W+3W+4W dance up one ; repeat (2W set advancing to 1M & 1W to 2M,  both pairs turn BH) ; repeat (three pairs turn) ; repeat (all turn: 4W+1M, 3W+2M, 2W+3M, 1W+4M)

33–::

  1W followed by other W dance behind 4M, in front of 3M, behind 2M, then 1W+2W & 3W+4W dance NHJ between partners to places (1,2,3,4)

41–::

  All C set twice ; turn RH (finish in Allemande-hold facing up)

49-64::

  (move into square set) 1c set advancing, turning R to face down in 1pl {4} ; 2c repeat, turning L and moving to 4pl (of Sq set) ;; 3c repeat turning R to 2pl ; 4c repeat with full L turn to 3pl

65–::

  All M set advancing to centre | set turning to face partner ; all set, the M 4 PdB or high cuts,  2M+3M (from 2pl/4pl) moving R to form line of M along original midline (2M, 1M, 4M, 3M),  middles face ends)

73–::

  All W set _while_{8} the M Reel4 in highland steps, at end 1M & 4M pass Rsh, all finish facing P

81–::

  All C set twice and turn BH back to form of original set, holding BH

89–::

  1c+2c & 3c+4c Poussette right round', 3);
INSERT INTO 'dancecrib' VALUES (11361, '2018-12-03 02:44:49.940821+00', '2019-01-24 14:53:00.549621+00', 7503, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; dance down and cast to face 1cnrs

9--::

  CPCP (2,1,3)

17--::

  All A&R ; 2c+1c Circle4 L{3}, on [24] 2c cast _as_ 1c dance up (1,2,3)

25--::

  1c+2c set | cross RH ; ½ R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11358, '2018-12-02 15:35:46.76706+00', '2018-12-02 15:39:01.696812+00', 17454, 1, 202, 'ace', '1--::

  1c cast two places (2c up on [3-4]), lead up to 1cnrs | set

9--::

  1c turn 1cnrs RH into lines3 across ; 1M+2W+3W & 1W+2M+3M Circle3 L into lines3 across

17--::

  1c pass RSh | turn 2cnrs RH to 2plx ; all set | 1c cross RH. 1M(1W) faces up(down)

25--::

  1c turn 3cnrs RH ; turn 4cnrs LH. 1c face out (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12273, '2019-10-06 22:39:44.650718+00', '2022-08-22 23:09:21.527222+00', 19690, 1, 202, 'ace', '1--::

  1c turn 2c EH ½ on sides, 1c in and down into DTr position | 6 bars of DTr. 1c face opposite sides

9--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag (3x,1x,2x)

17--::

  All A&R ; all turn P RH (3x,1x,2x)

25--::

  All chase clw ½ ; all dance BtoB (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14405, '2021-10-31 17:38:45.444963+00', '2022-09-13 12:13:18.860616+00', 6949, 2, 28690, 'ace', '1-4::

  1C & 2C lead down middle of dance,

5-8::

  1C followed by 2C cast up behind 4C, in front of 3C  and return to places,

9-12::

  1C with 2C RH across -while- 3C with 4C LH across,

13-24::

  2L leads 1C & 2M down into existing LH across at bottom of set -while- 3L leads 4C & 3M up into existing RH across at top of set (all retain hands across then pass alternately into other hands across of ''new'' figure). Finish in original places

25-32::

  All dance 4 couple pousette to finish 2,3,4,1.

', 4);
INSERT INTO 'dancecrib' VALUES (10361, '2017-12-27 06:26:36.255979+00', '2018-04-05 12:18:46.397734+00', 14898, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; ½ Fig8 up (2,1x,3)

9--::

  1c cross Lsh and dance out and down into Mirror Reels3{6} on the sides, ending BtoB in 2pl facing own sides for

17--::

  DTr (2,1,3)

25--::

  1c set | dance Rsh round P ; turn RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11362, '2018-12-03 14:15:44.333703+00', '2018-12-03 14:19:27.093125+00', 17450, 1, 202, 'ace', '1--::

  1c Fig8 round 2c (1,2,3)

9--::

  Circle6 and back (1,2,3)

17--::

  1c lead down {3}, up {3} | cast (2c up) (2,1,3)

25--::

  All A&R ; turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10581, '2018-04-05 12:24:52.338157+00', '2018-04-05 12:27:09.329426+00', 18274, 2, NULL, 'ace', '1-8::

    1s set, cast off (2s up), 1s set, turn LH 1.1/4 times

9-16::

    2s with 1W and 3s with 1M dance LSh reels of three across the set

17-24::

    1s dance LSh reels of three on own sides

25-32::

    1s dance between 3s, cast up around 3s, dance between 2s, cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (11360, '2018-12-03 02:28:51.185123+00', '2018-12-03 02:35:34.683965+00', 17452, 1, 202, 'ace', '1--::

  All W Fig8 clw, LSh to P (1,2,3,4)

9--::

  All M Fig8 cclw, RSh to P (1,2,3,4)

17--::

  All cpls in promhold A&R ; set to P | turn P RH. All W face out (1,2,3,4)

25--::

  All W chase clw ¼ ; All M pulling LSh back chase cclw ¼

33--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (11364, '2018-12-04 00:32:01.738041+00', '2018-12-04 00:39:37.254367+00', 17449, 1, 202, 'ace', '1--::
  1c dance between 2c, behind 3c, turn BH (skip change) and dance up to 1pl (1,2,3)
9--::
  Circle6 and back
17--::
  All (no hands, shaking hands on [18]) A&R  ; dance BtoB (1,2,3)
25--::
  1M+2W cross RH | 1W+2M cross RH ; 2c & 1c  Turn P Halfway and Cast (2,1,3)

*Turn Halfway and Cast is also known as Half-turn and twirl.*', 2);
INSERT INTO 'dancecrib' VALUES (11365, '2018-12-04 23:18:49.23185+00', '2018-12-04 23:22:57.133306+00', 17448, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c Poussette (1,2,3,4)

9--::

  2c+3c R&L _while{8}_ 1c & 4c set | cross RH ; set | cross RH (1,2,3,4)

17--::

  1M+2W cross RH | 1W+2M & 1M+3M cross LH ; 1W+3W & 1M+4W cross RH | 1W+4M cross LH (2x,3x,4x,1x)

25--::

  All W A&R{1+1} | all M repeat ; all turn P RH 1½ (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (14463, '2021-11-23 01:20:37.078666+00', '2021-11-23 01:23:59.522362+00', 16671, 1, 1645, 'ace', '*For a three person triangular set (1p, 2p, 3p)*

1--::

  1p+2p+3p Reel3, 1p starts RSh to 3p & ends above 2p & 3p facing down

9--::

  Inverting double triangles, 1p taking hands with 2p & 3p

17--::

  All circle3 to L & back to original places in triangular set

25--::

  All set | petronella 1pl to R (2,3,1) ; repeat (3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (13957, '2021-04-16 02:33:36.954207+00', '2021-04-18 06:22:38.821602+00', 20323, 1, 202, 'ace', '1--::

  1c+2c Poussette (1,2,3)

9--::

  1c turn BH | cast off (2c up) ; set, advancing on [14] | turn BH ½ and pivot R into 1diag BtoB facing 1cnrs

17--::

  Set H&G. On [23-24] clap _as_ 1c Petronella turn to 2pl (2,1,3)

25--::

  1c dance RSh round P and face P | kiss P ; set | cast R to 2pl _while{8}_ 2c+3c R&L up/down (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14347, '2021-10-03 23:12:41.466045+00', '2021-10-03 23:16:38.203067+00', 12779, 1, 202, 'ace', '1--::

  1c turn RH | lead down between 3c (2c up) ; cast up to 2pl | turn P RH ½ to face 1cnrs

9--::

  Corners Pass and Turn (2,1x,3)

17--::

  Reels3 on sides {6}, 1c LSh to 1cnrs | 1c cross RH (2,1,3)

25--::

  Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11363, '2018-12-03 16:33:46.476431+00', '2018-12-04 15:42:40.163269+00', 18118, 1, 202, 'ace', '1-4::

  1c & 2c Petronella Turn | set

5-12::

  »½ Celtic reel« [1c+2c pass P RSh | "outers" chase clw ¼ _while{2}_ "inners" turn Lsh (no hands) ¾ to face P ; repeat [5-8]]

13-16::

  2c & 1c turn P BH ¾ (to 2,1,3) | all set

17--::

  Corners Pass and Turn (2,1,3)

25--::

  All chase clw ½ ; All Turn P BH Halfway and Cast (3,1,2)



*Turn Halfway and Cast is also known as Half-turn and twirl.*', 4);
INSERT INTO 'dancecrib' VALUES (11367, '2018-12-05 04:56:08.245595+00', '2018-12-05 05:01:24.464803+00', 17446, 1, 202, 'ace', '1--::

  Circle6 and back

9--::

  1c set | 2c set ; 3c set _while{2}_ 1c+2c change places RH on W side, LH on M side | all cross RH (2x,1x,3x)

17--::

  3c set | 1c set ; 2c set _while{2}_ 1c+3c change places RH on W side, LH on M side | all cross RH (2,3,1)

25--::

  1c set | cast up (3c step down) ; dance up to top and cast to 2pl (2,1,3)



*Deviser''s note:  

On dancing couple’s 2nd time through, they cast to 4th place (4th couple step up on bars 31 and 32).*', 2);
INSERT INTO 'dancecrib' VALUES (11366, '2018-12-04 23:32:30.524044+00', '2018-12-04 23:39:42.431738+00', 17447, 1, 202, 'ace', '1--::

  Circle4 and back

9--::

  All W cross RH | set ; repeat _while{8}_ all M set | cross RH ; repeat

17--::

  RHA ; LHA

25--::

  A&R ; set | cross RH to next cpl', 2);
INSERT INTO 'dancecrib' VALUES (11368, '2018-12-06 11:05:19.911344+00', '2018-12-06 12:00:13.421127+00', 15740, 1, 202, 'ace', '1--::

  1c & 3c set | ¾ Fig8 round 2c, 1c cast to start (3,2,1x)

9--::

  2c Petronella Turn into facing lines3 across | all set ; all repeat [9-12] (3,2x,1x)

17--::

  2c+3c ½ R&L  (to 2,3x,1x) ; 1c cross RH | 1c turn 3c LH ¾ into line4 across ready for

25--::

  The Targe (2,3,1x)

33--::

  1c ½ Fig8 round 3c ; all turn P BH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (14828, '2022-05-16 00:07:41.017424+00', '2022-05-16 00:09:24.69743+00', 20823, 1, 202, 'ace', '1--::

  1c & 2c turn P RH ¾ | ½ Reel4 on midline | turn P RH ¾. 1c face 2cnrs (2,1,3)

9--::

  1c turn 2cnrs LH | turn P RH 1¼ to face 1cnrs ; turn 2cnrs LH | turn P RH 1¼ to 2pl (2,1,3)

17--::

  1c & 3c turn P RH ¾ | ½ Reel4 on midline | turn P RH ¾ (2,3,1)

25--::

  Circle6 and back (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11369, '2018-12-09 10:10:02.156413+00', '2018-12-09 10:13:54.738868+00', 19033, 1, 1645, 'ace', '1-::
  1c & 4c cross RH | cast inwards (2c & 3c to ends) ; 1c+4c RHA, retaining RH
9-::
  1c &4c take LH with crns & balance in crossing lines | 1c & 4c &frac12; turn cnrs LH ; 2c+3c RHA, end facing cnrs
17-::
  2c & 3c &frac12; turn cnrs LH | 1c+4c cross RH up/down on sides ; 1c & 4c &frac12; Fig8 out the ends (2,4,1,3)
25-::
  Circle8 & back (2,4,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (2815, '2012-01-22 19:29:58.541935+00', '2019-02-04 10:33:49.004386+00', 4506, 1, NULL, 'ace', '1–::

  1c lead down and half RH turn ; lead up and cast to 2plx (2c up)

9–::

  2c+1c R&L, finish holding P for

17–::

  Promenade

25–::

  2c+1c Advance {1}, retire {1} | repeat ; all turn RH', 2);
INSERT INTO 'dancecrib' VALUES (10904, '2018-07-15 16:33:28.801182+00', '2022-12-23 09:27:11.321777+00', 18334, 1, 202, 'ace', '1--::
  1c cross RH | cast (2c up) ; ½ Fig8 up round 2c to 2pl, 1c(3c) face dn(up) (2,1,3)
9--::
  1c&3c set | turn EH on sidelines, 1c starting in, 1c(2c) face up(dn) ; 1c&2c set | turn EH on sidelines, 1c starting in (2,1,3)
17--::
  Mirror Reels3 on sidelines, 1c starting in and down, 1c finish BtoB in centre facing own side
25--::
  DTr (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1999, '2012-01-22 19:29:14.263361+00', '2019-02-04 10:43:03.424673+00', 7375, 1, NULL, 'ace', '1–::

  1c+3c R&L

9–::

  1c+3c L-Chain

17–::

  2c+4c R&L

25–::

  2c+4c L-Chain

33–::

  All W A&R, RHA, finish facing out

41–::

  All W Chase clw round set (cast behind P to begin)

49–::

  All M A&R, LHA, , finish facing out

57–::

  All M Chase cclw round set (cast behind P to begin)

65–::

  1c+3c Promenade cclw round inside of set to own place, set facing in

73–::

  2c+4c Promenade clw round inside of set to own place, set facing in

81–::

  All circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (11055, '2018-09-01 23:18:56.112053+00', '2018-09-01 23:21:32.19599+00', 14120, 1, 202, 'ace', '1--::

  1W+2M & 3W+4M ½ R&L ; 1M+4W & 3M+2W repeat (3,4,1,2)

9--::

  All A&R ; ½ Gr-Chain (no polite turn) (1,2,3,4)

17--::

  All W RHA ¾ and loop LSh round original cnr | all set

25--::

  Circle8 and back



*Deviser''s note:  

Only the women progress; the woman who becomes 1st man''s partner always starts the rights and lefts.*', 2);
INSERT INTO 'dancecrib' VALUES (14634, '2022-03-04 11:41:28.10008+00', '2022-03-04 11:41:44.397958+00', 3128, 1, 1645, 'ace', '1-::

  1c cross RH | cast off (2c up) ; 2c+1c+3c set | cross RH (2x,1,3x)

9-::

  Circle6 to L & back

17-::

  All cross LH | set (2,1x,3) ; 1c &frac12; Fig8 up through 2c & face 1cnrs

25-::

  Turn CPCP (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10583, '2018-04-05 16:32:29.786429+00', '2022-10-01 15:15:16.703244+00', 18276, 1, 202, 'ace', '1--::

  1c dance Rsh round P | cast (2c up) | 1c lead down crossing over between 3c, cast up to 2pl (2,1x,3)

9--::

  Diagonal R&L (3x,1x,2x)

17--::

  1c ½ Reel4 on 1diag, pass Rsh ; ½ Reel4 on 2diag (2,1,3)

25--::

  3C Knot (3,1,2)', 5);
INSERT INTO 'dancecrib' VALUES (9951, '2017-06-10 03:34:27.320742+00', '2019-02-04 10:55:41.792301+00', 14727, 1, 202, 'ace', '1--::

 1c set | cross RH (2c up) and cast behind 3c ; cross RH below 3c to 2pl (2,1,3)

9--::

 Mirror Reels3, 1c crossing to 1plx, on [13] 1c cross back to 3pl (2,1,3), all finish  in midline ready for

17--::

 3C Allemande (3,1,2)

25--::

 1M+3M change pl RH _while{2}_ 1W+3W change pl LH _while{2}_ 2c set | 3M+2M change pl LH _while{2}_ 3W+2W change pl RH _while{2}_ 1c set (to 1,2,3) ; 2M+1M change pl RH (1M polite turn) _while{2}_ 2W+1W change pl LH (1W polite turn) _while{2}_ 3c set | all set', 2);
INSERT INTO 'dancecrib' VALUES (14633, '2022-03-03 00:36:52.740192+00', '2022-03-03 00:54:22.507823+00', 20675, 1, 1645, 'ace', '1--::
  All set R{1}, advance{1} | M LHA | all advance{1}, set L{1} & end facing out (3,4,1,2)
9--12::
  All M cast 1 place clw | all W repeat (2,3,4,1)
13--16::
  1c+3c cross RH | 2c+4c cross RH, 2W & 4W face out (4,1,2,3)
17--20::
  1c+3c &frac12; L-Chain _while{4}_ 2W & 4W chase &frac12; way clw outside
21--24::
  2c+4c &frac12; L-Chain _while{4}_ 1W & 3W chase &frac12; way clw outside (4,1,2,3)
25--::
  All circle8 to _R_ & back to _L_ (4,1,2,3)
::
  *Crib derived from the video*
', 2);
INSERT INTO 'dancecrib' VALUES (10941, '2018-08-05 22:54:22.524789+00', '2019-02-04 10:56:34.409411+00', 14372, 1, 202, 'ace', '1--::

  1c+2c RHA ; 1c cast off to face 1cnrs _while{4}_ 2c dance up to 1pl (2,*1*,3)

9--::

  Set To And Turn Corners. On [16] 1c pass P Lsh into DTr position facing own side

17--::

  DTr, 1c face out (2,1,3)

25--::

  Reels3 on sidelines, 1c Rsh to 3cnrs _while{8}_ 2c+3c R&L (no polite turns)

', 2);
INSERT INTO 'dancecrib' VALUES (12274, '2019-10-08 21:51:45.443401+00', '2019-10-13 17:58:22.098826+00', 19384, 1, 1645, 'ace', '1-::
  1c set | lead down ; cross RH below 3c | cast up (2c up) to (2,1x,3)
9-::
  *Shepherd''s Crook:*
  All take NH on sides, 1c & person on L set R as dancer on R of each line, followed by 1c, dances under arch made by 1c & dancer on L of line who turns under their own arm, all ending back in same line ; repeat with dancer on L of line leading
17-::
  All &frac12; RSh Reels3 on sides (3,1x,2) ; 3c turn BH _while_ 1c turn 1&frac12; BH ending ready for
25-::
  3c+1c &frac12; poussette ; 3c+2c &frac12; poussette (1,2,3)
33-::
  Circle6 once round | 1c cast to bottom _while_ 2c & 3c dance up (2,3,1)
', 4);
INSERT INTO 'dancecrib' VALUES (10726, '2018-05-01 14:53:44.076032+00', '2018-05-01 14:59:21.060406+00', 15834, 1, 202, 'ace', '1--::

  Circle6 and back to centre into promhold

9--::

  3C Promenade (1,2,3)

17--::

  1M+3W turn RH ½, face each other | cast R to exchanged places ; 1W+3M repeat [17-20] (3x,2,1x)

25--::

  2c set | cross LH to 1pl (3c down) ; 2c+3c+1c set | cross RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11411, '2018-12-21 01:10:37.723393+00', '2018-12-21 01:14:07.701122+00', 11019, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; turn LH to face 1cnrs

9--::

  Corner Chain. 1c face 2cnrs

17--::

  Corner Chain. On [23-24] 1c turn LH to face 1cnrs

25--::

  Reels3 across, 1c LSh to 1cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3146, '2012-01-22 19:30:13.316671+00', '2019-02-04 12:37:35.618436+00', 5713, 1, NULL, 'ace', '1–::

  All W cast by the R and round the set to places

9–::

  All M cast by the L and round the set to places

17–::

  G-Chain halfway round {6} | all set to P

25–::

  Continue G-Chain to places {6} | all set to P

33–::

  1c & 3c change places, 1c passing inside {3}, repeat back to places, 3c passing inside {3} | 1c+3c turn RH 1¼ into Allemande hold

41–::

  1c+3c (passing Lsh) Promenade cclw round inside of set to places

49–64::

  2c+4c repeat [33-48] (2c pass inside first)

65–::

  1c+3c half R&L ; 2c+4c half R&L

73–::

  Repeat [65-72] (to 1,2,3,4)

81–::

  All Circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (12276, '2019-10-10 22:50:58.214086+00', '2019-10-10 23:03:56.509637+00', 19692, 1, NULL, 'ace', '1--::

  1c+2c ½ DblFig8 (1c cross down and 2c dance up) ; 1c+2c turn EH on sides (1x,2x,3)

9--::

  1c lead down, 2c casting up and following ; 2c+1c change sides, W passing under joined arms and above M, and lead up (2,1,3)

17--::

  Mirror Reels3 on the sides, 2c out and down, 1c up the middle, 2c finish facing out (2,1,3)

25--::

  2c+1c turn EH on the sides ; 1c+3c turn EH on the sides (2,1,3)



*note: [1-8] is an Espagnole danced up-down.*

', 3);
INSERT INTO 'dancecrib' VALUES (12275, '2019-10-08 22:34:11.95444+00', '2019-10-09 16:47:48.283924+00', 14426, 1, NULL, 'ace', '1--::

  1c+2c set | 1W+2W NHJ cross and cast away _while{2}_ 1M+2M cross and curve in (to 1x,2x,3) ; 1c turn RH 1½ moving down _while{4}_ 2c cross LH and cast up (2,1,3)

9--::

  All A&R (1+1) | 1c turn BH ½ and twirl R to face 1cnr ; 1c+1cnrs set and turn BH into lines across

17--::

  Lines across A&R (1+1) | 1c turn BH ½ and twirl R to face 2cnr ; 1c+2cnrs set and turn BH to (2,1x,3) 

25--::

  Reels3{6} across, 1c Rsh to 4cnr | 1c cross LH (2,1,3)  



', 4);
INSERT INTO 'dancecrib' VALUES (10584, '2018-04-05 18:32:14.985152+00', '2022-10-11 03:17:45.113673+00', 18277, 1, 202, 'ace', '1--::

  2c+3c The Knot (1,3,2)

9--::

  3c ½ Fig8 R round 1cnrs ; all cross RH | all set (1x,3,2x)

17--::

  1W dances RSh round 3W _while{4}_ 2M dances RSh round 3M finishing BtoB facing P on 2diag ; ½ Reel4 on 2diag. 1W & 2M finish the reel as on [17] (1W,3M,1M on Mside, 2W,3W,2M on Wside)

25--::

  2W dances LSh round 3M _while{4}_ 1M dances LSh round 3W finishing BtoB on1diag, 2W faces 1W _as_ 1M faces 2M ; ½ Reel4 on 1diag passing LSh to begin. 2W & 1M finish the reel as on [25] (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (12571, '2020-02-09 13:23:42.706684+00', '2021-08-09 07:39:03.288955+00', 5063, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA (to 2x,1x,3) ; 1c+3c set | ½ LHA (2x,3x,1)

9--::

  1c cross RH | cast to top ; cross LH | cast back to 3pl _while{8}_ 2c+3c set | turn P RH ½ ; Circle4 L (2,3,1)

17--::

  1W+2M set, 1W advancing to 2plx _while{2}_ 1M+2W set, 1M advancing behind 1W to 2plx (3c down) (to 2,1x,3) | 1c turn 2c EH ¾, 1c out ; 1c lead down between 3c, cross and cast up (2,1,3)

25--::

  Circle6 and back (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14711, '2022-03-25 10:38:55.264667+00', '2022-03-25 10:39:07.294367+00', 20729, 1, 1645, 'ace', '1--::

  1c cross RH | cast off (2c up) ; &frac12; Fig8 up round 2c (2,1,3)

9--::

  1W+2c & 1M+3c RSh Reels3 across

17--::

  1M+2c & 1W+3c LSh Reels3 across

25--::

  Circle6 to L & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14829, '2022-05-16 22:25:24.575237+00', '2022-05-16 22:34:09.813465+00', 20542, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up and face out) ; 1c turn 2c EH (2,1x,3)

9--::

  ½ Mirror Reels3 on sides, 1c in and down. 2c & 3c curl into places on [12] ; 1c dance up and cast off to 2plx (3,1x,2)

17--::

  3C S&Link ; 1c turn P RH 1¼ to 2pl (2,1,3)

25--::

  Circle6 and back (2,1,3)



*Deviser''s note* : Bar 8, 1st couple need to finish the turn on the side approaching the centre to give 2nd & 3rd couples time to finish the half reel on the side curling into place.', 2);
INSERT INTO 'dancecrib' VALUES (14709, '2022-03-24 22:12:55.437577+00', '2022-03-25 18:39:59.542377+00', 17244, 1, 1645, 'ace', '1--::

  1W+2M & 3W+4M turn RH{3}, cast clw to midline{3} | &frac12; turn RH. On [5-6] 2W+4W & 1M+3M step &frac12; pl to their R

9--::

  1W+2M+3W+4M  &frac12; RSh Reel4 on midline ; 4M+2W+3W+1M & 2M+4W+1W+3M RHA

17--::

  4M+3W+2M+1W &frac12; RSh Reel4 ending as at [9] ;

  1c+2c & 3c+4c RHA just under once round, ending beside P, W above M, 1c & 3c on M side, 2c & 4c on W side

25--::

  1W+2M & 3W+4M change pl RH | 1c+4c S&Link | all set (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2898, '2012-01-22 19:30:02.095241+00', '2020-12-13 19:12:33.952026+00', 4858, 1, NULL, 'ace', '{{explanation}}

1M and 3rd M change places before start.  All bow to dancer opposite.



1–::

  1c (diagonally opposite) turn 1½ times RH (2c step into 1c''s starting places on [3-4] ; cast Rsh round 2cnr to 2plx

9–::

  1c+2c ½ diagonal R&L ; 1c+3c ½ diagonal R&L

17–::

  1c+2c ½ diagonal R&L ; 1c+3c ½ diagonal R&L, 1c finish facing 1cnrs (= 3c)

25–::

  1c SetH&G , finish BtoB facing 2cnrs (= 2c).

33–::

  1c+2c diagonal Reel4, 1c pass Lsh at end and face 2cnr

41–::

  1c Rsh Reels3{6} with corners | 1c cross to own side (M to top, W to bottom) _while{2}_ 3c cast to 2pl (to order 2W,3W,1W and 1M,3M,2M)', 3);
INSERT INTO 'dancecrib' VALUES (12278, '2019-10-11 23:08:56.235558+00', '2019-10-11 23:19:29.767424+00', 15498, 1, NULL, 'ace', '1--::

  1c+2c R&L

9--::

  All set | 1M+2W change places RH ; All set | 2W+2M change places LH (now 1c is on W side, 2c on M side, both W on R of M)

17--::

  In promhold 1c+2c A&R diagonally R (pass Lsh) ; A&R diagonally L (pass Rsh)

25--::

  1c+2c Tournee (on first bar advance in promhold, meeting Lsh on midline) (2,1)



', 3);
INSERT INTO 'dancecrib' VALUES (12279, '2019-10-13 12:18:32.299501+00', '2019-10-13 12:50:35.465384+00', 19695, 1, NULL, 'ace', '1--::

  1c cross RH | 1c ¾ Fig8 on opposite side (2c up) (2,1x,3)

9--::

  2c+1c RHA ; 1c+3c LHA

17--::

  All turn RH ½ | set to P; cast R to other sideline | cross RH, and 1c face out (2,1x,3)

25--::

  Reels3 on the sides, 1c Rsh to 1cnr, on [31-32] 1c cross to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12280, '2019-10-13 18:06:18.219715+00', '2019-10-13 18:25:03.916066+00', 19696, 1, NULL, 'ace', '1--::

  All dance Inveran Reels, 1c cross down to start (1,2,3)

9--::

  1c+2c The Knot, 1c finish facing 1cnr

17--::

  1c set to 1cnrs | to 2cnrs ; turn RH 1½ (2,1,3)

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (14063, '2021-06-13 11:19:46.560552+00', '2021-06-13 11:21:34.886915+00', 7057, 1, 1645, 'ace', '1-::
  1c & 4c &frac12; Fig8 round 2c/3c ; set | cross RH (1,2,3,4)
9-::
  1c & 4c &frac12; turn RH | lead to centre ; RHA retaining hands _while{8}_  
  2c & 3c cast to ends | cross RH ; set | &frac12; turn RH retaining hands
17-::
  1c & 4c continue &frac12; RHA | lead to ends ; cast inwards _while{6}_  
  2c & 3c continue &frac12; turn RH | cast inwards ; cross RH to ends | all set (2,4,1,3)
::
  *This crib follows the version in Skelton''s Lion Rampant Book.*
  *The earlier Green Book version has 2c & 3c also active in bars 1-8:*
  *2c & 3c set | &frac12; Fig8 out the ends | cross RH*
', 2);
INSERT INTO 'dancecrib' VALUES (8675, '2015-02-17 12:38:36.825594+00', '2021-03-23 20:15:35.544845+00', 7826, 2, 1, 'ace', '1–::

  1c turn RH 1¼ moving down (2c up on 3–4) ; 1c dance RS round 1st corners

  | 1c pass RS to face 2nd corners

9–::

  1c dance ½ diag reel4 w/2nd corners [fin in 2pl opp sides] ;

  1c dance ½ diag R&L w/1st corners [at end, retain LH for …]

17–::

  1c dance ½ LS diag reel4 w/1st corners [fin in 2pl own sides] ;

  1c dance ½ diag L&R w/2nd corners

25–::

  1c dance reels3{6} on opp sides (RS to 2nd corner to begin) | 1c cross RH', 3);
INSERT INTO 'dancecrib' VALUES (3391, '2012-01-22 19:30:23.426884+00', '2021-03-14 10:54:08.043367+00', 9052, 1, 202, 'ace', '1--::
  1c set | cross RH ; cast off (2c up) | turn P LH ¾ into lines3 across 1W between 2c, 1M between 3c both facing 1cnrs
9--::
  Reels3 across, 1c LSh to 1cnrs, all changing into the other reel3 by fast RH turn for: 2M+3W on [10], 1c on [12] 2W+3M on [14]. On [16] 1c turn P LH and face 1cnrs[pos] (3x,1,2x)
17--::
  ½ Reel4 on 1diag, 1c LSh to 1cnrs[pos], pass P RSh ; ½ Reel4 on 2diag, 1c RSh to 2cnrs[pos], pass P RSh (2,1,3)
25--::
  Circle6 and back  

*Deviser''s note* :  On bar 16, 1st couple ½ tum each other left hand to finish facing their 1st corner position (partner''s 1st corner person).', 2);
INSERT INTO 'dancecrib' VALUES (1740, '2012-01-22 19:28:59.366622+00', '2020-05-15 16:54:43.28136+00', 10546, 1, NULL, 'ace', '1–::

  All 4 bars of Schiehallion Reel ; 1c+3c RHA _while{4}_ 2c+4c turn RH

9–::

  All 4 bars of Schiehallion Reel ; 2c+4c RHA _while{4}_ 1c+3c turn RH

17–::

  All chase clw to original positions ; set | cast 1 place clw.

25–::

  All circle8 & back.



{{explanation}}

Repeat in Jig Time from new positions.', 2);
INSERT INTO 'dancecrib' VALUES (8164, '2014-02-02 21:25:18.382295+00', '2019-02-04 13:30:19.227733+00', 11590, 1, NULL, 'ace', '{{explanation}}

Square set, with 5c in the middle facing 1c.



1–::

  1c+2c+3c+4c Circle8 and back _while_ 5c set to P | turn RH | set facing up

9–::

  1c+5c+3c parallel ½ Reels3, 5c Rsh to 1c, 5c finish with M on the R of W, facing 4c ; 4c+5c+2c parallel ½ Reels3, 5c Rsh to 4c, 5c finish with M on the L of W, facing 3c

17–::

  Repeat to original places

25–::

  5c facing 1c set | ½ RHA and 1c face 4c ; 1c+4c repeat

33–::

  4c+3c repeat ; 3c+2c repeat (5,3,4,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (10585, '2018-04-06 13:12:44.217721+00', '2018-04-06 13:20:29.835992+00', 17532, 1, 202, 'ace', '1--::
  1c set | cast (2c up) ; dance between 3c | cast up to 2pl (2,1,3)
9--::
  1c Petronella turn into facing line of 3 across | all set ; ½ Reel4 on 2diag , 1c passing P Lsh
17--::
  1c Petronella turn into facing line of 3 across | all set ; ½ Reel4 on 1diag, 1c passing P Rsh (3x,1x,2x)
25--::
  1W+3c & 1M+2c LHA ; all chase cclw ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3174, '2012-01-22 19:30:14.452471+00', '2017-01-18 08:10:37.185725+00', 10471, 1, NULL, 'ace', '1--::

  1c+2c (& 3c+4c likewise) “The Spiral Progression”: 1M+2W turn RH ¾ to line of 4 | BiL, but on second step 1W+2M swivel L to face clw and rejoin hands ; line turns ¼ clw | 1M+2W turn RH ¾(to 2,1).  At the end 1M & 4W face out (2,1,4,3)

9--::

  2M+1M+4M & 1W+4W+3W Rsh Reels3 (1M & 4W start out and R), on [15-16] 1M & 4W cross to opposite side in 3pl & 2pl resp. while the others complete the reels

17--::

  2W+1W+1M & 4W+4M+3M Lsh Reels3 (1M & 4W start out and Lsh to P), on [23-24] 1M+4W cross to own sides (2,1,4,3), at end 2W+3M face out (2,1,4,3)

25--::

  2c (W leading) & 3c (M leading) cast behind 1W / 4M and pass between the other standing couple to finish on the midline at the opposite end (4pl and 1pl resp.), facing P ; 3c+2c set ; petronella to the sides (3,1,4,2)







*This is the original "Sailor Hector".  The revised version of this dance has been renamed "The Naughty Child"*

', 5);
INSERT INTO 'dancecrib' VALUES (2754, '2012-01-22 19:29:56.069816+00', '2020-02-09 21:25:01.870094+00', 4209, 1, NULL, 'ace', '*On 2nd chord 3c+4c cross (1,2,3x,4x)*   

1–::

  Gr-Chain (start 1c facing 2c & 3c facing 4c), on [8] 1c & 4c take promhold on midline facing middle

9–::

  1c+2W+2M & 4c+3W+3M Reels3 across (Lsh to W), finish 1c between 2c and 4c between 3c in facing lines of 4 across

17–::

  All set | 1c+4c RHA, on [22] the M swivel R to face end pos. | 1c+4c dance NHJ to ends and turn towards P to face the middle, NHJ _while{2}_ 2c+3c dance back to orig. pos. and face ends NHJ (1x,2,3x,4)

25–::

  All set advancing, passing facing couple | 1c+4c repeat _while{2}_ 2c+3c turn BH ; 2c+4c & 1c+3c circle4 L (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (10727, '2018-05-01 15:22:32.639881+00', '2020-12-30 21:29:38.455677+00', 15835, 1, 202, 'ace', '1--::

  1c Petronella Turn | set, 1M pivoting R on 2nd step to face down ; 1M followed by 1W dance down {2} to between 3c | set, 1M & 1W pivoting R to face own side

9--::

  1c+3c RHA ; 1M cast up round 3M _while{4}_ 1W dance down, cast up round 3W, 1c pass P Rsh to face 2cnrs

17--::

  ½ *Lsh* Reel4 on 2diag, pass P Rsh ; ½ *Lsh* Reel4 on 1diag to 2plx (3x,1x,2x)

25--::

  3c+1c+2c chase cclw ½ ; turn P LH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2282, '2012-01-22 19:29:29.629811+00', '2020-01-15 23:26:54.995117+00', 2349, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; turn LH | cast off one (3c up) (2,3,1)

9–::

  Circle6 and back

17–::

  1c lead to the top [**] (2c+3c down) ; 1c+2c set twice

25–::

  1c+2c ½ R&L ; 2c+1c set | cross RH (2,1,3)





[**] dance in {1}, dance up NHJ and out to 1pl {3}', 3);
INSERT INTO 'dancecrib' VALUES (14345, '2021-10-03 15:24:06.674331+00', '2021-10-03 15:56:53.323307+00', 15587, 1, 202, 'ace', '*Square set, with 5c in centre facing 1c. 5c is dancing couple.*
1--::
  5c in tandem (5M leading) +1c+3c both in promhold Reel3 in tandem (with lead change), 5c RSh to 1c. 5c (5M leading) in centre face 4c
9--::
  5c in tandem +2c+4c both in promhold Reel3 in tandem (with lead change), 5c LSh to 4c. 5c finish as on [1]
17--::
  2c+5W RHA _while{4}_ 5M+4c LHA. 5c face P in centre ; 5c set | turn P RH into promhold facing 1c
25--::
  All in promhold. 5c+1c change places, 1c face 4c | 1c+4c repat ; 4c+3c repeat | 3c+2c repeat. 2c is the new dancing couple in centre facing 5c in 1st place', 3);
INSERT INTO 'dancecrib' VALUES (14346, '2021-10-03 17:45:59.166852+00', '2021-10-04 06:49:01.070741+00', 13769, 1, 202, 'ace', '1--::
  1c+2c *Celtic Cross Progression* : 1M+2W turn RH _while_ 1W & 2M chase cclw ½ into line4 across {3}, 1c & 2c turn P LH ½ {1} ; 1W+2M turn RH ¾ _while_ 1M & 2W chase cclw ¼ into midline | 2c turn P LH ¾ to sides _while_ 1c turn P LH to face 1cnrs
9--::
  *Swing Corners* : 1c turn 1cnrs RH | turn P LH ½ to face 3cnrs ; turn 3cnrs RH | turn P LH ¾ to face 2cnrs. Cnrs dance continuously
17--::
  Repeat [9-16] with 2cnrs (2,1,3)
25--::
  Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3553, '2012-01-22 19:30:30.719645+00', '2021-03-14 20:11:47.134591+00', 8835, 1, NULL, 'ace', '1–::

  1c set advancing | turn BH ½ and face 2c NHJ ; set to 2c | 1c turn 2c easy hand to (1x,2) with 2c facing out

9–::

  1c+2c DblFig8 (1c cross down)

17–::

  1c, 2c following, lead down the middle, 1c turn RH ½ _while_{2} 2c split and pass ; 1c, 2c following, lead up into

25–::

  1c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (13816, '2021-03-14 18:30:26.663292+00', '2021-03-14 18:36:59.402709+00', 15730, 1, 202, 'ace', '1--::

  1c cast off | ½ Fig8 up round 2c (2c up on [5-6]) | cross LH (2,1,3)

9--::

  Reels3 across, 1c LSh to 4cnrs (2,1,3)

17--::

  Gr-Chain, 2c crossing (2,1,3)

25--::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (11377, '2018-12-13 02:21:40.603666+00', '2018-12-13 02:26:03.927277+00', 2657, 1, 202, 'ace', '1--::

  Mirror Reels3, 1c crossing down to opp side. 1c end in 1plx middle BHJ (1x,2,3)

9--::

  1c slip down, opening out to face up | set, 1W starting with PdB L ; slip up to top | cast to 2plx (2c up) (2,1x,3)

17--::

  1c+3M RHA ; 1c+3W LHA (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11378, '2018-12-13 02:57:21.458038+00', '2021-04-10 11:08:13.277798+00', 6526, 1, 202, 'ace', '1--::

  1W & 2M set | 1W cast to 2pl (2W up) ; 1M & 2W set | 1M casts to 2pl (2M up) (2,1,3)

9--::

  1W+2c & 1M+3c Circle3 L. On [12] 1c end in 2pl middle ; 1c turn BH 1½ _while{4}_ 2c & 3c chase clw ½ (3x,1x,2x)

17--::

  3C S&Link ; repeat (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11054, '2018-09-01 22:53:16.802316+00', '2018-09-01 22:57:22.460807+00', 14119, 1, 202, 'ace', '1--::

  1c lead down to 3pl, cross and cast to 2pl, _while{4}_ 2c set and cross into 3pl, _while{4}_ 3c cast to top and cross RH ; all set | all turn RH ½ into promhold

9--::

  3C Promenade (3,1,2)

17--::

  Repeat [1-6] (to 2x,3x,1x) | 2c cross RH _while{2}_ 1c & 3c turn RH ½ to centre, 1c(3c) facing up(down)

25--::

  3c+1c The Rondel (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11380, '2018-12-13 14:15:20.234878+00', '2018-12-13 14:19:59.70298+00', 19117, 1, 202, 'ace', '1--::
  1c cast to 2pl (2c up) | Petronella Turn into facing lines3 across ; all set | 1c turn RH to face 1cnrs[pos] _while{2}_ 2c & 3c cross RH (3,1,2)
9--::
  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag, 1c to 2plx (2x,1x,3x)
17--::
  All A&R{1+1} | turn P BH ½ and face P in middle ; set and cast R to sides (2,1,3)
25--::
  2c+1c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11381, '2018-12-13 23:27:41.781802+00', '2018-12-13 23:29:38.321564+00', 4897, 2, 1645, 'ace', '1-::

  1c lead down & back, 2c & 3c step in for

9-::

  All 3C promenade (1,2,3)

17-::

  1c+2c R&L

25-::

  1c cross RH | cast off (2c up) ; &frac12; Fig8 up round 2c (2,1,3)



*Crib derived from the video.*

', 2);
INSERT INTO 'dancecrib' VALUES (11807, '2019-04-25 12:21:18.149468+00', '2019-04-25 14:32:01.697017+00', 5305, 1, NULL, 'ace', '1--::

  1c set | dance down NHJ and face out and up in 2pl (2c up) ; ½ Reel3 on the sides (3,1,2)

9--::

  1c cast down round 2c, meet, dance up and face out, facing 2c in line across ; ½ Rsh Reel4 across

17--::

  1c (on opp. side) lead up RH to between 3c | turn P RH to face 3c ; ½ Rsh Reel4 across, at end 1c touch NH dancing down to 2plx (3x,1x,2x)

25--::

  1c cross RH, cast R onto midline _while{4}_ 3c+2c cross RH and set ; 1c pass P up/down RH and cast R _while{4}_  3c+2c change places RH and set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11383, '2018-12-14 11:04:18.644791+00', '2018-12-14 11:10:35.994811+00', 19103, 1, 202, 'ace', '1--::

  Reels3 on sides, joining NH when possible, 1c in and down, 2c out and down, 3c crossing up (1,2,3x)

9--::

  Reels3 on opp sides, joining NH when possible, 1c crossing down, 2c out and up, 3c in and up (1x,2,3x)

17--::

  1c+2c ½ DblFig8, 1c crossing down _while{4}_ 3c set twice. 2c face out (to 1,2x,3x) ;  2c+3c ½ DblFig8, 3c crossing up _while{4}_ 1c set twice (1,2,3)

25--::

  2c+1c following dance down | cast up round 3c (to 2,1,3) ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11384, '2018-12-14 20:08:16.456162+00', '2018-12-14 20:08:27.547489+00', 19112, 1, 1645, 'ace', '*On 2nd chord, 2c & 4c cross over (1,2x,3,4x)*

1-::

  1c+2c & 3c+4c  L-Chain, end ready for

9-::

  1c+2c & 3c+4c Targe (2,1x,4,3x)

17-::

  LSh Reels4 on the sides, end facing down/up (2,1x,4,3x)

25-::

  2c+1c & 4c+3c set | turn LH on sides ; 1c+4c &frac12; R&L starting on sides, 4M & 1M end facing out (2,4x,1,3x)

', 2);
INSERT INTO 'dancecrib' VALUES (11385, '2018-12-14 20:24:19.449669+00', '2018-12-14 20:24:40.987377+00', 19111, 1, 1645, 'ace', '1-::

  1c+2c set | RHA | 1c cast off as 2c dance up & face out (2,1,3)

9-::

  &frac12; RSh Reels3 on sides ; &frac12; LSh Reels3 across (3x,1x,2x)

17-::

  Set&Rotate for 3C (2x,1x,3x)

25-::

  Circle6 to L | all cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11386, '2018-12-14 23:30:20.222777+00', '2018-12-14 23:30:32.083744+00', 19109, 1, 1645, 'ace', '1-::

  1M+2W & 2M+3W change pl RH | all cross RH ; 2W+1M & 3W+2M change pl RH | all &frac12; turn P RH (1,2,3)

9-::

  All dance 3C promenade, 1c cast off as 2c dance up (2,1,3)

17-::

  2c+1c+3c S&Link ; 1c turn 1&frac12; RH to face 1cnrpos _while{4}_  2c & 3c set to P | cross RH

25-::

  1c &frac12; Reel4 on 1cnr diagonal, pass RSh to face 2cnrpos ; &frac12; Reel4 on 2cnr diagonal, pass RSh to (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11387, '2018-12-14 23:46:46.475218+00', '2018-12-14 23:46:55.987025+00', 19113, 1, 1645, 'ace', '*On 2nd chord, 2c & 4c cross over (1,2x,3,4x)*

1-::

  1c+2c RHA ; LHA _while_ 3c+4c LHA ; RHA

9-::

  1c+2c L-Chain _while_ 3c+4c M-Chain

17-::

  All set | 1c+2c & 3c+4c &frac12; RHA (2,1x,4,3x) ; 1c+4c &frac12; R&L

25-::

  All circle8 & back (2,4x,1,3x)

', 2);
INSERT INTO 'dancecrib' VALUES (10498, '2018-03-10 20:03:53.340758+00', '2019-02-04 13:54:59.853312+00', 17878, 1, 202, 'ace', '1--::

  1c set | turn RH ; cast (2c up) | cross LH and face out (2,1x,3)

9--::

  1M+2c & 1W+3c Reels3 across, Lsh to 2cnrs to start. On [15-16], 1c finish BtoB in centre into DTr position, 1M/1W facing up/dn

17--::

  1c »The Swivel« [All set as in Dtr, on [18] 1c pivot R to face P | 1c BHJ set, on [20] 1c change places and drop hands ; 1c retire{2} into facing lines of 3 across, 1M/1W between 3c/2c | all set]

25--::

  1M+3c & 1W+2c  Reels3 on sidelines, Lsh to 2cnrs to start (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (12805, '2020-05-10 00:28:40.794136+00', '2022-08-17 18:45:59.77535+00', 19972, 1, 202, 'ace', '1--::

  2C Bourrel (2,1,3)

9--::

  1c dance down | turn P BH ; dance up | turn P LH to face 1cnrs

17--::

  Reel4 on 1diag (2,1,3)

25--::

  All set | turn P BH, 1c & 3c ready for ; ½ Poussette (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (15364, '2022-12-23 16:38:02.375891+00', '2022-12-23 23:13:41.74913+00', 21221, 1, 202, 'ace', '1--::

  1c dance down | turn P BH opening to face up ; dance up | cast off (2c up) (2,1,3)

9--::

  Mirror Reels3 on sides, 1c in and down (2,1,3)

17--::

  1c set | turn P BH opening to face down ; dance down | cast up to 2pl (2,1,3)

25--::

  1c+3c Bourrel (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2056, '2012-01-22 19:29:17.389096+00', '2019-02-04 14:02:48.488527+00', 1546, 1, NULL, 'ace', '1–::

  1c+2c Espagnole, 1c finish facing 1cnrs

9–::

  1c+1cnrs ½diagReel4 ; repeat with 2cnrs (3x,1x,2x)

17–::

  1c turn RH to 2plx ; Opposing Rsh ½Reels3 across, 1W up, 1M down (to 3,1,2)

25–::

  3c+1W & 1M+2c RHA ; Lsh Snake Pass (unwind the RHA, 1c leading, pass other snake Lsh through 2plx and chase cclw) (2,1,3)



{{explanation}}

note: the original does not say where 1c ends on [16], I have assumed 2plx  

Espagnole: both W lead RHJ to M side, cross and cast back to exchanged places while Men cross to W side, lead RHJ back to M side and cross to exchanged places ; all turn P EH (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (11388, '2018-12-15 02:54:52.362545+00', '2018-12-30 09:30:38.031318+00', 13812, 1, 202, 'ace', '1--::

  1c dance down ; and up. 1c face out (1,2,3)

9--::

  Mirror Reels3 on sides, 1c starting out (1,2,3)

17--::

  1c cast to 2pl _as_ 2c dance up and loop to 1pl | all set ; all turn P RH (2,1,3)

25--::

  Circle6 and back (2,1,3)



*Deviser''s note:  

The last time through the dance, all 4 couples dance bars 19-32 (25 - 32 will be 8 hands round and back).*', 2);
INSERT INTO 'dancecrib' VALUES (12283, '2019-10-15 00:04:48.320935+00', '2019-10-15 00:07:47.638697+00', 15499, 1, 202, 'ace', '1--::

  1c set | cross down to 2plx (2c up) ; turn P BH 1¾ into BtoB position, 1M(1W) facing 2c(3c)

9--::

  All advance and pivot R | All advance and pivot R, 1c passing P RSh. 1M(1W) faces 3c(2c) ; all repeat [9-12]. On [11] 1c Petronella Turn passing RSh to 2plx (2,1x,3)

17--::

  2c+1c La-Chain (2,1x,3)

25--::

  1c ½ Fig8 R round 3cnrs ; all turn P BH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2023, '2012-01-22 19:29:15.442134+00', '2020-07-17 16:03:02.255623+00', 1469, 1, NULL, 'ace', '1–::

  1c cross RH _while_{2} 2c (starting in) +3c change place on the sides EH | Mirror Reels3{6} on the sides, 3c (in 2pl) starting in and up, 1c ends facing out (1x,3,2)

9–::

  1c cast off _while_{2} 3c dance to top giving NH | 1c ½ Fig8 L (1W up, 1M down) | 1c 1¼ turn LH (1M now below 1W)

17–::

  3c+1W & 1M+2c RHA (Teapots R), to sidelines ; 3c+1M & 1W+2c LHA (3,1,2)

25–::

  3c+1c+2c the Knot (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12281, '2019-10-14 10:09:15.681052+00', '2019-10-17 22:11:41.556137+00', 19697, 1, NULL, 'ace', '1--::

  Reels3 on the sides, 1c crossing down, at end 1c dance down NHJ and 2c up into DTr position (2, 1x in middle, 3)

9--::

  6 bars of Crown Triangles: set and move | set and move ; set | 1c turn 3cnr RH into lines3 across, and face 2cnr

17--::

  ½ Reels3 across, 1c Lsh to 2cnr, 1c pass Rsh to face 1cnr ; ½ Rsh diag. Reel4, 1c finish in 2plx facing 2cnr

25--::

  ½ Lsh Reels3 on the sides, 1c pass Rsh to face 1cnr ; ½ Lsh diag. Reel4 to (2,1x,3)

33--::

  S&Link3 into lines across ; All chase clw ½ round 

41--::

  In lines across S&Link3 ; All turn P RH, 1c turning 1½ (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (10587, '2018-04-06 21:10:34.349049+00', '2018-04-06 21:28:09.557154+00', 12717, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c »En rond« [All change places LH on sidelines (polite turn) | set to P ; Circle4 R] (2,1,4,3)

9--::

  1c+4c LHA, finishing BtoB in centre own side facing end cpl on the diagonal _while{4}_ 2c & 3c set twice ; all turn facing person RH

17--::

  Intersecting diagonal Reels4 (passing Lsh across in centre), middle cpls ending in centre ready for

25--::

  Poussette (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10729, '2018-05-01 21:05:00.770914+00', '2018-05-01 21:07:44.746862+00', 15846, 1, 202, 'ace', '1--::

  1c+2c 6 bars of Rondel | 1c cross down to 2plx facing out _while{2}_ 2c cast up to 1pl (2,1x,3)

9--::

  1c cast off round 3c, meet and lead up to top, cross and cast to face 1cnrs

17--::

  SetH&G, finish BtoB facing 2cnrs

25--::

  Reels3 {6} on sidelines, 1c start Rsh to 2cnrs | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14473, '2021-12-04 23:32:22.969563+00', '2022-02-21 09:31:20.059512+00', 20574, 1, 202, 'ace', '1--::

  2c set advancing passing LSh | dance RSh round 1cnrs and face 1cnrs | 2c+1cnrs set

9--::

  2c+1cnrs Corner Chain. 2c face 2cnrs

17--::

  2c+2cnrs Corner Chain (1,2,3)

25--::

  1c cast off to 3pl (2c+3c up) ; 2c & 3c turn P RH (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (2959, '2012-01-22 19:30:04.584995+00', '2020-02-10 15:37:37.108922+00', 5062, 1, NULL, 'ace', '1–::

  1c+2c RHA, 1W ends facing out ; 1W (1M following) casts off (2c up) (2,1x,3)

9–::

  1c+3c LHA, 1W ends facing out ; 1W (1M following) casts off (3c up) (2,3,1)

17–::

  1c set, dance to top NHJ, cast off to 2pl (3c down on 21-22)

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (10588, '2018-04-06 21:12:38.526934+00', '2018-07-24 17:18:09.195021+00', 8831, 2, 1, 'ace', '1–4:: 1c set | cross down RH [2c up] 

5–8:: 1c set | turn RH [face out] _while{4}_ 4c set | cross up LH [3c down]

9–12:: 2c set | cross down RH _while{4}_ 1c set | cast up

    _while{4}_ 4c set | turn RH [face out]

13–16:: 2c set | turn RH [face out] _while{4}_ 4c set | cast off

    _while{4}_ 3c set | cross up LH [fin 1x,2x,3x,4x]

17–20:: 1c+2c, 3c+4c set & link [1L, 2M, 3L, 4M fin facing out]

21–24:: ½ Reels4 on sides [fin 3x,4x,1x,2x]

25–:: 2c set | cross RH ; 2c cast to top _while{4}_ 3c+4c+1c set | cross down LH

    [fin 2341]', 3);
INSERT INTO 'dancecrib' VALUES (11392, '2018-12-16 00:46:54.973581+00', '2018-12-16 00:47:06.428097+00', 19106, 1, 1645, 'ace', '1-::

  1c+2c & 3c+4c RHA ; 1M & 3M cross over while 1W & 3W cross down | 1c & 3c cast R round 2c/4c to end BtoB facing them

9-::

  1c+2c & 3c+4c Reels4 across, 1c & 3c end passing RSh to face 1cnrs, 2c & 4c end in 1pl/3pl

17-::

  1c & 3c set & turn 1cnrs ; set & turn 2cnrs, end on sides (2,1x,4,3x,5)

25-::

  1c & 3c cross RH | cast off (4c & 5c up) ; 2c+4c & 1c+5c LHA _while_ 3c turn LH (2,4,1,5,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11391, '2018-12-15 14:28:23.145452+00', '2018-12-15 14:32:26.674776+00', 13813, 1, 202, 'ace', '1--::

  1c dance down (2c up) ; on [5] 1M turns below 1W who passes under his L arm, dance up to 2plx and face up. 2c face down (2,1x,3)

9--::

  »Inverted Gr-Chain«, 3c crossing. 1c face up (no polite turn) (2,1x,3)

17--::

  1c ½ Fig8 up ; dance down between 3c and cast to 2pl (2,1,3)

25--::

  All A&R ; all turn P RH (or Tulloch turn or Birl) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10985, '2018-08-14 18:24:32.047068+00', '2019-02-04 15:51:57.269646+00', 15287, 1, 202, 'ace', '1--::

  1c dance in and cast off 2 places (2c up) ; meet into promhold and dance up between 3c to face 2M (2,1,3)

9--::

  Reel3 on 1diag, RSh to 2M

17--::

  1M+3c & 1W+2c Mirror Reel3 across, 1M(1W) RSh(LSh) to 3M(2M), finish in centre BtoB 1M(1W) facing down(up)

25--::

  Set as in DTr | set, pulling RSh back to finish NHJ, facing down, 1W on 1M left ; 1c dance down and cast to 2pl (2,1,3)

33--::

  Circle6 and back (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11806, '2019-04-25 11:57:31.088255+00', '2019-04-26 22:37:38.815873+00', 5828, 1, NULL, 'ace', '1--::

  1c set |cross down RH, cast behind 3c, dance up between 3c and behind 2c to (1x,2,3)

9--::

  1c (start inwards) turn 2c EH ¾ into line across | 1c set to 2c ; turn again ¾ to sidelines | 1c set to 2c (2,1x,3)

17--::

  Crossover Reels3 on the sides, 1c start out and up, and cross down from the top, and finish in DTr position on own side

25--::

  2c+1c+3c DTr (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10732, '2018-05-01 23:52:11.994273+00', '2018-05-01 23:58:34.292963+00', 15844, 1, 202, 'ace', '1--::
  1c cross RH | cast (2c up) ; 1c turn LH (2,1x,3)
9--::
  2c+1c+3c chase cclw ½ ; Circle6 R ½ to places (2,1x,3)
17--::
  Reels3 {6} on sidelines, 1c start Rsh to 2cnrs | 1c cross RH to 2pl (2,1,3)
25--::
  1c cast (3c up) ; 2c+3c+1c set | turn LH (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (10589, '2018-04-06 21:45:41.989962+00', '2018-04-06 21:55:58.261165+00', 12715, 1, 202, 'ace', '1--::

  1c+2c RHA _while{4}_ 3c turn RH, 1W & 3M facing out at end ; 1W & 3M chase clw ½ to exchanged places _while{4}_ 1M+2c+3W ½ Diagonal R&L (3x,2x,1x)

9--::

  2c+1c LHA _while{4}_ 3c turn LH, 1M & 3W facing out at end ; 1M & 3W chase cclw ½ to exchanged places _while{4}_ 3M+2c+1W ½ Diagonal R&L (1,2,3)

17--::

  1c+2c Espagnole, finishing 2c(1c) facing out(in) (2,1,3)

25--::

  Reels3 on sidelines, 1c start Rsh to 4cnrs', 2);
INSERT INTO 'dancecrib' VALUES (12284, '2019-10-15 00:27:03.038885+00', '2019-10-15 00:30:25.89813+00', 15501, 1, 202, 'ace', '1--::

  1c & 4c turn P BH 1½ into Reel4 position ; ½ Reels4 (4x,3,2,1x)

9--::

  All repeat [1-8] from new positions (1,2,3,4)

17--::

  1c+2c S&Link _while{4}_ 3c set | cross  (to 2,1,3x,4) ; 1c+3c S&Link _while{4}_ 2c & 4c set | cross (2x,3x,1,4x)

25--::

  1c+4c S&Link (to 2x,3x,4x,1) ; 2c & 3c & 4c pass P RSh, pivot R ½ and face P | cast R to exchanged places  (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2118, '2012-01-22 19:29:21.071876+00', '2020-05-16 09:11:59.265056+00', 1783, 1, NULL, 'ace', '1–::

  1c+2c set twice ; 1c+2c turn P RH

9–::

  1c followed by 2c lead down the middle ; and up, 2c leading and casting off (to 1,2)

17–::

  1c+2c RHA {3}, LHA {3} | 1c cast to 2pl, 2c dance to top (to 2,1)

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (11393, '2018-12-16 01:37:04.873884+00', '2018-12-16 01:40:13.40406+00', 13819, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; turn RH 1½ to face 1cnrs

9--::

  [Corners pass and cast away :] 1c+1cnrs pass, cnrs turn RH ½, and cast away as 1c meet and pass RSh ; repeat with 2cnrs. 1c on own sides face out (3x,1,2x)

17--::

  Cnrs Petronella Turn one place clw | set ; repeat _while{8}_ 1c loop RSh round 3cnrs to 2plx ; repeat round 1cnrs to 2pl (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9108, '2016-03-05 00:49:42.318672+00', '2020-07-17 19:12:20.680129+00', 10698, 1, NULL, 'ace', '1--::

  1c fig8 on own side, start Rsh to 2c (1,2,3)

9--::

  Reels3 on the sides, 1c Rsh to 2c

17--::

  1c lead down and up, 2c steps in

25--::

  1c+2c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1689, '2012-01-22 19:28:56.740393+00', '2020-02-10 15:39:27.783552+00', 9138, 1, NULL, 'ace', '1–::

  1c+2c set | RHA | 1c cast as 2c dance up (2,1,3)

9–::

  Mirror Reels3 on own side, 1c start in and down

17–::

  1c ½Fig8 Left (M up, W dn) ; all chase clw ½ round (3x,1,2x)

25–::

  Diagonal R&L', 3);
INSERT INTO 'dancecrib' VALUES (2331, '2012-01-22 19:29:31.833372+00', '2020-03-10 20:28:24.409679+00', 2498, 1, NULL, 'ace', '*2 chords.  On 2nd chord 1W crosses down to R of P, 2W moves 1 place up and 2M crosses to her place, so 1c faces 2c across.*



1–::

  1c+2c R&L, finish with 2M between 2W & 1W facing down and NHJ, 1M behind him

9–::

  1W+2M+2W dance down the middle, 1M following ; all turn (W inwards, M R about) 1M NHJ with the women, and 2M following, dance up to finish in line across, the W on the sidelines facing P in the middle (1c on M side)

17–::

  1c+2c set to P: Glasgow Highlanders step (M may do some other Highland step)

25–::

  Reels4 {6} across the dance | 1c lead down the M side and 2c up the W side to face next couple. On reaching the top, 2c waits inactive on own side ; on reaching the bottom 1c waits inactive on own side.



{{explanation}}

Notes: The RSCDS prescribes a 4c set, but the tradition is a longwise set ''for as many as will''.', 3);
INSERT INTO 'dancecrib' VALUES (12287, '2019-10-15 08:32:59.437879+00', '2019-10-15 08:36:45.383677+00', 15519, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c Circle4 and back. 1c & 3c face down, 2c & 4c face up (1,2,3,4)

9--::

  1c+2c & 3c+4c R&L up/down (1,2,3,4)

17--::

  1c & 4c set | cast inwards (2c & 3c step out) ; 1c+4c+3c ½ RSh Reels3 (2,3,4,1)

25--::

  4c+1c RHA ; All A&R (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12285, '2019-10-15 01:12:57.593306+00', '2019-10-17 00:37:18.218991+00', 15481, 1, 202, 'ace', '1--::

  1c & 2c cross RH | set ; 1c & 2c turn P RH 1¾ into Reel4 position on midline

9--::

  Reel4. On [7] 1c & 2c turn P RH ¾ with polite turn to finish NHJ, 1c facing 2c

17-28::

  »Rondel in Twelve« [: is a slowed Rondel as follows: Under arch {2} | Cross and Loop {2} ; W under M arch {2} | Cross and Loop {2} ; 1c under 2c arch {2} | All cast with loop to new places {2}] (2,1)

29-32::

  2c+1c RHA (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (12288, '2019-10-16 00:28:10.655412+00', '2019-10-16 00:36:39.603875+00', 16661, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; cross RH and cast R into lines across, 2c+1W facing 1M+3c    

9--::

  All set | 1c change place LH and cast L to 2pl | All set (2,1,3)

17--::

  2c+1W & 1M+3c RHA ; Lsh Snake pass, finish (3,1,2)

25--::

  All turn P LH ½ into middle | cast L to own sideline ; All chase cclw ½ to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10410, '2018-01-31 14:02:48.055603+00', '2018-07-17 00:21:42.455786+00', 17122, 2, 160, 'ace', '1-8::  1C adv. 1step (take RH briefly)&ret. 1 step, half turn LH; cross down between 2C and cast up to place.

9-16::  1C 2C dance the Knot - 1C end facing 1st corners. (2 1 3)

17-24::  1C 1st corners Pass & Turn; 1C 2nd corners Pass&Turn. 1C pass Rsh to own sides. (corners turn BH)

25-32:: All dance cw to opp. side of set; all dance 1/2 turn (BH) and cast away. End on own sides. (3 1 2)', 3);
INSERT INTO 'dancecrib' VALUES (15365, '2022-12-23 16:57:41.041827+00', '2022-12-23 16:58:05.55026+00', 17913, 1, 202, 'ace', '1--::

  1c+2c RHA ; 2c+3c LHA

9--::

  1M+2W & 2M+3W change places RH and set ; 1W+3W & 1M+3M change places LH and set

17--::

  2W+3M & 1W+2M change places RH and set ; all turn P RH (3,2,1)

25--::

  3C Progressive Promenade (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11379, '2018-12-13 10:11:07.117251+00', '2018-12-16 09:50:00.550161+00', 19114, 2, NULL, 'ace', '1-4::

   All face partner and dance one setting step to the right to ladies form a small square. All ladies dance ¾ RHA while all men chase anticlockwise to meet their partners on the diagonals.

5-8::

   All turn partners LH ¾ times and ladies followed by partners chase anticlockwise to all finish one place clockwise from their original places.

9-12::

   2nd and 4th ladies (on top places) followed by partners chase ¼ anticlockwise behind side couples, dance through them, pass upcoming couple by the left shoulder and join hands with partner to face opposite couple. 

13-16::

   2s and 4s set retiring to top places and turn corners giving right hands ¾ times. All men now in the middle, facing ladies on diagonals.

17-24::

   All men dance set and turn with ladies and pass to meet next lady, repeat with next lady and pass to meet next lady in promenade hold facing anticlockwise.

25-28::

   All couples in allemande hold dance promenade anticlockwise half way

29-32::

   Men curve partner into line for one bar to form a square set, ladies release hands and dance RHA for three bars to return into lines to the same men.

33-36::

   1st and 3rd men followed by ladies from their right chase ¼ clockwise behind top couples, dance through them, pass upcoming couple by the right shoulder and join hands to face opposite couple.

37-40::

   Same couples set retiring to side places and turn corners once round giving right hands to open in a big circle.

41-44::

   All circle 8H round to the left half way. On the bars 43-44 all men dance in, curve one place to the right to join right hands with original partner (men inside) and face clockwise.

45-48::

   Men lead partners one place clockwise and turn them RH ¾ times to sides. 4 1 2 3 



Repeat one more time from new places.', 5);
INSERT INTO 'dancecrib' VALUES (10733, '2018-05-02 06:54:43.305033+00', '2018-05-02 06:59:03.561012+00', 15842, 1, 202, 'ace', '1--::

  All C NHJ advance | retire “diagonally” NHJ with cnr ; repeat [1-4] back to places

9--::

  All C turn cnr RH ; turn P LH

17--::

  All W RHA ; All M LHA ¾ into promhold with new P

25--::

  All C Promenade, all M with new P having moved one place clw', 2);
INSERT INTO 'dancecrib' VALUES (1846, '2012-01-22 19:29:05.623143+00', '2021-03-14 20:21:07.45027+00', 8812, 1, NULL, 'ace', '1–::

  1c set | cross RH, pulling back Rsh to face 2c ; 1c facing 2c set | ½ turn EH (1c passing inside) into 1c BtoB facing opposite side for

9–::

  DTr, finish 1c facing 1cnr

17–::

  Turn CPCP (2,1x,3)

25–::

  2c+1c+3c A&R ; 1c turn RH 1½', 3);
INSERT INTO 'dancecrib' VALUES (2174, '2012-01-22 19:29:23.886587+00', '2019-02-04 18:24:12.258705+00', 1965, 1, NULL, 'ace', '1–::

  All set | cross R ; set | cross R (1,2,3,4)

9–::

  1M+2W & 3W+4M turn 1½ to change places, all face P ; Set to P H.Schottische

17–::

  Parallel Reels4 on the sides

25–::

  1W+2M & 3M+4W turn 1½ to change places ; 2c+1c & 4c+3c ½ R&L (1,2,3,4)

33–::

  Circle8 and back

41–::

  1c+2c ½ RHA | 1c+3c ½ LHA ; 1c+4c ½ RHA | All cross (2,3,4,1)



{{explanation}}

(note: when handing or shoulder is omitted above for turn or cross, that information was not given by the original description.', 3);
INSERT INTO 'dancecrib' VALUES (1800, '2012-01-22 19:29:02.976297+00', '2020-02-10 20:54:29.085858+00', 652, 1, NULL, 'ace', '1–::

  1c turn RH | lead down (2c up) ; cast up round 3c to 2pl | turn LH to finish between end C facing 1cnr

9–::

  Opposing Lsh Reels3 across, but halfway 1c switch reels with quick turn RH, at the end 1c meet and pivot R to face 1cnrs

17–::

  1c+1cnrs change pl. RH _while{2}_ 2cnrs set diagonally | 1cnr persons turn ¾ LH to face 4cnr pos.  _while{2}_ 1c+2cnr persons chase 1 place clw ; 1c+1cnr persons change places RH (on 1diag.) _while{2}_ 2cnr persons set diagonally (on 2diag.) | 1c turn LH 1¼ to face 1cnr again _while{2}_ all cnr persons chase 1 place clw (finish in opposite cnr position)

25–::

  1c ½ Rsh Reel4 with 1cnrs , pass Rsh ; ½ Rsh Reel4 with 2cnrs , passing Rsh to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11056, '2018-09-01 23:28:34.720971+00', '2018-09-01 23:33:51.138024+00', 14121, 1, 202, 'ace', '1-12::
  3C R&L, 1c face out
13-16::
  1c cast (2c up) | dance round P RSh and pivot R to face 1cnrs (2,1,3)
17--::
  SetH&G (2,1,3)
25--::
  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11418, '2018-12-21 13:52:01.548012+00', '2018-12-21 14:28:49.555119+00', 11028, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; cross RH | cast to 3plx (3c up) (2,3,1x)

9--::

  3c+1c ½ R&L ; 2c+1c ½ R&L (1x,2x,3x)

17--::

  All dance BtoB ; all set | turn P RH ½ into promhold facing up (1,2,3)

25--::

  3C Promenade. On [31-32] 1c cast off and 2c dance up (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8204, '2014-02-17 23:24:46.023005+00', '2020-01-15 18:33:27.239822+00', 10504, 1, NULL, 'ace', '1–::

  1c dance down NHJ between 3c (2c up) ; cast up, dance between 2c, and cast to 2pl facing 1cnr, BtoB with P

9–::

  1c+1cnrs Rsh Gypsy turn _while_ the other cnrs set | repeat with 2cnrs ; with 3cnrs | with 4cnrs to finish (2,1,3)

17–::

  Reels3{6} across, 1c Lsh to 1cnr | All turn RH

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (9538, '2017-01-15 23:31:31.336627+00', '2017-01-18 08:10:23.606112+00', 17539, 1, NULL, 'ace', '1--::

  1c+2c (& 3c+4c likewise) “The Spiral Progression”: 1M+2W turn RH ¾ to line of 4 | BiL, but on second step 1W+2M swivel L to face clw and rejoin hands ; line turns ¼ clw | 1M+2W turn RH ¾(to 2,1).  At the end 1M & 4W face out (2,1,4,3)

9--::

  2M+1M+4M & 1W+4W+3W Rsh Reels3 (1M & 4W start out and R), on [15-16] 1M & 4W cross to opposite side in 3pl & 2pl resp. while the others complete the reels

17--::

  2W+1W+1M & 4W+4M+3M Lsh Reels3 (1M & 4W start out and Lsh to P), on [23-24] 1M+4W cross to own sides to (2,1,4,3), 2c+3c facing out

25--::

  2c+3c cast towards the middle, pass inwards between 1c and 4c (the dancer coming from the R goes first) , and dance on own side to other end (3,1,4,2) ; 1c+4c LHA (3,1,4,2)





', 5);
INSERT INTO 'dancecrib' VALUES (13960, '2021-04-17 09:40:02.14376+00', '2021-04-17 09:41:40.075734+00', 9576, 1, 202, 'ace', '1--::
  Parallel Reels3 on sides, 1c LSh to 2c (1,2,3,4)
9--::
  1W+2M turn LH ; 1M+2W turn RH (2,1,3,4)
17--::
  1c cross RH | cast off 2 places (2c+3c up) ; cross LH | cast off (4c up) (2,3,4,1)
25--::
  4c+1c R&L (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11394, '2018-12-17 00:06:08.603964+00', '2019-01-22 23:21:40.526949+00', 15492, 1, 202, 'ace', '1--::

  1M+2W turn RH 1½ _while{4}_ 1W & 2M chase cclw ½ (to 2x,1x) ; 2M+1W turn LH 1½ _while{4}_ 1M & 2W chase clw ½ (1,2)

9--::

  R&L (1,2)

17--::

  Poussette into allemande hold facing up

25--::

  2C Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (9537, '2017-01-15 00:03:55.74818+00', '2017-01-16 00:10:08.346494+00', 2983, 1, NULL, 'ace', '1--::

  1c+2c Circle4 and back (1,2,3)

9--::

  1c turn RH | cast (2c up) ; turn BH ½ (PdB) and swivel R to finish BtoB facing opp. side

17--::

  2c+1W & 1M+3c Reel3 across, Rsh to 1cnr, finish facing 2cnr (2,1x,3)

25--::

  Reels3 on opposite side, Lsh to 2cnr, finish BtoB facing opp. side

33--::

  Modified DTr: Set as in DTr | 1c move ¾ clw round P as corners set ; 2c+1M & 1W+3c set as in DTr | 1c move ¾ clw again as corners set (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10592, '2018-04-07 00:56:18.008296+00', '2018-07-17 10:56:02.588884+00', 4590, 1, NULL, 'ace', '1-::

  1c Adv&amp;Ret ; 1c cross RH | cast to take LH facing down between 3c _while{4}_ 2c Adv&amp;Ret

9-::

  1M+1W followed by 2W+2M cross LH below 3c, cast up, dance up to top &amp; 1c cast off (2x,1,3) | 2c+1c Adv{1} &amp; Ret{1}

17-::

  1M+1W followed by 2W+2M cast off round 3c | lead up _while{4}_ 3c Adv&amp;Ret ; 1c cross RH | cast _while{4}_ 2c dance up and cross to face out _while{4}_ 3c turn RH &amp; face out (2,1x,3)

25-::

  Reels3{6} on sides, 1c RSh to 2cnr | 1c cross RH (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (9542, '2017-01-18 22:06:40.879017+00', '2017-08-22 22:13:56.907954+00', 15000, 2, 160, 'ace', '1-8::

  1C lead down and up to face 1st corners.

9-16::

  Set to and Turn corners.

17-24::

  Half Lsh reel 3 on sides ; Half fig.8 - 1L down, 1M up..

25-32::

  3C 1C 2C - Set & Rotate', 4);
INSERT INTO 'dancecrib' VALUES (11396, '2018-12-17 00:40:10.163459+00', '2019-01-22 23:29:09.155236+00', 15495, 1, 202, 'ace', '1--::

  All M A&R{1+1} _as_ all W set | all W A&R{1+1} _as_ all M set ; all turn P BH twice (1,2,3)

9--::

  1c+2c Set&Rotate (2,1,3)

17--::

  Reels3 on sides, 1c RSh to 4cnrs (2,1,3)

25--::

  1M+3M & 1W+3W turn RH 1½ ; all turn P BH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10591, '2018-04-07 00:46:46.225277+00', '2018-07-20 19:46:52.319071+00', 2552, 1, NULL, 'ace', '*This dance starts with a fugal sequence: 1c, 2c, 3c & 4c dance successively shorter _variations_ of it, starting each 8 bars.*

*The first part of that sequence is repeated in [47-60], alternately up/down the set by 4c, 3c, 1c & 2c starting at 2 bar intervals.*  

*All dancing up/down is with NHJ, all crossing movements are with RH.*

*All full turns are BH in 4 bars, all half turns BH in 2 bars.*

*When a (half) turn is followed by casting, open out to face down/up before casting up/down.*



1-::

  1c set | cross ; cast off | dance down to 4pl centre &amp; take BH. 2c+3c+4c up on [7-8] (2,3,4,1x)

9-::

  1c &frac12; turn BH | cast up round 3c ; dance up to top | cast off _while{8}_  

  2c dance [1-8]. 3c+4c up on [15-16] (3,4,1,2x)

17-::

  1c meet in centre | turn BH down to 4pl | cast up _while{8}_  

  2c dance [9-16] _while{8}_  

  3c dance [1-8]. 4c up on [23-24] (4,2,1,3x)

25-::

  2c+1c stand _while{4}_  

  3c &frac12; turn BH | retire ; 2c+1c+3c stand | step up on [31-32] _while{8}_  

  4c dance [1-8] (2,1,3,4x)

33-::

  1c set | cross ; cast below 4pl &amp; face up NHJ _while{8}_  

  3c set | cross down to 4pl ; stand{4} _while{8}_  

  4c &frac12; turn BH | cast up ; repeat (2,4x,3x,1x)

41-::

  1c dance up to 3pl | cast up to 2pl _while{4}_  

  2c cast off to 2pl | dance down to 3pl _while{4}_  

  4c &frac12; turn BH | retire ;  

  all stand NHJ | 4c set (4,1x,2,3x)

49-::

  4c cross | cast off ; dance down to 4pl centre | &frac12; turn BH _while{8}_  

  3c set | cross ; cast up | dance up to 1pl centre _while{8}_  

  1c stand | set ; cross up | cast off _while{8}_  

  2c stand{4} ; set | cross (3,1,2x,4)

57-::

  3c &frac12; turn BH | cast off _while{4}_  

  1c dance down to 4pl | &frac12; turn BH _while{4}_  

  2c cast up | dance up to 1plx _while{4}_  

  4c cast up | &frac12; turn BH, all are now in the centre (2x,3x,4x,1x) ;  

  All (continue) &frac12; turn BH | retire (2,3,4,1)

', 4);
INSERT INTO 'dancecrib' VALUES (11395, '2018-12-17 00:22:09.850508+00', '2019-01-22 23:25:25.541261+00', 15493, 1, 202, 'ace', '1--::

  2c set advancing passing RSh into DTr[pos] | all set ; 2c dance RSh round P 1½ and face 3cnrs | all set

9--::

  Reel4 on 1diag, pass LSh and face 4cnrs

17--::

  Reel4 on 2diag (1,2,3)

25--::

  1c+2c S&Link ; 1c+3c S&Link (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (9102, '2016-02-29 01:34:24.444202+00', '2018-12-17 11:18:33.282458+00', 16886, 1, NULL, 'ace', '1-::

  1c & 3c set | cast off (2c & 4c up) to face 2cnrs ; 1c & 3c &frac12; diag RSh Reels4 with 2cnrs, end facing 3cnrs

9-::

  1c & 3c set to 3cnrs | 1c & 3c cast RSh round P to 1cnr position _while{2}_ 3cnrs dance into centre & swivel R to face own cnr ;

  repeat, 3cnrs finishing in exchanged places, 1c & 3c facing 4cnrs

17-::

  1s & 3c repeat with 4cnrs ending passing partner RSh to own side (5,1,4,3,2)

25-::

  All chase{6} clw &frac12; way round to (2x,3x,4x,1x,5x) | 2c+3c+4c cross RH _while{2}_ 1c+5c &frac12; RHA to (2,3,4,5,1)

', 5);
INSERT INTO 'dancecrib' VALUES (9539, '2017-01-18 21:40:09.832186+00', '2017-01-18 21:41:38.44837+00', 14996, 2, 160, 'ace', '1-8::
  1C dance down btwn 3C (4) ; cast up round 3C, dance up btwn 2C - face out in top pl.
9-16::
  1C dance down behind own lines to 4pl (2C 3C 4C up on 9-10) . dance up btwn 4C, up behind 3C. 
17-24::
  2C 1C 3C reel 3 own sides - begin 2C out&down, 1C in and up, 3C cast up.
25-32::
  1C turn 3C 1-1/2 (women LH men RH) ; 1C turn 4C 1_1/2 (women RH men LH).', 3);
INSERT INTO 'dancecrib' VALUES (9540, '2017-01-18 21:45:43.788681+00', '2017-01-18 21:45:43.788681+00', 14997, 2, 160, 'ace', '1-8::
  1W 2C Rsh reel 3 across.
9-16::
  1M 2C Lsh reel3 across.
17-24::
  1C lead down the middle and up
25-32::
  1C 2C poussette.', 3);
INSERT INTO 'dancecrib' VALUES (9541, '2017-01-18 21:51:49.319386+00', '2017-01-18 21:51:49.319386+00', 14998, 2, 160, 'ace', '1-8::
  1C dance down (2), set ; dance up, cast 1pl (2C up).
9-16::
  Repeat (3C up and face out).
17-24::
  Reel 3 on opp.sides (1C cross up)
25-32::
  Reel 3 on own sides (1C cross up).', 3);
INSERT INTO 'dancecrib' VALUES (12290, '2019-10-16 04:09:39.2028+00', '2019-10-17 08:19:11.229412+00', 19700, 1, 202, 'ace', '1--::
  1W (1M following) cast off one place | crosses to 2plx (2c up) ; 2c+1c RHA (2,1x)
9--::
  2M (2W following) cast off one place | crosses to 2plx (1c up) ; 1c+2c LHA (1x,2x)
17--::
  1c long cast to 2plx (2c up) ; 2c & 1c turn P RH 1½ (2,1)
25--::
  Circle4 and back (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (1814, '2012-01-22 19:29:03.819726+00', '2021-06-29 09:39:06.691911+00', 715, 1, NULL, 'ace', '{{explanation}}

C face C RR ; a mixer dance. W alternate between two places while M continue round.



1–::

  RHA ; LHA

9–::

  R&L

17–::

  ½ L-Chain ; set to new P | Turn BH and face other C HNJ

25–::

  Dance BtoB with former P and set | pass Rsh to meet new C', 3);
INSERT INTO 'dancecrib' VALUES (11397, '2018-12-17 12:40:52.552668+00', '2018-12-17 12:41:08.287447+00', 19125, 1, 1645, 'ace', '*On 2nd chord, 2c & 4c cross to opposite sides (1,2x,3,4x)*

1-::

  1c+2c & 3c+4c Circle4 & back

9-::

  1c+2c & 3c+4c set facing up/down | turn &frac34; RH ; &frac12; RSh Reels4 across

17-::

  All set to facing person | turn &frac34; RH ; &frac12; RSh Reels4 on the sides to (4,3x,2,1x)

25-::

  2c+1c set | &frac12; RHA (4,3x,1,2x) ; 3c+1c set | &frac12; LHA (4,1x,3,2x)

33-::

  4c+1c set | &frac12; RHA (1,4x,3,2x) ; all chase &frac12; way clw (2,3x,4,1x)

', 5);
INSERT INTO 'dancecrib' VALUES (11398, '2018-12-17 12:42:00.570252+00', '2018-12-17 12:46:02.109459+00', 15887, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c The Espagnole. On [5-8], 1c(4c) turn LH(RH) 1¼ and face P on midline (2,1,4,3)

9--::

  Reel4 on midline to sides (2,1,4,3)

17--::

  All set | Petronella Turn ; all turn P RH 1¼, 2c to 1pl, 1c+4c+3c into allemande hold

25--::

  3C Allemande (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10593, '2018-04-07 10:29:03.622768+00', '2018-07-20 14:02:16.419846+00', 2232, 1, NULL, 'ace', '1-::

  1c in promhold cast off round 2M (2c up) | cross over ; cast off 2pl (3c+4c up) | 1M crosses to (2,3,4,1)

9-::

  1W sets as 1M adv &amp; 1c take crossed hands | 1M ret as 1W adv to M side ; turn &frac34; BH moving up to 3pl | dance out to sides _while{8}_

  2c dance [1-8] (3,4,1,2)

17-::

  1c+2c with NHJ for [17-18] repeat [9-16] _while{8}_ 3c dance [1-8] _while{8}_ 4c lead up RH | dance [1-6] following 3c to centre below 4pl

25-::

  1c+2c+3c repeat [17-20] ; M(W) adv(ret) | M ret _while{8}_ 4c weave up behind 3M, 2W, 1M &amp; out to own sides (4,1,2,3)

33-::

  4c &amp; 2c in promhold cast off round 1M &amp; 3M (1c &amp; 3c up) | swing round to opp sides ;

  1W+4M &amp; 3W+2M turn LH on W side, 1M+4W+3M+2W step in on [40] taking promhold facing up/down/up/down (1,4x,2,3x)

41-::

  1c+4c+3c+2c swing L to start &frac12; LSh Reel4 in 6 bars to (2,3,4x,1x) facing up/up/down/down roughly on centre line |

  2c &amp; 3c dance out _while_ 4c &amp; 1c cross LH to own sides (2,3,4,1)

', 4);
INSERT INTO 'dancecrib' VALUES (3453, '2012-01-22 19:30:26.144655+00', '2019-02-04 18:43:15.5105+00', 6818, 1, NULL, 'ace', '1–::

  1W & 4M set to P | cast off /up one place (2W up, 3M down) ; 1W & 4M repeat (3W & 2M stepping) (to 2W, 3W, 1W, 4W facing 1M, 4M, 2M, 3M)

9–::

  Dancers in 1pl+2pl & 3pl+4pl RHA ; LHA

17–::

  (»Cat''s Cradle«)  4M+2M (in center) dance diagonally out the nearer end | cast in round end W ; cross diagonally to exchanged places (4M, crossing from top, passes in front) | change places LH with end M _while_{8} 3W+1W (in center) cross straight over | cast out round end M ; dance in diagonally to same place | exchange places LH. (2, 1, 3, 4), finishing on midline for:

25–::

  1c+3c+4c Three couple Poussette (to 2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11812, '2019-04-28 10:08:42.039808+00', '2019-04-28 10:08:42.039808+00', 13100, 1, NULL, 'ace', '*Starting positions: 5 dancers numbered clockwise, 1+2 in Line of 2 across facing the gaps between 3+4+5 forming line of three across* 



1--::

  1 & 2 Parallel Figs8 round (4+5) & (3+4): 1 & 2 dance down, Lsh round 4 & 3 ; Rsh round 5 & 4, to places (1,2,3,4,5)

9--::

  Circle5 L and back (1,2,3,4,5)

17--::

  In facing lines S&Link twice (in 3C S&Link the LH dancer moves 2 pl R and the others 1 pl L) (1,2,4,5,3)

25--::

  (1+2)+(5+3) ½ Diag. R&L, starting up/down (5,3,4,1,2); repeat on other diagonal (4,1,5,3,2)

', 3);
INSERT INTO 'dancecrib' VALUES (11399, '2018-12-17 12:42:34.080789+00', '2018-12-17 15:03:59.277746+00', 19127, 1, 1645, 'ace', '1-::  1c cross RH | cast (2c up) ; 2c+1M & 1W+3c RHA
9-::  3C Tourbillon: 2c & 3c &frac12; turn BH to sides _while_ 1c cast R | all set on the sides ;
      1c &frac12; turn BH the person on their R who ends opposite them _while_ 2W & 3M cast inwards to 2pl |
      all cross RH (M side: 3W,2W,1W; W side: 1M,3M,2M)
17-:: All set | cross RH ; all set adv | cast, LSh back, to own side, still opposite new partner
25-:: 3C Bourrel ending back with original partner (2,1,3)
', 5);
INSERT INTO 'dancecrib' VALUES (1802, '2012-01-22 19:29:03.084681+00', '2019-10-16 21:26:44.600273+00', 658, 1, NULL, 'ace', '1–::

  Introduction: all stand [1-4] ; bow/curtsey to P [5-6], bow/curtsey to corner [7-8].

9–::

  1c+3c advance RHJ | RHJ with person opposite dance out between side couples, cross and meet own P in opposite place | Turn P RH to finish with W on left of M.

17–::

  2c+4c repeat ; finish all M facing out, W facing in (3x,4x,1x,2x)

25–::

  Intersecting Reels4 (quick ½ LHA in the middle), at end all W dance ½ place clw to join RH with next man (1W+2M, etc.)

33–::

  All pairs turn W under joined arms into Allemande hold and dance cclw half round {5}, all M turn W as in Allemande to face them along the circle (M face cclw, W clw) {1} | All pull back Rsh & cast to original places, passing P Rsh, and face P (1,2,3,4)

41–::

  Gr-Chain (1 bar per hand)

49–::

  All set to P and turn P BH, into ; 1c+4c & 2c+3c circle4 L, into

57–::

  Circle8 and back (1,2,3,4)', 3);
INSERT INTO 'dancecrib' VALUES (10735, '2018-05-02 20:24:21.855281+00', '2018-05-03 00:04:43.843629+00', 18311, 1, 202, 'ace', '1--::

  1c facing 3c set | advance, with person opposite dance out between side cpls to original places (1,2,3,4)

9--::

  All W advance, Circle4 L ½, pulling Rsh back to face out _while{4}_ all M chase cclw ½ ; all set to P | turn P BH ¾ and face P (3,4,1,2)

17--::

  All La Baratte | chase cclw one place (4,1,2,3)

25--::

  Double (intersecting) La-Chain (4,1,2,3)', 4);
INSERT INTO 'dancecrib' VALUES (11057, '2018-09-02 06:09:04.269909+00', '2018-09-02 06:15:23.287954+00', 17279, 1, 202, 'ace', '1--::

  1c A&R {1+1} | cross RH ; turn down LH ¾ into lines3 across, 1c facing 1cnrs (2c up on [5-6])

9--::

  1c+1cnrs set | turn BH, 1c face 4cnrs ; ½ Reels3 across, 1c LSh to 4cnrs, to 2plx facing 2cnrs[pos] (2x,1x,3x)

17--::

  1c+2cnrs[pos] set | turn BH, 1c face 1cnrs[pos] ; ½ Reels3 on sidelines, 1c LSh to 1cnrs[pos] (3x,1x,2x)

25--::

  All W & all M Circle3 L opening (3c leading) into Circle6 ½ (to 2,1,3) | all set', 2);
INSERT INTO 'dancecrib' VALUES (14635, '2022-03-06 19:07:35.12267+00', '2022-03-06 19:08:43.0678+00', 13286, 1, 1645, 'ace', '1--::

  1c & 5c cast inwards (2c & 4c out) | turn LH & cast L to lines of 3/4/3 across facing 1cnrs

9--::

  1W+2c & 5M+4c RSh Reels3 across _while_ 1M+5W+3c RSh Reel4 across. 1W/5M end between 2c/4c, 1M & 5W end BtoB on centre line facing up/down to P

17--::

  1c+5c Reel4 on centre line ending RSh to P facing own side

  _while{8}_ 2c set adv | turn BH ; 2c+3c change pl RH on sides | 2c+4c change pl LH (3,1,4,5,2)

25--::

  1c & 5c Fig8 on own sides starting RSh round 3cnr _while{8}_ 3c+4c+2c cross RH | set ; cross RH | set (3,1,4,5,2)

', 2);
INSERT INTO 'dancecrib' VALUES (9543, '2017-01-19 17:57:53.134706+00', '2017-08-26 01:02:23.892842+00', 17540, 1, NULL, 'ace', '1-::

 1c set | cross RH ; cast (2c up) | all set (2,1x,3)

9-::

 ½ Reel3 across (1c Rsh to 4cnr), to (2x,1,3x) ; ½ Reel3 on sides (1c Lsh to 3cnr positions) (3x,1,2x)

17-::

 Diagonal R&L (2,1,3)

25-::

 1c+3c "Rose Progression" : 1W+3M change place RH | cast 1 place clw ; turn BH ½, face and twirl away _while{8}_ 1M+3W set | turn BH ½, face and twirl away | cross to other side (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (8034, '2013-09-15 20:22:41.050923+00', '2018-09-02 19:27:25.256879+00', 14271, 1, NULL, 'ace', '1–::

  1c set adv and give RH | 1W turns under own arm to face W side with P behind ; 1c cast behind 2W and cross (2c up) and 1c face 2c (2,1x,3)

9–::

  2W+1M & 2M+1W repeat [1-4] LH ; chase round square ¾ cclw (1c to M side, 2c to W side)

17–::

  1c & 2c advance NHJ, turn towards P and dance out NHJ and face out ; 1W+2W dance to L and cross _while{4}_ 1M+2M dance towards P guiding her RH, and follow her (2x,1,3)

25–::

  2c+1c+3c set | 2c cross RH and stand _while{6}_ 1c+3c complete S&Rotate (2,3,1)

33–::

  1c+3c set | dance up between 2c and cast to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11404, '2018-12-17 15:40:01.576177+00', '2021-06-05 09:26:27.669013+00', 18841, 2, 160, 'ace', '1-8::  1C 2C R&L [6 bars] , set to partners.

9-16::  1C 3C RHA; LHA.

17-24::  1C 3C poussette.

25-32::  1C 4C turn RH 1-1/2 on sides to change places; circle 4hands round to the left.', 3);
INSERT INTO 'dancecrib' VALUES (3335, '2012-01-22 19:30:21.008946+00', '2019-04-28 15:01:33.606797+00', 6373, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up), pass Lsh and cast R round 1cnr, to finish BtoB in the centre, M facing down, W up

9–::

  1W+2c & 1M+3c circle3, at end 1c swivels R to face P ; 1c set, turn ¾ BH to face 1cnrs (open out with 1M using RH to assist P)

17–::

  Turn CPCP

25–::

  Reels3{6} with corners, Lsh to 1cnr, 1c cross RH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11405, '2018-12-17 15:56:31.123634+00', '2018-12-17 15:56:31.123634+00', 18910, 2, 160, 'ace', '1-8::  1C cross down 2places, cast up behind 3C; cross over Lsh, cast up behind 2C to original places. 1W is dancing fig 8 on diagonal around 3M+2W - similarly 1M is dancing fig.8 around 3W+2M.
9-16::  1C set, cross RH; cast 1place, turn LH to 1cor.
17-24::  Set to corner-partner (Hello-Goodbye), turn RH to face out an end - 1M up, 1W down.
25-32::  Reel3 across -  begin Rsh to 2cor.', 3);
INSERT INTO 'dancecrib' VALUES (11401, '2018-12-17 12:59:45.419365+00', '2018-12-17 13:02:43.05392+00', 19128, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; cross down LH between 3c and cast up (2,1,3)

9--::

  ½ Reels3 across, 1c LSh to 1cnrs (to 2x,1x,3x) ; ½ Reels3 on sides, 1c RSh to 2cnrs (3x,1x,2x)

17-28::

  3C R&L (3x,1x,2x)

29-32::

  All set | cross RH (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (11402, '2018-12-17 13:41:14.713623+00', '2018-12-17 13:45:47.885151+00', 16169, 1, 202, 'ace', '1--::

  All cross RH | 1W+2M & 3W+4M turn RH 1½ _while{4}_ their P chase clw ½ | all set (2,1,4,3)

9--::

  1c & 4c turn RH ¾ | 1W+2c & 4M+3c LHA _while{4}_ 1M+4W turn LH | 1c & 4c turn RH ¾ into centre. 1c(4c) face up(down) (2,1x,4x,3)

17--::

  1c & 4c dance thrrough nearest ends and cast (to 2,1,4,3) ; 1c+4c S&Link (2,4,1,3)

25--::

  Circle8 and back (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10736, '2018-05-03 07:54:31.796464+00', '2018-05-03 08:05:01.422675+00', 2705, 1, 202, 'ace', '1--::

  1c lead down {2} | set to P (2c up) ; turn RH 1½ (2,1x,3)

9--::

  1c set _while{2}_ 2c & 3c cross RH | Mirror Reels3 {6}, 1c start in and up (2x,1x,3x)

17--::

  1c ½ Fig8 L round 4cnrs _while{4}_ 2c & 3c set | cross RH ; all dance BtoB (2,1,3)

25--::

  All turn P BH ; Circle6 L', 2);
INSERT INTO 'dancecrib' VALUES (9544, '2017-01-20 23:41:43.584115+00', '2017-01-20 23:41:43.584115+00', 15201, 1, NULL, 'ace', '*Couple face couple RR, 1c face clw, 2c cclw*

1--::

  All set to person opposite | set to P ; All Turn P RH

9--::

  1c, 1M leading, dance Fig8 round 2c, Lsh to 2W, to place 

17--::

  2c repeat, 2M Lsh to 1W

25--::

  1c+2c ½ RHA | ½ LHA with next cpl ; ½ RHA with next cpl | ½ LHA with next cpl

', 3);
INSERT INTO 'dancecrib' VALUES (11406, '2018-12-17 18:47:26.454818+00', '2018-12-17 18:48:02.207292+00', 18483, 1, 202, 'ace', '1--::

  1c Fig8 on sides, starting in and down (1,2,3,4)

9--::

  Circle8 and back. 1c face down, 2c up (1,2,3,4)

17--::

  1c & 2c set on sides | 1c cross down and face 3c (2c dance up) ; 1c & 3c repeat (2,3,1,4)

25--::

  1c & 4c set on sides | change places BH (PdB) ; all A&R with 4 claps (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11407, '2018-12-17 19:57:19.423908+00', '2018-12-17 20:02:04.010153+00', 7326, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; cross RH | cast R round 1cnrs into facing lines3 across

9--::

  All A&R ; all advance{2}, on [14] 1c turn BH ½ and change places | all retire{2}

17--::

  1c Reels3 {6} on sides, 1c LSh to 4cnrs finishing back as on [16] | 1c turn P RH ¾ to 2pl _while{8}_ 2c & 3c Reels3 on sides (2,1,3)

25--::

  1c+3c The Knot (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12835, '2020-05-16 22:19:44.335591+00', '2021-04-07 18:57:42.062871+00', 3238, 2, 2784, 'ace', 'U-shaped set: 1c in centre, facing down; 2c on M’s side, 3c on W’s side; M with P on L

1-8::

  All set to P, turn RH, set to P, turn RH 1.1/4 to finish M back to back in centre of set

9-::

  Clover leaf reel {12}, set to P and turn RH to original places {4}

25-::

  Turning reel of 3: 1c turn RH to start, 2c & 3c pass P RS; when people meet in 1pl they turn RH; finish in original places

33-::

  Circle L for 4, back for 2, turn P BH into new positions (3c at top, 1c on M’s side, 2c on W’s side)', 4);
INSERT INTO 'dancecrib' VALUES (12659, '2020-03-10 20:46:08.404889+00', '2020-03-10 20:48:29.096825+00', 7077, 1, NULL, 'ace', '1--::

  All W cast behind P and chase clw outside the set, to places

9--::

  All M cast behind P and chase cclw outside the set, to places

17--::

  1c+3c A&R ; dance BtoB

25--::

  2c+4c repeat

33--::

  All circle8 and back OR all face L and chase clw to places

', 3);
INSERT INTO 'dancecrib' VALUES (11412, '2018-12-21 07:55:39.422475+00', '2018-12-21 07:58:51.441792+00', 11021, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA ; set | 1c turn LH to face 1cnrs _as_ 2c cross LH (2,1,3)

9--::

  Corners Pass and Turn. 1c face 3cnrs

17--::

  Corners Pass and Turn (2,1,3)

25--::

  1c ½ Fig8 L (to 2,1x,3) ; turn RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11413, '2018-12-21 10:57:33.974127+00', '2018-12-21 11:00:05.176741+00', 11022, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; turn LH (2,1,3)

9--::

  3C Diagonal R&L (3x,1,2x)

17--::

  3c & 2c Petronella Turn | set ; repeat [17-20] _while{8}_ 1c chase clw between nearest ends to 2plx | pass RSh to 2pl (3,1,2)

25--::

  3C Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11415, '2018-12-21 12:48:55.953197+00', '2018-12-21 12:53:04.008728+00', 11023, 1, 202, 'ace', '1--::

  1c & 2c turn RH ½ | 1c+2c ½ RHA ; 1c & 3c turn RH ½ | 1c+3c ½ RHA (2,3,1)

9--::

  2c & 3c turn RH ½ | 2c+3c ½ RHA (to 3,2,1) ; 1c lead up to top (2c down) | cast to 2pl (3,1,2)

17--::

  3C Knot (2,1,3)

25--::

  1c lead up to top, cross and cast to 2plx ; lead down to bottom, cross and cast to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15366, '2022-12-26 00:04:21.24308+00', '2022-12-26 00:04:32.406067+00', 21216, 1, 1645, 'ace', '*3 persons in a triangle numbered clockwise 1,2,3 from the top*

1--::

  1+2+3 RHA ; LHA

9--::

  1 sets as in DTr with 2+3 | all adv & pull back RSh to invert triangle ; repeat

17--::

  1+2 set | cross RH ; 1+3 set | cross RH (2,3,1)

25--::

  Circle3 to L & back (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11408, '2018-12-20 03:09:14.9682+00', '2021-02-10 14:06:32.954441+00', 10236, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; cross RH cast R round 1cnrs into lines3 across

9--::

  Reels3 on sides, 1c RSh to 1cnrs into DTr[pos] facing opp sides

17--::

  DTr. On [23-24] 1c pivot R to finish in the middle facing W side NHJ, 1M on L

25--::

  1c dance out, split and cast round the W ; meet, dance out between the M, split and cast to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12660, '2020-03-10 23:54:34.122952+00', '2021-07-15 22:10:38.134757+00', 17318, 1, NULL, 'ace', '1--::

  1c+2c R&L (1,2,3)

9--::

  1c face 2c set and turn opposite EH, 2c starting outwards ; 2c (outwards) +3c repeat

17--::

  Mirror Reels3 on the sides, 2c start out and up (1,2,3)

25-28::

  1c+2c Circle4 L ½ | turn P BH _while{4}_ 3c stand | turn P BH ½ (2x,1x,3x)

29-32::

  1c+3c Circle4 L ½ | turn P BH _while{4}_  2c stand | turn P BH ½ (2,3,1) 

', 3);
INSERT INTO 'dancecrib' VALUES (14348, '2021-10-04 07:01:16.753288+00', '2021-10-04 07:02:44.54425+00', 13760, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; lead down LH and cross to 2pl (2,1,3)
9--::
  *Swing Corners* : 1c turn P RH ¾ to face 1cnrs | turn 1cnrs LH ; turn P RH ½ to face 3cnrs | turn 3cnrs LH. Cnrs dance continuously (2,1,3) 
17--::
  1c turn P LH ¾ to face 2cnrs | turn 2cnrs RH ; turn P LH ½ to face 4cnrs | turn 4cnrs RH. Cnrs dance continuously (2,1,3)
25--::
  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12291, '2019-10-17 01:44:35.032994+00', '2019-10-17 01:46:00.036075+00', 18124, 1, 202, 'ace', '1--::

  1c lead down ; and back. On [7] 1c cross over to 1plx (1x,2)

9--::

  1c & 2c dance BtoB ; set | 1W+2W cross LH (1M,1W on Wside, 2W,2M on Mside)

17--::

  »Modified Helix« [: 1M & 2M turn opposite W RH ¾ into midline. 1c(2c) face Wside/Mside | 2W+1W turn LH  _while{4}_ 1M & 3M chase clw ½ | 2c+ 1c turn RH ¾ to sides] (2,1x)

25--::

  1c set | ½ Fig8 up round 2c | set (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (12292, '2019-10-17 22:41:31.24492+00', '2019-10-17 22:52:30.768242+00', 15434, 1, NULL, 'ace', '1--::

  1c+2c dance the Bourrel, 1c finish facing 1cnr ; 

9--::

  1c set to 1cnr and face P | turn P RH to face 2cnr ; set to 2cnr and face P | turn RH to (2,1,3)

17--::

  All set and cross ; repeat 

25--::

  Circle6 and back (2,1,3)









', 3);
INSERT INTO 'dancecrib' VALUES (12293, '2019-10-17 22:42:45.83722+00', '2019-10-18 15:27:35.422116+00', 7999, 2, 108, 'ace', '1-4::  1C set, then passing R shoulders (no hands), dance half round to face in the centre of the set
5-8::  1C set, and again passing R shoulders, dance to original places

9-14::  1C and 2C dance right hands across for three steps, then left hands across back to places; 1C face down and 2C face up
15-16::  1W and 2W, also 1M and 2M change places passing L shoulders;  2C face across, 1C face down

17-24::  2C 1C and 3C dance grand chain

25-28::  1W followed by 2W, also 1M followed by 2M, dance down behind 3C, meet partners below 3C and dance up the centre;  at the end, men dance slightly ahead and join both hands with partner facing diagonally, ready for
29-32::  1C and 2C dance half poussette', 3);
INSERT INTO 'dancecrib' VALUES (2461, '2012-01-22 19:29:40.196972+00', '2019-02-05 11:25:17.404172+00', 3057, 1, NULL, 'ace', '1--::

   Circle8 L and back

9--::

  All W pass in front of P, dance behind next M ; RHA in the centre

17--::

   All W cross in front of opposite M, dance behind next M ; RHA, joining P for

25--::

  All Promenade once round clw (but see note)

33--::

  1c+3c (W following M) dance on 1 place clw and in (M round M, W round W) to face next couple ; set to and turn that person RH

41--::

  Reels4 across

49--::

  Fig8, 1c round 2c, 3c round 4c

57--::

  1c+3c LHA ; 1c/3c dance out Lsh round 2c/4c (M round M, W round W) and cclw to places

65--96::

  2c+4c repeat bars 33-64

97--::

  All Promenade once round cclw

105-120::

  The Men repeat [9-24] cclw with LHA in the centre

121--::

  Circle8 RIGHT and back (see note)



{{explanation}}

Note: This crib follows the current way of dancing.  In the original instructions, the promenade [25-32] is cclw. Bill Hamilton said in ''hindsight'' this promenade should be clw, but preferred not to change the official instructions.  Bill disapproved of another variant, where the circle [121-128] is continued to the R only.', 3);
INSERT INTO 'dancecrib' VALUES (11414, '2018-12-21 11:08:27.929442+00', '2019-01-04 16:22:46.098203+00', 19129, 1, 1645, 'ace', '1-::

  1c cross down into mirror Reels3 on opposite sides (1x,2,3)

9-::

  1c cross back into mirror Reels3 on own sides (1,2,3)

17-::

  1c dance down | turn BH ; dance up | turn BH

25-::

  1c+2c Rose progression (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11416, '2018-12-21 13:01:45.665546+00', '2019-02-05 00:14:52.815502+00', 11024, 1, 202, 'ace', '1--::

  2c & 3c Fig8 round nearest ends (1,2,3,4)

9--::

  Gr-Chain (1,2,3,4)

17--::

  2c+3c turn RH 1½ on sides (to 1,3,2,4) ; 1c+3c & 2c+4c S&Link (3,1,4,2)

25--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (2923, '2012-01-22 19:30:03.095322+00', '2019-02-05 11:28:46.184249+00', 4933, 1, NULL, 'ace', '{{explanation}}

figure 1



1-16::

  All set to P, change places RH ; circle8 and back ; all set to P, change places RH to own places

17–::

  1c+3c (BHJ) slip in a curve to change places (M back-to-back), set (inside foot) ; slip back (W back-to-back), set (R foot) and face in

25–::

  2c+4c repeat



{{explanation}}

figure 2



33–::

  All W RHA, Lsh round P, to places

41–::

  All set to P, dance BtoB, set

49–::

  All M LHA, Rsh round P, to places

57–::

  All set to P, dance BtoB, set



{{explanation}}

figure 3



65–::

  1M+3W Fig8 round 2c _while_{8} 1W+3M Fig8 round 4c (2c+4c spread apart, close at end)

73–::

  In promhold 1c dance Rsh round 4c and 3c round 2c ; 1c+3c dance Lsh round each other in the middle, to places

81-96::

  2c+4c repeat



{{explanation}}

figure 4



97–::

  All W R&L, starting 1W+2W & 3W+4W crossing

105–::

  All M R&L, starting 1M+4M & 2M+3M crossing

113-128::

  All set to P, change places RH ; circle8 and back ; all set to P, change places RH, to own places', 3);
INSERT INTO 'dancecrib' VALUES (2352, '2012-01-22 19:29:32.787598+00', '2020-02-10 15:51:09.637079+00', 8481, 1, NULL, 'ace', '1–::

  1c slip down (2c up) ; lead up RHJ and face 1cnr

9–::

  Set twice to 1cnr ; set twice to 2cnr

17–::

  Reels3{6} on the sides, Rsh to 2cnr | 1c cross RH



{{explanation}}

Note: There is a 32-bar version of this dance, by adding Circle6 and back..', 2);
INSERT INTO 'dancecrib' VALUES (11058, '2018-09-03 06:03:08.008165+00', '2018-09-03 06:08:26.069937+00', 14132, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c cross up no hands) ; cross LH (3c cross up no hands) (2x,3x,1,4)

9--::

  1c+4c ½ R&L ; all turn P RH 1½ (2,3,4,1)

17--::

  1c cross RH | cast up (4c down) ; cross up LH (3c down) | cast up (2c down) (1,2,3,4)

25--::

  1c dance down to 4pl (2c+3c+4c up) ; all turn P LH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11409, '2018-12-20 20:12:09.475405+00', '2019-02-24 10:35:29.286732+00', 11015, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; 1c+3c RHA (2,1x,3)

9--::

  1c+2c LHA ; 1M followed by 1W cast up round 2W and dance down to face 3W

17--::

  ½ Tandem Reel3 on 1diag with lead change. 1c (1W leading) face 2W ; ½ Tandem Reel3 on 2diag with lead change. 1c (1M leading) face 3W

25--::

  ½ Tandem Reel3 on 2diag with lead change. 1c (1W leading) face 2W ; ½ Tandem Reel3 on 2diag with lead change to 2plx (2,1x,3)

33--::

  1M followed by 1W cast off round 3W and dance up to 2plx ; 1c turn RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13815, '2021-03-14 11:19:48.082056+00', '2021-03-14 12:07:09.753682+00', 20261, 1, 202, 'ace', '*2c, 4c & 6c start on opposite sides*

1--::

  1c+2c & 3c+4c & 5c+6c S&Link ; Circle4 L. Odd couples face up, even couples down, all NHJ (2x,1,4x,3,6x,5)

9--::

  All S&Link across ; Circle4 L (2,1x,4,3x,6,5x)

17--::

  2c+1c & 4c+3c & 6c+5c L-Chain (2,1x,4,3x,6,5x)

25--::

  1c+4c & 3c+6c set | ½ RHA  ; 4c,1c,6c,3c turn P RH (2,4x,1,6x,3,5x)



*Deviser''s note* : 1st couple progresses 2 places to 3rd place, then 2 places to 5th place, then 1 place to 6th place,

then up 2 places to 4th place, then up 2 places to 2nd place, then up 1 place to 1st place.', 2);
INSERT INTO 'dancecrib' VALUES (11611, '2019-02-25 15:46:46.987913+00', '2019-02-25 15:46:46.987913+00', 13779, 1, NULL, 'ace', '1--::  1c+2c RHA ; LHA

9--::  1W dances Lsh round 1M, in front of 2M & 3M, behind 4M and crosses to 4Wpl _while{8}_  2W+3W+4W dance Lsh round P and cross back to W sides into top three places, and wait

17--::  M do likewise (2,3,4,1)

25--::  Circle8 and back





', 3);
INSERT INTO 'dancecrib' VALUES (3790, '2013-07-13 15:56:07.127858+00', '2021-03-14 20:23:48.250617+00', 14652, 1, NULL, 'ace', '1–::

  1M+2c advance to meet {1} retire {1} | dance clw to next position in triangle ; 1W+1M+2W repeat (2,1,3)

9–::

  2c+1c+3c Circle6 and back

17–::

  S&Link3 twice (3x,1x,2x)

25–::

  [1c turn RH ½ and twirl] _while_ [3W+1M, on 1diag, wait {2} and repeat] _while_ [3M+1W, on 2diag, wait {4} and repeat] (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3655, '2012-11-29 13:14:54.863946+00', '2021-03-14 23:20:28.357883+00', 8725, 2, 1, 'ace', '1-::

  1c set | cross R ; cast (2c up) | turn L ¾ to 1cnr

9-::

  1c turn 1cnr R, pass RS to 2cnr

13-24::

  1c R 9-12 with 2cnr, 3cnr, 4cnr, finish between cnrs

25-::

  Reels3 w/cnrs starting RS to 1cnr, on 31-32 1c dance diagonally

  across to 2pl own sides

', 4);
INSERT INTO 'dancecrib' VALUES (14064, '2021-06-13 12:23:58.690211+00', '2021-06-13 12:58:26.531914+00', 135, 1, 1645, 'ace', '1-::

  1c & 4c turn RH | cast inwards (2,1,4,3) ; set facing diagonally | &frac12; RHA to face corners

9-::

  1c & 4c double H&G setting ending 1M/4W in lines across between 2c/3c, 1W/4M on W/M sides

17-32::

  *Simultaneous Reels3 around the set:* four &frac12; Reels3, 1c & 4c starting RSh to person on their R, 2 bars per shoulder (4 bars per side) ending in same places

33-::

  1c & 4c set | 1M & 4W petronella to sides (2,1,4,3) ; 1c & 4c set | &frac12; turn RH retaining hands

41-::

  1c+4c RHA ; &frac12; R&L (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11419, '2018-12-22 10:20:21.123965+00', '2018-12-22 16:25:36.564962+00', 10040, 1, 202, 'ace', '*3-couple set with an extra dancer named No7 who starts in centre between 1c[pos] & 2c[pos] facing M side when No7 is a M, W side when No7 will be a W*



1--::

  1c+2c R&L _while{8}_ No7 chase cclw round 2M, across the set then behind W side and down the middle to original place (1c,No7,2c,3c)

9--::

  No7+1M+2M RHA ; No7+1W+2W LHA (1c,No7,2c,3c)

17--::

  No7 dance down the middle _as_ 1c then 2c (dancing up to begin)  lead down behind No7 ; and up to own sides (2c leading) except No7 to centre between 2c[pos] & 3c[pos] (2c,1c,No7,3c)

25--::

  No7 (facing up) set _while{2}_ 2c+1c+3c set | No7 set to face down _while{2}_ 1c cast to 3pl (3c up) ; No7+1W turn RH | No7+1M change places LH, 1M dancing to centre between 1c[pos] & 2c[pos] as new No7 facing M side



*Deviser''s note:  

1. At the end of the 4th time through*

29-32::

  No7+1M turn LH | No7+1W change places RH, 1W dancing to centre between 1c[pos] & 2c[pos] as new No7 facing W side  



*2. The original No7 will dance the last time through.*', 2);
INSERT INTO 'dancecrib' VALUES (12296, '2019-10-19 16:12:22.645399+00', '2019-10-19 16:25:33.424504+00', 2459, 1, NULL, 'ace', '1--::

  1M+2W turn RH ½ and cast R to exchanged places ; 1W+2M repeat (2x,1x,3)

9--::

  1M+3M repeat ; 1W+3W repeat (2x,3x,1)

17--::

  3c+1c ½ R&L ; 2c+1c set and cross (2,1,3)

25--::

  2c+1c (cross up) DblFig8 (2,1,3)

', 0);
INSERT INTO 'dancecrib' VALUES (10776, '2018-05-20 11:30:56.496334+00', '2022-02-05 07:13:58.196566+00', 15363, 1, 202, 'ace', '1--::
  1c long cast (2c up) ; ½ Fig8 R round 1cnrs (2,1x,3)
9-24::
  3C R&L | 1c ½ Fig8 R round 3cnrs (2,1,3)
25--::
  1c+3c »Rose Progression« [1W+3M change place RH | chase 1 place clw ; turn BH ½, face and cast away _while{8}_ 1M+3W set | turn BH ½, face and cast away | chase 1 place clw] (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3150, '2012-01-22 19:30:13.466805+00', '2020-08-27 09:38:29.842928+00', 5731, 1, NULL, 'ace', '1–::

  1W face down, 2W face across, 2M face up, 1M face across, all chase round the square to places

9–::

  1c+2c RHA, LHA

17–::

  1c lead down the middle and up

25–::

  1c+2c Poussette.', 2);
INSERT INTO 'dancecrib' VALUES (12295, '2019-10-18 12:11:50.402421+00', '2019-10-18 13:19:13.894715+00', 7378, 1, NULL, 'ace', '1--::

  1c (cross down) +3c ½ DblFig8 round 2c (1x,2,3x) ; 1c+3c set | turn P BH ¾

9--::

  1c+3c ½ Rsh Reel4 on midline, at end the middle dancers (3M & 1W) pivot L to face the 2c dancer on own side ; 3c & 1c (each in tandem) with 2c dance ½ Rsh Reel4 across, 1c+3c change lead in the loops, and at end veer R to midline (1M,1W,3M,3W), and all pivot R

17--::

  Repeat [13-16] (identical figure, rotated 180 degrees), at end 3M+1W pivot R to face P  ; 3c+1c ½ Rsh Reel4 on midline

25--::

  1c+3c turn P BH ¾ | All set (1,2,3) ; 1c+2c ½ RHA and keep RH with P | 2c+1c turn P RH ½ (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12661, '2020-03-11 00:55:03.81249+00', '2020-03-11 01:00:34.701922+00', 19722, 1, NULL, 'ace', '1--::

  All A&R twice (1,2,3,4)

9--::

  1c+2c & 3c+4c RHA ; LHA

17--::

  All dance BtoB with P ; 1c+2c & 3c+4c dance BtoB with each other on sidelines

25--::

  1c (start inwards) facing 2c turn opposite EH ½, | 1c (start outwards) +3c repeat, ; 1c (start inwards) facing 4c turn opposite EH 1½ (2,3,4,1)







', 3);
INSERT INTO 'dancecrib' VALUES (10554, '2018-03-28 00:00:57.749703+00', '2018-05-03 23:03:46.06589+00', 17054, 1, NULL, 'ace', '1--::

  1c long cast to 2pl (2c up on [3-4]) ; All Turn RH (2,1,3)

9--::

  2c+1c+3c promenade

17--::

  1c dance up NHJ and cast off ; dance down NHJ and cast up (2,1,3) 

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10740, '2018-05-03 17:34:30.729887+00', '2018-05-03 17:42:37.117069+00', 6242, 1, 202, 'ace', '1--::

  1c+2c+3c turn P BH ; all chase clw ½ (3x,2x,1x)

9--::

  2c turn P BH 1½ _while{4}_ 3c & 1c chase clw ½ to places ; 1c+2c RHA (1,2,3)

17--::

  Parallel Reels3 on sidelines, 1c start Rsh to 2c (1,2,3)

25--::

  1c+2c set | ½ R&L | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10739, '2018-05-03 17:21:45.977417+00', '2018-05-03 17:54:35.397932+00', 18301, 1, 202, 'ace', '1--::

  Circle8 and back (1,2,3,4)

9--::

  1c+2c & 3c+4c ½ RHA | 1c+4c Circle4 L | 2c+1c & 4c+3c ½ RHA (1,2,3,4)

17--::

  1c & 3c Fig8 down round 2c/4c (1,2,3,4)

25--::

  2c & 4c set | 4c lead up to 2pl _while{2}_ 2c cast to 4pl (to 1,4,3,2) ; 2c make an arch BHJ and dance up to 1pl _while{4}_ 1c followed by 4c & 3c dance down under the arch (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12297, '2019-10-19 23:09:47.84089+00', '2019-10-19 23:17:18.887931+00', 18127, 1, 202, 'ace', '1--::
  1c & 3c A&R touching LH ; turn P RH and face out (1,2,3)
9--::
  Reels3 on sides, 2c LSh to 3cnrs (1,2,3)
17--::
  1c+2c Allemande (2,1,3)
25--::
  2c+1W & 1M+3c RHA, pass RSh ; 2c+1M & 1W+3c LHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12298, '2019-10-19 23:29:47.102386+00', '2019-10-19 23:33:43.037636+00', 18133, 1, 202, 'ace', '1--::

  1c ½ Fig8 down round 2c ; 1c cross down LH to 2plx (2c up) | all set (2,1,3)

9--::

  1c Petronella Turn _while{2}_ 2c & 3c change places RH on sides | lines3 across set ; 1c Petronella Turn to 2plx _while{2}_ 2c & 3c cross RH | all set (3x,1x,2x)

17--::

  Diagonal R&L (2,1x,3)

25--::

  Reels3 {6} on sides | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12961, '2020-07-16 08:36:27.271025+00', '2020-07-16 09:47:56.33087+00', 20048, 2, NULL, 'ace', '1–4::

    1s set, cast off (2s step up)

5–8::

    4s set, cast up (3s step down)

9–12::

    2nd L and 3rd M dance Petronella Turn and set

13–16::

    2nd M and 3rd L dance Petronella Turn and set

17–20::

    2s and 3s dance half a reel of 4

21–24::

    2nd L and 3rd M, followed by their partners, dance half a chase clockwise

25–28::

    1s and 4s Set+Link with no hands given

29–32::

    All 4 cpls dance BtoB   2 4 1 3', 5);
INSERT INTO 'dancecrib' VALUES (1597, '2012-01-20 13:06:12.837856+00', '2020-07-17 17:16:58.489173+00', 13676, 2, 1, 'ace', '1-8::

  1C+2C set ; cross R | set & link

9-16::

  2C+1C dance »4 hands round w/crossing turns«: 2C+1C circle L ⅜ ; 1M+2W turn R ⅞

  *while* 1W+2M chase cw ⅜ ; 1M+2W chase cw ⅜ *while* 1W+2M turn R ⅞ ;

  2C+1C circle L ⅜ [fin w/nearer H joined, 2C facing down, 1C up]

17-24::

  2C+1C set ; cross R w/facing person | set & link [1C facing down, 2C up, fin in

  own sidelines]

25-32::

  1C+2C Knot

', 3);
INSERT INTO 'dancecrib' VALUES (15368, '2022-12-26 12:15:41.914901+00', '2022-12-26 12:19:26.827976+00', 13387, 1, 202, 'ace', '1-4::

  1c turn RH | cast off (2c up)

5-16::

  3C R&L (2,1,3)

17--::

  ½ Reel4 on 1diag, 1c pass RSh ; ½ Reel4 on 2diag (3x,1x,2x)

25--::

  *The Serpentine* : (middle couple always starts inwards} 1c+2c change places EH | 3c+2c (other hand) repeat ; 3c (other hand) +1c repeat, 2c+1c+3c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14349, '2021-10-04 07:31:00.985808+00', '2021-10-04 07:35:07.098875+00', 13759, 1, 202, 'ace', '1--::
  All turn P RH | all M dance into centre, RSh round the pillar to places and face out (1,2,3,4)
9--::
  All turn P LH | all W dance into centre, LSh round the pillar to places and face cclw (1,2,3,4)
17--::
  *Dolphin Loops* : 1c & 3c (1W & 3W leading) chase cclw ¼ behind sides, pass same sex person LSh ; 1c & 3c (1M & 3M leading) dance LSh round nearest sides to exchanged places, Men having changed places with P (3x,2,1x,4)
25--::
  2c & 4c repeat same pattern [17-24] with heads (3x,4x,1x,2x)
33--::
  Circle6 _Right_ and back, all M having progressed to opposite M places and all W one place cclw', 2);
INSERT INTO 'dancecrib' VALUES (3020, '2012-01-22 19:30:07.168397+00', '2020-12-14 09:59:40.954325+00', 5265, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; Teapots R (2c+1W & 1M+3c RHA)

9–::

  1c+1cnrs ½ diag Reel4 ; Teapots R with the end pairs (3W+2W+1M & 1W+3M+2M RHA)

17–::

  1c+2cnrs ½ diag Reel4 ; 1c pass LH, out the end and cast Lsh round 1cnr _while{4}_ 3c+2c ½ L&R starting LH along the sides (2,1x,3)

25–::

  2c+1c+3c Reels3{6} on the sides, Rsh to 2cnr | 1c cross RH', 3);
INSERT INTO 'dancecrib' VALUES (10215, '2017-10-29 14:18:53.770836+00', '2018-04-08 08:33:43.235284+00', 18009, 1, 202, 'ace', '*3c & 4c start on opposite sides*



1--::

  2c & 3c A&R{1+1} RHJ | change side, W passing under joined arms, finish RHJ 2c facing up, 3c down ; dance out through the ends and cast into centre facing cnr they just cast round on the diagonal

9--::

  2c+3c Double SetH&G, finish half way round facing other cnr on diagonal

17--::

  2c+3c Double Cnr-Chain [change pl RH with cnrs | cnrs LHA{2} ; change back RH | LHA{2} to sidelines] (1,3x,2,4x)

25--::

  3c+2c set | 3M followed by P cast up to 1pl _while[4}_ 2M followed by P cast down to 4plx (1c step down, 4c up on [29-30]) | all set (3,1,4x,2x)', 5);
INSERT INTO 'dancecrib' VALUES (10116, '2017-09-10 21:22:48.621171+00', '2018-04-08 10:19:02.171409+00', 15100, 1, 202, 'ace', '1--::

 1c+2c Mirror S&Link (1c cast, 2c dance up) ; 1c dance up between 2c and cast to 2pl (2,1,3)

9--::

 1c dance down between 3c and cast to 2pl ; 1c+3c Mirror S&Link (1c cast, 3c dance up) (2,3,1)

17--::

 1c cross RH | 1c+3c change pl LH on sidelines ; 1c cross RH | 1c+2c change pl LH on sidelines (1,2,3)

25--::

 1c lead down, crossing over (2c up) ; 1c lead up to 2pl, crossing over (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10595, '2018-04-08 00:12:52.365963+00', '2018-04-08 00:20:52.691395+00', 13907, 1, 202, 'ace', '1--::

  1c followed by 2c+3c dance down the middle (2c & 3c divide) ; 1c (leading) +2c+3c dance up

9--::

  3C Promenade

17--::

  1c cross RH | cast (2c up) ; 1c cross RH | cast (3c up) (2,3,1)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11421, '2018-12-22 13:58:06.8248+00', '2018-12-22 22:49:30.613335+00', 14925, 1, 202, 'ace', '*Seven dancers organised as follows:*  

. .Top  

. .1 . 2  

3 . 4 . 5  

. .6 . 7  

1--::

  1+3+6 & 4+2+5+7 RHA ; 1+3+6+4 & 2+5+7 LHA

9--::

  1+2+6+7 R&L starting up/down. On [16] 3 faces 4

17--::

  3+4+5 LSh Reel3

25--::

  2+5+7+4 ½ R&L, 4+2 & 7+5 changing places RH to start _while{4}_ 3+6 set | change places LH ; 1+5+3+6 ½ R&L, 5+1 & 3+6 changing places RH to start _while{4}_ 2+4 set | change places LH



*Finishing position*  

. .Top  

. .3 . 7  

5 . 6 . 2  

. .1 . 4', 2);
INSERT INTO 'dancecrib' VALUES (3149, '2012-01-22 19:30:13.427669+00', '2021-03-14 20:39:54.387606+00', 5726, 1, NULL, 'ace', '{{explanation}}

Start with 2c and 4c on opposite sides (1,2x,3,4x)



1–::

  1M+2M and 3M+4M turn RH 1½ to change places ; Women repeat

9–::

  2c+1c & 4c+3c Reels4 across, passing Rsh on sidelines to begin

17–::

  Reels4 on sides, 1c & 4c pass Lsh to begin

25–::

  1c+3c set | 1c lead up RH, cross between 2c, cast off to bottom and cross RH to 4pl on opposite sides _while{6}_ 3c lead up RH between 4c and 2c cross, cast off and cross RH to 2pl opposite side (2,3x,4,1x)', 2);
INSERT INTO 'dancecrib' VALUES (10596, '2018-04-08 00:54:42.070672+00', '2018-04-08 01:04:54.261554+00', 18244, 1, 202, 'ace', '1--::

  1c+2c Chain and Turn (2,1,3)

9--::

  1c dance up between 2c | cast to 2pl ; dance down between 3c | cast up to 2pl _while{8}_ 2c+3c R&L up/dn

17--::

  2c+3c A&R _while{4}_ 1c dance Rsh round P to finish facing 1cnrs ; 1c Set to Corners, 1c face 2cnrs at end

25--::

  Reels3{6} on sidelines, 1c start Rsh to 2cnrs | 1c cross RH', 2);
INSERT INTO 'dancecrib' VALUES (10578, '2018-04-04 07:32:41.01908+00', '2018-04-08 08:30:55.110658+00', 13904, 1, 202, 'ace', '_Strathspey_

1--::

  Inveran Reels3{6} | 1c & 2c continue the reels, 1c with a loop to 2pl, 2c to 1pl (2,1,3)

9--::

  2c+3c R&L (no polite turn) _while{8}_ 1c cross RH | cast R round 1cnrs position to between ends ; dance out through 2pl | cast R into lines of 3 across facing 2cnrs

17--::

  ½ Reels3 across, 1c start Lsh to 2cnrs ; 1c turn LH 1¾ _while{4}_ 2c+3c facing down/up set | change places RH (3x,1x,2x)

25--::

  S&Link3 twice (2,1,3)



*Repeat three times as Strathspey and four times as Reel*  

Deviser''s note:  

*In [21-24], 1c turn 1¾ in Strathspey time but ¾ in Reel time*', 4);
INSERT INTO 'dancecrib' VALUES (12300, '2019-10-20 00:43:56.217115+00', '2019-10-20 16:47:37.352969+00', 7652, 1, NULL, 'ace', 'Crib writing in progress

1--::

  1c+3c set facing diag. | 1M+3W turn RH ¾, chase 1 place clw and set to each other _while{6}_  1W+3M cast one place clw and turn the other RH 1¾ and face out (1,2,3)

9--::

  Rsh Reels3 on the sides, 2c starting in and R (2W up, 2M down) at end 1c+3c face out (1,2,3)

17--::

  2c petronella to midline and set _while{4}_ 1c+3c cast to middle and cross, the W passing between the M.  The M raises the arm closest to his P, the W the arm furthest from her P, and dances under the joined arms (no turns) ; 2c petronella to 2plx and set _while{4}_ 1c+3c cast to 1plx/3plx and turn P RH ½ to face the other cpl up/down 

25--::

  Circle6 and back (1,2x,3)

33--::

  1c+2c set | ¾ DblFig8, 1c crossing down to start (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11427, '2018-12-23 22:30:55.692207+00', '2019-01-29 00:13:51.187727+00', 19065, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; all set | cross RH. 2c & 3c face out, 1c face in (2x,1,3x)

9--::

  Reels3{6} on sides, 1c RSh to 4cnrs[pos] | all cross RH (2,1x,3)

17--::

  Circle6 and back (2,1x,3)

25--::

  Reels3{6} on sides, 1c RSh to 2cnrs | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11062, '2018-09-03 19:47:29.318355+00', '2018-09-03 19:49:41.657239+00', 18511, 1, 202, 'ace', '1--::

  1c long cast to 2pl ; turn RH (2,1,3)

9--::

  3C S&Link twice (3x,1x,2x)

17--::

  ½ Reel4 on 1diag, 1c passing P LSh to start, pass P RSh into ; ½ Reel4 on 2diag (2,1,3)

25--::

  All Petronella Turn | repeat 3 times (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10218, '2017-10-31 00:24:08.690339+00', '2020-10-06 15:18:42.949229+00', 15111, 1, 202, 'ace', '1--::

  1c set, 1W finish facing out | Parallel ½ Fig8 (2c up on [3-4]) | dance up round 3c, cross Lsh into DTr position

9--::

  Inverted DTr [set as in DTr | 2c+3c advance in and 1c out, all face R about ; set as in inverted DTr | advance back, 1c to face 1cnrs]

17--::

  ½ Reel4 in 1 diag, 1c turn LH ¾ to face 4cnrs ; ½ Reel4 in 2 diag (3x,1,2x)

25--::

  3c & 2c set twice, pivoting R ¾ to face W up, M down _while{4}_ 1c turn RH ½ and cast away to opposite sides ; all chase clw ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10212, '2017-10-29 00:20:11.897612+00', '2020-12-28 20:01:43.851329+00', 18006, 1, 202, 'ace', '*5 dancers in a square, 1+3 head, 2+4 on sides, 5 in middle facing 1*



1--::

  1+2+3+4 Circle4 and back _while{8}_ 5 dances any suitable reel step

9--::

  1+2+5 RHA ; 3+4+5 LHA

17--::

  5 dances Rsh round 1 & 2 _while{4}_ 1+2 & 3+4 turn RH ; 5 dances Lsh round 3 & 4 _while{4}_ 1+2 & 3+4 turn LH, finish 5 facing 1

25--::

  5+1 set | turn RH ½ ; 1+4 set | turn RH ½

33--::

  4+3 set | turn RH ½ ; 3+2 set | turn RH ½ (5,3,4,1 with 2 in middle facing 5) ', 4);
INSERT INTO 'dancecrib' VALUES (10192, '2017-10-19 22:02:03.061813+00', '2020-12-28 20:41:31.829692+00', 16775, 1, 202, 'ace', '1--::

  Circle4 and back

9--::

  1c+2c RHA ; LHA

17--::

  All turn opposite person RH ; All BtoB with P

25--::

  1c to 2c A&R ; pass opposite couple Rsh and meet next couple, all stamp 2', 4);
INSERT INTO 'dancecrib' VALUES (10597, '2018-04-08 12:47:26.104775+00', '2021-01-01 20:07:37.442589+00', 13932, 1, 202, 'ace', '1--::

  All set | 1c dance down to 3pl and face out _while{2}_ 2c & 3c dance up 1 place and face in ; 1c+3c change places EH 1½ (2,1,3)

9--::

  1c with 3c following cross between 2c, cast off, cross up between 2c again, and cast off to (2,3,1)

17--::

  All set | 1c dance up to 1pl and face out _while{2}_ 2c & 3c dance down 1 place and face in ; 1c+2c change places EH 1½, 2c facing out at end (2,1,3)

25--::

  Mirror Reels3 on sidelines, 1c cross up to start. On [29-30] 1c in 2plx cross down (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10210, '2017-10-28 23:10:50.663277+00', '2018-04-09 09:32:51.021556+00', 18013, 1, 202, 'ace', '1--::

  1M dances Rsh round 2W to midline between 1pl & 2pl facing up _while{4}_ 3W dances Rsh round 2M to midline between 2pl & 3pl facing down ; 1M+1W+2W & 3W+2M+3M RHA (1,2,3)

9--::

  1W dances Lsh round 2M to midline between 1pl & 2pl facing up _while{4}_ 3M dances Lsh round 2W to midline between 2pl & 3pl facing down ; 1W+1M+2M & 3M+2W+3W LHA (1,2,3)

17--::

  1c+2c+3c set | Petronella in tandem into lines of 3 across, 2c facing out, 1c & 3c facing diag in ; 2c chase clw ½ to exchanged places _while{4}_ 1W+3M set | cross RH & 3W+1M cross RH | set

25--::

  All set | Petronella in tandem (to 1,2,3) ; 1c dance to 3pl with a loop (2c+3c up on [31-32]) (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (3649, '2012-10-12 14:44:14.476316+00', '2021-04-16 22:41:03.218272+00', 5905, 2, 197, 'ace', '1–::

  1c A&R ; turn RH

9–::

  1c lead down the middle and up | 1c cast  (2c up) (2,1,3)

17–::

  1c+3c  RHA; LHA

25–::

  1c+3c Promenade (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12301, '2019-10-20 21:35:24.52927+00', '2019-10-20 21:39:18.554307+00', 18135, 1, 202, 'ace', '1--::

  All set |1c & 3c cross RH and face out  _while{2}_ 2c set ; ½ Mirror Reels3 on sides, 1c out and down, 2c in and up (3x,2,1x)

9--::

  All repeat [1-8] from new positions (1,2,3)

17-28::

  3C R&L (1,2,3)

29-32::

  1c+2c turn EH 1½ on sides, 1c out and down (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12302, '2019-10-20 23:10:20.823163+00', '2021-09-18 08:19:11.502879+00', 19701, 1, 1645, 'ace', '1-::

  1c+2c mirror S&Link (1c cast, 2c dance up) ; 1c turn LH to face out in 2pl (2,1,3)

9-::

  1c dance the track of LSh Reels3 across passing 4cnrs LSh _while_ 2c+3c dance the track of LSh Reels3 on the sides,

  1c end in centre, RSh to P, facing 4cnrs on the diagonal

17-::

  1c turn 4cnrs LH & end in centre facing 3cnrs ; turn 3cnrs RH & end in centre facing 2cnrs

25-::

  1c repeat [17-24] with 2cnrs & 1cnrs, ending on the sides (2,1,3)

33-::

  Circle6 & back (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (2766, '2012-01-22 19:29:56.543916+00', '2019-10-24 01:26:25.088341+00', 4291, 1, NULL, 'ace', '1–::

  1c+2c Reel4 across, 1M+2W pass Lsh as 1W/2M cast down/up, finish in places, 1W facing out (1W+2M final pass is Rsh)  (1,2,3)

9–::

  1c parallel Rsh Fig8 on own side round 2c+3c

17–::

  1W, followed by 1M, cast off behind 2W, cross down between 3c (2c up) ; cast up round 3M and cross (to 2,1,3)

25–::

  1c+3c RHA ; 2c+1c LHA

33–::

  2c+1c+3c parallel Reels3 on the sides (1c Rsh to 3c)

41–::

  All Circle6 and back  

  

*On [7-8] 1W+2M originally passed Lsh, but the deviser changed this to Rsh*.', 3);
INSERT INTO 'dancecrib' VALUES (3482, '2012-01-22 19:30:27.308052+00', '2019-02-05 15:05:16.438755+00', 6939, 1, NULL, 'ace', '{{explanation}}

On 2nd chord 2c+4c+6c cross to opposite side (1,2x,3,4x,5,6x).  The dance is centro-symmetric till bar 40



1–::

  1c+2c & 3c+4c &5c+6c dance ½R&L ; then ½ L-Chain, all finish BtB with P (all M face clw, all W cclw, the couples are in order 1,3,5 on W side, 2,4,6 on M side)

9–::

  ½ G-Chain for 6 couples (cross at top and bottom to start)

17–::

  All set to and turn person opposite RH ; set to and turn P LH ¾.  All M join RH in the centre, all W hold LH with P and join RH to next couple''s joined hands.

25–::

  Mill Wheel: All dance ½ round, the W in slip-steps, the M in PdB {6} | All M dance between P and W in front, to reform the longwise set as on bar 9

33–::

  1c+2c & 3c+4c & 5c+6c  ½M-Chain  (1,2x,3,4x,5,6x) ; All set, cross RH and 1c face out

41–::

  1c cast round 2c | cross between 3c ; cast round 4c, cross between 5c, cast round 6c to 6plx (other cpls up on 47-48) (2,3x,4,5x,6,1x)', 3);
INSERT INTO 'dancecrib' VALUES (10741, '2018-05-04 00:14:21.083872+00', '2019-02-26 00:02:24.965061+00', 15838, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; ½ Fig8 up round 2c (2,1x,3,4)

9--::

  1c+3c+4c Mirror Reels3 on sidelines, 1c in and down to start (2,1x,3,4)

17--::

  2c+1c+3c Circle6 and back

25--::

  1c cross RH | cast 2 places (3c+4c up) ; all turn P RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12304, '2019-10-23 12:37:57.383522+00', '2019-10-23 16:56:21.147685+00', 16873, 1, NULL, 'ace', '1--::

  Mirror Reels3 on the sides, 2c start out and up (1,2,3)

9--::

  1c turn RH and face down NHJ | 1c+2c set ; 2c dance up as 1c dance down and cast up round 3c to (2,1,3)

17--::

  1c turn RH to face 2cnr ; turn 2cnr LH and 1cnr RH into facing lines across 

25--::

  In lines across A&R ; 1c turn RH 1¼ (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10198, '2017-10-21 21:01:16.85214+00', '2018-04-09 13:24:58.10581+00', 17997, 1, 202, 'ace', '1--::

  Gr-Chain, 1 step/hand

9--::

  1c & 3c set | advance NHJ to centre, 1M+3W & 1W+3M NHJ dance out through side cpls and cast back to pl | 1c & 3c turn BH

17--::

  2c & 4c repeat [9-16]

25--::

  Dble R&L [1c+3c cross RH _while{2}_ 2c & 4c change places RH | 1c & 3c change places LH _while{2}_ 2c+4c cross LH ; all repeat [25-28] to pl]

33--::

  All W Lsh round P ; turn cnrs RH

41--::

  All M Rsh round P ; turn cnrs LH

49-::

  All La Baratte | All turn P RH ½, W finish facing out

57-72::

  Schiehallion reels

73--::

  Circle8 and back', 4);
INSERT INTO 'dancecrib' VALUES (11423, '2018-12-22 21:30:00.204728+00', '2018-12-22 21:31:49.571342+00', 18486, 2, 1645, 'ace', '*All dancers hold a glass of whisky in LH*
1- 8:: All dance 1/2 grand chain (1 bar to cross, 1 bar to change glass to other hand ) finish with glass in LH
9-16:: All turn partner RH 3 bars, change glass to RH, turn partner LH 3 bars, men change glass to LH
17-20:: 3s+1s advance, clink glasses with opposite, retire
21-24:: 3s+1s set to partner, Ladies change glass to LH, cross RH and face out in longwise set while 2s+4s advance, clink glasses with opposite, chase anticlockwise 1/4 round to face out between ends (4s up, 2s down) Ladies change glass to LH.  3 (4) 2 (1)
25-32:: 3s+4s also 2s+1s dance full double Fig of 8 (3s & 1s cast, 2s & 4s cross out through ends, give hands when crossing, changing glasses as required. All finish with glass in LH
33-40:: All Ladies advance (2 bars), dance RSh round partner to face them (4 bars), give glass to partner, retire
41-48:: All Ladies set (highland steps)
49-56:: All Men advance (2 bars), dance RSh round partner to face them (4 bars), give both glasses to partner, retire
57-64:: All Men set (highland steps) 
65-68:: 1s & 3s advance while 4s & 2s 1/2 turn RSh, All facing partner Ladies return glass (RH) to Men’s LH
69-72:: 3s+4s also 2s+1s dance RH across, after 3 bars 2M & 4M peel off to finish ready for:
73-80:: All dance double RH across, men with R arm round partner’s waist (all with glass in LH).  Finish in square set opposite original places
81-96:: Repeat bars 1-16.  Chord: bow/curtsey, clinking glasses - and drink
', 2);
INSERT INTO 'dancecrib' VALUES (12303, '2019-10-22 00:29:46.144432+00', '2021-01-04 12:35:16.050657+00', 18151, 1, 202, 'ace', '1--::

  1c+3c ½ R&L _while{4}_ 2c set | cross RH ; all chase clw ½ (1,2,3)

9--::

  1c+2c The Tournée. 1c face 1cnrs (2,1,3)

17--::

  Corners Pass and Turn on 1diag ; repeat on 2diag (2,1x,3)

25--::

  Reels3 {6} on sides, 1c LSh to 1cnrs | 1c cross to 2pl', 2);
INSERT INTO 'dancecrib' VALUES (13375, '2020-11-19 19:02:04.604557+00', '2020-11-19 19:02:22.641525+00', 20148, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; cross down LH between 3c and cast up (2,1,3)

9--::

  1c set advancing (2 pdb) | turn BH ½ (2 pdb) pivoting R into BtoB position facing opposite sides ; 4 bars of »Corners Pass and Cast Away« on 1diag. 1c finish between ends

17--::

  1c set advancing (2 pdb) | turn BH ½ (2 pdb) pivoting R into BtoB position facing ends ; 4 bars of »Corners Pass and Cast Away« on 2diag. 1c finish BtoB in centre as on [20] ready for

25--::

  3c+1M & 1W+2c Circle3 L {3}, open into Circle6 L {3} to sides | all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3209, '2012-01-22 19:30:15.791435+00', '2021-04-17 09:43:13.115042+00', 5897, 1, NULL, 'ace', '1–::

  1c+3c cross LH | 1c+2c & 3c+4c turn RH just over ¾ on the sides, bringing all M to the midline (2M faces 1M & 4M faces 3M), and all W to the sidelines, 1c+2c & 3c+4c each forming a diamond, with 2W+4W on W side facing 1W+3W on M side ; all set twice (or other suitable step)

9–::

  All M Reel4 on the midline _while{8}_ all W chase once round set clw

17–::

  1c+2c & 3c+4c RHA ; LHA (not to sides) to the same diamonds

25–::

  All M with P (in front) turn LH to finish (1x,2,3x,4) | 1c ½ turn RH _while_ 3c cross RH, 1c face down in the middle and all other C on sidelines face up ; 1c lead to 4pl as 2c+3c+4c dance up | all set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10191, '2017-10-19 21:42:41.507685+00', '2023-02-04 16:52:12.554394+00', 17941, 1, 202, 'ace', '1--::
  1c+2c S&Link ; 2c+1c chase clw ½ (1x,2x,3)
9--::
  3c set | ½ Fig8 round 2c | 1c+2c+3c turn RH ½ into allemande hold
17--::
  3C Allemande (3,2,1)
25--::
  3c+2c ½ R&L ; 2c+3c turn P RH 1 ½ (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (10275, '2017-11-28 08:20:46.267454+00', '2018-04-09 13:18:59.09301+00', 15121, 1, 202, 'ace', '1--::

  1c Mirror Fig8 on sidelines, 1c in to start (1,2,3)

9--::

  2c followed by 1c dance down ; 1c followed by 2c dance *out* and up behind 3c (1,2,3)

17--::

  1c+2c RHA ; 1W+2W & 1M+2M turn RH 1 ½, 1M facing out (2,1,3)

25--::

  1c+3c LHA ; 1W+3W & 1M+3M turn LH 1 ½ (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (11425, '2018-12-23 12:16:25.279214+00', '2018-12-23 14:31:50.132358+00', 15767, 1, 1645, 'ace', '1-::

  1c lead down{3} & back up{3} | cast off (2c up)

9-::

  2c+1W & 1M+3c RHA  ; 2c+1M & 1W+3c LHA, pass RSh to DTr position

17-::

  All set in DTr | 1c turn 1cnr RH ; set in DTr | 1c turn 2cnr LH (2,1x,3)

25-::

  RSh Reels3 on opposite sides, 1c pass LSh to own sides (2,1,3)



', 2);
INSERT INTO 'dancecrib' VALUES (11426, '2018-12-23 22:04:22.055491+00', '2018-12-24 04:17:20.33398+00', 15482, 1, 202, 'ace', '1--::
  1M+2W turn RH 1½ ; 1W+2M turn 1½ (2x,1x)
9--::
  1M+2c Reel3 across, 1M LSh to 2W (2x,1x)
17--::
  1W+2c Reel3 across, 1W RSh to 2M (2x,1x)
25--::
  2c+1c A&R ; cross RH | set (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11429, '2018-12-25 10:05:36.983033+00', '2018-12-25 18:47:54.833582+00', 13790, 1, 202, 'ace', '1--::

  1c cast off behind own lines (2c up) ; and cast back to 2pl (2,1,3)

9--::

  1c+1cnrs set twice ; turn RH (2,1,3)

17--::

  1c+2cnrs repeat [9-16] (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11428, '2018-12-25 09:50:51.33684+00', '2018-12-25 09:54:28.329228+00', 13789, 1, 202, 'ace', '1--::

  1c Fig8 down round 2c (1,2)

9--::

  2c Fig8 up round 1c (1,2)

17--::

  1c+2c set | cross RH ; set | turn RH ½ into allemande hold

25--::

  2C Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11431, '2018-12-26 12:08:24.489579+00', '2018-12-26 12:15:38.751946+00', 13791, 1, 202, 'ace', '1--::

  1c cross RH | cast to 3plx (2c up) ; cross LH | cast to 2pl (2,1,3)

9--::

  1M+1cnr+2cnr advance{2} and join hands in BiL[pos] | set ; retire{2} | set (2,1,3)

17--::

  1W+1cnr+2cnr repeat [9-16] (2,1,3)

25--::

  1c turn 1cnrs RH | pass RSh ; turn 2cnrs RH | pass RSh to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11432, '2018-12-26 12:36:20.096361+00', '2018-12-26 12:41:31.750234+00', 13792, 1, 202, 'ace', '1--::

  1c turn RH ; cast to 2pl and face 1cnrs (2c up) | 1c+1cnrs set (2,1,3)

9--::

  1c+1cnrs A&R ; dance BtoB. On [16] clap (2,1,3)

17--::

  1c+2cnrs repeat [9-16]

25--::

  Circle6 and back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11433, '2018-12-26 12:47:04.499109+00', '2018-12-26 12:50:21.141101+00', 13793, 1, 202, 'ace', '1--::

  1c turn RH ; cast (2c up) | set and pivot to face 3c (2,1,3)

9--::

  Gr-Chain (2,1,3)

17--::

  All A&R ; 1c turn LH (2,1,3)

25--::

  2c+1c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11434, '2018-12-26 13:02:36.182657+00', '2018-12-26 13:09:47.487917+00', 13794, 1, 202, 'ace', '1--::

  All Turn BH Halfway and Cast ; repeat (1,2,3)

9--::

  1c cross RH | cast ; ½ Fig8 down LH round 3c, passing LSh to face 1cnrs

17--::

  1c turn 1cnrs BH | pass RSh ; turn 2cnrs BH | pass RSh to 2pl (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10598, '2018-04-09 16:10:31.97887+00', '2018-04-09 23:22:12.715929+00', 18271, 2, 2697, 'ace', '1-8::

    1s+2s RHA; 1M+2M dance 1/2 Fig of 8 round 1L and 2L (1M passes in front, and finishes in 2M place)

9-16::

    1L+2M lead down the middle & back, finishing 1L facing out, and 2M in 1M place 

17-24::

    1s reel with 2L on Ladies side: 1L & 2L pass RSh _while_ 1M dances to 2nd pl on Ladies side to pass ptnr LSh (1s end in 2nd place own side) 

25-32::

    1s lead down the middle & back to 2nd place', 4);
INSERT INTO 'dancecrib' VALUES (10600, '2018-04-09 18:58:49.785158+00', '2018-04-09 23:22:12.717234+00', 18271, 1, 202, 'ace', '1--::

  1c+2c RHA ; 1M+2M cross between P (no hands, 1M in front) and cast back to exchanged places

9--::

  1W+2M lead down ; and up, 1W facing out and 2M in 1Mplace

17--::

  1c+2W Reel3 on W side [1W & 2W begin Rsh, 1M entering below them] (2,1)

25--::

  1c lead down ; and up (2,1)





', 4);
INSERT INTO 'dancecrib' VALUES (12307, '2019-10-25 10:06:31.652912+00', '2019-10-25 17:05:09.437013+00', 19718, 1, NULL, 'ace', '*start (1,2,3x,4x)*  

*Tip: In [9-40], each new promhold Reel3 starts ¼ cclw from the previous one*  

1--::

  1c+4c long cast inwards (2c+3c to ends) ; 4c+1c ½ R&L, take promhold and face out the end (2c/3c are in 1pl/4plx, and return there every 8 bars) 

9--::

  4c(promhold)+2c & 1c(promhold)+3c Rsh Reels3 across, 1c/4c finish in middle of sidelines facing 2W/3W

17--::

  1c(promhold) on Wside & 4c(promhold) on Mside Rsh Reels3, 1c/4c finish between end couples, facing 2M/3M and out

25--::

  2c+1c(promhold) & 4c(promhold)+3c Lsh Reels3 across, 1c & 4c finish (M with W on the R) in middle of the sides (Mside: 2M,4M,4W,3W; Wside 2W,1W,1M,3M) 

33--::

  1W+4W set and cross diag. LH _while{4}_ 2M+4M & 1M+3M turn LH ;  4c+1c ½ R&L (2,1,4x,3x)   



*repeat once* 



', 3);
INSERT INTO 'dancecrib' VALUES (11810, '2019-04-27 17:02:16.724066+00', '2019-04-27 20:12:43.561055+00', 6782, 1, NULL, 'ace', '1--::

  1c cross down and face out (2c dance up) | 2c+1c turn EH ½ on the side ; 1c cross down as 2c casts up | 1c turn 3 EH ½ on side, 3c face out and down (2,3,1)

9--::

  [Inveran Reels] 1c cross up into ½ Reel3 on the sides (1x,3,2) ; 1c cross down into ½ Reel3 on the sides (2,3,1)

17--::

  1c cross RH and cast up (3c down) ; 1c cross LH and cast up (2c down and steps in) ready for

25--::

  1c+2c Poussette (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2905, '2012-01-22 19:30:02.338121+00', '2021-03-14 20:46:32.948686+00', 4877, 1, NULL, 'ace', '1–::

  1c+2c+3c & 4c+5c+6c Reels3 on the sides, 1c & 4c crossing down to begin, and ending facing down in promhold between 2c (5c) in 1st (4th) place

9–::

  1c (promhold) Rsh Reel3 with 2c _while_ 4c does likewise with 5c

17–::

  1c/4c (promhold) lead down between 3c/6c (2c+5c up) , cross and cast up to 2pl/5pl ; 2c+1c & 3c+5c & 4c+6c RHA (2,1,3,5,4,6) flowing into

25–::

  1c+3c & 5c+4c LHA ; 1c cast off two (to 4pl, 3c+5c up) _while{4}_ 4c cast off one to 6pl (6c up) and set (to 2,3,5,1,6,4 ; i.e. the progression for 1c is 1-4-6-5-3-2-1)', 2);
INSERT INTO 'dancecrib' VALUES (12577, '2020-02-12 16:09:12.874183+00', '2020-02-12 16:15:48.024595+00', 16011, 1, NULL, 'ace', '

1--::

  1M+2W turn RH ; 1W+2M turn RH

9--::

  RHA ; LHA

17--::

  1c followed by 2c lead down ; lead up, 2c leading (2,1)

25--::

  Circle4 and back (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (15367, '2022-12-26 00:43:18.650636+00', '2022-12-26 00:43:28.694229+00', 21220, 1, 1645, 'ace', '1--10::

  1c Fig8 round 2c | cross down RH (2c up) to (2,1x,3)

11--20::

  Mirror Reels3 on opp sides, 1c starting out & down | 1c+3c continue Reels for 2 bars {2,3,1x)

21--30::

  1c turn RH | cast up (3c down) ; &frac12; Fig8 round 2c | cross RH to face 1cnrs

31--40::

  1c pass & turn with 1cnrs ; repeat with 2cnrs (end on opp side) | 1c cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3200, '2012-01-22 19:30:15.437588+00', '2021-04-17 10:11:29.786094+00', 5868, 1, NULL, 'ace', '1–::

  1c+2c turn RH ; 2c followed by 1c dance between 3c and cast up (to 2,1,3)

9–::

  Teapots R (1W+2c & 1M+3c RHA) ; 1c turn LH 1¼ and face out

17–::

  Opposing Reels3 on sidelines (Lsh to 2cnr), at end 1c cross to 2pl and 2c+3c face each other NHJ

25–::

  All set | ½RHA (6H) ; All chase clw (to 2,1,3).', 2);
INSERT INTO 'dancecrib' VALUES (12803, '2020-05-09 23:41:31.366336+00', '2020-05-09 23:51:03.199368+00', 12068, 1, 202, 'ace', '1--::
  1c dance down _while{4}_ 2c & 3c stand still | cross RH, 2c dancing up to 1pl ; 1c turn RH ½ and dance up to face 1cnrs[pos] (2x,*1*,3x)
9-12::
  ½ Reel4 on 1diag, 1c passing RSh in centre into facing lines3 across, 1M between 2M & 3M facing 1W between 2W & 3W
13-24::
  3C R&L. On [23-24] 1c continue to face 2cnrs[pos]
25--::
 ½ Reel4 on 2diag, 1c passing RSh in centre to 2pl (to 3,1,2) ; »Modified LSh Snake Pass« [1W (3W & 3M following) + 1M (2M & 2W following) pass LSh in centre through 2cnrs[pos] and chase cclw] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12308, '2019-10-25 11:26:46.814428+00', '2019-10-25 11:35:38.318889+00', 18176, 1, 202, 'ace', '1--::

  All chase clw ½ into Reel4 position ; ½ Reels4 (1x,2x,3x,4x)

9--::

  All A&R ; all turn P RH  (1x,2x,3x,4x)

17--::

  All repeat [1-8] from new positions (1,2,3,4)

25--::

  1c+2c set | ½ RHA ; 1c+3c set | ½ LHA (2x,3x,1,4)

33--::

  1c+4c set | ½ RHA ; all set | cross RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12309, '2019-10-26 00:58:21.4808+00', '2019-10-26 01:10:56.839097+00', 18156, 1, 202, 'ace', '1--::

  1c dance down between 3c, cast up to 2pl outside the set facing up  

 _while{4}_ 2c (dancing up to begin) dance down to 3pl and face out  

 _while{4}_ 3c touching hands long cast up to 1pl and face in ;  

 1M+2M+3M RHA 1½ _while{4}_ 1W+2W+3W LHA 1½. 1c NHJ in 2pl centre face down (2,1,3)

9--::

  1c dance down between 3c, cast up to 2pl centre and face up NHJ  

_while{4}_ 2c dance down, separate on [11] and loop to 3pl facing in  

_while{4}_ 3c cast up, touch hands on [11] and loop to 1pl facing out ;  

1M+2M+3M LHA 1½ _while{4}_ 1W+2W+3W RHA 1½ to sides (2,1,3)

17--::

  All dance BtoB ; all set | 1c cast up to 1pl centre and face down NHJ _while{2}_ 2c turn BH to 2pl centre and face up NHJ _while{2}_ 3c turn BH

25--::

  1c+2c The Rondel (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (4402, '2013-08-21 08:30:48.42027+00', '2023-02-21 19:26:55.728159+00', 767, 3, NULL, 'ace', '1-8::

    1s dance reels of 3 on sides (1L+2L & 2M+3M pass RSh) ending with

    1L+2L also 2M+3M changing places RH

9-16::

    1L+3M set & cross RH, 3M followed by 1L cast down behind 3L &

    crosses to end own side (1L ends in 3L place & 2M+3L step up)

17-20::

    1s dance in, pull back RSh (pirouette) into BtoB position (Man

    facing up) & dance out to 1L/3M places _while_ 3M & 2L cast on own

    sides to top/bottom & dance in & pull back RSh (pirouette) into BtoB

    position (Man facing up)

21-24::

    1s cast on opposite sides & cross to own sides _while_ 3M & 2L dance

    out to 1L/3M places & cast to bottom/top

25-32::

    1L+2L (at top) & 1M+3M (3rd pl) turn RH _while_ middle dancers turn

    LH 1.1/4 times, 3 Ladies (at top) also 3 Men dance RH across & 3L

    followed by 1L+2L dance down Ladies'' side _while_ 2M followed by

    1M+3M dance up Men''s side to end 2 1 3

33-40::

    1s cross down RH, cast up to 1st place & cross down LH to 2nd place

    own side facing out



{{explanation}}

End of 2nd turn:  1s dance down & cross LH to 4th place as 4s step up', 0);
INSERT INTO 'dancecrib' VALUES (12511, '2020-01-16 12:29:36.542751+00', '2022-03-09 01:06:07.668737+00', 19617, 2, 1645, 'ace', '1-::

  All set | 1c+2c & 3c+4c ¾ double figures of 8, 1c & 4c cast in to start, 2c & 3c end facing out (2,1x,4x,3)

9-12::

  1M+4M & 1W+4W cross NHJ (W under M''s arch) _while_ 2c & 3c cast down/up passing RSh | 1c & 4c turn cnr ¾ with ''free'' hand

13-16::

  1c facing 4c change places NHJ (arch going up) _while_ 3c & 2c cross passing RSh | 4c & 1c turn cnr as before to (3x,4,1,2x) 3c & 2c facing out

17-::

  Repeat [9-16] from new places to (2,1x,4x,3) 2c & 3c facing out

25-::

  2c & 3c set twice on sides, turning to face in _while{4}_ 1c+4c &frac12; R&L ; all turn P RH (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11440, '2018-12-30 19:36:58.840132+00', '2019-01-29 00:10:18.008616+00', 19073, 1, 202, 'ace', '1--::

  2C S&Link ; 2c+1c set | ½ RHA (1x,2x,3)

9--::

  1c cast off behind lines ; cast back to 1plx _while{8}_ 2c+3c LHA and stay in centre ;  set | ½ RHA to sides (1x,3x,2)

17--::

  Gr-Chain, (1c crossing, 1 bar per hand) (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11437, '2018-12-28 02:29:30.971028+00', '2018-12-28 02:36:36.524176+00', 13799, 1, 202, 'ace', '1--::

  1c cross RH | cast to 3plx (2c+3c up) ; cross LH | cast up to face 1cnrs (3c down)

9--::

  Corners Pass and Turn (2,1,3)

17--::

  1c set twice ; turn BH 1½ (2,1x,3)

25--::

  Reels3{6} across, 1c RSh to 4cnrs | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11435, '2018-12-27 10:32:49.23706+00', '2018-12-27 10:45:57.303055+00', 18734, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; dance down |cast round 3c to 2pl (2,1x,3)

9--::

  1M+2M & 1W+3W (1diag) cross RH _as_ 2W & 3M set | 2W+3W & 2M+3M (2diag) cross RH _as_ 1c set ; 1M+3M & 2W+1W (1diag) cross RH _as_ 2W & 2M set | 3W+1W & 1M+2M (2diag) cross RH _as_ 3M & 2W set

17--::

  1W+3c & 1M+2c RHA 1⅓ (to 3x,1x,2x) ; all turn P BH

25--::

  3C S&Link twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3231, '2012-01-22 19:30:16.666273+00', '2019-02-05 17:05:02.889429+00', 5972, 1, NULL, 'ace', '1–::

  1c+3c Turn RH | cast off (2c+4c up) ; cross LH and cast L to face 3cnr in lines of 3,4,3, across

9–::

  RSh Reels of 3,4,3 across, finish as started

17–::

  1c+3c dance straight ahead, out the sides and chase ½ cclw round the set, to finish (2,3x,4,1x,5)

25–::

  2c+3c & 1c+5c ½R&L  _while_{4}   4c set and cross RH (3,2x,4x,5x,1) ;  2c+4c+5c ½Circle L (3,5,4,2,1)', 3);
INSERT INTO 'dancecrib' VALUES (10195, '2017-10-20 19:39:10.969322+00', '2018-04-10 07:42:06.73868+00', 17943, 1, 202, 'ace', '1--::

  2c Petronella turn | set _while{4}_ 1c+3c facing dn/up set | change places RH ; 2c Petronella turn | set advancing to 3cnrs position _while{4}_ 3c+1c set to P | cross RH

9--::

  ½ Reel4 in 1diag, on [12] 2c pass Rsh to 4cnrs position ; ½ Reel4 in 2diag (1,2,3)

17--::

  1c+2c+3c Pick-up Chain (3c start, 2 bars per hand) (3,2x,1)

25--::

  2c 1/2 Fig8 round 3c ; 3c+2c S&Link (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (11436, '2018-12-27 13:12:02.498032+00', '2019-03-03 09:35:33.376231+00', 19066, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Reels3 across, 1c RSh to 4cnrs

9--::

  Reels3 on sides, 1c LSh to 3cnrs[pos] (2x,1,3x)

17--::

  All set | cross RH ; chase clw ½ (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12663, '2020-03-12 00:07:04.417393+00', '2020-03-13 01:29:08.656924+00', 19887, 1, NULL, 'ace', '1--::

    All M chase clw round the set, 1M looping Rsh round P and letting the others overtake, the M finish (2,3,4,1) the W in own places 

9--::

    Top two pairs & bottom two pairs RHA ; LHA at end all W face up

17--::

    The W repeat [1-8] cclw, 1W looping round 2M Lsh, finish all facing P (2,3,4,1)

25--::

    All A&R ; All turn P RH (M face up to continue) (2,3,4,1)



', 3);
INSERT INTO 'dancecrib' VALUES (13120, '2020-08-25 07:41:49.993619+00', '2020-08-25 07:45:59.081809+00', 9489, 1, 202, 'ace', '1--::

  1c dance down (2c up) ; and up to 2pl centre (2,1,3)

9--::

  2c+1W & 1M+3c RHA, pass RSh ; 2c+1M & 1W+3c LHA. 1c pass LSh to face 1cnrs

17--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2 diag. 1C pass RSh to 2pl into DTr (3x,1,2x)

25--::

  »Modified DTr« [: same as DTr but 3c & 2c set | cross RH ; set | change places LH on sides (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10135, '2017-09-17 01:27:52.504831+00', '2021-06-10 23:22:05.159197+00', 15119, 1, 202, 'ace', '1--::
 1c+2W & 2M+3c RHA ; 1c+2M & 2W+3c LHA (1,2,3)
9--::
 3c followed by 2c & 1c cross over and lead down ; 1c followed by 2c & 3c cross over and lead up to places, 1c+2c  in centre, 3c back to 3pl
17--::
 1c+2c Allemande, on [24] 1c advance{1} _while_ 3c step in
25--::
 1c+3c Poussette (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (14637, '2022-03-07 00:45:09.321049+00', '2022-03-07 09:39:46.361486+00', 20704, 1, 202, 'ace', '1--::
  1c long cast to 2pl (2c up) ; dance down between 3c and cast up to 3pl (3c up) (2,3,1)
9--::
  1c long cast up to 2pl (3c down) ; dance up between 2c and cast off to face 1cnrs
17--::
 Corner Chain on 1diag. 1c face 2cnrs
25--::
  Corner Chain on 2diag (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10957, '2018-08-09 08:06:48.344954+00', '2020-12-14 17:35:52.860427+00', 5818, 1, NULL, 'ace', '1--::

  1c set | cross down RH (2c up) ; 1c set | turn LH ¾ to face 1cnr

9--::

  1c+1cnrs ½diag. reel4, 1c pass Lsh into ; 1c+2cnrs ½diag Reel4, finish 1c between end cpls facing 3cnr (pos)

17--::

  Reels3 across, Lsh to 3cnr, 1c finish on midline (M below W) and face P

25--::

  1c set to P | turn RH to 2plx ; All set and cross RH (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (11438, '2018-12-29 02:37:41.1891+00', '2018-12-29 21:32:51.725862+00', 19130, 1, NULL, 'ace', '1-::

  1c lead down {3}, Turn BH {2} , dance up between 3c and behind 2c to places

9-::

  Mirror Reels3 on the sides, 2c starts out and up, take hands when possible (1,2,3)

17-::

  1c+2c The Knot, 1c finish facing 1cnr  

25-::

  1c set to 1cnr | spiral round P to face 2cnr ; set to 2cnr | spiral to (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (1723, '2012-01-22 19:28:58.463202+00', '2020-02-10 22:10:18.906688+00', 9288, 1, NULL, 'ace', '1–::

  1c+2c set advancing | slip down ; cast round 3c to 2c in 1pl and 1c LHJ and RHJ to 1cnr for

9–::

  1c+1cnrs BiL | turn 1cnr RH ; ½ Reels3 on sides, Lsh to 2cnr, 1c ends on 1diag RHJ and LHJ to 1cnrs (2cnr persons)

17–::

  BiL | turn cnr LH ; ½ Reels3 across, Rsh to 4cnr (to 3x,1,2x)

25–::

  1c+person on L (1cnr person) set facing other pair diagonally | ½ RHA ; 1c+person on R (4cnr person) set | ½ LHA (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11439, '2018-12-29 02:47:50.04952+00', '2018-12-31 01:51:55.530067+00', 19131, 1, NULL, 'ace', '*There should be no extra space between sets in a line.*

 

1-::

  1c+2c join hands in circle, balance forward and backward.  All petronella one place cclw in circle ; repeat (2x,1x) 

9-::

  2c+1c face P RHJ and balance F&B | All cross making arch, W dancing under arch and passing in front of M turning her back to him ; 2c+1c RHA (2,1)

17-::

  1c dance down ; dance Rsh round P 1½ and face up

25-::

  1c dance up to 1plx and face out _while{4}_ 2c long cast to (1x,2) ; 1M+2W & 1W+2M dance "easy shoulder" round each other 1½ times, and 2c face out (2,1x)

33-::

   2c+1c DblFig8 (2,1x)

41-::

  1c ½ Fig8 round standing couple below ; 1c+standing couple below Circle4 L (2,1) and keep hands in circle with this new 2c for the repeat



*1c omits [45-48] when at the bottom of the set.*', 3);
INSERT INTO 'dancecrib' VALUES (12315, '2019-10-28 16:22:46.766191+00', '2019-10-28 16:27:30.854972+00', 19726, 1, 202, 'ace', '1--::

  1c turn RH ; cast off (2c up) | turn LH to face 2cnrs

9--::

  1c turn 2cnrs RH | turn P LH to face 1cnrs ; turn 1cnrs RH | turn P LH to face 4 cnrs

17--::

  ½ Reels3 across, 1c RSh to 4 cnrs ; ½ Reels3 on sides, 1c LSh to 3 cnrs

(3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10744, '2018-05-04 22:13:23.083377+00', '2018-05-04 22:13:23.083377+00', 18331, 2, NULL, 'ace', '1 ̶ 4::

    1st couple cross over giving right hands and cast to 2nd place, 2nd couple step up on bars 3 ̶ 4

5 ̶ 8::

1st couple dance a half figure of eight, man up between 2nd couple, lady down between 3rd couple, and finish facing 1st corners.

9–10::

    1st couple and 1st corners pass right shoulders, 1st corners pass each other right shoulders and face 2nd corners. 2nd corners set.

11–12::

    1st and 2nd corners pass right shoulders, 2nd corners pass each other right shoulders and face 1st couple. 1st couple set.  NB These 4 bars describe the formation “Dance to each corner and set” are the same as bars 5 – 8 of Gothenburg’s Welcome [RSCDS book 37].

13–16::

    1s and 2nd corners dance a half diagonal reel of 4, 2nd corners pass each other right shoulders and face 1st corners.

17–18::

    1st and 2nd corners pass right shoulders, 1st corners pass right shoulders and face 1st couple. 1st couple set.

19–20::

    1st corners and 1st couple pass right shoulders, 1st couple pass right shoulders and face 2nd corners. 2nd corners set. NB These 4 bars are the same as bars 5 – 8 but danced from new positions

21–24::

    1st couple and 2nd corners dance a half diagonal reel of 4, 1st couple pass right shoulders and face 1st corners.

25–28::

    1st couple and 1st corners dance a half diagonal reel of 4.

29–32::

    1st couple turn with right hands to 2nd place own sides.', 5);
INSERT INTO 'dancecrib' VALUES (11059, '2018-09-03 09:18:29.669201+00', '2018-09-03 09:25:35.892217+00', 14131, 1, 202, 'ace', '1--::

  1c cast (2c up) | 2c+1c+3c cross LH ; set | 1c turn RH to face 3cnrs[pos] (2x,1x,3x)

9--::

  »Modified Turn CPCP« [same as Turn CPCP except start with LH to cnrs]. On [15-16] 1c turn P RH to centre facing up, 1W on 1M left

17--::

  1c lead to top | cast to 2plx ; all set | 1c turn RH to face 3cnrs[pos] _while{2} 2c+3c change places RH on sidelines (3x,1x,2x)

25--::

  ½ LSh Reel4 on 1diag, pass P RSh to face 4cnrs[pos] ; ½ LSh Reel4 on 2diag. On [31-32] lc cross RSh to 2pl and face out (2,1,3)



*Deviser''s note:  

At the end of the second time through, the dancing couple face out in third position. On bars 1 - 2 they dance down to fourth position as 4th couple step up.*', 2);
INSERT INTO 'dancecrib' VALUES (12317, '2019-10-29 06:56:33.753772+00', '2019-10-29 07:06:15.071385+00', 4639, 1, NULL, 'ace', '1--::

  1c cross RH and cast off (2c up) ; All cross RH and set (2x,1,3x)

9--::

  Diagonal R&L (3,1,2)

17--::

  All lead down the middle and up, into (*3,1,2*)

25--::

  3C Allemande (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10134, '2017-09-16 21:03:09.257686+00', '2018-04-10 08:42:07.22559+00', 15112, 1, 202, 'ace', '1--::

 Cumulative Gr-Chain (1c cross LH | 1c+2c change pl RH on sidelines ; 2c cross LH _while_ 1c+3c change pl LH on sidelines | 2c+3c & 1c+4c change pl RH on sidelines into Reel4 position (3,2x,4,1x)

9--::

 Parallel Reels4 with 3W & 1W ending with a loop

17--::

 3c+2c & 4c+1c ½ RHA (to 2,3x,1,4x) | 3c+1c ½ LHA (to 2,1x,3,4x) ; 2c+1c & 3c+4c ½ RHA (to 1,2x,4,3x) | 2c+4c ½ LHA (1,4x,2,3x)

25--::

 All set | cross RH, 1M & 2W facing out (to 1x,4,2x,3) ; 1c+2c chase clw ½ (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1621, '2012-01-22 19:28:51.439222+00', '2020-01-16 13:26:01.228015+00', 43, 1, NULL, 'ace', '1–::

  1c+2c circle4 and back

9–::

  1W followed by 1M casts off and dances round 2c and back to place

17–::

  Repeat [9-16], 1M leading

25–::

  1c+2c & 3c+4c R&L

33–::

  1c+2c+3c Circle6 and back, finishing for

41–::

  1c+2c Allemande (2,1,3,4)

49–::

  2c+1c+3c+4c G-Chain, end couples crossing

57–::

  1c lead up and cast to 4pl (3c+4c up)', 4);
INSERT INTO 'dancecrib' VALUES (11308, '2018-10-25 11:43:57.736904+00', '2022-11-08 16:53:46.494998+00', 6047, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; ½ Fig8 R, LSh to 1cnrs _while{4}_ 2c & 3c set | cross RH, 2M & 3W facing out (2x,1x,3x)

9--::

  2M+3W chase clw ½ _while{4}_ 2W+1M & 1W+3M set | cross RH (to 1M,3M,2M on M side, 3W,2W,1W on W side) ; 1c chase cclw ½ _while{4}_ 3c & 2c cross RH (to 1W,3W,2W on M side, 3M,2M,1M on W side)

17--::

  3M+2W chase clw ½ _while{4}_ 1W+2M & 3W+1M cross RH (to 2,1,3) ; all turn P RH into allemande hold for

25--::

  3C Allemande (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (12664, '2020-03-13 10:15:56.233961+00', '2020-03-13 10:20:40.981776+00', 10726, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 1c cross LH | dance LSh round 1cnrs into lines3 across

9--::

  All set | cross RH ; all set | 1c turn P RH to 2pl _while{2}_ set, all facing clw (3,1,2)

17--::

  All chase clw ½ (to 2x,1x,3x) ; all turn P RH Halfway and Cast (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (1826, '2012-01-22 19:29:04.45879+00', '2023-02-21 19:33:11.595951+00', 760, 1, NULL, 'ace', '1–::

  1c cross RH, cast off ; lead up and cross, cast off to 2pl (2c up)

9–::

  1c set | cross RH ; set | turn LH to face 1cnrs

17–::

  Turn corner, P, corner, P, finish on own side (2,1,3)

25–::

  2W+1W & 1M+3M (=1c+4cnr position) set, turn RH ; 1W+3W & 2M+1M set, turn LH', 3);
INSERT INTO 'dancecrib' VALUES (7860, '2013-08-21 08:31:50.02987+00', '2023-02-04 01:23:07.678753+00', 9158, 3, NULL, 'ace', '{{explanation}}
All form circle around the room with partner on Mans right

1-8::
    All couples Adv+Ret, set facing in & set to partner
9-16::
    All couples turn partners RH, turn partners LH ending BtoB with
    partner in a large circle
17-24::
    All dance Grand Chain for 4 hands (2 bars per hand) & end with a
    polite turn (the 4th person is your new partner)
25-32::
    All dance round & back', 0);
INSERT INTO 'dancecrib' VALUES (12505, '2020-01-13 02:25:34.127894+00', '2020-05-17 01:40:50.273827+00', 16672, 2, 963, 'ace', '1-8::  

  1&3c lead down middle; change places with prtn, women dancing under men''s right arm and dance back up to finish btob, 1&3w facing up, 1&3m facing down  2s&4s up 3&4

9-16::  

  1c, similarly 3c, turn 1st crn LH, partner RH, 2nd crn LH, partner RH to 2nd/4th place own side  2,1,4,3,5

17-24::  

  All adv/retire and dance btob  

25-32::  

  1c&4c/3c&5c dance the tournée  2,4,1,5,3  



  This can also be danced in a 3 couple set .



', 3);
INSERT INTO 'dancecrib' VALUES (12324, '2019-10-29 23:55:44.25158+00', '2019-10-30 00:26:02.164165+00', 18182, 1, 202, 'ace', '_Strathspey_

1--::
  1c & 3c turn P RH. 1W & 3M face out ; 1c & 3c chase clw ½ to exchanged places (3x,2,1x)
9--::
  1c & 3c repeat [1-8] from new places (1,2,3)

_Jig_

17--::
  1c+2c ½ R&L (to 2x,1x,3) ; 2c+1c set | cross RH (2,1,3)
25--::
  Circle6 L ; chase clw (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12323, '2019-10-29 16:04:28.198437+00', '2019-10-30 03:14:42.799548+00', 11386, 1, NULL, 'ace', '1--::

  1c Petronella turn and set ; Turn RH 1¼ | cast off (2c up) to (2,1,3)

9--::

  1c+3c ½ DblFig8 (1c cross down) ; 2c+1c ½ DblFig8 (1c cross up) (2x,1,3x)

17--::

  2W+1c+3M ½ Rsh Reel4 on 1diag., at end 1c pass Lsh to face 2cnr ; 2M+1c+3W  ½ Reel4 on 2diag., finish 1c Lsh to Lsh in 2pl, facing 1M up/ 1W down (3,*1*,2)

25--::

  3M+1W+2M & 3W+1M+2W RHA ; 1c turn LH 1½ _while{4}_ 3W+2W & 3M+2M change RH and set to P (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3043, '2012-01-22 19:30:08.116187+00', '2020-12-15 19:44:41.213407+00', 5351, 1, NULL, 'ace', '1–::

  1M & 3W meet and lead to the top, 3W casts off to 2pl (2W down) and 1M loops to own place ; 1W+3M repeat (1,3,2)

9–::

  3c followed by 1c lead down the middle (2c up) ; 1c lead up to the top _while{4}_ 3c lead up {2} and turn RH to own places (1,2,3)

17–::

  1c cast off | lead down between 3c (2c up), cast up on own side to 2pl (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10185, '2017-10-18 09:55:02.831663+00', '2019-02-06 00:52:27.247236+00', 18003, 1, 202, 'ace', '1--::

  1c+2c The Knot finishing facing 1cnrs

9-20::

  Dance to corners and set

21-24::

  1c dance out through end cpls | cast L round 3cnrs to 2pl (3x,1,2x)

25--::

  3c+1c+2c diag R&L (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10282, '2017-11-30 10:47:44.976147+00', '2018-04-10 08:58:07.776407+00', 15104, 1, 202, 'ace', '1--::

  All set | turn BH ½ to face ; cast R to exchanged places | set (1x,2x,3x)

9--::

  1c dance down to centre | turn BH ½ to face (2c up) ; cast R Rsh round 3cnrs to finish in centre, Rsh with P, 1W(1M) facing up(down)

17--::

  »Snake Pass across« [1W+3W+2W & 1M+2M+3M LHA ; 1W leading +3W+2W & 1M leading +2M+3M, all pass Rsh to ends, chase clw on own sides, finishing into lines of 3 across, 1W between 3c in 3pl, 1M between 2c in 1pl]

25--::

  1c turn BH ½ to face | cast R Rsh round 4cnrs to 2pl | 1c NHJ dance to 3pl (3c up) (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (11814, '2019-04-29 08:11:21.741602+00', '2019-05-27 06:59:24.812554+00', 3134, 1, 202, 'ace', '1--::

  »Modified Muirland Willie formation«: 1c lead down to 3pl, cross and cast to 2pl, _while{4}_ 2c set and cross RH into 3pl facing out, _while{4}_ 3c cast to top and set (to 3,1x,2x) ; repeat [1-4] from new positions (2x,3x,1)

9--::

  Repeat [1-4] (to 1,2,3) ; repeat [1-4], but on [15-16] 3c cross RH and 1c finish facing 2cnrs, 3M & 2W face out (3x,1,2x)

17--::

  ½ Reel4 on 2diag, 1c pass LSh to face 1cnrs ; ½ Reel4 on 1diag, 1c finish in centre LSh to P, 1M(1W) facing up(down) (2,1,3)

25--::

  1M+2W+3W & 1W+2M+3M RHA, finishing 2W&1M(3M&1W) facing up(down) ; 2c+1M & 1W+3c LHA (2,1,3)



*Deviser''s note: For [1-16], I suggest that RH are used when crossing from own sides, and LH when crossing from opposite sides.*', 4);
INSERT INTO 'dancecrib' VALUES (2741, '2012-01-22 19:29:55.508207+00', '2018-09-03 15:43:43.403665+00', 8118, 1, NULL, 'ace', '1–::

  1c dance in, take promhold, dance behind 2M (2c up) into the middle facing W side ; ½ Reel3 with 2W+3W, Lsh to 2W

9–::

  1M continues reel with the W. _while{4}_ 1W ½ Reel3 with 2M+3M (Lsh to 3M), on [11-12] 1c cross to own side ; all advance [1], retire [1] cross

17–::

  2W+1W+3W dance up the M side, cross and down the W side _while{4}_ all M set and cross (to 3,1,2) ; all turn P RH and stay in the middle facing up

25–::

  3c+1c+2c Allemande', 2);
INSERT INTO 'dancecrib' VALUES (10132, '2017-09-15 13:44:37.356419+00', '2018-04-10 09:16:20.467289+00', 15115, 1, 202, 'ace', '1--::

 1c set | cross RH ; cast (2c up) | turn LH to face 1cnrs

9--::

 1c turn 1cnrs RH | 1c turn P LH ½ _while_ 1cnrs set ; 1c+3cnrs Pass and Turn, 1c turn LH to face 2cnrs

17--::

 1c turn 2cnrs RH | 1c turn P LH ½ _while_ 2cnrs set ; 1c+4cnrs Pass and Turn, 1c turn LH to 2pl

25--::

 Teapots R ; Teapots L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9151, '2016-05-29 05:43:49.690296+00', '2018-09-03 17:42:33.204429+00', 16960, 1, NULL, 'ace', '1--::

  1W ½ Fig8 round 2M into promhold with P ; 1c ½ Reel3 across with 2c, Lsh to 2W

9--::

  1c followed by 2c dance down between 3c and cast up ; 1c+2c ½ R&L (2,1,3)

17--::

  3M ½ fig8 round 1W into promhold with P (M on the R) ; 3c ½ Lsh Reel3 across with 1c

25--::

  3c followed by 1c dance up between 2c and cast off ; 3c+1c ½ R&L (2,3,1)





', 2);
INSERT INTO 'dancecrib' VALUES (12326, '2019-10-30 03:22:10.181598+00', '2019-10-30 04:02:09.964771+00', 19564, 1, NULL, 'ace', '1--::

  1c cross down RH and cast up to 1plx ; cross down LH between 3c (2c up) and cast up to 2pl in middle facing down (2,*1*,3)

9--::

  All M RHA _while{4}_ All W LHA ; continue both HA, 1c/2c/3c in turn crossing down to other wheel 

17--::

  1c, with 2c+3c following dance down the middle {3}, all change sides, W passing above P and under joined arms {2}, and dance up, 3c leading, and 3c cast off to 3pl, 2c face out in 1pl, 1c stays in middle flowing into

25--::

  All M LHA _while{4}_ All W RHA ; 1c dance up between 2c and cast off (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (12327, '2019-10-31 07:14:00.625567+00', '2019-10-31 07:20:44.117814+00', 16899, 1, 202, 'ace', '1--::
  Circle8 L ½ and face P ; set to P | turn P LH. All M face out, All W face in (3,4,1,2)
9--::
  All 8 bars of »reverse Schiehallion Reels« [: same as Schiehallion Reels except that M follows W who dances RSh in centre to the next M place to the L]. All M face out (1,2,3,4)
17--::
  All M dance LSh round P, RSh in centre to the next M place to the L ; dance LSh round new W, RSh in centre, behind next W to the L and finish beside new W
25--::
  All W cast behind new M, LSh in centre to the next W place to the R ; dance RSh round new M, LSh in centre, behind P and finish beside P. All face P (3,4,1,2)
33--::
  RSh interlocking Reels4. All M face in (3,4,1,2)
41--::
  3c+1c ½ M-Chain ; 4c+2c ½ La-Chain
49--::
  3c+1c ½ La-Chain ; 4c+2c ½ M-Chain (3,4,1,2)
57--::
  RSh interlocking Reels4. All W face out (3,4,1,2)
65--::
  All 8 bars of Schiehallion Reels
73--::
  Circle8 L ½ and face P ; set to P | turn P RH ¾ to bring W into centre for bow and curtsey (1,2,3,4)', 2);
INSERT INTO 'dancecrib' VALUES (10474, '2018-03-02 19:26:24.127795+00', '2019-10-31 17:16:02.766216+00', 13487, 1, 202, 'ace', '1--::
  1c+2c ½ DblFig8, 1c crossing down ; 1c+3c ½ DblFig8 round 2c, 1c crossing down (1,2x,3x)
9--::
  1c turn 2c EH 1 ½, 1c in and down to start ; 2c+1c+3c ½ Mirror Reels3, 1c out and down to start, finishing in DTr position facing own side
17--::
  ½ DTr, 1c to 2plx at end (to 3x,1x,2x) ; all turn P RH into promhold facing down (3x,1x,2x)
25--::
  3c+1c+2c »The Japonaise« [Promenade {3} to W side all facing up, slip into middle and face P {1} ; turn P RH] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12804, '2020-05-10 00:07:38.643922+00', '2020-05-12 21:36:12.240851+00', 18808, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; 2c+1W & 1M+3c RHA, 1c pass RSh ready for (2,1,3)

9--::

  2c+1M & 1W+3c LHA. 1c RSh to P face opposite sides ; »RSh Snake Pass« [: unwind the LHA, 1c leading, pass other snake RSh through 2plx and chase clw] (3,1,2)

17--::

  1c turn P RH 1¾ ; ½ Reels3 across, 1c RSh to 4cnrs[pos] (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12580, '2020-02-12 17:42:49.999332+00', '2020-02-13 00:42:48.345819+00', 13507, 2, 1645, 'ace', '1-8::

  1C dance down 2 places, cast up behind 3C, dance to the top and cast to 2nd place (2C step up on Bars 7-8)

9-16::

  2C+1C+3C dance diagonal R+L (8 bars) *M up W down both times* (3)1(2)

17-24::

  3C+1C+2C set, adv+retire and set again

25-28::

  3C+2C chase one place clockwise round the standing 1C, all set

29-32::

  Repeat Bars 25-28 213', 0);
INSERT INTO 'dancecrib' VALUES (1836, '2012-01-22 19:29:05.003198+00', '2021-04-17 17:40:50.981835+00', 795, 1, NULL, 'ace', '1–::

  1c+3c set | turn BH to face up NHJ ; 1c cast to 3pl and lead up LHJ to face 1cnr (2c up) _while_{4} 3c dance to top and cast to 3pl

9–::

  1c dance as in ½Reel4 on 1diag _while_{4} 2c+3c ½ R&L (no polite turn) ; 1c + 1cnrs ½Reel4, 1c pass Lsh to face 2cnr(pos)

17–::

  1c as in ½Reel4 on 2diag _while_{4} 2c+3c ½ R&L up/down (no polite turn) ; 1c + 2cnrs ½Reel4, 1c finish Lsh to Lsh facing opp. side

25–::

  All ½ chase clw (1c merge in) ; All C turn BH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11060, '2018-09-03 12:30:08.886761+00', '2021-01-04 12:09:06.291704+00', 14130, 1, 202, 'ace', '1--::

  3C Knot (3,2,1)

9--::

  All cpls set H.Schottische ; all turn P RH and stay in centre ready for

17--::

  3C Allemande (1,2,3)

25--::

  1c+2c The Tournée (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2783, '2012-01-22 19:29:57.226616+00', '2017-01-21 23:54:48.984016+00', 4365, 1, NULL, 'ace', '1--::

  1c+3c lead far down (2c+4c up) | turn ¾ RH and face P, RHJ ; set , W turning under M’s arm | 1c+3c dance up (W leading)

9--::

  1c+2W & 3c+4W RHA ; 1c+4M & 3c+5M LHA, 1c+3c finish facing 1cnrs

17--::

  1c+3c with 1cnrs pass and turn, pass P Rsh ; repeat with 2cnrs, at end pass P Rsh onto midline, W above and facing M

25--::

  Reel4 on midline, at end pass Rsh in the middle to finish 1c facing out in 2pl on W side / likewise 3c in 4pl on M side

33--::

  1c dance out between 2W & 4W, split, cast round them, meet in middle, repeat through M side _while{8}_ 3c do the same, starting between 4M & 5M. (1M & 3W pass Lsh between 4c). All finish where they started the reel, but 1M faces 3W

41--::

  1W+3M set twice facing up and down _while{4}_ 1M+3W turn RH to face P ; 1c+3c turn P LH ¾ | cast off on own side (4c+5c up) (2,4,1,5,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8747, '2015-04-05 09:18:35.464741+00', '2015-04-05 09:43:23.71653+00', 16185, 1, NULL, 'ace', '1--::

  2c ½ Fig8, Lsh round 1cnr ; ½ Reels3 across, 2c Lsh to 3cnr (1x,2,3x)

9-12::

  Circle6 L 2 places | M chase on 4 places clw inside the W, who loop L on the spot

13-16::

  Circle6 R 2 places | W chase on 4 places cclw inside the M, who loop R on the spot (3x,1,2x)

17--::

  1c lead down, change sides (W crossing above, under M''s arm), and lead up (3x,1x,2x)

25--::

  All set | cross RH ; All turn P RH (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (10278, '2017-11-28 16:44:57.02636+00', '2019-02-01 15:33:12.092369+00', 15114, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; turn LH | cast Lsh round 4cnrs into lines of 3 across, 1c facing 1 cnrs

9--::

  Reels3 across, 1c Rsh to 1cnrs to start (2,1x,3)

17--::

  1c set advancing, finish BtoB facing opposite sides | 4 bars of Crown Triangles, 1c finish BtoB facing own side | 1c set and pivot R ending Lsh to P and facing 1 cnrs

25--::

  1c turn 1cnr RH | pass P Rsh ; turn 2cnr RH | pass P Rsh (2,1,3)

33--::

  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (10217, '2017-10-30 12:14:25.06274+00', '2018-04-10 11:33:51.554214+00', 18000, 1, 202, 'ace', '1--::

  All M ½ RHA _while{2}_ All W chase cclw 1pl | All M turn W LH ; All M ½ RHA _while{2}_ All W chase cclw 1pl | All M turn W LH 1 ¼, finish M facing out

9--::

  Intersecting La-Chain, finish M facing out

17--::

  M dancing behind W on R, LHA ½ ; turn P RH 1 ¾, finish W facing out

25-40::

  Shiehallion reel, finish facing P (3,4,1,2)

41--::

  Gr-Chain, 2 bars per hand (to 1,2,3,4). On [48] all turn P LH ¾, finish M in middle facing P

49--::

  Interlocking Poussette [All dance as 1st cpl in normal Poussette but on [54] all dance ¼ turn instead of ½, then retire, curving slightly, to finish on the diagonals facing in

57--::

  Circle8 and back moving 1pl clw (4,1,2,3)', 4);
INSERT INTO 'dancecrib' VALUES (10177, '2017-10-14 08:31:22.265063+00', '2018-04-10 11:42:33.061911+00', 18008, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA ; 2W+1M cross RH | 2M+1W cross RH (1,2,3)

9--::

  2c+3c set | ½ LHA ; 3W+2M cross LH | 3M+2W cross LH (1,2,3)

17--::

  1c lead down, crossing over (2c up) ; 1c lead up to 2pl, crossing over (2,1,3)

25--::

  2c+1c+3c Mirror Reels3, 1c start out and up (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (12564, '2020-02-04 10:07:28.074811+00', '2020-02-11 15:37:37.226374+00', 19841, 1, NULL, 'ace', '*Start (1,2,3x,4x)*

1--::

  1c+4c cross RH | cast inward (2c+3c to ends) ; cross RH | 1M(leading)+4W & 4M(leading)+1W dance Rsh round 1M/4W positions into

9--::

  2c+(1M+4W) & 3c+(4M+1W) ½ Reels3 across, Lsh to 1W/4M positions (no lead-change), into facing lines of 4 across ; set and cross with opposite up/down [now (3M,1W,4M,3W) facing (2W,1M,4W,2M)]

17--::

  2c+3c chase clw to bar 17 positions _while{8}_ 1c+4c chase clw ½ ; ¾ RHA to finish: 1c & 4c in tandem, W leading, facing 4W/1M places

25--::

  1c+4c, W always leading, ½ Rsh diag. Reel4 on 1diag, pass Rsh up/down ; ½ diag. Reel4 on 2diag, finish in middle (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (9545, '2017-01-22 00:56:19.763102+00', '2017-01-22 00:56:19.763102+00', 12580, 1, NULL, 'ace', '1--::

  1c cast (2c up) | ½ Fig8 up round 2c | turn RH to face 2cnr

9--::

  1c+2cnrs “Corners Pass and Twirl” (Like Corners Pass and Turn, but corners pass Rsh, twirl R to face and cast out to opposite corner) ; 1c+3cnrs repeat (3x,1x,2x

17--::

  All S&Link3 into lines across ; S&Link3 to (2,1,3)

25--::

  2c+1c Slipknot (finish wint ½ LHA), (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3211, '2012-01-22 19:30:15.870168+00', '2021-04-16 22:48:46.700556+00', 5904, 1, NULL, 'ace', '1–::

  1c lead down the middle and up (2c step in)

9–::

  1c+2c Rondel (2,1)

17–::

  2c+1c NHJ A{1}&R{1} | turn BH ; open into circle4 L (to 2,1)

25–::

  2c+1c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (10130, '2017-09-15 08:19:24.963383+00', '2018-04-10 11:50:56.631032+00', 14366, 1, 202, 'ace', '1--::

 All turn P BH, stay in middle | all set advancing to BtoB ; 1c+2c+3c dance to opp sides and chase clw ½, 2c finishing facing 1cnrs

9--::

 2c set “Hello&Goodbye”, on [15-16] 2c set advancing to BtoB

17--::

 2W+3c & 2M+1c RHA ; Lsh Snake Pass (unwind the RHA, 2c leading, pass other snake Lsh through 2plx and chase cclw) to 1,2,3

25--::

 1c+2c set | 1c cast to 2pl _while{2}_ 2c dance up curving out to 1pl ; 1c+3c set | 1c dance down curving out to 3pl _while{2}_  3c cast up to 2pl (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (10276, '2017-11-28 10:33:59.185001+00', '2018-04-10 11:56:04.332069+00', 15118, 1, 202, 'ace', '1--::

  1c turn RH into allemande hold facing W side ; 1c dances Rsh round 2W towards 2M, drop RH and 1M guides P in front of him (2c up on [7-8]) ready for

9--::

  Reel3 in tandem in 1 diag (with lead change), 1c Rsh to 2M, finish in 2 plx, 1W(1M) facing out(in) and up (2,1x,3) ready for

17--::

  Parallel Reels3, 1c Rsh to 2c to start (2,1x,3)

25--::

  1c set | turn BH ½ to face up NHJ ; 1c followed by 3c dance up and cast off (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (11061, '2018-09-03 19:09:21.349531+00', '2018-09-10 14:17:12.311433+00', 18554, 2, 160, 'ace', '1-8::  1s set, cast 1 place; dance down btwn 3s, cast up to 2nd place.
9-16::  half Diagonal R&L (woman up, man down); that again. (3x, 1, 2x)
17-24::  1s set, cast R about; (man in from top, woman in from bottom) 1s birl (turn RH) to end 2nd place opposite sides.  (3x, 1x, 2x)
25-32:: All chase CW to own sides; all birl (turn RH)', 5);
INSERT INTO 'dancecrib' VALUES (9549, '2017-01-24 00:02:26.899209+00', '2017-01-24 00:02:26.899209+00', 17008, 1, NULL, 'ace', '1--::

  1c+4c cross, cast inwards (2c+3c to end) ; ½ Fig8 through end couple (2,1,4,3)

9--::

  1c+2c & 3c+4c Slipknot (like 2C Knot, but finish with ½ LHA; no progression), finish 2M & 3W facing out with P close behind (2,1,4,3)

17-20::

  2c & 3c in tandem cast inwards, cross (1c+4c to ends) and leading dancer faces out (1,2x,3x,4)

21-24::

  1W+2c+4W  & 1M+3c+4M ½ Rsh tandem reels3 on the sides (no lead change), 2c+3c finish on own side in line across, 2M (at end) facing 3M and 3L (at end) facing 2L

25--::

  2c+3c set | petronella to sideline (4,3,2,1) ; S&Link4 in tandem (4c+3c move down, 2c+1c move up, passing in the middle to finish 2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12573, '2020-02-11 21:41:44.937183+00', '2020-02-12 14:59:51.35463+00', 15632, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*



1--::

  1c+2c & 3c+4c S&Rotate (2,1,4x,3x)

9--::

  2c+1c & 4c+3c DblFig8, 1c & 4c crossing (2,1,4x,3x)

17--::

  1c+4c set | ½ LHA (to 2,4,1x,3x) ; 2c+4c & 1c+3c RHA

25--::

  Circle8 and back ', 2);
INSERT INTO 'dancecrib' VALUES (10746, '2018-05-07 00:47:54.44562+00', '2018-05-07 01:05:59.350471+00', 18316, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) to finish facing 2cnrs ; ½ Reel4 on 2diag, pass Lsh to face 1cnrs

9--::

  ½ Reel4 on 1diag, finish in centre 1M(1W) facing up(dn) ; 1c set | turn P RH ½ into facing lines of 3 across

17--::

  All set | change places RH ; 1c loop round 4cnrs to 2pl | all set (2x,1,3x)

25--::

  1M+2c & 1W+3c ½ Reels3 across, 1c Rsh to 2cnr[pos] (to 2,1x,3) ; 1c turn P RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10605, '2018-04-11 08:39:16.470964+00', '2019-02-11 10:22:01.194014+00', 17683, 1, 202, 'ace', '1--::

  1c+2c set | A&R {2+2} | 1c cast (2c up) (2,1,3,4)

9--::

  1c+3c RHA ; 2c+1c LHA

17--::

  1c lead down {3}, lead up {3}  cast to 4pl (3c+4c up) (2,3,4,1)

25--::

  4c+1c R&L', 4);
INSERT INTO 'dancecrib' VALUES (10602, '2018-04-11 00:14:10.692241+00', '2018-04-11 01:20:52.942528+00', 17524, 1, 202, 'ace', '1--::
  1c+2c Reel4 across, 1W+2M start passing Lsh, to finish 2c in 2pl and 1c in midline facing down  1W leading, 1M behind P
9--::
  1c dance down {3}, pull Rsh back, 1M leading dance up {3} and cast to 3pl (2c+3c up) (2,3,1)
17--::
  2c & 1c facing diagonally, all set | all dance in to form a circle, on [20] pull Rsh back to face out ; dance out, on [22] pull Rsh back to form a circle and face in | all set (no hands)
25--::
  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10601, '2018-04-10 19:56:16.034674+00', '2018-04-11 00:46:11.188045+00', 17526, 1, 202, 'ace', '1--::
  1c+2c turn RH ¾ to middline into promhold, 1c facing M side, 2c facing W side | 1c+2c keeping close together dance cclw ½ into middline, facing P at end, W(M) facing up(dn) ; set to P RHJ | turn RH ¾ to sidelines (2,1,3)
9--::
  Reels3 across, 1c start Rsh to 1cnrs, on [8] 1c pull Lsh back into facing lines of 3 across
17--::
  Circle6 and back into facing lines of 3 across
25--::
  1c Petronella turn to centre, ending BtoB in crown triangle position | all set ; 1c cast L round 3cnrs to 2pl (2,1,3) ', 2);
INSERT INTO 'dancecrib' VALUES (10603, '2018-04-11 01:30:15.266723+00', '2018-04-11 08:18:45.142123+00', 16618, 1, 202, 'ace', '1--::
  1c turn RH | cast (2c up) ; dance up between 2c | cast to 2pl (2,1,3)
9--::
  ½ Mirror Reels3 on sidelines, 1c start in and down ; ½ Reels3 across, 1c start Lsh to 1cnrs position (3x,1x,2x)
17--::
  Diagonal R&L, 1W up, 1M down to start  (2,1x,3)
25--::
  1c Petronella turn | set ; repeat (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10604, '2018-04-11 06:42:04.302095+00', '2018-04-11 06:47:47.962747+00', 17533, 1, 202, 'ace', '1--::

  1c long cast (2c up) ; all turn BH (2,1,3)

9--::

  1c Petronella turn into facing lines of 3 across | all set ; repeat to sidelines (2,1x,3)

17--::

  Reels3 on sidelines, 1c start by crossing LH to 3pl, all joining NH when possible. 1c & 3c continue the reels one more place (2,3,1)

25--::

  Circle6 and back.', 2);
INSERT INTO 'dancecrib' VALUES (12574, '2020-02-11 21:48:10.895637+00', '2020-02-11 21:48:10.895637+00', 8644, 1, NULL, 'ace', '1--::

  1W+2c Rsh Reel3 across (1,2)

9--::

  1M+2c Lsh Reel3 across (1,2)

17--::

  Dbl Fig8, 1c cross down and 2c cast upto start

25--::

  1c+2c Allemande (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9550, '2017-01-24 00:26:36.953838+00', '2017-01-24 00:26:36.953838+00', 10370, 1, NULL, 'ace', '1--::

  All set | cross RH ; All chase clw ½ round (4,3,2,1)

9--::

  All turn P BH 1½ ; All chase clw ½ round (1,2,3,4)

17--::

  All ½ Reels4 on the sides ; 3c+2c+1c ½ Reels3 on sides (4,1,2,3)

25--::

  4c+1c & 2c+3c Slipknot (= 6 bars of 2C knot + ½ LHA) (4,1,2,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9551, '2017-01-24 21:21:42.441931+00', '2017-01-24 21:22:05.574407+00', 15001, 2, 160, 'ace', '1-8::
  All dance (NHJ) CCW ; turn inward dance back to place.
9-16::
  1/2 Turn and Cast (into ptnr''s pl). ; Repeat LH.
17-24::
  Both lines circle Right ; set to new ptnr , Turn RH into prom hold.
25-32::
  All prom. CW.', 3);
INSERT INTO 'dancecrib' VALUES (9552, '2017-01-24 21:35:45.167501+00', '2017-01-24 21:36:13.753616+00', 15002, 2, 160, 'ace', '1-8::
  All set , 3C 1C dance down below 4C  cast up behind own lines - (3 2 1 4)
9-16::
 3C 2C and 1C 4C  R&L. 
17-24::
  2C 1C RHA ; LHA *While* 3C 4C chase CCW round the set.
25-32::
  3C 2C and 1C 4C- Set&Link ; hands 4 to left.', 3);
INSERT INTO 'dancecrib' VALUES (9553, '2017-01-24 21:54:37.229957+00', '2017-01-24 21:54:37.229957+00', 15017, 2, 160, 'ace', '1-4::
  1C 2C Set&Link.
5-8::
  1M followed by 2M dance to top and down the middle to 2pl. *while* 1L followed by 2L dance up to the top and down behind own lines to 2pl.
9-16::
  1C followed by 2C dance down for 2. set to ptnr ; 2C 1C dance up.
17-24::
  Set to corner partner (Pet. turn into 2pl.)
25-32::
  6 hands round and back.
', 3);
INSERT INTO 'dancecrib' VALUES (9554, '2017-01-24 22:02:58.431877+00', '2017-01-24 22:02:58.431877+00', 15004, 2, 160, 'ace', '1-8::
  1C 2C set, turn BH ; circle left.
9-16::
  1C 2C dance Half Rondel 
17-24::
  2C 1C circle right - 2C face down NHJ, 1C face up NHJ. - 2C 1C Set&Link.
25-32::
  2C 1C chase CW to opp. sides ; 1/2 Turn&Cast to own sides.', 3);
INSERT INTO 'dancecrib' VALUES (12512, '2020-01-17 21:10:58.507272+00', '2020-01-17 21:10:58.507272+00', 6473, 1, NULL, 'ace', '1--::

  Circle 6 and back

9--::

  Gr-Chain  (1,2,3)

17--::

  1c set | cast to face 1cnr ; set to 1cnr | to 2cnr

25--::

  Reels3{6} on the sides, Rsh to 2cnr | cross to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9555, '2017-01-24 22:28:25.844013+00', '2019-03-23 14:09:02.43326+00', 15005, 2, 160, 'ace', '1-8::

  8 hands round & back

9-16::

  All Adv.&Ret. ; All turn RH once round.

17-24::

  1C 3C in prom hold dance in passing Rsh, cast left round side C back to place [6] all set - 1C to face 4C and 3C to face 2C on the diagonal.

25-32::

  1C 4C + 3C 2C dance R&L.

33-40::

  All chase CCW half round ; all Turn LH 1_1/4 (Ladies in the middle)

41-48::

  Ladies RHA ; turn ptnr LH 1_1/2 (Men in the middle).

49-56::

  Men RHA to pl.  ; All chase CW half round to original pl.

57-64::

  All Adv&Ret. ; All turn RH once round.

65-72::

  2C 4C in prom hold dance in passing Rsh, cast left round head C back to place [6] all set - 2C to face 1C and 4C to face 3C on the diagonal.

73-80::

  2C 1C + 4C 3C dance R&L.

81-88::

  8 hands round & back.', 3);
INSERT INTO 'dancecrib' VALUES (10747, '2018-05-07 01:47:39.896871+00', '2020-11-15 11:29:49.381162+00', 18317, 1, 202, 'ace', '1--::

  1c & 2c turn RH ½ and face down | lead down {2} ; change sides  (W crossing above, under M’s arm) and lead up to original places, 1W & 2M facing out (1,2,3)

9--::

  1c+2c Reel4 across with progression (2,1,3)

17--::

  1c ½ Fig L round 2cnrs ; 1c turn P RH 1 ½ (2,1,3)

25--::

  2c+1c Circle4 and back', 2);
INSERT INTO 'dancecrib' VALUES (11567, '2019-02-06 22:55:17.346352+00', '2019-02-08 17:37:18.401572+00', 19059, 1, NULL, 'ace', '1--::

  1c+2c+3c Inveran reels{6} | 1c pass Rsh to face 1cnr

9--::

  1c turn 1cnr RH and pass P Rsh to face 2cnr ; ½ Reel4 on 2diag., at end 1c face 3cnr

17--::

  1c turn 3cnr RH and pass P Rsh to face 4cnr ; ½ Reel4 on 2diag. to (2,1,3,4)

25--::

  1c ½ Fig8 round 3c ; 1c cross down between 3c and 4c (3c up) and turn 4c EH ½ to (2,3,4,1)

33--::

  All Circle8 and back (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (11173, '2018-09-30 09:54:34.406228+00', '2020-11-19 19:22:06.553147+00', 18636, 1, 1645, 'ace', '{{title}}

Strathspey (1c, 2c & 3c)



1-::

  1c & 2c set | 6 bars of DblFig8, 1c casting to start (2x,1x,3,4)

9-::

  Mirror Reels3 on sides taking NH, 1c start in & down, 2c & 3c end with loops, 1c end facing 1cnrs

17-::

  Set H&G | 1c turn &frac34; LH & face down

25-::

  1c cross down | cast up _while{2}_ 3c dance in, face down & cast away to sides ; 1c+3c turn twice EH on sides to (2,1,3,4)



{{title}}

Reel (1c, 3c & 4c)



1-28::

  As for Strathspey (2,3,1,4)

29-32::

  1c+3c turn 1&frac12; EH on sides to (2,3,4,1)

', 4);
INSERT INTO 'dancecrib' VALUES (12665, '2020-03-13 10:32:06.448975+00', '2020-03-13 10:34:41.467293+00', 10619, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; ½ Fig8 R round 1cnrs to 2plx (2,1x,3)

9--::

  All set | cross RH ; Circle6 L ½ retaining hands on sides (3,1x,2)

17--::

  All set | cross LH ; Circle6 R ½ (2,1x,3)

25--::

  1c cast round 1cnrs to between ends | cross RH up/down ; dance LSh round 3cnrs to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3781, '2013-07-13 15:56:05.032295+00', '2015-04-07 07:00:54.188313+00', 14568, 1, NULL, 'ace', '1–::

  1c+2c DblFig8, 1c crossing down

9–::

  Mirror reels on the sides, 2c starts out and up

17–::

  1W with 1M following dance down the middle ; 1M with 1W following dance up, casting behind 2c to (1,2,3)

25–::

  1W+2W & 1M+2M change places EH (1c starts inwards) | 1c+3c turn EH 1½ to (2,3,1), 3c facing out to start again



{{explanation}}

The 6C version of this dance is called »Double the Trouble«.', 3);
INSERT INTO 'dancecrib' VALUES (3658, '2012-12-08 11:01:00.216612+00', '2019-02-06 00:50:25.480145+00', 12243, 1, NULL, 'ace', '1–::

  Circle8 and back

9–::

  1c+3c: with person opposite dance ½ Fig8 through nearest side couple, turn RH ½, and twirl R to own place facing out

17–::

  All turn cnr EH and face P ; All set to P and turn P BH with skip-change, to places

25-40::

  2c+4c: repeat [9-24]

41–::

  All W ½ RHA | dance Lsh round opposite M | ½ RHA to places

49–::

  All M ½ LHA | dance Rsh round opposite W | ½ LHA into

57–::

  In promhold, M on the L, all dance cclw round the set to places.', 3);
INSERT INTO 'dancecrib' VALUES (10599, '2018-04-09 16:30:30.394671+00', '2021-08-02 14:15:12.883891+00', 9776, 1, 202, 'ace', '1--::

  Mirror Reels3 on opposite sides, 1c (then all cpls in 1pl) crossing down to start (1x,2x,3x)

9--::

  Repeat [1-8] back to own sides (1,2,3)

17--::

  1c lead down and up (1,2,3)

25--::

  1c+3c DblFig8, 1c cast to start(1,2,3)

33--::

  1c+2c The Knot (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10748, '2018-05-08 16:39:51.141323+00', '2018-05-08 16:53:55.409001+00', 18222, 1, 202, 'ace', '1--::

  4W followed by 3W, 2W & 1W dance up to top, cast off behind M side and up on W side

9--::

  All M repeat [1-8] in mirror pattern with 4M leading (4,3,2,1)

17--::

  Mirror Reels3 with 3c+2c in tandem (with lead change) on sidelines, 4c start out and down and finish facing out (4,3,2,1)

25--::

  4c followed by 3c, 2c & 1c cast off to 4pl, form an arch ; 3c followed by 2c & 1c dance up  through arch (to 3,2,1,4)

33--::

  3c & 4c cross RH _while{2}_ 2c+1c ½ RHA | 3c+1c & 2c+4c change places LH (to 1x,3x,4x,2x) ; 1c & 2c cross RH _while{2}_ 3c+4c ½ RHA | 1c+4c & 3c+2c change place LH (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (8748, '2015-04-06 15:03:02.602242+00', '2021-01-30 11:00:28.450634+00', 11063, 2, 160, 'ace', '1-8::

  1C 2C petronella in tandem ; repeat. (2x 1x 3)

9-16::

  1C dance a petronella turn, 1M up, 1L down, 1C set advancing & pass Lsh ;

  1L 2C also 1M 3C dance RH Across. 1C end 2pl own side. (2x 1 3)

17-24::

  1C dance a petronella turn, 1L up, 1M down, 1C set advancing & pass Lsh ;

  1M 2C also 1L 3C dance RH Across. 1C end on sides. (2X 1X 3)

25-32::

  1C dance up NHJ, cast to 2pl ; 2C 1C set and cross RH to own sides.', 0);
INSERT INTO 'dancecrib' VALUES (12581, '2020-02-12 22:08:01.119943+00', '2020-10-12 11:38:24.255432+00', 15636, 1, 202, 'ace', '_Strathspey_
1--::
  All set | cross RH ; repeat (1,2,3)
9--::
  1c turn RH | cast off (2c up) ; turn LH to face 1cnrs
17--::
  Corners Pass and Turn (2,1,3)
25--::
  1c+3c S&Link ; 3c+1c Circle4 (2,3,1)

_Reel_  
1--32::
  2c repeat in reel time

*Note:*  
3rd couple repeat in strathspey; 1st couple repeat in reel time; 2nd couple in strathspey and 3rd couple in reel time.', 4);
INSERT INTO 'dancecrib' VALUES (10750, '2018-05-08 21:34:46.371375+00', '2018-12-29 12:44:02.013122+00', 18217, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; 1c ½ Fig8 up round 2c (2,1,3)

9--::

  1c set advancing to face 1cnrs _while{2}_ 1cnrs set | 1c turn 1cnrs BH into facing lines of 3 across ; 1c set advancing to face 2cnrs _while{2}_ 2cnrs set | 1c turn 2cnrs BH to sidelines (2,1x,3)

17--::

  1c lead down ; and up to 2plx centre

25--::

  1c lead up, cross and cast to 2pl ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10606, '2018-04-11 09:03:51.428358+00', '2018-04-11 09:19:03.459697+00', 17684, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c RHA ; 2c+4c LHA into Reel4 position

9--::

  Parallel Reels4, ending odd cpls facing down, even cpls facing up

17--::

  All set | change places RH (to 2,1,4,3) ; ½ Parallel Reels4, ending odd cpls facing down, even cpls facing up (3,4,1,2)

25--::

  All set | change places RH (to 4,3,2,1) ; 4c+3c+2c ½ Parallel Reels3, 3c Lsh to 2c to start (2,3,4,1)

33--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (10749, '2018-05-08 18:11:25.145763+00', '2019-02-01 15:26:58.877911+00', 16827, 2, 2929, 'ace', '1-4:: 1L and 4M lead a chase followed by their partner: cast up/down around 2/3C and dance across

5-8:: 1C+4C LH across

9-12:: 1C+4C dance out (1M+4L out ends, 1L+4M out sides) and cast around one person, pulling back right shoulders at end WHILE 2C+3C advance and retire on diagonal

13-16:: Repeat from new positions, 1C+4C finishing slightly inside, M facing down, L facing up

17-24:: Alternating tandem reels of 3 on sides

25-32:: 4C+1C slip knot

', 4);
INSERT INTO 'dancecrib' VALUES (10608, '2018-04-11 12:03:56.649053+00', '2018-04-11 16:02:59.299774+00', 13919, 1, 202, 'ace', '1--::
  1c+2c The Knot, 1c continue turning LH to face 1cnrs
9--::
  1c+1cnrs set | 1c turn 1cnrs RH ¾ to face 4cnrs ; ½ Reels3 across, 1c start Lsh to 4cnrs, passing P Rsh to face 3cnrs position at end
17--::
  1c+2cnrs set | 1c turn 2cnrs RH ¾ to face 2cnrs position ; ½ Reels3 across, 1c start Lsh to 2cnrs position, passing P Rsh to 2pl
25--::
  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (12578, '2020-02-12 16:10:37.576245+00', '2021-01-11 12:56:45.048037+00', 11181, 1, 202, 'ace', '1--::

  1M+3W & 2M+4W turn BH 1½ ; 1W+3M & 2W+4M turn BH 1½ (3x,4x,1x,2x)

9--::

  3c+4c & 1c+2c RHA 1½ (to 4,3,2,1) | all set advancing and meet P in centre

17--::

  4C Allemande. On [23-24] 1c turn P RH ending RSh to P between 2c facing opposite sides

25-36::

  12 bars of The Spurtle (2x,3x,4x,1x)

37-40::

  All turn P RH ¾ to midline | Petronella turn (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3067, '2012-01-22 19:30:09.132393+00', '2020-12-15 19:46:50.05679+00', 5443, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c set | RHA | 1c+3c cast off _while{2}_ 2c+4c dance up (to: 2,1,4,3,5)

9–::

  1c+4c+3c mirror Reels3 on own side, 4c starting up and out, join hands where possible

17–::

  2c+1c & 3c+5c full DblFig8, end couples casting, inner C (1c & 3c) crossing (2,1,4,3,5)

25–::

  1c & 3c ½ RH turn and face the other couple down/up | set ; the right hand partners (1W & 3M) cast out through own side and cast off one _while{4}_ left hand partners (1M & 3W) cross to own side and cast off one (4c+5c up) (to: 2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (2497, '2012-01-22 19:29:45.146718+00', '2020-05-05 22:50:26.808227+00', 3225, 1, NULL, 'ace', '1–::

  1W advance to P | set ; dance Lsh round 2M to between 2c | set to 2M

9–::

  1M+1W+2M set twice (join first RH, then LH) ; 1c turn RH, 1W passing under 1M''s arm into Allemande-hold facing W side (2c up)

17–::

  1c Fig8 round 2c, start Rsh to 2W, at end 1W passes under 1M''s R arm to finish BtoB between 2c, 1W facing 2M and 1M facing 2W

25–::

  1c+2c Reel4 across, at end 1c pass Rsh and face P (in the starting places of the reel)

33–::

  1c set twice, turn RH 1½ to 2pl   



*(Note: 1W dancing round 2M in bars [5-6]  is very challenging.  Originaly the dance was also taught without setting on [7-8])*', 3);
INSERT INTO 'dancecrib' VALUES (12575, '2020-02-12 07:26:03.256488+00', '2021-03-31 19:33:29.465197+00', 19548, 1, NULL, 'ace', '1--::

  1c set | cast  (2c up) ; ½ Fig8 up (2,1x,3)

9--::

  All turn P RH ; chase clw ½ round (3x,1,2x)

17--::

 Diag R&L, first to the R, then to the L   Cnrs make polite turns (2,1,3)

25--::

  2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA (2,1,3)









', 3);
INSERT INTO 'dancecrib' VALUES (14065, '2021-06-13 13:18:25.612964+00', '2021-06-14 08:59:10.376098+00', 1878, 1, 1645, 'ace', '1-::
  1c cross | cast off (2c up) ; 1c set | cast up _while{4}_ 2c set | dance down NHJ to face out (1x,2,3)
9-::
  1c cross down into Reels3 on own side, 2c start up & out (1,2,3)
17-::
  1c & 2c &frac12; turn P RH | lead down ; &frac12; turn | lead up staying in centre
25-::
  1c+2c Poussette (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (14067, '2021-06-14 07:18:22.51602+00', '2021-06-14 07:21:41.948087+00', 2457, 1, 202, 'ace', '1--::
  1c+2c ½ RHA | turn P RH ½ (to 2,1) ; 2c+1c ½ LHA | turn P LH (1,2)
9--::
  1c turn P RH 1½ ; ½ Fig8 down round 2c (2,1)
17--::
  1c & 2c turn P RH ½ | 2c (+1c following) lead down ; 1c & 2c turn P RH ½ | 1c (+2c following) lead up ready for
25--::
  2C Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (14464, '2021-11-23 09:48:52.381268+00', '2021-11-23 09:52:42.060527+00', 20517, 1, 202, 'ace', '1--::

  1M+2W change places RH | 1W+2M repeat ; 2c+1c chase clw ½ (1,2,3)

9--::

  1c set | cast off (2c up) ; dance down between 3c | cast up and face 1cnrs

17--::

  ½ Reel4 on 1 diag, pass P LSh ; ½ Reel4 on 2diag (3x,1x,2x)

25--::

  All A&R ; Circle6 L ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11815, '2019-04-29 08:24:23.454166+00', '2019-05-19 07:54:10.791813+00', 19277, 2, 26003, 'ace', '

1- 8:: 1s dance in and cast, lead down between 3s, cross and cast up to 2nd place on opp.sides



9-16:: 1s petronella turn to centre (1M between 2s facing down, 1L between 3s facing up), all set and dance 1/2 RSh reel of 3 across (1s to R to begin).



17-24:: 1s petronella turn to own sides, all set and dance 1/2 LSh reel of 3 on the side (1s to L to begin).



25-32:: 1s dance diagonal R&L (1M down, 1L up to begin), ending 213 on own sides.



33-40:: All set, 1s+3s ‘link’ to change places, all turn 2H once round.



41-48:: All circle 6H round and back   231', 5);
INSERT INTO 'dancecrib' VALUES (10751, '2018-05-09 02:25:35.56383+00', '2018-05-09 02:34:10.504682+00', 18207, 1, 202, 'ace', '1--::

  3C Gr-Chain, 1c cross to start (1,2,3)

9--::

  1c dance down | turn P BH ; dance up | cast off to face 1cnrs (2c up)

17--::

  1c+1cnrs Corner Chain with Setting

25--::

  1c+2cnrs repeat [17-24]  (2,1,3)



*Deviser''s note:  

At the end of the second time through 1st couple cross down to 4th place while the 3rd couple step up.*', 2);
INSERT INTO 'dancecrib' VALUES (10752, '2018-05-09 02:51:19.955929+00', '2018-05-09 02:59:12.222827+00', 18212, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; 1c cross LH | cast (3c up), 2c & 3c facing down (2,3,1,4)

9--::

  Mirror Reels3 with 1c+4c in tandem (with lead change) on sidelines, 1c+4c start in and up (2,3,1,4)

17--::

  1c cross RH | cast (4c up) ; 1c ½ Fig8 up round 4c (2,3,4,1)

25--::

  Circle8 and back (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (1725, '2012-01-22 19:28:58.563305+00', '2019-04-29 16:27:28.838147+00', 407, 1, NULL, 'ace', '1–::

  1c+2c set | turn P BH ; 1c+2c ½ circle4 L | cross RH to (2,1,3)

9–::

  2c+1c+3c set | Circle6 L | set (2,1,3)

17–::

  Reels3 across, Lsh to 1cnr, at end pass Lsh to face 2cnr

25–::

  Reels3{6} on opposite sides, Rsh to 2cnr | 1c cross RH (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (11064, '2018-09-04 18:23:33.159133+00', '2018-09-04 18:34:26.67905+00', 9373, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; »RSh Turn« [dance RSh round P to places] (2,1,3)

9--::

  2c+1c Poussette. On [15-16] 1c drop hands closest 3c and pivot to finish BtoB facing own sides

17--::

  »Modified DTr« [same as DTr except that cnrs start setting to the left], 1c face 1cnrs

25--::

  Corners Pass and Turn (2,1,3)



*Note:  

»RSh Turn« (Right Shoulder Turn) is also known as Gypsy Turn, a term now considered offensive by some.*', 2);
INSERT INTO 'dancecrib' VALUES (9556, '2017-01-24 22:42:21.052658+00', '2017-01-24 22:42:53.397797+00', 15006, 2, 160, 'ace', '1-6::
  1C 2C 3C Reel 3 on own sides - 1C in&down [6]
7-8::
  1C pass L to face 2crnr *AS* 2C end at top & 3C loop into pl.
9-16::
  1C+crnrs dance Lsh Reel 3 on opp. side - 1C face 1crnr.
17-32::
  Four 1/2 diagonal Reels 4 - 1C pass by Rsh in the middle.', 3);
INSERT INTO 'dancecrib' VALUES (12579, '2020-02-12 16:54:53.387782+00', '2020-02-13 00:42:48.342773+00', 13507, 1, NULL, 'ace', '1--::

  1c dance down the middle, cast up round 3c, dance up between 2c and cast off (2c up ) (2,1,3)

9--::

  Diagonal R&L (unusual: first to the L, then to the R) (3x,1,2x)

17--::

  All set | A&R | set (3x,1,2x)

25--::

  3c+2c chase to next place clw round 1c who stand, 3M+2W casting to start | all set to opposite ; repeat last 4 bars. (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10611, '2018-04-12 08:00:42.834148+00', '2018-04-12 09:00:06.89352+00', 13929, 1, 202, 'ace', '1--::

  1c+3c Petronella turn to midline (2c & 4c up)  | set ; 1c(3c) turn P LH ½, cast Lsh round 2c(4c), pass P Lsh to finish between 2c(4c) BtoB facing opposite sides

9--::

  Parallel Reels4 across, on [15-16], 1c & 3c turn P RH ¾ to midline, M(W) facing up(dn)

17--::

  1c+3c ½ Reel4 ; 3c+2c & 1c+4c RHA

25--::

  3c(1c) set advancing, turn P BH ¾ to face up NHJ between 2c(4c) ; 3c(1c) cast into 2pl(4pl) | all set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12506, '2020-01-13 08:31:38.371765+00', '2020-05-17 01:40:50.275836+00', 16672, 1, 202, 'ace', '1--::

  1c & 3c lead down (2c & 4c up) ; on [5] 1c & 3c change sides (W crossing above, under M’s arm) and lead up to 2pl & 4pl midline, BtoB M(W) facing down(up)

9--::

      »Turn CPCP Other Hand« [: 1cnr LH | P RH ; 2cnr LH | P RH to own side] (2,1,4,3,5)

17--::

    All A&R ; dance BtoB (2,1,4,3,5)

25--::

    1c+4c & 3c+5c The Tournée (2,4,1,5,3)', 4);
INSERT INTO 'dancecrib' VALUES (10612, '2018-04-12 09:39:33.639511+00', '2018-04-12 11:00:20.311122+00', 13928, 1, 202, 'ace', '1--::

  1c+2c dance down. On [4], 1c cross over and face up NHJ, 2c divide ; 1c followed by 2c dance up. On [8], 1c cross over to 1pl and face down, 2c dancing out to 2pl

9--::

  1c+2c facing dn/up turn EH 1½, 1c start in and down ; 1c dance down and cast up round 3c to 2pl centre into promhold facing 2W

17--::

  1c Rsh Reel3 on 2diag, finish in centre facing 2M

25--::

  1c Lsh Reel3 on 1diag to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11566, '2019-02-05 23:04:57.613516+00', '2019-02-17 01:12:28.838626+00', 7578, 1, NULL, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 L (2,1,3)

9--::

  2c+1W & 1M+3c RHA, 1c pass Lsh to face 2cnr ; 1c+2cnrs ½ diag. Reel4, at end 1c turn LH ½

17--::

  1W+3c (on W side) & 1M+2c (on M side) RHA, 1c pass Lsh to face 1cnr ; 1c+1cnrs ½ diag. Reel4, 1c finish BtoB in 2pl facing own side

25--::

  All set as in DTr | Cnrs set as 1c spiral R to 2plx ; All chase ½ clw to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12227, '2019-09-16 23:49:05.609383+00', '2021-06-14 08:20:30.78496+00', 19648, 1, 202, 'ace', '1--::

  2c ½ Fig8 up round 1c ; 1c & 2c turn P RH (1,2x)

9--::

  2C Set&Rotate, all facing diagonally on [9] (2x,1)

17--::

  2c+1c Circulating Knot [: 4 bars of the Knot, 2c looping up, 1c down ; 1M & 2M pass their P across, 1W & 2M (P following) pass RSh curving out to places slighty inside the set] (2,1x)

25--::

  Circle4 L on [28] cross R foot over L, pivot and chase back cclw (2,1x)

33--::

  2c & 1c set diagonally | set to P ; 1c ½ Fig8 up round 2c (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (10613, '2018-04-12 11:24:22.686207+00', '2018-04-12 14:50:04.086823+00', 13927, 1, 202, 'ace', '1--::
  1c long cast to behind 2c, dance down between 3c and cast up to 2pl (2c up) (2,1,3)
9-20::
  3C R&L (2,1,3)
21-24::
  2c & 3c turn P RH _while{4}_ 1c turn P RH 1¾ into lines of 3 across, 1c facing 4cnrs
25--::
  Rsh Reels3{6} across | 1c cast R round 4cnrs to 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10614, '2018-04-15 10:16:59.459692+00', '2018-04-15 10:16:59.459692+00', 12093, 1, NULL, 'ace', '1-::

  1c &amp; 3c &frac12; Fig8 between 2c &amp; 4c ; 1c+2c &amp; 3c+4c RHA, 1M &amp; 4M end facing out (1x,2,3x,4)

9-::

  1M &amp; 4M followed by P cast off/up 3pl _while{4}_ 2c+3c LHA (4x,2,3x,1) ; 4c+2c &amp; 3c+1c S&Link (2,4x,1,3x)

17-::

  4c+1c+3c S&Link twice (2,3,1x,4)

25-::

  1c+4c S&Link ; 1c set | cross RH (2,3,4,1) 

', 2);
INSERT INTO 'dancecrib' VALUES (13817, '2021-03-15 21:21:32.05366+00', '2021-03-15 21:25:39.789741+00', 14680, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; cross LH | cast off (3c up) (2,3,1)

9--::

  Circle6 and back

17--::

  1c cross RH | cast up (3c down) ; cross LH | cast up (2c down) (1,2,3)

25--::

  Circle6 and back

33--::

  1c+2c *modified 2c Allemande* : same as 2C Allemande except 1c dance down 2 places on [35-36] _while_ 3c step up (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2123, '2012-01-22 19:29:21.310229+00', '2022-10-22 14:21:37.047677+00', 1793, 1, NULL, 'ace', '1–::

  1c set | cast off 2 (2c +3c up) ; set and face out | cast up (3c down), 1c curve R into facing lines across (1W between 2c, 1M between 3c)

9–::

  All set | 2c & 3c set as 1c petronella to 2plx ; all set to P twice 

17–::

  Reels3{6} on the sides, Rsh to 2cnr | 1c cross RH to 2pl.', 3);
INSERT INTO 'dancecrib' VALUES (13464, '2020-12-16 01:21:36.92926+00', '2020-12-16 01:25:03.840951+00', 12479, 1, 202, 'ace', '1--::

  1c dance behind own lines {3} and back {3} | 1c+2c turn EH ½ on sides (2,1,3)

9--::

  Mirror Reels3 on sides, 1c out and down into DTr position (2,1,3)

17--::

  DTr. 1c finish in centre RSh to P, 1M facing up

25--::

  1M+3M+2M & 1W+2W+3W LHA ; 1c turn P RH to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (4395, '2013-08-21 08:30:48.241155+00', '2023-02-21 19:33:11.599059+00', 760, 3, NULL, 'ace', '1-8::

    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 2s

9-16::

    1s set, cross RH, set & turn LH to face 1st corners

17-24::

    1s turn 1st corners RH, turn partners LH, 2nd corners RH & partners

    LH to 2nd places.  2 1 3

25-32::

    1s set to person on right & turn RH, 1s set to person on left & turn

    LH', 0);
INSERT INTO 'dancecrib' VALUES (10569, '2018-04-02 20:07:39.405175+00', '2018-04-15 10:33:06.781568+00', 12099, 2, 1, 'ace', '1–4:: 1M crosses over, casts behind 2L [to middle below 2c facing up]

   _while_ 1L dances between 2c, casts up behind 2M [to middle above 2c

   facing down]

   _while_ 3c&5c dance likewise around 4c&6c

5–8:: 1c+2c & 3c+4c & 5c+6c RH across

9–:: 1c+3c+5c Reel6 [6 changes, 1 step per change,

   fin 5M,5L,3M,3L,1M,1L, M facing down, L up] | 

   dance one more change passing ptr RS

   [fin facing ptrs, M facing up, L down]

17–:: 5c turn ¾ R [fin facing up NH joined]

  _while_ 2c dance up and in [fin facing down NH joined]

  _while_ 3c+4c & 1c+6c dance likewise [all M have ptr on their left] | all S ;

  in groups of 2cpls, 4H round to L [to 25x43x61x]

25–30:: 5c&3c&1c ½ fig8 up | turn ptr BH

31–32:: 5c turn BH _while_ 3c lead down to 6pl _while_ 1c cast up to 4pl

   [to 254163]', 3);
INSERT INTO 'dancecrib' VALUES (11568, '2019-02-07 02:39:02.989625+00', '2020-12-07 13:05:19.07673+00', 9376, 1, 202, 'ace', '1--::

  All M (1M leading) chase clw ½ _while{4}_ All W (1W leading) chase cclw ½, all passing RSh) ; all set twice (3x,2x,1x)

9--::

  Repeat [1-4] 3c leading ; all dance BtoB (1,2,3)

17--::

  Mirror Reels3 on sides, all crossing down from the top (1x,2x,3x)

25--::

  Repeat, all crossing to own side (1,2,3)

33--::

  1c lead down {3}, turn RH {2}, lead up {3}

41--::

  3C Poussette (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (10615, '2018-04-15 15:14:21.05698+00', '2019-04-22 15:16:55.536544+00', 18282, 2, 1645, 'ace', '1-8::

  All circle 8 hands round and back.

9-16::

  1s & 3s dance Rights and Lefts 

17-24::

  2s & 4s dance Rights and Lefts 

25-32::

  1s & 3s turn partners RH and, Man leading, dance to the right, passing through side couples and returning to place.

33-40::

  2s & 4s turn partners LH and, Lady leading, dance to the left, passing through head couples and returning to place.

41-48::

  All four ladies dance RHA, then all four men dance LHA 

49-56::

  1s & 3s dance a Ladies’ Chain

57-64::

  2s & 4s dance a Man’s Chain

65-72::

  All face partners and dance a Grand Chain (1 bar to each hand)

73-80::

  All take promenade hold and dance once round, finishing with ladies back to back in the centre, wait for the chord, and honour your partner. 

', 5);
INSERT INTO 'dancecrib' VALUES (11481, '2019-01-01 01:58:06.903451+00', '2023-02-04 01:23:05.233646+00', 19012, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s Set+Link (Ladies normal Set+Link, Men Reverse
    Set+Link); 1s+4s (middle couples) face on sides, turn 1.1/4 LH so
    Ladies in centre ready for …
9-16::
    1s+4s dance the Targe  2 4 (1) (3)
17-24::
    All dance RSh reels of 4 on sides
25-32::
    _25-26_   2M (top) + 4L (2nd place) cross RH,
::
    _27-28_   2L+2M (1st/2nd place Ladies'' side) cross LH with 4M+1L
    (2nd/3rd place Men''s side);
::
    _29-30_   2L+2M (2nd/3rd place Men''s side) cross RH with 1M+3M
    (3rd/4th place Ladies'' side),
::
    _31-32_   2L (3rd Place Ladies'' side) cross RH with 3L (4th place
    Men''s side)  End (4) 1 3 (2)
33-40::
    All set, 2s (bottom couple) cast up (3s step down); All set, 3s & 4s
    (end couples) cross RH with partner. End 4 1 (2) (3)
41-48::
    All turn partners 2H, remaining in centre, flowing into 4s+1s also
    2s+3s circle 4H round to Left', 0);
INSERT INTO 'dancecrib' VALUES (12576, '2020-02-12 09:37:40.193791+00', '2020-02-12 14:54:30.162864+00', 15633, 1, 202, 'ace', '1--::

  Inveran Reels {6} | 1c+2c continue the reels into DblTr position, 1c BtoB in 2pl centre facing own sides (2,*1*,3)

9--::

  DblTr. 1c end BtoB on midline, 1M(1W) facing down(up)

17--::

  2c+1W & 1M+3c RHA, 1c pass RSh ; 2c+1M & 1W+3c LHA (2,1,3)

25--::

  Reels3 on sides, 1c RSh to 4cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10618, '2018-04-16 08:37:05.666206+00', '2018-04-16 08:39:10.389201+00', 8072, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 down round 3c (2,1,3)

9--::

  All set | cross RH ; set | turn RH ½ into promhold facing up

17--::

  3C Promenade

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10620, '2018-04-16 09:09:36.059535+00', '2018-04-16 09:12:48.376321+00', 8061, 1, 202, 'ace', '1--::

  1c lead down ; and up ready for

9--::

  1c+2c Allemande (2,1,3,4)

17--::

  1c+3c RHA, 1W ends facing out ; 1W followed by 1M cast off and cross to 3plx (3c up) (2,3,1x,4)

25--::

  1c+4c LHA, 1W ends facing out ; 1W followed by 1M cast off and cross to 4pl (3c up) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10621, '2018-04-16 10:04:40.729774+00', '2019-02-04 10:54:40.799205+00', 13102, 1, 202, 'ace', '*5 dancers in a square, numbered 1d,2d,3d,4d clw, 5d in centre facing 1d and 2d (top dancers)*

1--::

  5d+1d+2d set as in DTr | 5d PdB{2} to face down ; 5d+3d+4d set as in DTr | 5d PdB{2} to face up

9--::

  5d diagonal Fig8 around 2d position and 4d position, starts Rsh to 2d _while{8}_ 4d+3d change places RH | 4d+1d change places LH ; 4d+2d changes RH | corners set.  

On [16], 5d finishes between 3d and 1d (new bottom dancers) facing 1d

17--::

  3d+5d+1d Reel3 across, 5d starts Rsh to 1d, ending in centre facing 4d

25--::

  2d+5d+4d Reel3 across, 5d starts Rsh to 4d. At end, 5d turn 4d RH to centre (2d,5d,1d,3d, 4d in centre facing new top dancers)



*Deviser''s note:  

On [9-14] 4d makes a backwards "Z" shape*', 2);
INSERT INTO 'dancecrib' VALUES (11125, '2018-09-19 02:53:13.961196+00', '2018-09-19 02:56:44.188683+00', 18625, 1, 202, 'ace', '1--::

  1c+2c RHA ; LHA (1,2)

9--::

  1c+2c set | Petronella in tandem ; repeat (2x,1x)

17--::

  2c+1c set | turn RH ½, face P ; cast R to own side | set (2,1)

25--::

  Circle4 and back', 2);
INSERT INTO 'dancecrib' VALUES (11390, '2018-12-15 13:36:21.283542+00', '2020-02-13 16:42:44.110414+00', 13821, 1, 202, 'ace', '1--::

  1c+3c RHA ; LHA (1,2,3,4)

9--::

  1c+3c Set&Rotate (3x,2,1x,4)

17--::

  1c+3c Circle4 and back (3x,2,1x,4)

25--::

  1c+3c S&Link. 1c & 3c face P ; all set Highland Schottische (3,2,1,4)



*Deviser''s note:  

- On the second round of the dance, 2nd and 4th couples repeat the above.  

- On the third round, 1st and 3rd couples repeat back to original places, as do 2nd and 4th couples on the fourth round.  

- On bar 28 of the last round, 1st and 3rd couples turn to face each other and all four couples set to partners with Highland Schottische setting step.*', 2);
INSERT INTO 'dancecrib' VALUES (10754, '2018-05-10 00:12:23.184879+00', '2020-06-28 10:44:24.557937+00', 18208, 1, 202, 'ace', '1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 2c+1c & 4c+3c RHA, finishing 1c & 4c in tandem, 1W(4M) leading facing 2M(3W) (to 2,*1x*,*4x*,3)

9--::

  Corners Pass and Turn in tandem (with lead change), 1c & 4c ending in centre (to 2,*1*,*4*,3)

17--::

  1c+4c RHA, 1c(4c) ending in centre NHJ facing up(dn) ; 1c(4c) dance up(dn) between nearest ends and cast off(up) to 2pl(3pl) (2,1,4,3)

25--::

  1c+4c Chain Progression (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12794, '2020-05-05 13:01:46.840426+00', '2021-04-20 17:54:58.909689+00', 19192, 1, 202, 'ace', '1--::

  1c+2c set | 1c cross down RH to 2plx and face out _while{2}_ 2c cast up (to 2,1x,3) ; 1c cast to 3plx _while{2}_ 3c cross up LH to 2plx _while{2}_ 2c cross RH (2x,3x,1x)

9--::

  1c cross RH | cast up two places ; turn RH 1½ (or pivot turn) to 2plx centre BtoB facing opposite sides (3c down)

17--::

  »Modified DTr« [: same as DTr but cnrs chase cclw ¼ in PdB after setting with 1c] (3,1x,2)

25--::

  ½ Reels3 on sides, 1c RSh to 2cnrs[pos] (to 2,1x,3) ; 1c ½Fig8 R round 3cnrs _while{4}_ cnrs set | cross RH (2x,1,3x)

33--::

  3C S&Link ; 1c Petronella Turn to 2pl | set _or{4}_ 2 PdB + 4 high cuts _while{4}_ cnrs chase clw ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3686, '2013-01-19 13:58:11.77779+00', '2022-05-16 22:55:41.305129+00', 8144, 2, 1, 'ace', '*Any number of couples in a big circle, facing ctr, W on M''s R, hands joined*

1–2::
  Balance forward and back
3–4::
  M swing LH W in front of them to their R (giving BH)
5–16::
  R 1–4 three more times, fin in ballroom hold, side towards ctr
17–20::
  Move towards ctr (step-close) then out again, M starting LF, W RF | turn away
  from ptr (M LS back, W RS back)
21–24::
  R 17–20 starting towards outside
25–28::
  Still in ballroom hold, move towards ctr (step-close-step-close) then out again
29–32::
  Waltz round the room to fin in circle again', 3);
INSERT INTO 'dancecrib' VALUES (13959, '2021-04-16 22:47:21.378563+00', '2022-08-15 14:11:15.307577+00', 20326, 1, 202, 'ace', '1--::

  1c+2c Circle4 and back (1,2)

9--::

  1c lead down ; and up (1,2)

17--::

  1c+2c RHA ; LHA (1,2)

25--::

  1c+2c Poussette (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (3151, '2012-01-22 19:30:13.505967+00', '2020-02-12 09:47:47.981446+00', 5732, 1, NULL, 'ace', '1–::

  1c+4c fig8 round nearest C (who step to end on [1-2], finish between that C on own side, in facing lines across.

9–::

  All A&R up/down ; All turn person opposite RH

17–::

  1c+4c RHA, LHA, finish on sidelines (2,1,4,3)

25–::

  All A&R across ; All Turn P RH, finish 2c in 1pl and other Cs making arches (2,1,4,3)

33–::

  2c turn RH | lead down the midde (2W leading) to bottom {4} | All step back to (1,4,3,2)



{{explanation}}

Repeat from new places, but on [33-40] the bottom couple, turning LH, moves up to the top.  Order now (3,4,1,2), using the initial numbering of bar [1].  Repeat {40+40}, leading from top on 3rd time through, from bottom on 4th time.', 3);
INSERT INTO 'dancecrib' VALUES (10755, '2018-05-10 09:18:45.976713+00', '2018-05-10 09:29:12.292704+00', 18210, 1, 202, 'ace', '1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) : 1c+4c Circle4 L (2,1x,4,3x)

9--::

  2c+1c+4c+3c »Borrowing reels« [2c & 3c cross Rsh _while{2}_ 1c+4c pass Rsh on sidelines | 2c+4c & 1c+3c dance Lsh round each other to places ; repeat [9-12]] (2,1x,4,3x)

17--::

  1c+4c Set&Rotate (2,4,1x,3x)

25--::

  4c & 1c Fig8 up/dn round nearest ends (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (10756, '2018-05-10 14:21:13.09478+00', '2018-05-10 16:02:30.442175+00', 18215, 1, 202, 'ace', '1--::

  1c turn RH to 2pl (2c up) ; cast R round 3cnrs, dance up/down, turn LH to face 1cnrs (2,*1*,3)

9--::

  ½ Reel4 on 1diag, pass Lsh ; ½ Reel4 on 2diag finishing in centre, Lsh to P facing own side

17--::

  1W+2c & 1M+3c RHA ; all chase clw ½ (2,1x,3)

25--::

  1c ½ Fig8 down round 3c ; 1c followed by 3c dance up, cast off round 2c (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10707, '2018-04-29 06:25:05.639997+00', '2018-10-30 22:28:00.665122+00', 18309, 2, 2269, 'ace', '1--:: 1s cross RH & cast down 1 place, dance &frac12; Fig of 8 round the 2s

9--:: 1s dance RH across 1&frac12; times (1M with 3s, 1L with 2s) to end 1L at top, 1M at bottom, facing own sides, supporting couples having changed sides; 1s cast to 2nd place own sides

17--:: 1s pass LSh and dance &frac12; diagonal reels of 4 with 1st corner _positions_; then pass RSh to dance &frac12; diagonal reels of 4 with 2nd corner positions, ending in 2nd place opposite sides

25--:: 1s dance LH across 1&frac12; times (1M with 2s at _bottom_, 1L with 3s at _top_) to end 1L at top, 1M at bottom, facing opposite sides, supporting couples having changed sides; 1s cast to 2nd place, opposite sides

33--:: 1s pass LSh to dance &frac12; diagonal reels of 4 with 3rd Corners then pass Rsh to dance &frac12; diagonal reels of 4 with 4th corners to end in 2nd place own sides', 4);
INSERT INTO 'dancecrib' VALUES (2116, '2012-01-22 19:29:20.961275+00', '2021-06-14 20:43:39.077363+00', 1780, 1, NULL, 'ace', '1–::

  1W cast off (2W up) | cross and turn 3M RH, finish between 2M and 3M ; 1M cast off (2M up) | cross and turn 3W RH to between 3c _while_{4} 1W moves to between 2c into facing lines across

9–::

  All set twice, 1c with Petronella turn to (2,1x,3) ; All set twice, 1c finish on 1diag. and face L, facing 1cnr

17–::

  Turn CPCP (2,1,3)

25–::

  All set twice ; All Turn P RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (15451, '2023-02-20 12:11:39.925637+00', '2023-02-22 17:54:54.368965+00', 21344, 1, 1645, 'ace', '1--::

  1c lead down (2c up on 3-4) ; lead up, separate & cast up around 3c (2,1,3)

9--::

  1c+3c RHA ; LHA, 1c end facing up to 2c

17--::

  Reels3 on the sides, 1c start RSh to 2c

25--::

  2c+1c RHA ; all, including 4c, turn P RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (1626, '2012-01-22 19:28:51.711864+00', '2019-02-07 17:39:03.974778+00', 55, 1, NULL, 'ace', '1–::

  All 4 couples NHJ A&R ; all cross Rsh, M making arches

9–::

  Repeat, again M making arches

17-32::

  1c &4c RH tulloch swing, to face down/up, W on the right ; R&L up/down, inside the set {8} ; LH tulloch swing

33–::

  1c+4c L-Chain up/down, 1c finish with full LH turn to own side and face out (1,2,3,4)

41–::

  1c followed by 2c+3c+4c cast off behind own sides, 1c in 4pl make arch ; the others dance up under it, all retire (to 2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (12963, '2020-07-18 23:41:03.883501+00', '2020-07-19 00:06:12.204039+00', 16479, 1, 202, 'ace', '1--::
  1c+2c RHA ; 1W (1M following) casts off to 2plx (2c up on [7-8]) (2,1x,3)
9--::
  1c+3c LHA ; 1W (1M following) dance RSh round 2M (2c down on [15-16]) ready for
17--::
  1c (1W leading) + 2c ½ Reel3 in tandem across (with lead change), LSh to 2W ; ½ Reels3 in tandem across (no lead change). 2c end in 1pl.
25--::
  1c (1M leading) + 3c ½ Reel3 in tandem across (no lead change), LSh to 3W ; ½ Reels3 in tandem across (with lead change) (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10760, '2018-05-14 06:02:02.716013+00', '2019-09-08 11:03:29.387602+00', 8006, 1, 202, 'ace', '1--::
  All stand still | 1c+2c & 3c+4c ¾ R&L (2,1,4,3)
9--::
  All stand still | 1c+4c Petronella turn ; set | Petronella turn (2,1x,4x,3)
17--::
  All stand still | 1c+4c ½ RHA ; 1c+4c LHA (2,4,1,3)
25--::
  2c+4c & 1c+3c Circle4 L into centre, hands joined ; all stand still | swivel R and spiral out clw into longwise set (2,4,1,3)

*Deviser''s note:  
On [29-30], all dancers may call out " Wait for it "*', 2);
INSERT INTO 'dancecrib' VALUES (11068, '2018-09-05 06:21:29.035095+00', '2018-09-05 06:27:39.817567+00', 17456, 1, 202, 'ace', '1--::

  All set | cross RH ; repeat [1-4] (1,2,3)

9--::

  Circle6 and back (1,2,3)

17--::

  1M+2W cross RH | 1W+2M cross RH ; 1c+2c turn P RH ½, face P | cast R to exchanged places (2,1,3)

25--::

  1c & 3c set to P | set up/down ; turn EH 1½ on sidelines, 1c start in and down (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11067, '2018-09-05 02:35:57.924206+00', '2018-09-05 02:42:34.239585+00', 17457, 1, 202, 'ace', '1--::

  1c Mirror Fig8 on sidelines, 1c start in (1,2,3)

9--::

  Circle6 and back

17--::

  All A&R ; all turn P RH (1,2,3)

25--::

  1c ½ turn RH | lead down to between 3c (2c up) ; ½ turn RH | lead up to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10757, '2018-05-10 16:48:03.977498+00', '2020-11-14 10:39:22.374714+00', 18216, 1, 202, 'ace', '1--::

  1M followed by 1W cast | crosses to W side (2c up) ; cast round 3W | crosses to 3pl (3c up) (2,3,1)

9--::

  2c+3c+1c Circle6 and back, finishing 2c(1c) NHJ facing dn(up)

17--::

  2c & 1c S&Link across (to 2x,3,1x) ; 1c+3c S&Link (2x,1x,3)

25--::

  1c cross RH, face out _while{2}_ 2c turn BH ½ and face down _while{2}_ 3c turn BH and face up | Mirror Reels3 {6} on sidelines, 1c start out and up (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14068, '2021-06-15 05:10:19.646421+00', '2021-06-15 05:10:55.499571+00', 19136, 1, 202, 'ace', '1--::

  1W+2W+3W A&R ; turn P RH (1,2,3,4)

9--::

  1M+2M+3M A&R ; turn P LH. 1c face out (1,2,3,4)

17--::

  1c dance down behind own lines (2c+3c up) ; meet and dance up NHJ round 4c to 4pl (4c up on [23+24]) (2,3,4,1)

25--::

  4c+1c R&L (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10759, '2018-05-13 20:59:17.559751+00', '2018-05-29 22:19:54.242305+00', 18221, 1, 202, 'ace', '1-4::
  1c+2c & 3c+4c S&Link, (1M,2W,3M,4W facing out) (2,1,4,3)
5-12::
  2c+1c & 4c+3c Parallel Reels4 across (2,1,4,3)
13-16::
  1c+4c change places LH ; 1c+3c change places RH (2,4,3,1)
17--::
  4c+3c S&Link (3W,4M facing out) ; 2c+3c & 4c+1c turn LH 1½ on sidelines (3,2,1,4)
25--::
  3c+1c & 1c+4c Espagnole (2,3,4,1)

*Repeat once as Strathspey and twice as Reel.*  
*Deviser''s note:  
2nd and 1st men take nearer hands on bars 25 - 26 likewise for 3rd and 4th women on bars 27 – 28.*', 2);
INSERT INTO 'dancecrib' VALUES (9751, '2017-04-06 08:40:14.033753+00', '2023-02-04 01:22:20.764101+00', 5917, 3, NULL, 'ace', '1-8::
    1s set to 2s on sides, 1L+3M & 1M+3L set on diagonal, 1s set to each
    other & cast to 3rd place (2s+3s step up)
9-16::
    1s set to each other, 1L+2M & 1M+2L set on diagonal, 1s set to 3s on
    sides & cross up to 2nd place opp sides (3s dance down to 3rd place)
17-24::
    2s+1s+3s dance reflection reel of 3 on sides (1s out/up, 2s in/down,
    3s in/up) taking hands when possible
25-32::
    1s+2s dance 1/2 double Fig 8 (1s dance up, 2s cross down).  2s+1s+3s
    turn RH
33-40::
    1s+2s dance LH across.  1s+3s dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (11069, '2018-09-05 10:51:57.167747+00', '2018-09-05 10:57:24.210198+00', 17455, 1, 202, 'ace', '1--::

  1c+2c Circle4 and back (1,2,3)

9--::

  1c set | cast (2c up) ; 2c+1c+3c chase clw ½. On [15-16] 1c turn LH to face 1cnrs (3x,1,2x)

17--::

  ½ Reel4 on 1diag, pass P LSh ; ½ Reel4 on 2diag to 2plx (2,1x,3)

25--::

  All set | 1c cross RH _while{2}_ 2c & 3c pivot R (PdB) on spot ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11071, '2018-09-05 16:39:06.356344+00', '2018-09-05 16:46:44.410588+00', 18516, 1, 202, 'ace', '1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; ½ Fig8 round nearest end cpls (2,1,4,3)

9--::

  2c+1c & 4c+3c RHA ; 1c+4c ½ LHA | set to nearest cnrs (2,4x,1x,3)

17--::

  Reels4 (2,4x,1x,3)

25--::

  All dance BtoB with cnrs and face P ; 4c+1c turn P RH 1½ (2,4,1,3) ', 2);
INSERT INTO 'dancecrib' VALUES (1847, '2012-01-22 19:29:05.682772+00', '2021-03-15 22:50:17.077906+00', 8660, 1, NULL, 'ace', '1–::

  Circle4 to left only ; turn person opposite BH, turn P BH

9–::

  Set H.Schottische R foot turn person opposite LH ; Set H.S. L foot, turn opposite RH

17–::

  Reel4 within set, men starting Lsh

25–::

  Rondel', 2);
INSERT INTO 'dancecrib' VALUES (11070, '2018-09-05 13:06:07.7375+00', '2018-09-05 18:39:54.199737+00', 18520, 1, 202, 'ace', '1--::
  1c+2c & 3c+4c RHA ; LHA (1,2,3,4)
9--::
  1M+2W & 3M+4W turn RH ; 1W+2M & 3W+4M turn RH (1,2,3,4)
17--::
  1c slip down the middle ; and up to 4 pl (2c+3c+4c up) | all clap 4 times (2,3,4,1)
25--::
  Circle8 and back', 5);
INSERT INTO 'dancecrib' VALUES (11817, '2019-04-30 21:57:47.214772+00', '2019-05-03 23:01:09.473599+00', 19281, 1, NULL, 'ace', '1--::

  1c+3c A&R | ½ R&L

9--::

  2c+4c repeat 

17--::

  All W ½ RHA | join LH with opp. M and all set in star ; All W ½ turn M into centre | All set

25--::

  All M ½ RHA | join LH with P and all set in star ; ½ turn P into centre | set  

33--::

  All turn P RH 1¼ to place and face P ; All set, M pivoting R to face clw | all chase 1pl clw

41--::

  Circle8 & Back', 3);
INSERT INTO 'dancecrib' VALUES (12896, '2020-06-24 09:52:44.360315+00', '2020-06-24 10:29:50.886822+00', 20034, 2, 10819, 'ace', '4 dancer in a square set, dancer #5 on #1s right hand side.



1-4:: 1+3+5 RA, 1 finishing in own place, whilst 3+5 keep RH staying in the center of the set, pulling RS back to finish facing side couples (3 facing 2, 5 facing 4).

5-8:: 1/2 RS reel of four; 3+5 join LH for final LS pass, keep hands and face 1.

9-12:: 1+3+5 LA, 1+3 finishing in own places, 5 rather in the center of the set.

13-16:: 5 dance LS around 1 to finish on 2''s left side (being in 4th place).

17-32:: Repeat 1-16 reversed (changed hands and directions and with side couples in the lead): LA & LH twirl, 1/2 LS reel with RH turn at the end, face 2 (in 4th place), RA, 5 dance around 2 (giving RS) to finish on 3''s right side (being in top place).	

33-36:: All circle 3/4 (to 4, 1, 2, 3/5 together).

37-40:: 5 cast to top to finish on 4''s left side (new joint couple in 1st place). Progressed order is now 5/4, 1, 2, 3.', 5);
INSERT INTO 'dancecrib' VALUES (3078, '2012-01-22 19:30:10.266681+00', '2020-12-16 10:10:49.934003+00', 5474, 1, NULL, 'ace', '{{explanation}}

Two chords; on 2nd chord 1W+2c & 3W+4c move as for »Glasgow Highlanders, putting 1c & 3c on the M side, facing 2c & 4c on the W side.



1–::

  1M+2M & 3M+4M turn RH ¾ , dance Rsh round P, to places ; 1W+2W & 3W+4W repeat LH/Lsh

9–::

  1c+2c & 3c+4c (NHJ with P) set | ½ Circle4 L ; set | petronella in tandem into the middle, 1c facing 2c & 3c facing 4c (1x,2,3x,4)

17–::

  1c+4c S&Link twice with P, finish in sidelines, _while{8}_ 2c+3c »S&Link Back to Back« twice (LH person to RH place, RH person to place behind, repeat so each couple ends in other couple''s place) finishing in the middle (1x,3,2x,4)

25–::

  3c & 2c dance NHJ through own end couple and cast to (1x,3,2x,4) ; all set, each M NHJ with W on L | all W cross _while{2}_ all M cast one place clw in on the side, finish C facing C across, each M to L of P



{{explanation}}

All C have now progressed one position clw', 2);
INSERT INTO 'dancecrib' VALUES (11570, '2019-02-08 11:31:30.635644+00', '2019-02-08 11:37:43.852885+00', 19183, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; turn LH to face 1cnrs

9--::

  1c+1cnrs A&R ; »modified Corners Pass and Turn« [same as Corners Pass and Turn except that cnrs turn RH ½, face that person and cast away to exchanged places]. 1c face 2cnrs

17--::

  1c+2cnrs repeat [9-16] 1c to 2plx (3x,1x,2x)

25--::

  All chase clw ½ ; dance BtoB (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11072, '2018-09-05 22:44:15.956858+00', '2018-09-05 23:55:20.756102+00', 14398, 1, NULL, 'ace', '1--::

  1c cross RH | 6 bars of Mirror Reels3 on sidelines, 2c in and down, finish 3c in 3pl, 2c & 3c facing cclw (2,1x,3)

9--::

  1c turn RH ¾ _while{2}_ corners chase to next place cclw | 2W+3W+1M & 1W+2M+3M LHA | 1c turn RH ¾ _while{2}_ corners chase to next place cclw

17--::

  1M+2W+3W & 1W+2M+3M LHA ; 1c turn RH to face 1cnr

25--::

  ½ diag Reel4 on 1diag, 1c pass Rsh ; ½ diag Reel4 on 2diag, 1c pass Rsh to (2,1,3).



  ', 4);
INSERT INTO 'dancecrib' VALUES (11074, '2018-09-06 22:19:47.36898+00', '2018-09-06 22:26:23.142968+00', 14123, 1, 202, 'ace', '1--::

  1c cross RH | 1W+2M change places LH ; 1W+2W cross RH | 1c turn P LH ½, 1M & 2M face out

9--::

  La-Chain

17--::

  1c & 2c set | chase cclw 1 place (to 1x,2) ;  1c ½ Fig8 round 2c (1,2)

25--::

  Poussette (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11816, '2019-04-29 20:46:55.392132+00', '2019-05-01 00:01:24.601572+00', 19278, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 1c cross down LH between 3c and cast up to face 1cnrs (2,1,3)

9-20::

  [Dance to Each Corner & Set] Basic figure{2}:  Middle dancers change place Rsh with the cnrs they face, those corner dancers meet Rsh in middle and face R towards next cnr cclw _while{2}_ the other two corners set.  

This figure is danced 6 times, alternately on 1st and 2nd diagonals, finishing (3x,1,2x) with 1c in the middle

21-24::

  1c cast up on own side and set _while{4}_ 3c step down and 3c+2c ½ RHA (1,2,3)

25--::

  [Progressive Grand Chain] : As a Gr-Chain, but making full turns at the ends (all remain on own side) (2,3,1)

33--::

  All set | all cast clw ¼ round into lines across ; Circle6 L ¾ (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10761, '2018-05-14 06:56:59.462589+00', '2019-04-29 22:29:29.487323+00', 18214, 1, 202, 'ace', '1--::

  1c cross down between 2c & 3c, cast down behind 3c, cross up between 2c & 3c, cast up behind 2c to 1pl (1,2,3,4)

9--::

  1c+2c R&L

17--::

  1c+3c »modified DblFig8« round 2c [1c & 3c set | 1c cross down to 3plx _while{2}_ 3c cast up to 1pl ; 1c cast up to 1plx, curl in to face 1cnrs (2c up on [23-24]) _while{4}_ 3c dance down to 3pl | set] (2,*1*,3,4)

25--::

  1c+1cnrs »Set to corner and cast away« [1c set to 1cnr | 1c cast Rsh round each other to 3cnr position _while{2}_ 1cnrs dance into centre, and swivel R to face own cnr ; repeat, 1cnrs finishing in exchanged places, and 1c facing 2cnr]

33--::

  1c+2cnrs repeat [9-16]. On [15-16], 1c cast inwards to 2pl (3x,1,2x,4)

41--::

  3c+1c+2c chase clw ½ (to 2,1x,3,4) ; 1c turn RH 1½ to 4pl (3c+4c up on [47-48]) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11073, '2018-09-06 00:12:07.10218+00', '2018-09-06 06:24:34.206314+00', 18518, 1, 202, 'ace', '1--::

  1W followed by all W dances across behind M side, crosses and dance up to (1,2,3,4,5)

9--::

  All M, 1M leading, repeat similar pattern

17--::

  All dance BtoB ; turn P BH (1,2,3,4,5)

25--::

  1c dance down between 2c, behind 3c, between 4c, behind 5c to sidelines | all step up (2,3,4,5,1)', 4);
INSERT INTO 'dancecrib' VALUES (11076, '2018-09-07 03:26:46.318278+00', '2018-09-07 03:37:54.694748+00', 14129, 1, 202, 'ace', '1--::

  1W & 2W dance across LSh to P, behind M line, 1W(2W) cross LSh round 2M(3M) to places | 1c+2c set (1,2,3)

9--::

  1M+2M repeat mirror pattern on W side | 1c+2c set (1,2,3)

17--::

  1W+3M cross RH | 1M+3W cross RH ; 1c cross RH | all set, 2c & 3c facing on sidelines (3x,2x,1x)

25--::

  ½ Gr-Chain, 1c & 2c retain RH on sidelines (to 1,2,3) ; 1c & 2c change places RH | all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10764, '2018-05-16 00:41:11.727239+00', '2018-05-16 00:53:30.398156+00', 2379, 1, 202, 'ace', '1--::

  1c Fig8 down round 2c (1,2)

9--::

  1c+2c RHA, finishing 1W+2W & 1M+2M RHJ ; 1c+2c turn RH 1½, finishing in centre BHJ with P (2,1)

17--::

  2c & 1c slip down ; and up opening into

25--::

  Circle4 and back (2,1)



*Deviser''s note:  

On the 6th round, standing couple at the top (original 1c) join in:*

17--::

  1c & 2c & 3c slip down ; and up

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10762, '2018-05-15 05:41:30.388677+00', '2018-05-18 05:41:35.255547+00', 18218, 1, 202, 'ace', '1--::

  1c set | cross down to 2plx just outside facing out and down (2c up) ; 1M+2W+3W RHA _while{4}_ 1W+2M+3M LHA (2,*1*,3)

9--::

  1c dance down behind 3c, meet and dance up to centre, out behind 2c, meet and face 3M in tandem, 1W leading

17--::

  Reel3 in tandem on 2diag. On [23-24], 1c face 3W and pull Rsh back, 1c face 2M in tandem, 1M leading

25--::

  Reel3 in tandem on 1diag, 1c finish in 2pl (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (10765, '2018-05-16 01:00:37.501566+00', '2018-05-16 01:03:09.64277+00', 13662, 1, 202, 'ace', '1--::

  1c A&R, touching hands briefly ; turn RH (1,2,3)

9--::

  3c followed by 2c & 1c lead down ; 3c leading followed by 2c & lead up (3,2,1)

17--::

  3C Allemande (1,2,3)

25--::

  1c cross Rsh | cast (2c up) ; ½ Fig8 up round 2c (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2886, '2012-01-22 19:30:01.583894+00', '2018-09-07 09:49:27.730629+00', 4815, 1, NULL, 'ace', '1–::

  1W, 2W+3W following, dance across the top, behind the men ; cross round 3M, 2M, 1M to own side, all set

9–::

  Men repeat, crossing at the top and round own P to own side ; all set (to 3,2,1)

17–::

  1c (in 3pl) cross RH, cast up 2 (2c down), cross LH and cast off one to face 1cnr positions

25–::

  ½Reel4 with 1cnr-pos, pass Rsh ; repeat with 2cnr-pos, meet in middle

33–::

  1c turn RH (1 or 2 turns at choice) to face down promhold, 1W on the right ; ½ Rsh Reel3 with 3c

41–::

  ½ Lsh Reel3 with 2c (in 1pl) ; lead LHJ between 3c, cross and cast up (2,1,3)



{{explanation}}

On second turn: on last 4 bars 1c dance out to 3pl (3c up) and set', 2);
INSERT INTO 'dancecrib' VALUES (11571, '2019-02-08 17:45:47.409544+00', '2019-02-08 17:58:57.95453+00', 6729, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c ½ R&L up/down (to 2x,1x,4x,3x) ; middle cpls set up/down and face P on [6] | 1c+4c ½ LHA (2x,4,1,3x)

9--::

  All repeat [1-8] from new positions (4x,3x,2x1x)

17--::

  4c+3c & 2c+1c set up/down | change places RH (to 3x,4x,1x,2x) ; middle cpls change places LH | all cross RH. 1c & 4c face out (3,1,4,2)

25--::

  3c+1c & 4c+2c DblFig8, 3c & 1c crossing inwards (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (13463, '2020-12-15 13:07:59.895302+00', '2020-12-15 13:17:43.464979+00', 18718, 1, 202, 'ace', '1--::

  All cross RH | 1c & 3c cast off (2c set up & 4c cross up) (to 2x,1x,4,3x,5x) ; 2c+5c chase clw ½ _while{4}_ 1c & 3c turn LH to face 1cnrs

9--::

  Parallel »Set to Corners and Cast« on both 1diag [: 1c & 3c set to 1cnrs | 1c & 3c cast RSh round P to 3cnr[pos] _while{2}_ 1cnrs dance into centre and swivel R to face own cnr ; repeat [9-12]. 1cnrs have changed places and 1c & 3c face 2cnrs]

17--::

  Repeat [9-16] on both 2diag. 1c & 3c face 3cnr[pos]

25--::

  Repeat [9-16] on both 1diag. 1c & 3c finish on midline BtoB with P, Women facing up

33--::

  2c+1W & 1M+4c+3W & 3M+5c RHA ; 1c & 3c turn LH and cast off (4c & 5c up) (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (10610, '2018-04-11 20:17:52.359432+00', '2018-09-07 11:05:50.184256+00', 18279, 1, 202, 'ace', '1--::

  1c dance between 2c and cast up ; dance between 3c and cast up to 2pl (2c up) (2,1,3)

9--::

  Mirror Reels3 on sidelines, joining hands when possible, 1c start in and up, 2c & 3c loop to places, 1c finishing on 1diag RHJ and LHJ with 3cnrs

17--::

  The spoke moving clw (2,1,3)

25--::

  Circle6 and back', 5);
INSERT INTO 'dancecrib' VALUES (11573, '2019-02-09 10:30:31.934081+00', '2020-05-16 11:52:43.423943+00', 9287, 1, 202, 'ace', '1--::
  1c set | dance down to 2pl (2c up) ; dance round 4cnrs (1M RSh, 1W LSh) to face 1cnrs
9--::
  1c SetH&G  
  _while{8}_ 1cnrs set | chase clw ½ {6}  
  _while{8}_ 2cnrs stand still {4} ; set | start chasing clw {2}
17--::
  ½ Reel4 on 1diag, 1c pass P LSh to face 4cnrs[pos] _while{4}_ 2cnrs chase clw to exchanged places ; ½ Reel4 on 2diag, 1c to 2pl (2,1,3)
25--::
  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3089, '2012-01-22 19:30:10.80111+00', '2020-12-16 10:20:49.078698+00', 5519, 1, NULL, 'ace', '{{explanation}}

The W form a square, numbered 1,2,3,4 clw, 1M in the middle faces 1W



{{title}}

Strathspey



1–::

  1M with 1W+3W Rsh Reel3 _while{8}_ 2W+4W dance cclw ½ round outside ; and back clw

9–::

  All W set in places as M sets, swivelling R to face each W in turn, finishing facing 4W

17-32::

  Repeat [1-16] from new positions, M finishes facing 3W



{{title}}

Reel



33-64::

  Repeat [1-32]  in Reel time.', 3);
INSERT INTO 'dancecrib' VALUES (11417, '2018-12-21 13:27:04.830515+00', '2019-02-09 16:16:57.831102+00', 11026, 1, 202, 'ace', '1--::

  1c ½ Fig8 round 2W & 4M _while{8}_ 3c ½ Fig8 round 4M & 2W ; 1c & 3c turn P RH (1x,2,3x,4)

9--::

  1c+3c Reel4, both W passing LSh. On [15-16] all pass P RSh to face original cnrs (1,2,3,4)

17--::

  Interlocking Reels4. All face P (1,2,3,4)

25--::

  All turn P RH ¾ into promhold | Promenade clw ¾ (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10767, '2018-05-16 17:40:11.369938+00', '2018-05-16 17:40:11.369938+00', 18336, 1, NULL, 'ace', '1-::

  1c cross RH | cast off (2c up) ; cross LH | set (2,1,3,4)

9-::

  2c+1c+3c diagonal R&amp;L (1W up, 1M down) to (3x,1,2x,4)

17-::

  1c+2c+4c diagonal R&amp;L (2W down, 2M up) to (3x,4x,2x,1x)

25-::

  3c+4c &amp; 2c+1c RHA ; 4c+2c LHA (3x,4x,2x,1x)

:: *Repeat from new places on opposite sides*

', 2);
INSERT INTO 'dancecrib' VALUES (11572, '2019-02-08 20:34:40.936053+00', '2019-02-09 10:58:28.296916+00', 5095, 1, 1645, 'ace', '1-::
  1c+2c RHA ; LHA, retaining hands with P for
9-::
  1c+2c promenade
17-::
  1c cross RH | cast off (2c up) ; 2c+1c+3c advance & retire
25-::
  1c turn 1&frac12; RH ; 2c+1c+3c advance & retire (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (10768, '2018-05-17 02:03:12.436201+00', '2018-05-17 02:11:05.273216+00', 18325, 1, 202, 'ace', '1--::

  1c+2c+3c Inveran reels (1,2,3)

9--::

  1c+2c set | La Baratte (1x,2x,3)

17--::

  1c+2c S&Link ; turn P 1½ (2,1,3)

25--::

  Circle6 L {4}, pivot L by crossing R foot over L and chase back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10769, '2018-05-17 02:38:49.072884+00', '2018-05-17 02:44:19.237152+00', 18324, 1, 202, 'ace', '1--::
  1c+2c+3c cross RH | chase clw {2} into facing lines of 3 across ; repeat [1-4] to sidelines (3,2,1)
9--::
  Parallel Reels3 on sidelines, 2c Rsh to 3c (3,2,1)
17--::
  Repeat [1-8] (1,2,3)
25--::
  1c cross | cast (2c up) ; ½ Fig8 L round 4cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (7839, '2013-08-21 08:31:49.589624+00', '2023-02-04 01:23:05.244663+00', 6941, 3, NULL, 'ace', '1-8::
    1s & 3s dance double Fig of 8 round 2s (1s casting to start, 3s
    crossing up), 1s end facing out
9-16::
    1s cast to 2nd place as 2s start Allemande, 2s+1s continue
    Allemande, on Bar 14 men bring Ladies round to face them, then both
    couples face down, 2s cast up to 1st place, 1s dance down to 2nd
    place facing out
17-24::
    2s+1s+3s dance reels of 3 on sides (1s dance out & down to start)
    taking hand where possible. 1s end in 2nd place facing in,  2s & 3s
    in centre facing down/up NHJ with partners
25-32::
    2s+1s+3s set, circle 6H round to L for 4 bars, dance into centre &
    spiral out clockwise to places', 0);
INSERT INTO 'dancecrib' VALUES (10766, '2018-05-16 01:13:48.640977+00', '2022-08-15 08:37:07.437373+00', 17348, 1, 202, 'ace', '1--::

  1c lead down ; and up (1,2,3)

9--::

  1c turn RH | cast (2c up) ; ½ Fig8 R round 1cnrs to 2plx facing 2cnrs (2,1x,3)

17--::

  Rsh Reels3 {6} | 1c cross RH (2,1,3)

25--::

  Circle6 L {3}, pivot L by crossing R foot over L and chase back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12440, '2019-12-18 12:08:57.378983+00', '2020-06-24 10:39:40.234162+00', 13643, 1, 202, 'ace', '1--::

  1c+3c DblFig8 round 2c, 1c crossing down. 1c in 1pl centre NHJ face down as 2c step in on [8] and face up NHJ (1,2,3)

9--::

  1c+2c »Half Rondel« [: 3 bars of Rondel in {4} ; all set to P | cross LH] (2,1,3)

17--::

  2c+1c+3c Circle6 R {3}, cross L foot over R, pivot R and chase back clw. On [24] 2M & 3W face out (2,1,3)

25--::

  Reels3 on sides, 1c LSh to 3cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10030, '2017-07-24 04:07:09.407178+00', '2018-09-07 12:36:33.675958+00', 17896, 1, 202, 'ace', '1--::
 All NHJ in a circle A&R twice
9--::
 All turn P RH : turn P LH
17--::
 All BHJ slip to centre | clap 4 times ; slip back | clap 4 times
25--::
 All dance BtoB with P ; All passing P Rsh chase 1 place, W clw & M cclw

*Deviser''s note:  
This jig can also be danced by 2 couples only, since dancers only meet opposite persons and own partners. In this case, they can start in 1s and 3rd positions, leaving 2nd and 4th positions empty, until they arrive there end of bar 32.*', 5);
INSERT INTO 'dancecrib' VALUES (11077, '2018-09-07 14:22:45.506087+00', '2018-09-07 14:31:12.838681+00', 15401, 1, 202, 'ace', '1--::
  Circle6 and back (1,2,3)
9--::
  1c set | cast (2c up) ; turn LH to face 1cnrs
17--::
  1c+1cnrs set | 1c dance (skip-change) RSh round P to face 2cnrs ; 1c+2cnrs set | dance (skip-change) RSh round P to centre, RSh to P facing own side
25--::
  1W+2c & 1M+3c LHA (to 2,1x,3) ; 1c set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10770, '2018-05-17 09:21:36.331468+00', '2018-05-19 21:15:20.68614+00', 2233, 1, 1645, 'ace', '1-::

  1c &amp; 4c set | cast inwards (2c+3c out) ; 1M &amp 4W &frac12; Fig8 out the ends _while{4}_ 1W &amp; 4M cross | cast R to lines across in 1pl/4pl

9-::

  4W &amp; 1M LSh Reels3 on opp sides with 2c+3c _while{8}_ 1W+4M set | change pl RH ; repeat to face 2W/3M

17-::

  2c+1W &amp; 3c+4M RSh Reels3 across _while{8}_ 1M+4W set | cross RH ; set | turn &frac34; RH to end in tandem behind 4M/1W

25-::

  1W+4W (also 4M+1M) &frac12; Fig8 out the ends to (2,4,1,3) ; all turn P RH

', 2);
INSERT INTO 'dancecrib' VALUES (2988, '2012-01-22 19:30:05.774438+00', '2020-12-17 22:21:34.27728+00', 5853, 1, NULL, 'ace', '{{explanation}}

3c+4c begin on opposite sides (1,2,3x,4x); centro-symmetric dance.



1–::

  1c+2c & 4c+3c »La Girandole«: 1c+2c set | 1W+2M turn RH ¾ _while{2}_ 1M+2W cast L about ; 1c+2c ¾ RHA (fast) into | 2c+1c turn RH ½ _while{8}_ 4c+3c do likewise (to 2,1,4x,3x ; 2W, 1M, 4M, 3W facing out).

9–::

  Reels4 on the sides, on [16] 1M+4W & 1W+4M, instead of passing, take LH and the M swivels L about to face the same way as the W

17–::

  In promhold, 4M+1W with 2c &1M+4W with 3c  ½ Lsh Reel3 across ; the pairs meet & join own P in promhold, W to R of M ; 4c with 2c & 1c with 3c ½ Rsh Reels3 across, 4c & 1c finish facing each other across the set ready for

25–::

  1c+4c Circle4 left, on [28] form a diagonal line, 1c above 4c & men BtB in the middle ; 1c+4c ½ Poussette (to 2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (12176, '2019-09-05 13:14:43.71292+00', '2020-02-16 01:32:30.020959+00', 4904, 1, NULL, 'ace', '*Strathspey*  



1--::

  [Progressive Chain]  1c+4c cross RH | 1c+2c & 3c+4c pass LH ; pass next RH | pass next LH (4x,2x,3x,1x)  

9--::

  4c (cast) +3c & 2c+1c (cast) DblFigs8 (4x,2x,3x,1x)

17--::

  3c+2c ½R&L ; cross RH and cast to ends (4c & 1c in) (3x,4x,1x,2x)

25--::

  All ½ Petronella (3,4,1,2)



*Reel*  



33--::

  All ½ Petronella (3x,4x,1x,2x)

41--::

  Reels4 on the sides (3x,4x,1x,2x)

49--::

  3c+4c & 1c+2c set | ½ RHA ; 3c+2c set | ½ LHA (4,2x,3x,1)

57--::

  4c+2c & 3c+1c set | ½ LHA ; 4c+1c set | ½ LHA (2,1,4,3)  



*repeat once*

', 3);
INSERT INTO 'dancecrib' VALUES (10772, '2018-05-18 07:40:09.667297+00', '2018-05-18 14:27:10.136639+00', 11781, 1, 202, 'ace', '1--::
  1M+2W & 3M+4W turn RH ½ | cast Rsh round standing person on own side to places ; 1c+2c & 3c+4c RHA (1,2,3,4)
9--::
  Parallel Reels4 (1,2,3,4)
17--::
  2W+3M turn LH ½ ; | cast Lsh round standing person on own side to places ; 2c+3c LHA (1,2,3,4)
25--::
  1c & 4c cross RH | cast inwards (2c & 3c step out) (to 2,1x,4x,3) ; 4c followed by 1c LHJ lead down between 3c and cast up (2,4,1,3) ', 2);
INSERT INTO 'dancecrib' VALUES (10771, '2018-05-17 09:30:11.402752+00', '2018-05-19 21:12:52.968772+00', 11825, 1, 1645, 'ace', '1-::

  1c set, 1W turning to face out | 1W followed by 1M casts round 2W ; crosses (2c up) to (2,1x,3) | 1c turn &frac34; RH to 2cnr

9-::

  1c+2cnrs &frac12; diag RSh Reel4, 1c &frac12; turn LH ; 1c set | &frac12; turn LH to 3cnr _while{4}_ 2cnrs chase &frac12; way clw back to place

17-::

  1c+3cnrs &frac12; diag RSh Reel4, 1c pivot to take 1cnrs in promhold (1c on the inside) ; 1c+1cnrs chase &frac12; way clw to (2,1x,3)

25-::

  1c &frac12; Fig8 (M down, W up) ; 2c+1W &amp; 1M+3c RHA (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11081, '2018-09-08 20:44:47.254249+00', '2018-09-08 20:44:47.254249+00', 14252, 1, NULL, 'ace', '1--::

  1c & 4c turn P RH and cast to middle (2c+3c to ends) ; 1c+4c RHA (2,1,4,3)

9--::

  All Circle8 and back

17--::

  1c & 4c lead out own end and cast back ; All set twice (2,1,4,3)

25--::

  1c+4c ½ R&L and set {6} while 2c+3c chase ¾ clw round the set (2W+3M cast R to start) {6} | 4M+1L cross LH while 2c+3c set to P



*The set has now rotated ¼ turn cclw (“top” on the former M side; couples in the order 2,4,1,3.  The following times the set finishes (4,3,2,1, top at the former bottom), (3,1,4,2, top on the original W side), and (1,2,3,4 = original set)*

', 3);
INSERT INTO 'dancecrib' VALUES (10774, '2018-05-20 06:28:00.321704+00', '2018-05-20 06:34:41.065557+00', 18329, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; turn RH 1½ to face 1cnrs (2,*1*,3)

9--::

  ½ Reel4 on 1diag, pass Rsh ; ½ Reel4 on 2 diag to 2plx (3x,1x,2x)

17--::

  3C S&Link ; 2c & 3c set | cross RH _while{4}_ 1c turn RH 1¼ to 2pl (2,1,3)

25--::

  Circle4 L, pull Lsh back to pivot round and chase back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12838, '2020-05-16 23:19:21.015686+00', '2020-06-03 22:20:54.715455+00', 11073, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 up round 2c to 2pl centre NHJ facing 2c

9--::

  1c set diagonally to 2c | turn outwards (2 PdB) to face 3c NHJ ;  set diagonally to 3c | turn P RH ½ to face 1cnrs

17--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag, pass RSh to face 3cnrs[pos]

25--::

  Repeat [17-24] with 3cnrs[pos] then 4cnrs[pos] (2,1,3)

33--::

  2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11080, '2018-09-08 13:19:52.815735+00', '2019-04-03 20:17:53.914056+00', 15338, 1, 202, 'ace', '1--::

  1c long cast to 2pl touching nearer hands (2c up) ; set advancing | turn BH ½ and pivot R to face 1cnrs (2,1,3)

9--::

  1c+1cnrs set | dance RSh round P to face 2cnrs ; repeat [9-12] with 2cnrs to 2pl facing out

17--::

  1c cast R round 3cnrs | pass P Rsh up/down the centre _while{4}_ 3cnrs turn RH ½, face each other | cast R to exchanged places ; repeat [17-20] with 4cnrs (3x,1x,2x)

25--::

  All chase clw ½ ; turn P BH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2113, '2012-01-22 19:29:20.801468+00', '2021-06-14 20:46:05.330762+00', 1774, 1, NULL, 'ace', '1–::

  1W+2W+3W A&R ; 1M+2M+3M A&R

9–::

  1c followed by 2c+3c cast behind own lines and up the middle ; 1c cast to face 1cnr, 2c dance to 1pl

17–::

  Turn CPCP, 1c finish on opposite side.

25–::

  1c set twice ; cross RH', 2);
INSERT INTO 'dancecrib' VALUES (11078, '2018-09-07 15:10:25.808333+00', '2018-09-08 14:21:50.167833+00', 14251, 2, 116, 'ace', '01-08::

  1L & 6L dance RSh round partners; then, followed by their partners, they dance half LSh reels of 3 across the set with the next C

09-16::

  1C & 6C, with NH joined, dance down/up the middle to meet WHILE 2C & 3C step up, 4C & 5C step down [bars 9 & 10], then dancing couples change places RH up and down (women dancing under partners'' R arm, pulling back LSh); 6C & 1C dance RH across once round

17-24::

  6L & 1L, followed by their partners, dance half RSh reels of 3 across the set with 3C/4C (resp.); then 6C dance up between 2C and cast off 1 place WHILE 1C dance down between 5C and cast up 1 place WHILE 3C step down, 4C step up [bars 23 & 24]

25-32::

  2C & 6C & 3C and 4C & 1C & 5C set and link for 3 twice. Finishing order: 362514 (514 on opposite sides)', 4);
INSERT INTO 'dancecrib' VALUES (11082, '2018-09-08 21:48:38.648111+00', '2018-09-08 21:51:44.066625+00', 17067, 1, NULL, 'ace', '*Couple face Couple Round the Room*



1--::

  1c facing 2c R&L, M face out 

9 --::

  La-Chain

17 --::

  W turn RH ; M turn LH

25 --::

  1c facing 2c A&R ; turn opposite LH 1½ (2,1) and face next couple

', 3);
INSERT INTO 'dancecrib' VALUES (13362, '2020-11-02 01:22:19.224951+00', '2023-02-04 01:23:05.255659+00', 16610, 3, NULL, 'ace', '1-8::
    1s lead down, cross out between 3s, cast up, dance in between 2s/4s,
    cross RH, dance out between 2s/4s & cast up back to place
9-16::
    2s+4s dance R&L
17-24::
    All circle 8H round & back
25-32::
    All set, turn partner 3/4 RH into prom hold facing clockwise (Ladies
    on inside) & promenade 3 places round to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (10775, '2018-05-20 09:40:51.441881+00', '2018-05-20 09:42:51.724262+00', 18266, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; dance between 3c, cast up to 2pl (2,1,3)

9--::

  Mirror Reels3 on sidelines, 1c cross to 1plx to start. On [3], 2c cross to 3plx, on [4], 3c cross to 1plx (2x,1x,3x)

17--::

  All set | 2c & 3c change places on sidelines, 2M & 3W casting (to 3x,1x,2x) ; 3c & 2c chase clw ½ _while{4}_ 1c turn 1½ (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11083, '2018-09-08 22:15:56.057905+00', '2018-09-08 22:24:28.80202+00', 17068, 1, NULL, 'ace', '1--::

  1c dance down the middle {3} and up {3} | cross and cast off (2c up) (2,1x) 

9--::

  2c facing 1c set | change places RH ; set | change places LH (M face out) (2,1x)

17--::

  2c+1c Ladies'' chain (2,1x)

25--::

  1c ½ Fig8 up | 1c turn P RH (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10778, '2018-05-21 02:33:42.832199+00', '2018-05-21 07:26:47.80792+00', 18341, 1, 202, 'ace', '1--::
  1c dance Rsh round P to places ; 1c set | cast (2c up) (2,1,3)
9--::
  1W+2c & 1M+3c Reels3 across, Lsh to 1cnrs, finish facing 2cnrs
17-20::
  Corners Pass and Turn on 2diag, finish facing 3cnrs
21-28::
  SetH&G, finish facing 1cnrs
29-32::
  Corners Pass and Turn on 1diag (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (11688, '2019-03-18 00:47:28.132315+00', '2020-02-16 12:22:00.538189+00', 17320, 2, NULL, 'ace', '1-8::   all dance six hands round and back, finish facing partner



9-16::   all dance back to back with partner and turn right hand once round, finish facing comer



17-24::   all dance back to back with comer and tum left hand once round, finishing 1n promenade hold



25-32::   all promenade with new partner looking for two new couples to begin again.

', 5);
INSERT INTO 'dancecrib' VALUES (11084, '2018-09-09 05:27:24.782941+00', '2018-09-10 19:14:28.467179+00', 18515, 1, 202, 'ace', '1--::
  2c followed by 1c lead down | 2c divide and cast back _as_ 1c lead down ; 2c followed by 1c lead up to sidelines (2,1,3)
9-12::
  All turn P (PdB) BH ½, face P | cast R to exchanged places (2x,1x,3x)
13-24::
  3C R&L (2x,1x,3x)
25--::
  All set advancing | cast R back ; all turn P (PdB) BH ½, face P | cast R to own sides (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14540, '2022-01-10 02:20:33.402484+00', '2023-02-23 00:53:34.345922+00', 17973, 3, NULL, 'ace', '{{explanation}}

Progressive 2 couple dance, 2 facing 2 round room, Lady on Man''s right, 1s face clockwise, 2s anticlockwise



1-8::

    1s+2s NHJ with partner, slip step left (2 bars) & back right (2

    bars); 1s+2s circle 4H round to left

9-16::

    1s+2s circle 4H round to right; 1s+2s NHJ with partner, slip step

    right (2 bars) & back left (2 bars)

17-24::

    1s+2s dance RH across & LH across

25-32::

    1s+2s turn opposite dancer 1.1/4 RH into line of 4 across; Ladies

    join LH in centre & RH with partner & all Bal-in-Line; all drop

    hands & Adv to meet new couple with »new« partner', 0);
INSERT INTO 'dancecrib' VALUES (10780, '2018-05-22 07:09:58.217408+00', '2018-05-22 12:25:03.268719+00', 11549, 2, 1, 'ace', '1–:: 1c+2c dance Espagnole up and down (1c start by crossing down, 2c by dancing up) [2c fin facing out]

9–:: Mirror Reels3 on sides [1c cross down to 2pl on 9–10, 2c on 11-12]

17–:: 1c dance down | ½ turn under arm ; dance up | cast off [2c up]

25–:: 1c (from sidelines) pass&turn w/3rd corners, pass RH up/down ; pass&turn w/4th corners [corners turn RH each time]', 3);
INSERT INTO 'dancecrib' VALUES (10779, '2018-05-21 19:04:18.740301+00', '2018-05-21 19:07:07.113738+00', 8080, 1, 202, 'ace', '1--::

  1c long cast touching NH (2c up) ; 1c turn RH ending in centre facing down (2,*1*,3)

9--::

  1c lead down ; and up to 2pl (2,1,3)

17--::

  2c+1c RHA ; 1c+3c LHA (2,1,3)

25--::

  1c turn LH ending in centre facing up ; dance up between 2c | cast to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10781, '2018-05-22 09:35:17.428232+00', '2018-05-22 09:35:17.428232+00', 18349, 1, NULL, 'ace', '1-::

  1c &amp; 3c &frac12; turn RH | lead down (2c &amp; 4c up) ; &frac12; turn RH | lead up to (2,1,4,3)

9-::

  2c &amp; 4c repeat but return to (2,1,4,3)

17-::

  1c+4c dance Set &amp; Rotate

25-::

  All circle8 and back (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10782, '2018-05-22 12:15:40.666988+00', '2018-05-22 12:25:03.269358+00', 11549, 1, 202, 'ace', '1--::

  1c+2c Espagnole up/down, 1c cross RH to 2plx to start, 2c facing out at end (1x,2x,3)

9--::

  Mirror Reels3 on sidelines, 1c (& 2c on [11-12]) cross down to 2pl to start (1,2,3)

17--::

  1c dance down | change side (1W passing under M''s arm) ;  dance up and cast to 2pl (2c up) (2,1x,3)

25--::

  »Modified Corners Pass and Turn« [same as original except that 1c start with 3cnrs and give RH briefly when passing Rsh] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10784, '2018-05-22 20:47:00.213179+00', '2018-05-22 21:08:32.05724+00', 18351, 1, 202, 'ace', '1--::

  1c lead down (2c up), cross and cast behind 3c to 2pl centre back to 1cnrs ; 1c set to P | set pivoting R to face 1cnrs (2,*1*,3)

9--::

  ½ Reel4 on 1 diag, pass Rsh ; ½ Reel4 on 2diag, to 2pl centre in promhold facing down (3x,*1*,2x)

17--::

  ½ Reel3 on 1 diag, 1c Lsh to 2M ; ½ Reel3 on 2diag, 1c Lsh to 2W, to 2pl centre facing up (2,*1*,3)

25--::

  Mirror Reels3 on sidelines, 1c up and out to start



*Deviser''s note:  

When 1st couple finishes reels of three on the side (first time through) they should loop round to be ready to lead down the middle and cross. On the second time through they should cast down to allow 3rd couple to step up.*', 2);
INSERT INTO 'dancecrib' VALUES (10785, '2018-05-25 14:52:16.511706+00', '2018-05-25 16:06:57.276249+00', 18352, 2, 2697, 'ace', '1-8::

  1s lead down & back to place

9-16::

  1s+2s dance RH across & LH back

17-24::

  1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 2s

25-32::

  1s+2s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (11092, '2018-09-09 21:25:05.346232+00', '2018-10-09 12:08:21.183378+00', 18568, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; ½ Fig8 up round 2c (2,1x,3)

9--::

  2c+1c+3c Pick-up Chain (3,1x,2)

17--::

  All A&R ; ½ Reels3 across, 1c RSh to 4cnrs[pos] (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11126, '2018-09-19 07:56:30.241428+00', '2018-09-19 07:56:47.365236+00', 18643, 1, 1645, 'ace', '1-::

  Mirror reels3 on the sides, 2c start out and up

9-::

  1c dance down the middle & back, 2c step in for

17-::

  1c+2c allemande, 1c end facing 1cnrs

25-::

  Turn CPCP (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10786, '2018-05-25 14:54:02.897795+00', '2020-10-17 17:33:58.044188+00', 18353, 2, 2697, 'ace', '1-8::

  1s+3s cross RH, cast 1 place & dance 1/2 Fig of 8 round couple above

9-16::

   2s+4s cross RH, cast 1 place & dance 1/2 Fig of 8 round couple above

17-24::

   1s lead down to bottom & turn RH

25-32::

   All dance 10H round & back

', 0);
INSERT INTO 'dancecrib' VALUES (13958, '2021-04-16 10:58:36.046704+00', '2021-11-24 12:34:53.754242+00', 20319, 1, 1645, 'ace', '1--::

  1c turn RH | cast off (2c up) ; 1c turn LH to end BtoB facing 1cnrs

9--::

  1c+1cnrs *Set to Corners and Cast Away*: 1c+1cnrs set | 1c cast away to 3cnr[pos] while 1cnrs dance in & swivel R to end BtoB ; repeat from new places, 1c end BtoB facing 2cnrs

17--::

  1c+2cnrs repeat, 1c end passing RSh to opp sides (3x,1x,2x)

25--::

  All &frac12; turn RH & cast away ; 1c+2c RHA (3,1,2)

  

*Note: Set to Corners and Cast Away is also called Best Set in the Hall or Peter White figure.*

', 2);
INSERT INTO 'dancecrib' VALUES (14324, '2021-09-18 08:34:26.170992+00', '2021-11-24 12:39:25.781653+00', 20317, 1, 202, 'ace', '1--::

  1c turn BH (2c up) | set advancing as for Reel4 position across ; 1M+2W turn RH ¾ _while_ 1W+2M turn LH ¾ (to 2,1x,3) | all turn P RH ½ into promhold

9--::

  3C Circulating Allemande. On [15-16] 1c turn P LH ¾ to face 3cnrs[pos]

17--::

  Corners Pass and Turn (3x,1,2x)

25--::

  All chase clw ½ ; 1c turn BH ½, face P | cast R to exchanged places (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10787, '2018-05-25 16:05:06.37954+00', '2018-05-25 16:06:57.27693+00', 18352, 1, 202, 'ace', '1--::

  1c lead down ; and up (1,2)

9--::

  1c+2c RHA ; LHA

17--::

  1c cross RH | cast (2c up) ; ½ Fig8 up round 2c (2,1)

25--::

  2c+1c R&L (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (12584, '2020-02-15 17:47:13.343444+00', '2020-02-16 01:01:22.471357+00', 19599, 2, NULL, 'ace', '1-4::

   2nd couple cross LH, cast to the left, 2M to top of the set facing down 2L to bottom of the set facing up (on bars 3-4, 1s and 3s step toward one another on the sidelines, 1s face up and 3s down, taking hands with the 2s as in crown triangles)

5-8::

    2s, 1s and 3s dance Half Inverted Double Triangles

9-12::

    2M with 1s, 2L with 3s dance Half RSH reels of 3 across the dance to finish in their partner''s place back to back, 2M facing down, 2L facing up.  (2M giving RSH to 1L, 2L giving RSH to 3M) (1s and 3s finish facing down and up on the sidelines taking hands with the 2s as in crown triangles)

13-16::

    1s, 2s, and 3s dance Half Inverted Double Triangles

17-20::

    2L with 1s, 2M with 3s dance Half RSH reels of 3 across the set, finishing LSH to LSH in 2nd place. (2L giving RSH to 1L, 2M giving RSH to 3M)

21-24::

    RHA , 2L with the 1s, 2M with the 3s , pass RSH to other end

25-28::

    LHA, 2M with the 1s , 2L with the 3s, finish facing out in 2nd place

29-32::

    1s and 2s cast one place as 3s dance up to 1st place and all 3 couples set.   



*Repeat from new places*

', 3);
INSERT INTO 'dancecrib' VALUES (12586, '2020-02-17 00:29:39.753081+00', '2020-02-17 00:29:39.753081+00', 534, 1, NULL, 'ace', '1--::

  1c+2c RHA {3}, LHA {3} | 1c cross LH to face 1cnr _as_ 2c cast to 1pl

9--::

  1c+1cnrs  ½ diag. Reel4 ; 1c+2cnrs ½ diag. Reel4, 1c finish facing 3cnr

17--::

  1c+1cnrs (in 3cnr pos.) set coupé-PdB (start R foot) | change place RH (Skip-Ch. L foot) ; set coupé-PdB (start L foot) | change place RH (Skip-Ch. R foot), 1c finish facing 4cnrs

25--::

  Repeat [17-24] on 2diag. (3x,1,2x)

33--::

  1c+1cnrs ½ diag. R&L ; 1c+2cnrs ½ diag. R&L (2,1,3)

41--::

  Circle6 and back (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (10859, '2018-06-22 16:29:41.0868+00', '2023-02-23 00:54:19.465615+00', 17973, 1, 202, 'ace', '*Cpl facing Cpl round the room, 1c facing clw*

1--::

  1c & 2c NHJ slip L | slip R ; Circle4 L

9--::

  1c & 2c NHJ Circle4 R | slip R ; slip L 

17--::

  RHA ; LHA

25--::

  1c & 2c turn opposite dancer RH 1¼ into line4 across ; BiL | dance on to next cpl', 2);
INSERT INTO 'dancecrib' VALUES (11079, '2018-09-07 15:36:56.174546+00', '2018-09-09 20:54:50.700677+00', 4023, 1, 202, 'ace', '*3c & 4c start on opposite sides (1,2,3x,4x)*

1--::

  1c & 4c ½ Fig8 round nearest middle ; 1W & 4W followed by P cross diagonally  out between 2c & 3c, cast R to exchanged places (4,2,3x,1x)

9--::

  Reels4 on the sides, 2M & 3M face out (4,2,3x,1x)

17--::

  2M+3M cast Rsh round closest cnr, cross, cast R along the side, pass between end couple and cast R back to starting place _while{8}_ 2W+3W cross | dance Rsh once round same cnr, and down/up the middle.  Meet the "other" M Rsh and follow him to starting place (4,2,1x,3x))

25--::

  4c+2c & 3c+1c The Tourbillon (2,4,1x,3x)', 4);
INSERT INTO 'dancecrib' VALUES (11091, '2018-09-09 20:54:28.144551+00', '2018-09-09 21:00:12.159657+00', 18567, 1, 202, 'ace', '1--::

  1c lead down (2c up on [3-4] ; turn RH ½ and lead up to 2plx (2,1x,3)

9--::

  2c+1c La-Chain

17--::

  1c+3c RHA ; 1c cast to 3pl _as_ 3c dance up to 2pl | 1c cross RH (2,3,1)

25--::

  Circle6 and back (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (9982, '2017-06-28 00:09:50.255783+00', '2019-05-01 08:47:20.597921+00', 17795, 1, 202, 'ace', '1--::

 All W pass Rsh to cnr for Fig8 round that cnr and P to places

9--::

 All W LHA ; RHA _while{8}_  all M chase cclw to places

17--::

 All M pass Lsh to cnr for Fig8 round that cnr and P to places

25--::

 All M RHA ; LHA _while{8}_  all W chase clw to places

33--48::

 1M+cnr NHJ & 3M+cnr NHJ A&R {4}, R&L {8}, all cpls turn P RH {4}

49-64::

 2M+cnr & 4M+cnr repeat [33-48], all W facing out

65-80::

 Schiehallion Reels

81--::

 Circle8 and back



*Deviser''s note: There are no polite turns in the rights and lefts figures.*', 2);
INSERT INTO 'dancecrib' VALUES (11094, '2018-09-09 21:52:59.591095+00', '2019-02-01 15:47:10.530633+00', 11464, 1, 202, 'ace', '1--::

  Mirror Reels3 on opposite sides (1c cross down), finish 2c in 1pl and 1c BtoB in centre facing opposite sides (2,1,3)

9--::

  DTr (2,1x,3)

17-28::

  3C R&L (2,1x,3)

29-32::

  1c turn RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3834, '2013-07-13 15:56:18.600969+00', '2018-09-10 19:09:23.920869+00', 9888, 1, NULL, 'ace', '1–::

  1c+3c A&R ; ½ R&L

9–::

  2c+4c A&R ; ½ R&L (3,4,1,2)

17–::

  All couples NHJ set | Petronella in tandem R ; All chase back 1 place clw | turn RH ¾ (W in centre)

25–::

  All W LHA _while_{4} all M chase clw ½ ; All face new P and set | turn RH ½ (M in centre)

33–::

  All M LHA _while_{4} all W chase clw ½ ; All face own P and set | turn RH ¾ to own place (1,2,3,4)

41–::

  Circle8 L ½ ; All set | cast L (back) one place L (4,1,2,3)



{{explanation}}

Repeat as J,S,J to own places.  ', 3);
INSERT INTO 'dancecrib' VALUES (10788, '2018-05-26 01:41:12.966181+00', '2018-05-26 02:05:42.369941+00', 17877, 1, 202, 'ace', '1--::

  1c set advancing pivoting R into BtoB facing own side | cast two places, meet below 3c, dance up into DTr facing own side (2c up on [7-8]) (2,*1*,3)

9--::

  All set | 1c turn 3cnrs RH ; 1c turn 4cnrs LH into DTr | all set (2,*1*,3)

17--::

  Reels3 across, 1c Rsh to 3cnrs. On [24], 1c meet up/down the middle, turn LH ½, 2c & 3c loop to places (2,1,3)

25--::

  1M+3c & 1W+2c RHA, 1c to 2pl at end ; all turn P RH

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10789, '2018-05-26 01:59:54.341408+00', '2018-05-26 02:07:36.397111+00', 17876, 1, 202, 'ace', '1--::

  1c+2c S&Link ; 2c+1c+3c turn P RH, all M(W) face up(dn) (2,1,3)

9--::

  All chase clw ½ ; set | cross RH (3,1,2)

17--::

  3C S&Link | 1c turn P RH 1¼ to 2plx facing out (2,1x,3)

25--::

  Reels3 on sidelines, 1c Rsh to 1cnrs. On [31-32], 1c pass P Lsh to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10790, '2018-05-26 05:50:26.295112+00', '2018-05-26 05:54:29.184696+00', 17875, 1, 202, 'ace', '1--::

  1M+2M S&Link, 1M to 2pl centre as 2W step in, both facing up NHJ ; 1M+2W S&Link to 2plx (2M,2W on M side, 1W,1M on W side)

9--::

  1c+2c Circle4 L, face P on sidelines ; set to P | turn RH into promhold across the set

17--::

  1c+2c in allemande hold dance round each other M Lsh to Lsh. On [20], the M bring P around under arms to midline (2M,2W,1W,1M) ; set to P | turn BH

25--::

  1c & 2c set to P | Petronella turn (to 2,1x) ; 1c cross RH through 2c | cast to 2pl (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (10791, '2018-05-26 18:45:56.996513+00', '2019-10-27 23:53:04.768082+00', 17874, 1, 202, 'ace', '1--::

  1c & 3c set | dance down one place, touching hands briefly and face out (2c & 4c up) (to 2,1,4,3,5) ; 1W & 3W (1M & 3M) cast off(up) one place, cross to midline and dance up(dn) to DDTr position facing own sides (2,*1*,4,*3*,5)

9--::

  DDTr, 1c & 3c face out (2,1,4,3,5)

17--::

  1M+2c & 3W+5c Reels3 across, Rsh to 2M/5W _while{8}_ 1W+3M+4c Reel4 across, 4c passing P Lsh to start. On [24], 1W & 3M pass Lsh to face P on midline (1M,1W,3M,3W)

25--::

  All set | 1c & 3c turn P LH 1¼ to sidelines | 1c & 3c cast (4c & 5c up) (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (11128, '2018-09-19 09:13:32.886599+00', '2018-09-19 09:13:49.17098+00', 18651, 1, 1645, 'ace', '1-::

  1c+2c RHA ; LHA

9-::

  1c down the middle & back

17-::

  1c+2c allemande

25-::

  All circle6 & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12587, '2020-02-17 00:49:42.47728+00', '2020-02-17 00:49:42.47728+00', 533, 1, NULL, 'ace', '1--::

  1c set | change places RH  and 1c face 2c ; 1c+2c set and change places LH (2,1x,3)

9--::

  ½Reels3 on the sides, 1c Rsh to 3c (3,1x,2) ; 3c +1c ½ La-Chain 

17--::

  3c+1c Lsh Reel4 across, the W start by passing Rsh in the middle

25--::

  3c+1c ½ La-Chain (3,1x,2) ; ½Reels3 on the sides, 1c start by crossing Rsh to 4cnr pos. (2,1,3) 





', 3);
INSERT INTO 'dancecrib' VALUES (11121, '2018-09-17 15:34:17.481257+00', '2019-03-07 00:18:58.96274+00', 8204, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c Circle4 and back

9--::

  1c & 3c lead down ; and up (1,2,3,4)

17--::

  All turn P RH ; turn P LH

25--::

  1c dance down to end ; all step up | all clap 3 times', 2);
INSERT INTO 'dancecrib' VALUES (15369, '2022-12-27 13:35:56.149154+00', '2022-12-27 13:41:35.747318+00', 21165, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c 4 bars of The Tourbillon ; Circle4 L. All face P on sides

9--::

  Reels4

17--::

  ½ G-Chain (1 bar per hand). All face P on sides ; last 4 bars of The Tourbillon (3x,4x,1x,2x)

25--::

  2c dance up and loop to 1pl (3c+4c+1c step down) ; all set | cross RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11818, '2019-05-01 08:58:35.954594+00', '2019-05-02 00:30:48.964485+00', 9233, 1, 202, 'ace', '1--::
  1c dance between 2c and cast up ; 2c ½ Fig8 up round 1c (1,2x,3)
9--::
  1W+2M & 1M+2W set |Petronella in tandem ; repeat [9-12] (2,1x,3)
17--::
  All set to the R then Circle6 L {3} ; all M turn W on R BH into circle | Circle6 L {2} all facing clw (2,1x,3)
25--::
  Reels3 {6} on sides, 1c LSh to 1cnrs who cast | 1c cross RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10792, '2018-05-26 20:00:43.112867+00', '2019-03-06 20:17:21.27953+00', 18334, 2, 13458, 'ace', '1-8::    1s cross by the right, cast, ½ fig of 8 round the 2s and end in 2 pl.  1s facing down and 3s facing up

9-16::    1s + 3s set.  Ladies turn LH and men turn RH (2 bars).  1s end in 2 pl facing up and 2s facing down. 1s + 2s set.  Ladies turn RH and men turn LH (2 bars) ending 2 1 3

17-24::    2s+1s+3s reflection reel of 3 on the side, 1s down and in to start, and end in the middle back to back facing own side.  Corners loop round to finish

25-32::    2s+1s+3s dance Double Triangles.  1s end by setting to own side (213)
', 3);
INSERT INTO 'dancecrib' VALUES (9558, '2017-01-25 16:44:39.909539+00', '2017-01-27 00:40:00.833947+00', 2391, 1, NULL, 'ace', '1--::

  1c lead down the middle, cross below 4c and cast up to (1x,2,3,4)

9--::

  1W followed by 2M+3M+4M chase clw round the set to (1x,2,3,4)

17--::

  1M followed by 2W+3W+4W chase cclw round the set (1x,2,3,4)

25--::

  1c cross and cast to 4pl (2c+3c+4c up) ; All turn P RH

', 3);
INSERT INTO 'dancecrib' VALUES (10793, '2018-05-27 00:17:36.340214+00', '2018-05-27 10:15:36.500514+00', 13942, 1, NULL, 'ace', '1--::

  1c (cross) + 2c (cast up) DblFig8, end 1c facing 2c NHJ (1,2) 

9--::

  1c+2c S&Link ; RHA (1x,2x)

17--::

  R&L starting up/down, end 1c facing 2c NHJ (1x,2x)

25--::

  1c+2c S&Link; Circle4 L (1,2)

33--::

  All chase clw ½ | set to P ; Turn P RH 1½ (2,1)  



*crib derived from the video*

', 2);
INSERT INTO 'dancecrib' VALUES (12589, '2020-02-17 16:41:43.26973+00', '2020-02-17 17:25:53.310373+00', 19845, 2, 1007, 'ace', '1-8::   1c+2c ½ RHA (end 2M face out 2W close behind); 1C+3C ½ LHA (end 3W+1W face out partner close behind; 2c+3c+1c ½ Lsh reel3 in tandem down centre (3c down and L to start Reel) to finish 1,(3),(2) 



9-16::  1c+3c+2c Rsh parallel reel3 on side (1c+3c pass Rsh to start)



17-24::   1W+3M and 1M+3W turn RH 1½; 1c turn LH 1¼ to 1cnrs positions



25-32::   1C+2M+3W ½ diagonal Reel4 (on 1st cnr diagonal), 1C pass Rsh to face 2cnrs position; 1c+3M+2W ½ diagonal Reel4 (on 2nd cnr diagonal), 1c pass Rsh to 2,1,3



33-40::   Circle6 and back



', 0);
INSERT INTO 'dancecrib' VALUES (11096, '2018-09-11 22:39:09.150305+00', '2018-09-11 22:44:32.420637+00', 18579, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; 1c turn RH | cast R, 1W to 3pl, 1M to 1pl (3W & 1M step inwards on [7-8]) (1,2,3 on M side, 2,3,1 on W side)

9--::

  3C Bourrel (3,1,2)

17--::

  All chase clw ½ ; set | all pass P RSh, Men making arches (2,1,3)

25--::

  Reels3 across, 1c RSh to 2cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11097, '2018-09-11 22:59:20.129744+00', '2018-09-13 14:58:29.106413+00', 18580, 1, 202, 'ace', '1--::

  1M+3W & 1W+3M turn RH and face out ; 1c & 3c chase clw ½ _while{4}_ 2M+4W & 2W+4M turn RH and face out (3,2,1,4)

9--::

  2c & 4c chase clw ½ _while{4}_ 1c & 3c A&R ; 2c & 4c A&R (3,4,1,2)

17--::

  3c+1c ½ La-Chain ; 4c+2c ½ La-Chain

25--::

  All face new P and set | all turn RH into promhold | all Promenade clw 1 place and face in', 2);
INSERT INTO 'dancecrib' VALUES (10795, '2018-05-27 06:16:43.641423+00', '2018-05-27 08:31:18.963711+00', 17873, 1, 202, 'ace', '1--::
  1c & 2c turn RH 1¼ into midline ; ½ Reel4
9--::
  2c turn RH 1¼ to 1pl _while{4}_ 1c turn RH, pivot R to finish BtoB in centre, 1M(1W) facing dn(up) ; 1c cast R round 4cnrs and face 1cnrs (2,*1*,3)
17--::
  Set to and Turn Corners (2,1x,3)
25--::
  All set | 1c turn BH 1½ to 2pl _while{4}_ 2c & 3c turn BH | all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3821, '2013-07-13 15:56:15.287739+00', '2021-01-20 10:11:32.39487+00', 11774, 1, NULL, 'ace', '{{explanation}}

Square set, with 4 »single« dancers in the middle, each facing »his« couple.



1–::

  All C set to Singles | RHA with single | singles ½ LHA in middle to face opposite couple

9–::

  Repeat, to original places, but couples a finish a bit apart

17–::

  All Singles Rsh Reel3{6} with their Couple | couple ¾ LH turn to promhold facing facing cclw _while_{2} singles cast out and L round their couple to places.

25–::

  All C promenade round once cclw, finish making an arch NHJ with corner.

33-48::

  All singles dance out through gap opposite, cast R, and in under the arch into middle, swiveling R to face next gap clw ; repeat 3 times to places facing in.

49–::

  1W+ 2 singles+2M  & 3W+ 2 singles+4M make two facing rows NHJ (=1st diagonal) _while_{8} 1M + 2W following and 3M + 4W following dance round the line end, in through the channel and cast R to the other pair''s place ; when meeting in the channel give RH, LH, RH. At the end rearrange the "channel" along the other diagonal,

57–::

  The other two pairs dance likewise, 1W & 3W leading.  All couples are now on the opposite side.

65–::

  Parallel Lsh ½Reel4 on the "first" diagonal lines, starting with the facing singles passing Lsh ; the singles chase ½ cclw 2 places _while_{4} couples turn RH once.

73–::

  Parallel Lsh ½Reel4 on the "second" diagonal, as before (all are in own places again) ; each C with own "single" Circle3 L, opening out ("single" behind) into

81–::

  All circle 12H L and back.

', 3);
INSERT INTO 'dancecrib' VALUES (12442, '2019-12-18 13:58:47.531866+00', '2020-06-24 10:43:33.761307+00', 13313, 1, 202, 'ace', '1--::

  1c+2c Set&Rotate (set diagonally). 1c face down (2,1,3)

9--::

  Parallel Reels3 on sides, 1c LSh to 3c. 1c pass RSh and face 1cnrs

17--::

  1c turn 1cnrs RH | pass RSh ; turn 3cnrs LH | pass LSh to 2cnrs

25--::

  1c turn 2cnrs RH | pass RSh ; turn 4cnrs LH | pass LSh to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11127, '2018-09-19 09:02:48.603477+00', '2018-11-06 09:10:39.395011+00', 18650, 1, 1645, 'ace', '1-::
  1c cross RH | cast off (2c up) ; cross LH | cast off (3c up)
9-::
  3c+1c &frac12; RHA | 1c & 3c &frac12; turn RH ;  2c+1c &frac12; LHA | 1c & 2c &frac12; turn LH (1,2,3)
17-::
  1c+2c Knot, 1c end facing 1cnrs
25-::
  Turn CPCP (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (1858, '2012-01-22 19:29:06.462186+00', '2021-03-16 09:49:28.141528+00', 8629, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c DblFig8, end couples cross in to start

9–::

  2c+3c continue cast to end places _while_{2} 1c+4c dance in to meet | 1W+4W & 1M+4M turn BH ; 1c+4c circle4 L (2,1,4,3)

17–::

  1c+4c Poussette (2,4,1,3)

25–::

  2c+3c cross RH | cast to middle positions (1c+4c step to end) ; cross, 2W+3W passing under 2M+3M arch, all turn ½ nearest hand in sideline to finish 2,4,1,3', 2);
INSERT INTO 'dancecrib' VALUES (10873, '2018-07-03 05:08:51.672046+00', '2020-09-22 08:39:22.685862+00', 13835, 1, 202, 'ace', '1--::

  All set | 1c cast (2c cross up no hands to 1plx) _while{2}_ 3c cross RH (to 2x,1,3x) ; ½ Rsh Reels3 on sidelines, 2c(3c) looping to face up(dn) on sidelines (3x,1,2x)

9--::

  1c Petronella turn _while{2}_ 2c+3c change places RH into facing lines3 across | all set ; ½ Rsh Reels3 across into facing lines3 across

17--::

  Diag R&L, finishing facing cclw

25--::

  All chase cclw ½ ; set in lines3 across | 1c Petronella turn to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12435, '2019-12-12 10:57:00.887886+00', '2021-11-24 14:03:16.49727+00', 19792, 1, 202, 'ace', '1--::

  1c turn BH and face up NHJ | cast off (2c up) ; cross down RH between 3c and cast up to face 1cnrs

9--::

  Corners Pass and Turn BH, finishing on opposite sides (2,1x,3)

17--::

  1c dance up | cast off ; 1c turn P RH ½, face P | cast R to exchanged places (2,1,3)

25--::

  1c+3c The Tourbillon (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (15455, '2023-02-23 11:22:13.158993+00', '2023-02-24 20:03:05.805329+00', 21348, 1, 202, 'ace', '1--::

  1c & 4c turn P RH ; LH _while{8}_ 2c+3c RHA ; LHA (1,2,3,4)

9--::

  2c & 3c Fig8 out round nearest ends (1,2,3,4)

17--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 1c+4c ½ R&L (2,4,1,3)

25--::

  Circle8 and back (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10783, '2018-05-22 17:37:04.284436+00', '2018-05-27 16:32:25.569215+00', 18350, 1, 202, 'ace', '1--::
  1c ½ Fig8 on sidelines, 1c start in and down ; meet and dance up to BtoB between 2c in 1pl (2c up on [5-6])
9--::
  1c turn 2c EH ¾ (to 2,1,3) | 1c turn 3c EH ; 2c+1c+3c A&R (2,1,3)
17--::
  1c ½ Fig8 R round 2cnrs (to 2,1x,3) ; 1c turn 1cnrs LH (2,1x,3)
25--::
  1c ½ Fig8 L round 3cnrs (to 2,1,3) ; 1c turn 4cnrs RH (2,1,3)

*Deviser''s note:  
Bar 8:  1c have to anticipate the 2-bar turn that follows on bar 9.  Therefore, 1c only just slide in back to back between 2c in order to flow into that turn.*', 5);
INSERT INTO 'dancecrib' VALUES (3822, '2013-07-13 15:56:15.314411+00', '2019-05-02 21:39:06.322698+00', 12539, 1, NULL, 'ace', '*2 chords, to move to (1,2,3,4x,5x,6x)   

This dance is centro-symmetric; both ends do identical figures*   

1–::

  1c+6c cross RH | cast inwards (2c+5c to end) ; cross LH | cast to middle (3c+4c to end) (2,3,1,6x,4x,5x)

9–::

  1M+6W & 6M+1W in promhold Lsh Reels3 across with 4c/3c resp. (2,3,1,6x,4x,5x)

17–::

  2c+3c+1c & 6c+4c+5c mirror Reels3 on the sides, 1c&6c start inwards towards own end (2,3,1,6x,4x,5x)

25–::

  1c+6c R&L

33–::

  2c&5c cross RH _while{2}_ 3c+1c & 6c+4c ½ RHA | on sidelines change place LH between 1pl/2pl, 3pl/4pl and 5pl/6pl  (1x,2x,4,3x,5,6) ; repeat {4}

41–::

  repeat [33-36] ; All turn P RH (5,4,6,1x,3x,2x)    



*Dance 3 times to end 6 5 4 3 2 1 or 6 times to end 1 2 3 4 5 6*', 2);
INSERT INTO 'dancecrib' VALUES (11100, '2018-09-13 12:13:36.128576+00', '2022-07-05 22:44:03.702524+00', 18586, 2, 2697, 'ace', '1-8::

    1s turn RH (elbow grip) | cast to 2nd place; 2s+1s+3s turn RH twice (elbow grip)

9-16::

    1s dance ½ fig of 8 round 2s; 1s dance ½ fig of 8 round 3s

17-24::

    1s pass each other LSh, 1s turn 1st corner RH (elbow grip), partner LH, 2nd corner RH (elbow grip)

25-32::

    2s+1s+3s circle 6H round & back', 3);
INSERT INTO 'dancecrib' VALUES (3530, '2012-01-22 19:30:29.480956+00', '2019-05-02 22:57:03.714154+00', 7111, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; turn LH 1½ to finish BtoB between 2c

9–::

  1c+2c Reel4 across, at end 1c pass Rsh to face 1cnr

17–::

  Turn CPCP, finish between 3c, BtoB facing opp. side

25–::

  1c+3c Reel4 across, 3c finish in 2pl, 1c pass Lsh in centre and join LH

33–::

  1c turn LH and cast off on own sides (4c up) ; 1c turn RH. (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (1589, '2012-01-20 13:06:12.798673+00', '2020-06-24 10:43:33.757965+00', 13313, 2, 1, 'ace', ' 1-8::

  1C+2C set & rotate (face person diag opp to begin), 1C fin facing down

 9-16::

  Parallel Reels3 on own sides (1C LSh to 3C), 1C pass RS to fin facing 1cnr

17-24::

  1C turn 1cnr RH, pass RSh ; turn 3cnr LH, pass LSh

25-32::

  Turn 2cnr RH, pass RSh ; turn 4cnr LH, pass LSh and loop into 2pl own

  sides.

', 3);
INSERT INTO 'dancecrib' VALUES (2594, '2012-01-22 19:29:49.077826+00', '2018-09-12 20:46:53.625617+00', 3580, 1, NULL, 'ace', '1–::

  1M+2W turn RH, to places ; 1c turn LH 1½ (2W up on [7-8]) to face down in line across 1W+1M+2W

9–::

  2W+1M+1W down the middle and up (1M hands 1W across in front as 2M joins in behind him for)

17–::

  1c+2c RHA, LHA (1,2)

25–::

  1c+2c Poussette. (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (10797, '2018-05-29 17:33:41.878723+00', '2018-05-29 17:33:41.878723+00', 4707, 1, NULL, 'ace', '1-::

  1c turn RH ; cast off 2pl (2c up) | lead up LH to 1cnrs

9-::

  1c turn 1cnrs RH | pass RSh ; turn 2cnrs LH | pass RSh (cnrs dance 4 bars)

17-::

  1c set to 1cnrs | set to 2cnrs ; 1c turn 1&frac14; LH _while{4}_ cnrs chase &frac12; way clw

25-::

  1c &frac12; diag RSh Reel4 with 1cnrs, pass RSh ; &frac12; diag RSh Reel4 with 2cnrs (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3269, '2012-01-22 19:30:18.324653+00', '2020-12-17 22:27:15.775712+00', 6104, 1, NULL, 'ace', '1–::

  1c+2c Tourbillon: 1c+2c turn P BH ½, opening out to one place clw in the square (1c to W side, 2c to M side) | 1c set to 2c ; repeat figure (to 2x,1x) | 2c+1c cross RH (2,1,3)

9–::

  1c (M up, W down) dances ½ Fig8 Rsh round 2 cnr ; 1M+3c & 1W+2c ½ Rsh reels3 across (2x,1,3x)

17–::

  Diagonal R&L (to 3,1,2)

25–::

  All set | 3c+1c ½ RHA _while{2}_ 2c cross RH ; all chase clw ½ round (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (10798, '2018-05-29 17:38:37.174673+00', '2018-05-29 17:38:37.174673+00', 4553, 1, NULL, 'ace', '1-::

  1c turn 1&frac12; RH moving down (2c up on [3-4]) ; 2c+1c RHA

9-::

  1c+3c LHA ; 1c turn 1&frac12; LH (2,1,3) *For [1-16] 1c only return to the sides on [16]*

17-::

  2c+1c+3c set | cross RH ; 2c &amp; 3c set | cross LH _while{4}_ 1c cast L to take hands in lines across (1M+2c, 1W+3c)

25-::

  Circle6 &frac34; to L ; all set adv to diagonal line between 2cnrpos (3W,2W,1M,1W,3M,2M) | 1c turn RH _while{2}_ 3W+2W &amp; 3M+2M turn LH to (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3727, '2013-04-13 16:38:32.053742+00', '2020-02-18 22:14:34.788689+00', 11397, 1, NULL, 'ace', '1–::

  All W dance in, face R about and dance out ; cast clw ½ round set

9–::

  All W pass in front of new P for Fig8 round that P and cnr

17-32::

  All M repeat [1-16] L and cclw (3,4,1,2)

33–::

  1c+3c R&L finish facing cclw

41–::

  1c+3c chase cclw ¼ round, loop simultaneously Lsh round a side person, and chase on ¼ to own place (1,4,3,2)

49-64::

  2c+4c repeat [33-48] (1,2,3,4)

65–::

  All W RHA ; LHA

73–::

  All M LHA ; RHA and all face cnr

81–::

  All set to cnr and swivel R | All set to P ; all turn P RH 1¼ to promhold

89–::

  All promenade cclw to places (1,2,3,4)', 3);
INSERT INTO 'dancecrib' VALUES (1994, '2012-01-22 19:29:14.019021+00', '2019-02-12 02:04:07.605073+00', 12080, 1, NULL, 'ace', '1–::

  All set | 1c+2c & 3c+4c ½ RHA ; 2c+1c & 4c+3c ½ DblFig8, to start 2c & 4c cross down) (2,1,4,3) 

9–::

  Mirror »Crossover Reels4« (on M side Rsh, on W side Lsh), in the middle all Cs when dancing up cross LH to other side (2x,1x,4x,3x)

17–::

  2c+1c+4c ½ Reels3 on sides (1c start out and up) (4x,1x,2x,3x) ; middles face ends and change places on sides EH (4c & 2c moving outwards) | set to person just passed (1x,4x,3x,2x)

25–::

  Rsh Reels4 on the sides, but halfway the sideline each M dancing down meeting the W dancing up, make quick turn RH ½ to exchange places, joining the reel on own side (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (10799, '2018-05-29 17:46:26.220271+00', '2018-05-29 17:46:26.220271+00', 4749, 1, NULL, 'ace', '1-::

  1M+2W set adv | turn RH to pl ; 1W+2M set adv | turn 1&frac14; LH to face P on 1cnr diagonal

9-::

  1c+2c diag RSh Reel4 ending in original pl (1,2,3)

17-::

  1M+3W set adv | change pl RH ; 1W+3M set adv | turn &frac34; LH to face P on 1cnr diagonal

25-::

  3c+1c &frac12; diag RSh Reel4, 1c end taking RH at the top ; 1c turn RH | cast off (2c up) to (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (9559, '2017-01-25 16:44:58.356227+00', '2017-01-25 17:04:24.165603+00', 17570, 2, 160, 'ace', '1-8::
  Head cpls slip down/up (men pass B-to-B) ; slip back to place (Ladies pass B-to-B)
9-16::
 Sides repeat.
17-24::
  All Grand Chain.
25-32::
  All Ladies Chain.
33-40::
 8 hands round & back.
41-44::
  All Pet. in tandem and set (face out).
45-48::
  If facing a cpl. (in another set) - dance 1/2 R&L with that cpl. (end in that new set)
  if NOT facing a cpl.- turn RH and face in.', 3);
INSERT INTO 'dancecrib' VALUES (13783, '2021-03-02 15:35:06.433306+00', '2021-04-18 11:05:22.180837+00', 4337, 1, 202, 'ace', '1--::

  All RHA ½ | set ; LHA ½ | set

9--::

  Circle4 and back

17--::

  Inside pair (M facing cclw with opposite W) NHJ dance between outside pair | cast round own P to places ; outside pair repeat same pattern

25--::

  All W change places RH | All M change places RH ; all set | all change places with P RH and face a new couple', 2);
INSERT INTO 'dancecrib' VALUES (10824, '2018-06-10 11:26:29.613958+00', '2018-06-10 11:26:29.613958+00', 18374, 2, 1, 'ace', '1–:: Mirror reels of 3 on opp sides
9–:: 1c down the middle and up to 1st corners (2c up on 11–12)
17–20:: 1c+1st corners pass and turn (1c quick RH turn to 4th corner at end)
21–24:: 1c+4th corners pass and turn [to 213]
25–:: Circle6', 3);
INSERT INTO 'dancecrib' VALUES (12042, '2019-08-24 16:24:27.144067+00', '2022-11-12 12:26:09.850174+00', 5787, 1, 202, 'ace', '1--::

  1c cross down to 2plx (2c up)  | turn 2c EH ½ on sides ; repeat [1-4] from new positions. 2c face out (1,2,3)

9--::

  Mirror Reels3 on opposite sides (1c cross down, 2c out and up) (1x,2,3)

17--::

  Repeat [9-16] to own sides. 2c face out (1,2,3)

25--::

  1c, 2c following, dance down to the bottom, cast up round 3c to 2pl, dance up to the top and cast off to own sides having changed places (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11099, '2018-09-13 10:13:23.725454+00', '2018-09-28 23:27:53.940001+00', 18571, 1, 202, 'ace', '1--::

  1c long cast (2c up) ; 3C S&Link

9--::

  All dance BtoB up/down | 3C S&Link, 1c face 1cnrs[pos] (3x,1,2x)

17--::

  »Set to Corners and Cast Away« [1c set to 1cnr[pos] | 1c cast Rsh round P to 3cnr[pos] _while{2}_ cnrs on 1diag dance into centre, and swivel R BtoB to face own cnr[pos] ; repeat, cnrs on 1diag finishing in exchanged places, and 1c facing 2cnrs[pos]]

25--::

  Repeat [17-24] with 2cnrs[pos]. On [32] 1c finish in centre BtoB facing own side (2,1,3)

33--::

  1c loop R round 3cnrs | pass P RSh up/down ; loop R round 4cnrs to 2pl (2,1,3)



*Note:  

»Set to Corners and Cast Away« is also called "Best Set in the Hall Figure".*', 2);
INSERT INTO 'dancecrib' VALUES (3063, '2012-01-22 19:30:08.950004+00', '2018-08-18 20:12:30.032776+00', 7494, 1, NULL, 'ace', '{{explanation}}

Each couple dance 64 bars; a new couple starts every 32 bars.  Music 5 x 32.



1–::

  1c set | lead to centre, cross W in front and dance out between the side couples to places |  turn LH ½

9–::

  1c+3c (promhold) A&R ; dance cclw outside set to exchanged places

17–::

  1c+3c M-Chain

25–::

  All Circle8 and back



{{explanation}}

Next couple (in order 2,3,4) now starts at bar 1, interlocking with the others



33–::

  1c+3c R&L (start across)

41–::

  1c+3c in promhold advance | turn P RH ½ ; ½Poussette, finish with turn P RH ½ to exchanged places

49–::

  1c+3c M-Chain (intersecting, M give quick LHA in the middle)

57–::

  All Circle8 and back



{{explanation}}

on last 32 bars [129-160] only 4c dances', 3);
INSERT INTO 'dancecrib' VALUES (3714, '2013-03-09 22:32:39.463487+00', '2018-09-13 14:04:56.902217+00', 14720, 1, NULL, 'ace', '1–::

  All Rsh Reels3 on own side, on [7-8] 1W cross up through 2Mpl _while_ 1M crosses at the top (1x,2,3)

9–::

  Repeat to places (1,2,3)

17–::

  1c+2c RHA ; LHA finishing in a line on 1diag, BHJ with P

25–::

  1c+2c set R, set L each cpl turning 3/8 to the R, to finish in line across | repeat to finish on 2diag ; repeat to finish on midline (2M,2W,1M,1W) | all petronella to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11102, '2018-09-13 21:11:07.789945+00', '2018-09-13 21:11:07.789945+00', 17249, 1, NULL, 'ace', '1--::

  1c turn RH | cast (2c up) ; turn LH 1½ to face 2cnr

9--::

  *[Circle of Friends]*  1c turn 2cnr BH | 1c dance round P Rsh to face 3cnr(pos) _while{4}_ 1cnrs change place RH and set ; repeat on 1diag while 2diag change place and set, 1c finish facing 4cnr(pos)

17--::

  repeat with 4cnr and 1cnr(pos), finish facing 2cnr

25--::

  	Reels3 across, 1c Rsh to 2cnr (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10800, '2018-05-29 17:56:46.651158+00', '2018-05-29 17:56:46.651158+00', 4464, 1, NULL, 'ace', '1-::

  1c+2c set | &frac12; RHA ; 1c+3c &frac12; LHA staying in the centre; all cross LH (2,3,1x)

9-::

  1c set | cast up (3c down) ; 1c &frac12; Fig8 up round 2c (2,1,3)

17-::

  1c dance down below 3c | cast up 2pl  (2c down) ; 1c followed by 2c &amp; 3c lead down (3,2,1) | all turn RH

25-::

  All set (no hands) &amp; 2c face down | 1c+2c change pl (M LH, W RH) _while{2}_ 3c set ; &frac12; Reels3 on sides, 1c start up &amp; out (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (9561, '2017-01-25 23:47:31.4816+00', '2017-01-25 23:47:31.4816+00', 12664, 1, NULL, 'ace', '1--::

  1M+3W & 2M+4W change places LH | All W (above) + All M (below) RHA | All dance 2 pl clw round the set (to M: 3,4,2,1; W 4,3,1,2)

9--::

  repeat figure: 3M+1W & 4M+2W change places LH | All W (above) + All M (below) RHA | All dance 2 pl clw round the set (2,1,4,3)

17--::

  2c+1c & 4c+3c R&L flowing into

25--::

  ½ Reels4 on the sides, Rsh on M side and Lsh on W side (3,4,1,2) ; 2c cast to top (3c+4c+1c down)  (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (11819, '2019-05-03 19:26:43.502809+00', '2019-05-03 23:41:02.866329+00', 19282, 1, NULL, 'ace', '1--::

  1c+4c cross RH | cast inwards (2c+3c to ends) ; 1c+4c RHA, finish with twirl R and face cnr 

9--::

  All set | All middle+cnr La Baratte, finish (1x,2,3,4x) with 2c & 3c in the middle

17--::

  2c+3c RHA ; LHA to sidelines _while{8}_ 1c+4c set and chase 1 place cclw ; repeat (4,2,3,1)

25--::

  Middles facing ends set and turn RH ½ on the sides ; 4c+1c LHA (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10801, '2018-05-29 18:02:10.720314+00', '2018-05-29 18:02:10.720314+00', 1227, 1, NULL, 'ace', '1-::

  1W+2M set | change pl RH ; 1M+2W repeat (2x,1x)

9-::

  1W &amp; 2M cast up/off | pass LSh to face P ready for ; &frac12; diag RSh Reel4 ending in original pl (1,2)

17-::

  1c+2c set | cross RH ; set | &frac12; RHA (2,1)

25-::

  1W &amp; 2M cross over | cast up/off _while{4}_ 1M+2W passing RSh dance round BtoB to face P ready for ; &frac12; diag RSh Reel4 to (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (10802, '2018-05-29 18:26:52.715238+00', '2018-05-29 18:26:52.715238+00', 4821, 1, NULL, 'ace', '1-::

  1M+2W turn RH ; 1M &amp; 2W cast off/up and cross to each others place _while{4}_ 1W+2M turn RH

9-::

  1M+2W turn LH _while{4}_ 1W &amp; 2M cast off/up and cross to each others place ;

  1M &amp; 2W set | turn LH to 1cnrpos _while{4}_ 1W &amp; 2M cross RH to original place | cast off/up to face P ready for

17-::

  2c+1c diag RSh Reel4 ending on the sides (2,1)

25-::

  2W &amp; 1M cross over | turn &frac34; LH _while{4}_ 2M &amp; 1W turn &frac34; RH | cast up/off (2,1) ; repeat (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11820, '2019-05-04 00:05:32.90437+00', '2019-05-04 00:20:43.131836+00', 8346, 1, NULL, 'ace', '1--::

  1c set | cross RH to 2plx (2c up) ; dance Rsh round 1cnr and turn P LH to finish in the middle with Rsh to own side

9--::

  All M & All W RHA on the sides, at end 1c pass P Rsh ; 1M +2W+3W & 1W+2M+3M LHA, finish in facing lines across, 1M / 1W between 2c / 3c

17--::

  All set | change places RH with opposite ; set again in facing lines | change places RH again, 2c+3c face out the ends while 1c faces P

25--::

  Reels3 across, 1c Rsh to 3cnr, finish (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11783, '2019-04-12 17:45:54.355607+00', '2019-05-03 21:06:25.156303+00', 19272, 1, 1645, 'ace', '1-::

  1c turn 1&frac34; RH as 6c turn 1&frac34; LH to face own sides ; 1c & 6c set, W turning under M''s arm | cast inwards (2c & 5c out)

9-::

  1c & 6c &frac12; RSh diagonal Reels4 with 1cnrs, pass RSh ; repeat with 2cnrs (3x,1x,2x,5x,6x,4x)

17-::

  2c+5c &frac12; R&L ; 2c+5c turn 1&frac12; RH on sides _while{4}_ 1c & 6c dance BtoB _while{4}_ 3c & 4c turn 1&frac12; RH (3,1x,2,5,6x,4)

25-::

  1M & 6W each followed by P chase clw to (3,6,2,5,1,4) ; 1c & 6c turn RH or birl

', 2);
INSERT INTO 'dancecrib' VALUES (11821, '2019-05-04 00:28:49.0617+00', '2019-05-04 00:46:06.134596+00', 6672, 1, NULL, 'ace', '1--::

  1c ½ Fig8 round 2c; 2c ½ Fig8 round 1c (1x,2x) 

9--::

  1W+2W NHJ cross under arch by 1M+2M | All change places on side, 1c passing under raised hands (2,1) ; Circle4 L

17--::

  2c+1c ½ R&L (no polite turn) ; turn P RH 1½ into

25--::

  1c+2c Poussette (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (11103, '2018-09-13 21:41:04.008193+00', '2018-09-13 21:42:23.437815+00', 17254, 1, NULL, 'ace', '1--::

  1c+2c DblFig8 (1c cross down, 2c cast up)

9--::

  1c dance down NHJ, turn in and face up _while{4}_ 2c+3c S&Link  ; 1c set and dance to 2pl, BtoB and facing own side _while{4}_ 3c+2c S&Link, 2c finish in 1pl 

17--::

  Set in DTr | 1c change places as in DTr _while_ cnrs chase 1 place clw ; All set as in DTr | 1c petronella to 2pl _while_ cnrs chase 1 place clw (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (11101, '2018-09-13 18:11:58.745707+00', '2021-06-26 19:55:13.078272+00', 932, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA ; 1c+3c set | ½ LHA (2x,3x,1)

9--::

  1c set | cast up to 2pl (3c down) ; dance to top and cast to 2pl (2x,1,3x)

17--::

  1c+3c ½ DblFig8, 1c crossing down ; 1c+2c ½ DblFig8, 1c crossing up (2,1,3)

25--::

  Reels3 across, 1c LSh to 1cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11115, '2018-09-16 01:47:17.433055+00', '2018-09-16 01:50:55.714171+00', 6963, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; ½ Fig8 R round 1cnrs (2,1x,3)

9--::

  1W+3c & 1M+2c RHA ; 1W+2c & 1M+3c LHA, 1c (1W on P''s left) finish in centre NHJ facing up

17--::

  Reels3 on sidelines, 1c up and cast off, 2c down and in (2,1x,3)

25--::

  1c ½ Fig8 R round 2cnrs ; 1c turn RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (7047, '2013-08-21 08:31:34.915847+00', '2023-02-25 14:47:10.17695+00', 5581, 3, NULL, 'ace', '{{explanation}}

Round the Room Dance 2 facing 2



1-8::

    All circle 4H round & back

9-16::

    All dance Ladies'' Chain finishing in promenade hold facing

    anticlockwise

17-24::

    All couples in prom hold dance interlocking 2 couple Promenade

    (anticlockwise, looping LSh round couple in next set & back to

    places)

25-32::

    All couples dance LH across, turn opposite partner RH 1.1/2 times to

    face new couple', 0);
INSERT INTO 'dancecrib' VALUES (14752, '2022-04-10 15:58:08.210715+00', '2022-04-10 15:58:08.210715+00', 18035, 2, 160, 'ace', '1-4:: 1C approach and cast to 2pl.
5-8:: Half Rsh reels3 across - 1M2C and 1W3C - 1C end in middle btwn 2C and 3C respectively.
9-12:: 1M2W also 1W3M Turn LH 1+1/4 - end 1M home, 2W in 2M''s place , 1W in 3W''s place, and 3M in 2W''s place. Order is 1M 2W 3W - 2M 3M 1W 
13-16:: Set+Link3 - end in lines3 across the dance.
17-20:: Set+Link3. Order is now 1W 3M 2M vs 3W 2W 1M
21-24::  2C3C flow into RHA once and a quarter round AS 1W dances up and into the middle, 1M dances down and into the middle and set. 
25-27::  LHA once round - 1W with 3M2M and 1M with 3W2W
28-30:: Unwind - 1W leads 3M and 2M down the men''s side AS 1M leads 2W and 3W up the ladies side. Order is now 2M 3M 1W vs 1M 2W 3W.
31-32:: All set.
33-34:: 1C cast to the middle AS 2W ''links'' up the center  to top place and 3M ''links'' down the center to 3rd place.
25-40:: 1C turn RH once round to face up, dance up crossing over, and cast to 2nd place.', 3);
INSERT INTO 'dancecrib' VALUES (10803, '2018-05-30 04:49:03.264177+00', '2018-11-01 23:58:40.544529+00', 17728, 1, 202, 'ace', '1--::

  1c set | cast off two places ; dance up to top | cast off one place (2c up) to face 1cnrs (2,1,3)

9--::

  »Progressive Corner Chain with Setting« [same as Corner Chain with Setting with cnrs in centre turning LH 1½]

17--::

  Repeat [9-16] with 2cnrs, to 2pl facing out (3x,1,2x)

25--::

  1c loop Lsh round 4cnrs[pos] to 2pl _while{4}_ 3c+2c ½ R&L ; all turn P RH (2,1,3)  



*Deviser''s note:  It may be necessary for the corners to “borrow” a little in bars 9-12 and 17-20 to enable them to complete the turn 1½ on time – i.e start the left hand turn on about bar 10ish or 18ish.*  ', 5);
INSERT INTO 'dancecrib' VALUES (10258, '2017-11-14 20:06:04.555443+00', '2020-06-25 05:26:17.288097+00', 15685, 1, 202, 'ace', '1--::
  1c+2c & 3c+4c Espagnole, 1c & 3c finish facing 1cnrs
9--::
  1c & 3c Turn CPCP, finish facing 1cnrs
17--::
  1c & 3c Parallel Reels4 on 1diag, ending LHJ with P
25--::
  1c & 3c turn P LH | cast to 3plx/5plx (4c & 5c up) ; ½ Fig8 up round 4c/5c (2,4,1,5,3)', 4);
INSERT INTO 'dancecrib' VALUES (11104, '2018-09-13 22:06:40.463008+00', '2018-09-13 22:09:36.039+00', 17247, 1, NULL, 'ace', '1--::

  1c+3c set | petronella to midline ; repeat (to 1x,2,3x)

9--::

  3c with 1c following dance down NHJ {3}, change sides holding hands, M crossing below W {2} (2c up on [11-12]), 1c dance to between 2c and face 2W, 1M behind 1W _while_ 3c dance up to 3pl 

17--::

  1c (change lead) +2c Rsh Reel3 across, 1c finish facing 1cnr

25--::

  1c turn 1cnr RH| pass Rsh ; Turn 2cnr RH | pass Rsh to (2,1,3)



*on 2nd time through1c cross to 4pl (4c up)*



', 3);
INSERT INTO 'dancecrib' VALUES (11105, '2018-09-13 23:54:25.428709+00', '2018-09-13 23:55:50.126458+00', 12169, 1, NULL, 'ace', '1--::

  1c+2c set | cross RH ; set | cross RH and 2c face out (1,2)

9--::

  1c+2c DblFig8

17--::

  1c lead down | turn RH ; lead up | cast off (2c up) (2,1)

25--::

  2c+1c R&L (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (10805, '2018-05-30 10:05:36.936006+00', '2018-05-30 10:05:36.936006+00', 4708, 1, NULL, 'ace', '1-::

  1c cast (2c up) | turn BH opening out to face up ; cast (3c up) | turn BH ending RHJ facing up (2,3,1)

9-::

  1c lead up to top | turn RH _while{4}_ 2c Adv{1}&amp;Ret{1} | cast to 3pl  (1,3,2); repeat from new places (2,3,1)

17-::

  3c cast as 1c cross up into &frac34; DblFig8 | 3c cross LH _while_ 1c cast L (W up, M down) to lines of 3 across

25-::

  1W+2c facing 1M+3c Adv{1}&amp;Ret{1} | 1c turn &frac34; RH to (2,1x,3) ; all Adv{1}&amp;Ret{1} | 1c cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10806, '2018-05-30 10:14:19.423341+00', '2018-05-30 10:14:19.423341+00', 6555, 1, NULL, 'ace', '1-::

  1M+2W change pl RH | 1W+2M repeat ; 2c+1c Circle4 L (2x,1x,3)

9-::

  1c lead up &amp; cross | cast off _while{4}_ 2c cast off | lead up &amp; cross ; 2c+1c Circle4 L (2,1,3)

17-::

  1M+3W change pl RH | 1M &amp; 3W cast off/up &amp; cross _while{2}_ 1M+3W turn RH ; 1c+3c Circle4 L (2,1,3)

25-::

  All &frac12; RSh Reels3 on sides (3,1,2) ; &frac12; Circle6 L | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10804, '2018-05-30 07:11:48.556315+00', '2018-05-30 08:04:49.726699+00', 16509, 1, 202, 'ace', '1--::
  1c & 3c Petronella turn into middline | set ; 1c+3c ¼ Reel4 on middline, 1W & 3M (end persons) passing Lsh into line of 4 across _while{2}_ 2c set | 1W+2c+3M ¼ Reel4 across, 2c passing Lsh into middline
9--::
  Repeat [5-8] twice (3M,3W,1M,1W on middline, 2c in 2plx)
17--::
  3c & 1c turn RH ¾ (to 3,2x,1) | set ; 3c+2C ½ RHA | 3c+1c ½ LHA (2,1x,3)
25--::
  1c turn BH 1½ ; dance down and cast to 2pl (2,1,3)

*Deviser''s note:  
On bars 31-32 of 2nd time through, 4th couple step up into third place while 1st couple loop into fourth place instead of casting up.*', 2);
INSERT INTO 'dancecrib' VALUES (11822, '2019-05-04 01:01:30.717579+00', '2019-05-04 01:04:37.362879+00', 19079, 1, NULL, 'ace', '1--::

  1c+3c change places RH on the sides while 2c Petronella turn | set in facing lines across ; 1c+3c cross RH while 2c Petronella turn | All set (3x,2x,1x)

9--::

  All (1c leading) lead down{3} and All change sides, the W passing above P under joined R arms ; All dance up (3,2,1)

17--::

  Gr-Chain, 3c cross to begin(3,2,1)

25--::

  2c+1c Espagnole (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (10807, '2018-05-31 19:34:19.995466+00', '2019-08-16 13:06:49.085492+00', 16507, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

  1c lead down ; and up to 1pl _while{8}_ 4c cast up, dance behind own sides ; turn outwards, back to 4pl (1,2,3x,4x)

9--::

  2c & 3c Fig8 round nearest ends back to centre into promhold facing up/dn. On [16], 1c & 4c step in into promhold facing up/dn

17--::

  1c+2c & 3c+4c Interlocking Allemandes. On [23-24], 4c & 1c (inner cpls) turn RH ½ (2,4,1x,3x)

25--::

  2c+4c & 1c+3c LHA ; RHA

33--::

  4c+1c La-Chain

41--::

  Circle8 and back (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (11106, '2018-09-14 00:37:06.355962+00', '2018-09-14 00:42:25.453091+00', 17252, 1, 202, 'ace', '1--::

  1c+2c A&R ; 1c+2c step down and set _while{4}_ 3c set advancing and dance to 1pl facing out (3,1,2)

9--::

  Reels3 on sidelines, 1c LSh to 3cnrs[pos]

17--::

  1W+3c & 1M+2c RHA, pass P RSh ; 1W+2c & 1M+3c LHA (3,1,2)

25--::

  3C Set&Rotate (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3288, '2012-01-22 19:30:19.127564+00', '2020-12-17 22:31:48.878882+00', 6177, 1, NULL, 'ace', '1–::

  1c ½ Fig8 round 2c ; 1c turn 2c EH ½ and face out | Turn 3c EH ½ (2,3,1)

9–::

  1c ½ Fig8 up round 3c ; 1c turn 3c EH ½ and face out | Turn 2c EH ½ (1,2,3)

17–::

  1c dance to 2pl in centre (2c up) | set to 3c ; 1c set to P, set to 2c and face up

25–::

  2W+1W+3W RHA _while{4}_ 2M+1M+3M LHA ; 1c dance to top and cast off to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15370, '2023-01-03 14:58:25.082305+00', '2023-01-03 15:02:22.933711+00', 3833, 1, 202, 'ace', '_Strathspey_  

1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 1c+4c ½ R&L (2,4x,1x,3)

9--::

  1c turn P RH | cast off (3c up) ; Circle8 L ½ (1,3x,4,2x)



_Reel_

1--::

  1c+3c & 4c+2c L-Chain

9--::

  3c & 2c cross RH as for Reel4 position | 1c+3c & 4c+2c change places LH (to 3,1,2,4) ; 1c+2c change places RH | 3c+2c & 1c+4c change places LH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (7841, '2013-08-21 08:31:49.605843+00', '2023-02-04 01:23:05.282644+00', 10548, 3, NULL, 'ace', '1-8::
    1s cross down RH, set, cross down LH & set
9-16::
    1s cross RH, change places on sides with 3s LH, 2s+1s cross RH & 3/4
    turn LH on sides to form line of 4 across
17-24::
    2s+1s dance the Targe :
::
    _17-18_ 1st & 2nd Ladies  3/4 turn RH _while_ Men dance 1/4 way
    round anticlockwise
::
    _19-20_ 1st Man with 2nd Lady & 1st Lady with 2nd Man full turn LH
::
    _21-22_ 1st & 2nd Ladies  3/4 turn RH _while_ Men dance 1/4 way
    round anticlockwise
::
    _23-24_ 1st Man with 2nd Lady & 1st Lady with 2nd Man turn 3/4 LH to
    end on sides to 2(1)3
25-32::
    1s cross down below 3s, cast up, dance up between 2s & cast to 2nd
    place', 0);
INSERT INTO 'dancecrib' VALUES (10716, '2018-04-30 09:09:26.283944+00', '2019-02-12 14:44:19.140981+00', 17128, 1, 202, 'ace', '1--::
  1c cross RH | cast (2c up) ; 1c lead down LH, cross and cast up to centre, LHJ facing 1cnrs
9--::
  1c set to 1cnrs (swivel ½ inwards), set to 3cnrs ; ½ Reel4 on 1diag, finish LHJ facing 4cnrs
17--::
  1c set to 4cnrs (swivel ½ inwards), set to 2cnrs ; ½ Reel4 on 2diag, finish BtoB 1M(1W) facing up(dn)
25--::
  1M+2c & 1W + 3c Circle3 L {3}, break (1c leading) into Circle6 L {3} to places | all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11517, '2019-01-18 11:06:32.674314+00', '2021-02-19 14:44:13.843649+00', 9824, 2, 20978, 'ace', '

_Strathspey_



1-2::

  All set to ptnr on side

3-4::

  turn ptnr RH to bring L into middle

5-6::

  L dance LH across moving 2 pl a/cw (while M) dance 1 pl c/w rnd outside

7-8::

  All turn ptnr to finish M in middle L outside facing ptnr

9-10::

  All set adv passing ptnr on 2nd step

11-12::

  moving to R all dance curing travelling steps to finish facing ptnr

13-14::

  M Highland rocking step L Glasgow Highlanders step

17-24::

  Triple reels:-  

  Passing RSh with ptnr all L dance on curve into middle LH across dance out curving moving on one pl c/w then curve into middle & face out (while M) follow dancing on curve through ptnrs pl to begin M finish on outside having moved on 1 pl facing ptnr

25-28::

  All turn ptnr RH once rnd dropping hand M dance rnd outside L curving out to follow M all join hand briefly in circle adv one pl back to original pstn.  

29-32::

  All turn ptnr BH to finish facing each other.  



_Jig_  



1-8::

  as Strathspey 1-8

9-12::

  Do-si-do with ptnr

13-16::

  Highland setting step and point

17-24::

  Triple reels

25-26::

  Turn ptnr RH once rnd

27-28::

  L LH across dance two pl ac/w (while M) dance one pl c/w rnd outside

29-32::

  All turn ptnr pivot turn to finish L in middle facing out M outside facing in.

 ', 0);
INSERT INTO 'dancecrib' VALUES (10811, '2018-06-02 15:01:57.862215+00', '2018-08-06 06:34:43.318358+00', 15414, 1, 202, 'ace', '1--::
  1c+2c Espagnole. On [5-8], 1c turn P LH 1½ to 2plx facing out (2,1x,3)
9--::
  Reels3 on sidelines, 1c Lsh to 2cnrs (2,1x,3)
17--::
  1c loop Lsh round 2cnrs, cross RH up/dn, loop Rsh round 4cnrs to 2pl (2,1,3)
25--::
  Circle6 and back (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (10814, '2018-06-03 05:57:09.210774+00', '2018-08-06 06:35:32.332256+00', 16029, 1, 202, 'ace', '*3c & 4c start on opposite sides*
1--::
  1c+2c & 3c+4c RHA (to 1,2,3x,4x) ; 2c+3c LHA, finish 2W+3M (2M+3W) facing up(dn)
9--::
  Reels3 across in tandem, 2W+3M (2M+3W) Lsh to 1M(4M) (1,3x,2,4x)
17--::
  3c+2c S& Link (to 1,2,3x,4x) ; 1c & 3c set | cross RH, 1c face out (1x,2,3,4x)
25--::
  1c cast to 4pl (2c+3c+4c up) ; all turn P RH (2,3,4x,1x)', 5);
INSERT INTO 'dancecrib' VALUES (12888, '2020-06-14 13:05:54.023056+00', '2021-10-05 10:50:08.840909+00', 12511, 1, 1645, 'ace', '1-::

  1c+5c+6c+3c parallel RSh Reels4 up/down, 5c & 6c end passing RSh

9-::

  1c+5c & 6c+3c RHA ; 5c+6c 1&frac14; LHA to face 4c/2c

17-::

  2c+6c+5c+4c parallel RSh Reels4, end facing same person, 1c & 3c face P

25-::

  *4 changes of Grand Chain for 6 at top & bottom:* 1c, 3c, 2c+6c & 5c+4c, facing across, change pl RH | 2c+4c, facing across, change pl LH in centre _while_ others change LH at corners ; repeat [25-28] to (4M+2W,5,2M+4W,6,1x,3x) with 1c & 3c facing sides, BtoB with P

33-::

  1c & 3c loop RSh round facing person ; turn P 1&frac12; RH & face original place (4M+2W,5,2M+4W,6,1,3)

41-::

  2W & 4W cast &frac12; way round clw ; 4c & 2c turn P RH (4,5,2,6,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11108, '2018-09-15 04:13:50.454583+00', '2018-09-15 09:48:14.236658+00', 7888, 1, 202, 'ace', '1--::

  1c cross RH and cast (2c up) {3}, cross LH, meet below 3c {3} dance up to 2plx and face out {2} (2,1x,3)

9--::

  1c turn 2c EH,dance down to between 3c {3}, turn 3c EH to 2pl {3} | set (2,1,3)

17--::

  1W+2c & 1M+3c RHA ; 1W+3c & 1M+2c LHA (2,1,3)

25--::

  Circle6 and back

', 2);
INSERT INTO 'dancecrib' VALUES (11823, '2019-05-04 07:17:11.804984+00', '2019-05-04 10:11:18.804113+00', 19283, 1, 202, 'ace', '1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; ½ Fig8 round nearest ends (2,1,4,3)

9--::

  1c+4c S&Link and face clw _while{4}_ 2c & 3c turn P RH ; all chase clw ½ (3x,1x,4x,2x)

17--::

  3c+1c & 4c+2c RHA ; all chase clw ½ (2,4,1,3)

25--::

  All NHJ set | all La Baratte (2x,4x,1x,3x)

33--::

  2c+4c & 1c+3c chase cclw ½. Middles face ends on sides ; all turn LH 1 ½ on sides (2,4,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (10808, '2018-06-01 13:02:22.592143+00', '2018-06-01 13:02:46.288047+00', 16617, 1, 202, 'ace', '1--::

  All A{1}&R{1} | set passing Lsh ; cast R to own place | turn P BH (1,2,3)

9--::

  1c dance down | set to P _while{4}_ 2c stand still | cross up to 1plx ; dance up and loop Rsh, 1M(1W) round 2W(2M) to 2pl (2x,1,3)

17--::

  ½ Parallel Reels3 on sidelines, 1c Lsh to 3c (to 3,1,2x) ; 3M turn 1W LH 1½ _ while{4}_ 1M & 3W chase clw ½ to exchanged places (1x,3x,2x)

25--::

  3C S&Link twice', 2);
INSERT INTO 'dancecrib' VALUES (10812, '2018-06-02 17:34:37.22768+00', '2018-06-02 17:34:49.809323+00', 16027, 1, 202, 'ace', '1--::

  1M+3W with 2c & 1W+3M with 4c ½ Fig8 to centre ; 1c+3c RHA, pivoting R to face sides

9--::

  Parallel Reels4

17--::

  3W+1M & 1W+3M »S&Link BtoB« twice [LH person to RH place, RH person to place behind, repeat so cpls have changed places] _while{8}_ 2c & 4c S&Link twice

25--::

  3W+1M & 1W+3M dance out through sides ; turn P RH 1½ to original places

33--::

  2c & 4c repeat [1-32] ', 2);
INSERT INTO 'dancecrib' VALUES (10809, '2018-06-01 13:49:25.853206+00', '2018-06-01 13:55:59.488168+00', 15342, 1, 202, 'ace', '1--::

  1c+2c set | 1c cast as 2c dance up to 1pl taking NH briefly ; 1c ½ Fig8 R round 1cnrs to 2plx facing 2cnrs (2,1x,3)

9--::

  Reels3 on sidelines, 1c Rsh to 2cnrs (2,1x,3)

17--::

  1c ½ Fig8 R round 3cnrs to 2pl ; all turn P RH (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10810, '2018-06-01 14:17:21.802743+00', '2018-06-01 14:22:53.406998+00', 15343, 1, 202, 'ace', '1--::

  1c set | cross RH ; cast (2c up) | turn LH ¾, Lsh to P facing opposite side (2,*1*,3)

9--::

  1W+2c & 1M + 3c RHA ; Lsh »Snake Pass« [[unwind the RHA, 1c leading, pass other snake Lsh through 2plx and chase cclw], 1c Rsh to P facing opposite side (3x,*1*,2x)

17--::

  1W+2c & 1M + 3c LHA ; Rsh »Snake Pass« [[unwind the LHA, 1c leading, pass other snake Rsh through 2plx and chase clw], (2,1,3)

25--::

  ½ Reels3 across, Rsh to 2cnrs ; ½ Reels3 across, Rsh to 4cnrs[pos] (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10813, '2018-06-03 05:22:17.858407+00', '2018-06-03 05:22:52.797433+00', 16028, 1, 202, 'ace', '1--::

  1c & 3c set | 1c cast to 3pl and lead up *LH* to face 1cnrs _while{6}_ 3c dance up to 1pl and cast back to 3pl (2c up) (2,*1*,3)

9--::

  ½ Reel4 on 1diag, pass Rsh ; ½ Reel4 on 2 diag, 1c in 2plx facing 1cnrs[pos] (3x,1x,2x)

17--::

  All chase clw ½ ; turn P RH (or Birl) (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10815, '2018-06-03 07:59:48.223549+00', '2018-06-03 08:06:05.587368+00', 16031, 1, 202, 'ace', '1--::

  1c lead down (2c up) | turn P RH ¾, retain RH ; set, 1W pivoting R under 1M''s arm | 1W leading dance up to face 2W (2,*1*,3)

9--::

  Rsh Reel3 in tandem (with lead change) on 2diag, 1c finish facing 2M, 1W leading

17--::

  *Lsh* Reel3 in tandem (with lead change) on 1diag, 1c finish in centre on own sides facing up NHJ (2,*1*,3)

25--::

  1c dance up, cast to 2pl ; all turn P RH (2,1,3) ', 2);
INSERT INTO 'dancecrib' VALUES (11109, '2018-09-15 14:31:25.738501+00', '2018-09-15 14:35:18.030919+00', 3413, 1, 202, 'ace', '1--::

  1c+2c ½ R&L ; 1c+3c ½ R&L (2x,3x,1)

9--::

  1c set | dance to top (3c down) ; cross and cast to 2plx (2x,1x,3x)

17--::

  ½ Reels3 across, 1c LSh to 3cnrs[pos] ; ½ Reels3 on sidelines, 1c RSh to 4cnrs[pos] (3,1,2)

25--::

  ½ Circle6 L ; all set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11253, '2018-10-06 08:25:44.621274+00', '2019-02-12 14:55:48.863519+00', 18818, 1, 202, 'ace', '1--::
  1c turn BH | 1c+2c Circle4 L | 1c cast to 2pl facing in and down _as_ 2c dance up to 1pl and face out (2,1,3)
9--::
  Mirror Reels3 on sidelines, 1c in and down, 3c casting. 1c face 1cnrs (2,1,3)
17--::
  Corners Pass and Turn. 1c in 2pl face out (2,1,3)
25--::
  3C Chain Progression (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (10510, '2018-03-13 23:07:52.753604+00', '2018-09-19 09:43:44.115811+00', 18260, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c S&Rotate (2,1,4,3)

9--::

  1c+4c DblFig8, 1c cross to start

17--::

  Mirror Reels4 on sidelines (W Rsh, M Lsh)

25--::

  1c+4c ½ R&L (to 2,4x,1x,3) ; 4c & 1c ½ Fig8 round nearest ends (2,4,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3266, '2012-01-22 19:30:18.202906+00', '2022-10-24 12:42:37.849825+00', 6098, 1, NULL, 'ace', '1–::

  1M+2W set adv. | turn BH to places ; 1W+2M repeat

9–::

  1c lead between 3c (2c up) cross and cast up to (2,1x,3) ; 2c+1c R&L (1 bar/hand), 1c face 1cnr

17–::

  Set to and turn cnrs, finish facing W side, 1W above 1M

25–::

  1c dance out, split and cast round 2W/3W, turn BH and face M side, 1W above 1M ; dance out, split and cast round 2M/3M, turn LH to (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11824, '2019-05-04 12:39:21.594487+00', '2019-05-04 12:48:32.933853+00', 16817, 1, NULL, 'ace', '1--::

  All set | cross RH ; All set | 1c+3c cross _while_ 2c turn BH to face 1cnr

9--::

  2c+1cns Corners pass and turn (BH turn), pass Rsh to face 2cnrs ; repeat with 2cnrs, 2c pass Rsh to (1,2,3)

17--::

  1c+2c Espagnole, 1c finishes and 3c step in for (2,1,3) 

25--::

  1c+3c ½ Poussette ; All turn P BH (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (12895, '2020-06-24 09:31:22.48558+00', '2020-06-25 06:09:22.477418+00', 20033, 2, 10819, 'ace', '2C is dancing couple.

1-4:: 2C (giving LS to pass) with 1M+3L dance 1/2 reel of four, 2C finishing between couples, 1M facing up, 1L facing down.

5-8:: All set and link for three to sidelines.

9-12:: All set and link for three to lines across (M facing down, L facing up).

13-16:: 2C (giving LS to pass) with 3M+1L dance 1/2 reel of four (to 1, 2, 3 own side).

17-20:: 2C dance RS around one another with no hands for two bars, then TB to finish facing 3rd corner position.

21-24:: 1/2 reel on first diagonal, 2C finishing between couples, M facing down, L facing up.

25-32:: Repeat movement of bars 17-24 from new positions: 2C dance RS around one another with no hands for two bars, then continue TB to finish facing 2nd corner position. 1/2 reel on the second diagonal (to 3, 2, 1 on opp. side).

33-34:: All 1/2 TB, 3C+2C stay in center facing down, 1C dance out to sidelines.

35-40:: 2C, followed by 3C, dance down the middle NHJ, cast up behind the standing 1C and dance up (to 2, 3, 1).', 5);
INSERT INTO 'dancecrib' VALUES (10820, '2018-06-04 23:42:53.927685+00', '2019-02-04 09:58:52.941804+00', 15729, 1, 202, 'ace', '1--::

  All turn P RH ; 1c cast (2c up and face down) | 1c cross LH and face up (2,1x,3)

9--::

  2c+1c set | turn RH on sidelines ; 1c+3c set | turn LH on sidelines (2,1x,3)

17--::

  Parallel Reels3{6} on sidelines, 1c Rsh to 2c | 1c cross RH, (2c & 3c step in) all into promhold (2,1,3)

25--::

  3C Promenade (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11110, '2018-09-15 14:57:41.587073+00', '2019-03-11 18:10:33.307041+00', 5413, 1, 202, 'ace', '1--::

  All cross RH | set ; repeat [1-4] (1,2,3)

9--::

  1c+3c DblFig8, 1c cross down _as_ 3c cast up to start (1,2,3)

17--::

  1c+2c ½ R&L (to 2x,1x,3) ; 2c+1c turn P 1½, 2c to 1pl, 1c into Allemande hold _while{4}_ 3c turn RH into Allemande hold

25--::

  1c+3c Allemande (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11111, '2018-09-15 15:56:32.24293+00', '2018-09-22 14:41:53.984351+00', 18587, 1, NULL, 'ace', '1--::

  Circle6 and back

9--::

  1c cross down into mirror Reels3 on opp. side, at end 1c turn RH ½ and face down RHJ (1,2,3) 

17--::

  1c + 2c following lead down ; 1c lead to 1pl _while{4}_ 2c split and dance to 3pl, 3c dancing up to 2pl on [23-24] (1,3,2)

25--::

  4 bars of 3C Allemande, into ; All turn P LH (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (14069, '2021-06-15 10:42:06.715408+00', '2021-06-15 10:44:46.455427+00', 6292, 1, 202, 'ace', '1--::

  1c lead down ; lead up (1,2)

9--::

  1c+2c set | ½ RHA ; 2c+1c set | ½ LHA (1,2)

17--::

  1c set | cast off (2c up) ; 1c turn P RH (2,1)

25--::

  2c+1c R&L (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (10819, '2018-06-04 12:39:02.806254+00', '2018-06-04 12:42:23.454556+00', 15727, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; turn LH 1¼ to face 1cnrs (2,*1*,3)

9--::

  Corner Chain on 1diag, 1c face 2cnrs

17--::

  Corner Chain on 2diag. On [23-24], 1c turn LH 1¼ to between ends facing 3cnrs

25--::

  Reels3{6} across, 1c Lsh to 3cnrs | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11825, '2019-05-04 13:16:23.514871+00', '2019-05-04 13:16:23.514871+00', 19284, 2, NULL, 'ace', '1- 8::

  1s dance RSh reels of 3 on own sides

9-16::

  1s+2s+3s circle to the left, LH across back to place

17-24::

  1s lead down the middle & back (1s end facing 1st corners)

25-32::

  1s set & turn 1st corners 2H, set & turn 2nd corners 2H (1s end between 2s & 3s on opposite sides, 1L face up, 1M face down)

33-40::

  LSh reel of 3 on opp sides

41-48::

  2s+1s+3s Ret & Adv, 1s turn RH 1.1/2 times back to own side 2nd place



', 4);
INSERT INTO 'dancecrib' VALUES (10821, '2018-06-05 15:19:23.691246+00', '2019-02-03 21:12:52.35336+00', 18365, 1, 202, 'ace', '1--::

  1c Petronella turn | set ; 1 M pivot R to between 3c _while{2}_ 1W dance down (2c up on [5-6]), into two facing lines of 3 across | all set

9--::

  Reels3 on sidelines, 1c Lsh to 2cnrs, finish BtoB facing 1cnrs (2,*1*,3)

17--::

  Corners Pass and Turn on 1diag. On [20], 1c pull Rsh back to face 4cnrs ; Corners Pass and Turn on 2diag (2,1,3)

25--::

  1c+3c Tourbillon (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (3293, '2012-01-22 19:30:19.327801+00', '2020-12-17 22:36:18.639729+00', 6197, 1, NULL, 'ace', '{{explanation}}

On 2nd chord, 4c+5c+6c cross to opposite sides. The dance is centro-symmetrical ; we will use »centre« and »ends« rather than »top« and »bottom«, »off« means towards the centre.



1–::

  1c+6c cross RH, cast »off« one (2c+5c to ends) ; ½Fig8 round the nearest centre couple (to 2,1,3,4x,6x,5x)

9–::

  Two Reels3{6} on each sideline, 1c+6c starting in and towards end, and 3c+4c casting into the reel | all three pairs on each sideline make a full turn (easy hand at the ends, BH in the middle)

17–::

  1c+6c ½ Fig8 round nearest end couple _while{4}_ 3c+4c circle4 L ; all C turn RH ½  to face up/down in pairs, all set (2x,1,3x,4,6x,5)

25–::

  Double 3c Allemande: the first step to the right separates the two threes, the leading couples do not pass each other, the others fall in behind (to 5,4,1,6x,3x,2x)



{{explanation}}

The progression returns dancers to places after 3 times through', 2);
INSERT INTO 'dancecrib' VALUES (12964, '2020-07-19 00:37:06.252344+00', '2020-07-19 09:48:07.449784+00', 19789, 1, 202, 'ace', '1--::
  Mirror Reels3 on sides, 1c crossing down to 2plx. On [7-8] 1c & 2c continue the reel. 1c in 2plx face out (2,1x,3)
9--::
  1c turn 3c EH and cross up to 2pl ; 1c turn 2c EH and cross down to 2plx facing out (2,1x,3)
17--::
  1c cast off round 3c, lead up to top, cross and cast to 2pl (2,1,3)
25--::
  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (11826, '2019-05-04 23:40:34.824141+00', '2019-05-04 23:54:42.202522+00', 19286, 1, NULL, 'ace', '1--::

  1c set | ½ Fig8 down | set (1x,2)

9--::

  2c set | ½ Fig8 up | set (1x,2x)

17--::

  2c with 1c following dance down, all change sides, W passing above M and under joined arms, and up (1,2) 

25--::

  1c+2c Poussette (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (11112, '2018-09-15 16:32:38.18062+00', '2021-04-04 11:38:19.106112+00', 6890, 1, 202, 'ace', '1--::

  All set twice ; turn P BH twice into Allemande hold (1,2,3)

9--::

  3C Allemande (3,2,1)

17--::

  2c+1c facing down/up set | change places, M(W) with R(L)H ; ½ Mirror Reels3 on sidelines, 1c in and up to start (2,1,3)

25--::

  1M+3c & 1W+2c RHA, pass RSh ; 1M+2c & 1W+3c LHA (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (9578, '2017-02-01 00:39:14.9336+00', '2017-02-01 00:39:14.9336+00', 13311, 1, NULL, 'ace', '1--::

  1c+2L & 1M+3c RHA ; 1c+3c chase clw ½ round _while{4}_ 1c turn LH 1½, finish 1M facing 1cnr (pos) with 1W behind

9--::

  1c+1cnrs ½ Rsh lead-change diag. Reel3 ; 1c+2cnrs ½ Rsh lead-change diag. Reel3 (1,2,3)

17--::

  All A&R ; All dance Rsh once round P to finish in the middle for 

25--::

  3C Poussette (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (12968, '2020-07-20 07:47:49.17571+00', '2020-07-20 11:48:12.483538+00', 19148, 1, 202, 'ace', '1--::
  1W (1M following) casts off to 2plx (2c up) ; 1M (1W following) casts off to 3pl (3c up) (2,3,1)
9--::
  1c dance up to top, into Mirror Fig8 on sides then face 1cnrs (3c down on [15-16])
17--::
  1c turn 1cnrs LH, dance LSh round 2cnrs into facing lines3 across ; 1c turn P RH ¾ to 2pl _while{4}_ 2c & 3c turn opposite person RH (2,1,3)
25--::
  Circle6 and back (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (13674, '2021-02-20 13:33:29.173684+00', '2021-02-20 13:46:55.231327+00', 17726, 1, 202, 'ace', '1--::
  1c lead down {3}, lead up {3} and cast off (2c up) (2,1,3)
9--::
  1c+3c RHA ; LHA (2,1,3)
17--::
  All turn P RH ; turn P LH (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (9565, '2017-01-27 17:23:33.17753+00', '2017-01-27 17:25:46.348314+00', 15007, 2, 160, 'ace', '1-8::
  1C 3C cross LH, 1L 2M also 2L 3M turn RH 1_1/4  ; 1L 3M turn  LH once round, and dance on - 3M into 1M’s pl. and 1L into 3Ls pl. + face out.
9-16::
  Half Reel 3 on sides - 1L 3M pass 2C by Lsh to begin ; join hands on sides - all set and cross RH with opposite. (1Lx 3L in top pl. + 1M 3Mx in 3pl.)
17-24::
  3L 1L cross LH as do 1M 3M, 3L 1M turn 2C RH 1_1/4 ;1M 3L turn LH and dance on  into original places + face out. (1 2x 3).
25-32::
  Half Reel 3 on sides. 3L 1M pass 2C by Lsh to begin ; join hands on sides - all set and cross over giving RH to partner. (3x, 2, 1x)
33-40::
  All chase CW half round (1, 2x, 3) ; 1C cast to 2pl as 2C cross up to top place as 3C set, all set.', 3);
INSERT INTO 'dancecrib' VALUES (11113, '2018-09-15 16:47:49.491931+00', '2018-09-15 16:58:08.850788+00', 18588, 1, NULL, 'ace', '1--::

  All set | 1c+2c & 3c+4c ¾  Lefts and Rights (2,1,4x,3x)

9--::

  1c+4c ½ RHA | lead out the end RHJ, cross and cast in to face cnr diagonally (2,4x,1,3x)

17--::

  Double "Hello & Goodbye", finish facing opp. cnr diagonally (2,1x,4,3x)

25--::

  1c+4c dancing out the ends turn cnr EH, to sidelines ; 1c+4c S&Link (2,4,1x,3x)



', 3);
INSERT INTO 'dancecrib' VALUES (10822, '2018-06-06 21:22:36.724883+00', '2019-08-26 08:01:45.342244+00', 5509, 2, 160, 'ace', '1-8::

  1s cross, cast (2x up); 2s 1s turn RHx1 - 2s face out  and 1s face up in prom. hold.

9-16::

  Rsh Prom. Reel3 across with 2s. Finish in line of 4, 1s facing up betwn 2s facing down.

17-24::

  All set, 1s turn 2s 1/2 way; all set, 1s turn 2s 3/4 - 1s at top face out on wrong side.

25-32::

  1s 2s dance 3/4 fig, 8, all set.', 0);
INSERT INTO 'dancecrib' VALUES (11114, '2018-09-15 21:26:40.406471+00', '2020-10-22 20:37:48.212352+00', 17181, 2, 19283, 'ace', '1-8::

  1s dance in and cast, 1s dance a half figure of eight around 2s

9-16::

  all dance mirror reels of 3 on the side (1s dance in and down, 2s cast to start)

17-24::

  1s lead down and up, remaining in centre in 2nd place and retaining hands

25-32::

  1s cross up through the 2s, 1s cast to 2nd place on own sides, all turn RH

33-40::

  all circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (12591, '2020-02-19 02:07:27.172041+00', '2020-02-19 02:14:49.571226+00', 16892, 1, NULL, 'ace', '*Couples form Big Circle RR, M on L of W*  

1--::

  All A&R to centre ; walk (or slip) clw

9--::

  All A&R to centre ; walk (or slip) cclw and all face P

17--::

  Pass P RH | next LH ; next RH | next LH and meet new P 

25--::

  with new P dance BtoB, giving 2-hands clap to next person beyond on bar 27 ; Turn new P RH and reform circle 

', 2);
INSERT INTO 'dancecrib' VALUES (3103, '2012-01-22 19:30:11.385344+00', '2019-02-12 22:14:03.737509+00', 7293, 1, NULL, 'ace', '1–::

  1c+4c Turn RH | cast to middle (2c+3c step to end) ; RHA finish in the middle facing cnr on the diagonal

9–::

  1c+4c double SetH&G , finish half way round facing other cnr on diagonal

17–::

  Centres turn cnrs RH ½ into St. Andrews Cross, 2c+3c joining LH in the middle | All set ; 1c+4c chase clw ½ round  _while_{4}    2c+3c LHA to sides (1,2,3,4)

25–::

  1c cross down RH | cast behind 3c ; cross LH | cast to 4pl (1c+2c+3c up) (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (9564, '2017-01-27 16:31:30.248186+00', '2017-01-27 17:38:22.193812+00', 15009, 2, 160, 'ace', '1-8::
  1C dance down the middle and up (NHJ)
9-16::
  1C 2C poussette. 1C end B-to-B facing own side.
17-24::
  All set, 1C 3C turn HH once round as 2C set ; all set, 1C 2C turn HH once round as 3C set.
25-32::
  1C dance out the sides, cast behind 3C, dance up the middle, and cast off into 2pl.
', 3);
INSERT INTO 'dancecrib' VALUES (10823, '2018-06-07 08:47:56.700195+00', '2019-08-26 08:01:45.342825+00', 5509, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; 2c & 1c turn P RH, finish 2c facing out, 1c into promhold (1W on 1M''s L) facing up

9--::

  Reel3 across, 1c Rsh to 2W, finish in one line of 4 across, 1C facing up between 2C facing down

17--::

  All set | 1C turn 2C EH ½ ; all set | 1C turn 2C ¾, 1c to 1plx facing out (1x,2)

25--::

  ¾ DblFig8, 1c casting | all set (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2363, '2012-01-22 19:29:33.494535+00', '2018-06-09 11:49:41.515223+00', 9061, 1, NULL, 'ace', '1–::

  1c+2c circle4 L ; S&Link, 1c ends facing down and 2W facing out (2,1,3)

9–::

  Parallel Reels3 on the sides, Lsh to 3c

17–::

  1c set | turn ¾ BH and twirl R into ; 1W+2c & 1M+3c RHA, all finish on midline for

25–::

  2c+1c+3c Allemande (to 3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (9566, '2017-01-28 00:52:13.370664+00', '2017-01-28 00:52:13.370664+00', 8816, 1, NULL, 'ace', '1--::

  1c set adv | turn BH to places ; ½ Fig8 round 2c (1x,2,3)

9--::

  1c ½ Fig8 round 2c ; 1c advance and dance down (2c up) | set advancing past P to face 1cnr

17--::

  1c pass 1cnr Rsh to midline facing in, 1cnrs finish facing out in 2pl own side | 1c pass P LH to end of 1diagonal facing out _while{2}_ both pairs of corner persons change places LH on sides (polite turn) ; 1c and middle dancer on sideline change places LH | All A&R {1+1}  (3,1,2)

25--::

  1c+2c Poussette (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (11828, '2019-05-06 10:14:01.367651+00', '2019-05-06 10:14:23.719816+00', 8770, 2, NULL, 'ace', '1–8::

  1L casts off below 2L while 2M casts up round 1M. 1L, 2M turn RH 1½ to return to place. 

9–16::

  1M casts off below 2M while 2L casts up round 1L. 1M, 2L turn LH 1¼ to face partner on the sides (men facing up, ladies facing down).

17–24::

  1C, 2C change places with a modified poussette movement:  1C progress up the side, 2C progress down the side  ¼ turn  progress across the set  ¼ turn  progress up or down  ¼ turn  into the centre  ¼ turn to fnish in a line in the centre of the set (men facing up, ladies facing down)

25–32::

  2C, 1C dance a reel of 4. All dance out to own sides on bars 31–32, 1M following 2M from the bottom of the reel and 2L following 1L from the top of the reel. ', 2);
INSERT INTO 'dancecrib' VALUES (2997, '2012-01-22 19:30:06.222539+00', '2018-01-22 10:33:16.952426+00', 5207, 1, NULL, 'ace', '1–::

  1c long cast to 3pl _while{4}_ 3c set | dance up to 1pl ; repeat the figure (1,2,3)

9–::

  1c cross below 2c, cast behind 3c (2c up) and lead up to 1cnrs ; set to 1cnrs, to 2cnrs, finish 2plx in middle facing down

17–::

  1c dance between 3c, cross and cast up to 2pl, 2c dance in on [20] ; 2c+1c ½Poussette (1,2,3)

25–::

  1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3360, '2012-01-22 19:30:22.035243+00', '2020-12-17 22:43:44.137606+00', 6424, 1, NULL, 'ace', '1–::

  1c+2c+3c mirror Reels3 on the sides, 1c cross down to start (join hands with P when possible), on [7-8] 2c+1c finish on the midline NHJ, 1c in top place facing M side, 2c below them facing the W side.

9–::

  1c+2c »Poussette with NHJ«: out on [1], ¼ turn | 1c down & 2c up on [3], ¼ turn ; into the middle on [5], W set on the spot _while_ the M dance ½ turn to face P BHJ | 1c ½ turn and open out to face own sides _while_ 2c falls back.

17-28::

  2c+1c+3c »Revolving DTr«: All set | All Petronella turn cclw one place in their triangle ; repeat twice, but the 3rd time 1c set adv towards P for

29-32::

  1c turn RH | cast to 4pl (3c+4c up).



{{explanation}}

Note: On [10] & [12] the M dances slightly backwards to make a sharp ¼ turn', 3);
INSERT INTO 'dancecrib' VALUES (12592, '2020-02-19 05:00:13.649422+00', '2020-02-19 05:23:58.134148+00', 19846, 1, 202, 'ace', '1--::  

  1c cross RH | cast off (2c up) ; 1c+3c RHA (2,1x,3)  

9--::  

  2c+1c La-Chain (2,1x,3)  

17--::  

  1c ½ Fig8 down round 3c ; all turn P RH. 2c into 1pl, 1c & 3c into Allemande hold  

25--::  

  2C Allemande (2,3,1) ', 2);
INSERT INTO 'dancecrib' VALUES (12593, '2020-02-19 12:46:27.678761+00', '2020-02-19 12:51:40.406021+00', 8380, 1, 202, 'ace', '1--::

  1c cast off (2c up) | 2c+1c+3c set ; 1c Petronella turn into facing lines3 across _while{2}_ all cnrs set | all set

9--::

  Reels3 across, 1c RSh to 1cnrs with loops to places (2,1,3)

17-28::

  3C R&L

29-32::

  All turn P RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (1648, '2012-01-22 19:28:52.907958+00', '2018-06-08 22:24:23.763175+00', 9762, 1, NULL, 'ace', '1–::

  1c set | cast off one (2c up) ; dance NHJ between 3c and cast up to 2pl (2,1,3)

9–::

  1c+1cnrs set | set advancing slightly ; 2M+3W turn RH to places _while{4}_  1c swivel R and cast Rsh round 2cnr to 2plx

17–::

  1c+4cnrs set | set advancing slightly ; 2W+3M turn LH to places _while{4}_  1c swivel L and cast Lsh round 3cnr to 2pl (2,1,3)

25–::

  ½Reels3 across, Lsh to 1cnr  ; ½Reels3 across, Lsh to 3cnr pos (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (10485, '2018-03-05 04:54:30.017515+00', '2019-03-27 12:16:30.562606+00', 13488, 1, 202, 'ace', '_Strathspey_

1--::

  1c+2c The Tournée, 1W, followed by 1M, facing 2M at end

9--::

  Tandem Reel3 in 1diag with lead change, 1c finishing in promhold facing 3M 

17--::

  Reel3 in 2diag, 1c finishing in centre LHJ facing down

25--::

  2c+3c R&L up/dn _while{8}_ 1c cross down | cast up ; dance up the middle | cast off (2,1,3,4)



_Reel_

33--:: 

  1c+3c »Typhon« [1M+3W turn RH ¾, face each other, and twirl to progressed places facing out _while{4}_ 1W+3M set diagonally and cast 1 place clw] (to 2,3,1,4) ;  3c turn RH _while{4}_ 1c turn LH, 1W followed by 1M facing 3M at end, ready for a tandem reel with lead change in 1diag (3M+4W)

41-64::

  Repeat [9-32] (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12898, '2020-06-25 06:08:52.684802+00', '2020-06-26 02:32:04.365702+00', 20033, 1, 202, 'ace', '1--::
  2c ½ Reel4 on 1diag into facing lines3 across : 3C S&Link
9--::
  3C S&Link ; 2c ½ Reel4 on 2diag (1,2,3)
17--::
  2c dance RSh round P no hands | turn P BH to face 3cnrs ; ½ Reel4 on 1diag into facing lines3 across
25--::
  2c dance RSh round P no hands | turn P BH to face 2cnrs ; ½ Reel4 on 2diag (3x,2x,1x)
33--::
  All turn P BH ½. 3c & 2c in centre NHJ face down | 2c (3c following) dance down between 1c and cast up to sides (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11116, '2018-09-16 02:46:56.062627+00', '2018-09-17 11:01:20.724056+00', 18610, 1, 202, 'ace', '1--::

  1c+2c Tourbillon (2,1,3,4)

9--::

  2c+1c set | Circle4 L ½ (to 1x,2x,3,4) ; 1c+2c+3c »Set and Mirror Link in tandem« [same as 2C S&Link except that 1c+2c cast in tandem _as_ 3c dance to 1pl and face out] (3,1x,2x,4)

17--::

  Mirror Reels3 in tandem (with lead change) on sidelines, 1c+2c in tandem in and down, 4c out and up to start (3,1x,2x,4)

25--::

  1c+2c+4c »Set and Mirror Link in tandem« (to 3,4,1x,2x) ; 1c+2c set | Circle4 L ½ (3,4,2,1)', 2);
INSERT INTO 'dancecrib' VALUES (1924, '2012-01-22 19:29:10.116521+00', '2021-02-18 11:27:09.993239+00', 9843, 1, NULL, 'ace', '{{explanation}}

Hold the cell phone to your L ear.



1–::

  1c cast off behind own lines and back (it would be proper to phone one''s partner)

9–::

  1c+2c RHA ; 1c cross RH | cast off (2c up) (2,1x,3)

17–::

  1c+3c RHA ; 1c ½ Fig8 round 2c (2,1,3)

25–::

  1c turn 1cnr RH | pass Rsh ; turn 2cnr RH | cross Rsh (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9573, '2017-01-30 23:34:28.136876+00', '2017-01-30 23:34:28.136876+00', 17574, 1, NULL, 'ace', '1--::

  1c cross RH | cast (2c up) ; turn LH to face 1cnr

9--::

  1c+1cnrs ½ Reel4, 1c pass Rsh ; repeat with 2cnrs, (to 3x,1x,2x)

17--::

  All set | All turn P RH (3x,1x,2x) | All M (passing below) turn W under R arm into Allemande hold 

25--::

  3c+1c+2c Allemande (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9574, '2017-01-31 00:22:44.633114+00', '2017-01-31 00:22:44.633114+00', 3357, 2, 1, 'ace', '1–::
  1c&3c set | cross R ; all set | 1c&3c cross R _while_ 2c turn R to face out
9–12::
  1c&3c RH across _while_ 2c dance clw halfway round set
13–16::
  1c&3c dance clw halfway round set _while_ 2c turn R [to 3x,2x,1x]
17–20::
  All set | 3c cast into third pl _while_ 1c&2c dance up 1pl [2x,1x,3x]
21–24::
  All set | cross R
25–::
  Circle6 round & back', 3);
INSERT INTO 'dancecrib' VALUES (11118, '2018-09-17 06:36:42.065089+00', '2018-09-17 06:43:12.197357+00', 2148, 1, 202, 'ace', '1--::

  1c+2c set twice ; ½ R&L (2x,1x)

9--::

  2c+1c repeat [1-8] (1,2)

17--::

  1c lead down ; and up

25--::

  1c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (11830, '2019-05-06 21:32:27.292058+00', '2019-05-06 22:18:46.217493+00', 19288, 2, NULL, 'ace', '*(3rd & 4th couples on opposite side)*    

1-8::

  1st couple dance down the middle and back 

9-10::

  1st and 4th couples cast off/up, as 2nd and 3rd couple step up/down. 

11-14::

  1st and 4th couples dance Right Hands Across in the centre (once plus a tiny fraction extra) to end with ladies facing out the sidelines, men facing out the top/bottom of the set.

15-16::

  1st and 4th couples cast one place to their left, 1M casting left shoulder round 2M, 1L round 2L, 4M round 3M, and 4L round 3L, to end facing in:

17-22::

  1st and 4th couples dance 6 bars of Hello-Goodbye setting, to:

23-24::

  4L and 2L, 1L and 3L turn right hands to sidelines while men dance two further bars of Hello-Goodbye setting. End on side lines in the order 2 4 (1) (3)

25-32::

   All 4 couples circle 8 hands round and back.', 5);
INSERT INTO 'dancecrib' VALUES (9576, '2017-01-31 15:31:29.99698+00', '2017-01-31 15:33:43.584212+00', 15011, 2, 160, 'ace', '1-8::
  1M sets adv. toward 2L (who does not set back), 1L 1M 2M join hands and all set to 2L who sets back; all set again 1M retiring to pl., 1C cast - 2C dance up & curl into top pl.
9-16::
  2C 1C turn BH twice round ; 4 hands round to the Left.
17-24::
  1L repeat bars 1-8 (2C casts).
25-32::
  1C 2C Knot.', 3);
INSERT INTO 'dancecrib' VALUES (9577, '2017-01-31 15:50:52.357003+00', '2017-01-31 15:50:52.357003+00', 15012, 2, 160, 'ace', '1-8::
  Dance down 2pl, cast up and cross to face 1crnr [4] ; Half reel4 to face 3rd crnr.
9-16::
  set to 3rd crnrs, turn BH to lines across - 1M btwn 2C + 1L btwn 3C ; 1C pass Lsh, cast R and pass Lsh to face 2nd crnr.
17-24::
  1C 2nd crnr half reel4 to face 4th crnr. ; set to 4th crnr, turn BH to end on sides.
25-32::
  Diagonal R&L - L up M down.', 3);
INSERT INTO 'dancecrib' VALUES (11832, '2019-05-06 22:02:51.017166+00', '2019-05-06 22:24:16.612578+00', 19288, 1, NULL, 'ace', '*Start (1,2,3x,4x)*

1--::

  1c dance down ; and back

9--::

  1c+4c cast inwards (2c+3c to ends) | 1c+4c RHA and a bit, and all face out, W on the sides and M at the ends | 1c+4c cast L one place and face in

17--::

  1c+4c 6bars of setting H&G | 4W+2W & 1W+3W turn RH _while{2}_ 1M+4M dance on H&G, finish (2,4,1x,3x)

25--::

  Circle8 and back

', 3);
INSERT INTO 'dancecrib' VALUES (13672, '2021-02-20 10:11:01.221247+00', '2021-02-20 13:48:29.264182+00', 17720, 1, 202, 'ace', '1--::
  All RHA ; releasing hands, all chase to places
9--::
  All A&R ; all turn opposite person BH
17--::
  Each line Circle3 L ; then RHA to places
25--::
  All A&R ; All pass opposite person RSh and meet new lines', 5);
INSERT INTO 'dancecrib' VALUES (12513, '2020-01-17 22:08:40.859519+00', '2020-04-18 22:54:34.411219+00', 18597, 1, NULL, 'ace', '*(Start (1,2,3x,4x)*

1--::

  1c+4c set | cast to middle (2c+3c to ends) ; in promhold dance out own end and cast R round end of 2diag (1W & 4W starting positions)

9--::

  2c+4c(promhold) & 1c(promhold)+3c ½ Rsh Reels3 acrosss ; repeat at other end (1c up, 4c down), finish in 2pl+3pl, 1c on W side and 4c on M side  

17--::

  1c+4c set | ½ RHA ; 1W+4W A&R _while{4}_ 4M+1M set and change places RH (2,1,4x,3x)

25--::

  Circle8 and back (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (2171, '2012-01-22 19:29:23.724245+00', '2019-01-05 23:24:20.457859+00', 2484, 1, NULL, 'ace', '1–::

  All circle8 and back

9–::

  1c+3c advance NHJ | take corner with free hand and retire into longwise set across ; ½Reels4 on sides

17–::

  ½ R&L at each end (start across) ; both pairs of dancers at the ends and both middle pairs of the sidelines turn RH 1½ to form a square set, (ends to 2pl/4pl, middles to 1pl/3pl)

25–::

  All W petronella to next W place cclw | all W set ; repeat, finishing next to P, and face out on last step (2,3,4,1)

33-48::

  Schiehallion reels (to 2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (11575, '2019-02-14 09:20:25.529617+00', '2019-02-22 23:16:54.136118+00', 19185, 1, NULL, 'ace', '1--::

  All set | turn BH to face down NHJ ; dance down | lead up and take promhold

9--::

  6 bars of 3C Allemande | 3c+1c cast outwards away from P and dance a small loop to the sideline _while{2}_ 2c turn LH to face 1cnr

17--::

  3c+2W & 2M+1c Reels3 across (Lsh to 1cnr) (3,2,1)

25--::

  2c dance down and cast up round 1c into middle ; 3c (start outwards) turn 2c EH 1½ (2,3,1)

', 4);
INSERT INTO 'dancecrib' VALUES (7830, '2013-08-21 08:31:49.337915+00', '2023-02-04 01:23:04.418622+00', 8203, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 on own sides (dancing in & down to start)
9-16::
    3s dance Figs of 8 on own sides (dancing in & up to start)
17-24::
    1s+2s+3s turn RH, turn LH
25-32::
    1s slip step down for 4 steps & back up to top, 1s cast to bottom as
    2s+3s+4s step up', 0);
INSERT INTO 'dancecrib' VALUES (15242, '2022-11-10 09:02:46.825142+00', '2022-11-10 09:04:48.242669+00', 20639, 1, 1645, 'ace', '1--::
  1c set | cast off below 3c ; dance up to top | cast off to 2pl facing in  
  _while{8}_ 2c stand{2} | set ; cast off below 3c | dance up to 1pl facing out  
  _while{8}_ 3c stand{4} ; set | set turning to face out in 3pl (2,1,3)
9--::
  Mirror Reels3 on sides, 1c start in & down
17--::
  2W+1W+3W set | advance ; retire | set  
  _while{8}_ 2M+1M+3M stand | set ; advance | retire
25--::
  1M sets | petronella to between 3c | 1M+3c set | advance  
  _while{8}_ 1W stands | sets ; petronella to between 2c | 1W+2c set
33--::
  1M+3c retire | 1M advances _while{4}_ 1W+2c advance | retire ; 1W followed by P casts round 2M & crosses to own side (2,1,3)
::
  *NB Crib derived from the video*
', 2);
INSERT INTO 'dancecrib' VALUES (11119, '2018-09-17 12:39:01.815671+00', '2018-09-17 12:48:56.843706+00', 4252, 1, 202, 'ace', '1--::

  1c+2c ½ R&L ; 1c+3c ½ R&L (2x,3x,1)

9--::

  1M+3M cross RH | 1W+3W cross RH (to 2x,1x,3) ; 1W+2M cross RH | 1M+2W cross RH (1,2,3)

17--::

  All set | 1c cast (2c lead to 1pl) _as_ 3c set (to 2,1,3) ; 1c lead between 3c and cast to 2pl (2,1,3)

25--::

  Reels3 across, 1c LSh to 1cnrs (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11835, '2019-05-06 23:52:23.175871+00', '2019-05-13 13:29:21.897184+00', 19291, 1, NULL, 'ace', '1--::

  1c set | turn RH ; cast off (2c up) | cross RH (2,1x,3)

9--::

  Circle6 and back

17--::

  1c La Baratte | set passing Lsh to face 1cnr

25--::

  Turn 1cnr RH and pass Rsh ; turn 2cnr RH and cross to own side (2,1,3)

33--::

  All lead down ; and back, staying in the middle for (2,1,3)

41--::

  3C Allemande (3,1,2)

', 5);
INSERT INTO 'dancecrib' VALUES (13670, '2021-02-19 20:18:42.478959+00', '2021-02-19 20:25:01.948379+00', 1990, 1, 202, 'ace', '1--::

  All set | turn P BH into 2 Reels4 position in the middle ; ½ Mirror Reels4, 1c & 3 c in and down, 2c & 4c out and up, to sides. 1c & 3c face outward, 2c & 4c face inward (4,3,2,1)

9--::

  4c+3c & 2c+1c DblFig8, 4c & 2c crossing down (4,3,2,1)

17--::

  4c & 2c set | turn P BH | 4c cast to 3pl _while{2}_ 2c lead to 1pl (2,3,4,1)

25--::

  2c+3c & 4c+1c R&L (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11836, '2019-05-08 12:01:38.85197+00', '2023-02-16 11:16:36.142458+00', 17803, 1, 202, 'ace', '1--::
  1c dance down | turn 3c EH (2c step up and face down) ; dance up | turn 2c EH and face 1cnrs
9--::
  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag and face 3cnrs[pos]
17-28::
  Dance to Corners and Set. On [28] 1c finish in middle RSh to P facing opp sides
29-32::
  1c turn P RH ¾ to 2pl | all set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11123, '2018-09-17 18:57:21.875454+00', '2018-09-17 22:25:40.403926+00', 18624, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) | turn RH 1½ to face 2cnrs

9--::

  1c+2cnrs set | turn RH ; ½ Reel3 on sidelines, 1c LSh to 1cnrs, end BtoB facing 1cnrs

17--::

  1c+1cnrs set | turn RH ; ½ Reel3 on sidelines, 1c LSh to 2cnrs into lines3 across

25--::

  1c set | turn RH ¾ ; 1c lead down (3c up) | all turn RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11120, '2018-09-17 15:00:43.134985+00', '2018-09-18 03:35:15.638678+00', 18612, 1, NULL, 'ace', '1--::

  1c+3c DblFig8 round 2c, 1c cross and 3c cast to start

9--::

  1c (1W leading) dance down the middle, dance Rsh round P (2c up) and dance up, M leading, to (2,1x,3)

17--::

  Mirror reels3 on the sides, 1c out and up 

25--::

  Cnrs pass and gypsy: [as Cnrs Pass & Turn, but no hands]', 3);
INSERT INTO 'dancecrib' VALUES (14350, '2021-10-04 23:08:24.952763+00', '2021-10-05 15:58:14.501516+00', 20499, 1, 202, 'ace', '1--::

  1c dance down (2c up) ; turn inwards on [5] and dance up to 2pl (2,1,3)

9--::

  Mirror Reels3 on sides, 1c out and up, 2c in and down, giving hands where possible

17--::

  1c dance to top | cast to 2pl ; turn P RH 1½ to face 1cnrs

25--::

  *Interrupted H&G Setting* : 1c SetH&G to 1cnrs | turn P RH ¾ to face 2cnrs ; SetH&G to 2cnrs | turn P RH to 2pl (2,1,3)



*Deviser''s note* : On 25-32 in lieu of turning partner RH, 1C may twiddle or other free-form move to next position, but make sure you do it in 2 bars and that your partner has agreed. Or not.', 5);
INSERT INTO 'dancecrib' VALUES (12515, '2020-01-18 09:01:29.839629+00', '2020-01-18 09:22:20.39621+00', 17983, 1, NULL, 'ace', '1--::

  1c cast to bottom, Turn RH, cast to top (1,2,3,4)

9--::

  1c+2c & 3c+4c RHA ; LHA 

17--::

  All keeping NHJ in circle, 1c dances under 4c arch, the others following, and 1c dances to top with all passing under the 1c arch (1,2,3,4)

25--::

  1c cast to 4pl (2c+3c+4c up) ; 1c birl (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (13465, '2020-12-18 13:19:58.483785+00', '2020-12-18 13:23:31.952469+00', 10691, 1, 202, 'ace', '1--::

  1c lead down {3}, lead up {3} | cast off (2c up) (2,1,3)

9--::

  2c+1W & 1M+3c RHA ; 1c turn P LH and face 1cnrs

17--::

  Set to And Turn Corners (2,1x,3)

25--::

  Reels3 on sides {6}, 1c LSh to 1cnrs | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1657, '2012-01-22 19:28:53.378581+00', '2017-02-01 15:27:29.420213+00', 144, 1, NULL, 'ace', '1–::

  1M followed by 1W cast off one, cross below 2M to 2plx ; 1M dances Rsh round 3W _while{4}_ 1W dances Rsh round 3M  (2c up) (2,1x,3)

9–::

   2c+1c+3c Reels3 on sides (1c Lsh to 2c) (2,1x,3)

17–::

  2c+1c L-Chain

25–::

  1c ½ Fig8 up round 2c ; 1c Turn RH (2,1,3)













', 3);
INSERT INTO 'dancecrib' VALUES (9531, '2016-12-19 23:12:44.541287+00', '2017-02-02 14:14:03.214018+00', 17459, 1, NULL, 'ace', '1--::

  1c long cast to 2pl (2c up) ; dance between 3c and cast up (2,1,3)

9--::

  2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA, finish 2c in 1pl facing 3c in 3pl, both NHJ, and 1c BtoB in middle, M facing up, W down 

17--::

  All set | 2c+3c, making arches, dance to meet as 1c dance under, finish 1c (in 1pl/3pl) facing P on midline and 2c+3c BtoB in middle, NHJ ; All set | 2c+3c making arches dance to ends, and cast into the reel  _while{2}_ 1c dance under arch passing P Lsh and finish between end cpl, facing 1cnr

25--::

  2c+1W & 1M+3c Lsh Reels3{6} across (2c+3c with loops) (to 2,1,3) | All set 



*Note: after 2nd time through 1c may repeat [1-4] to get to 4pl.*

', 3);
INSERT INTO 'dancecrib' VALUES (9579, '2017-02-02 18:13:03.303418+00', '2017-02-02 18:13:03.303418+00', 13049, 1, NULL, 'ace', '1--::

  1W, with 1M following, cast off 2 places and cross (2c+3c cross up one place LH) (2x,3x,1x,4) ; 1c+3c RHA finishing 1c (1W leading) facing 3W

9--::

  3W+1c+4W ½ Rsh diagonal lead-change Reel3 (1M, with 1W behind, now faces 4M) ; 3M+1c+4M ½ Rsh Diag. lead-change Reel3 (2x,4x,1,3)

17--::

  1W with 1M following cast up one and cross (4c down) (2x,1x,4x,3) ; 2c+1c RHA 

25--::

  2W+1c+4M ½ Rsh diagonal lead-change Reel3 (1M, with 1W behind, now faces 4W) ; 2M+1c+4W ½ Rsh Diag. lead-change Reel3 (4,1,2,3)', 5);
INSERT INTO 'dancecrib' VALUES (3397, '2012-01-22 19:30:23.667409+00', '2020-12-18 20:09:08.391735+00', 6599, 1, NULL, 'ace', '1–::

  1c+2c set twice ; 1M turns 2W BH (on W side) _while{4}_ 1W (passing in front) turns 2M BH (on M side), finish in own places

9–::

  1c+2c+3c Rsh Reels3{6} | 1c+2c change places Rsh (2,1,3)

17–::

  2c+1c circle4 twice

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (2949, '2012-01-22 19:30:04.167568+00', '2017-02-06 00:49:35.533228+00', 5006, 1, NULL, 'ace', '1–::

  1c set | cross down RH (2c up) ; cast behind 3c, dance up NHJ to 2pl BtoB facing opp. side

9–::

  2c+1c+3c set as in DTr | All set advancing and swivel R to form »inverted« DTr (2c+3c are BtoB in centre) ; All set | All set advancing (1c into the middle) into

17–::

  2W+1M+3W & 2M+1W+3M RHA, 1c pass Rsh ; 1W+2W+3W & 1M+2M+3M LHA, finish in lines 1W between 2c facing 1M between 3c

25–::

  Lines A&R ; 1c turn RH 1¼ to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (15457, '2023-02-26 17:31:03.44172+00', '2023-02-26 17:46:58.625116+00', 12948, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; ½ Fig8 up round 2c (2,1x,3)

9--::

  1c ½ Fig8 L round 4cnrs _while{4}_ 2c & 3c set | cross LH ; 2c+1M & 1W+3c LHA (2x,1,3x)

17--::

  1c ½ Fig8 L round 2cnrs _while{4}_ 2c & 3c set | cross RH ; 2c+1M & 1W+3c RHA (2,1x,3)

25--::

  1c ½ Fig8 down round 3c ; 1c dance down and loop to 3pl (3c up) | 1c set (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12130, '2019-09-01 22:28:03.293023+00', '2020-02-20 15:17:20.27502+00', 19581, 1, 1645, 'ace', '*On 2nd chord, 2c & 4c cross to opposite sides (1,2x,3,4x)*

1-4::

  1c & 4c dance inwards (no hands) | 1W & 4W cast L round 2M/3M to place _while_ 1M+4M turn LH

5-8::

  1W & 4W set adv to centre _while_ 1M & 4M cast R round 2W/3W to place | 1c & 4c turn BH opening out to diag lines 1M+1W+2M & 3W+4W+4M

9-12::

  1c+2M & 4c+3M set in diag line _while_ 2W & 3W set solo | 2M & 3M cross as 1M & 4M cast to opposite sides _while_ 1W & 4W cast clw to 2pl/3pl _while_ 2W & 3W cast clw into new diag lines between 1M+2M & 3M+4M

13-16::

  2c+1M & 3c+4M set in diag line _while_ 1W & 4W set solo | 1M & 4M dance in to be LSh to each other on centre line as 2M & 3M cast to ends of centre line _while_ W cast clw to sides, 4W+2W & 3W+1W between 1pl/2pl & 3pl/4pl 

17-24::

  2c+4W+1M & 4M+1W+3c RHA, 1M & 4M pass RSh ; 2c+4c & 1c+3c LHA, M ending on centre line

25-32::

  4M+4W+2M+2W & 1M+1W+3M+3W snake passing RSh, 4M & 1M crossing over to (3x,1,4x,2) in from sidelines | all &frac12; turn RH to sides (3,1x,4,2x)

', 5);
INSERT INTO 'dancecrib' VALUES (11129, '2018-09-20 04:17:51.393762+00', '2018-09-20 04:38:30.58872+00', 18626, 1, 202, 'ace', '1--::

  1c+2c ½ R&L ; A&R (2x,1x)

9--::

  1c+2c ½ R&L ; dance BtoB (2,1)

17--::

  1M+2W turn RH 1½ ; 1W+2M turn RH 1½ (2x,1x)

25--::

  All set | RHA | cross RH (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11130, '2018-09-20 04:54:59.145841+00', '2018-09-20 04:58:50.258469+00', 18627, 1, 202, 'ace', '1--::

  1c set | cast ; set | turn RH into lines3 across, 1c face 4cnrs

9--::

  RSh Reels3 across {6}, 1c to 2plx | 1c set (2,1x,3)

17--::

  All dance BtoB ; 1c set | turn LH into lines3 across, 1c face 1cnrs

25--::

  LSh Reels3 across {6}, 1c to 2pl | 1c set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11131, '2018-09-20 22:47:26.192821+00', '2018-09-20 22:49:45.499642+00', 18630, 1, 202, 'ace', '1--::

  1c+2c Poussette (1,2,3)

9--::

  3C S&Link twice (3x,2x,1x)

17--::

  All dance BtoB ; turn P BH 1½ (3,2,1)

25--::

  2c+1c The Tournée (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (12595, '2020-02-19 21:35:20.224984+00', '2020-02-20 22:51:35.645494+00', 19847, 1, NULL, 'ace', '1--::

  1c set | cross down RH (2c up) ; cast off behind 3c and dance up to 2plx facing out (2,1x,3)

9--::

  1c turn 2c EH, 1c dance down NHJ and turn 3c EH to 2plx | All set (2,1x,3)

17--::

  Grand Chain, 2c cross to start (2,1x,3)

25--::

  1c ½ Fig8 R through end cpl ; All turn P RH (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (11132, '2018-09-20 23:23:44.605624+00', '2018-09-20 23:27:32.315201+00', 14080, 1, 202, 'ace', '1--::

  1c+4c long cast inwards (2c & 3c step out) ; 1c+4c RHA (2,1,4,3)

9--::

  2c+3c long cast inwards (1c & 4c step out) ; 2c+3c LHA (1,2,3,4)

17--::

  Reels4

25--::

  1c set | cast (2c+3c+4c set up) ; all turn P RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11133, '2018-09-21 12:36:23.177998+00', '2018-09-21 12:46:30.532298+00', 14078, 1, 202, 'ace', '1--::

  1c set | 1c+2c ¾ DblFig8 (1c cast, 2c cross up) (2,1x,3)

9--::

  1c+3c RHA ; ½ DblFig8 (1c cast, 3c cross up), 1c face out and up (2,1,3x)

17--::

  Mirror Reels3 on sidelines, (2c in and down, 1c out and up, 3c crossing to 2plx to start), 1c & 3c finish in centre NHJ facing up (2,1,3)

25--::

  1c+3c dance up between 2c, cast to sidelines (to 2,3,1) ; all set | turn P BH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12491, '2020-01-10 14:19:59.712508+00', '2020-01-18 10:25:46.980931+00', 4301, 1, NULL, 'ace', '1--::  

  1c cast (2c up) | 1c turn RH ; lead down between 3c, cast up and cross to face 1cnr

9--::  

  1c+1cnrs ½ diag. Reel4, pass Rsh ; 1c+2cnrs repeat, 1c pass Rsh to face 3cnr

17--:: 

  CPCP, at end passing P LH into 2plx facing out (3x,1x,2x)

25--::     

  3c facing 2c set _as_ 1c cast R round 1cnr into lines across | All cross RH with opposite ; 2c+3c set to P _as_ 1c cast R round 2cnr | All cross RH (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (12599, '2020-02-21 07:26:06.773513+00', '2020-02-21 07:27:32.446633+00', 1946, 1, 202, 'ace', '1--::

  1c+2c set to P (no hands) | cross RH ; set on sides | change places LH (2x,1x)

9--::

  2c+1c set to P | cross RH ; 2M+1M & 2W+1W turn LH ¾, 2M+1W passing LSh to face P into Reel4 position across

17--::

  Reel4 across

25--::

  ½ Reel4 across ; all set to P | all passing P RSh dance to own sides (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2106, '2012-01-22 19:29:20.425885+00', '2021-06-15 08:16:09.617119+00', 1757, 1, NULL, 'ace', '1–::

  1c turn RH | cross down ; cast up | dance to face 1cnr  _while{8}_   2c cross RH | cast up ; cross down | cast up to 1pl

9–::

  Set H&G, finish BtoB M facing up, W down

17–::

  2c+1M & 1W+3c Circle R  (to 2,1x,3) ; 1c turn LH to face 2cnr  _while{4}_  2c+3c turn P RH

25–::

  1c+2cnrs Pass & Turn, 1c turning RH into ; 1c+1cnrs Pass & Turn', 2);
INSERT INTO 'dancecrib' VALUES (13671, '2021-02-20 05:12:25.346592+00', '2021-02-20 12:48:56.366195+00', 19180, 1, 202, 'ace', '1--::

  1c pass P RSh, dance outside and meet, cross up LH between sides to 1pl | all turn P RH (1,2,3)

9-20::

  12 bars of Schiehallion Reels. All face clw (1,2,3)

21-24::

  All chase clw 1 place (to 3,1,2) | turn P BH ¾ facing clw NHJ (3,1,2)

25--::

  All W LHJ with P ½ RHA. On [28] all M NHJ with P move forward. All face cclw ; All M RHJ with P ½ LHA (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (10880, '2018-07-07 01:29:58.945766+00', '2020-09-22 08:41:41.038451+00', 13841, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c DblFig8, 1c&4c cross to start (1,2,3,4)

9--::

  1c & 4c set | cast inwards (2c & 3c step out) ; 1c+4c RHA (2,1,4,3)

17--::

  2c & 3c set | cast inwards (1c & 4c step out) ; 2c+3c LHA (1,2,3,4)

25--::

  All set | 1c+2c change places EH, 2c dancing up in a wide turn ; 1c+3c change places EH, 1c dancing down | 1c+4c change places EH, 4c dancing up (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12596, '2020-02-19 22:48:09.969846+00', '2020-02-19 23:17:09.166978+00', 19848, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c R&L, 1M & 3M face out

9--::

  1M & 3M, P following, cast down one, dance up between couple above, cast off on W side and (2c+4c up) cross to 2pl/4pl (2,1,4,3) (middles face ends)

17--::

  Reels4 on the sidelines, omit last Lsh pass) (2,4,1,3)

25--::

  3M cast up 2 _as_ 3W dances  2 places up middle (4c+1c down) ; 2c+3c LHA _as_ 4c+1c RHA (2,3,4,1)



', 2);
INSERT INTO 'dancecrib' VALUES (9581, '2017-02-03 18:09:16.76751+00', '2017-02-03 18:09:16.76751+00', 17577, 1, NULL, 'ace', '1--::

  1c cross RH and cast off (2c up) ; ½ Reels3 on the sides, 1c starts in and down, all make loops at the end (3,1x,2)

9--::

  All set | 3W+2M cast clw behind own line to other end while{2} the others dance (M side down, W side up) to next place, with polite loop ; 1c cross diagonally RH | 1W+2W & 1M+3M turn RH ½ on side, (2,1,3)

17--::

  Reels3 on the sides, 1c start Lsh to 3cnr (pos) (2,1,3)

25--::

  1c+4cnr turn RH ; 1c+3cnr turn LH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11136, '2018-09-23 21:22:39.537387+00', '2018-09-23 21:22:59.697304+00', 18539, 1, 1645, 'ace', '1-::

  2c &frac12; Petronella, 1c & 3c set on [7-8] (1,2x,3,4)

9-::

  1c & 3c &frac12; Petronella, 2c set on [15-16] (1x,2x,3x,4)

17-::

  1c & 2c & 3c turn BH ; chase &frac12; way cclw (3,2,1,4)

25-::

  2c+1c &frac12; Poussette ; 2c+4c &frac12; Poussette (3,1,4,2)

', 2);
INSERT INTO 'dancecrib' VALUES (3638, '2012-08-20 20:52:51.982181+00', '2018-03-20 18:13:39.447429+00', 14418, 1, NULL, 'ace', '1--::

  1c+2c Chain Progression (turn RH ¾ | centres turn LH 1½ as outers chase ½ | turn RH ¾) (2,1)

9--::

  cross RH on 2diag as 1diag set | change place Rsh on sides ; all chase clw half round (both M to 1pl, W to 2pl)

17--::

  Repeat (1x,2x)

25--::

  1c+2c dance down, W passes under joined arms to change side, and dance up (1,2)

33--::

  Poussette (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (11841, '2019-05-09 22:37:32.533502+00', '2019-05-09 22:37:32.533502+00', 8043, 1, NULL, 'ace', '

*Form large circle all facing in, W on R of M*  



1-::

  All A&R ; A&R, finish facing P

9--::

  Grand Chain (pass 4 persons, 2 steps per hand)

17--::

  With 5th person (new P) dance BtoB ; turn New P RH and face in

25--::

  All circle round and back.', 3);
INSERT INTO 'dancecrib' VALUES (12667, '2020-03-17 00:11:49.680079+00', '2022-04-26 09:34:08.977712+00', 11613, 1, 202, 'ace', '1--::

  3c turn LH ; 2c turn LH | 1c turn LH (1,2,3)

9--::

  1c+2c the Bourrel. On [15-16], 2c & 1c turn BH ½ (pas de basque)

17--::

  Reel4 on midline. On [24] 2M+1W pass RSh to sides (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12806, '2020-05-11 11:51:31.240558+00', '2020-05-11 14:21:49.156537+00', 7302, 2, NULL, 'ace', '*Note: This is the original description, no crib we tried out was better.*  

*A new top couple starts every 16 bars.*



1-8::

  1c: set, turn RH 4 steps into allemande position facing up, then with pdb turn clockwise as a couple to face down.

9-16::

  1c: promenade reel of three (Rsh to 2nd man) with 2c who finish in top place.      1c face out on opp sides in 2nd place.

17-24::

  2c+1c+3c: set in triangles. 1c+3c turn symmetrically one & half times, then 3c+1c+4c set in inverted triangles (lc facing in). 2c dance as 1c did in 1-8.

25-32::

  1c+4c: double figure eight in 6 steps, then 1c dance down & 4c cast up. 2c+3c  reel as 9-16.

33-40::

  1c+5c: set, dance 4 hands round to the left, drop pt''s hand & change under on the sides to face out. 3c: as 1-8.   2c+4c: set, turn symmetrically, set, as 17-24.

41-48::

  1c: set turning to face in, propelled pivot to own side.  2c+5c: figure eight as 25-32.  3c+4c: reel of three as 9-16.

49--::

         4c begins; the others continue.   

65--::

         5c begins: 

::

           on reaching original place, each couple falls idle.

113-120::

  All: advance & retire,  then 1c+2c & 4c+5c: 4 hands round to the left; 3c: propelled pivot.

121-128::

  All: advance & retire, then 1c+5c pivot, while 2c+3c+4c  6 hands round.

', 5);
INSERT INTO 'dancecrib' VALUES (11138, '2018-09-23 21:31:25.238466+00', '2018-09-23 21:31:37.547568+00', 18541, 1, 1645, 'ace', '1-::

  All set facing in | W &frac34; RHA | set to new P on side

9-::

  All set facing in | M &frac34; LHA | set to new P on side

17-::

  All turn new P RH ; turn corner LH

25-::

  2c+4c (in 1pl & 3pl) &frac12; L-Chain ; 1c+3c: &frac12; L-Chain (4,1,2,3)

33-::

  Circle8 & back (4,1,2,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11139, '2018-09-23 21:36:16.627814+00', '2018-09-23 21:36:28.62965+00', 18542, 1, 1645, 'ace', '1-::

  2c turn RH ; cast R (M up, W down) to centre (2c & 3c small step towards 2pl) | 2c set

9-::

  1c+3c set NHJ | 1c & 3c cross with M making arch ; 1c & 3c cross (1c in front) into lines of 3 across | all set

17-::

  All change pl RH with opposite | chase{4} &frac12; way clw | set in lines across

25-::

  2c turn &frac34; RH ; cast off (1c up) | all set (3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (11135, '2018-09-21 15:10:28.222109+00', '2018-09-23 21:42:05.512355+00', 396, 1, NULL, 'ace', '1--::

  1c set | cross RH ; set | cast off (2c up) (2,1x,3)

9--::

  2c+1c cross RH | ½ circle4 L ; cross LH | ½ circle4 R (2,1x,3)

17--::

  Reels3 across, 1c Rsh to 4cnr, finish facing 1cnr

25--::

  Set "H&G" (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (9582, '2017-02-04 15:45:55.09322+00', '2017-02-04 15:49:35.476968+00', 16750, 1, NULL, 'ace', '1--::

  All W, 1W leading, cast off behind own line, and up the middle, the M step in for

9--::

  3C Promenade, at end, 1c cast off (2,1,3)

17--::

  All M, 2M leading, cast off behind own line, and up the middle, the W step in for

25--::

  3C Allemande (3,1,2)

  ', 2);
INSERT INTO 'dancecrib' VALUES (1685, '2012-01-22 19:28:56.545357+00', '2019-02-15 20:17:12.657846+00', 246, 1, NULL, 'ace', '1–::

  Reels4 on the sides.

9–::

  1c cast behind 2c, in front of 3c, behind 4c and turn RH (2c+3c+4c up on [15-16] (2,3,4,1)

17–::

  1c+4c ½ LHA | 1c+3c ½ RHA ; 1c+2c ½ LHA | all C ½ RH turn into 1c facing down, other C facing up (1,2,3,4)

25–::

  1c+2c set advancing to pass | 1c+3c repeat _while_{2} 2c turn RH to own side ; 1c+4c repeat _while_{2} 3c turn RH to own side | 1c+4c turn RH to own side', 2);
INSERT INTO 'dancecrib' VALUES (11140, '2018-09-23 21:39:23.695937+00', '2018-09-23 21:39:39.474598+00', 18543, 1, 1645, 'ace', '1-::

  1W+3M set facing diagonally _while{2}_ 1M+2W & 2M+3W change pl LH | all chase &frac14; cclw to lines across ; repeat to (3x,2x,1x)

9-::

  All S&Link twice (1,2,3)

17-::

  2c &frac12; RSh Reels3 across (M up) ; pass to &frac12; RSh Reels3 across (M down), 1c & 2c end ready for

25-::

  1c+2c &frac12; poussette ; 1c+3c &frac12; poussette (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11141, '2018-09-23 21:42:11.248837+00', '2018-09-23 21:42:21.55001+00', 18544, 1, 1645, 'ace', '1-::

  1c set | cast off (2c up) ; 2c+1W & 1M+3c RHA

9-::

  1c &frac12; Reels3 on sides, LSh to 3cnr (3,1,2) ; 3c+1M & 1W+2c LHA

17-::

  1c Reels3 across, LSh to 1cnrpos ; 3c+1M & 1W+2c LHA

25-::

  1c lead to top | cast off ; lead down | cast up _while{8}_ 3c+2c &frac12; R&L ; set | cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11576, '2019-02-15 20:39:30.908408+00', '2019-02-15 20:39:30.908408+00', 19186, 2, NULL, 'ace', '1-::  1s set and cast off 1 place as 2s step up. 2s+1s+3s turn RH into allemande hold facing up 

9-::  2s+1s+3s allemande

17-::  3s+1s+2s set and rotate

25-::  2s+1s+3s circle 6H round', 5);
INSERT INTO 'dancecrib' VALUES (11577, '2019-02-15 21:21:44.502632+00', '2019-02-19 17:15:31.34992+00', 19186, 1, 202, 'ace', '1--::
  1c set | cast (2c up) ; all turn P RH into allemande hold (2,1,3)
9--::
  3C Allemande (3,1,2)
17--::
  3C Set&Rotate (2,1,3)
25--::
  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11574, '2019-02-13 21:36:07.201989+00', '2019-02-16 11:03:01.012898+00', 19184, 2, 1645, 'ace', '1-::

  1c+2c Knot (2,1,3)

9-::

  1c Fig8, 1W round 2c, 1M round 3c

17-::

  1c+3c R&L

25-::

  2c+1c+3c circle6 & back

:: *Repeat [1-32] in Reel time to (2,3,1,4) then 1c repeat [1-8] with 4c in Strathspey time to end in 4th place. NB crib derived from the video.*

', 0);
INSERT INTO 'dancecrib' VALUES (12600, '2020-02-21 07:39:52.009343+00', '2020-02-21 07:46:31.804705+00', 4975, 1, 202, 'ace', '1--::

  1c cross RH | cast off ; lead up and cross to 1pl | 1c set to P (1,2)

9--::

   1c cast off | lead up and cross to 1plx ; cast to 2plx _while{6}_ 2c lead up and cross to 1plx | cast off to 2plx ; lead up and cross to 1pl (to 2,1x) | 2c+1c set (2,1x)

17--::

  R&L (2,1x)

25--::

  A&R ; 1c cross RH | all set (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11838, '2019-05-08 18:15:48.31699+00', '2019-05-08 18:20:47.953718+00', 19285, 1, 202, 'ace', '1--::

  »Twisted R&L« : 1c & 2c cross RH and face on sides | 1c+2c turn LH ¾ into line4 across ; all BiL | 1M(2W) cast R to 2Mpl(1Wpl) _while{2}_ 1W+2M turn RH to own side opposite P place. 1c face up (2,1,3)

9--::

  1c dance RSh ½ round cnr they face, 1W (P following) cast to 2Wpl and dance between 3c, 1c divide and cast up to 2pl (2,1,3)

17--::

  All NHJ Adv {2} | set pivoting R (M face down, W face up) ; 2W & 3M leading, all cast R to own side (3,1,2)

25--::

  2M & 3W leading, 3c & 2c chase clw ½ to midline, RHJ to P and facing own side ; 1c turn RH _while{4}_ 2c & 3c turn RH 1¼ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11143, '2018-09-23 21:47:43.267058+00', '2018-09-23 21:47:53.359502+00', 18547, 1, 1645, 'ace', '1-::

  1c long cast to 3pl (2c & 3c up on [3-4]) ; 1c turn RH | lead up to 1pl facing out _while{4}_ 2c long cast to 3pl (1,3,2)

9-::

  1c & 2c Fig8 round 3c, 1c cast to start

17-::

  1c & 2c turn &frac34; RH | &frac12; Reel4 | turn &frac34; RH (2,3,1)

25-::

  1c+3c RHA ; LHA (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11578, '2019-02-18 21:44:09.880497+00', '2020-05-05 10:38:39.745353+00', 17581, 2, 2603, 'ace', '1--::

  Back to Back

5--::

  1st dance down 2pl and cast up (2c up)

9--::

  1st set adv. to 1cnrs; TR corner ;  Repeat with 2cnrs

17--::

  Repeat with 3cnrs ; Repeat with 4cnrs

25--::

  2c+1c+3c  Back to back; 2c+1c+3c TR', 0);
INSERT INTO 'dancecrib' VALUES (13567, '2021-01-20 19:03:10.357266+00', '2021-01-20 19:07:46.251286+00', 12491, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 R round 3cnrs to face 1cnrs

9--::

  1c+1cnrs set advancing passing LSh | 1c loop R to 1cnrs[pos] _while_ 1cnrs turn BH pivoting R to face original places ; 1cnrs+1c set advancing  passing LSh | 1cnrs loop R back to original places _while_ 1c turn BH pivoting R to face 2cnrs

17--::

  1c+2cnrs repeat [9-16]. On [16] 1c open out in 2pl centre to face up NHJ

25--::

  1c dance up between 2c | cast off ; dance down between 3c | cast up to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8518, '2015-02-04 07:15:42.34878+00', '2015-04-10 22:03:58.210396+00', 15968, 2, 1, 'ace', '*3c and 4c start on opposite side*



1–::

  1c+4c cross RH | cast to middle (2c up, 3c down) ; 1c+4c RH across,

  fin as pairs 1M+4W & 4M+1W facing out on W/M side in prom hold

9-::

  Pairs+2M+3M ½ diagonal Reel4 ; pairs meet & take P in prom hold

  for LS ½ diagonal Reel4 w/2W+3W

16-::

  Meet and repeat (as pairs RS ¼ diagonal Reel4 w/2M+3M ; with P

  LS ½ diagonal Reel4 w/2W+3W)

25–::

  1c (passing inside) turn 4c EH to sidelines ; 4M+1W dance across set

  crossing RH _while_ 1M+4W dance across set passing outside 1W+4M |

  1M+4W dance across set crossing LH _while_ 1W+4M dance across set

  passing outside 1M+4W [fin in order 2,4,1x,3x]', 3);
INSERT INTO 'dancecrib' VALUES (11839, '2019-05-09 16:50:30.972033+00', '2019-05-13 12:58:28.420802+00', 19295, 1, 1645, 'ace', '*Couples numbered clockwise round longwise set: 1M,1W,2M,2W down M side, 4W,4M,3W,3M down W side (M have partner on their right)*
1-::
  1c+4c & 2c+3c circle4 & back
9-::
  All S&Link with P on the side ; repeat to places
17-::
  Reels4 on the sides, starting RSh to P
25-::
  All set | chase 2 places cclw ; set | turn opposite RH (4,1,2,3)
', 2);
INSERT INTO 'dancecrib' VALUES (8749, '2015-04-12 21:02:42.315306+00', '2015-04-12 21:02:42.315306+00', 9224, 1, NULL, 'ace', '1--::

  1M+2W & 3M+4W cross passing Rsh | cast Lsh round P ; dance down/up the middle passing Rsh | cast R round person on own side, to place [as “Happy Meeting”].

9--::

  Reels4 on both sidelines

17--::

  1c+2c & 3c+4c set | ½ RHA ; 1c+4c S&Link (2x,4x,1x,3x)

25--::

  All set | cross RH ; 2c+4c & 1c+3c Circle4 L (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9584, '2017-02-07 12:45:39.016756+00', '2017-08-23 22:23:11.546165+00', 14394, 1, 202, 'ace', '1-::

 1c+2c S&Rotate (2,1,3)

9-::

 1c+3c RHA ; 2c+1c+3c chase clw ½ (3x,1x,2x)

17-::

 3W+2M cross RH | 3M+2W cross LH ; 1c turn RH ½ to 3pl (3c up) | All set (2,3,1)

25-::

 Circle6 and back (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (1779, '2012-01-22 19:29:01.941318+00', '2019-05-10 08:38:28.224377+00', 584, 1, NULL, 'ace', '{{explanation}}

3c+4c cross on 2nd chord(1,2,3x,4x). This dance has top/bottom symmetry



1–::

  All C set | 1c+2c & 3c+4c RHA | 1c & 4c cast in to 2pl/3pl _while_{2} 2c+3c lead out to end places

9–::

  1c+4c cross RH, cast to ends, meet in promhold and dance in between end couples, curve round the other couple Rsh to finish 1c / 4c on M/W side facing out and right

17–::

  1c & 4c (in promhold) Rsh Reels3 with the »corners« on M/W sides, at end meet in the centre

25–::

  4c+1c RHA, at end M swivels right so couples face ends of set (1c down, 4c up, W on P''s left, RHJ) ; 4c&1c cross between end couples and cast in to (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (9583, '2017-02-06 23:43:48.957541+00', '2017-02-06 23:43:48.957541+00', 15245, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; 1c ½ Fig8 round 2c (1x,2)

9--::

  1c set | cross RH and 1W turns in for ; 1M with 1W following cast up and dance down the middle, 1W+2c joining hands to make a Trio

17--::

  1M with Trio following dance down, all pivot R ; trio +1M following dance up, at end 1M joins trio to L of 1W

25--::

  1c cast off and set ; 2c+1c RHA (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (3406, '2012-01-22 19:30:24.075477+00', '2019-05-10 08:40:16.610095+00', 3252, 1, NULL, 'ace', '1–::

  1c+3c lead down the middle (2c+4c up) ; and up to 2pl/4pl BtoB facing own side (2,1,4,3,5)

9–::

  Double DTr, finish on own side facing up NHJ (2,1,4,3,5)

17–::

  1c+3c dance up one | cast off one ; dance down one (between 3pl/5pl) | cast up (to 2,1,4,3,5), 4c&5c stepping in for

25–::

  1c+4c & 3c+5c Poussette (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (11161, '2018-09-25 20:35:18.01708+00', '2018-09-25 20:36:11.592405+00', 18470, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 up round 2c to 2pl (2,1,3)

9--::

  Circle6 and back (2,1,3)

17--::

  Reels3 on sidelines, 1c RSH to 4cnrs (2,1,3)

25--::

  All A&R ; 1c set | cast (3c up) (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12597, '2020-02-19 23:45:38.868877+00', '2020-02-26 18:47:06.913607+00', 16338, 1, NULL, 'ace', '*Form Big Circle, W on L of M*

1--::

  All A&R  to centre ; repeat

9--::

  Circle L ; Circle R, finish NHJ with P 

17--::

   M swings W once under his L arm and into 2 fast turns R in ballroom hold, finish facing cclw RR, W outside 

25--::

  All promenade in waist hold, at end form circle, M finding a new P on his L ', 4);
INSERT INTO 'dancecrib' VALUES (3459, '2012-01-22 19:30:26.38599+00', '2020-12-18 20:11:27.220748+00', 6835, 1, NULL, 'ace', '1–::

  1c slip down _while{4}_ 4c (forming arch) slips up ; both C slip back, 1c making arch

9–::

  2M+3M & 2W+3W slip across (W arch) ; and back (M arch)

17–::

  1c leading all cast behind own line, 1c makes arch ; 2c+3c+4c dance up under arch (2,3,4,1)

25–::

  All Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (11251, '2018-10-05 19:45:06.508119+00', '2020-05-12 21:44:28.174035+00', 18806, 1, 1645, 'ace', '1-::

  RSh Reels4 on the sides (1,2,3,4)

9-::

  1c+2c six bars of R&L | set (2,1,3,4)

17-::

  1c+3c Knot (2,3,1,4)

25-::

  1c+4c S&Link ; Circle4 to L (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (3844, '2013-07-13 15:56:21.032952+00', '2019-02-19 01:00:40.102233+00', 6205, 1, NULL, 'ace', '1–::

  1c set | cross down RH (2c up) ; set as DTr | 1c turn 1cnr RH into lines across (1W above, 1M below)

9–::

  All set | change pl RH up/dn ; all set | turn opposite RH ½, 1W+3M+3W then pivoting R to form close pairs, 1c facing up in centre, and 2c behind 3c facing down on the sides 

17–::

  Rsh Tandem Reel3 across (pairs 1W+1M, 3L+2L & 3M+2M each dancing as 1 person)  (to 2,1,3)

25–::

  All M LHA and all W RHA ; Repeat, each dancer switching wheel when meeting P in the centre (as in Alison Rose)

33–::

  1c followed by 3c+2c dance up, cross & cast (to 2,3,1) ; all C turn RH

41–::

  Circle6 & back (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (12668, '2020-03-17 02:14:08.994489+00', '2020-03-17 02:14:08.994489+00', 17398, 1, NULL, 'ace', '1--::

  1c+2c RHA ; 1c cross down as 2c cast up | All set (2,1x,3)

9--::

  All dance 6 bars of R&L for 3 and all face clw | 2c+3c chase 1 place clw _while{2}_ 1c turn LH ½ into

17--::

  3c+1W & 1M+2c RHA (to 2,1,3) ; All turn P RH, 1c turning 1¼ 

25--::

  3c+1M & 1W+2c LHA ; Rsh Snake Pass to (2,1,3)







', 3);
INSERT INTO 'dancecrib' VALUES (2044, '2012-01-22 19:29:16.744641+00', '2020-03-17 19:52:24.859293+00', 9222, 1, NULL, 'ace', '1–::

  1c dance between 2c and cast up to place ; 1c+2c RHA

9–::

  1c fig8 round 2c _while_{8} 2c set | cross ; set | cross and face out

17–::

  1c (2c casts up to follow) down the middle, all turn in on [5] and dance up, 2c leading

25–::

  2c+1c Promenade.', 2);
INSERT INTO 'dancecrib' VALUES (11145, '2018-09-23 22:42:03.437356+00', '2018-09-23 22:42:41.033301+00', 18646, 1, 202, 'ace', '1--::

  1c set | 6 bars of Fig8 (2c up on [7-8]), 1c face out (2,1,3)

9--::

  Mirror Reels3 on sidelines, 1c out and down, 3c in and up. On [15-16], 1c dance down to centre, BtoB facing own side

17--::

  DTr (2,1,3)

25--::

  1c turn P RH ; 1M+2c & 1W+3c LHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12598, '2020-02-20 21:46:36.355839+00', '2020-02-21 09:38:52.879864+00', 2229, 1, NULL, 'ace', '1--::

  1W+2W+3W dance Rsh fully round P and face them across and close by ; All set | All W cast R back to places

9--::

  The M repeat (1,2,3)

17--::

  1W+2M change places RH | 1M+2W change places RH ; 2c+1c RHA (2x,1x,3)  

25--::

  2c+1c ½ DblFig8, to start 2c cast and 1c cross up ; 1c NHJ dance between 3c and cast up to 2pl (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (11146, '2018-09-23 22:47:08.237585+00', '2018-09-23 22:47:41.173905+00', 18647, 1, 202, 'ace', '1--::

  1c set | 6 bars of Fig8 (2c up on [7-8]), 1c face out (2,1,3)

9--::

  Mirror Reels3 on sidelines, 1c out and down, 3c in and up. On [15-16], 1c dance down to centre, BtoB facing own side

17--::

  DTr (2,1,3)

25-28::

  All A&R

29-40::

  3C R&L', 2);
INSERT INTO 'dancecrib' VALUES (11147, '2018-09-23 22:57:15.175628+00', '2018-09-23 23:00:15.777026+00', 18648, 1, 202, 'ace', '1--::
  1c set | 6 bars of Fig8 (2c up on [7-8]), 1c face out (2,1,3)
9--::
  Mirror Reels3 on sidelines, 1c out and down, 3c in and up. On [15-16], 1c dance down to centre, BtoB facing own side
17--::
  DTr (2,1,3)
25--::
  1c turn P RH and face out ; 1c cast to 3pl (3c up) | 1c set (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (14754, '2022-04-10 23:49:42.705632+00', '2022-04-10 23:55:34.457356+00', 20753, 1, NULL, 'ace', '1--::

   1M+3W set | cast cclw to 2pl (2c step to empty end) ; 3W cast R about to 3M place as 1M follows to 3W place (2W+3M step up to 2pl)    

  1W    2W    1M  

  2M    3M    3W  



9--::

   1W+3M set | they cast clw to 2W/1M places (2W steps up, 2M down) ; 1W casts L about to 1W place and cross to 1M place as 3M follows to 1W place    

  3M    2W    1M  

  1W    2M    3W  



17--::

   All NHJ A&R, 2c changing sides (as in Trip to Bavaria) ; 1M, 2M+3M following, chase clw half round the set _while{4}_ the W stand{2} | dance individual full circle clw, all finish in promhold with P facing up    





25--::

   All promenade, on [31-32] 1c cast off and 2c dance up (2,1,3)

', 0);
INSERT INTO 'dancecrib' VALUES (11148, '2018-09-23 23:21:00.926734+00', '2018-09-24 09:33:11.046124+00', 18545, 1, NULL, 'ace', '1-::

  1M+2W set | turn RH to promhold on W side, facing in ; 1W+2M set | turn LH to promhold on M side

9-::

  1W+2M & 1M+2W Fig8 round 3c with 1W+2M crossing first (2,1x,3)

17-::

  1c turn RH into Reels3 on opp side, RSh to 2cnr (to 2,1x,3)

25--::

  [cnr-assisted petronella] All set | 1c petronella R to between end cpl (initially NHJ with 2cnr) ; All set in facing lines across | 1c petronella (initially NHJ with 3cnr) to (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (11150, '2018-09-24 18:54:06.74313+00', '2018-09-24 18:56:18.435812+00', 18641, 1, 202, 'ace', '1--::

  1c set | cross RH ; cast | turn LH ¾ into facing lines3 across

9--::

  All A&R. On [11-12] 1c dance RSh round P to face 1cnrs ; Set to Corners (2,1x,3)

17-28::

  3C R&L (2,1x,3)

29-32::

  1c turn RH 1½ (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11149, '2018-09-24 17:05:35.16494+00', '2018-09-27 13:18:48.268673+00', 18546, 1, NULL, 'ace', '1-::

  Tourbillon for 3C:  

  1-4: 1c+3c Tourbillon turn (1c to W side, 3c to M side) _while_ 2c chase 1 place clw | All set  

  5-8: 2W+1M & 2M+3W Tourbillon turn to 3pl/1pl _while_ 1W+3M chase 1 place clw to 2pl | All cross RH (M side: 3W, 1W, 2W; W side: 2M, 3M, 1M)

9-::

  3M & 1W (in 2pl) &frac12; Fig8 L through ends to centre ; turn RH 1&frac14; to positions[bar9] 

17-::

  Tourbillon for 3C back to (1,2,3)

25-::

  1c+3c 6 bars of DblFig8, (1c cross down) | 3c cross RH _while{2}_ 1c turn 2c EH &frac12; on sides to (3,1,2)

', 4);
INSERT INTO 'dancecrib' VALUES (9587, '2017-02-09 17:03:35.942987+00', '2017-02-09 17:03:35.942987+00', 15994, 1, NULL, 'ace', '1--::

  1c lead down (2c up) ; and up to face 1cnr

9--::

  1c+1cnrs diag. Reel4, with 2c joining in as if also dancing a Reel4 on 2diag., 1cnrs+2cnrs meet each time in ½ LHA.  At end 1c turn LH ½ to face P in the middle on opp. side

17--::

  1c set | lead up and cross ; cast off to 3pl (3c up) (2.3.1)

25--::

  All Circle6 L {5} and dance into centre | pivot R and dance out to (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (12516, '2020-01-18 22:40:30.596628+00', '2020-01-18 22:50:39.735622+00', 14571, 1, NULL, 'ace', '1--::

  1c dance BtoB ; long cast to 2pl (2c up) (2,1,3)

9--::

  1c Fig8 round 2c (2,1.3)

17--::

  1c Fig8 on own side, start down between 3c (2,1,3)

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1824, '2012-01-22 19:29:04.34328+00', '2020-05-13 19:08:02.071734+00', 753, 1, NULL, 'ace', '1–::

  1c cross RH and cast off behind sidelines | on [3] 2c cast and follow on own side ; all cast up | 2c curve in to turn 1c (easy hand) into the middle of a line of 4 across facing down

9–::

  In line of 4 down the middle ; turn R and dance up, 1c move ahead and cast as 2c dance to top (2,1x)

17–::

  2c+1c L-Chain

25–::

  1c ½ Fig8 round 2c ; 2c+1c turn RH', 4);
INSERT INTO 'dancecrib' VALUES (12810, '2020-05-13 23:36:38.723846+00', '2021-08-10 18:01:17.909338+00', 19974, 1, 202, 'ace', '1--::

  1c &4c A&R diagonally ; 2c+3c dance BtoB (1,2,3,4)

9--::

  1c+2c & 3c+4c Circle4 L ½ opening in centre to face up or down (to 2x,1x,4x,3x) | all set ; ½ R&L up/down to sides into Reel4 position (1,2,3,4)

17--::

  Reels4 (1,2,3,4)

25--::

  1c+2c ½ RHA | 1c+3c ½ LHA ; 1c+4c ½ RHA | all cross LH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (8931, '2015-09-29 14:23:17.401287+00', '2015-09-29 14:27:18.363273+00', 13869, 2, NULL, 'ace', '1–8::

  Mirror Reels of Three on the sidelines 2’s Crossing up ( no hands) to begin whilst 1’s & 3’s casting into reels ( 1’s & 3’s curving into place to end the reels)

9–16::

  1’s 2’s (on opposite sides) 3’s Set and Link for Three and joining hands in lines across the dance and flow into 6 hands round to the left half way.

17–24::

  1’s 2’s 3’s Set and Link for Three and joining hands on the sidelines flow into 6 hands to the left to the left half way

25–28::

  2’s dance half diagonal reel of four with first corner positions (passing corners right shoulder to begin). At the end of the reel (end of bar 28) 2’s come in towards each other and turn their back on their partner and finish back to back in the middle with the 2nd Women facing up and 2nd Man faces down towards their 4th corner positions

29-32::

  2’s dance half diagonal reel of four with fourth corner positions. Finish everyone on their own sides in the order 123 and with 1’s facing across, 2’s facing down, 3’s facing up

33–40::

  1’s 2’s & 3’s Progressive Grand Chain 1’s Turn right hand (once round) WHILST 2nd & 3rd Man and 2nd & 3rd Women cross right hand 2’s Turn left hand (once round) WHILST 1st &3rd Man and 1st & 3rd Women cross left hand 3’s Turn right hand (once round) WHILST 1st& 2nd Man and 1st & 2nd Women cross right hand 1’s Turn left hand (once round) WHILST3rd & 2nd Man and 3rd &2nd Women cross left hand Finish 2 3 1





*(At end of 1’s final left turn continue out and up to start reel on the sidelines, no polite turn)*

', 5);
INSERT INTO 'dancecrib' VALUES (9588, '2017-02-09 21:33:30.953982+00', '2022-05-07 21:26:29.674076+00', 16007, 2, 160, 'ace', '1-8::

  4H  Round & Back.

9-16::

  Turn Opp. RH ; Turn Ptnr LH.

17-24::

  Ladies chain.

25-32::

  All Adv&Ret ; pass Rsh to meet new col.', 3);
INSERT INTO 'dancecrib' VALUES (11151, '2018-09-24 21:59:02.470281+00', '2018-09-24 22:02:04.485292+00', 18640, 1, 202, 'ace', '1--::

  All set | cross ; repeat (1,2,3)

9--::

  1c lead down {2}, up {2} ; cast to 3pl (2c+3c up) (2,3,1)

17--::

  1c turn 3c on sidelines RH 1½ ; 1c turn 2c on sidelines LH 1½, 1c & 2c finish in centre facing up ready for

25--::

  2C Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11154, '2018-09-24 23:23:19.699351+00', '2018-09-25 05:51:03.032201+00', 18663, 1, NULL, 'ace', '1--::

  1c long cast (2c up) ; cross RH and face out | 1c+2cnr change places LH 

9--::

  ½ Reels3 on the sides, 2cnr persons start Rsh to 1cnr (2W and 3M finish in 2pl own side) ; 1c meet and turn BH to midline facing own side, 1W above 1M 

17--::

 3c+1W & 1M+2c Reels3 across, 1c starting Lsh to 4cnr (pos), and 1c pass Rsh  at end to finish in lines across, 1M between 3c facing 1W between 2c

25--::

  All adv{1}, ret{1} | Link for 3 ; All chase clw (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (9589, '2017-02-09 21:51:25.190206+00', '2022-05-09 11:56:12.179343+00', 16008, 2, 160, 'ace', '1-8::

  Slip down (to man''s right) and back. End btwn 2C.

9-16::

  4H round & back

17-24::

  2C slip down and back.

25-32::

  1C 2C 4H round & back', 3);
INSERT INTO 'dancecrib' VALUES (15456, '2023-02-25 10:50:47.495107+00', '2023-02-27 09:51:56.470824+00', 5295, 2, 26429, 'ace', '1-8::

  1s and 2s dance rights and lefts

9-16::

  1s, 2s and 3s circle left and back

17-18::

  1s cross down as 2s cast up and 3s turn Right hand

19-20::

  2s cross down as 1s cross down as 3s cast up to top

21-22::

   3s cross down as 2s cross down as 1s cast up to top

23-24::

  3s cross down to place as 2s cast up to place as 1s set in place

25-32::

  1s and 2s dance chain progression', 4);
INSERT INTO 'dancecrib' VALUES (4405, '2013-08-21 08:30:48.448318+00', '2023-02-04 01:18:54.222931+00', 8418, 3, NULL, 'ace', '1-8::
    1s set, cross down RH, dance out round 1st corner & turn LH to face
    own side
9-16::
    1s dance RH across on side, pass RSh & dance LH across on opp side
    ending in lines of 3 across dance with Man between 2s & Lady between
    3s
17-24::
    2s+1s+3s set, change places RH with person opposite, set & change
    back RH with 1s turning right about to face 3rd corner
25-32::
    1s dance RSh reels of 3 across ending in 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (11153, '2018-09-24 22:50:32.64028+00', '2018-09-25 06:11:05.194177+00', 18658, 1, NULL, 'ace', '1--::

  1c+4c set adv to P and 1c face 4c | dance towards each other (2c+3c to end) ; 1c set to 4c | cast back to own end (2c+3c to middle) (1,2,3,4)

9--::

  1c+4c cross RH _while{2}_ 2c+3c ½ RHA | top two cpls and bottom two cpls change place LH on the sides ; repeat pattern [9-10] | All set (3,4,1,2)

17--::

  4c+1c Poussette, finish middles facing ends (3,4,1,2)

25--::

   ½ Reels4 on the sidelines, but at end 4c & 1c do not pass but face back ; 2c+4c & 1c+3c Circle4 L (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11155, '2018-09-25 07:43:19.978251+00', '2018-09-25 07:44:32.72193+00', 18659, 1, 1645, 'ace', '1-::  1c+2c &frac12; LHA | 1c & 2c &frac12; turn P LH ; &frac12; diagonal R&L
9-::  &frac12; RSh Reel3 on sides ; &frac12; LSh Reel3 across
17-:: 1c &frac12; Fig8 LSh round 1cnr _while{4}_ 1cnrs &frac12; turn LH and twirl away ; 1c &frac12; Fig8 RSh round 2cnr (3x,1x,2x)
25-:: &frac12; diagonal _L&R_ ; &frac12; LSh Reel3 on sides
33-:: &frac12; RSh Reel3 across ; 1c &frac12; Fig8 RSh round 4cnr _while{4}_ 4cnrs &frac12; turn RH and twirl away
41-:: 1c &frac12; Fig8 LSh round 3cnr (2,1,3) ; 1c & 2c &frac12; turn P RH | 1c+3c &frac12; RHA (2,3,1)
::    *Bars 25-44 repeat bars 5-24 from opposite sides with opposite hands.*
', 5);
INSERT INTO 'dancecrib' VALUES (11152, '2018-09-24 22:21:35.743023+00', '2018-09-25 20:41:45.18456+00', 18657, 1, NULL, 'ace', '1--::

  1c+2c RHA ; 1c set | cast off (2c up) (2,1,3,4)

9--::

  1c+3c+4c Mirror Reels3 on the sides, 3c start out and up (2,1,3,4)

17--::

  1c with 2c following dance down the middle, cast to the top, finish in Allemande hold facing up (1,2,3,4)

25--::

  1c+2c Allemande, but on [31-32] 1c slip to the bottom (3c+4c up) (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (1926, '2012-01-22 19:29:10.226859+00', '2015-09-29 14:36:44.539831+00', 7362, 1, NULL, 'ace', '1–::

  1c set | turn ¾ LH (2c up) ; 1c set, turn ¾ LH to face 2c in line across

9–::

  (Celtic reel) 1c+2c pass Rsh | »outers« chase ¼ way R (=clw) _while_{2} »inners« turn (no hands) ¾ Lsh to face same person ; repeat

17–::

  Repeat ; repeat to starting position in line across

25–::

  All set to and ¾ turn EH with person opposite (1c starting upwards), 1c finishes in 2plx ; 1c ½ Fig8 up

', 2);
INSERT INTO 'dancecrib' VALUES (11158, '2018-09-25 08:38:18.982225+00', '2019-09-01 20:46:39.691891+00', 18661, 1, 1645, 'ace', '*2nd couple start on opposite sides (1,2x,3).*

1-::  Reels3 across, 1M & 3W cast to start, 2c start RSh to 2cnrs & end passing LSh to centre line

9-::  1c+2M & 2W+3c RHA, 2c pass RSh ; 1c+2W & 2M+3c LHA, end in original places (1,2x,3)

17-:: 2c cross RH with 1cnrs | 3W & 1M (in 2pl) cross LH with 2cnrs ; 2c (in 1cnrpos) cross RH | 3W+1M (in 2cnrpos) cross LH

25-:: 3M+1W (in 2plx) cross RH: all have now moved 1 place clw & are opposite new P | chase clw (or circle6) back to same places (M side: 2W,3M,3W; W side: 1M,1W,2M).

', 5);
INSERT INTO 'dancecrib' VALUES (11162, '2018-09-25 20:54:32.504787+00', '2018-09-25 20:57:13.254764+00', 18474, 1, 202, 'ace', '1--::

  1c Fig8 on sidelines, starting in (1,2,3,4)

9--::

  Middle cpls Fig8 round nearest end cpls (1,2,3,4)

17--::

  4c Fig8 on sidelines, starting in (1,2,3,4)

25--::

  1c set | cast to 3pl _while{4}_ 3c set advancing | dance up to 1pl ; 4c set | cast to 2pl _while{4}_ 2c set advancing | dance down to 4pl (3,4,1,2)

33--::

  Top 2 cpls & bottom 2 cpls Circle4 and back (3,4,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (14351, '2021-10-05 22:17:06.877131+00', '2021-10-05 22:18:30.901241+00', 20500, 1, 1645, 'ace', '1-::

  1c+2c A&R ; 1c cross RH | cast off (2c up) to (2,1x)

9-::

  2c+1c RHA, W retain RH ; &frac12; L-Chain flowing into

17-::

  Reel4 across, W start passing RSh in centre, M start to their R

25-::

  2c+1c &frac12; L-Chain ; 1c &frac12; Fig8 up round 2c (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11157, '2018-09-25 08:17:54.532274+00', '2020-07-04 10:21:56.50891+00', 18662, 1, 1645, 'ace', '1-::  1c lead down below 3c | cross & cast up to 2plx (2c up) ; &frac12; Fig8 R through ends to 2pl (2,1,3)

9-::  1W+2W & 2M+3M lead RH to opposite sides and cross _while{2}_ 1M & 3W cross singly to (W: 213 on M side; M: 132 on W side) |

      repeat three times from new places to (M: 132; W: 321)

17-:: 2W with 1M+3W (top) & 3M with 2M+1W (bottom) RHA ; 3M & 2W pass RSh for LHA to sides (M: 132; W: 321)

25-:: 3 couple Bourrel to (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (9773, '2017-04-06 16:03:13.865617+00', '2021-11-25 00:59:46.986347+00', 17706, 2, 1, 'ace', '{{title}}

Strathspey



1–4::

  1c&3c turn 1½ BH

5–8::

  1M+2M, 3M+4M turn ¾ RH, pull RS back to face ptr | all S to ptr

9–::

  1c+2c, 3c+4c diagonal Reels4 [M cross over at end to face ptr in sidelines]

17–::

  Highland setting step (e.g., Highland schottische)

25–28::

  1c+2c, 3c+4c dance first 4 bars of set & rotate

29–32::

  All S in sidelines | 1c&3c cast off _while_ 2c&4c cross up RH

33–::

  1c+4c dance Tourbillon



{{title}}

Reel



R from new positions (use skip-change to turn BH in tourbillon)', 3);
INSERT INTO 'dancecrib' VALUES (9590, '2017-02-09 21:55:23.138453+00', '2017-02-09 21:55:23.138453+00', 16009, 2, 160, 'ace', '1-8::
  Ladies chase a round the men - 1L leading.
9-16::
  Men repeat - 1M leading..
17-24::
  1C slip down and up [4] ; 1C cast to bottom.
25-32::
  8H round & back.', 3);
INSERT INTO 'dancecrib' VALUES (10743, '2018-05-04 21:50:14.483443+00', '2019-02-19 15:48:24.614175+00', 18330, 2, NULL, 'ace', '1–4::

    1st with 2nd couple, 3rd with 4th couple dance double half figures of 8, 1st couple crossing down and 4th couple crossing up to begin.

5–8::

    1st and 4th couples turn partner right hand one and a half times to places. 2nd and 3rd couples turn on the sides right hand one and a half times to change places.

9–12::

    1st with 3rd couple, 2nd with 4th couples dance a double half figure of 8, 1st couples crossing down and 4th couple crossing up to begin.

13–16::

    1st and 4th couples turn partner left hand one and a half times and finish in the middle facing partner as 2nd and 3rd couples turn on the sides left hand one and a half times and finish on sides facing person just turned.

17–24::

    All 4 couples dance a grand chain and all finish facing in [no polite turns].

25–26::

    All turn partner right hand half way and retain hands.

27–28::

    1st couple with 2nd, 3rd with 4th, dance right hands across half way.

29–30::

    1st couple with 2s, 3rd with 4th, dance left hands across halfway.

31–32::

    Dropping hands, all follow partner to finish:- 2nd couple at top on own side, 3rd couple at bottom on the opposite side, 1st couple on mens’ side and 4th couple on ladies side, all facing in.

33–36::

    1st and 4th couples set, and dance petronella in tandem.

37–40::

    1st and 4th couples set, and link across the dance to finish in order 2, 4, 1, 3 with 1st and 3rd couples on opposite side.', 5);
INSERT INTO 'dancecrib' VALUES (10745, '2018-05-05 00:44:20.50857+00', '2019-02-19 15:48:24.614836+00', 18330, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

  1c+2c & 3c+4c ½ DblFig8, 1c(4c) crossing dn(up) to start (to 1x,2x,3,4) ; 1c & 4c turn P RH 1½ _while{4}_ 2c+3c facing dn/up change places RH 1½ (1,3,2x,4x)

9--::

  1c+3c & 2c+4c ½ DblFig8, 1c(4c) crossing dn(up) to start (to 1x,3x,2,4) ; 1c & 4c turn P LH 1½ _while{4}_ 3c+2c facing dn/up changes places LH 1½ (1,2,3x,4x)

17--::

  4C Gr-Chain, end cpls crossing (omit polite turn) (1,2,3x,4x)

25--::

  All turn P RH ½, stay in centre RHJ | 1c+2c & 3c+4c ½ RHA (to 2,1,4x,3x) ; 2c+1c & 4c+3c ½ LHA (to 1x,2x,3,4) | dropping H, all follow P 2 places cclw (to 2M,1M,1W,3W on M side, 2W,4W,4M,3W on W side)

33--::

   1c+4c set | Petronella in tandem (to 2,4x,1,3x) ; 1c & 4c S&Link across (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (11159, '2018-09-25 20:11:19.341892+00', '2018-09-25 20:12:21.826521+00', 18468, 1, 202, 'ace', '1--::

  1c cross RH | cast to 3plx (2c+3c up) ; 2c cross RH | cast to 3plx (3c+1c up) (3,1x,2x)

9--::

  3c set | cast to 3pl (1c+2c up) ; set | cross RH (1x,2x,3x)

17--::

  All chase clw ½ (to 3,2,1) ; 3c set | cast to 2pl (2c up) (2,3,1)

25--::

  Circle6 and back (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10947, '2018-08-08 00:59:41.183037+00', '2018-09-25 19:05:02.746926+00', 18490, 1, 202, 'ace', '1--::
  1W followed by 1M cast | cross to 2plx (2c up) ; all cross RH and 1c face out | 1c turn 4cnrs[pos] LH into 2diag (2x,*1x*,3x)
9--::
  1c+4cnrs[pos] set | change places Rsh into 2diag ; set | cnrs cast Rsh round each other to exchanged places _while{2}_ 1c dance into centre and swivel R to face 1cnrs[pos]
17--::
  1c+1cnrs[pos] repeat [9-16] on 1diag. On [23-24] 1c dance in and curve R to 2pl facing out (3,1,2)
25--::
  1c chase clw ½ to exchanged places _while{4}_ 2c&3c dance diagonally  and pull Rsh back | dance to places ; 1c ½ Fig8 R round 3cnrs (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (12966, '2020-07-19 12:39:43.539854+00', '2020-07-20 07:13:24.565232+00', 19154, 1, 202, 'ace', '1--::
  1c lead down ; and up. On [8] 2c step in (1,2,3)
9--::
  2C Allemande. 1c face 1cnrs
17--::
  Corner Chain. 1c face 2cnrs
25--::
  Corner Chain. 1c in 2pl centre NHJ face up
33--::
  1c Mirror Fig8 on sides (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (9312, '2016-09-20 14:29:54.214297+00', '2017-02-09 23:06:50.859363+00', 16046, 1, NULL, 'ace', '1--::

  1c cast (2c up) | 1c turn RH | 1c cast up (2c down) (1,2,3)

9--::

  1c+2c turn P RH ½ | take hands in circle and set ; 2c+1c cast into clw chase half round (2,1,3)

17--::

  1c set to and turn cnrs, and face 1cnr 

25--::

  Reels3{6} with cnrs, Lsh to 1cnr | 1c cross RH (2,1,3)



', 2);
INSERT INTO 'dancecrib' VALUES (11160, '2018-09-25 20:27:12.894298+00', '2018-09-25 20:28:39.711352+00', 18469, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; dance down between 3c | cast to 2pl (2,1,3)

9--::

  Mirror Reels3 on sidelines, 1c out and down, 1c in and up (2,1,3)

17--::

  Turn CPCP (2,1,3)

25--::

  1c set | cast (3c up) ; all turn P RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2564, '2012-01-22 19:29:47.824612+00', '2020-05-14 21:59:42.459019+00', 3463, 1, NULL, 'ace', '1–::

  1c+2c set | 1c cross RH ; cast off (2c up) to between 3c NHJ | turn 3c easy hand, to finish (2,1x,3), 1c facing in and up, 3c facing out

9–::

  2c+1c+3c Mirror Reels3 on the sides (all give hands), finish (2,1x,3) with 2c facing 3c (make loops), finish 

17–::

  1c Petronella Turn _while{2}_ corners change place on side RH | All set in threes across ; 1c Petronella Turn, _while{2}_ corners cross RH | All set (3x,1,2x)

25–::

  Diagonal R&L (1c+1cnrs change places RH | 1c change places LH with mid-person on sides ; 1c+2cnrs repeat)', 4);
INSERT INTO 'dancecrib' VALUES (12969, '2020-07-20 08:09:40.252992+00', '2020-07-20 11:53:54.955526+00', 17340, 1, 202, 'ace', '1--::
  1c lead down ; and up to 2pl centre into promhold facing 2W (2c up on [3-4])
9--::
  Reel3 on 2diag, RSh to 2W. 1c face 2M
17--::
  Reel3 on 1diag, LSh to 2M. 1c in 2pl centre face up (2,1,3)
25--::
  1c dance to top and cast off to 3pl (3c up on [27-28] ; all A&R{1+1} | all set (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (14353, '2021-10-06 15:44:55.683058+00', '2021-10-06 15:49:24.0787+00', 20502, 2, NULL, 'ace', '1-::

 1C cast off behind own lines and back

9-::

 1C & 2C RH across and back

17-::

 1C followed by 2C lead down; 2C followed by 1C lead back to the top to 2, 1

25-::

 1C & 2C turn partners RH; turn partners LH', 3);
INSERT INTO 'dancecrib' VALUES (13568, '2021-01-21 06:48:14.861407+00', '2021-01-21 06:52:18.997927+00', 18938, 1, 202, 'ace', '1--::

  1c lead down ; lead up | dance out between 2c & 3c to 1pl (1,2,3)

9--::

  1c+2c DblFig8, 1c crossing (1,2,3)

17--::

  1c+2c set | ½ RHA ; 2c turn LH ½ _while{4}_ 1c turn LH and face 1cnrs

25--::

  SetH&G. On [31-32] 1c Petronella turn to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11163, '2018-09-25 21:56:49.610742+00', '2018-09-25 22:08:17.799878+00', 18664, 2, NULL, 'ace', '*2s & 4s start on opp. sides*  

1 - 8::

   1s+4s set & cast 1 place, cross passing LSh & cast RSh round 2L/3L, 4M following 1L & 1M following 4L, into centre ending with 1L & 4L BtoB, facing the man who was following them (4M/1M are at the top/bottom of the set)

9 -16::

   1L+4M circle left with 2s & 1M+4L with 3s, 1L+4L turn to face each other & 1s+4s set advancing, ladies passing to face partners, 4s+1s 3/4 turn partner 2H to end facing corners (4s facing 2s, 1s facing 3s)

17-24::

  4s+1s turn 1st corner RH, dance 1/2 LH across in middle, turn opposite corner RH & 1/2 LH across into side lines, facing 1st corners. (2) 4 (1) 3

25-32::

  All dance 1/2 Reel of 4 & turn BH. 3 (1) 4 (2)', 0);
INSERT INTO 'dancecrib' VALUES (2477, '2012-01-22 19:29:41.73901+00', '2020-01-21 08:13:42.488735+00', 3129, 1, NULL, 'ace', '1–::

  1c dance through 3c (2c up) and cast up ; 2c+1W & 1M+3c RHA, 1c finish facing 1cnrs.

9–::

  1c+1cnrs ½Reel4, pass Lsh ; ½Reel4 with 2cnrs, fast ¾ LH turn in the centre

17–::

  1W+3c (at top) & 1M+2c Reels3 across (Lsh to 1cnr pos), (to 3x,1,2x)

25–::

  diagonal R&L (1M down,1W up) (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11579, '2019-02-19 16:56:08.265603+00', '2019-02-20 09:48:08.775645+00', 19188, 1, 202, 'ace', '1--::
  1c dance down | cast up round 2c to 1pl ; lead down, cross and cast up round 3c to 2plx (2c up) (2,1x,3)
9--::
  1c turn BH ¾, face P and cast away into facing lines3 across (2c+1M & 1W+3c) ; 3C S&Link (2x,1x,3x)
17--::
  Reels3 across, 1c RSh to 4cnrs[pos] (2x,1x,3x)
25--::
  1c set ; Petronella turn _while{4}_ 2c & 3c Turn BH Halfway and Cast away ; 1c turn BH ¾, face P and cast away to 2pl (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (8259, '2014-05-01 19:08:31.129103+00', '2019-05-12 09:00:34.09026+00', 5215, 2, 160, 'ace', '1-8::

 1C set, Turn RH 1/2 round (face down) ; lead down between 2C+3C , cast up to 2place.

9-16::

 Diagonal half R&L - 1M up, 1W down to begin ; Diagonal half R&L - 1M up, 1W down to begin.

17-24::

 All set, turn partner RH 3/4 (to line of 6 up+down centre/retain RH) ; All set , turn RH 3/4 + face up in allemande hold.

25-32::

 3C 1C 2C Allemande.', 2);
INSERT INTO 'dancecrib' VALUES (10758, '2018-05-13 15:16:23.946995+00', '2018-09-26 22:00:18.3313+00', 18224, 1, 202, 'ace', '1--::

  1W followed by 1M cast | dances between 3c (2c up on [3-4]), up round 3M to 2pl | 1c turn RH to face 1cnrs (2,*1*,3)

9--::

  1c+1cnrs »Set to corner and cast away« [1c set to 1cnr | 1c cast Rsh round each other to 3cnr position _while{2}_ 1cnrs dance into centre, and swivel R to face own cnr ; repeat, 1cnrs finishing in exchanged places, and 1c facing 2cnr]

17--::

  1c+2cnrs repeat [9-16] (3x,1x,2x)

25--::

  3C S&Link twice (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11164, '2018-09-25 22:23:03.741879+00', '2018-09-25 22:29:25.709098+00', 9153, 1, 202, 'ace', '1--::

  Circle6 and back (1,2,3)

9--::

  1c+2c The Knot, 1c finish in centre, LSh to P facing opposite sides (2,1,3)

17--::

  1M+3c & 1W+2c RHA, 1c pass RSh ; 1M+2c & 1W+3c LHA, 2W & 3M face out (2,1,3)

25--::

  2c+1c+3c »modified diagonal R&L« [same as diagonal R&L (1M down, 1W up) except that on [25-28] cnrs on 2diag chase clw ½ ; on [29-32] cnrs on 1diag chase cclw ½] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11165, '2018-09-26 07:04:52.605123+00', '2018-09-26 07:09:23.352621+00', 18481, 1, 202, 'ace', '1--::

  1c+2c set | 1c cast (2c dance to 1pl) ; 1c+3c set | 1c cast (3c dance to 2pl and face out) (2,3,1)

9--::

  Mirror Reels3 on sidelines, 2c in and down, 3c out and up (2,3,1)

17--::

  1c dance up to top, cast (3c down on [19-20]) | set advancing to face 1cnrs

25--::

  1c turn 1cnrs RH | pass RSh ; turn 2cnrs RH | pass RSh to 2pl (2,1,3)

33--::

  Circle6{3} L, pivot L ; chase cclw to places (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3136, '2012-01-22 19:30:12.824791+00', '2021-01-21 10:05:42.670189+00', 11703, 1, NULL, 'ace', '1–::

  1c fig8 round 2c, (1M cross, 1W cross down, i.e. Rsh to 2c) (2c up on [3-4]) and finishing in middle 1M/1W facing 2W/2M

9–::

  1c+2c Reel4 across, 1c pass Lsh to face out and down (2,1x,3)

17–::

  Mirror Reels3 on sides, joining NH on meeting:, 1c finish NHJ facing down (2,1x,3)

25–::

  1c cross below 3c | cast up ; lead between 2c | cast to (2,1,3).', 2);
INSERT INTO 'dancecrib' VALUES (14264, '2021-08-22 22:18:21.721786+00', '2021-11-25 01:04:38.740378+00', 20316, 1, 202, 'ace', '1--::

  1c Fig8 on sides, RSh to 2c (1,2,3)

9--::

  1c set | 1c (1W leading) cast off ; cross to 2plx | turn P RH to face 1cnrs

17--::

  *Modified Corners Pass and Turn* : same as Corners Pass and Turn except on  [20] 1c pivot R to face 4cnrs. 1c finish BtoB in 2pl centre facing own sides

25--::

  Reels3 on sides, 1c RSh to 3cnrs (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11168, '2018-09-27 12:03:59.049614+00', '2018-09-27 12:05:31.391488+00', 18634, 1, 1645, 'ace', '*One position is chosen in advance as the "hot spot".*

*Start in W shape with dancers 1 & 2 facing gaps in line of dancers 5, 4 & 3:*  

*5...4...3*  

*..1...2*

1-::

  1 & 2 Fig8 round 5, 4 & 3, starting RSh to 4 & 3

9-::

  All set as in DDTr | 1+4 & 2+3 &frac12; turn RH (4,3,2,1,5) ; all set as in DDTr | 4+5 & 3+1 &frac12; turn LH (5,1,2,3,4)

17-::

  Dancer in the "hot spot" chooses any 8 bar figure, solo or with other dancers (eg Reel3, RHA+LHA, Fig8, swing, etc)

25-::

  Circle5 & back to (5,1,2,3,4)

', 2);
INSERT INTO 'dancecrib' VALUES (11051, '2018-08-30 23:31:09.657475+00', '2018-09-27 21:33:58.957563+00', 18550, 1, 202, 'ace', '1--::

  1c set | 1c lead down (2c up) ; cross and cast round 3c to 2plx (2,1x,3)

9--::

  Mirror Reels3 on sidelines (join hands with P when possible), 1c in and up, 2c & 3c loop to places (2,1x,3)

17--::

  2c+1c+3c A&R ; ½ Circle6 L (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11166, '2018-09-26 11:10:25.738494+00', '2018-09-28 22:34:32.195433+00', 18482, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; turn P LH to face 1cnrs (2,1,3)

9--::

  SetH&G, 1c finish BtoB facing 3cnrs

17--::

  RSh Reel4 on 1diag, on [24] 1c pass RSh to face 2cnrs

25--::

  RSh Reel4 on 2diag, 1c to 2pl (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9592, '2017-02-11 00:00:40.787888+00', '2017-02-11 00:00:40.787888+00', 5466, 1, NULL, 'ace', '1--::

  1c cross down (2c up) | cast Lsh round 2cnr (1W down 1M up) ; cross passing 3cnr Rsh | cast Lsh round 4cnr to face 2M in promhold

9--::

  2M+1c in promhold +3W Rsh diag. ½ Reel3, and face 3M ; 2W+1c+3M Rsh diag. ½  Reel3, and 1c face out W side

17--::

  3c+2c R&L while{8} 1c lead out, cross and cast (1W up, 1M down), meet in the middle facing M side , lead out, cross and cast (1M up, 1W down) and meet in promhold facing 2M (in 3W place)

25--::

  Repeat [9-16] (Rsh ½ Reels3, on 1diag, then on 2diag), finish with corners in own places and 1c coming in on W side 

33--::

  1c dances Lsh round 1cnr to 2plx ; turn P RH 1½ to (2,1,3)

41--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12965, '2020-07-19 12:12:15.770602+00', '2020-07-19 17:17:26.101172+00', 19822, 1, 202, 'ace', '1--::
  1c dance down, cast down round 3c ; 1c followed by 3c & 2c (who dance down) lead up to top. All in promhold face up (1,3,2)
9--::
  3C Promenade. On [15-16] 1c cast to 2pl (3c dance up to 1pl) (3,1,2)
17--::
  3C Knot. 1c face 1cnrs. 2c & 3c face out (2,1,3)
25--::
  Reels3 {6} on sides, 1c LSh to 1cnrs, 3c RSh to 2c | 1c cross RH (2,1,3)
33--::
  1c & 3c set | turn P BH ½ ; ½ Circle4 L | set (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (11632, '2019-03-02 06:53:05.482772+00', '2023-02-28 10:40:52.221398+00', 18264, 1, 202, 'ace', '1--::

  1c+2c Set&Rotate (2,1,3)

9--::

  Parallel Reels3 on sides, 1c RSh to 2c (2,1,3)

17--::

  2c, 1c & 3c set |La Baratte (2x,1x,3x)

25--::

  2c, 1c & 3c following, dance down {2} | change sides, W dancing under M arm {2} ; dance up to sides | set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11550, '2019-01-29 22:04:51.594311+00', '2021-03-16 10:11:59.1916+00', 8627, 1, 1645, 'ace', '{{explanation}}
Strathspey

1-8::
  Interlocking Reels4 starting RSh to P
9-16::
  All set to P | turn RH ; set to corner | turn LH
17-32::
  Schiehallion reels back to place

{{explanation}}
Jig

1-8::
  M petronella to centre | set adv to cnr ; M &frac12; turn cnr RH | set, M facing in, W out
9-16::
  Intersecting RSh Reels4
17-24::
  W turn original P RH | W &frac12; LHA ; turn opposite M 1&frac14; RH
25-32::
  Circle8 & back. *Repeat with new partner (M progress clockwise, W anticlockwise)*
', 2);
INSERT INTO 'dancecrib' VALUES (3496, '2012-01-22 19:30:27.862365+00', '2020-12-18 20:16:30.308865+00', 6995, 1, NULL, 'ace', '1-10::

  1c set, cross RH, set, lead down, cross and cast up (1,2)

11-20::

  1c+2c R&L (no polite turn), cross RH (1x,2x)

21-30::

  1c+2c set | ½ RHA ; set | ½ LHA | 1W+2M continue ½ LH turn _while{2}_ 1M+2W (the leading M and W) cast R and out on opposite side, all finish in line across facing P

31-40::

  Reel4 across the set | Pass P Rsh and dance to own side (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (8750, '2015-04-17 14:26:29.578187+00', '2015-04-17 14:26:29.578187+00', 13938, 2, NULL, 'ace', '1- 4::

    1s+2s chase clockwise once round

5- 8::

    1s+2s dance RH across

9-12::

    1s+2s dance LH across

13-16::

    1s+2s chase counter clockwise once round

17-20::

    1M+2L turn LH

21-24::

    1L+2M turn LH

25-32::

    1s+2s dance ¾ RL, 2s+1s set

', 3);
INSERT INTO 'dancecrib' VALUES (9593, '2017-02-11 14:51:32.695934+00', '2017-02-11 14:51:32.695934+00', 986, 1, NULL, 'ace', '1--::

  1c dance down | set ; turn BH | cast up to(1,2,3)

9--::

  The Bourrel”:  1M+2W set, advancing on second step | turn BH ¾ to midline and pivot R to stand BtoB while{4} 2M+1W cross and cast L to midline facing P ; 2c+1c set to P | turn P RH, 2c to in 1pl and 1c to promhold in the middle facing down

17--::

  1c+2cnrs ½ diag. Reel3, Rsh to 3M ; 1c+1cnrs ½ diag. Reel3, Rsh to 3W, at end 1c face out in 2pl    (3x,1,2x)

25--::

  1c cast R (M up W down) round the set to 2plx while{2} cnrs advance {1} to make circle, set L {1} | Set R {1} and cast R to place (3x,1x,2x) ; All turn P BH | Circle6 L ½ round (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11169, '2018-09-27 22:33:44.039479+00', '2018-09-27 22:38:32.577116+00', 16228, 1, NULL, 'ace', '*Start in big cross: M form inner cross at arm''s length and face cclw, having RHJ with P outside and facing clw*

1-4::

  All set outward and inward | Turn P RH¾ to square set M facing in, W out

5-24::

  Schiehallion reels, finish in a big cross, W inside facing P outside ; All turn P RH once

25--::

  Intersecting Reels4 (touch LH briefly in middle) finish in big cross with M and W interchanged.  



*repeat once*', 2);
INSERT INTO 'dancecrib' VALUES (11580, '2019-02-19 22:55:22.988422+00', '2019-02-19 23:09:42.610273+00', 16956, 1, 1645, 'ace', '1-::

  1c cross RH | 1W casts off 2pl & up centre to face M side _while_ 1M casts off 1pl, in round 3W back to 2pl behind W line as 2W & 3W turn to face him, all M looking at their partner''s back

9-::

  2c+1c+3c inverting DTr (from &lt;&lt; to &gt;&gt; configuration & back), on [15-16] 1M sets pulling RSh back to face out, 1W behind him

17-::

  1M, 1W following, casts R below 3W & up the middle, finishing 1M between 2c facing down to 1W between 3c ; 1c turn RH to 1W in 2pl, 1M in centre

25-::

  2c+1W+3c circle5 & back with 1M in the centre looking confused, but ending on own side (2,1,3) *2M & 3M optionally leave a gap in the circle.*

', 2);
INSERT INTO 'dancecrib' VALUES (11170, '2018-09-28 19:34:02.231786+00', '2018-09-28 21:26:51.766259+00', 18666, 1, NULL, 'ace', '1--::

  1c set | dance between 3c (2c up) and cast up to 2pl | set advancing and pivoting R into  

9--::

  DTr, at end 1c set advancing into 2plx facing out  (2,1x,3)

17--::

  1c chase clw half round set ; turn RH _while{8}_ 2c+3c ½ RHA and twirl out to sidelines ; cross RH | set (3,1,2)  

25--::

  Circle6 and back (3,1,2)  

', 4);
INSERT INTO 'dancecrib' VALUES (3007, '2012-01-22 19:30:06.649985+00', '2015-10-16 16:27:51.670445+00', 9540, 1, NULL, 'ace', '1–::

  1c cross down into Mirror Reel3 on sides (1x,2,3)

9–::

  1c turn RH | cast (2c up) ; ½ Fig8 R (M up, W down) (2,1,3)

17–::

  2c+1W & 1M+3c RHA ; All chase clw ½ round (3x,1x,2x)

25–::

  All S&Link3 twice (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11844, '2019-05-11 16:26:20.431534+00', '2019-05-12 08:26:37.415949+00', 2574, 1, 1645, 'ace', '1-::

  1c turn RH | cast off (2c up) ; 1c cross LSh | cast RSh round 1cnr to facing lines across

9-::

  1c each with 1cnrs in promhold change places passing RSh ; repeat with 2cnrs passing LSh

17-::

  1W+3M+2M & 1M+3W+2W LHA ending back in lines across ; all set | change pl RH, 1c face out (up/down)

25-::

  1c cast RSh round 2cnr (2x,1x,3x) | all set ; all turn P 1&frac12; RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11859, '2019-05-26 16:11:24.788288+00', '2019-05-26 16:18:27.870728+00', 10142, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; turn LH to face 2cnrs

9--::

  Reels3 {6} on sides, RSh to 2cnrs | cross RH (2,1,3)

17--::

  1c dance down ; and up into DTr position

25--::

  DTr (2,1,3)

33--::

  2c+1c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11172, '2018-09-29 20:11:37.619676+00', '2018-09-29 20:28:10.783919+00', 18494, 1, NULL, 'ace', '1--::

  1c+6c dance in 2 places to face each other | set (2c+5c to end) ; set advancing passing Rsh and 6c face 1c again | retire to 2pl/5pl in middle, still facing (2,6,3,4,1,5)

9--::

  6c & 1c joining EH with the two nearest on own side dance three hands across, at end 1c+6c change sides ; repeat 3 hands across, corners use same hands again (2,6x,3,4,1x,5)

17--::

  2c+6c+3c & 4c+1c+5c Reels3 on the sides, to start 2c+5c cast and 6c & 1c dance towards the centre (between 3c / 4c) (2,6x,3,4,1x,5)

25--::

  6c+3c & 4c+1c set to P | 6c+1c cast to middle places as 3c+4c join NH on midline and face end ; 6c+1c set and cross _while{4}_ 3c+4c dance out the end and cast inwards (2,3,6,1,4,5)

33--::

  Circle12 and back (2,3,6,1,4,5)

', 3);
INSERT INTO 'dancecrib' VALUES (11581, '2019-02-19 22:57:46.537735+00', '2019-02-19 23:08:16.583043+00', 16955, 1, 1645, 'ace', '1-::

  1c & 3c petronella to centre line | set ; turn 1&frac12; RH

9-::

  1c+3c Reel4 on centre line

17-::

  1c & 3c petronella to sides (1,2,3) | set ; all turn RH

25-::

  1c+2c poussette (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12602, '2020-02-21 22:58:03.696788+00', '2020-02-22 23:28:03.327724+00', 15965, 1, NULL, 'ace', '1--::

  1c+2c+3c Inveran Reels{6} | 1c cross down Lsh to form line of four across, 1c (facing opp. side) between 2c 

9--::

  1c+2c ½ Reel4 across, 2c end in 1plx and 1c turning P RH to form line across, 1c (facing opp. side) between 3c ; 1c+3c ½ Reel4 across, 1c pass RH to finish (2x,3x,1) 

17--::

  3c+1c ½ R&L ; 2c+1c ½ R&L (1,2,3)

25--::

  1c+2c Tournee (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8932, '2015-10-01 22:09:37.286419+00', '2015-10-01 22:09:37.286419+00', 16465, 1, NULL, 'ace', '1--::

  1c set | cross down no hands (2c up) ; cast behind 3c and up the midline, W in front of P 

9--::

  2M + 1W (1M following) + 3W Lsh diag Reel3, at end 1c pivot R to face down. 1M in front

17--::

  2W+1M (1W following) +3M Rsh Diag. Reel3, 1c finish facing 1cnr

25--::

  1c+1cnrs Cnrs Pass and Turn, pass Rsh ; 1c+2cnrs Cnrs Pass and Turn, 1c crossing to (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (11845, '2019-05-11 16:43:45.190546+00', '2019-05-11 16:47:47.602197+00', 4612, 1, 1645, 'ace', '1-::

  All circle8 & back

9-::

  1c & 3c advance NHJ, join 2c & 4c in facing lines across | all set ; all turn opposite BH, opening out to face sides | all set

17-::

  1M+3W+2c & 1W+3M+4c RHA ; LHA back to square set, 3W+1M to 1pl, 1W+3M to 3pl (1W & 3W in exchanged places)

25-::

  All W dance behind M to their R | in front of next M to face third M ; all turn new P BH

:: *W progress to (4,3,2,1), M do not progress. Repeat with side couples leading for [9-24].*

', 2);
INSERT INTO 'dancecrib' VALUES (13675, '2021-02-20 19:46:19.260353+00', '2021-02-20 19:52:10.472385+00', 17724, 1, 202, 'ace', '1--::

  1c dance between 2c and cast behind 3c to bottom. As 1c meet, 2c & 3c step in and make arches BHJ ; 1c lead up to top under arches. All stay in the middle facing up in promhold

9--::

  3C Promenade. On [15-16] 1c cast off _while_ 2c dance up to 1pl (2,1,3)

17--::

  Mirror Reels3 on sides, 1c in and down, 3c out and up (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3395, '2012-01-22 19:30:23.587243+00', '2020-06-27 16:51:06.832725+00', 9049, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; 1c turn LH | cast off one (3c up) (2,3,1)

9–::

  2c+3c+1c G-Chain (1c crosses to start)

17–::

  3c+1c set | 1c dance up and cast to 2pl (3c down) | 2c+1c set.

25–::

  2c+1c R&L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12967, '2020-07-19 17:48:56.112119+00', '2020-07-20 07:14:06.853579+00', 19145, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; dance between 3c (3c up) | cast off (4c up) (2,3,4,1x)
9--::
  4c+1c ½ R&L ; 3c+1c ½ R&L (2,1x,3x,4x)
17--::
  2c+1c ½ R&L (to 1,2x,3x,4x) ; All advance {2}. On [22] 2c & 3c & 4c turn BH ½ | all retire {2} to own sides (1,2,3,4)
25--::
  ½ Mirror Reels4 on sides, RSh on Mside, LSh on Wside (to 4,3,2,1) ; 1c stand still _while{4}_ 4c+3c+2c continue into ½ Mirror Reels3 on sides (2,3,4,1) ', 5);
INSERT INTO 'dancecrib' VALUES (9963, '2017-06-18 14:39:27.368092+00', '2020-07-20 08:28:16.280649+00', 17792, 1, 202, 'ace', '1--::

 1c dance to bottom into Mirror Fig8 (2c up on [7-8]) (2,1,3)

9--::

 Diagonal R&L (3x,1,2x)

17--::

 3C S&Link twice (2,1x,3)

25--::

 All set | 1c turn P RH 1½ | all set (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (11582, '2019-02-19 23:01:36.694691+00', '2019-02-19 23:12:35.415725+00', 16957, 1, 1645, 'ace', '1-::

  2c &frac12; turn RH & twirl away ; cast R to middle ending LSh to P _while{4}_ 1c & 3c &frac12; turn RH & twirl away

9-::

  1c+2W & 2M+3c RHA ; 2c turn &frac34; LH to own side _while{4}_ 1c & 3c keep turning RH  (1x,2,3x)

17-::

  1c+2c &frac12; R&L ; 1c+3c &frac12; R&L (2x,3,1x)

25-::

  2c & 1c cross RH _while{2}_ 3c set | all circle6 to L (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15371, '2023-01-05 11:34:36.98693+00', '2023-01-05 11:34:46.251255+00', 21213, 1, 1645, 'ace', '1--::

  1M+2W & 3M+4W cross RH _while{2}_ 1W, 2M, 3W & 4M set on diagonal | 1c+2c & 3c+4c chase &frac14; clw, 1M & 4W face out (2,1,4,3) ;

  1c+4c LHA & face the ends

9--::

  RSh Reels4 on sides, 1c+4c end facing in diagonally

17--::

  1W+4M cross LH _while{2}_ 1M & 4W set | 1c+4c chase &frac14; cclw (2,4,1,3) ; 2c+4c & 1c+3c RHA

25--::

  2c+4c & 1c+3c Poussette (2,4,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (12603, '2020-02-21 23:22:55.510241+00', '2020-02-21 23:38:49.753893+00', 15963, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; turn RH 1¼ to face 1cnr

9--::

  1c+1cnrs Pass&Turn, 1c pass Lsh ; 1c+2cnrs Pass&Turn, 1c pass Lsh to face 1cnr

17--::

  Reels3{6} on the sides, 1c Lsh to 1cnr | 1c cross to 2pl (2,1,3)

25--::

  2c+1c Poussette (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3471, '2012-01-22 19:30:26.827603+00', '2015-04-15 15:58:50.65947+00', 11569, 1, NULL, 'ace', '1–::

  1M+2W (on W side) & 1W+2M (on M side) turn BH 1½ to (2x,1x) ; 2c+1c set | 2c cross RH _while{2}_ 1c turn RH 5/8 to face P on 1diag

9–::

  2M+1c+3W set, 1c advancing to pass P Lsh | 1c turn 1cnr BH to face P on 2diag ; repeat figure, to face 1cnr (2,1x,3)

17–::

  Opposing Lsh Reels3{6} on sidelines, | turn RH ½ and face down

25–::

  Lead between 3c and cast up ; lead between 2c and cast to (2,1,3).', 2);
INSERT INTO 'dancecrib' VALUES (11584, '2019-02-20 00:20:57.503459+00', '2019-02-20 01:00:58.078646+00', 19189, 1, NULL, 'ace', '1--::

  1c set | cast (2c up) ; All set twice, on [7-8] 1c advance to 1cnrs

9--::

  Set H&G, but on [15-16] 1c change place LH and face out between 1cnr and 4cnr 

17--::

  1c Fig8 round those cnrs, Lsh to 1cnr, finish (2,1,3)

25--::

  2c+1W & 1M+3c RHA ; All cpls spin RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1829, '2012-01-22 19:29:04.6036+00', '2015-04-15 21:28:43.896665+00', 773, 1, NULL, 'ace', '1–::

  1c set and cast off one (2c up) ; 1c set and cast off one (3c up) (2,3,1)

9–::

  1c cross up into Mirror Reels3 (upside down) on opposite side (3c out and down) (2,3,1x)

17–::

  1c cross into Mirror Reel3 on own sides, at end 1c+3c speed up so 3c finish in 3pl as 1c dancing up turn RH to face 4cnr

25–::

  1W (1M) Rsh Reels3{6} across with 2c (3c) | 1c cross RH to own side (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11175, '2018-09-30 19:02:17.055907+00', '2018-09-30 19:07:04.645329+00', 9441, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; lead down between 3c | cast up to 2pl (2,1x,3)

9--::

  All turn P RH ; chase clw ½ (3x,1,2x)

17--::

  All turn P LH ; chase cclw ½ (2,1x,3)

25--::

  1c Fig8 on sidelines, LSh to 3cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15458, '2023-02-27 20:10:35.186121+00', '2023-02-28 01:36:21.591237+00', 15374, 2, 1363, 'ace', '

1-8::

 	1s set cross giving right hands cast off one place 2s step up . 1s advance setting to finish back-to-back.



9-16::

	 1s dance crown triangles to finish facing first corners.



17-24::

	1s dance pass and turn with first corners, pass RS, dance pass and turn with second corners.

25-32::

	1W with 3C and 1M with 2C dance RH across; 1C pass RS to finish in second place on own side and all set

', 0);
INSERT INTO 'dancecrib' VALUES (15182, '2022-10-24 15:46:05.962401+00', '2022-10-24 22:32:15.555162+00', 16771, 2, 160, 'ace', '1-4:: 1s + 2s Set and Link  - end 1M facing out.

5-8::  1s dance R shoulder around the dancer above - end 1M facing out.

9-16:: 2s 1s 3s dance L shoulder Reel3 on own sides - 1s pass Lshoulder to face 1st corners

17-24::  Corners change diagonally: 1corners change with half turn &twirl; 2corners the same  AS  1s pass 1Corner by R, pass R; pass 2corner R and pass R to face 3rd corners.

25-32::  Half diagonal Reel4 with 3corners , 1s pass R shoulder; half diagonal reel4 with 4corners.', 3);
INSERT INTO 'dancecrib' VALUES (11050, '2018-08-30 22:52:25.114451+00', '2018-09-30 22:01:36.112048+00', 18551, 1, 202, 'ace', '1-6::

  1c+3c »The Capstan« [1c+3c dance 1½ times round 2M/2W, 1c starting out, 3c in] (3,2,1,4,5)

7-12::

  1c+5c »The Capstan« [same pattern as above except that 1c start in, 5c out] (3,2,5,4,1)

13-16::

  3c+2c & 5c+4c Mirror S&Link (odd cpls cast, even cpls dance up), ending 2c to 1pl, 4c to 3pl, with 3c & 5c on 1diag in BiL position (RH with P, LH with 3cnrs)

17--::

  3c & 5c The Spoke (clw) (2,3,4,5,1)

25--::

  3M+2c & 5W+1c ½ RSh Reels3 across _while{4}_ 3W+4c+5M ½ Reel4 across (3W+5M pass LSh to start) (to 2x,3x,4x,5x,1x) ; 3W+2c &5M+1c ½ RSh Reels3 across _while{4}_ 3M+4c+5W ½ Reel4 across (3M+5W pass LSh to start) (2,3,4,5,1)', 4);
INSERT INTO 'dancecrib' VALUES (2037, '2012-01-22 19:29:16.414172+00', '2020-03-17 23:20:25.784148+00', 1521, 1, NULL, 'ace', '1–::

  1W+3M cast and chase clw half round to exchanged places _while{4}_ 1M+2M+2W+3W ½ diagonal R&L (3x,2x,1x) ; 1M+3W cast and chase clw half round to exchanged places _while{4}_ 1W+2W+2M+3M ½ diagonal R&L (to 1,2,3)

9–::

  1c set advancing | cast off one (2c up) ; turn RH 1½ to face 1cnr (polite turn)

17–::

  SetH&G , finish BtoB in middle, M (W) facing up (down)

25–::

  2c+1M & 1W+3c LHA ; 2c+1W & 1M+3c RHA (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11846, '2019-05-12 08:50:03.721632+00', '2019-05-12 08:53:50.534863+00', 4386, 1, 1645, 'ace', '1-::

  1c Fig8 down round 2c

9-::

  1M+2W set | cross RH _while{4}_ 1W+2M cross RH | set ; 1M+2W set | cross _LH_ ending BtoB _while{4}_ 1W+2M cross RH & face out | cast R to end in diagonal line, M facing M, W facing W

17-::

  1c+2c diag RSh Reel4 but on [23-24] 1M & 2W dance straight across (2,1)

25-::

  1c+2c RHA ; LHA (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (3815, '2013-07-13 15:56:13.468812+00', '2019-05-12 09:22:19.363888+00', 13622, 1, NULL, 'ace', '1–::

  1c dance NHJ to 3pl {3} and cast back to 1pl {3} _while_{6} 3c dance up outside {3} and NHJ to 3pl {3} | 1c+3c turn RH and W with M behind face 4M/2M

9–::

  1c+4M & 3c+2M RHA ; 1c+2W & 3C+4W LHA

17–::

  1c +4M+2W & 3c+2M+4W Rsh lead-change Reels3 across

25–::

  All set adv & take hands in circle | retire to places ; all c Petronella in tandem 1 place cclw | All set facing inwards

33–::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (11848, '2019-05-12 09:35:10.820343+00', '2019-05-12 09:37:56.9192+00', 1425, 1, 1645, 'ace', '1-::

  1c turn RH | cast off (2c up) to face 1cnr, LHJ with P ; set to 1cnr, turn inwards to face 3cnr, RHJ with P | set to 3cnr

9-::

  1W+2c & 1M+3c Reels3 across, starting LSh to 4cnr, 1c end LHJ facing 2cnr

17-::

  1c repeat [5-8]  with 2cnr & 4cnr ; 1c cast LSh round 1cnr | cross RH (2,1,3)

25-::

  All circle6 & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3564, '2012-01-22 19:30:31.338873+00', '2021-11-27 17:24:37.770886+00', 7239, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; ½ Fig8 L (Rsh round 4cnr) to face 1cnrs

9–::

  Corner chain: (turn 1cnr RH ½ | corners turn each other LH in the middle ; half RH turn brings 1c back to centre | turn LH 1¼ to 2cnrs)

17–::

  Repeat with 2cnrs, finish 1c facing 1cnr

25–::

  Lsh Reels3{6} on sides | cross RH to (2,1,3)



*(The name means 1,2,3 in the local dialect of Yorkshire sheep farmers, in the area where Derek lived.)*', 3);
INSERT INTO 'dancecrib' VALUES (12604, '2020-02-22 00:50:47.156941+00', '2020-02-22 14:20:51.605907+00', 2315, 1, 202, 'ace', '1--::
  1c+2c ½ RHA | 2c (forming arch) + 1c change places  (to 1x,2x,3) ; 1c+2c ½ LHA | 2c + 1c (forming arch) change places. 2c face out  (1,2,3)
9--::
  Mirror ½ Reels3 on opposite sides, all crossing RH from 1pl (to  3,2x,1x) ; 3c cross RH _while{2}_ 2c+1c change places on sides, 1c in and up | all set (3x,1x,2x)
17--::
  All A&R ; 3c+2c ½ RHA to 3pl/1pl _while{4}_ 1c chase cclw ½ and face 1cnrs
25--::
  CPCP (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11850, '2019-05-14 22:05:51.52767+00', '2019-05-14 22:05:51.52767+00', 19354, 2, NULL, 'ace', '1-4::

  1st man and 2nd woman set advancing, turn with both hands and return to place.



5-8::

  1st woman and 2nd man repeat bars 1-4.



9-16::

  1st couple cross giving right hands, cast off one place as 2nd couple step up, and dance a half figure of eight around 2nd couple.



17-24::

  2nd and 1st couples dance a diamond poussette.



25-32::

  2nd and 1st couples set to partner, turn with both hands once round and merge into a circle four hands round to the left.



Repeat having passed a couple.', 3);
INSERT INTO 'dancecrib' VALUES (11849, '2019-05-14 04:18:48.825746+00', '2019-05-14 04:31:23.632973+00', 18679, 1, 202, 'ace', '1--::

  1c dance down between 2c and cast to 1pl ; dance down between 3c (2c up) and cast to 2pl (2,1,3)

9-20::

  3C R&L

21-24::

  1c turn P RH 1 ½ and face 1cnr

25--::

  Corners Pass and Turn to 2pl centre ready to start (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14273, '2021-09-07 11:29:51.94328+00', '2022-09-13 13:04:28.009695+00', 9358, 2, 3069, 'ace', '1-8::	1C lead down the middle & up

9-16::	1+ 2C allemande. 1C finish for Double Triangles

17-24::	Double Triangles. see NB

25-32::	2+1C, 3+4 C poussette.

33-36::	1M+3W turn RH 1&1/2 times, 1W+3M turn LH 1&1/2 times, to finish 1C in 3rd place on opposite sides, 3C in 2nd place on own sides.

37-38::	All set.

39-42::	1M +4M turns LH 1&1/2 times, 1W+4W turns RH 1&1/2 times, to finish, 1C in 4th place on own sides, 4C in 3rd place on own sides.

43-44::	All set.

45-48::	All turn partner 2 hands

NB:: Double Triangles in Strathspey time, corners start their setting to the left.

', 3);
INSERT INTO 'dancecrib' VALUES (12970, '2020-07-20 11:46:18.606722+00', '2020-12-27 17:01:21.847051+00', 98, 1, 202, 'ace', '1--::

  1W+2W cross LH | chase clw to exchanged places | set

9--::

  1M+2M cross RH | chase cclw to exchanged places | set

17--::

  Circle4 and back

25--::

  All dance BtoB ; all A&R{1+1} | pass opposite person RSh and face new couple', 2);
INSERT INTO 'dancecrib' VALUES (11585, '2019-02-20 00:20:57.504259+00', '2019-02-20 00:27:12.466721+00', 19189, 2, NULL, 'ace', '1-4::

  1st couple set and cast off one place. 2nd couple step up on bars 3-4.

5-8::

  2nd, 1st and 3rd couples set twice with 1st couple advancing to 1st corners on	bars 7-8.

9-16::

  1st couple dance hello-goodbye setting, but on bars 15-16 they pass each other giving left hands and using travelling steps. They face out with the 1st lady facing up between the 2nd couple and the 1st man faces down between the 3rd couple 

17-24::

  1st lady dances a figure of eight around 2nd couple in first place giving left shoulder 	to her first corner. 1st man daces a figure of eight around 3rd couple in third place giving left shoulder to his first corner.  They end by casting into 2nd place on their own side. (lady down, man up)

25-28::

  1st lady dances right hands across with the 2nd couple and 1st man dances right hands across with the 3rd couple				

29-32::

  2nd, 1st and 3rd couples turn (spin) with the right hand.   



*Repeat from 2nd place*', 5);
INSERT INTO 'dancecrib' VALUES (2469, '2012-01-22 19:29:40.678653+00', '2019-05-16 13:47:25.577454+00', 9836, 1, NULL, 'ace', '1–::

  1W+2W & 1M+2M turn 1¼ EH, 1c starting inwards, into line across with 1c BtB in the middle | 1c+2c set ; turn with the other hand ¾ (1c starts up) to (2,1,3), 2c facing out

9–::

  Opposing Reels3 on the sides, 1c start to the R (1M Rsh to 3M, 1W Rsh to 2W), on [13-14] 1c cross to »2cnr position, on [15-16] 1c turn 2cnr persons (2W and 3M) RH into 2diagonal line

17–::

  1c+2cnrs BiL | 1c turn LH to join 1cnr with RH ; BiL | 1c turn LH to finish side by side in the centre, 1W facing up, 1M down

25–::

  1W+2W+3W & 1M+2M+3M RHA ; 1M+1W dance out the end and cast R into (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11751, '2019-03-31 16:33:50.104923+00', '2019-05-16 20:58:38.428032+00', 19082, 1, NULL, 'ace', '1--::

  1M cross as 1W dances to midline and loops R to follow | 1c cast off 2 on W side (2c+3c up) to 3pl, into ; 3c+1c RHA, finish RHJ in middle, join LH with corners

9--::

  3c+1c turn cnrs LH (with polite turns) to (2,3,1,4) ; All turn P RH, 2c to sideline and 3c+1c+4c to Allemande hold

17--::

  3c+1c+4c Allemande (2,4,1,3)

25--::

  Circle8 and back (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8826, '2015-07-31 01:49:06.310377+00', '2021-01-21 10:08:10.234229+00', 11694, 2, 160, 'ace', '1-4::

  1C cross Rsh, 1M+2L change RH as 1L+2M change LH ; (2 1x)

5-8::

  1C cross Lsh, 1L+3L change RH as 1M+3M change LH. (2 3 1)

9-14::

Mirror Reel3 on own sides - 1C in&up, 3C out&down to begin.

15-16::

  3L+1L Turn RH as 3M+1M Turn LH into DT position.

17-24::

  Double Triangles

25-32::

 Circle 6.', 0);
INSERT INTO 'dancecrib' VALUES (11852, '2019-05-18 22:55:24.320594+00', '2019-06-17 10:00:38.294721+00', 19358, 1, 1645, 'ace', '1-::

  1c turn RH | cast in tandem, 1W leading, round 2W (2c up) ; 2c+1M RHA _while{4}_ 1W+3c LHA

9-::

  1c (1W leading) &frac12; alternating tandem LSh Reel3 on M side ; 1c cross (1M leading) to repeat on W side (3,1x,2)

17-::

  3M+1W+2M RHA _while{4}_ 3W+1M+2W LHA ; 1c (1W leading) &frac12; alternating tandem RSh Reel3 across in 3pl

25-::

  1c cross up (1M leading) to repeat in 1pl & 1W ends crossing to (3x,1x,2x) ; all chase &frac12; way clw (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (10053, '2017-08-29 15:38:58.645123+00', '2020-06-27 21:37:53.473642+00', 17681, 2, 1645, 'ace', '1-::

  1c+2c &frac12; RHA | 1c+3c &frac12; LHA ; 1c &frac12; turn LH | cast up (2x,1x,3x)

9-::

  1c turn 2c (M RH, W LH) ; 1c &frac12; Fig8 down round 3c (2x,1,3x)

17-::

  Mirror Reels3 on the sides (1c up between 2c to start)

25-::

  1c &frac12; Fig8 up round 2c ; all set | all cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (9594, '2017-02-12 00:33:48.828065+00', '2017-02-13 18:52:24.781486+00', 17578, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c R&L

9--::

  All set | All turn P BH ; Circle8 L two places | 3M+1M & 1W+3W change places RH 

17--::

  All M (at top) & All W (at bottom) RHA ; ½ Reels4 on both sidelines 

25--::

  All W (top) & All M (bottom) Circle4 L ; with 1W and 2M leading both circles unwind to own side (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (1660, '2012-01-22 19:28:53.530792+00', '2021-01-21 22:45:01.601723+00', 11684, 1, NULL, 'ace', '1–::

  All set | turn P RH ½ and face P, cast R to P''s place | turn RH ½ for

9–::

  All Promenade (1,2,3)

17–::

  1c cross RH | cast off (2c up) ; All set | 1c turn RH ½ and face down in the centre

25–::

  1c dance between 3c, cast up, dance between 2c and cast off to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3040, '2012-01-22 19:30:07.953808+00', '2020-06-28 08:28:37.4791+00', 12454, 1, NULL, 'ace', '1–::

  1M+2M+4W+5W all dance Fig8 round P and dancer to the R (pass between, cast R, dance up and Lsh round P) to places, at end 1M and 3W face out

9–::

  1M (1W follows) & 3W (3M follows) cast off (2c+4c up) and cross (to 2,1x,4,3x,5) ; 2c+1c & 3c+5c LHA

17–::

  1c+3c set advancing swiveling R into DTr position facing opposite sides | All dance 6 bars of Double DTr (1c+3c now face own side)

25–::

  1c+3c dance out casting off (4c+5c up) | All set ; All turn P RH (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (11587, '2019-02-20 19:06:05.119609+00', '2021-06-06 13:25:50.771857+00', 8544, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; 2c & 1c turn P RH into promhold facing up (2,1)

9--::

  Allemande (1,2)

17--::

  1c & 2c turn P RH into ; 1c+2c RHA ready for (1,2)

25--::

  Poussette (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (12975, '2020-07-23 23:43:59.285499+00', '2020-07-24 12:20:00.989464+00', 9661, 1, 202, 'ace', '1--::
  Parallel Reels3 on sides, 1c RSh to 2c. 1W faces out (1,2,3)
9--::
  1W (1M following) chase clw round the set to 1pl (1,2,3)
17--::
  1c+2c RHA ; LHA (1,2,3)
25--::
  2C Poussette (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (12973, '2020-07-22 22:02:41.303923+00', '2020-07-28 15:59:08.877697+00', 19164, 1, 202, 'ace', '1--::
  All set | turn P BH ½ ; repeat (1,2,3)
9--::
  1c chase clw round own lines back to 1pl
17--::
  Parallel Reels3 on sides, 1c RSh to 2c (1,2,3)
25--::
  All set | 1c+2c Circle4 L ½ _while{2}_ 3c turn P BH ½ (to 2x,1x,3x) ; all set | 2c turn P BH ½ _while{2}_ 1c+3c Circle4 L ½ (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (12971, '2020-07-20 23:23:11.349266+00', '2020-07-28 17:48:39.428914+00', 19147, 1, 202, 'ace', '1--::
  1c+2c S&Link ; 1c+3c S&Link (2,3,1)
9--::
  3c+1c The Knot (2,1,3)
17--::
  2c+1c ½ Poussette ; 1c ½ Mirror Fig8 on sides (2c up on [21-22], 3c up on [23-24]) (2,3,1)
25--::
  All dance BtoB ; all turn P BH (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (11589, '2019-02-20 22:38:38.812069+00', '2019-02-20 22:38:38.812069+00', 7785, 1, NULL, 'ace', '1--::

  1W, 1M following, cast off, cross (2c up), cast off, cross (3c up), 1c set to P (2,3,1)

9--::

  1c dance to top, cast off one and turn P RH to face 2W in promhold

17--::

  ½ Reel3 on 2diag, Rsh to 2W ; ½ Reel3 on 1diag, Rsh to 2M

25--::

   ½ Reel3 on 2diag, Rsh to 3M ; ½ Reel3 on 1diag, Rsh to 3W, finish in centre facing up

33--::

  2c+1c LHA ; 1c+3c RHA (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11590, '2019-02-20 23:28:05.022398+00', '2019-02-20 23:35:50.206721+00', 19194, 2, NULL, 'ace', '1-2::  1s dance down to between 3s as 2s step up



3-4::  1s, dropping hands, turn about (1M LSh, 1L RSh) with 2 pdb to finish side by side facing up



5-8::  1M turns 3M LH, then 1/2 turn 2M RH, as 1L turns 3L RH and 1/2 turn 2L LH. 1s finish back in 1st place facing in.



9-16::  1s+2s+3s dance Inveran reels of 3 on the sides (1s crossing down to start and crossing back to own side), to finish 1 2 3



17-24::  1s cross RH (2s step up on bars 19-20), cast down below 3s, dance up to 1st corners



25-32::  1s 1/2 reel of 4 with 1st corners, pass LSh and dance 1/2 reel of 4 with 2nd corners, to finish (3) (1) (2).



33-40:: 3s+1s+2s Set & Link for 3 twice, finishing in order 2 1 3.', 4);
INSERT INTO 'dancecrib' VALUES (11591, '2019-02-21 01:00:01.891193+00', '2019-02-21 01:10:05.395207+00', 8549, 1, 202, 'ace', '1--::
  1c+2c & 3c+4c DblFig8, middle couples crossing out (1,2,3,4)
9--::
  1c+2c & 3c+4c change places on sides EH, 2c & 3c in and up/down | all set (to 2,1,4,3) ; 1c & 4c turn LH/RH 1½ and face nearest cnrs (2,1x,4x,3)
17--::
  1c+4c Dbl SetH&G. 4c & 1c in the middle face out (2,4,1,3)
25--::
  Mirror Tandem Reels3{6} across, 4c (4W leading) RSh to 2W and 1c (1W leading) LSh to 3W | 4c & 1c (4W & 1W leading) dance across to 2pl/3pl (2,4,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (11592, '2019-02-21 01:54:00.375471+00', '2019-02-21 02:03:47.720575+00', 8552, 1, 202, 'ace', '1--::
  3C Gr-Chain, 1c crossing (1,2,3,4)
9--::
  1c+2c RHA ; LHA (1,2,3,4)
17-20::
  1c cast to 4pl (2c+3c+4c up)
21-28::
  Circle8 and back (2,3,4,1)
29-32::
  1c cast back to top (1,2,3,4)
33--::
  1c (starts inwards) weave down on sides round 2c, 3c, 4c and turn P LH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11593, '2019-02-21 03:07:20.869278+00', '2019-02-21 03:12:20.329722+00', 8547, 1, 202, 'ace', '1--::

  1c Fig8 round 2c (1,2,3,4)

9-12::

  1c cross RH | cast (2c up) (2,1x,3,4)

13-20::

  1c Fig8 round 3c (2,1x,3,4)

21-24::

  1c cross RH | cast up (2c down) (1,2,3,4)

25--::

  1c lead down ; 1c followed by 4c, 3c & 2c, lead up to top into promhold (1,4,3,2)

33--::

  4C Allemande (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3004, '2012-01-22 19:30:06.531162+00', '2019-02-21 20:23:26.949742+00', 5219, 1, NULL, 'ace', '1–::

  1M+2M & 1W+2W 1½ RH turn to change places ; 1M+3M & 1W+3W 1½ LH turn to change places

9–::

  1M+4M & 1W+4W 1½ RH turn to change places ; 1c 1½ LH turn to 4plx, facing out (2,3,4,1x)

17–::

  1c weave up: behind 4c, between 3c, behind 2c ; 1c turn RH to finish between 2c, LHJ with 2c

25–::

  1c+2c BiL | 1M+2W & 1W+2M turn LH, 1c finish between 3c, RHJ, and LHJ with 3c ; 1c+3c repeat [25-28], finish between 4c

33–::

  1c+4c repeat [25-28], finish in 4plx ; 1c 1½ RH to 4pl and form an arch

41–::

  2c followed by 3c+4c dance down through arch, cast up on own sides (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (8751, '2015-04-17 15:07:22.46753+00', '2015-04-17 15:07:22.46753+00', 14631, 2, NULL, 'ace', '1-4::

    1s, 2s and 3s set to partner, all cross over RH (men face down, ladies face up)

5-8::

    1s, 2s and 3s chase cw half-way (1M stay facing out)

9-12::

    1M, followed by partner cast up 1 place, cross to 2nd place opp side and pull back Rsh. 

    2s step down on 11&12

13-16::

    1s RH turn to face 1st corner

17-20::

    1s dance half diagonal reel of 4 with 1st corners, pass Rsh to 2nd corners

21-24::

    1s dance half diagonal reel of 4 with 2nd corners, 1s finish in 2nd place own side (1M face up, 1L down)

25-30::

    1s dance 6 bar Rsh reel of 3 on own sides (1M with 2L+3L and 1L with 3M+ 2M)

31-32::

    2s and 3s cross RH to own sides', 3);
INSERT INTO 'dancecrib' VALUES (11853, '2019-05-18 22:58:32.828891+00', '2019-05-18 22:58:46.732028+00', 19356, 1, 1645, 'ace', '1-::

  1W+2M cross RH _while_ 3W casts up (2W down) | 2M+3W pass RSh _while_ 1W+3M pass LSh ; 3M+2M+1W+2W 1&frac14; LHA to (M: 1,2,3; W: 3,2,1)

9-::

  1W+2M cross LH _while_ 3W casts down (2W up) | 1c pass RSh _while_ 3W+2M pass LSh ; 1c+2c circle4 1&frac14; to L (1,2,3)

17-::

  Modified set & link: all set | 2M+3M & 1W+2W cast clw to ends _while_ 1M+3W turn LH to centre line facing ends ;

      all M (top) & W (bottom) RHA, 1M & 3W end facing 2cnrs

25-::

  2M+1M+3W+2W &frac12; diagonal RSh Reel4, 1M+3W end passing RSh to own sides (M: 3,1,2; W: 2,3,1) ; all turn new P BH.

', 5);
INSERT INTO 'dancecrib' VALUES (1678, '2012-01-22 19:28:56.150305+00', '2019-05-01 06:34:41.430066+00', 222, 1, NULL, 'ace', '1–::

  1c set, cast off (2c up) ; 1c set, 1W casts up to between 2c and 1M casts off to between 3c, in facing lines across

9–::

  All A&R ; circle6 L, 1c finish facing 1cnr.

17–::

  Set to and turn 1cnrs BH ; set to 2cnrs, pivoting R to face P | turn P BH to (2,1,3)

25–::

  2c+1c Circle4 L ; 2c+1c+3c turn P RH.   

', 3);
INSERT INTO 'dancecrib' VALUES (9595, '2017-02-13 03:46:32.164975+00', '2017-02-13 03:46:32.164975+00', 17527, 1, NULL, 'ace', '1--::

  1c lead down (2c up) ; and up to face 1cnr

9--::

  Set H&G (2,1,3)

17-28::

  R&L for 3 couples

29-32::

  1c turn RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (1968, '2012-01-22 19:29:12.51537+00', '2017-02-13 14:06:55.21602+00', 1293, 1, NULL, 'ace', '1–::

  1c pass Rsh to 2pl BtoB, W facing up, M dn (2c up) | with 2c+3c facing diagonally in, All set ; 2c+1W & 1M+3c Circle3 L, breaking (1W/1M leading) to sideline, into

9–::

  Circle6 L | keep hands in circle, all set ; drop hands, dancing on clw {1} and casting back cclw to (2,1,3)

17–::

  1c pass Lsh to 2pl BtoB, M facing up, W dn | 2c+3c facing diagonally  in, All set ; 2c+1M & 1W+3c RHA to (2,1x,3), the corners facing out

25–::

  Reels3{6} on the side, 1c starting Lsh to 1cnr | 1c cross RH', 3);
INSERT INTO 'dancecrib' VALUES (12606, '2020-02-23 11:02:13.801964+00', '2020-02-23 11:11:22.251886+00', 17805, 1, NULL, 'ace', '1--::

  1c+2c+3c Reels3 on opposite side, all couples crossing down from 1pl (1x,2x,3x)

9--::

  1c dance down between 3c | and cast up to 2plx (2c up) (2x,1x,3x) ; S&Link3 into facing lines across

17-28::

  R&L for 3 couples, start up/down (diagonal crossing along 1diag.)

29-32::

  S&Link3 (3,1,2)



', 3);
INSERT INTO 'dancecrib' VALUES (2340, '2012-01-22 19:29:32.180307+00', '2019-02-21 21:37:49.630228+00', 9006, 1, NULL, 'ace', '1–::

  1c cross (no hands) to 3plx and face out (2c+3c dance up) (2,3,1x) | 2c+1c »The Capstan«: (2c (start inwards) + 1c (outwards) dance 1½ times »easy shoulder« round 3c on the side) 2c finish facing up (1x,3,2)

9–::

  repeat from new positions, to (1,2,3)

17–::

  1c+2c set | cross RH ; set | 1c cast off as 2c cross up (no hands, no loop) (2,1x,3)

25–::

  1c (cross down) ½Fig8 down ; 1c turn 3c 1½ times on sideline, 1c starting inwards (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (8033, '2013-09-13 20:45:03.817296+00', '2019-02-21 21:50:52.373705+00', 9583, 1, NULL, 'ace', '1–::

  1c+2c circle4 L ; 1c face 2c and set, 1c swivel to face up | 1c cast as 2c dance up (2,1,3)

9–::

  1c+3c repeat (2,3,1)

17–::

  Mirror Reels3 on the sides, 3c starts down and out (2,3,1)

25–::

  All set | 2c+1c turn P BH and face down/up/down _while_{2} 3c makes arch ; 2c dance under arch & cast to top _while_{4} 1c cast to top & dance under arch (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (12609, '2020-02-23 23:41:18.423054+00', '2020-02-23 23:41:18.423054+00', 5373, 2, 160, 'ace', '1-8::  1s cross down and dance reel of 3 on opposite sides.
9-16:: 1s  cross down and dance reel of 3 on own sides.
17-24::  1s cross to below 2s , cast off round 3s [2s and3s up]; 1s set and cast up [3s down]. 2 1x 3.
25-32::  1s set, 2s 3s set AS 1s turn RH half; All turn RH once round.', 0);
INSERT INTO 'dancecrib' VALUES (3233, '2012-01-22 19:30:16.744101+00', '2017-02-13 14:56:50.718966+00', 5980, 1, NULL, 'ace', '1–::

  1c+2c+3c set | {1M+3W petronella-turn to finish BtoB between 2c with 1M facing up and 3W facing down ; dance through P''s place | cast R to exchanged places} _while_{6} {1W+3M cast clw to other end ; petronella to finish BtoB with 3M facing up and 1W facing down | both dance out to exchanged places (3x,2,1x)

9–::

  All set, circle6 L. On [14], all drop hands, dance into the centre pulling Rsh back to face out, and dance clw to starting places (3x,2,1x)

17–::

  3c+2c+1c repeat figure [1-8] to (1,2,3)

25–::

  2c followed by 1c dance down NHJ between 3c and cast up to 1pl / 2pl ; 1c with 3c following dance up NHJ between 2c and cast off to 3pl / 2pl (to 2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2832, '2012-01-22 19:29:59.257057+00', '2017-02-13 17:18:52.014982+00', 4579, 1, NULL, 'ace', '1–::

  1c+2c set | cross RH ; set | ½ RHA (3c dance in) to finish ready for

9–::

  2c+1c+3c Promenade, 2c+1c finishing BHJ in position for

17–::

  2c+1c ½ Poussette ; merging into 1c+2c+3c circle6 L, 1c+2c finish ready for

25–::

  1c+2c Allemande', 3);
INSERT INTO 'dancecrib' VALUES (11855, '2019-05-21 16:39:50.944589+00', '2019-05-21 16:41:27.537453+00', 19359, 1, 1645, 'ace', '1-::

  1c+2c Circle4 to L ; turn P BH & face up | 1c cast off to face 1cnrs as 2c dance up (2,1,3)

9-20::

  1c turn 1cnrs 1&frac12; RH ; 1c+1cnrs &frac12; diagonal RSh Reel4 ;; 1c followed by 1cnrs chase &frac12; way clw, 1cnrs end back in place as 1c pass RSh to face 2cnrs _while{4}_ 2cnrs adv & ret  

21-32::

  Repeat [9-20] with 2cnrs, 1cnrs adv & ret on [29-32], 1c end passing RSh to (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2302, '2012-01-22 19:29:30.6565+00', '2017-10-25 22:03:22.087031+00', 2401, 1, NULL, 'ace', '1–::

  1c set, cast off (2c up) ; dance between 3c and cast up to 1cnrs

9–::

  1c turn 1cnrs RH _while{2}_ 2cnrs set, 1c turn LH _while{2}_ corners chase clw one place ; repeat with 1cnrs (2cnr persons), to finish 1c BtoB in middle 1W facing up, 1M down

17–::

  3c+1W & 1M+2c circle3 L {3}, break with 1c leading into ½circle6 L finishing (2,1x,3) {3} | all set

25–::

  Reels3{6} across, Lsh to 3cnr | 1c cross RH (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (11856, '2019-05-21 16:45:02.982851+00', '2019-05-21 16:45:12.918912+00', 19360, 1, 1645, 'ace', '1-::

  All cross RH | set ; 1c+2W & 2M+3c &frac12; RSh Reels3 across (1,2,3)

9-::

  All S&Link3 twice (3x,2x,1x)

17-::

  3c+2c &frac12; R&L _while(4}_ 1c cross LH | set (2,3,1) ; all turn P RH

25-::

  All Circle6 & back (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11594, '2019-02-22 01:41:42.657217+00', '2019-02-22 01:49:39.274537+00', 16139, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*



1--::

  1c+2c & 3c+4c The Tournée (2,1,4x,3x)

9--::

  1c+4c LHA _while{4}_ 2c & 3c chase clw ½ (to 3,1,4x,2x) ; 3c+1c & 4c+2c RHA

17--::

  Reels4 on sides (3,1,4x,2x)

25--::

  1c+4c turn P RH ¾ | ½ Reel4 on midline | turn P LH ¾ to sides _while{8}_ 3c & 2c chase clw ½ ; turn P RH (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (3510, '2012-01-22 19:30:28.475913+00', '2020-12-18 20:20:25.83038+00', 7045, 1, NULL, 'ace', '1–::

  1c turn RH ½ to 2pl in middle facing P (2c up) | 1c set ; cross RH and cast R round 3cnr to midline

9–::

  1c pass RH and cast R round 4cnr to 2pl _while{4}_ 2c+3c set, cross RH and face out ; ½Reels3 on the sides (1c Lsh to 3cnr position).  At the end 2c face 3c up/down (3x,1,2x)

17–::

  1c cross RH and cast Rsh round 1cnr position _while{4}_ 3c set to 2c and change places RH ; ½Reels3 across, (1c Lsh to 4cnr position), 1c finish in 2plx Lsh to Lsh

25–::

  1M+2W+3W & 1W+2M+3M RHA on the sides ; flowing into 2c+1M & 1W+3c LHA (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11595, '2019-02-22 02:00:24.865855+00', '2019-02-22 02:02:46.212097+00', 16138, 1, 202, 'ace', '1--::

  1c+2c Chain Progression (2,1,3)

9--::

  1c+1cnrs A&R ; dance BtoB (2,1,3)

17--::

  1c+2cnrs repeat [9-16]

25--::

  1c cross RH | cast (3c up) ; ½ Fig8 up round 3c (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11513, '2019-01-17 00:04:06.903969+00', '2020-06-27 21:01:19.829911+00', 17682, 1, 1645, 'ace', '1-::

  All W dance LSh round cnr, &frac12; RHA, dance LSh round P, LHA to place

9-::

  All M repeat with opposite hand, starting RSh round cnr

17-::

  Speedwell: all turn P &frac34; RH | W &frac23; LHA ; W &frac12; turn facing M RH | M &frac23; LHA (3,1,2)

25-::

  Circle6 to L, pivot : chase back to (3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (12607, '2020-02-23 11:22:43.638737+00', '2020-02-23 13:24:51.206716+00', 19851, 1, NULL, 'ace', '1--::

  1c lead down RHJ, cross below 3c and cast up to 1plx | 1c turn 2c EH ½ and face out (2,1x,3)

9--::

  ½ Reels3 on the sides, Rsh to 1cnr, 1c curve to finish BtoB W facing up, M down ; ½ DTr 

17--::

  2c+1M & 1W+2c ½ Rsh Reel3 across, at end 1c curve into DTr position facing opp side ; ½ DTr, finish (3x,1,2x) all facing clw 

25--::

  All chase ½ round clw ; 1c turn RH 1½ (or birl) (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (9596, '2017-02-14 01:13:31.826164+00', '2017-02-14 01:31:05.637863+00', 17582, 1, NULL, 'ace', '1--::

  1c+4c RHA (2c+3c to ends) and finish as middles facing ends ; All set to opposite | All turn opposite RH ½ (1,2,3x,4x)

9--::

  2c+3c LHA _while{4}_ 1c+4c chase clw ½ round set | 2c+3c dance out their end and cast back (4,2,3x,1x)

17--::

  All set | 4c+2c & 3c+1c ¾ R&L (2,4,1x,3x)

25--::

  Circle8 and back(2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (2453, '2012-01-22 19:29:39.673365+00', '2019-02-22 17:18:09.115205+00', 9635, 1, NULL, 'ace', '1–::

  Mirror Reels4 on the sides (M Rsh, W Lsh), to start 1c+3c cross down, 2c+4c out and up (1x,2,3x,4)

9–::

  1c+3c cross down into ½ Fig 8 round C below ; 2c+4c cross up into ½ Fig 8 round C above (1,2x,3,4x)

17–::

  1c+3c set to P | cross RH ; 1M+3W change places LH | 1W+3M repeat RH (3,2x,1,4x)

25–::

  2c+3c & 1c+4c set | ½ RHA (release early) ; 3c+1c turn P 1½ BH and face out to continue (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (11596, '2019-02-22 17:56:51.449823+00', '2019-02-22 17:58:40.808058+00', 19195, 1, NULL, 'ace', '1-4::

  All W set and cast to P’s place facing in _while{4}_ 1M+3M pass Rsh to next W place cclw _while{4}_ 2M+4M cast to P’s place and dance cclw to next W place, all M face out

5-12::

  Half Schiehallon Reel 

13-16::

  All W RHA 1¼ to next W place _while{4}_ All M chase clw to next M place (M 3,4,1,2; W 2,3,4,1)

17--::

  All M petronella 1 pl cclw and set _while{4}_ All W set and petronella 1 pl cclw ; repeat

25--::

  All M RHA 1¼ ; turn P LH (4,1,2,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2229, '2012-01-22 19:29:26.868518+00', '2019-02-22 18:33:16.590105+00', 9389, 1, NULL, 'ace', '1–::

  All C set | turn BH ; open into circle8 L half round (3,4,1,2)

9–::

  All C turn RH 1½ and dance 1 position on (M cclw, W clw) passing Lsh ; repeat (to 1,2,3,4)

17–::

  1c facing 3c cross RH, into circle4 ½ round to the L and out to own places (M on the R) ; 2c+4c repeat

25–::

  All C set in promhold facing in | all C set advancing, at end, keeping hold, swivel towards P to face out ; dance out to place and clw to next position', 2);
INSERT INTO 'dancecrib' VALUES (2304, '2012-01-22 19:29:30.73593+00', '2019-02-22 22:07:19.351098+00', 2409, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c ½R&L ; 1c+4c ½R&L (2x,4,1,3x)

9–::

  2c+4c & 1c+3c ½circle4 L | 2c+3c ½circle4 R ; 1c lead to top (others step down) (to 1x,4x,3x,2x)

17–::

  End couples facing middle couples All Set H.Schottische ; half G-Chain (2,3,4,1)

25–::

  All Reels4 on own sides.', 3);
INSERT INTO 'dancecrib' VALUES (9808, '2017-04-24 14:55:00.309707+00', '2021-02-20 20:20:51.599778+00', 9783, 2, 1824, 'ace', '1-8:: 1s lead down middle followed by 2s who dance up to follow 1s. On bar 4 1s separate and dance around 2s, lead up to top & cast to 2nd place while 2s dance up to top and cast off to 1st place.



9-16:: 1s petronella turn ending man between 3s, lady between 2s , 1W+2s & 1M+3s join hands and set up & down. (repeat three more times as follows): 1s petronella turn to sides, 1W+2M+3M & 1M+3W+2W, join hands and set across.



17-24:: 1s petronella turn ending man between 2s, lady between 3s, 1W+3s & 1M+2s join hands and set up & down: 1s petronella turn to own sides, 1W+2W+3W & 1M+2M+3M, join hands and set across.



25-32:: 2s+1s+3s circle 6H round & back

', 2);
INSERT INTO 'dancecrib' VALUES (13570, '2021-01-22 08:10:19.669508+00', '2021-01-22 08:14:13.730982+00', 20206, 1, 202, 'ace', '1--::

  1c+2c DblFig8, 1c crossing down (1,2,3)

9--::

  1c long cast to 2pl (2c up) : all dance BtoB (2,1,3)

17--::

  1c+3c DblFig8, 1c crossing down (2,13)

25--::

  Gr-Chain no hands (2,13)', 2);
INSERT INTO 'dancecrib' VALUES (11858, '2019-05-24 21:00:17.070235+00', '2019-05-24 21:15:52.721944+00', 19361, 1, 1645, 'ace', '1-::

  1c set | cast (2c up) ; 1c turn LH to face 1cnrpos _while{4}_ 2c & 3c set, pulling RSh back | rotate 1 cnr place clw

9-::

  1c+2W+3M &frac12; diag RSh Reel4, 1c end facing P in centre ; 1c turn &frac34; LH | &frac12; turn 3W/2M RH

17-::

  2M+3W+1c &frac12; diag RSh Reel4, 2M+3W end facing in centre ; 2M+3W turn &frac34; LH | &frac12; turn P

25-::

  2c+3c &frac12; diag RSh Reel4, 3M & 2W end on centre line ; 3W+1W+3M & 2W+1M+2M RHA

33-::

  1W+3c & 1M+2c chase &frac12; way clw & form circle with 2M+1M, 2W+3M & 1W+3W in 1st, 2nd & 3rd places ; circle6 &frac34; to L (3,1,2)

', 5);
INSERT INTO 'dancecrib' VALUES (12605, '2020-02-22 15:04:18.818674+00', '2020-02-22 21:51:08.754274+00', 14851, 1, NULL, 'ace', '1--::

  1c+2c Circle4 L ; 2c+3c Circle4 L (1,2,3)

9--::

  1M+2W+3M set, cast clw past one person ; RHA to the new positions and face out                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       

17--::

   Reels3 on both sidelines, 1W+1M+3W (1M Rsh to 3W) and 3M+2M+2W (2M Rsh to 2W)  

25--::

  1W+2M+3W LHA | dance out through own place and cast cclw past one person {4} (3,1x,2)

33--::

  All S&Link3 into facing lines across ;  the top line across (2W,1W,2M) S&Link3 to own sides _as_ 1M set and cast to 2M place _and_ 3c stand (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (12608, '2020-02-23 17:38:10.465538+00', '2020-02-23 18:58:57.295995+00', 9291, 1, NULL, 'ace', '*Begin (1x,2)*

1--::

  1W+2W turn RH ; 1M+2M turn LH 1¼ and join R hands with P (on 1diag)

9--::

  H.Schottische Balance in Line [like Common Schottische Balance, but with HS step] ; ½ Reel4  

17--::

  1c+2c turn RH ½ and W join LH in middle | "Common Schottisch Balance" [set R, changing hands (join new under old ) and set L (repeat change hands) ; 1W+2W turn LH ½ and join RH with other M | "Common Schottisch Balance"

25--::

  1c+2c ½Reel4 on 1diag. ; 1M+2W following and 2M+1W following chase clw half round to (2,1x)

', 0);
INSERT INTO 'dancecrib' VALUES (3614, '2012-07-21 11:45:53.725327+00', '2017-02-14 15:21:31.470621+00', 9701, 1, NULL, 'ace', '1–::

  1C long cast to 2pl (2c up) ; ½ Fig8 up (2,1x,3)

9–::

  All set | cross RH ; All set | 2c+3c cross RH  _while_{2}   1c turn RH & pivot R to face 1cnr

17–::

  1c Turn 1cnr BH | pass Rsh ; turn 2cnr BH | pass Rsh to (2,1,3)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (1817, '2012-01-22 19:29:03.982127+00', '2019-02-22 23:42:30.532656+00', 721, 1, NULL, 'ace', '1–::

  1W & 3W cross down & cast up round 2M & 4M into centre to face them ; set | swivel L & dance up the middle to places

9–::

  1M & 3M repeat (swivel R)

17–::

  All circle8 & back

25–::

  1c+2c change places Easy Hand on sides (1c passes outside, 2c polite turn) | 1c cross down as 3c cast up ; 1c+4c change places no hands on sides (1c passes outside, 4c polite turn) | 1c cross RH (to 2, 3, 4, 1)', 2);
INSERT INTO 'dancecrib' VALUES (11847, '2019-05-12 09:18:24.892941+00', '2019-05-26 09:02:41.481128+00', 5931, 1, 1645, 'ace', '1-::

  1c dance below 2c | out & round 3c ; up to top | cast off (2c up) to (2,1,3)

9-::

  1W+2c & 1M+3c &frac12; LSh Reels3 across ; 1c dance track of &frac12; RSh Reels3 on sides _while{4}_ 2c & 3c change pl RH on sides | set (3x,1x,2x)

17-::

  Repeat [9-16] from new places (2,1,3)

25-::

  1c turn 1cnr RH | pass RSh ; turn 2cnr LH | turn P &frac34; RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11860, '2019-05-26 16:29:19.171238+00', '2019-05-26 16:36:46.57051+00', 10143, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; turn LH to face 1cnrs

9--::

  1c turn 1cnrs RH | 4cnrs LH ; 3cnrs RH | 2cnrs LH into facing lines3 across

17--::

  All set | 1c turn BH ¾ _while{4}_ cnrs set diagonally ; repeat. 1c face 1cnrs

25--::

  6 bars of SetH&G | Petronella turn (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11597, '2019-02-23 00:56:44.203641+00', '2019-02-23 01:06:20.828051+00', 16136, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; ½ Fig8 R (2,1x,3)

9--::

  ½ Reels3 on sides, 1c RSh to 2cnrs ; ½ Reels3 across, 1c LSh to 3cnrs[pos]. On [16] 1c face 3cnrs[pos]

17--::

  1c set to 3cnr[pos] | cast RSh round each other to 1cnr[pos] _while{2}_ 1cnrs dance into centre and swirel R to face own cnr ; repeat, 1cnrs finishing in exchanged places and 1c facing 4cnrs[pos]

25--::

  Repeat with 4cnrs[pos] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11861, '2019-05-26 18:18:55.373027+00', '2019-05-26 18:25:40.584857+00', 10144, 1, 202, 'ace', '1--::

  1c turn RH ½ | lead down (2c up on [3-4] | lead up and face 2W in promhold

9--::

  ½ Reel3 on 2diag, RSh to 2W. On [12] 1c turn inwards and face 3W in promhold ; ½ Reel3 on 1diag, RSh to 3W. On [16] 1c turn inwards and face 3Mplace in promhold

17--::

  ½ Reel3 on 2diag, RSh to 2W in 3Mplace. On [20] 1c turn inwards and face 2Mplace in promhold ; ½ Reel3 on 1diag, RSh to 3W in 2Mplace. 1c face 1cnrs

25--::

  Corners Pass and Turn. 1c slap RH when passing to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12612, '2020-02-24 22:11:31.835797+00', '2020-02-25 16:45:41.766511+00', 16715, 1, NULL, 'ace', '_Crib writing in progress_   

*Dancers 1,2,3,4 form a square (N,E,S,W), 5 in middle faces N.*

1--::

  5 sets to 1+2 | 5+1+2 RHA ; 5 sets to 3+4 | 5+3+4 LHA 

9--::

  (1+2 promhold)+5+(3+4 promhold) Rsh Reel3, 5 starts North

17--::

  5 sets to (1+2) | 5+1+2 petronella 1 place clw ; 2 sets to (3+4) | 2+3+4 petronella 1 place clw (5,1,2,3,4)

25--::

  L&R for 5 dancers [the four cnrs dance a full L&R, 5+3 facing 1+2 to start, 4 joining in as follows:  2+3 pass LH as 5+1+4 ½ LHA (4 now outside the set) | 5+1 pass 2+3 RH and 4 returns to centre ; 2+3 pass LH as 5+1+4 ½ LHA | 5 & 1 pass 2 & 3 RH and 4 returns to centre] (5,1,2,3,4)

  

', 3);
INSERT INTO 'dancecrib' VALUES (8755, '2015-04-24 16:26:21.035445+00', '2019-09-08 11:05:05.562109+00', 16222, 1, NULL, 'ace', '1--::

  1c lead down ; cast up behind own line to places (1,2,3)

9--::

  All Circle6 and back (1,2,3)

17--::

  1c+2c set to P | ¾ R&L, 1c finish facing out (2,1,3)

25--::

  1c cast R round next person and meet ; Turn RH 1¾ moving down (3c up) to (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (12277, '2019-10-11 14:08:25.849794+00', '2020-02-25 22:19:35.66176+00', 19691, 1, 1645, 'ace', '1-::

  1c+3c R&L

9-::

  2c+4c R&L

17-::

  1c+3c &frac12; turn RH & twirl away ;

  chase &frac14; clw & dance in, M between side couples, W RSh round 4M/2M, 1c/3c end facing 4c/2c

25-::

  1c+4c & 3c+2c RHA ; drop hands & dance round clw to original places (1,2,3,4)

33-64::

  Repeat [1-32] with 2c & 4c leading

65-::

  All W figure of 8 in front of P & next M

73-::

  All M repeat in front of P & next W

81-::

  Grand chain &frac12; way (1 bar per hand) ; spin partner

89-::

  Repeat to original places

', 2);
INSERT INTO 'dancecrib' VALUES (2055, '2012-01-22 19:29:17.337028+00', '2021-02-20 20:23:24.269035+00', 9775, 1, NULL, 'ace', '1–::

  1c+2c+3c Mirror Reels3 on the sides, 1c starts in

9–::

  2c dance on to 1pl [9-10] _while_ 1c lead down the middle and up, finish in 2pos facing up 1M behind 1W

17–::

  1W leading, 1c+2M+3W Lsh lead-change diagonal Reel3, 1c finish as before

25–::

  1W leading, 1c+2W+3M Rsh lead-change diagonal Reel3. 1c finish in middle own side facing up for

33–::

  2W+1W+3W RHA _while_{4} 2M+1M+3M LHA ; 1c NHJ dance out the top and cast to 2pl

', 2);
INSERT INTO 'dancecrib' VALUES (11600, '2019-02-23 02:32:24.727806+00', '2019-03-20 23:54:08.850516+00', 16141, 1, 202, 'ace', '1--::

  Circle8 and back

9--::

  1c+3c set advancing | ½ RHA ; lead out to opposite place | set (3,2,1,4)

17--::

  2c+4c repeat [9-16] (3,4,1,2)

25--::

  All turn P RH into promhold and Promenade cclw to original place (1,2,3,4)

33--::

  All set to P | turn P RH ; set to cnr | turn cnr LH. All W face out (1,2,3,4)

41-56::

  Schiehallion Reels (1,2,3,4)

57--::

  All set to cnr | turn cnr LH ; set to P | turn P RH and face P (1,2,3,4)

65--::

  Interlocking Reels4. All W face out (1,2,3,4)

73--::

  Double M-Chain (1,2,3,4)

81--::

  Circle8 and back (1,2,3,4)', 2);
INSERT INTO 'dancecrib' VALUES (11599, '2019-02-23 01:48:05.368853+00', '2019-02-23 01:52:36.982111+00', 16143, 1, 202, 'ace', '1--::

  1c+2c Circle4 and back (1,2,3)

9--::

  1c lead down (2c+3c up on [11-12]) ; and up to 3pl (2,3,1)

17--::

  3c+1c RHA ; LHA (2,3,1)

25--::

  1c dance up to 1pl (2c+3c down on [25-26]) | cast (2c up) ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11598, '2019-02-23 01:25:30.370724+00', '2019-02-23 01:37:41.167673+00', 16137, 1, 202, 'ace', '1--::

  1c & 3c cross RH | cast (2c & 4c up) ; turn RH, 1W & 3W facing up with P behind

9--::

  Reels3 in tandem (with lead change) on 2diag, 1W & 3W RSh to 4cnrs. 1c & 3c finish as on bar [9]

17--::

  Reels3 in tandem (with lead change) on 1diag, 1W & 3W LSh to 1cnrs. 1c & 3c finish in DTr[pos] facing own sides

25--::

  All set | 1c+4c & 3c+5c turn RH 1½ on W side, LH 1½ on M side to change places | all set (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (14354, '2021-10-06 21:07:40.449042+00', '2021-10-06 21:26:44.970756+00', 20501, 1, 202, 'ace', '1--::
  1c in tandem (1M leading) dance down ; 1c in tandem (1W leading) dance up
9--::
  Reel3 across, 1c in tandem (1W leading) LSh to 2M. 1c face 1cnrs
17--::
  *Modified Corners Pass and Turn* : same as Corners Pass and Turn except that cnrs A&R (2,1x,3)
25--::
  1c ½ Fig8 up round 2c ; all dance BtoB (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12601, '2020-02-21 17:12:50.024349+00', '2020-02-22 23:00:28.648851+00', 3140, 1, NULL, 'ace', '1--::

  Reels3 on opposite side (1c cross down, 2c start out and up), at end 1c cross down LH to face 3cnr _as_ 2c dance to 1pl 

9--::

  1c+3cnrs change places RH | 1c set _while{2}_ these cnrs change places LH on 1diag. ; 1c change places with 1cnr persons RH | 1c turn LH to face 2cnr

17--::

  Repeat figure on 2diag., finish (3x,1x,2x)

25--::

   ½ Gr-Chain (3c cross to start) and hold second RH given ; 1M+3M & 1W+3W & 2c turn RH (2,1,3)







', 4);
INSERT INTO 'dancecrib' VALUES (10184, '2017-10-18 09:33:17.850863+00', '2019-02-23 19:01:16.177605+00', 18004, 1, 202, 'ace', '1--::

  1c set | turn RH ; 1c+2c RHA

9--::

  1c+2c+3c Circle6 L ; 1c+2c+3c+4c A&R finishing in Reel4 position

17--::

  Parallel Reels4

25--::

  1c+2c ½ R&L ; 1c+3c ½ R&L (2x,3x,1,4)

33--::

  1c+4c ½ R&L ; 2c+3c+4c+1c turn RH ½ and cast away to own sides', 4);
INSERT INTO 'dancecrib' VALUES (9459, '2016-11-04 01:17:19.264038+00', '2019-02-23 19:05:10.069837+00', 17462, 2, NULL, 'ace', '1- 8	::  All circle 8 hands round and back

9-12::  1L followed by 2L+3L+4L cross the top of the set, 1L dances around 1M by LSh while remaining Ladies pass 1M by LSh and dance down behind Men’s line.  1L joins in the chase behind 4L.  

13-16::  Ladies cross below 4M, chase back to own side & finish in order 2341. 

17-24::  1M followed by 2M+3M+4M repeat bars 9-16 dancing round behind Ladies & back to place

25-28::  All dance back-to-back with partner

29-32::  All turn partner RH, or birl. 

', 5);
INSERT INTO 'dancecrib' VALUES (11864, '2019-05-27 10:43:49.866738+00', '2019-05-27 10:48:50.35804+00', 13348, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; turn RH to 2plx and face 1cnrs (2,1x,3)

9-20::

  »Fig8 Gr-Chain« [: 1c+1cnrs & 2cnrs change places RH | all change places LH with P ; repeat twice [9-12] from new positions to end as on [9]] (2,1x,3)

21-24::

  1c set | cross RH (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11609, '2019-02-25 13:25:05.884675+00', '2019-02-25 14:17:55.261022+00', 2363, 1, NULL, 'ace', '1--::   [The Ghost Train]  All facing cclw chase | stand ; chase | stand (3,4,1,2)

9--::   repeat (1,2,3,4)

17--::   [The Big Wheel]  All cpls NHJ facing clw, W in middle ½ RHA ; repeat M in middle, ½ LHA

25--::   [Roundabout]  Circle8 and back

33--::   [The side stalls]  1c+3c change places, 1c making arch ; repeat back, 3c making arch

41--::   2c+4c repeat, 2c make first arch

49--::   [Meeting to go home]  All turn P RH ; LH into

57--::   All promenade to places [for repeat] or away [at end]

', 3);
INSERT INTO 'dancecrib' VALUES (2165, '2012-01-22 19:29:23.454758+00', '2017-02-14 15:38:43.847208+00', 1934, 1, NULL, 'ace', '{{explanation}}

Retain the basic triangular shape throughout



1–::

  1c lead between 2c & 3c | cross and cast up round them ; cross Rsh 1M to face 2c and 1W to face 3c | all set

9–::

  2c & 3c make arches as 1c dances under, cast off | 1c meet & turn RH ; cast up round outside of set (1M behind 2c, 1W behind 3c) to original positions

17–::

  All C Petronella Turn to partners and set ; repeat to finish in P''s place

25–::

  All M chase 1/3 clw _while_{4}   all W 2/3 LHA ; join RH with P and set in star, all C turn RH ½

33–::

  All W chase 1/3 clw _while_{4}   all M 2/3 LHA ; join RH with P and set in star, all C turn ¾ RH (to 2,3,1)

41–::

  All circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (11601, '2019-02-24 00:15:03.733487+00', '2019-02-24 00:21:35.277672+00', 16140, 1, 202, 'ace', '1--::

  1c long cast (2c up) ; turn RH 1½ to face 1cnrs

9--::

  1c turn 1cnrs LH to 2pl (cnrs dance 4 bars) | turn 2cnrs RH to 2pl ; ½ Reels3 on sides, LSh to 1cnrs. 1c pass LSh to face 3cnrs[pos]

17--::

  1c turn 3cnrs[pos] RH to between ends (cnrs dance 4 bars) | turn 2cnrs[pos] LH to between ends ; ½ Reels3 across, RSh to 3cnrs[pos] (3x,1x,2x)

25--::

  All set | chase cclw ½ | all set (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11863, '2019-05-26 22:53:38.567263+00', '2019-05-26 23:04:34.454272+00', 10149, 1, 202, 'ace', '1--::

  2c Corners Pass and Turn. 2c in 2pl face out (1,2,3)

9--::

  2c Fig8 on 1diag [:2c dance RSh round 3cnrs[pos], pass LSh, dance LSh round 1cnrs[pos], pass RSh to 2pl] _while{8}_ 1c & 3c cross RH | set ; change places LH on sides | set (3x,2,1x)

17-28::

  3C R&L (3x,2,1x)

29-32::

  All set | 3c cross RH _while{2}_ 2c cast to 3pl  _while{2}_ 1c cross up to 2pl (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (11862, '2019-05-26 18:52:23.493872+00', '2019-05-27 11:07:49.566152+00', 10145, 1, 202, 'ace', '1--::

  Inveran Reels (1,2,3)

9-12::

  1c set | cross down no H (2,1x,3)

13-24::

  »Fig8 Gr-Chain« [: 1c+1cnrs & 2cnrs change places RH | all change places LH with P ; repeat twice [13-16] from new positions to end as on [13]] (2,1x,3)

25--::

  All set | 1c cast RSh round 1cnrs _while{2}_ 2c & 3c cross RH into facing lines3 across ; 3C S&Link (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3104, '2012-01-22 19:30:11.424419+00', '2021-04-24 10:17:21.410544+00', 5547, 1, NULL, 'ace', '1–::

  1c RH turn, cast off one (2c up) ; turn LH to 2pl own side

9–::

  1M+3c & 1W+2c Reel3 across, Lsh to 1cnr, end BtoB in centre, M facing down and W up

17–::

  1W+2c & 1M+3c circle3 left ; at end 1c passing BtoB drop RH into ; circle6 once round to left (to 2,1x,3)

25–::

  2c+1c+3c Reels3{6} across, Lsh to 3cnr, 1c cross RH', 2);
INSERT INTO 'dancecrib' VALUES (12613, '2020-02-24 23:36:51.56249+00', '2020-02-24 23:39:43.337672+00', 19828, 1, 202, 'ace', '1--::

  Circle4 and back (1,2)

9--::

  1c Petronella turn | set (2c up) ; repeat to 2plx (2,1x)

17--::

  1c ½ Fig8 up round 2c ; 2c & 1c turn P RH into promhold facing up (2,1)

25--::

  2C Promenade (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (12614, '2020-02-25 10:48:22.194992+00', '2020-02-25 19:14:44.428734+00', 9531, 2, NULL, 'ace', 'DANCE WITHDRAWN.    



In Feb. 2020 Sue Petyt wrote to the SCDDB editors:   

   

North Herts Reel is missing from my website because it was not very good and didn''t really work very well. Even the most experienced dancers found it impractical so I have abandoned it!



Thank you for your enquiry.   

  

Keep Dancing   

Sue Petyt  

sue@suepetyt.me.uk

', 5);
INSERT INTO 'dancecrib' VALUES (12972, '2020-07-20 23:31:42.116602+00', '2020-07-28 16:48:51.785258+00', 19149, 1, 202, 'ace', '1--::
  1c cast off to 4pl (2c+3c+4c up) ; 4c+1c Circle4 L (2,3,4,1)
9--::
  1c cast up to 1pl (2c+3c+4c down) ; 1c+2c Circle4 R (1,2,3,4)
17--::
  1c dance down into Mirror Fig8 on sides (1,2,3,4)
25--::
  1c set advancing to P | turn P RH ½ ; lead down and turn to 4pl (2c+3c+4c up on [29-30]) (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (10309, '2017-12-12 14:57:32.221059+00', '2020-02-26 12:01:40.724472+00', 11047, 1, 202, 'ace', '1--::

  Circle8 and back

9--::

  All set to P | turn BH 1 ¼ to finish NHJ facing cclw ; M LHJ in centre, ½ LHA (3,4,1,2)

17--::

  All M pulling Lsh back ½ RHA to P''s original place _while{4}_ all W chase cclw ½ to P''s original place ; all set to P | turn P BH ½ (1,2,3,4)

25--::

  1c+3c (W following M) dance on 1 place clw and in (M Rsh round M, W Rsh round W) to face next cpl ; all set | all turn opposite person BH, M ¾, & W 1 ¼ into circle (3M+1W+2c+1M+3W+4c)

33--::

  Circle8 L (top&bottom M on W''s R)

41--::

  1c+3c ½ RHA to original places ; all ½ Gr-Chain (3,4,1,2)

49--::

  4c+2c (W following M) dance on 1 place clw and in (M Rsh round M, W Rsh round W) to face next cpl ; all set | all turn opposite person BH, M ¾, & W 1 ¼ into circle (3c+2M+4W+1c+4M+2W)

57--::

  Circle8 L (sides M on W''s R)

65--::

  2c+4c ½ RHA to original places ; all ½ Gr-Chain to finish NHJ with P facing clw (1,2,3,4)

73--::

  W RHJ in centre, all RHA ending W in centre facing P', 4);
INSERT INTO 'dancecrib' VALUES (13569, '2021-01-21 23:54:03.981734+00', '2021-01-22 00:00:40.881376+00', 18937, 1, 202, 'ace', '1--::

  1c lead down (2c up on [3-4]) ; lead up to 2pl (2,1,3)

9--::

  1c turn 2c on sides starting up and out ; 1c turn 3c on sides EH into DTr position

17--::

  DTr. 1c face 4cnrs

25--::

  Reel4 on 2diag (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1716, '2012-01-22 19:28:58.10739+00', '2015-04-18 19:48:58.867466+00', 358, 1, NULL, 'ace', '1–::

  1M+3M set twice, swiveling R about (or show off to P in some other way) ; 1W+3W (flirting) dance loop towards P, go R and to own place facing out

9–::

  1W+3W followed by P cast off | cross up (2W+4W up) ; cast off round 2M / 4M | cross turning P LH and both join RH to 1cnr (2M+4M up)

17–::

  All dancers set for 8 bars: BiL with 1cnr | set advancing to 2cnrs ; BiL with 2cnrs | ½ turn LH in PdB to midline, W above M _while_{2} 2cnrs swivel cclw in PdB

25–::

  All dance RHA (2c+1W & 1M+4c+3W & 3M+5c) ; 1c+3c turn LH and cast off (4c+5c up) (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (11602, '2019-02-24 14:52:57.437569+00', '2019-02-24 17:42:55.324139+00', 19199, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; 1c+3c RHA. 1W with 1M behind faces own side (2,1,3)

9--::

  ½ Reel3 in tandem (with lead change) on 1diag, 1W (leading) RSh to 4cnr ; ½ Reels3 in tandem (with lead change) on 2diag, 1M (leading) LSh to 2cnr (3x,1x,2x)

17--::

  Parallel Reels3 on sides, 1c LSh to 2c (3x,1x,2x)

25--::

  3W+1W & 1M+2M set | ½ RHA _while{4}_ 3M & 2W cross RH | set ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11603, '2019-02-24 21:22:24.978525+00', '2019-02-24 21:26:44.366508+00', 11784, 1, 202, 'ace', '1--::

  1M+2W & 3M+4W Turn Halfway and Cast. All face out ; 1M+2W & 3M+4W dance LSh round P to original places (1,2,3,4)

9--::

  1W+2M & 3W+4M repeat [1-8] but dance RSh round P to original places (1,2,3,4)

17--::

  Reels4 on sides, ending as on [17]

25--::

  All change places RH on sides (to 2,1,4,3)| 1c+4c change places LH on sides (to 2,4,1,3) ; 2c+4c & 1c+3c RHA (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11604, '2019-02-24 21:55:44.702984+00', '2019-02-24 22:26:39.664809+00', 6819, 1, 202, 'ace', '1--::

  1c cast (2c up) | lead down ; on [5] 1W crosses under P''s arm, 1c lead up to 2plx (2,1x)

9--::

  2c ½ Fig8 down round 1c ; 2W+1M cross RH | 2M+1W cross RH (1,2)

17--::

  1c+2c A&R ; turn P RH ready for

25--::

  2C Poussette (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11605, '2019-02-24 23:27:55.96332+00', '2019-02-24 23:32:07.344015+00', 5686, 1, 202, 'ace', '_Strathspey_



1--::

  1c set | cast (2c up) ; turn BH | set (2,1,3)

9--::

  1c ½ Fig8 R round 1cnr _while{4}_ 2c & 3c set | cross RH (to 2x,1x,3x) ; 1c ½ Fig8 round 3cnr _while{4}_ 2c & 3c set | cross RH (2,1,3)



_Reel_

1--::

  1c+3c RHA ; dance LSh round 2c on sides to 2pl (2,1,3)

9--::

  2c+1c LHA ; dance RSh round 2c on sides to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11608, '2019-02-25 13:04:21.363682+00', '2019-02-25 13:08:13.981011+00', 8211, 1, NULL, 'ace', '1--::  All W cast behind P and dance clw round to places

9--::  All M cast behind P and dance cclw round to places

17--::  1c+3c RHA ; LHA

25--::  2c+4c repeat

33--::  1c+3c A&R ; dance BtoB

41--::  2c+4c repeat

49--::  1W+3M & 1M+3W Fig8 round nearest side couple 

57--::  2W+4M & 4W+2M Fig8 round nearest top/bottom couple

65--::  1c+3c turn dancer opposite RH ; then LH [alternative: R&L]

73--::  2c+4c repeat

81--::  Circle8 and back

', 3);
INSERT INTO 'dancecrib' VALUES (11610, '2019-02-25 14:18:57.759232+00', '2019-02-25 14:23:58.458975+00', 17323, 1, NULL, 'ace', '1--::  1c dance down {3}, cast up round 3c to top {3} | 1M+1W following dance down one place (2c up)

9--::  2W+1c+3M ½ Rsh reel 3 (1M leads), 1c pivot R to face M side ; 2M+1c+3W ½ Rsh reel 3 (1W leads), 1c pivot R to face up

17--::  Repeat on 2diag (1M leads) ; repeat on 1diag (1W leads), at end 1c fast ¼ turn RH (2,1,3)

25--::  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11612, '2019-02-25 16:15:06.181321+00', '2019-02-25 16:15:06.181321+00', 12297, 1, NULL, 'ace', '1--::  1W+3W turn LH | turn P RH, 1W+3W finish facing cnr ; 4M+1W+3W+2M ½ diag Reel4, 1W+3W end in places

9--::  1M+3M turn RH | turn P LH, 1M+3M finish facing cnr ; 2W+1M+3M+4W ½ diag Reel4, 1M+3M end in places

17--::  Grand Chain

25--::  4c+2c ½ R&L and all face clw ; All chase 1 place clw and turn P RH  (4,1,2,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2139, '2012-01-22 19:29:22.149662+00', '2017-02-14 15:45:58.187942+00', 1858, 1, NULL, 'ace', '1–::

  1c lead down below 3c and turn RH ½ ; cross up and cast up behind 2c to (1,2,3)

9–::

  1W+3M change places RH | cast R to 2pl ; cross RH | cast R to finish on midline in 1pl and 3pl  _while_{8}    the others set | petronella in tandem ; repeat (to sidelines)

17–::

  All set | circle6 L to (1,2,3) | All set

25–::

  2c leading 1c dance between 3c and cast up to (2,1,3) ; 1c leading 3c dance between 2c and cast to (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (7905, '2013-08-21 08:31:51.167466+00', '2023-02-04 01:23:10.918854+00', 7073, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH & dance RH across
9-16::
    1s+2s set, cross LH & dance LH across
17-24::
    1s lead down the middle, back to top & cast to 2nd places
25-32::
    1s+3s circle 4H round & back
33-40::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (11649, '2019-03-07 11:10:05.871207+00', '2019-03-07 11:10:05.871207+00', 19227, 1, NULL, 'ace', '1--::

  1M+2W A&R ; dance BtoB

9--::

  1W+2M repeat

17--::

  1c dance down the middle (2c up) and back to 2pl

25--::

  2c+1c R&L



', 3);
INSERT INTO 'dancecrib' VALUES (10934, '2018-08-02 12:04:42.333851+00', '2020-02-27 11:48:06.724887+00', 18488, 1, 202, 'ace', '1--::

  1c+2c Chain Progression (2,1,3)

9--::

  Pick-up Chain, 3c cross RH to start (3,1x,2)

17--::

  1c ½Fig8 R round 3cnrs ; all turn P RH (3,1,2)

25--::

  3C S&Rotate (2,1,3)

33--::

  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (11616, '2019-02-25 20:25:43.576172+00', '2022-12-01 23:09:50.440011+00', 13572, 1, 202, 'ace', '1--::
  1c set | cast (2c up) ; 2c+1W & 1M+3c RHA, 1c pass LSh to face 1cnrs
9--::
  Corners Pass and Turn, 1c pass RSh to face 2cnrs ;  repeat [9-12] with 2cnrs
17--::
  1c repeat [9-12] with 3cnrs ;  repeat [9-12] with 4cnrs. 1c BtoB with P face own side in second place
25--::
  DTr 1c to 2pl (2,1,3)
33--::
  Circle6 and back (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (9818, '2017-05-04 12:38:12.903752+00', '2021-02-20 20:49:19.642869+00', 9766, 1, 202, 'ace', '1--::

 1c turn RH | cast (2c up) ; cross down RH | cast to 2plx (2,1,3)

9--::

 S&Link3 ; all set | cross RH

17--::

 S&Link3 ; all set | cross RH finishing facing out (2,1,3)

25--::

 All chase clw ⅔ ; Circle6 (to 2,1,3) | all set', 2);
INSERT INTO 'dancecrib' VALUES (12977, '2020-07-24 06:29:35.218965+00', '2021-06-06 12:12:24.371356+00', 10924, 1, 202, 'ace', '1--::

  1W+2M turn RH ; dance BtoB (1,2)

9--::

  1M+2W dance BtoB ; turn RH retaining hands (1,2)

17--::

  1c+2c RHA ; LHA ready for

25--::

  Poussette (2,1)', 5);
INSERT INTO 'dancecrib' VALUES (11613, '2019-02-25 17:10:31.416181+00', '2019-02-25 17:10:31.416181+00', 8583, 1, NULL, 'ace', '1--::  1c+2c S&Link ; repeat, 2M+1W making ½ turn LH to face P on 1diag

9--::  Reel4 on 1diag, finish (1,2) with loops

17--::  1M+2W half turn RH and cast away ; 1W+2M repeat (2x,1x)

25--::  2c+1c dance BtoB ; All turn P BH 1½ ', 3);
INSERT INTO 'dancecrib' VALUES (8933, '2015-10-04 18:47:53.630302+00', '2015-10-04 18:58:16.739712+00', 16633, 2, 160, 'ace', '1-8::

  1C 2C dance "Pinwheel" progression. End 2 1 3.

9-12::

  All Set & Link 3 (end in lines across - 1M btwn 3C at top and 1L btwn 2C in 3pl) ;

13-16::

  All set, pull back Rsh and cast to end on sidelines. On ladies side: 3M 1M 3L. On men''s side: 2M 1L 2L.

17-20::

  All cross RH with opp. and chase to lines of 3 across. End 1M btwn (3C) at top and 1L btwn (2C) in 3pl.

21-24::

  All Set & Link 3. Order is 3 (1) 2.

25-28::

 Half Reel3 on sides ; 1M in and up, 1L in and down to begin.

29-32::

 Half fig8 - 1L up, 1M down.

::

Pinwheel Progression:



1-4::

1M 2L dance back to back *Meanwhile* 1L 2M dance CW 1pl and adv with ptnr as ptnr retires. End in line of 4 on 1crnr diagonal NH joined with ptnr facing CCW.

5-6::

  All dance 2 steps to end on centerline, 2C facing men''s side 1C facing ladies'' side.

7-8::

2L cast to 1L''s pl ; 2M dance out & up to 1M''s pl ; 1L dances out to 2L''s pl. as 1M cast to 2M''s pl.', 2);
INSERT INTO 'dancecrib' VALUES (13678, '2021-02-21 07:41:42.436669+00', '2021-02-21 11:21:52.633046+00', 17723, 1, 202, 'ace', '1--::

  3C Gr-Chain (1,2,3)

9--::

  All dance BtoB ; 1c dance down to 3pl under arch made by 3c _while{4}_ 3c dance up and cross to 1pl (3x,2,1)

17--::

  Circle6 and back

25--::

  All set twice ; 3c turn P LH 1½ _while{4}_ 2c cross RH, cast off and cross LH _while{4}_ 1c turn P LH 1¾ moving up to face 1cnrs (3,1,2)

33--::

  Turn CPCP. 1c face 1cnrs

41--::

  Reels3 across, 1c LSh to 1cnrs (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (11866, '2019-05-30 10:22:23.525931+00', '2019-05-31 08:35:04.56924+00', 19364, 1, 202, 'ace', '1--::

  1c+2c S&Rotate (2,1)

9--::

  DblFig8, 1c crossing up (2,1)

17--::

  1c dance down ; and back (2,1)

25--::

  2c+1c set to P twice ; turn EH on sides, 1c up and out (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11868, '2019-05-31 09:01:11.332749+00', '2019-05-31 09:16:39.328575+00', 9354, 1, NULL, 'ace', '1--::

  1W Fig8 round 2M+1M, Lsh to 2M

9--::

  1c lead down  (2c up) ; and up (2,1)

17--::

  2c+1c A&R ; 2c+1c turn P RH to finish 2c facing 1c, NHJ

25--::

  Circle4 and back (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (3334, '2012-01-22 19:30:20.969259+00', '2020-06-27 21:31:03.592229+00', 12792, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; turn LH 1½ to face 2cnr, LHJ with P

9–::

  Set to 2cnr & turn inwards | set to 4cnr ; ½Reel4 with 4cnrs, finish LHJ facing 1cnr

17–::

  Set to 1cnr & turn inwards | set to 3cnr ; ½Reel4 with 3cnrs, finish 1M above 1W on midline, facing P

25–::

  2c+3c set and chase 1 place clw _while_{4} 1c turn RH 1½ to join the chase ; All chase 1 place clw and set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11614, '2019-02-25 17:34:46.614182+00', '2019-02-25 21:26:30.77492+00', 19202, 2, NULL, 'ace', '1-8::   1s & 3s set, cast 1 place & dance 1/2 figure of 8 round the couple below (1s round 4s & 3s round 5s) (2s & 4s step up on bars 3-4)

9-16::   1M & 3L pass LSh into reel of 4 across with 4s to finish in the middle, 1M facing up, 3L facing down, while1L/3M dance across to turn 2L/5M LH, 2M/5L RH to finish facing partners in a line up & down the middle of the set.

17-24::   Reel of 4, finish 1L facing up between 2s, partner behind & 3M facing down between 5s, partner behind.

25-32::  1s & 3s dance up or down, cast to opposite sides, (2nd/4th place), cross RH & cast down another place (1s to 3rd place, 3s to 5th place) (4s & 5s step up on bars 31-32)

33-40::   10 hands round & back', 5);
INSERT INTO 'dancecrib' VALUES (11617, '2019-02-25 22:04:38.488631+00', '2019-02-25 22:04:38.488631+00', 19203, 2, NULL, 'ace', '1 - 8::  1st & 2nd couples dance rights & lefts; 

9 - 16::  1st, 2nd & 3rd couples set and dance 6 hands once round to left; 

17-24::  1st couple, followed by 2nd couple dance down & back to place, 2nd couple dividing as 1s dance back up; 

25-32::  1st & 2nd couples dance a rondel.', 3);
INSERT INTO 'dancecrib' VALUES (12987, '2020-07-25 09:32:54.562151+00', '2020-08-03 20:26:18.480189+00', 2150, 2, 2784, 'ace', '1-::

  Reel3 on sides, 1c cross down to start (1x,2,3)

9-::

  1c+2c face on the sides, set and change places RH ; 1W+3W change places LH {2} 1M+3M change places {2} (2,3x,1)

17-::

  2c+3c+1c A&R ; 3c+1c 1/2 R&L (2,1x,3)

25-::

  Reel3 across, 1W+2c, 1M+3c {6} 1c cross RH to 3pl (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11867, '2019-05-31 00:10:13.141761+00', '2019-05-31 00:11:41.777119+00', 10148, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; turn LH to face 1cnrs | 1c+1cnrs change places RH

9--::

  2M+3W turn LH ¾ | 2c & 3c change places RH with P on 2diag ; 2W+3M turn LH ¾ | 1W+3M & 2W+1M change places RH on 1diag. 1c face 1cnrs[pos]

17--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reels3 across, 1c RSh to 2cnrs[pos] into facing lines3 across with polite turn

25--::

  3C S&Link (to 2x,1x,3x) ; all turn P RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11869, '2019-06-01 12:50:59.640974+00', '2019-06-01 12:54:34.335848+00', 6443, 1, 202, 'ace', '1--::

  1c cross down round 2c | cast to 1plx ; cross RH | set (1,2)

9--::

  2c ½ cross up round 1c | cast to 2plx ; cross RH | 1c+2c set (1,2)

17--::

  1c (2c following) lead down ; 2c (1c following) lead up to sides (2,1)

25--::

  R&L (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (3217, '2012-01-22 19:30:16.11559+00', '2021-10-06 21:54:46.407569+00', 8464, 1, NULL, 'ace', '1–::

  All A&R ; Dance BtoB

9–::

  All circle8 and back

17–::

  1c, followed by the other couples, cast off to 4pl and form arch ; the other couples dance up (NHJ) under the arch and out (to 2,3,4,1)

25–::

  All C RH turn ; LH turn', 2);
INSERT INTO 'dancecrib' VALUES (12982, '2020-07-24 16:00:03.801283+00', '2020-07-24 18:21:24.615541+00', 9671, 1, 202, 'ace', '1--::
  All A&R{1+1} | all pass P RSh to opposite sides, M making arches ; repeat, W making arches (1,2,3)
9--::
  1c dance down under 2c+3c''s arches | turn P BH ; repeat [9-12] back to 1pl (1,2,3)
17--::
  1c NHJ make arch and dance down over 2M & 3M who kneel when passing over | turn P BH ; repeat [17-20] on Wside back to 1 pl (1,2,3)
25--::
  2C Rondel. On [31-32] 3c make arch and dance to 2pl _while_ 1c dance to 3pl (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (14052, '2021-05-29 21:37:26.192088+00', '2021-06-15 08:57:04.513999+00', 10263, 2, 35787, 'ace', '1-8 :: 1C dance in toward each other, then turn away and cast off to 2d place; 2C up on 3&4. 1C dance down between 3C and cast up to 2nd place on own sides.

9-16 :: 1C with 2M & 3W (1cnrs) dance RHA once round WHILE 2W & 3M dance cclw around set to opposite position. 1C with 2W & 3M (2cnrs) dance LHA once round WHILE 3W & 2M dance clw around set to opposite position. (Each time, the dancers dancing around the outside of the set begin by dancing across the ends of the set, then up or down opp side.)

17-24 :: 1C dance diag R&L with 2C & 3C, 1W up 1M down.

25-32 :: 2C, 1C, & 3C set on the sides, turn ptnr BH twice round, then set on the sides.', 0);
INSERT INTO 'dancecrib' VALUES (14356, '2021-10-08 10:42:10.985013+00', '2021-10-08 10:44:12.119587+00', 9548, 1, 1645, 'ace', '1--::

  1M+2W turn RH ; 1W+2M turn 1&frac14; RH to face P on diagonal

9--::

  1c+2c RSh diagonal Reel4. On [16] 1W+2M take LH in passing & RH with P, all on centre line

17--::

  Rotate line &frac14; clw with 4 PdB, 1M & 2W (ends) advancing, so M/W face down/up ;

  1W+2M drop LH, 1c & 2c turn P &frac14; RH with PdB so M end below P, 1c/2c nearer W/M sides |

  1W & 2M cast down/up _while_ 1M & 2W dance across to own sides (2,1)

25--::

  2c+1c Circle4 to L & back (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11618, '2019-02-25 22:30:26.596095+00', '2019-02-25 22:30:26.596095+00', 8243, 1, NULL, 'ace', '1--::  1W casts behind W line and 1M dances down the middle, to below 4c _while[on 3-4]_ 2W+3W+4W A&R ; 1M casts behind M line and 1W dances up the middle, to 1pl _while[on 7-8]_ 2M+3M+4M A&R (1,2,3,4)

9--::  Reels4 on the sidelines, finish facing up/dn

17--::  1c+2c & 3c+4c turn opposite ½ | 1c+4c ½ LHA ; 2c+4c & 1c+3c turn opposite RH ½ | All set to P (4x,2,3,1x)

25--::  1c+4c turn P BH | 4c+1c cast in (to 2plx/3plx) (2c+3c step to end) ; 4c+1c ½ Fig8 round own end cpl 

33--::  Circle8 and back (2,4,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (10590, '2018-04-06 22:45:44.253669+00', '2019-02-25 23:49:21.708871+00', 16794, 2, 1, 'ace', '1–:: Mirror Reels3 on sides [1c out/down, 2c in/up,

    3c dance in/touch hands/cast up into reel, all give hands where possible,

    fin 1c at top facing up/NH joined, 3c at bottom facing down/NH joined]

9–:: “Highland Schottische Balance w/turns”: 1c&3c ¾ turn BH to fin in line

    facing own sides | HS to R [L full turn (RS back) under R arms moving R] ;

    HS to L [L full turn (LS back) under L arms moving L] | ¾ turn BH

    [fin 1c facing down, 3c up, NH joined]

17–:: All set | ½ Circle6 to L ; M+L on their right turn BH | ½ Circle6 to L [fin

    1x,2,3x]

25–:: 2c&1c dance LH Ladies'' Chain (i.e., Men''s Chain w/L dancing as M)

33–:: 1M followed by 1L, 3L followed by 3M chase to change pl;

    1c&3c turn BH twice

41–:: 2c+1c dance Rose Progression [fin 312]', 3);
INSERT INTO 'dancecrib' VALUES (12670, '2020-03-17 23:21:09.663635+00', '2020-08-12 09:35:32.249618+00', 19892, 1, 202, 'ace', '1--::

  1c cast off and dance behind own lines (2c up on [3-4]) ; cast up to 2pl (2,1,3)

9--::

  2c set | cross RSh ; stand still {4}  

_while{8}_ 1c stand still {2} | set ; cross RSh | stand still {2}  

_while{8}_ 3c stand still {4} ; set | cross RSh (2x,1x,3x)

17--::

  All chase clw ½. On [20] 2W & 3M pull LSh back ready for ; ½ Reels3 on sides, 1c LSh to 3cnrs[pos]. 1c face 1cnrs (2,1,3)

25--::

  SetH&G.  1c in 2pl face out (2,1,3)



*Note:  

At the start of the 3rd repetition of the dance, 1C cast off to 4th place as a new couple casts off from the top.*', 5);
INSERT INTO 'dancecrib' VALUES (8752, '2015-04-20 21:08:18.633872+00', '2016-05-18 23:51:19.359129+00', 12620, 1, NULL, 'ace', '1--::

  1c+2c set | ½ RHA ; 1c+3c set | ½ LHA (2x,3x,1)

9--::

  2c+3c set | ½ RHA ; flow into Turn P BH into 

17--::

  3c+2c ½ Poussette, 1c step in for ; 3c+1c ½ Poussette (2,1,3)

25--::

  Circle6 and back



*Official variant: To dance this as 3C/3L, replace [21-24] by    3c+1c Circle4 L (2,3,1)*

', 4);
INSERT INTO 'dancecrib' VALUES (9130, '2016-04-06 04:12:46.338142+00', '2017-11-12 15:51:49.087998+00', 13381, 2, 2929, 'ace', '1-::
  1C + 2C, 3C, 4C + 5C half RSh tandem reels on sidelines, 3C passing 2C + 1C to begin
5-::
  Top 4 couples (4, 5, 3, 1) half LSh reels of 4
9-::
  Top 3 couples (1, 3, 5) half LSh reels of 3
13-::
  Top 2 couples (5, 3) turn LH halfway on sides WHILE bottom 3 couples (1, 4, 2) take hands and set
15-::
  All chase counter clockwise 2 places
17-::
  All set, change RH diagonally right (1C do nothing)
21-::
  All set, change LH diagonally left (5M + 4L do nothing)
25-::
  All set, change RH diagonally right (3M + 2L do nothing)
29-::
  All advance for 1, L turn under M''s right arm, retire for 2', 2);
INSERT INTO 'dancecrib' VALUES (11873, '2019-06-03 06:55:08.941469+00', '2020-11-01 10:07:16.794625+00', 17502, 1, 202, 'ace', '1--::

  1W & 2M »½ Fig8 round P« [: 1W casts off one place _as_ 2M casts up | pass RSh in centre ; dance LSh round P | pass LSh in centre to original places] (1,2,3,4)

9--::

  1c+2c+3c Gr-Chain (2 bars per hand, 3c cross to start) (3,1x,2x,4)

17--::

  1M & 2W »½ Fig8 round P« [: pass LSh in centre | dance RSh round P ; pass RSh in centre | dance LSh round 2M/1W to original places]  (3,1x,2x,4)

25--::

  1c+2c ½ R&L ; 3c+2c & 1c+4c turn RH on sides 1½ to exchanged places (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12618, '2020-02-28 21:21:18.48766+00', '2020-02-28 21:32:27.517435+00', 7731, 1, 202, 'ace', '1--::

  1c & 4c Fig8 round nearest cpl (1,2,3,4)

9--::

  1c+2c & 3c+4c Circle4 and back

17--::

  1c lead down, lead up ; cross and cast to 2plx (2c up) facing down _while{8}_ 4c lead up, lead down ; cross and cast to 3plx (3c down) facing up (2,1x,4x,3)

25--::

  Ends set to P _as_ middles set on sides | all change places RH with opposite person (to 2x,4x,1x,3x) ; all set in line in 4 | cross RH (2,1,4,3)', 2);
INSERT INTO 'dancecrib' VALUES (2588, '2012-01-22 19:29:48.808076+00', '2015-04-15 09:56:11.209858+00', 8684, 1, NULL, 'ace', '1–::

  G-Chain No Hands, start to P {6} | set to P

9–::

  Repeat

17–::

  All W RHA _while{4}_ all M chase cclw ½ round ; Turn new P LH 1½

25–::

  All M RHA _while{4}_ all W chase cclw ½ round ; All turn P LH 1 ¼ to (3,4,1,2)

33–::

  1c+3c BHJ slip across, W pass BtoB _while{4}_ 2c+4c stamp 3 times | 1c+3c stamp _while{4}_ 2c+4c slip across ; repeat

41–::

  All C polka cclw once round the set to (3,4,1,2) and face P

49-64::

  Drambuie Chain (Advance one pas de valse and give RH, retire in one PdV, pass RH and next person LH) ; repeat 3 times (3,4,1,2)

65-80::

  All W face out for Schiehallion Reel, finish facing cclw in Allemande hold

81–::

  All promenade 1¼ cclw, at end drop RH into W leads M

89–::

  All chase ¾ cclw ; Circle8 R to (1,2,3,4)', 3);
INSERT INTO 'dancecrib' VALUES (2668, '2012-01-22 19:29:52.350907+00', '2020-12-18 20:43:47.085045+00', 7310, 1, NULL, 'ace', '1–::

  1c dance down, cast down round 3c ; dance up, cast up round 2c

9–::

  1c set advancing | slip RHJ to 3pl ; turn RH _while{8}_ 2c+3c set | cast up one ; ½R&L (3x, 2x, 1)

17–::

  3c set advancing | slip RHJ to 3pl ; turn RH _while{8}_ 2c+1c set | cast up one ; RHA (2x, 1, 3x)

25–::

  1c cross RH between 3c and cast to 2plx _while{4}_ 3c set and cross ; 1c cross up RH and cast to 2pl _while{4}_ 2c set and cross (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2579, '2012-01-22 19:29:48.420674+00', '2020-11-20 15:20:26.173963+00', 3528, 1, NULL, 'ace', '1–::

  1M (greets 2W in passing) Reel3 across with 3c, Lsh to 3W, finish in 2pl (2M up)

9–::

  1W (greets 2M in passing) Reel3 across with 3c, Rsh to 3M, finish in 2pl (2W up) (2,1,3)

17–::

  1M+3c and 1W+2c Reels3 across, Lsh to 1cnr

25–::

  1c cast up into Fig8 round 2c (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12617, '2020-02-28 13:27:25.11603+00', '2023-01-20 12:04:55.281852+00', 2834, 2, 2755, 'ace', '1-:: 1c,2c,3c cross RH, set twice, 1/2 turn RH  

9-:: 1c,2c,3c allemande 

17-:: 3c, 2c, 1c 6H round and back 

25-:: 3c dance down and out to 3rd place, 2c, 1c step up. 2c, 1c, 3c turn BH

', 0);
INSERT INTO 'dancecrib' VALUES (3262, '2012-01-22 19:30:18.043127+00', '2020-12-17 22:55:30.268705+00', 6490, 1, NULL, 'ace', '{{explanation}}

Square set, with 5c in the middle facing 1c



1–::

  1c+5c+3c Parallel Rsh Reels3

9–::

  2c+5c+4c Shadow Reel3 across, 4c starts down, giving Lsh to 5c (2M, 5M and 4W lead their P, acting as one dancer in the reel)

17–::

  1c+5c ½ R&L ;  Circle 4 L (1c now in middle)

25–::

  Outside couples Circle8 L half round ; set, swiveling R and chase 1 place clw _while{8}_ 1c (kilt or elbow grip) turn R ; turn L (to 2,3,4,5, with 1 in the middle)', 3);
INSERT INTO 'dancecrib' VALUES (8911, '2015-09-21 09:10:20.728363+00', '2019-02-25 23:57:39.958336+00', 16576, 2, 1633, 'ace', '1-8::

          1s dance down for 2steps, face and set, 1W casts up to 2nd place own side whilst 1M casts down to 2nd place own side then 1s turn LH to face 2nd corners.    



9-16::

           1s ½ RSh reel of 4 with 2nd corners then turn LH to face 1st corners for ½ RSh reel of 4 finishing with 1W between 3s facing down and 1M between 2s facing up.  



17-24::

           Set and link for 3 twice to end with 1M between 2s at top and 1W between 3s at bottom. 



25-32::

           1s set advancing and turn 2H opening out to face down on own sides, then 1W and 3W with LH and 1M and 3M with RH turn 11/2 to end 2,3,1. ', 0);
INSERT INTO 'dancecrib' VALUES (11871, '2019-06-02 16:44:23.785306+00', '2019-06-02 16:51:31.35756+00', 19381, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; ½ Reels3 across, 1c LSh to 1cnrs (2x,1x,3x)

9--::

  2W+1M & 1W+3M cross RH | 2M+3M & 2W+3W cross LH ; 1M+3W & 2M+1W cross RH (to 3x,1x,2x) | all cross LH. 3c & 2c remain in centre facing down/up (3,1,2)

17--::

  All set | Circle6 L | all turn P RH ready for

25--::

  3C Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3415, '2012-01-22 19:30:24.453352+00', '2020-12-18 20:48:52.570558+00', 7544, 1, NULL, 'ace', '1–::

  All advance to meet partners, pull Rsh back and loop through next position on the R to own place ; all chase ½ way clw (4x,3x,2x,1x)

9–::

  All with NHJ set PdB-Coupé , finish 4c facing 3c and 2c facing 1c

17–::

  All dance Rsh Reels4 on sidelines, for 2c+3c the last pass is Rsh.

25–::

  4c+3c LHA _while{4}_ 2c+1c RHA, but drop hands on [27] ; continue wheels without hands but change successively (2W + 3W begin) to opposite wheels, lower wheel dancers (1c+2c) passing in front, (to 1x,2x,3x,4x).

33–::

  All set NHJ | cross RH ; All C turn RH into promhold facing up.

41–::

  1c+2c & 3c+4c 4 bars of promenade ; 1c follows 3c+4c in promenade _while{4}_ 2c promenades alone to 1pl (finishing 2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12974, '2020-07-23 12:29:36.602063+00', '2020-07-23 15:57:48.445288+00', 20053, 1, 202, 'ace', '1--::
  1c cross down RH to 2pl (2c up) | all set ; all cross RH | all set (2x,1,3x)
9--::
  1c cast RSh round 3cnrs[pos] | cross RH up/down ; dance RSh round 4cnrs[pos] | cross RH to face 1cnrs[pos] _while{8}_ 2c & 3c change places RH on sides then set facing each other ; cross RH| set (3,1,2)
17--::
  ½Reel4 on 1diag, pass LSh ; ½Reel4 on 2diag, pass LSh to face 3cnrs[pos] (2x,1,3x)
25--::
  Reels3 {6} on sides, 1c RSh to 3cnrs[pos]. 1c end in 2plx | all cross RH (2,1,3)

*Deviser''s note:*  
_Alternative ending for a 3-couple set:_ *Reels of 3 on the sides, but 1st couple remains on their own sides instead of crossing. On bars 31-32, 1st couple dances out and down to 3rd place, 2nd couple crosses as above, and 3rd couple crosses up to 2nd place.*', 5);
INSERT INTO 'dancecrib' VALUES (1769, '2012-01-22 19:29:01.393306+00', '2019-06-02 23:05:48.798299+00', 556, 1, NULL, 'ace', '1–::

  1c+3c+5c set advancing into line of 6 NHJ, with P on the R | BiL ; 3c+5c Turn RH and lead up 2 places _while_{4} 1c cast off to 5pl (3,2,5,4,1)

9–::

  Repeat from new places (to 5,2,1,4,3)

17–::

  2c+4c lead down {3}, up {3}, and cast off one (1c+3c up) (to 5,1,2,3,4)

25–::

  5c+1c & 3c+4c R&L _while_{8} 2c cross RH, Set, cross back RH, set (5,1,2,3,4)



', 3);
INSERT INTO 'dancecrib' VALUES (11620, '2019-02-26 00:38:42.38017+00', '2019-02-27 11:09:43.427116+00', 17162, 1, 202, 'ace', '1--::
  1c set | ½ Fig8 down round 3c. On [6] 2c face down | 1c turn 2c on sides (RH on M side, LH on W side) into DTr[pos], 1c BtoB in middle facing opp sides (2,1x,3)
9--::
  DTr. 1c between ends face 2cnrs
17--::
  Reels3 across, 1c RSh to 2cnrs (2,1,3)
25--::
  1c turn P RH ½ | turn 1cnr LH ; turn P RH | turn 3cnr LH to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12619, '2020-02-29 11:51:43.788211+00', '2020-02-29 11:51:43.788211+00', 14421, 1, NULL, 'ace', '*Trio face Trio Round the Room*

1--::

  Circle6 and back

9--::

  Outside dancers A&R diagonally ; Centre dancers turn RH 1½ into other trio

17--::

  Reels3 across, Rsh to dancer on the R, at end center cpl passes Lsh to original places

25--::

  All set to and turn opposite RH ½ ; set | pivot R to face next trio 



', 3);
INSERT INTO 'dancecrib' VALUES (8935, '2015-10-10 14:22:49.261887+00', '2015-10-10 14:22:49.261887+00', 7878, 2, NULL, 'ace', '1-4::

  1s2s right hands across WHILE 3s4s left hands across;

5-8::

  1L followed by 1M cast to 3rd place (opposite sides) WHILE 3M followed by 3L cast to 1st place (opposite sides);

9-12::

  3s2s right hands across WHILE 1s4s left hands across;

13-16::

  1L followed by 1M cast up and dance down the centre line WHILE 3M followed by 3L cast down and dance up the centre line, 1L3M finishing left shoulder to left shoulder, between 2s, 1M 3L holding back ready for the reel of 4;

17-24::

  1M3M1L3L reel of 4 up and down the centre line, finishing in original places, 1s facing out;

25-28::

  1s cast to the bottom WHILE 2s3s4s step up;

29-32::

  2s 3s turn by the right WHILE 4s 1s turn by the left, finishing 2s3s4s1s', 3);
INSERT INTO 'dancecrib' VALUES (11622, '2019-02-26 08:15:42.424192+00', '2019-02-26 08:15:42.424192+00', 18503, 1, NULL, 'ace', '1--::  Mirror Reels3 on the sides, 2c starts out and up (1,2,3)

9--::  All set | turn P BH twice | All set

17--::  1c, 2c following, lead down the middle ; and up, 1c leading, stay in middle for

25--::  1c+2c Allemande, on [31-32] 1c casts off and 3c dance up (2,3,1) 

', 3);
INSERT INTO 'dancecrib' VALUES (11623, '2019-02-26 10:19:17.431265+00', '2020-01-07 21:37:50.933578+00', 19134, 1, NULL, 'ace', '1--::  1c cross RH | cast off 2 (2c+3c up) ; cross LH | set (2,3,1)

9--::  2c repeat pattern [1-8] (3,1,2)

17--::  1c turn 1cnr RH (cnrs 4-bar turns), pass Rsh ; turn 2cnr RH, pass Rsh to (3,1,2)

25--::  All chase clw ½ round ; All set | cross RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12672, '2020-03-19 01:28:32.264378+00', '2020-03-19 01:36:08.117898+00', 13758, 1, NULL, 'ace', '1--::

  1c long cast to 3pl (2c+3c up) ; 3c+1c Mirror S&Link (3c cast down, 1c dance up) (2,1,3)

9--::

  Mirror Reels3 on the sides (1c out and up), take hands when possible (2,1,3)

17--::

  "Unisex Chain": 2W+3M turn LH ¾ to other end of their sideline _as_  their Ps cross _as_ 1c set | 2M+3M  & 2W+3W Turn RH½ _as _ 1c cross ; repeat (2,1,3) 

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8934, '2015-10-10 13:54:58.691649+00', '2015-10-10 18:46:40.678784+00', 16786, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c RHA ; All turn P RH | 1c+4c in promhold cast R one place while{2} 2c+3c lead to nearest end

9--::

  2W+1c+3M (on W side) & 2M+4c+3W (on M side) Lsh Reels on the sides, finish (2,4,1x,3x) middles facing ends

17--::

  All set to person opposite | turn opposite RH, and 4c faces 1c ; 4c+1c set to and turn opposite LH, to (2,4,1x,3x) middles facing ends

25--::

  Gr-Chain, starting along sidelines (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (11624, '2019-02-26 10:35:49.645536+00', '2019-02-26 10:36:39.326095+00', 19135, 1, NULL, 'ace', '1--::  1c+2c petronella to midline and set ; turn P RH 1¼, 1c face 2c NHJ 

9--::  1c+2c Rondel, finish for 

17--::  Grand Chain (2c cross to start) (2,1,3)

25--::  All set and rotate into lines across ; Circle6 L to (2,1,3)|



', 3);
INSERT INTO 'dancecrib' VALUES (3030, '2012-01-22 19:30:07.561576+00', '2021-04-18 18:08:41.614983+00', 5307, 1, NULL, 'ace', '1–::

  1c+2c+3c circle6 and back.

9–::

  1c+2c+3c Allemande (3,2,1)

17–::

  2c+1c S&Link (3,1,2) ; 3c+1c S&Link (1,3,2)

25–::

  1c+3c turn RH into ; 1c+3c ½ Poussette (to 3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (12985, '2020-07-25 09:27:44.070493+00', '2020-07-26 08:14:10.973387+00', 12545, 2, 2784, 'ace', '*1c have backs to centre of circle, 2c face centre of circle*

1-::

  1c A&R ; 2c A&R

9-::

  1c lead between 2c, divide and dance back to pl ; 2c repeat

17-::

  1W+2M lead between P and turn RH to finish beside P ; 1M+2W repeat

25-::

  1c+2c circle4 to L only ; 1c+2c slip R {2} and clap {2}, slip L {4} to face new cpl', 2);
INSERT INTO 'dancecrib' VALUES (12991, '2020-07-25 22:42:33.956381+00', '2020-07-28 12:48:51.933198+00', 6725, 1, 202, 'ace', '1--::
  1c turn P BH (Skip change) and face up NHJ ; 1c cast off into Fig8 on sides to 2pl (2c up on [7-8]) (2,1,3)
9--::
  1c turn P BH (Skip change) and face up NHJ ; 1c lead up and cast off to face 1cnrs
17--::
  SetH&G (2,1,3)
25--::
  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (9056, '2015-12-04 19:38:49.418587+00', '2020-02-28 17:42:58.622934+00', 1088, 2, 111, 'ace', '1-8::

  1s2s3s set, cross over RH; Repeat back to place.

9-16::

 1M followed by 1L - Cast behind 2M, cross up btwn 2s; cast behind 2L, cross to own side 2pl. 1L end in 2pl own side.

17-24::

  1s 3s LH Across; 2s 1s RH Across.

25-32::

  6 hands round and back.', 0);
INSERT INTO 'dancecrib' VALUES (3574, '2012-05-01 12:26:50.328953+00', '2020-02-29 12:02:00.777858+00', 14421, 2, 1, 'ace', '1-::

  All Circle6

9-12::

  Outside dances A&R diagonally

13-16::

  Center dancers turn R 1½ [fin between »corners« facing »out«]

17-::

  Reels3 w/corners, RS to 1crnr to begin [center dancers fin by dancing back to original pl]

25-::

  All set to & turn opp R ½, set to opp, swivel R and dance on to fin facing next trio', 3);
INSERT INTO 'dancecrib' VALUES (12620, '2020-02-29 15:02:23.375374+00', '2020-02-29 15:09:23.556199+00', 2371, 1, NULL, 'ace', '1--::

  1c+2c Tournée (2,1,3)

9--::

  2c+3c chase 1 place clw _as_ 1c petronella, into facing lines3 | All set ; repeat  (3x,1x,2x) 

17--::

  ½ Reels3 on sides, 1c Rsh to 2cnr (2x,1x,3x) ; ½ Reels3 across. 1c Rsh to 4cnr (2,1,3)

25--::

  All M cross & pass behind P Rsh | All M cross back, P loops and starts to follow ; All W pass Rsh behind P and cross to own side (2,1,3)



', 2);
INSERT INTO 'dancecrib' VALUES (11606, '2019-02-25 00:06:27.119397+00', '2019-02-26 11:46:50.403191+00', 19200, 2, NULL, 'ace', '1-8::  Circle round and back



9-16::  All dance right shoulder round partner, then left shoulder round partner



17–24::  Turn partner right hand then corner person left hand to finish in promenade hold, men in the inside and facing anticlockwise



25–32::  All promenade.', 5);
INSERT INTO 'dancecrib' VALUES (9597, '2017-02-14 21:53:33.472749+00', '2017-02-14 23:01:25.72172+00', 8125, 1, NULL, 'ace', '1--::

  1c set adv | Turn BH ; cast off (2cup) | set (2,1,3)

9--::

  corners set as 1c Petronella turn to make lines across | All Circle6 L ¾ | All set

17--::

  1c cross Rsh into LHA (W above, B below) ; with 1c leading unwind wheels along opposite sides | 1c cast to 2plx as dancers behind (2W+3M) dance on to end of line (3x,1x,2x)

25--::

  3C Allemande starting downwards, but at end all cross LH to own side (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2198, '2012-01-22 19:29:25.396524+00', '2017-02-14 23:23:49.742198+00', 9041, 1, NULL, 'ace', '1–::

  1c+2c+3c RHA | LHA (6H)

9–::

  1c+2c join NH with P and set | 1c Turn 2c RH and 2c face 3c ; Join NH with P and set | 2c turn 3c LH (1,2,3)

17–::

  Reels3 on own side, start 1c Rsh to 2c (1,2,3)

25–::

  "Fuguette": 1c set | 1c turn RH and stay in middle as 2c set ; 2c turn RH and stay in middle as 3c set | 3c turn RH and stay in middle

33–::

  1c+2c+3c Poussette (2,3,1)

41–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (11874, '2019-06-03 23:29:47.446815+00', '2019-06-09 16:39:02.12852+00', 17018, 1, 202, 'ace', '1--::

  1c cast (2c up) | ½ Fig8 up round 2c | set advancing to face 1cnrs

9--::

  1c turn 1cnrs RH | turn P LH to face 1cnrs ; ½ Reel4 on 1diag, pass LSh to face 2cnrs

17--::

  Repeat [9-16] with 2cnrs and pass RSh to sides (3x,1,2x)

25--::

  1c turn P RH ; turn P LH _while{8}_ cnrs set | cross RH and face on sides ; set up/down | change places LH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8936, '2015-10-12 21:14:29.654758+00', '2015-10-12 21:14:29.654758+00', 13164, 1, NULL, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 R (M up, W down), finish W above M on midline, facing opposite side

9--::

  2C+1W & 1M+3c RHA ; Snake Pass (both wheels unwind, 1c leading, passing others Lsh, and casting L to finish (3,1,2) with 1c Rsh to Rsh on midline

17--::

  2C+1W & 1M+3c LHA ; repeat Snake Pass passing the others Rsh, to (2,1,3)

25--::

  All A&R ; All dance BtoB

', 3);
INSERT INTO 'dancecrib' VALUES (11625, '2019-02-26 12:19:44.040359+00', '2019-02-26 12:28:15.03445+00', 2551, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c set | 1c & 4c cast inwards _while{2}_ 2c & 3c cross over up/down to 1plx/4plx (to 2x,1,4,3x) ; 1c+4c ½ R&L (2x,4x,1x,3x)

9--::

  2c+4c & 1c+3c ½ R&L starting up/down (to 4,2,3,1) ; 2c+3c set up/down | change places RH on sides (4,3,2,1)

17--::

  4c+3c & 2c+1c Poussette (3,4,1,2)

25--::

  All set | 2c cast to top _while{2}_ turn P RH moving down 1 place (to 2,3,4,1) ; 2c+3c & 4c+1c RHA (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (14357, '2021-10-09 06:26:01.266439+00', '2021-10-09 06:31:17.252347+00', 13056, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 R round 3cnrs (2,1,3)

9--::

  2c+1W & 1M+3c RHA. 1c retain hands with 1cnrs ; 1c turn 1cnrs RH. Pass P RSh

17--::

  2c+1M & 1W+3c LHA. 1c retain hands with 2cnrs ; 1c turn 2cnrs LH | turn P LH

25--::c

  Reels3 on sides, 1c RSh to 3cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8937, '2015-10-13 12:42:07.664738+00', '2015-10-13 12:42:07.664738+00', 7501, 1, NULL, 'ace', '1--::

  1c+5c cross and cast inwards (2c+4c to end) ; 1c+3c+5c set and ½ Circle6 L (2,5,3x,1,4)

9--::

  2c+5M & 1W+4c Rsh Reels3 across while{8} 5W+3c+1M Reel4 across, 5W & 1M passing Lsh to start, finish 5c & 1c facing 1cnrs

17--::

  5c & 1c CPCP, to (2,5,3x,1,4)

25--::

  All set | 3c cross as 2c+5c+1c+4c turn BH , finish on sidelines with 1c facing 3c ; 1c set to 3c and change places on the side. (2,5,1,3,4)

', 3);
INSERT INTO 'dancecrib' VALUES (11637, '2019-03-03 07:10:02.339081+00', '2019-03-03 07:10:02.339081+00', 12170, 1, NULL, 'ace', '1--::

  1c turn RH ; lead down and cast up round 3c (2c up) to (2,1,3)

9--::

  1c turn 1cnr RH,pass Rsh  ; turn 2cnr RH, pass Rsh 

17--::

  Circle6 and back (2,1,3)





', 3);
INSERT INTO 'dancecrib' VALUES (12621, '2020-02-29 16:05:56.637823+00', '2020-02-29 16:12:27.686104+00', 19856, 1, 1645, 'ace', '1-::

  1c & 3c set adv | &frac12; turn opposite BH to 1M & 3M in exchanged places ; 2c & 4c repeat

9-::

  All set | pull LSh back & cast cclw in tandem (M: 4,1,2,3; W: 2,3,4,1) ;

  S&Link ending on diagonals, W facing in, M BtoB facing out (1M facing 2W)

17-::

  All &frac12; turn BH | M dance to next cnr clw _while_ W chase cclw &frac12; way round inner square, making &frac14; turn at the cnr, to end facing P ;

  repeat from new places to face previous person again

25-::

  All &frac12; turn BH to next side | W chase &frac14; clw _while_ M curve RSh back in to take P RH (1,2,3,4) ;

  all lead &frac14; clw | turn P &frac34; RH (4,1,2,3)

', 5);
INSERT INTO 'dancecrib' VALUES (13963, '2021-04-18 23:21:29.094876+00', '2021-04-19 00:32:24.209307+00', 20328, 1, 202, 'ace', '1--::

  Set&Rotate (2,1)

9--::

  Chain Progression (1,2)

17--::

  Poussette (2,1)

25--::

  Circle4 and back (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (12671, '2020-03-19 00:31:30.428119+00', '2020-03-19 01:13:51.304516+00', 14540, 1, NULL, 'ace', '1--::

  Mirror Reels3 on the sides, 2c start out and up, finish 2c NHJ in 1pl facing down, 3c NHJ in 3pl facing up, 1c crossing into 2pl facing down and out, joining EH with 3c (2,1x,3)

9--::

  All set | 1c turn 3c EH, finish (2,1x,3) with 2c NHJ facing 3c HNJ and 1c facing out in 2pl EH joined with 1c ;  All set | 1c turn 2c EH, 1c finish in promhold facing down (2,1x,3)

17--::

  2M+1c+3W ½ Lsh Reel3 and 1c face across ; 2W+1c+3M ½ Reel3 (Lsh to 3M), finish (3x,1,2x) in DTr positions

25--::

  3c+1c+2c DTr, 1c dancing normal DTr but on [27-38] and [31-32] 2c+3c petronella one place cclw in the square (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12622, '2020-02-29 23:57:55.563829+00', '2020-02-29 23:59:30.180969+00', 15233, 1, 1645, 'ace', '1-4::
  All S&Link with P, M end LHJ in centre & RHJ with W originally to their R (1M with 4W)
5-8::
  All BiL | M &frac12; LHA & retain LH _while_ W dance 1 pl clw ending RHJ with P
9-12::
  All BiL | change pl RH with P & M face clw
13-16::
  All chase clw to (2,3,4,1) | set
17-::
  2c+4c dance Ladies chain
25-::
  1c+3c set adv | turn P BH (skip change) ; circle4 to L (2,3,4,1)
', 2);
INSERT INTO 'dancecrib' VALUES (8201, '2014-02-14 10:42:51.584414+00', '2020-03-01 10:22:55.002693+00', 1894, 2, 776, 'ace', '*Couple face couple round the room*  



_Bars_:: _Description_

1-8:: c1+c2 circle

9-12:: c1 lead through c2, cast back to places

13-16:: c1 TR

17-24:: c2 repeat bars 9-16

25-28:: c1+c2 set to partner, set opposite

29-32:: c2 forming arch with nearer hands | c1 dive through arch to meet new couple', 0);
INSERT INTO 'dancecrib' VALUES (12676, '2020-03-20 21:03:19.933245+00', '2020-03-20 21:03:19.933245+00', 3037, 1, NULL, 'ace', '1--::

  1c cast (2c up) | ½ Fig8 round 2c | 1c dance Lsh round P to face 1cnr

9--::

  Set H&G, 1c finish BtoB facing 2cnr

17--::

  ½ Reels3 on the sides, 1c Rsh to 2cnr ; 3c+2c continue the reels _as_ 1c dance Rsh round 4cnr to (2,1,3)

25--::

  1c dance BtoB _as_ 2c+3c set twice ; 1c sets twice _as_ 2c+3c dance BtoB (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11627, '2019-02-26 23:03:06.651575+00', '2019-03-21 00:09:52.705422+00', 278, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c set | ½ RHA (to 2x,1x,4x,3x) ; 1c+4c set | ½ LHA (2x,4,1,3x)

9--::

  2c+4c & 1c+3c set | ½ RHA (to 4x,2,3,1x) ; 2c+3c set | ½ LHA (4x,3x,2x,1x)

17--::

  Circle8 and back

25--::

  4W+3W + 2M+1M ½ diagonal R&L ; 4M+3M + 2W+1W ½ diagonal R&L (1,2,3,4)

33--::

  1c cross RH | cast off 1 place ; cross LH | cast to 4pl (2c+3c+4c up on [39-40] (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (14890, '2022-06-23 22:03:46.997573+00', '2023-02-28 00:03:22.832108+00', 20903, 1, 1645, 'ace', '1--::
  1c & 4c cross RH | cast inwards (2c & 3c to ends) ;
  &frac12; Fig8 round 2c/3c, end on 1diag, 1W behind 1M facing 2M & 4M behind 4W facing 3W
9-12::
  *Shadow H&G Setting:*
  1c & 4c set R & dance (SkCh) to sides: 1M & 4M in 2pl, 1W & 4W in 3pl |
  set & face 2cnrs, now 1M & 4W are behind P on 2diag
13-16::
  4c & 1c set R & dance to lines across: 4c/1c between 2c/3c, M closer to M side |
  set & dance to centre, 4c/1c facing M/W sides, 4M & 1W behind P
17-20::
  *Corners pass & turn in (lead change) tandem:*
  4c & 1c pass 2M/3W, change lead, pass other couple RSh & end facing 3M/2W _while{4}_ 2M+3W turn RH
21-24::
  Repeat on 2diag, 4c & 1c end in from the sides in 2pl & 3pl
25--::
  4c+1c RHA ; turn P RH (2,4,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (2252, '2012-01-22 19:29:27.95526+00', '2019-02-26 21:40:38.08558+00', 12941, 1, NULL, 'ace', '1–::

  1W, 1M following, cast off 2, cross below 3c ; 1W cast up and 1M dance up the middle and 2c dance up (to 2,1x,3) | All set adv into promhold, 1c facing down, 2c & 3c up

9–::

  Circulating Allemande: all dance as in a normal 3c allemande, only 1c starts down, finish (3,1x,2)

17–::

  1c ½ Fig8 L (W up M down) ; all turn P BH (3,1,2)

25–::

  1c+2c Poussette (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (11760, '2019-04-01 23:51:48.917358+00', '2019-06-04 17:54:17.159237+00', 19252, 1, NULL, 'ace', '1--::

  1c+2c S&Link ; ½ Reels3 on the sides, 1c Lsh to 3c (3,1,2)

9--::

  3C Knot (2,1,3)

17--::

  All chase cclw half round ; 1c ½ Fig8 R (3x,1,2x)

25--::

  1c+1cnrs ½ Reel4, pass Rsh : repeat with 2cnrs and pass Rsh (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11628, '2019-02-27 00:32:15.351279+00', '2019-02-27 00:33:06.993226+00', 2920, 1, NULL, 'ace', '1--::  

  1W+3M cross, and with P in promhold (M on L) cast L round 2c, cross, and cast L round 2c to middle, 1c (on opposite side) facing 3c _while{8}_ 2c wait{2} | set ; turn RH and face 1c (1x,2,3)

9--::  

  Reels 3 on the sides, 1c cross down to start  (1,2,3)

17-20::  

  1c+2c ½ R&L _while{4}_ 3c set and cross RH (2x,1x,3x)

21-28::

   1c+3c R&L  (2x,1x,3x)

29-32::  

  All set and cross RH (2,1,3)



', 2);
INSERT INTO 'dancecrib' VALUES (2994, '2012-01-22 19:30:06.015023+00', '2021-01-21 22:49:46.886424+00', 11669, 1, NULL, 'ace', '1–::

  1M+2W turn LH ¾ and join RH with P''s LH | in line revolve L ¾ {4}| 1M+2W turn LH ¾ (to 2,1,3)

9–::

  2c+1W & 1M+3c RHA ; the same chase in circles of 3 clw once round, 1M & 1W leading

17–::

  Repeat 9-16 (to Left, LHA, cclw), 1c finish in centre facing up

25–::

  1c lead up between 2c | cross and cast off, meet in centre | lead between 3c and cast up to 2pl (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11626, '2019-02-26 22:44:04.568951+00', '2019-02-26 23:54:07.940916+00', 3708, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c Reels4 across, 1M+2W & 3M+4W passing LSh (1,2,3,4)

9--::

  Circle8 and back

17--::

  All set | 3c followed by 2c+1c lead down, cross and cast up _while{6}_ 4c cast up and follow 1c to 4plx (3x,2x,1x,4x)

25--::

  All set | 3c+2c & 1c+4c ½ RHA ; all turn P RH (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (8425, '2014-10-11 20:39:01.684317+00', '2022-04-12 11:46:14.971927+00', 15659, 2, 1, 'ace', '1–::

  1c dance down between 2c | cast up ; dance down between 3c [2c step up] | cast up to 1st corners

9–20::

  Dance to corners and set [on bar 20, 1c pass RS then pull RS back to fin back to back, 1M facing down, 1L facing up]

21–24::

  1c dance out the ends and cast to right to fin in 2pl _while_ 2c+3c set and dance ½ RH across

25–::

  1c+3c dance the Rose Progression (1L+3M change places RH | cast to R ; dance ½ turn RH & twirl on 2M/3L diagonal _while_

  1M+3L set | dance ½ turn RH & twirl on 2M/3L diagonal | dance across to own side)', 3);
INSERT INTO 'dancecrib' VALUES (2193, '2012-01-22 19:29:25.009316+00', '2015-10-14 17:49:14.228782+00', 2030, 1, NULL, 'ace', '1–::

  1c dance NHJ between 2c and cast up to top ; dance NHJ between 3c and cast up to 1cnrs (2c up on [7-8])

9–::

  Reel4 with 1cnrs, at the end pass Lsh to face 2cnrs

17–::

  Reel4 with 2cnrs, finishing between 2c on own side, facing up NHJ

25–::

  1c cast off one | 2c+1c+3c set ; all turn P BH', 3);
INSERT INTO 'dancecrib' VALUES (11619, '2019-02-25 23:57:55.196319+00', '2019-02-27 15:50:41.33208+00', 17155, 1, 202, 'ace', '1--::

  1c+2c Poussette Right Round (1,2)

9--::

  1M+2W turn RH ¾ | dance RSh round 2M/1W back to places ; 1c+2c turn P RH (1,2)

17--::

  1W+2M turn LH ¾ | dance LSh round 2W/1M back to places ; 1c+2c turn P LH (1,2)

25--::

  2C S&Link ; 2c+1c dance BtoB (2,1)', 5);
INSERT INTO 'dancecrib' VALUES (12623, '2020-03-01 13:34:18.777628+00', '2020-03-01 13:45:50.934412+00', 10352, 1, NULL, 'ace', '1--::

  1c set | cross down into 2plx (2c up) ; All set and cross RH, 1c faces out (2x,1,3x)

9--::

  ½ Reels3 on the sides, 1c Rsh to 3cnr, at end 1c turn LH to the other side ; Repeat the ½ Reels3, 1c giving Lsh to 2cnr, 1c finish in 2pl, BtoB facing opp. side 

17--::

  All set | 1c dance out to 2plx and face in _while{2}_ 2c+3c turn P BH ½ into the middle facing P ; All set | 1c cross RH _while{2}_ 2c+3c cast R to own sideline (2,1,3)

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11629, '2019-02-27 23:44:50.711533+00', '2019-02-27 23:47:55.474859+00', 45, 1, 202, 'ace', '1--::
  1c & 4c turn P RH | cast inwards (2c & 3c step out) ; 1c & 4c ½ Fig8 through nearest middle (2,1x,4x,3)
9--::
  2c+1c & 4c+3c La-Chain (2,1x,4x,3)
17--::
  2c & 3c repeat [1-8] from new positions (1x,2x,3x,4x)
25--::
  Reels4 (1x,2x,3x,4x)
33--::
  1W+2M cross RH | 1M+2W & 1W+3W cross LH ; 1M+3M & 1W+4M cross RH | 1M+4W cross LH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2075, '2012-01-22 19:29:18.440215+00', '2020-03-20 21:16:38.623537+00', 1616, 1, NULL, 'ace', '1–::

  1c+2c+3c Turn RH ; 1c set, cast to 2pl in promhold facing up (2c up)

9–::

  1c+2W+3M Reels3, Rsh to 2W

17–::

  1c+2M+3W Reels3, Lsh to 2M, 1c finish BtoB facing own side for

25–::

  2c+1c+3c DTr', 2);
INSERT INTO 'dancecrib' VALUES (11630, '2019-02-28 19:33:02.093897+00', '2019-03-01 00:54:50.43384+00', 19205, 1, 202, 'ace', '1--::

  1c dance down (2c up) ; on [5] change sides with NHJ, 1W passing above 1M and under his arm to face up, 1c dance up to 2plx (2,1,3)

9--::

  Mirror Reels3 on sides, 1c starting out and up, 2c in and down. 1c face 1cnrs

17--::

  Corners Pass and Turn on 1diag. On [19-20] 1c turn RH and face P (M faces down, W up) ; Corners Pass and Turn on 2diag, 1c pulling RSh back. On [23-24] 1c turn RH and face P back to own side

25--::

  1c cast R to 2pl _while{2}_ 2c & 3c set | all set ; all turn P BH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (12624, '2020-03-01 16:36:33.47475+00', '2020-03-01 16:49:01.624856+00', 19849, 1, NULL, 'ace', '1--::

  All set and cross RH ; repeat (1,2,3,4)

9--::

  1c+2c & 3c+4c S&Link ; All turn P BH (2,1,4,3)

17--::

  Reels4 on the sides 

25--::

  1c+4c Espagnole (2,4,1,3)

33--::

  Circle8 and back (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12674, '2020-03-19 22:59:00.399473+00', '2020-03-19 23:02:27.376947+00', 19860, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c in and down, touching hands when possible (1,2,3)

9--::

  1c+2c turn EH 1½ ; 1c+3c turn EH 1½ (2,3,1)

17--::

  All set | all M set _while{2}_ all W advance ; all M advance _while{2}_ all W retire | all W set _while{2}_ all M retire (2,3,1)

25--::

  3c+1c the Tourbillon (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2925, '2012-01-22 19:30:03.175193+00', '2019-02-28 21:34:48.76516+00', 12744, 1, NULL, 'ace', '1–::

  1c+3c set | Petronella in tandem finishing BtoB in middle facing side couples ; All set | In each small square all Petronella Turn 1 place cclw, to form lines across (M at the ends) all facing P

9–::

  Parallel ½ Reels4 ; All set to P | In each square all Petronella Turn 1 place cclw, 1c+3c in middle face 4c+2c (M on the R) who are opposite their starting positions

17–::

  The middle men (1M+3M) change places diagonally RH with the end women (2W+4W) | Middle women (1W+3W) repeat LH with end men (2M+4M) ; 2c+4c RHA ¾, dancing out into a square set, all C facing P (4,1,2,3)

25–::

  ½ G-Chain ; all turn P RH (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (3864, '2013-07-21 10:07:55.606893+00', '2015-10-15 22:31:12.08158+00', 14982, 1, NULL, 'ace', '1–::

  1c (inwards) +2c turn EH 1¼ on side ; 1c dance down between 3c and cast up to 2pl (2,1,3)

9–::

  1c (inwards) +2c turn EH on side ; 1c dance up between 2c and cast off to 2pl

17–::

  1c (inwards) +3c turn EH on side ; 1c (inwards) +2c turn EH on side

25–::

  Circle6 and back (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14358, '2021-10-10 10:44:06.379831+00', '2022-09-13 11:56:43.121863+00', 6071, 1, 202, 'ace', '1--::

  1c (+2c who dance up to follow) lead down ; 2c+1c lead up (2,1,3,4)

9--::

  1c (+3c who dance up to follow) lead down ; 3c+1c lead up (2,3,1,4)

17--::

  1c lead down {3}, lead up {3} | cast off (4c up) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12625, '2020-03-01 16:58:43.90053+00', '2020-03-01 17:02:38.258257+00', 11804, 1, NULL, 'ace', '1--::

  1c+2c Circle4 and back

9--::

  2c+3c RHA ; LHA

17--::

  3c+4c Circle4 and back

25--::

  1c cast to 4pl (2c+3c+4c up) ; All turn P RH (2,3,4,1)



', 3);
INSERT INTO 'dancecrib' VALUES (3840, '2013-07-13 15:56:20.255924+00', '2017-02-14 23:36:56.287196+00', 9124, 1, NULL, 'ace', '1–::

  1c dance ½ Fig8 round 2c ; repeat round 3c (2c up on [5-6]) (2,1,3)

9–::

  1c dance up NHJ to between 2c | join hands and BiL ; 1c turn 2c EH to sidelines and all set (2,1,3)

17–::

  Circle6 and back

25–::

  1c+3c non-progressive knot (2,1,3)



{{explanation}}

Note: a non-progressive knot finishes with ½ LHA', 3);
INSERT INTO 'dancecrib' VALUES (12657, '2020-03-09 10:39:02.726373+00', '2020-06-28 21:23:01.277272+00', 572, 1, 202, 'ace', '1--::

  Mirror Reels4 on sides, 2c & 4c up and out, 1c & 3c crossing down to opposite sides (1x,2,3x,4)

9--::

  1c+2c & 3c+4c ½ R&L (to 2x,1,4x,3) ; ½ La-Chain up/down, finishing all W on sides, all M on midline into Reel4 position (2M,1M,4M,3M)

17--::

  Reel4 (1W,1M,3W,3M on Mside, 2M,2W,4M,4W on Wside)

25--::

  1c+2c & 3c+4c ½ R&L (to 2W,2M,4W,4M on Mside, 1M,1W,3M,3W on Wside) ; ½ La-Chain up/down, finishing all M on sides, all W on midline into Reel4 position (1W,2W,3W,4W)

33--::

  Reel4 (1x,2,3x,4)

41--::

  1c+2c ½ RHA | 1c+3c ½ LHA ; 1c+4c ½ RHA ; all set (2x,3,4x,1).



*Note:  

The dance starts again without crossing on [1-2]*', 2);
INSERT INTO 'dancecrib' VALUES (11631, '2019-03-01 15:16:10.809099+00', '2019-04-25 08:28:20.595841+00', 16825, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; cross down and cast up to 2pl (2,1,3)

9-12::

  2c+3c ½ DblFig8, 2c crossing down. 3c face in (2x,1,3x)

13-24::

  3C R&L (2x,1,3x)

25--::

  Diagonal R&L (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (13121, '2020-08-28 21:39:16.106381+00', '2020-08-28 21:59:21.592021+00', 20078, 2, NULL, 'ace', 'Dancers are numbered anticlockwise from the top: dancer 1 at the top, etc. 
1–4::                                                                                                                                                                                                                                                                                                                                                                                               All advance, join nearer hands & raise them (Christmas tree) & retire.
5–8::
  All advance then pull RSh back to cast one place clockwise, & pivot once round on the spot on last bar (ornaments). Dancer 2 is now at the top.
9–::
  All dance RH across & LH back (star). “Bottom dancers” finish nearer hands joined facing up & “top dancer” finishes facing down.
17–20::
  All set. Bottom dancers make an arch, dance up, turn towards each other & face down, while top dancer dances down under the arch & turns about, pulling right shoulder back, to face up (Santa going down the chimney).
21–24::
  All set. Top dancers make an arch, dance down, turn towards each other & face up, while bottom dancer dances up under the arch & turns about, pulling right shoulder back, to face down (Santa going up the chimney).
25–::
  All circle 3H round & back (reindeer flying).
', 4);
INSERT INTO 'dancecrib' VALUES (8940, '2015-10-16 20:13:52.530633+00', '2015-10-16 20:13:52.530633+00', 14358, 1, NULL, 'ace', '1--::

  1c+2c RHA and 1c face 2c ; set to and turn opposite RH ¾ into line across

9--::

  Reel4 across

17--::

  1W+2W & 1M+2M set and turn BH ¾ ; into Circle 4 L (2,1)

25--::

  2c+1c R&L

', 3);
INSERT INTO 'dancecrib' VALUES (8942, '2015-10-16 21:14:48.101251+00', '2015-10-16 21:14:48.101251+00', 15032, 1, NULL, 'ace', '1--::

  1c+2c chase clw once round the square 

9--::

  1c lead down (2c up on [11-12]) and up (2,1)

17--::

  1c Fig8 round 2c (2,1)

25--::

  1c+2c dance BtoB ; turn P RH (2,1)



', 3);
INSERT INTO 'dancecrib' VALUES (11876, '2019-06-07 13:28:02.974397+00', '2019-06-07 13:39:24.514442+00', 1489, 1, 202, 'ace', '1--::

  »1c Set and Hook« [: 1W+2M set | cast off/up _while{4}_ 1M+2W set advancing | turn RH ¾ (to 2,1,3) ; 1c set | cross RH (2,1x,3)

9--::

  ½ Diagonal R&L starting to the L (polite turn) ; repeat to the R (polite turn) (3x,1x,2x)

17--::

  1c ½ Fig8 L and face clw _while{4}_ 2c&3c set | cross RH ; ½ Reels3 on sides, LSh to 3cnrs[pos] (2,1,3)

25--::

  1c set | turn P RH ½ ; lead up, cross and cast to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11879, '2019-06-08 12:09:26.995174+00', '2019-06-08 12:10:13.331699+00', 19389, 1, 1645, 'ace', '1-::

  1c lead down & back to 2pl (2c up on [3-4])

9-::

  2c+1c RHA ; 1c+3c LHA, 1c end facing 1cnrs

17-::

  1c+1cnrs &frac12; RSh diag Reel4, pass RSh ; repeat with 2cnrs & all face clw (3x,1x,2x)

25-::

  All chase &frac12; way clw ; all turn RH or birl (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2981, '2012-01-22 19:30:05.50773+00', '2017-02-15 11:52:37.814056+00', 5154, 1, NULL, 'ace', '1–::

  1c+2c+3c 6H round and back

9–::

  1c followed by 2c & 3c lead down, cross at bottom and lead up on opposite side (1x,2x,3x)

17–::

  All full petronella to own sides (1,2,3)

25–::

  1c+2c half R&L ; set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11877, '2019-06-07 20:14:32.910177+00', '2019-07-21 09:11:41.491502+00', 10638, 1, 1645, 'ace', '1-::

  1W set adv to P | 1W followed by P dance down ; &frac12; turn RH (2c up) | dance up to face 2W, 1M behind 1W

9-24::

  *Shadow H&G setting:* 1c set to 2W then side by side between 2c & face 2M, 1W behind 1M ;

  repeat 3 times to end to face end facing 2W again, 1W leading

  *(when setting to or between corners, 1M is closer to 2M/3W, 1W closer to 2W/3M)*

25-40::

  1c dance four alternating tandem &frac12; diag RSh Reels3 with corners, end facing 2W again, 1W leading

41-::

  1c tandem Fig8 round 2c, starting RSh to 2W (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13679, '2021-02-21 15:38:53.975932+00', '2021-02-21 15:39:15.190894+00', 20223, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; turn LH to face 1cnrs

9--::

  1c+1cnrs change places RH | set ; changes places LH | pass P RSh to face 2cnrs

17--::

  1c+2cnrs change places RH | set ; changes places LH | pass P RSh to 2pl (2,1,3)

25--::

  All dance BtoB ; all turn P RH (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (8941, '2015-10-16 20:49:21.820263+00', '2015-10-17 01:49:58.375108+00', 8064, 1, NULL, 'ace', '1--::

  1M+3W A&R ; 1W+3M A&R

9--::

  1c+2c ½ R&L ; set | 2c cross RH to own side as 1c turn RH to face 1cnr

17--::

  1c Set to and turn 1cnr ; and 2cnr, finish facing 1cnr

25--::

  Lsh Reels3{6} on the sides | 1c cross RH (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (8945, '2015-10-19 13:36:12.854098+00', '2018-10-08 20:09:47.815617+00', 15326, 1, NULL, 'ace', '1--::

  1c cross RH | cast (2c up) ; turn BH to (2,1x,3)

9--::

  All turn P RH ½ and cast to other side (2x,1,3x) ; All set | all turn P RH ½ into Allemande Hold, 1c facing down 

17--::

  3C Circulating Allemande: On [23-24] 1c finish on opp. side as 2c+3c turn LH ¾ or 1 ¼ to midline, W in middle

25--::

  The Targe: middles turn RH ¾ as outsides chase ¼ cclw | 2c+3c turn P LH while 1c set ; repeat [25-26] | 1c set as 2c+3c turn LH ¾ or 1¼ to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8944, '2015-10-19 08:27:57.737662+00', '2015-10-19 08:27:57.737662+00', 12579, 1, NULL, 'ace', '1--::

  All set | 3c dance to 1pl as 1c cast off to 3pl ; 3c+1c set and turn BH to finish 3c facing 1c NHJ (3,2,1)

9--::

  All Circle6 and back (3,2,1)

17--::

  Mirror Reels3 on own sides, 2c start in and down, 1c & 3c cast into reel, finish 2c facing 1c NHJ (3,2,1)

25--::

  2c+1c Rondel, 1c making the arch (3,1,2)



', 3);
INSERT INTO 'dancecrib' VALUES (11880, '2019-06-08 12:12:21.133999+00', '2019-06-08 12:15:43.165772+00', 19376, 1, 1645, 'ace', '*Trio facing trio round the room considered as 3C longwise set*

1-24::

  *Dance to each corner & set:*

  Centres start by dancing to 1cnr[pos] passing RSh _as_ 1cnrs dance in passing RSh to face 2cnrs _as_ 2cnrs set |

  continue, visiting all 4 corners & ending in original places  

25-32::

  *Modified Set & Rotate:*

  All set | pull RSh back & cast &frac14; clw ; cross LH with opposite | chase &frac14; cclw to face next trio

', 2);
INSERT INTO 'dancecrib' VALUES (12988, '2020-07-25 09:33:58.501209+00', '2020-08-17 10:07:36.839892+00', 2227, 2, 2784, 'ace', '1-::
  1c set, cross RH and ‘weave’ down opp side (behind 2c, in front of 3c, behind 4c)
9-::
  1c, followed by 4c, 3c, 2c, lead up and cast off (2,3,4,1)
17-::
  1c turn RH to face opp sides and ’Strip the Willow’ up the set, turning LH on the side {2} and RH with P {2} on bar 32 2c step in for
33-::
  1c+2c Allemande, on bars 39-40 1c lead to 4pl (3c+4c up)
41-::
  2c+3c, 4c+1c R&L

*This is how the dance was originally published*
', 0);
INSERT INTO 'dancecrib' VALUES (8946, '2015-10-20 00:08:10.746601+00', '2015-10-20 00:08:10.746601+00', 16568, 1, NULL, 'ace', '1--::

  1c+2c set to P{1} and diag inwards{1} | 1M+2W cast Rsh back to midline _while{2}_ 1W+2M turn RH just over ½, into staggered line of 4, all facing P ; ½ Reel4 on midline, finish facing P

9--::

  2c+1c set | petronella to opposite sideline ; ½ R&L, at end 1M faces out (1,2,3)

17--::

  1M, 1W following. cast off on M side and cross to 2plx (2c up) , 1c pivoting L so that 1W faces out | repeat the cast, 1W leading, to (2,3,1)

25--::

  1c, 3c following, dance NHJ through 2c and cast off on own side, 1c casting up to 2pl as 3c dances to 3pl (2,1,3)

*Note: 1W may if needed on bar 20 omit the pivot L once round*





', 3);
INSERT INTO 'dancecrib' VALUES (2940, '2012-01-22 19:30:03.792183+00', '2019-03-02 11:54:03.322948+00', 11628, 1, NULL, 'ace', '1–::

  1c+3c set | cross RH ; chase clw, the W leading, to P''s place

9–::

  1c+2W & 3c+4W RHA ; 1c+4M & 3c+2M LHA

17–::

  1c+3c dance Rsh Dolphin Reels3 with corners (W lead first, change the lead at each end of reel)

25–::

  1c+3c (W leading) chase clw to opposite places ; set, cross RH to own places

33-64::

  2c+4c repeat [1-32]

65–::

  1c+3c change places (3c makes arch) | set to P ; cross back (1c arch) | set to P

73–::

  2c+4c repeat (4c makes first arch)

81–::

  All Turn P RH ; cnr LH

89–::

  All Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (11881, '2019-06-08 12:19:06.287551+00', '2019-06-08 12:19:45.256258+00', 19385, 1, 1645, 'ace', '1-::

  1c turn RH | cast off (2c up) ; 1c turn 1&frac14; LH

9-::

  2c+1W & 1M+3c &frac12; RHA ; 1c chase &frac14; clw _while_ 2c & 3c cross RH ;

  all M & all W &frac12; RHA on sides | 1c turn LH to face 1cnrs _while_ 3c+2c change RH on sides

17-::

  Turn CPCP, ending on own sides (2,1,3)

25-::

  All advance & retire ; all dance BtoB (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11882, '2019-06-08 12:21:36.027676+00', '2019-06-08 12:21:47.088394+00', 19391, 1, 1645, 'ace', '1-::

  1c+2c S&Link ; 1c &frac12; Fig8 up round 2c (2,1x)

9-::

  2c+1c La-Chain

17-::

  2c+1c &frac12; R&L (1,2x) ; 2c &frac12; Fig8 up round 1c (1,2) & 1c step in for

25-::

  1c+2c Poussette (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (8943, '2015-10-16 21:50:14.411494+00', '2015-10-20 01:05:15.758812+00', 14357, 1, NULL, 'ace', '1--::

  1c Turn RH and 1c face 2c ; set to and turn opposite RH ¾ into line across

9--::

  Reel4 across

17--::

  1W+2W & 1M+2M set and turn BH ¾ ; into Circle 4 L (2,1)

25--::

  2c+1c Poussette

', 3);
INSERT INTO 'dancecrib' VALUES (8947, '2015-10-20 19:49:05.669841+00', '2015-10-20 19:52:04.957598+00', 16204, 1, NULL, 'ace', '1--::

  1c cross LH | cast (2c up) ; set | set twirling R (1W once, 1M 1½ times) (2,1x,3)

9--::

  2c+1c La-Chain (2,1x,3)

17--::

  Reels3{6} on the sidelines, 1c start Rsh to 3c | 1c cross RH (2,1,3)

25--::

  All set R{1} and Circle6 L {3} ; pivot{1} and chase back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3388, '2012-01-22 19:30:23.308331+00', '2019-03-02 16:02:45.540839+00', 10775, 1, NULL, 'ace', '1–::

  1c+2c set, RHA, turn RH to promhold facing up

9–::

  1c+2c Allemande, 2c ending in 1pl and 1c turn LH to face opp. side

17–::

  Teapots R (M down, W up) , 1c end in 2pl and corners face out for ; ½Reels3 on sidelines (Lsh to 3cnr) (3,1,2)

25–::

  ½Reels3 across (Lsh to 1cnr pos) ; ½Reels3 on sideline (Rsh to 2cnr pos)  (2x,1x,3x)



{{explanation}}

All end on opposite side ; for the next round top and bottom are interchanged.', 3);
INSERT INTO 'dancecrib' VALUES (1664, '2012-01-22 19:28:53.757324+00', '2015-01-11 23:22:38.134507+00', 161, 1, NULL, 'ace', '1–::

  1c+2c turn ¾ RH, ½Reel4 on centre line, dance Rsh ¾ round P to (2,1,3) (»Half-Reel progression«)

9–::

  All set | cross RH and 1c face in ; ½Reels3 on sides, 1c dancing in and R (3x,1x,2x)

17–::

  Repeat (to 2,1,3)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (11665, '2019-03-12 23:14:19.264202+00', '2020-01-21 08:32:43.635894+00', 8360, 1, NULL, 'ace', '*Start (1,2,3x,4x)*

1--::

  All set to P | 1c+4c cast inwards _while{2}_ 2c+3c dance to end and face out ; 2c+1c & 4c+3c turn EH on the sides (2,1,4x,3x)

9--::

  1c+4c ½ R&L (1M+4M face out) ; 4c+1c chase ½ round cclw (2,1,4x,3x)

17--::

  Rsh Reels4 on both sidelines, at end the middle dancers pass Rsh and face each other

25--::

  1c+4c change places RH and face again | set to opposite {1} and P {1} ; change place with P with "half turn and cast away" (2,4,1x,3x)



', 4);
INSERT INTO 'dancecrib' VALUES (11883, '2019-06-08 12:24:22.633744+00', '2019-06-08 12:26:32.088646+00', 19387, 1, 1645, 'ace', '1-::

  All set | 1M+2M & 3W+4W &frac12; turn LH _while_ 1W+2W & 3M+4M  &frac12; turn RH, 1c & 4c end BtoB, NHJ with P ;

  2c & 3c dance BtoB _while_ 1c (facing up) & 4c (facing down) S&Link across (2,1x,4x,3)

9-::

  1c & 4c &frac12; Fig8 through nearest end ; 1c & 4c S&Link on sides (2,4,1,3)

17-::

  1c & 4c adv{1} & ret{1} _while_ 2c & 3c change places, M RH, W LH (3,4,1,2) | 4c+1c+2c &frac12; Reel3 on sides (3,2,1,4) | all turn BH & face up/down NHJ for

25-::

  3c+2c & 1c+4c Mirror rondels, 2c (up) & 1c (down) making arches on [25] and [31]

33-::

  2c+3c & 4c+1c Poussette (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (12900, '2020-06-28 19:36:22.632087+00', '2020-06-28 19:37:13.076574+00', 52, 1, 202, 'ace', '1--::

  1c+2c RHA ; ½ Parallel Reels3 on sides, 1c RSh to 2c (3,2,1,4)

9--::

  3c+2c & 1c+4c RHA ; ½ Reels4 on sides (4,1,2,3)

17--::

  All BHJ slip down. 4c is on original 4pl ; 1c+2c+3c slip up under 4c making arch (1,2,3,4)

25--::

  1c cast off (2c up), cross RH, cast off (3c up), cross LH, cast off (4c up) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (14359, '2021-10-10 13:45:00.748184+00', '2021-10-10 13:49:26.110254+00', 830, 1, 202, 'ace', '1--::

  1c lead down (2c up) ; lead up to 2pl (2,1,3)

9--::

  ½ Fig8 up round 2c ; 2c+1c RHA (2,1x,3)

17--::

  ½ Fig8 L round 4cnrs ; 1c+3c RHA (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10968, '2018-08-10 21:13:13.129755+00', '2019-03-02 22:20:39.392949+00', 567, 1, NULL, 'ace', '1--::

  1c+2c set | ¾ DblFig8, 1c cast off and 2c cross up to start (2,1x,3)

9--::

  The Fiddich, 2c+3c finish facing out (2W+1M & 1W+3M set | ½ RHA _while{4}_ 2M+3W chase ½ clw ; (3W+1M & 1W+2M set | ½ RHA _while{4}_ 2M+3W chase ½ clw ; 3W+1M & 1W+2M set | ½ LHA _while{4}_ 3M+2W chase ½ cclw) (2,1x,3)

17--::

  Reels3{6} on the sides, Rsh to 2cnr | 1c cross RH (2,1,3) 

25--::

  Wheelie Chain (2c+3c dance R&L, 2M+1M following & 3W+1W following each dancing as one, and each turn of the in R&L becomes a ½ 3HA) (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11884, '2019-06-09 10:24:39.71572+00', '2019-06-09 16:34:49.708475+00', 19395, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 up round 2c (2,1,3)

9--::

  All A&R ; all dance BtoB (2,1,3)

17--::

  1c Fig8 on sides, RSh to 4cnrs (2,1,3)

25--::

  2c+1c R&L (2,1,3)



*Variations:  

Bars 17-24: Reels3 on sides, 1c RSh to 4cnrs (2,1,3)  

Bars 25-32: All »The Arandel« [: All cross RH | on 2diag set diagonally _while{2}_ 1c+1cnr[pos] change place LH ; All cross RH | on 1diag same dancers set diagonally _while{2}_ 1c+same dancers change back LH] (2,1,3)*', 2);
INSERT INTO 'dancecrib' VALUES (11633, '2019-03-02 22:36:53.250917+00', '2019-03-02 22:51:47.235673+00', 16839, 1, NULL, 'ace', '1--::

  1c long cast (2c up on [3-4]) ; dance between 3c and cast up to face 1cnr

9--::

  ½ Diag Reel4, pass Lsh ; 1c+2cnrs ½ diag. Reel4, 1c finish in 2plx facing 4cnr (3x,2x,1x)

17--::

  1c ½ Reels3 across, Rsh to 4cnr ; ½ Reels3 on sides, Lsh to 3cnr (2,1,3)

25--::

  2c+1c Poussette (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (2908, '2012-01-22 19:30:02.455611+00', '2015-04-24 20:57:04.430729+00', 4890, 1, NULL, 'ace', '1–::

  All set | all turn BH twice | all set

9–::

  G-Chain (1c cross to start)

17–::

  1c Fig8 on own side round 2c+3c, starting inwards.  On [24] 1c+2c dance in for

25–::

  1c+2c ½ Poussette, on [28] 1c continue slow turn and 3c dance in ; 1c+3c ½ Poussette (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (12899, '2020-06-28 18:59:29.072669+00', '2020-06-30 18:58:20.926582+00', 47, 1, 202, 'ace', '1--::

  Circle4 and back

9--::

  Both M turn LH ¾ joining RH with opposite W | BiL ; 1c turn 2c RH ½ | BiL

17--::

  Reel4 ending as on [17]

25--::

  BiL | Both W turn LH ½ joining RH with P ; BiL | 1c & 2c turn P RH. 1c & 2c finish BtoB facing a new couple', 4);
INSERT INTO 'dancecrib' VALUES (8756, '2015-04-25 12:54:23.982241+00', '2015-04-25 12:54:23.982241+00', 16221, 1, NULL, 'ace', '1--::

  All Circle8 and back

9--::

  Mirror Reels4 on the sides, 1c+3c start in and down

17--::

  1c lead down ; and up

25--::

  1c cross RH | cast off to bottom (2c+3c+4c up) | cross RH (2,3,4,1)

33--::

  2M+3W & 4M+1W set | turn RH ; 2W+3M & 4W+1M set | turn RH (2,3,4,1)

41--::

  2c+3c & 4c+1c diagonal Reels4 (2W+3M & 4W+1M start passing Lsh and P Rsh) (2,3,4,1) 

', 3);
INSERT INTO 'dancecrib' VALUES (2757, '2012-01-22 19:29:56.189271+00', '2017-02-14 23:49:12.910068+00', 4230, 1, NULL, 'ace', '1–::

  1c turn RH {2}, cast off one (2c up) ; turn LH to 1cnrs

9–::

  1c+cnrs Reels3 on the sides, Rsh to 1cnr, at end 1c turn LH to face 2cnrs

17–::

  1c+cnrs Reels3 on the sides, Lsh to 2cnr, finish (2,1,3)

25–::

  2c+1c+3c circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (12673, '2020-03-19 18:31:34.705891+00', '2020-03-19 19:03:45.423348+00', 19893, 1, 202, 'ace', '1--::

  All dance BtoB ; 1c+2c & 3c+4c A&R diagonally into Reel4 position on sides (1,2,3,4)

9--::

  Reels4 on sides (1,2,3,4)

17--::

  1c+2c & 3c+4c set (no hands) ; RSh across ½ (to 2x,1x,4x,3x) ; all set (no hands) | 2c & 3c cross LSh _while{2}_ 1c+4c LSh across ½ ending BtoB in centre ready for

25--::

  Double SetH&G. On [31-32] all dance RSh across to sides (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2100, '2012-01-22 19:29:20.077755+00', '2015-10-21 10:32:55.844598+00', 1708, 1, NULL, 'ace', '{{explanation}}

Start with the three bottom couples on opposite side (1,2,3,4x,5x,6x)



1–::

  All W A&R ; all M dance Rsh round P into BH hold

9–::

  1c+2c+3c slip down & up (W side) _while_{8} 4c+5c+6c slip up & down (M side), finish for

17–::

  1c+2c+3c & 4c+5c+6c Allemandes, each starting towards the end. The third couple in each Allemande overtakes the second couple (2,3,1,6x,4x,5x)

25–::

  1c+6c RHA, LHA

33–::

  2c+3c & 4c+5c R&L

41–::

  1c & 6c lead towards own end, cross and cast round the end couple ; dance down/up the middle to meet and turn person opposite BH ½

49–::

  Repeat towards the other end

57–::

  All set twice ; turn P RH (2,3,1,6x,4x,5x)', 2);
INSERT INTO 'dancecrib' VALUES (11634, '2019-03-02 23:44:32.829457+00', '2019-03-02 23:56:42.70036+00', 6786, 1, NULL, 'ace', '1--::

  1c set | cast (2c up) ; ½ Reels3 on the sides, 1c Rsh to 4cnr (3,1,2)

9--::

  ½ Reels3 across, 1c Lsh to 1cnr, finish in facing lines across ; 1c set to P and turn P LH (3x,[1c],2x)

17--::

  3c+1W & 1M+2c RHA ; 3c+1M & 1W+2c LHA, finish 1c facing P on midline 

25--::

  1c set | turn RH ¾_while{4}_ 2c+3c change place RH on side | and aross LH ; All set | turn P RH (2,1,3) 

', 3);
INSERT INTO 'dancecrib' VALUES (11636, '2019-03-03 06:28:30.407825+00', '2019-03-03 06:28:30.407825+00', 15329, 1, NULL, 'ace', '*Slip step throughout*    

1--::

  Join NH to form a chain from 1W round to 1M, 1M+2M make arch, and 1W leading, the chain dance through the arch, to places

9--::

  Repeat, 1W+2W making the arch, and 1M leading the chain, to places

17--::

  1c BHJ slip down far (2c+3c+4c up) ; 1c slip up to 4pl (2,3,4,1)

25--::

  Circle8 and back (2,3,4,1)









', 3);
INSERT INTO 'dancecrib' VALUES (13571, '2021-01-22 08:54:43.91684+00', '2021-01-22 08:58:42.088155+00', 19973, 1, 202, 'ace', '1--::

  1M+2W cross RH | 1W+2M cross RH (to 2x,1x,3) | 1M+3M cross RH | 1W+3W cross RH (2x,3x,1)

9--::

  1c set | lead up between 2c |cross and cast off to 2pl (3c down) (2x,1x,3x)

17--::

  Reels3 across, 1c RSh to 4cnrs[pos]

25--::

  All A&R ; all turn RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13964, '2021-04-19 09:19:06.440377+00', '2021-04-20 15:57:57.253585+00', 20331, 1, 202, 'ace', '1--::

  1c turn BH | cast R to 1pl ; 1c+2c change places (RH on Mside, LH on Wside) | all set (2,1,3)

9--::

  1c+3c Poussette (2,1,3)

17--::

  3C S&Link ; ½ Reels3 on sides, 1c RSh to 4cnrs[pos] (2,1,3)

25--::

  1c Fig8 R round ends _while{8}_ 2c & 3c set | cross RH ; set | cross LH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14755, '2022-04-12 11:43:09.042396+00', '2022-04-12 17:06:33.585969+00', 15659, 1, 202, 'ace', '1--::
  1c dance down | cast up round 2c ; dance down bewteen 3c (2c up) | cast up to face 1cnrs
9-20::
  Dance to Corners and Set. On [19-20] 1c pass P RSh then pull RSh back into BtoB position, 1M facing down, 1W facing up
21-24::
  1c dance RSh round 4cnrs[pos] _while{4}_ 3c+2c set | ½ RHA (2,1,3)
25--::
  1c+3c Rose Progression (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2724, '2012-01-22 19:29:54.736658+00', '2020-12-18 20:52:39.812476+00', 7570, 1, NULL, 'ace', '1–::

  1c+2c set | 1M+2W turn ¾ RH and cast to place _while{4}_ 1W+2M cast clw one place and turn ¾ RH to places | 1c+2c set, advancing on [8]

9–::

  1c+2c Poussette (2,1,3)

17–::

  1c+3c DblFig8, (1c cross down, 3c dance up, finish facing out)

25–::

  2c+1c+3c mirror Reels3 on the sides, 1c starts in and up (to 2,1,3), corners finish the long way', 2);
INSERT INTO 'dancecrib' VALUES (8674, '2015-02-17 12:02:21.634746+00', '2021-06-15 11:42:54.872328+00', 1609, 2, 1, 'ace', '1–4::

  1c cross RH | cast off (2c up)

5–8::

  1L+2L turn RH ½ (fin in each other''s pl) _while_ 1M&2M set | 1c&2c turn RH ½

  (fin in sidelines, 1c on L side, 2c on M side, w/BH joined)

9–16::

  1c+2c dance 6 bars of Poussette, 1c starting towards top, 2c towards bottom

  | 1c+2c set, pivoting to join BH (1M+2W, 1W+2M)

17–24::

  1M+2W, 1W+2M dance Poussette, M dancing backward to begin

25–32::

  1M+2W, 1W+2M change pl RH | 1W+2W change pl _while_ M set ;

  1c ½Fig8 round 2c', 3);
INSERT INTO 'dancecrib' VALUES (2347, '2012-01-22 19:29:32.554951+00', '2020-12-19 11:22:55.69845+00', 8094, 1, NULL, 'ace', '1–::

  1W (1M follows) casts off and crosses to 2plx (2c up) ; Turn P LH 1¾  (2,1,3)

9–::

  2c+1W ½ RHA _while{2}_ 1M casts up on W side and pass 1W Lsh | 1M+2c ½ LHA _while{2}_ 1W cast to2pl ; Repeat with 3c (1M LH, 1W RH)  (2,1,3)

17–::

  1c+1cnrs ½ diag Reel4, 1M passes P Rsh and follows her into ; 1c (Rsh to 3M)+2cnrs ½ diag Reel3 (3x,1,2x)

25–::

  1c (Rsh to 3Wpl)+1cnrs ½ diag Reel3 ; 1c split, 1W veering R, and face 2cnr pos, 1c+2cnrs ½ diag Reel4, passing Rsh to (2,1,3)



{{explanation}}

After 2nd time through, 1c may dance [1-8] to reach 4pl', 3);
INSERT INTO 'dancecrib' VALUES (3041, '2012-01-22 19:30:07.997955+00', '2020-12-23 10:30:43.607448+00', 10116, 1, NULL, 'ace', '1–::

  1c set | cross down (no hands) (2c up) ; 1c+3c ½ R&L starting RH on sideline, finish 3c facing 1c with NHJ (2,3x,1)

9–::

  3c+1c »Set and half Rondel«: set | 3c dances down under arch by 1c, 1c+3c cross to other side | Set to P (2,1x,3)

17–::

  2c+1c »set and half Rondel«: set to P | Pass, 1M+2W making arch, cross W in front | set to other C up/down (1,2x,3)

25–::

  1W+2W turn LH 1½ _while{4}_ 1M+2M cast and dance clw half round, all to midline joining P with EH ; BiL | turn P RH ¾, 2c to 1pl and 1c to the middle, M facing down, W up

33–::

  1c ½Fig8 round 4cnr to 2pl ; All A&R', 3);
INSERT INTO 'dancecrib' VALUES (7886, '2013-08-21 08:31:50.564755+00', '2023-02-04 01:23:09.612387+00', 7031, 3, NULL, 'ace', '1-4::
    All set, 1L+2L also 3M+4M change places RH on sides _while_ 1M+2M
    also 3L+4L change places LH
5-8::
    1s+4s set (right) to each other & set (left) to partner; 1s+4s cross
    to opp sides, Ladies dancing between Men. 1s face up, 4s face down
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1s & 4s set & Petronella-in-tandem into centre, set &
    Petronella-in-tandem onto sides. 2 4 1 3
25-32::
    All circle 8H round & back.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13680, '2021-02-21 15:53:47.717731+00', '2021-02-21 15:57:54.739182+00', 20224, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c in and down, 2c out and up (1,2,3)

9--::

  All set | 1c cross RH ; cast off (2c up) | cross LSh to P to face 1cnrs

17--::

  1c set to 1cnrs | dance RSh round P to face 2cnrs _while{4}_ 1cnrs set ; 1c set to 2cnrs | dance RSh round P to face ends (1M face 2c) _while{4}_ 2cnrs set

25--::

  2c+1M & 1W+3c LHA, pass LSh ; 2c+1W & 1M+3c RHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12989, '2020-07-25 09:35:20.59202+00', '2020-08-31 15:14:25.446554+00', 3925, 2, 2784, 'ace', '1-::

  1c+4c set twice, turn RH and cast (2,1,4,3)

9-::

  2W+1W+4W Reel3 (1W+4W give Rsh) _while_ 1M+4M+3M Reel3 (1M+4M give Rsh)

17-::

  1W+4W+3W Reel3 (1W+4W give Rsh) _while_ 2M+1M+4M Reel3 (1M+4M give Rsh)

25-::

  2c+1c, 4c+3c RHA {3} LHA {3} 1c+4c cast back to pl _while_ 2c+3c lead back to pl

33-::

  1c+2c 1/2 R&L ; 1c+3c 1/2 R&L

41-::

  1c+4c 1/2 R&L ; all cross RH to own sides

', 2);
INSERT INTO 'dancecrib' VALUES (11635, '2019-03-03 05:58:31.75008+00', '2021-06-20 22:09:59.497529+00', 2177, 1, 202, 'ace', '1--::

  1c lead down ; and back to 1pl centre. On [8] 2c step in ready for (1,2)

9--::

  6 bars of 2C Allemande | on [15-16] Petronella turn into midline

17--::

  2 bars of Reel4 | BiL ; repeat [17-20]

25--::

  Repeat [17-20] ; 2 bars of Reel4 | dance out to own sides (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (12979, '2020-07-24 09:12:10.45937+00', '2020-07-25 03:52:14.017748+00', 20054, 1, 202, 'ace', '1--::

  1c set | Petronella turn to midline ; set | turn P BH ¾ to 1plx (1x,2,3)

9--::

  1c+2c »Modified 4 bars of Espagnole« [: same as 4 bars of Espagnole but on [11-12] 1W+2M give LH] (to 2,1x,3) ; 1c+3c Circle4 R ½ | 2c & 1c set _while{2}_ 3c cross RH (2,3,1)

17--::

  3C S&Link twice (1x,3x,2x)

25--::

  All chase clw ½ (to 2,3,1) ; turn P RH | A&R{1+1} (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (13818, '2021-03-16 04:51:39.13389+00', '2021-03-22 17:45:23.926745+00', 20258, 1, 202, 'ace', '1--::
  1c set | 1c wave on sides to 4 pl, RSh to 2c (2c & 3c & 3c stepping up every two bars starting on [3-4]). On [8] 1c face up, 3c & 4c down
9--::
  3c+4c+1c ½ Parallel Reels3 on sides, 1c RSh to 4c (to 2,1,4,3) ; all set | all cross to opposite sides, 2W+1W & 4W+3W under 2M+1M & 4M+3M making arches into Reel4 position on sides (2x,1x,4x,3x)
17--::
  Set H. Schottische R foot | changes places LH on sides (polite turn)  and face P ; Set H. Schottische L Foot | cross RH (1,2,3,4)
25--::
  1c+2c & 3c+4c The Knot. On [31-32] 1c+4c ½ LHA (2,4,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (14360, '2021-10-11 02:52:57.69262+00', '2021-10-11 02:56:17.404706+00', 3944, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c in and down, 2c out and up, 3c casting to start then in and up (1,2,3)

9--::

  1M+2W & 2M+3W change places RH _while{2}_ 1W & 3M set | 1c+3c change places diagonally ; all chase clw two places (1,2,3)

17--::

  1c cross | cast off (2c up) ; dance down between 3c | cross and cast up to 2pl (2,1x,3)

25--::

  1c turn P RH ¾ into facing lines3 across | all set ; 1c turn P RH ¾ : all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14465, '2021-11-23 21:56:02.192726+00', '2021-11-27 16:56:55.469121+00', 20561, 2, 2269, 'ace', ' 1-:: All set on the sides, 1W cast down 2 places, round 3W to 2nd place facing up _while_ 1M dance down round 3M to 2nd place facing up (2c up on 5-6)

 9-:: 1s dance reel of 3 on sides (LSh to 2s)

 17-:: 2c+1c LH across, 1c+3c RH across

 25-:: 1W cast up 1 place and dance down to 3rd place _while_ 1M dance up and cast to 3rd place (3c up on 27-28), All set on sides ', 4);
INSERT INTO 'dancecrib' VALUES (14467, '2021-11-25 13:35:04.110989+00', '2022-06-16 22:20:37.322854+00', 20320, 1, 202, 'ace', '1--::
  1c set | cross down RH ; cast off behind 3c | dance up NHJ to 2pl centre facing opposite sides (2c up on [7-8])
9--::
  1c 6 bars of DTr _while{6}_ 2c & 3c set | cross RH ; set  | 1c dance RSh round 3cnrs[pos] into facing lines3 across _while{2}_ 2c & 3c cross RH
17--::
  3C S&Link (2,1,3) ; all turn P RH 1½ (2,1,3)
25--::
  Circle6 and back (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11897, '2019-06-16 12:46:03.424698+00', '2022-08-17 21:29:45.115979+00', 19405, 1, 202, 'ace', '1--::

  1c dance down between 3c, cast up, dance up between 2c and cast to 2pl (2c up) (2,1,3)

9--::

  All turn P LH 1½ ; all chase cclw ½ (3,1,2)

17--::

  Reels3 on sides, 1c RSh to 4cnrs[pos], 3W & 2M casting to start (3,1,2)

25--::

  3c+1W & 1M+2c RHA ; with 1c leading LSh Snake Pass to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13962, '2021-04-18 21:25:33.598654+00', '2022-12-10 12:46:15.011601+00', 3892, 2, 963, 'ace', '1-8::  

  1c & 2c set and rotate

9-16::

  1c R4 up&down with 1st corners - begin 1c pass rt sh with 1st corner, end corners pull back rt sh, 1c pull back lt sh to   2,1,3  

17-20::  

  1c ''gypsy'' left to finish btob, woman facing up, man dwn  

21-24::

  1w with 2c, 1m with 3c circle 3 hands round to the left 2,1,3   

25-32::  

  1c R4 across with 2nd corners - begin 1c pass L sh, 2w dance down, 3m dance up, end 2,1,3

  ', 2);
INSERT INTO 'dancecrib' VALUES (13205, '2020-09-22 18:39:55.730261+00', '2020-09-23 09:26:22.34188+00', 20083, 1, NULL, 'ace', '1--::

  1c+2c The Knot (2,1,3)

9--::

  ½ "Dance to each cnr and set", 1c starts along 1diag | 2c+3c chase clw one place _while{2}_ 1c set, and finish in the middle facing P across

17--::

  Mirror Reels3{6} on own sides, 1c lead down to start | 1c+3c pass RH on the sides (2,3,1)

25--::

  All circle L ½,  finish in circle ; all dance to centre, cast R and chase clw to (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (11886, '2019-06-10 13:35:35.494571+00', '2020-02-13 16:53:37.973602+00', 1569, 1, 202, 'ace', '1--::

  All set | cross RH ; repeat (1,2,3,4)

9--::

  1W+4M cross | cast to exchanged places _while{4}_ 1M+4W A&R diagonally ; 1M+4W cross | cast to exchanged places _while{4}_ 1W+4M A&R diagonally (4x,2,3,1x)

17--::

  2c+3c set | ½ RHA (to 4x,3x,2x,1x) ; 4c+3c+2c ½ Reels3 on sides, 3c RSh to 4c (2x,3x,4x,1x)

25--::

  All set twice ; 2c+3c & 4c+1c ½ DblFig8 [: 2c&4c cross down RH and cast up _while{4}_ 3c&1c cast up and cross down] (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (11639, '2019-03-03 14:47:01.773938+00', '2019-03-03 14:47:01.773938+00', 9669, 1, NULL, 'ace', '1--:: 

  1M+2W turn RH ; dance BtoB

9--:: 

  1W+2M turn RH ; dance BtoB

17--:: 

  2c+1c following dance down the middle, 1c splits ; 2c+1c following dance up (2,1)

25--:: 

  2c+1c RHA ; LHA (2,1)



', 3);
INSERT INTO 'dancecrib' VALUES (2966, '2012-01-22 19:30:04.892385+00', '2017-02-15 11:51:53.403908+00', 5090, 1, NULL, 'ace', '1–::

  1c set | cast off ; dance between 3c (2c up) and cast up (2,1,3)

9–::

  2c+1c set | cross RH and face other couple ; set | turn RH ½ to meet P in middle facing down

17–::

  2c (leading)+1c lead down, change side (W pass above M under his arm) ; and lead up (to 1,2,3)

25–::

  Progressive Chain (like G-Chain, 2 bars/hand, but when meeting P make full turn to stay on own side (to start, 1c turn, 2c+3c change on side)  (2,3,1)

33–::

  All circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10141, '2017-09-22 21:48:25.975+00', '2020-08-29 22:57:56.135776+00', 1245, 2, 160, 'ace', '1-8::

  1s dance mirror figure eight on own sides - 1s in and down to begin (touch hands when possible).

9-16::

  1s cross over RH, cast 1place; cross over LH and cast left (1W up around 2W +1M down around 3M) into lines3 across.

17-24::

  All set in lines across, 1s turn RH 3/4 to opposite sides ; all set on sides. 1s cross RH to own sides.

25-32::

  Dance 6 hands round & back.

', 3);
INSERT INTO 'dancecrib' VALUES (12990, '2020-07-25 09:37:09.917809+00', '2020-10-21 10:32:45.131803+00', 17084, 2, 2784, 'ace', '*3c+4c start on opp side (1,2,3x,4x)*

1-::

  1c+2c, 3c+4c DblFig8 (1c cross down, 4c cross up, 2c+3c cast)

9-::

  1c+4c L-chain (M stand 9-10), end with W facing in middle of set, M at ends of set facing in

17-::

  1M+2c+3c+4M circle6 and back to end in original pl _while_ 1W+4W set, change pl RH, set, change pl LH to end facing out of set

25-::

  1c promhold cast round 1M pl (2c up), drop RH and dance into 2 pl _while_ 4c promhold cast round 4M pl (3c down), drop RH and dance into 3 pl ;

1c+4c 1/2 R&L (no polite turn)



*W may improvise solo (bars 17-24) but must end beside P facing out of the set*

', 2);
INSERT INTO 'dancecrib' VALUES (11638, '2019-03-03 07:21:44.317737+00', '2019-03-03 07:31:14.395944+00', 19212, 2, NULL, 'ace', '1-4::  

  1st couple turn by the right, man ends facing out, woman facing in.  *Charles and Linda meet.*  

5-6:: 

  1st man cast down into 2nd place, 2nd man step up; 1st woman set in original place.  *Charles goes off to China.*  

7-8::  

  1st woman casts thru 2nd place to meet partner in center of the set, 2nd woman step up. 1st man advance setting to meet his partner in the center of the set; both finish facing up with nearer hands joined. 3rd couple step into the center, also facing up with nearer hands joined.  *Linda goes to China later.*  

9-16::  

  1st and 3rd couples advance and retire up and down the center of the set twice.  *Lion Dance in celebration.*  

17-24::  

  1st couple turn 2nd couple above with outside hands: men by left hand, women by right. 1st couple turn 3rd couple below with inside hands: men by right hand, women by left. *Charles and Linda visit a pagoda.*  

25-26::

  Begin to form a circle of dancers in the center of the set:  2nd man and 3rd woman advance setting and continue setting.   *Firecrackers going off.*  

27-28::  

  3rd man and 2nd woman advance setting to center and continue setting.  *More firecrackers going off.*  

29-30::    

  1st couple advance setting to center.  *More firecrackers going off.*  

31-32::  

  All 3 couples cast back to sides with pas de basque.  *Fireworks explode.*  ', 5);
INSERT INTO 'dancecrib' VALUES (2181, '2012-01-22 19:29:24.222857+00', '2020-08-30 21:31:04.065667+00', 13367, 1, NULL, 'ace', '1–::

  1c+2c+3c set | Mirror Reels3{6} on own side, 2c start out and up

9–::

  1c dance BtoB ; cast off (2c up) | cross RH and face out (2,1x,3)

17–::

  1cnrs dance BtoB diagonally _while_{4} 1c cast R to meet in centre and stand BtoB, M facing down, W up ; All dance 4 bars of DTr, finish 1M facing up, 1W down

25–::

  2cnrs dance BtoB diagonally _while_{4} 1c cast R to meet in centre and stand BtoB, facing opposite side ; All dance 4 bars of DTr, finish (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13206, '2020-09-26 03:54:09.698781+00', '2020-12-07 13:04:02.524346+00', 10408, 1, 202, 'ace', '1--::

  Parallel Reels3 on sides, 1c LSh to 2c (1,2,3)

9-24::

  1c turn 2c LH 1½ on sides (to 2,1,3) | 3C R&L (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (13676, '2021-02-20 21:24:46.479088+00', '2021-02-20 21:24:46.479088+00', 20221, 2, NULL, 'ace', '1-8:: 1s slip step down and back.



9-16:: 1s followed by 2s+3s+4s cast to bottom & 1s form arch as 2s+3s+4s dance under arch & up to top



17-24:: Men thread the needle.



25-32:: Women thread the needle.

', 2);
INSERT INTO 'dancecrib' VALUES (12519, '2020-01-21 07:13:47.367858+00', '2020-01-22 09:09:37.019709+00', 19833, 2, 2697, 'ace', '1-8::

   1s set | cast 1place ; dance down | cast up to 2nd place own sides

9-16::

   1s set advancing to 1st corners | turn 2H to finish in lines across (1L with 2s, 1M with 3); Repeat with 2nd corners to finish on 2nd place opp sides

17-24::

   1s dance ½ fig of 8 to 2nd place own sides (1L up, 1M down) ; all set | turn RH into Allemande hold , ready for…

25-32::

   Allemande for 3cpls', 0);
INSERT INTO 'dancecrib' VALUES (2231, '2012-01-22 19:29:26.977767+00', '2021-03-16 05:18:15.760914+00', 11878, 1, 202, 'ace', '1–::
  1c set | cross RH ; cast off (2c up) | 2c+1c set (2,1x)
9–::
  1c+2c L-Chain. 1M faces facing out
17–::
  1M casts up _while_ 1W dances up | 1c (1W leading) cast off and cross to 2pl | 1c dance up in promhold
25–::
  1c (promhold) +2c ½ Reel3 across, RSh to 2W ; 1c split and cast to 2pl as 2c continues the reel (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (12677, '2020-03-21 03:17:46.548455+00', '2020-03-22 00:40:11.68478+00', 19864, 1, 202, 'ace', '1--::

  1c+2c the Espagnole. On [5-8] 1c turn P LH 1¼ to face 1cnrs

9--::

  ½ Reel4 on 1diag, pass LSh ; ½ Reel4 on 2diag. On [16] 1c turn P LH ½. 1c LSh to P face opposite side

17--::

  3c+1W & 1M+2c RHA ; 1c »Rsh Turn« [: Dance RSh round P to 2pl] _while{4}_ 3c+2c chase clw ½  (2,1,3)

25--::

  Circle6 and back



*Note:*  

»RSh Turn« (Right Shoulder Turn) is also known as Gypsy Turn, a term now considered offensive by some.', 2);
INSERT INTO 'dancecrib' VALUES (2576, '2012-01-22 19:29:48.301786+00', '2020-12-18 21:02:55.964158+00', 7782, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; ½Fig8 R round 3cnr (2,1,3)

9–::

  Diagonal R&L, 1c finish in the middle facing own sides Lsh to Lsh, no polite turn (3x,1,2x)

17–::

  3c+1M & 1W+2c ½ RHA | 3c & 2c continue, turning RH once round _while{4}_ 1c chase ½ way clw round set | 1M+2c & 1L+3c ½ RHA, 1c finish facing 1cnr position

25–::

  1c ½ Diag. Reel4 with 1cnrs, 1c pass Rsh to face 2cnr pos ; ½ Diag. Reel4 with 2cnrs ; 1c pass Rsh to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11563, '2019-02-03 10:09:37.924004+00', '2020-08-30 09:37:16.908205+00', 1963, 1, 202, 'ace', '1--::

  1c+2c »Progressive DblFig8« [1c cross, cast ; cross up, cast while{8} 2c set, cross up, cast, cross up] (2,1,3)

9--::

  Reels3 on sides, 1c in and down, 3c out and up. On [16] 1c pass LSh to face 1cnrs

17--::

   Reels3 across, 1c LSh to 1cnrs (2,1,3)

25--::

  1c+3c RHA ; ½ Poussette (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11935, '2019-07-03 08:18:28.510775+00', '2021-04-18 19:02:51.62363+00', 10368, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; 2c+1W & 1M+3c RHA. 2W & 3M face out (2,1,3)

9--::

  All cnrs chase clw ½. 2W & 3M face out ; 1c turn 4cnrs[pos] EH (3x,1,2x)

17--::

  1c ½ Fig8 L ; 3c+1W & 1M+2c LHA. 3W & 2M face out (3x,1x,2x)

25--::

  All cnrs chase cclw ½. 3W & 2M face out ; 1c turn 1cnrs EH (2,1x,3)

33--::

  Reels3{6} on sides, 1c RSh to 2cnrs | 1c cross LH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13677, '2021-02-20 21:35:07.436674+00', '2021-02-20 21:35:07.436674+00', 20222, 2, NULL, 'ace', '1-4:: Four steps forward, four steps back.



5-8:: Eight steps forward.



9-12:: Men dance in front of their partner and get back to place (possible change partner to get back to partner behind).



13-16:: Partners repeat (possible change partner to get back partner in front).



17-24:: Four slip steps anticlockwise and turn away from partner, repeat backwards.



25-28:: Clap 3 times: own hands, own hands risen in the air, stamp 3 times and clap on partner''s both hands.



29-32:: Polka.

', 2);
INSERT INTO 'dancecrib' VALUES (11640, '2019-03-03 21:05:57.725365+00', '2019-03-03 21:05:57.725365+00', 12399, 1, NULL, 'ace', '1--:: 

  1c lead down the middle ; cross below 4pl and cast up to (1x,2,3,4)

9--:: 

  1W leads 2M+3M+4M clw round the set, to (1x,2,3,4)

17--:: 

  1M leads 2W+3W+4W cclw round the set, to (1x,2,3,4)

25--:: 

  1c turn RH and face 2c | 1c turn 2c LH ; 1c turn RH to face 3c (2c up) | 1c turn 3c LH



33--:: 

  1c turn RH and face 4c (3c up) | 1c turn 4c LH ; 1c turn RH to 4pl (4c up) (2,3,4,1)





', 2);
INSERT INTO 'dancecrib' VALUES (11641, '2019-03-03 21:49:58.526242+00', '2019-03-03 21:50:36.110641+00', 17745, 1, NULL, 'ace', '1--::

  1c+2c Espagnole, 1c face 1cnr

9--::

  1c+1cnrs ½ diag. Reel4, pass Lsh ; 1c+2cnrs repeat, and 1c face 3cnr

17--::

  Set to and turn cnrs BH, (3x,1,2x)

25--::

  Diagonal R&L (start to the R) (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (11642, '2019-03-03 22:09:19.306905+00', '2019-03-03 22:11:42.941871+00', 17187, 1, NULL, 'ace', '1--::

  Big wheel (M in middle. NHJ with P) LHA ; repeat with W in middle RHA, to places with 1c facing clw

9-24::

  1c making arch dance over 2c, 3c, 4c, to places ; 2c repeat ; 3c repeat ; 4c repeat

25--::

  Circle8 and back (1,2,3,4)  



*3 repetitions, starting on bar 9 with 2c, 3c, 4c respectively*', 3);
INSERT INTO 'dancecrib' VALUES (11643, '2019-03-03 22:52:00.51469+00', '2019-03-04 01:15:10.094697+00', 19222, 1, 202, 'ace', '1--::

  All set | cross RH ; repeat (1,2,3,4)

9--::

  1c lead down ; and up 

17--::

  1c followed by 2c+3c+4c cast to 4pl and make arch ; 2c+3c+4c dance up under it to progressed places (2,3,4,1)

25--::

  Circle8 and back (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (9563, '2017-01-27 16:04:04.171107+00', '2019-06-11 21:23:07.188506+00', 15008, 2, 160, 'ace', '1-8::

  1C cross down to 3pl, cast up to 2pl *AS* 2C set, cross down to 3pl *AS* 3C cast to top pl, cross over RH ; All set, cross over RH. (3 1 2)

9-16::

  Chase CW half round ; All turn RH half way and cast to own sides. (2 1 3)

17-24::

  Grand Chain - 1C end B-to-B facing own side.

25-32::

  All set, 1W 3W also 1M 2M turn RH ; All set, 1W 2W also 1M 3M turn LH.

33-40::

  1C dance out through 2pl, cast up and meet at top (3C up); dance down the center and loop into 3pl.', 3);
INSERT INTO 'dancecrib' VALUES (3554, '2012-01-22 19:30:30.771309+00', '2020-09-24 12:48:35.242474+00', 13886, 1, NULL, 'ace', '1–::

  1c Cast into Fig8 on own side round 2c & 3c (join hands when possible)

9–::

  1c+2c set to P | turn P BH ; Circle4 L

17–::

  1c+2c+3c The Knot (to 3,2,1)

25–::

  3c+2c & 1c+4c set to P (join hands in pairs) | dance ¾ of R&L (to 2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (11644, '2019-03-04 17:02:16.087451+00', '2019-03-04 17:05:19.191768+00', 4550, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; cross LH | cast L to between end cpls facing P 

9--::

  1c set adv and pivot R ½ to finish BtoB facing ends _while{2}_ 2c+3c set turning ¼ to face up/dn | set as in DTr ; All set adv and pivot (2c+3c inwards, 1c R), finish 2c BtoB with 3c on the sides and 1c at the ends facing P | All set as Inverted Triangles 

17--::

  1c change places RH _while{2}_ 2c/3c dance to 1pl/3pl facing out | Reels3{6} across, 1c Rsh to 2cnr, finish (2,1,3) 

25--::

  2c+1M & 1W+3c LHA ; 1c turn RH | All set (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9598, '2017-02-19 02:45:03.145552+00', '2017-08-25 06:01:54.95319+00', 17613, 1, NULL, 'ace', '1-::

 1c lead down the middle and up, 2c step in on bar 8 for

9-::

 1c+2c allemande, 1c finishing facing 1cnr

17-::

 Modified Cnrs Pass&Turn : 1c dance normally, but cnrs turn RH ½ and twirl R to exchanged places (3x,1x,2x)

25-::

 Set&Rotate for three [All Set | all cast clw to lines across ; all cpls change place RH | all chase clw] (2x,1x,3x)



{{explanation}}

The set is now inverted ; repeat using the bottom (3c) as new top.', 5);
INSERT INTO 'dancecrib' VALUES (8955, '2015-11-02 04:43:41.429833+00', '2021-03-16 10:14:26.753595+00', 8620, 2, 2452, 'ace', '1-8:: ADVANCE, RETIRE, ½ TURN, TWIRL, AND TURN: All advance and retire to partner (1 step each way: 2 bars), turn halfway with right hands and twirl to partner place (i.e. retaining right hands dance toward partner, and pulling right shoulder back dance to partner''s place), then turn partner ¾ round with right hands;

9-16:: CHASE: Men dance anticlockwise round an inner circle AS women dance clockwise round outer circle (4 bars), pull right shoulder back and chase back to partner;

17-20::  TURN: turn partner 1¼ times around with left hands to original places;

21-24:: SET: Set to partner with Glasgow Highlanders Setting Step;

25-28:: ½ CIRCULAR REELS OF 3: all dance a ½ reel of 3 starting by passing partner by the left shoulder and the next person by the right shoulder; and reversing direction

29-32:: TURN: turn new partner 1½ times around with both hands.



REPEAT WITH NEW PARTNER.', 0);
INSERT INTO 'dancecrib' VALUES (8103, '2013-11-08 00:09:08.76048+00', '2019-06-12 22:52:54.712017+00', 5830, 1, NULL, 'ace', '1–::

  1c cross down RH to 3plx and cast up one _while_{4} 2c set and cross down RH to 3plx _while_{4} 3c cast up to 1pl and cross RH (3x,1x,2x) ; 1c cross LH and cast L to midline, all cpls face person opposite up/dn

9–::

  All turn person opposite RH, 3c & 2c finish facing out the ends ; Half Reels3 on the sides, 1c on own side giving Rsh to 3cnr pos, and finishing 1M at top between 2c and 1W between 3c

17–::

  1c ½ Fig8 on own side (Lsh to 4cnr pos) ; pass P RH up/dn and cast R round 2cnr pos to (2x,1x,3x)

25–::

  All turn P RH, 2c & 3c end facning out ; Half Reels3 across, 1c giving Rsh to 4cnr pos (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12675, '2020-03-19 23:10:59.531659+00', '2020-03-19 23:16:18.657493+00', 18576, 1, NULL, 'ace', '1--::

  Reels3 on the sides, 1c crossing down and 2c starting out and up, finish 1c in 1plx and 2c between 3c in 3pl, facing up

9--::

  1c cross Rsh and cast off _as_ 2c dance up (no hands) and 2M faces out ; 2c+1c chase cclw ½, 1W+2M face out (1x,2x,3) 

17--::

  1c (1W leading) + 2c (2M leading) cast off behind 3c | dance ¾ DblFig8 up round 3c (2c always cross first) (1c+2c finish on opposite sides, 2M+1W above 3c and 1M+2W below 3c) 

25--::

  1W+2M & 1M+2W cross up _as_ 3c dance up the sides | 1W followed by 3W+2W dance up, cross at the top, and down behind the M, cross below P to own side (2,3,1)



', 0);
INSERT INTO 'dancecrib' VALUES (2090, '2012-01-22 19:29:19.217031+00', '2021-02-17 20:00:36.148019+00', 9855, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; 2c+3c turn P RH, finish 2M & 3W on own sideline and P on midline _while_{4} 1c turn LH to finish 1W in 1Wpl and 1M in 3Mpl

9–::

  1W+2W facing 1M+3M S&Link (brings 1M&1W to midline) ; Set in facing lines across | 1c cast to 2pl _while_{2} 2c+3c change places on the side, the M with RH and the W with LH (3,1,2)

17–::

  [»Double Muirland Willie«] top C lead down RH crossing to 3pl and cast up to 2pl _while_{4} mid C set to P and cross down RH _while_{4} bottom C cast to top and cross RH (2x,3x,1x) ; repeat from new positions, using LH (1,2,3), but 1c+2c finish for

25–::

  1c+2c Allemande', 3);
INSERT INTO 'dancecrib' VALUES (11888, '2019-06-14 22:32:04.189094+00', '2022-10-03 08:22:33.311121+00', 19398, 1, 202, 'ace', '1--::
  1c+2c Set&Rotate (2,1,3)
9--::
  2c+1c *The Helix* : both couples set passing LSh | cast R back to own sides ; turn P RH ½ | ½ RHA (1,2,3)
17--::
  Inveran Reels3 (1,2,3)
25--::
  1c+2c The Tournée (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2209, '2012-01-22 19:29:25.908386+00', '2020-08-30 09:47:07.692612+00', 2100, 1, NULL, 'ace', '1–::

  1c lead down {3}, up {3} | cast to 2pl (2c up)

9–::

  1c+1cnrs ½ diagonal R&L (no polite turn), finish 1M above 1W BtoB facing ends ; with these circle3 L, circles break between the cnr persons and unwind to finish (2,1x,3)

17–::

  1c+4cnrs ½ diagonal R&L (no polite turn), finish 1W above 1M BtoB facing ends ; with these circle3 R, circles break between the cnr persons and unwind to finish (2, 1, 3)

25–::

  All C set | turn BH {4} | set', 3);
INSERT INTO 'dancecrib' VALUES (11321, '2018-10-29 21:13:53.095221+00', '2020-08-31 13:50:03.625144+00', 3667, 2, 13151, 'ace', '1–4:: 1C turn RH and cast off (2C up on 3+4).

5-8:: 1C dance down NHJ below 3C and cast up round them into 2pl.

9–16:: 1M Reel3 LSh with 3C while 1L LSh with 2C. 1C finish in 2pl BtoB (pulling RSh back when approaching).

17–20:: 1C, 2C & 3C join hands as for DTr and set. While 1C move round to the other side 2C & 3C dance two PdB on the spot but making a complete turn to the right.

21-24:: Repeat 17-20 finishing with 1C BtoB facing out.

25-32:: 1C, 2C & 3C mirror Reels3 on the sides (1c start out & up).', 4);
INSERT INTO 'dancecrib' VALUES (1588, '2012-01-20 13:06:12.793896+00', '2020-08-31 14:32:58.352941+00', 3669, 2, 1, 'ace', '1-8::

  1C cross R | cast off (2C up) ; ½Fig8 round 2C

9-16::

  2C+1C+3C lead down the middle and up, fin in centre

17-24::

  2C+1C+3C promenade

25-28::

  1M RH across w/3C _while_ 1W RH across w/2C

29-32::

  1M LH across w/2C _while_ 1W LH across w/3C

', 3);
INSERT INTO 'dancecrib' VALUES (2910, '2012-01-22 19:30:02.534603+00', '2015-04-27 21:44:31.746177+00', 8727, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; dance between 3c and cast up to face 1cnrs

9–::

  (1cnr Chain:) 1c+1cnrs change places RH | 1cnrs turn LH ; 1c+1cnrs change places RH | 1c turn LH to face 1cnr

17–::

  SetH&G , finish facing 2cnr

25–::

  (2cnr Chain:) repeat [9-16] with 2cnrs, finish 2pl facing out (2,1,3)

33–::

  Opposing Reels3 on the sides, 1c Lsh to 4cnr', 3);
INSERT INTO 'dancecrib' VALUES (14352, '2021-10-05 22:31:37.660467+00', '2021-10-05 22:47:54.397877+00', 17628, 1, 202, 'ace', '1--::
  2c & 4c set advancing to centre finishing facing own sides BtoB with P into DTr position _while{2} 1c+3c+5c Petronella turn one place cclw round the set | all continue the DTr with Petronella {6}. 2c & 4c in centre face 1cnrs (3W,1W,1M on Mside, 5W,5M,3M on Wside)
9--::
 ½ Reels4 on 1diag, pass P RSh ; ½ Reels4 on 2diag, pass P RSh to face 3cnrs[pos]
17--::
  All repeat same pattern [9-16] to finish as on [1]
25--::
  Top two couples ½ RHA _while_ last couple turn P LH ½ (to 2x,1x,4x,3x,5x) | top couple turn P R ½ _while_ last two couples ½ LHA (to 2,4,1,5,3) ; all repeat same pattern [25-28] (4,5,2,3,1)

*Deviser''s note* : 2nd couple and 4th couple are dancing couples. In bars 25-32 it is important that, at the end of every two bars, everyone continues dancing in the direction they are facing, rather than turning away to the sides.', 2);
INSERT INTO 'dancecrib' VALUES (11525, '2019-01-20 10:02:42.821632+00', '2019-03-05 20:08:00.665127+00', 9280, 1, 202, 'ace', '{{title}}

Strathspey



1--::

  1c & 3c Petronella Turn | set ; turn LH ¾ | all set (1,2,3,4)

9--::

  2c & 4c cross RH | cast up 1 place ; cross LH | cast to original places (1,2,3,4)

17--::

  1c+2c & 3c+4c S&Link ; all turn P RH into promhold facing up (2,1,4,3)

25--::

  4C Promenade (2,1,4,3)



{{title}}

Reel



1--::

  2c+1c & 4c+3c Set&Rotate (1,2,3,4)

9--::

  Reels4 on sides (1,2,3,4)

17--::

  1c & 3c set | 1c cast to 3pl _as_ 3c dance (no hands) to 1pl ; all set | set advancing and join BH (3,2,1,4)

25--::

  3c+2c & 1c+4c Poussette (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12962, '2020-07-16 09:47:33.824534+00', '2020-07-24 10:30:33.337721+00', 20048, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; 4c set | cast up (3c down) (2,1,4,3)

9--::

  2W & 3M Petronella turn | set ; 2M & 3W repeat [9-12]

17--::

  ½ Reel4 on midline ; 3M & 2W (their P following) chase clw ½ to 4pl/1pl (2,1,4,3)

25--::

  1c+4c S&Link no hands ; All BtoB (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11890, '2019-06-15 07:43:44.549176+00', '2019-06-15 07:51:32.240106+00', 19400, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; ½ Reels3 on sides, 1c in and down (3,1,2)

9-20::

  3C R&L (3,1,2)

21-24::

  1c & 2c cross RH | ½ RHA _while{4}_ 3c turn RH. 3c+2c+1c finish in centre facing P (3,2,1)

25--::

 3C Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11891, '2019-06-15 22:08:54.480831+00', '2019-06-15 22:15:48.735025+00', 19401, 1, 202, 'ace', '1--::

  1c+2c A&R ; set | 1c cast (2c up) (2,1,3)

9--::

  1c+3c repeat [1-8] (2,3,1)

17--::

  1c dance up to top and cast to 2pl (3c down on [19-20]) ; 1c turn P LH to face 1cnrs

25--::

  SetH&G (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2039, '2012-01-22 19:29:16.522358+00', '2021-03-16 10:17:12.636568+00', 8603, 1, NULL, 'ace', '1–::

  All W A&R ; all M repeat

9–::

  1c+2c RHA ; LHA

17–::

  All set twice ; 1c cast to the bottom (others up) (2,3,1)

25–::

  1c Fig8 round couple above



{{explanation}}

Deviser''s Note: this dance can also be done in a 2C, 4C or 5C set)', 2);
INSERT INTO 'dancecrib' VALUES (13681, '2021-02-21 16:50:52.004845+00', '2021-08-24 18:37:54.702081+00', 20225, 1, 202, 'ace', '1--::
  1W+3M set | change places RH ; chase clw ½ to original places (1,2,3)
9--::
  1M+3W set | change places LH ; chase cclw ½ to original places (1,2,3)
17--::
  Mirror Reels3 on sides, 1c out and down, 2c up (1,2,3)
25--::
  1c (+2c who dance up to follow) lead down ; on [29] 1c & 2c turn inwards, 2c+1c lead up to exchanged places (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (14071, '2021-06-16 23:00:42.941641+00', '2021-06-17 08:55:09.833496+00', 20341, 1, 1645, 'ace', '1-::

  1c+3c Double Fig8, 1c start crossing down

9-::

  1c+2c Set&Rotate, 1c end RHJ with P across the set & facing 3cnr (2,1,3)

17-::

  *Figure of H setting:* 1c join LH with 3cnrs on sides & set, 1c turn inwards to face 4cnrs on 2nd PdB| 1c join LH with P, RH with 4cnrs on sides & set ; all chase &frac12; way cclw, 1c end RHJ with P & facing 1cnr[pos]

25-::

  Repeat Figure of H setting with 1cnr[pos] & 2cnr[pos] ; chase &frac12; way cclw (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2458, '2012-01-22 19:29:40.037224+00', '2020-12-19 14:15:37.503731+00', 8123, 1, NULL, 'ace', '1–::

  1M crosses and 1W dances in, 1c in promhold cast off round 2W (2c up) ; 1W+2c RHA _while{4}_ 1M+3c LHA, 1c ending in promhold in the middle

9–::

  1c cast off round 3M and up between 3c ; mirror Teapots on the sides (all M LHA, all W RHA), 1c briefly touch NH to finish BtoB in DTr position, facing own side

17–::

  2c+1c+3c ½DTr (all set holding hands, all set, 1c turning BtoB by the right to face opposite side) ; 2c+3c ½R&L _while{4}_ 1c dance Rsh round 1st corner and meeting in the middle make quick swivel R ¾ to the same DTr position as bar 16

25–::

  All set as in DTr | 1c continue DTr _while{2}_ 2c+3c set advancing swiveling ½R, all C are now BtoB facing opposite sides ; all dance out and chase clw to own side, (to 2,1,3)



{{explanation}}

Note: on bar 29 don''t go too far out to opposite sideline, especially 2M and 3W', 2);
INSERT INTO 'dancecrib' VALUES (11889, '2019-06-14 23:02:50.300249+00', '2022-09-28 00:58:15.30656+00', 19399, 1, 202, 'ace', '1--::
  1c+2c *The Helix* : both couples set passing LSh | cast R to original places ; turn P RH ½ | ½ RHA (2,1)
9--::
  2c+1c set | 1c cross RH ; set | 2W+1W change places RH and face out
17--::
  M-Chain into promhold, 1c on Wside, 2c on Mside
25--::
  The Tournée, 1c&2c stepping into midline on [25-26], 1M+2M LSh (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (11895, '2019-06-16 10:32:59.572624+00', '2019-06-21 00:10:10.86007+00', 19404, 1, 202, 'ace', '1--::
  1c ½ Fig8 down round 2c, ending between 2c BtoB facing opp sides ; ½ Reel4 across. On [8] 1c pass P RSh to 2pl (2x,1,3)
9--::
  1c ½ Fig8 down round 3c, ending between 3c BtoB facing opp sides ; ½ Reel4 across. On [8] 1c pass P RSh and face down between 3c (2x,1,3x)
17--::
  1c cross down and cast to 2plx ; ½ Mirror Reels3 on sides, 1c in and up (3x,1x,2x)
25--::
  3C S&Link twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11893, '2019-06-16 04:46:10.398097+00', '2019-06-16 04:49:26.464469+00', 19403, 1, 202, 'ace', '1--::

  1c lead down the middle and up, 2c+3c step in for (1,2,3)

9--::

  3C Allemande (to 3,2,1)

17--::

  3C Poussette. 1c face 1cnrs (2,1,3)

25--::

  Turn CPCP (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11892, '2019-06-15 22:43:12.62646+00', '2019-06-30 03:56:00.497167+00', 19402, 1, 202, 'ace', '1--::

  1c cast off behind own lines and back (1,2,3)

9--::

  1c+2c+3c set | cross RH. 1c face out and 2c retain RH ; 1c cast _as_ 2c dance up to 1plx | 1c turn LH to midline LSh to P facing opp sides

17--::

  2c+1W & 1M+3c RHA ; with 1c leading LSh Snake Pass to (3x,1,2x)

25--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag, pass RSh to 2pl and face out (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11898, '2019-06-16 19:35:28.70588+00', '2022-11-12 12:31:17.954283+00', 5730, 1, 1645, 'ace', '*The opening fugal theme is danced successively by all four couples starting on bars 1, 9, 17 & 19.*

*This crib gives a flavour of the dance: the full instructions and diagrams are recommended.*

1-8::

  1c set | turn BH ; cast off to 4pl (2c+3c+4c up on [7-8])

9-16::

  1c turn | lead up & cross above 4c ; cast off | cross up to 3pl  

  _while_ 2c set  | turn BH ; cast off to 4pl (3c+4c up on [15-16]) (3,4,1,2)

17-24::

  1c set | turn BH ; turn BH moving up | lead up & circle into 1pl  

  _while_ 2c turn BH to 4pl | set ; turn moving up | &frac12; turn to 3plx  

  _while_ 3c set | turn BH ; cast to 4pl  

  _while_ 4c stand | set ; turn BH moving up to 1pl | start casting off (following 3c)

25-28::

  3c &frac12; turn BH | lead up to 2plx centre  

  _while_ 4c continue cast to 4pl | meet & lead up to 3pl centre (2c down on [27-28])

29-30::

  3c & 4c &frac12; turn, 3W/4W end on W/M side between 2pl & 3pl, 3M/4M end on centre line in 2pl/3pl facing up/down

31-32::

  3M/4M dance up/down & face W/M side (3W+4W stand)

33-36::

  3W+4W set twice  

  _while_ 3M & 4M exchange places by casting RSh round 1W/2W (in 1W/4M pl) & dance in below/above P back to centre line

37-40::

  3c+4c circle4 L to (1,4x,3,2x)

41-44::

  All &frac12; circle8 L to (2,3x,4,1x)

45-48::

  2c & 4c turn P _while_ 3c & 1c turn P 1&frac12; to (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (2341, '2012-01-22 19:29:32.220172+00', '2020-03-21 08:18:41.08769+00', 2556, 1, NULL, 'ace', '1–::

  1c+2c set | ½ RHA ; 1c+3c set | 1.2 LHA (2x,3x,1)

9–::

  1c set | 1c cast up as 3c cross down ; 1c set | 1c cast up as 2c cross down (1,2,3)

17–::

  Mirror Reels3 on the sides, 2c starts out and down (1,2,3)

25–::

  Chain progression: 1c+2c Turn RH ¾ | 1M+2W turn LH 1½ _while_{4} 1W+2M chase clw ½ round them | 2c+1c turn RH ¾ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2322, '2012-01-22 19:29:31.473713+00', '2020-09-24 13:04:52.279529+00', 13910, 1, NULL, 'ace', '1–::

  1c dance between 2c, cast off behind 3c, dance up and cast up behind 2c (1,2,3)

9–::

  All Pertonella turn | set ; repeat (1x,2x,3x)

17–::

  1W, 2W+3W following, dance across the top and down own side _while{4}_ 3M, 2M+1M following, dance across the bottom and up own side (3,2,1) ; 3c+2c turn RH into

25–::

  3c+2c allemande (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2452, '2012-01-22 19:29:39.620144+00', '2020-09-26 07:11:20.991978+00', 14086, 1, NULL, 'ace', '1–::

  1c long cast (2c up) ; turn RH to face 1cnr

9–::

  1c+1cnrs ½ diag. Reel4 _while{4}_ 2cnrs chase clw half round, 1c pass Rsh to face 2cnr position ;

  1c+2cnrs ½ diag. Reel4 _while{4}_ 1cnrs chase clw half round, 1c pass Rsh to face 3cnr position

17–::

  1c+1cnrs ½ diag. Reel4 _while{4}_ 2cnrs chase clw half round, 1c pass Rsh to face 4cnr position ;

  1c+2cnrs ½ diag. Reel4 _while{4}_ 1cnrs chase clw half round (2,1,3)

25–::

  1c turn LH 1¼ ; Teapots R (2c+1W & 1M+3c RHA)', 2);
INSERT INTO 'dancecrib' VALUES (11646, '2019-03-05 22:14:48.862104+00', '2019-03-07 01:23:51.18871+00', 19224, 1, NULL, 'ace', '1--::

  1c+2c Tourbillon, and 1c face out (2,1,3)

9--::

  1c dance Rsh round 3cnr, meet in the middle and turn BH 1½, dance Rsh round 4cnr to 2pl (2,1,3)

17--::

  Reels3 on the sides, 1c Lsh to 3cnr

25--::

  Reels3 across, 1c Rsh to 2cnr (2,1,3)

33--::

  1c+3c Bourrel (2,3,1)



', 4);
INSERT INTO 'dancecrib' VALUES (12883, '2020-06-08 11:31:01.815786+00', '2021-04-19 19:28:44.300727+00', 20002, 1, 202, 'ace', '*On 2nd chord, 1c & 3c cross to opposite side (1x,2,3x,4)*



1--::

  1c set | cross RH _while{4}_ 2c+3c+4c Circle6 L ½ (to 1,4x,3,2x) ; Circle8 L ½ (2,3x,4,1x)

9--::

  2c & 4c (3c & 1c) facing down (up), all S&Link across into Reels4 position on sides ; all turn opposite person on sides RH (2x,3,4x,1) 

17--::

  Reels4 (2x,3,4x,1)

25--::

  2c & 3c & 4c making arches, 1c dance up to top, 1M behind Mside, 1W under arches ; 1c dance down, 1M under arches, 1W behind Wside (2x,3,4x,1)', 2);
INSERT INTO 'dancecrib' VALUES (9599, '2017-02-20 01:28:06.182083+00', '2017-02-20 12:07:43.205124+00', 8927, 1, NULL, 'ace', '*Start (1,2x,3x,4)*



1--::

  1c+4c cross RH | cast inwards (2c+3c step to end) ; ½ Fig8 round end cpl (2x,1,4,3x)

9--::

  Reels4 on the sides, on [16] 4c+1c curve into the middle to finish close to P and BtoB, 4c facing 2c and 1c facing 3c 

17--::

  4c+1c Set double H&G, at end 1M+4W set as 1W & 4M petronella (2x,1x,4x,3x)

25--::

  Middles (start inwards) turn ends (start outwards) EH ; 2c+3c cross RH and wait _while{4}_ 1c+4c ½ RHA (retain RH) | cross RH (2,4x,1x,3) 

 

', 3);
INSERT INTO 'dancecrib' VALUES (12113, '2019-08-31 11:16:49.213562+00', '2020-01-22 09:42:39.712689+00', 14584, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*



1--::

  2c & 3c Fig8 round nearest ends giving appropriate hands when crossing (1,2,3x,4x)

9--::

  All turn P BH ½ , finish NHJ, middles facing ends | 1c+2c & 3c+4c Circle4 L | repeat [9-10], to NHJ, middles facing ends (1,2,3x,4x)

17--::

  1c & 4c S&Link with P _while{4}_ 2c+3c »S&Link Back to Back« [: LH person to RH place, RH person to place behind] ; repeat [17-20], finishing (1,3,2x,4x), 1c+3c facing up, 2c+4c facing down, all in promhold

25--::

  1c+3c Allemande _while{8}_ 2c+4c Inverted Allemande (3,1,4x,2x)', 4);
INSERT INTO 'dancecrib' VALUES (12993, '2020-07-26 19:46:21.140024+00', '2020-07-26 19:46:30.68067+00', 20055, 1, 1645, 'ace', '1-::

  1c cross RH | cast off (2c up) ; turn 1&frac34; LH

9-::

  2c+1W & 1M+3c RHA, 1c pass RSh ; LHA ending on sides, 2c & 3c face out

17-::

  Reels3 on sides, 1c start RSh to 4cnr

25-::

  Circle6 & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2215, '2012-01-22 19:29:26.21153+00', '2020-12-19 14:59:18.121313+00', 8630, 1, NULL, 'ace', '{{explanation}}

or August in Erlangen



1–::

  1c+3c Petronella Turn (2c+4c up) | all set ; all Petronella Turn and set

9–::

  2c+4c (on midline) Reel4.

17–::

  1c+2c & 3c+4c RHA ; 4M leads 3M, 4W, 3W in chase up M side, _while{4}_ 2W leads 1W, 2M and 1M in chase down W side

25–::

  1M+2M+3M+4M & 1W+2W+3W+4W circle4 left ; middle pairs (in 2pl+3pl) ½R&L (order on W side 1M, 4W, 3M, 2W)

33–::

  1M+4W & 3M+2W lead (RHJ) across between opposite dancers, cross and cast back to exchanged places on W side (to 4,1x,2,3x) ; 1c+3c cross up RH and cast off (4,1,2,3)', 3);
INSERT INTO 'dancecrib' VALUES (12766, '2020-04-15 19:35:14.313217+00', '2022-04-25 20:09:45.774238+00', 19956, 1, 1645, 'ace', '1-::

  1c+2c Tourbillon (2,1)

9-::

  2c+1c RHA ; LHA (2,1)

17-::

  2c+1c Bourrel, on [23-24] turn RH into allemande hold facing up (1,2)

25-::

  1c+2c Allemande (2,1)

', 5);
INSERT INTO 'dancecrib' VALUES (2998, '2012-01-22 19:30:06.262099+00', '2020-12-20 11:23:25.112825+00', 9074, 1, NULL, 'ace', '1–::

  1c cross down RH _while_{2} 2c cast up and 3c set | Mirror Reels3{6} on sidelines, 1c starting out and down (to 2,1x,3)

9–::

  3c cross up LH _while_{2} 1c cast off & 2c set | Mirror Reels3{6} on sidelines, 3c starting out and up (to 2,3x,1x)

17–::

  3c+1c ½ R&L ; 2c+1c ½ R&L (to 1x,2x,3)

25–::

  1c+2c Reversed Espagnole :[1M+2M lead RHJ to M side crossing 2M in front and cast back to exchanged places _while{4}_ 1W+2W cross to W side, cast in and lead RHJ to M side crossing 2W in front, to exchanged places ; both C turn P EH 1½] (to 2,1,3)



{{explanation}}

For [16] Finley''s original version says »… third couple … in 2nd place on the opposite side, "having danced the long way into place", a phrase omitted in the RSCDS version.', 3);
INSERT INTO 'dancecrib' VALUES (2061, '2012-01-22 19:29:17.647846+00', '2020-12-20 23:41:59.477632+00', 1562, 1, NULL, 'ace', '{{explanation}}

Trio face trio RR.



1–::

  Circle6 and back

9–::

  Each centre person sets to RH P and turns him/her BH ; repeat with LH P

17–::

  Reel3 across, Lsh to RH P

25–::

  In lines of 3 across A&R ; advance Rsh through the opposite line of 3 to meet the next line of 3.



{{explanation}}

Many variations in handing, polite turns and shoulder exist', 3);
INSERT INTO 'dancecrib' VALUES (9608, '2017-02-20 15:38:07.808222+00', '2021-01-04 11:54:10.837681+00', 17311, 1, 202, 'ace', '1--::

 1c Petronella turn | set ; repeat (1x,2)

9--::

 1c+2c Interlocking Knot (2,1x)

17--::

 2c+1c Circle4 R then L

25--::

 1c set | Turn Halfway and Cast | 2c+1c set (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (13683, '2021-02-21 23:22:46.237076+00', '2021-02-21 23:29:23.813415+00', 8911, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 down round 3c (2,1x,3)

9--::

  Reels3 across, 1c RSh to 4cnrs (2,1x,3)

17--::

  Reels3 on sides, 1c RSh to 2cnrs (2,1x,3)

25--::

  1c ½Fig R LSh to 3cnrs (to 2,1,3) ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12981, '2020-07-24 12:57:02.772135+00', '2020-07-24 18:23:41.158945+00', 10922, 1, 202, 'ace', '1--::
  1c turn P LH | 1M (1W following) dances LSh round 2M, across the set, RSh round 3W to between 3c and face up in tandem (2c up on [5-6])
9--::
  Reel3 in tandem (no lead change) on Mside, 1M leading RSh to 2M
17--::
  Reel3 in tandem (no lead change) on Wside, 1M leading LSh to 2W. 1c end in centre midline facing up, 1W behind 1M
25--::
  1M pulling RSh back (PdB) faces 1W | 1M raising both arms in "Scottish Style" snaps fingers _while{2}_ 1W Petronella turn to 2pl ; 1M Petronella turn to 2pl | 1c set (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (13682, '2021-02-21 20:00:11.320405+00', '2021-02-21 20:02:47.268187+00', 20050, 1, 202, 'ace', '1--::

  1c set | cross RH to 2pl (2c up) ; 1c turn RH and face out and clw _while{4}_ 2c & 3c set | turn P RH ¾ into midline

9--::

  »Weasel Reel« [: All continuously dance ½ Reel4 on midline, dancers who reach the end cast clw on own side and rejoin the reel at the other end. All finish as on [9]. Dancers entering and leaving the reel pass RSh.] 1c finish slightly further clw

17--::

  1W+2c & 1M+3c RHA. On [19] 1c release H and meet in centre facing opposite sides _while_ 2c & 3c continue turning RH to own sides ; 1c turn LH ½, dance LSh round 3cnrs to 2pl (2,1,3)

25--::

  1c lead down into Fig8 round 3c ; lead up into Fig8 up round 2c (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9610, '2017-02-21 01:43:02.80208+00', '2017-02-21 01:46:10.023054+00', 17304, 2, NULL, 'ace', '1- 8::

   1s turn RH 1½ times, then 1s+2s dance Set+Link 

9-16::

   2s+1s dance a Men’s chain 

17-24::

   2s+1s+3s dance reels of 3 on the sides, 1s and 3s passing LSh to begin and 1s finish facing 1st corners, 1M pulling back right shoulder at the end 

25-32::

   2s+1s+3s dance a Hello-goodbye setting, dancing a Petronella turn to 2nd place at the end. All clap on bar 31.', 4);
INSERT INTO 'dancecrib' VALUES (9609, '2017-02-20 22:23:27.508006+00', '2018-03-31 16:53:28.065163+00', 17615, 1, 202, 'ace', '1--::

 1c set | cross RH ; cast off (2c up) | turn LH to finish facing 1cnr

9--::

 SetH&G for {6} | cross RH to finish 1M/1W between 3c/2c facing out

17--::

 1c cast R round 4cnr ; turn RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1899, '2012-01-22 19:29:08.766726+00', '2021-03-16 16:38:13.354618+00', 8568, 1, NULL, 'ace', '1–::

  1W+2M set twice, A&R _while_{8} 1M+2W turn RH and chase clw to exchanged places

9–::

  2W+1M set twice, A&R _while_{8} 1W+2M turn RH and chase clw to exchanged places (2x,1x)

17–::

  Modified Chain Progression (2c+1c turn ¾ RH | the »ends« chase ½ round clw _while_ centres turn LH ½ ; 1c+2c turn 1¼ RH) (1,2)

25–::

  Poussette (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9607, '2017-02-20 13:06:39.883114+00', '2022-03-29 16:16:57.948264+00', 17535, 1, 202, 'ace', '1--::
  1c+3c R&L
9--::
  All M RHA ; LHA
17--::
  All W RHA ; LHA back to pl facing out
25-40::
  Schiehallion reels
41--::
  All S&Link, finish facing P ; turn P RH ¾ to promhold | chase 1 pl cclw (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13686, '2021-02-22 09:26:24.72635+00', '2021-02-22 13:40:51.019144+00', 20226, 1, 202, 'ace', '_Strathspey_

1--::

  2C S&Link ; 1W+2M turn RH (2,1)

9--::

 2C S&Link ; 1M+2W turn RH (1,2)

17--::

  1c+2c A&R {1+1} twice ; 1c long cast to 2pl (2c up)  (2,1)

25--::

  Circle4 and back

33-64::

  Repeat [1-32]  



_Reel_

1-64::

  Repeat [1-64] in Reel time except [17-20] & [49-52]: 1c+2c A&R *instead of* 1c+2c A&R {1+1} twice.



*Deviser''s note:  

If dancing in a longer set, dance the strathspey section once, then the reel section, so the medley becomes 32S + 32R.*', 2);
INSERT INTO 'dancecrib' VALUES (13965, '2021-04-19 11:57:16.304451+00', '2021-07-13 22:33:54.975765+00', 20333, 1, 202, 'ace', '1--::

  1c cast off to 3pl (2c+3c up) | all set ; 1c cast up to 1pl (2c+3c down) | all set (1,2,3)

9--::

  1c+2c Poussette. On [15-16] 1c & 2c turn RH ½ and retire to opposite sides (2x,1x,3)

17--::

  1c+3c R&L (2x,1x,3)

25--::

  All turn P BH (PdB) ; 2c+1c ½ RHA (1,2,3)

33--::

  1c+2c Allemande (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2235, '2012-01-22 19:29:27.158029+00', '2020-08-30 10:02:53.781699+00', 2192, 1, NULL, 'ace', '1–::

  1c dance clw 1¼ round P, spiraling in, finish facing down 1M behind 1W ; 1W, with 1M following, cast up round 2M to (1,2)

9–::

  1c lead down the middle and up, facing out

17–::

  1c+2c Double Fig8, finish in the middle for

25–::

  1c+2c Allemande (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (2314, '2012-01-22 19:29:31.166372+00', '2020-08-31 14:55:50.879248+00', 3898, 1, NULL, 'ace', '1–::

  1c+3c set | 1c cross down RH (2c up) _while{2}_ 3c cross RH ; 1c+3c set | ½ LHA (2,3,1)

9–::

  3c+1c Poussette (2,1,3)

17–::

  DTr (start facing own side) leading into

25–::

  ½Reels3 across, 1c Rsh to 4cnr , quick turn ¾ LH into ; ½Reels3 across, Lsh to 3cnr pos', 2);
INSERT INTO 'dancecrib' VALUES (3625, '2012-07-21 11:46:08.697437+00', '2021-04-19 21:02:57.780965+00', 5848, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; 1c turn LH 1¾  _while_{4}   2c+3c ½ R&L (3x,{1M,1W},2x)

9–::

  3+1M & 1W+2c ½ RHA | 1c chase ¼ clw  to outside sidelines ; 1c+cnrs ½ RHA on sides | 1c turn LH to face 1cnr (2,1x,3)

17–::

  ½ Reels3 across, Lsh to 1cnr ; ½ Reels3 on opposite side, Rsh to 2cnr

25–::

  ½ Reels3 across, Lsh to 3cnr ; ½ Reels3 on own side, Rsh to 4cnr, finish facing 1cnr

33–::

  CPCP (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11647, '2019-03-07 09:05:49.338215+00', '2019-03-07 09:05:49.338215+00', 19225, 1, NULL, 'ace', '1--::

  1c cast behind own lines and back

9--::

  1c cross | cast off (2c up) ; ½ Fig8 R(2,1,3)

17--::

  1c turn 1c RH and pass Rsh ; turn 2cnr Rh and cross Rsh (cnrs dance 4 bars) (2,1,3)

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (15184, '2022-10-24 22:05:10.059143+00', '2022-10-25 12:17:15.42574+00', 21117, 1, 202, 'ace', '1--::
  1c turn RH _while{2}_ 2c set | 1c lead down {4} and back {2} to 2pl centre facing up _while{6}_ 2c cast up | turn P RH to 1pl centre. On [8] 3c step in (2,1,3)
9--::
  3C Allemande. 1c face 1cnrs
17--::
  ½ Reel4 on 1diag ; ½ Reel4 on 2 diag (2x,1x,3x)
25--::
  1c turn RH ½ and face down | lead down. On [28] 1M passes 1W in front of him ; 1c (1W leading) dance RSh round 3M[pos] to 2pl _while{4}_ 2c & 3c set | cross RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2669, '2012-01-22 19:29:52.39193+00', '2017-02-21 20:37:01.549012+00', 3786, 1, NULL, 'ace', '1–::

  1c & 4c cross and cast (2c+3c step to end) ; 1c+4c LHA to face ''corner''

9–::

  All set and change places RH ; all set and change places LH

17–::

  1c+4c RHA, LHA _while{8}_ ''corners'' chase cclw once round, finish (2,1x,4x,3)

25–::

  All set | 1c & 4c turn RH ½ ; 1W+4M Turn LH ½ _while{2}_ 1M & 4W dance clw. ½ way around them, 4c & 1c cross over RH (to 2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9612, '2017-02-21 22:28:47.467296+00', '2017-02-21 22:28:47.467296+00', 17616, 1, NULL, 'ace', '1--::

  1c set to 2c | turn opposite BH ; All set to P | turn P BH and face in diagonally

9--::

  Set and rotate (no hands) (2,1)

17--::

  Circle4 and back

25--::

  Poussette (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9613, '2017-02-21 23:23:35.069331+00', '2017-02-21 23:23:35.069331+00', 17617, 1, NULL, 'ace', '1--::

  1W+2W & 2M+3M & 3W+4W change places RH | All set across ; top 4 & bottom 4 RHA

9--::

  Top 4 & Bottom 4 R&L

17--::

  Top 4 & Bottom 4 Circle4 and back, finish in middle and face up

25--::

  Top 4 & bottom 4 each 2C Allemande (All W end in own place, M in order: 3,1,4,2)

', 3);
INSERT INTO 'dancecrib' VALUES (9611, '2017-02-21 18:43:31.522111+00', '2017-02-22 00:34:36.812982+00', 11782, 2, 323, 'ace', '1- 8::

   1s cross RH, cast (2s step up). 1M dances up, casts round 2M to 2nd place own side as 1L dances down, casts up round 3L to 2nd place own side 

9-16::

   RSh reels of 3 on sides (1M RSh to 3M, 1L RSh to 2L), 1s pass LSh to face 1st corners 

17-24::

   1s+1st corners set, 1s dance round each other by Right to face 2nd corners. 1s turn 2nd corners LH to finish on own sides End 2 1 3 

25-32::

   1L+2s & 1M+3s dance RH across, 1s pass each other to dance LH across with other couple (1L+3s & 1M+2s)  

', 4);
INSERT INTO 'dancecrib' VALUES (9614, '2017-02-22 00:25:28.861015+00', '2017-02-22 00:31:41.489589+00', 11782, 1, NULL, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 R (2,1,3)

9--::

  Reels3 on the sides, Rsh to 4cnr, finish facing 1cnr

17--::

  1c set to 1cnr | dance Rsh round P to face 2cnr ; 1c+2cnr turn LH to finish (2,1,3)

25--::

  2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8416, '2014-10-05 01:13:05.268221+00', '2017-02-22 12:44:26.206873+00', 8453, 1, NULL, 'ace', '1--::

  2c+1c following lead down ; 1c split and 2c+1c following lead up (2,1,3)

9--::

  2c+1c+3c Allemande (3,1,2)

17--::

  All set | cross RH ; all chase ½ clw (2,1,3)

25--::

  Reels3 on the sidelines, 1c starting out, Rsh to 3cnr (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3344, '2012-01-22 19:30:21.402412+00', '2020-12-20 23:49:18.76816+00', 9189, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; cross LH and cast L to finish between 1cnr and 4cnr

9–::

  All set in lines across | All set advancing pulling right shoulder back to finish back to back ; All set again in a double line across | All set, 2c+3c advancing to their corners pulling Rsh back to face in _while{2}_ 1c couple swivel R  about each other to finish in the centre,  1M facing up and 1W facing down.

17–::

  Reels3 on opposite side (Rsh to 2cnr), finish facing 2cnr

25–::

  1c turn 2cnr RH | P LH ; 1cnr RH | P LH (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9615, '2017-02-23 17:21:58.241778+00', '2017-10-04 22:05:56.302586+00', 17618, 1, 202, 'ace', '1--::

  1M+2W set | 1M+2c Reel3{6} across, Lsh to 2W, 1c finishing in the middle facing down NHJ (1W dance in on bar 8)

9--::

  1c dance down one place while 2c cast up NHJ behind 1c | 2c+1c set facing down ; 1c cast up and turn P RH moving down to finish (pulling Rsh back) facing 1cnrs _while{4}_ 2c dance down one place and cast up to 1pl (2,1,3)

17--::

  Turn CPCP (2,1,3)

25--::

  1W+3M set | 1W+3c Reel3{6} across, Rsh to 3M (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13684, '2021-02-21 23:53:51.595456+00', '2021-02-21 23:57:19.216367+00', 8913, 1, 202, 'ace', '1--::

  1c set | cast off ; ½ Fig8 up round 2c (2c up on [7-8] (2,1x)

9--::

  1c turn P RH to between 2c ; 1W+2M turn LH _while{4}_ 1M+2W turn LH 1½ into line4 across, 1c facing up, 2c facing down

17--::

  1c+2c The Targe (1,2x)

25--::

  2c cross RH | cast up (1c down) ; all turn P RH (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11095, '2018-09-11 12:47:25.059368+00', '2021-02-22 11:29:17.603993+00', 9570, 2, 19009, 'ace', '1-2::

  1''s cross down, ending back to back between the 2''s and 3''s  

  2''s step up one place and face down  

  3''s face up  

  4''s cast up one place to face the 1''s  

  Two diamond formations have been made

3-4::

  all set

5-8::

  Slip step once around

9-16::

  2''s and 3''s stand; 1''s and 4''s dance a half reel of four, turn RH once around with the one you meet (4M with 1L, 1M with 4L), ending in promenade position with 4M and 1L facing 3M, 1M and 4L facing 2L

17-20::

  Retain promenade hold to dance a half reel across the dance, giving RSh to begin

21-24::

  Meet in the center to dance RH across; finish by taking own partner in promenade hold, 4M with 4L facing 2M, 1M with 1L facing 3L

25-28::

  Retain promenade hold to dance a half reel across the dance, giving RSh to begin

29-32::

  Meet in the center to dance RH across, with 4M stopping in second position, 4L passing him to stop in second position, and 1M and 1L continuing to end in third position  

Finish 2,4,1,3  

Repeat from new positions, three more cycles', 2);
INSERT INTO 'dancecrib' VALUES (14072, '2021-06-16 23:10:59.466258+00', '2021-06-16 23:11:43.473478+00', 20339, 1, 1645, 'ace', '1-::

  All chase clw round square

9-::

  RHA ; LHA

17-::

  *Bent figure of 8:* all loop LSh round next cnr pos cclw (to R) ; then loop RSh round next cnr pos clw (to L)

25-::

  All set adv to next cnr clw turning to R on 2nd PdB | repeat 3 times round square to places', 2);
INSERT INTO 'dancecrib' VALUES (11648, '2019-03-07 10:58:42.390985+00', '2019-03-07 10:58:42.390985+00', 19226, 1, NULL, 'ace', '1--::

  All set twice ; turn P RH

9--::

  All set twice ; turn P LH

17--::

  1c cross RH | cast off (2c up) ; ½ Fig8 up (2,1,3)

25--::

  2C+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (9616, '2017-02-24 12:38:26.054552+00', '2021-11-25 07:41:20.32906+00', 17316, 1, 202, 'ace', '1--::

  1c cast off 2 ; lead up to 1pl finishing in the middle, 2c step in on [8]

9--::

  1c+2c allemande (2,1,3)

17-20::

  2c+1c+3c set | All cross RH

21-28::

  Circle6 and back

29-32::

  2c+1c+3c cross LH |  All set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14470, '2021-11-29 00:31:11.540629+00', '2021-11-29 00:32:38.509331+00', 20564, 1, 202, 'ace', '1--::

  1c+2c R&L (1,2,3)

9--::

  1c lead down {3}, lead up {3} | cast off (2c up) (2,1,3)

17--::

  1c+1cnrs set, 1c passing LSh | 1c+1cnrs turn BH into facing lines3 across ; 1c+2cnrs set, 1c passing LSh | 1c+2cnrs turn BH (2,1x,3)

25--::

  Mirror Reels3 on sides, 1c crossing to 3pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11651, '2019-03-07 16:56:57.4639+00', '2019-03-08 22:22:23.921784+00', 16244, 1, NULL, 'ace', '1--::

  1c+2c Poussette

9--::

  1c lead down {3} and up {3} | cross and cast off to face 1cnr (2c up) 

17--::

  Reels3 on sides, 1c Lsh to 1cnr, and 1c face 1cnr

25--::

  Set "H&G", at end petronella to (2,1,3)

33--::

  "Untie the Knot": 1M+3M cross to W side and turn P RH into allemande hold facing down | 1c+3c (leading) dance to the R and up the middle (to 2pos / 3pos) {3} and pass R arms over W''s head to face P across, hands still joined {1} |   drop hands, face down and curve to the sidelines (2,3,1)





', 5);
INSERT INTO 'dancecrib' VALUES (3354, '2012-01-22 19:30:21.799997+00', '2020-08-30 10:43:52.27696+00', 8577, 1, NULL, 'ace', '1–::

  1M Reel3 with 1W+2W  (Rsh to 2W)

9–::

  1M with 1W tenaciously following Reel3 with 2c (Rsh to 2M)

17–::

  1c dance down middle, 1M leading ; 1c lead back up RHJ, 2c step in on [24] for

25–::

  1c+2c allemande', 3);
INSERT INTO 'dancecrib' VALUES (3024, '2012-01-22 19:30:07.325675+00', '2015-04-30 08:21:05.320827+00', 11189, 1, NULL, 'ace', '1-16::

  All W dance Rsh round cnr ; RHA in middle ; Lsh round P ; LHA in middle, to places

17-32::

  All M dance Rsh round P ; RHA in middle ; Lsh round cnr ; LHA in middle, to places

33-48::

  1c+3c turn RH 1¼ ; 1M & 3M (W following) dance between couple on the R and cast clw to places ; 1c+3c R&L

49-64::

  2c+4c repeat

65–::

  All W dance into middle, swivel R and dance through own place clw half way round set

73–::

  All M dance into middle, swivel L and dance through own place cclw half way round set

81–::

  All turn P RH 1¼ ; promenade cclw half way round set, to own places', 3);
INSERT INTO 'dancecrib' VALUES (13572, '2021-01-22 10:57:49.370213+00', '2021-08-10 17:59:57.045175+00', 20207, 1, 202, 'ace', '1--::

  1c dance BtoB ; set | cast off (2c up) (2,1,3)

9--::

  1c cross RSh | dance RSh round 1cnrs into lines3 across _while{4}_ 2c & 3c cross RSh pivoting R to face diagonally | 2c & 3c set ; 1c pass RSh | dance RSh round 2cnrs[pos] to 2plx, cross LSh and face 3cnrs[pos] _while{4}_ 2c & 3c change places RSh on sides pivoting R to face diagonally | 2c & 3c set 

17--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag and face 1cnrs

25--::

  SetH&G. On [31-32] 1c dance (skip ch.) to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8758, '2015-04-29 22:38:37.722869+00', '2015-04-29 22:44:33.149864+00', 1989, 1, NULL, 'ace', '1--::

  1c lead down {3}, up {3} and cast off (2c up) (2,1,3,4)

9--::

  1c+3c turn P RH 1½ and stay in middle facing end cpl ; set to end cpl | turn end cpl EH, passing out the ends, to (2,1x,3x,4)

17--::

  1c+3c ½ R&L ; 3c+1c  turn P RH, 3c finish on side as 4c step in for 

25--::

  1c+4c poussette (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (3268, '2012-01-22 19:30:18.283614+00', '2021-03-16 16:40:32.979806+00', 8566, 1, NULL, 'ace', '1–::

  2c Petronella Turn to between end couples | all set in lines across (2M with 3c, 2W with 1c) ; 2c Petronella Turn to 2plx | all set

9–::

  Reels3 on the sides, 2c Rsh to 2cnr, finish in 2plx

17–::

  Reels3 across, 2c giving Lsh to 3cnr, and finish in 2plx (1.2x,3)

25–::

  All half circle6 Left ; 3c+2c ½ RHA | 2c+1c cross RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2374, '2012-01-22 19:29:34.138178+00', '2020-12-06 18:33:45.074933+00', 2660, 1, NULL, 'ace', '1–::

  1c turn RH 1½ and face down in allemande hold ; dance bars 5-6 of an allemande and face P close (2c up) | turn RH 1¼ to face opposite side

9–::

  Reels3{6} with corners. Rsh to 1cnr | cnrs set diagonally _while{2}_ 1c turn LH and face own side

17–::

  Reels3{6} with 3cnr+4cnr, Lsh to 4cnr | cnrs set diagonally _while{2}_ 1c turn BH ½ and swivel R to finish M facing down, W up

25–::

  Reels3{6} across, Lsh to 1cnr | 2c+1c+3c set', 3);
INSERT INTO 'dancecrib' VALUES (3147, '2012-01-22 19:30:13.356111+00', '2022-11-12 12:37:29.031672+00', 5721, 1, NULL, 'ace', '1–::

  1c turn RH (1M to 2M place, 2M steps up) ; 1M+2W repeat (1M ends in 3M place)

9–::

  1W and 1M cross RH with persons opposite | change places LH in sidelines with 3M resp 2W ; 1c Petronella Turn to lines of 3 across (all M at top face P below) | all set

17–::

  All change places RH with partners and chase clw ¼ to sidelines (3,1,2) | all turn P RH into

25–::

  3 couple Allemande', 3);
INSERT INTO 'dancecrib' VALUES (1684, '2012-01-22 19:28:56.493977+00', '2018-03-07 00:09:14.757808+00', 245, 1, NULL, 'ace', '1–::

  1c+2c RHA ; 1c cast off (2c dance up) | 1c set

9–::

  1c+3c LHA ; 1c cast off (3c dance up) | 1c set (2,3,1)

17–::

  1c dance up to top, cast off ; dance between 3c and cast up to face 1cnrs (3c down)

25–::

  SetH&G {6} | 1c Petronella to 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2316, '2012-01-22 19:29:31.245016+00', '2020-12-19 15:13:28.005782+00', 8672, 1, NULL, 'ace', '1–::

  1c+3c cross RH | cast off (2c+4c up) ; 1c+3c cross up RH one place and cast off _while{4}_ 2c+4c cast off and dance up, finishing (2,1,4,3), with 2c facing out, 3c facing in, and 1c facing 4c in the middle NHJ

9–::

  »The Bridge«:  Mirror Reels4 on the sides, each couple dancing down from 2pl NHJ under the arch made by the couple dancing up from 3pl, all finish as at the start (2c long loop to face in)

17–::

  1c+4c Rondel (2,4,1,3)

25–::

  2c+4c & 1c+3c set | Petronella in tandem ; all set up/dn | cast right to (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8287, '2014-06-22 21:02:00.827045+00', '2021-02-22 11:40:59.172914+00', 9550, 2, 1, 'ace', '1–::

  1c cross down between 2c&3c (no hands) | cast off ; dance up between 2c&3c | cast up

  (fin in 1plx in middle w/BH joined)

9–12::

  1c set to ptr (open to 2c) | set to 2c

13–16::

  1M+2W turn LH _while_ 1W+2M turn RH

17–::

  Mirror reels3 (1c cross down to own sides to begin)

  (1c fin in middle w/BH joined, 2c dance up on 23–24 to fin in 2pl w/BH joined)

25–::

  1c+2c poussette', 3);
INSERT INTO 'dancecrib' VALUES (1625, '2012-01-22 19:28:51.655416+00', '2019-06-18 23:55:15.01769+00', 54, 1, NULL, 'ace', '1–::

  All four men cross above P, cast below 4W and back up own side to 4,3,2,1

9–::

  All circle8 and back, end in a square set, with the dancers spaced equally around the circle.

17–::

  1M+LH person (=2M) & 1W+LH person (=2W) dance as pairs diagonally across the circle (1M pair forms arch, 1W pair passes under) through opposite places, divide and 1M & 1W cast R to pick up next person on left in the circle ; 1W+3M & 1M+3W repeat across

25–::

  1W+4W & 1M+4M repeat diagonally ; 1W+2M & 1M+2W repeat up and down

33–::

  Top and bottom couples cross RH to start 4 changes of a snow ball chain, to finish Men 2,3,4,1 and Women 1,4,3,2

41–::

  All women cross below opposite man, cast up round top and down own side to longwise set 2,3,4,1', 3);
INSERT INTO 'dancecrib' VALUES (10033, '2017-08-01 13:40:03.209794+00', '2021-02-22 16:32:25.404331+00', 9549, 2, 160, 'ace', '1-8::

  Cross, cast  ; dance down & cast up round 3C. 2 1x 3

9-16::

 Teapots:-  RHA - 1M up and 1W down ; LHA other end.

17-24::

  Reel3 on sides - Rsh to 2corner to begin.

25-32::

  Turn LH [2 bars - zesty!] end in center man above & facing, set ; petronella turn to own sides, all set.', 0);
INSERT INTO 'dancecrib' VALUES (7866, '2013-08-21 08:31:50.094582+00', '2023-02-04 01:23:08.102669+00', 14322, 3, NULL, 'ace', '1-8::
    All set & turn RH, all turn corners LH into lines of 4 across for
    reels (1s+3s BtoB in middle)
9-16::
    All dance RSh reels of 4 across (1s with 4M+2L, 3s with 2M+4L), 1s &
    3s end with 1/2 turn LH into prom hold facing in and to right
17-24::
    1s & 3s in prom hold dance reels of 3 on sides (1s with 4s, 3s with
    2s) & all end in original places (1s+4L also 3s+2L pass LSh to
    start)
25-32::
    All circle 8H round & back
33-40::
    All set & Men set again as all Ladies set advancing, Ladies dance RH
    across
41-48::
    Ladies dance Fig of 8 round partner & corner (RSh round partner)
49-56::
    All set & Ladies set again as all Men set advancing, Men dance LH
    across
57-64::
    Men dance Fig of 8 round partner & corner (LSh round partner, RSh
    round corner), finish in places
65-72::
    All set & turn partner RH, all turn corners LH into lines of 4
    up/down for reels (2s+4s BtoB with partners in middle)
73-80::
    All dance RSh reels of 4 (2s with 1M+3L, 3s with 3M+1L), 2s & 4s end
    with 1/2 turn LH into prom hold facing inwards and to right
81-88::
    2s & 4s in prom hold dance reels of 3 across (2s with 1s, 4s with
    3s) & end in original places (2s+1L also 4s+3L pass LSh to start)
89-96::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12404, '2019-12-05 01:30:47.928577+00', '2023-02-28 15:27:31.211275+00', 19604, 3, NULL, 'ace', '1-8::

    1s+2s dance 1/2 R&L; 2s+1s set, 2s cross LH _while_ 1s turn LH to

    face 1st corners

9-16::

    1s+1st corners set & turn RH once round; 1s face each other

    diagonally & 1s followed by 1st corners pass LSh, curve round corner

    position, dance in & briefly give LH to face 2nd corners while1st

    corners end in diagonally opposite corner position

17-24::

    Repeat 9-16 with 2nd corners.  1s end 1L between 3s (at top) facing

    down, 1M between 2s (3rd place) facing up

25-32::

    All set twice with 1s petronella turning (bars 27-28) to 2nd place

    opp sides; 3s+1s+2s circle 6H 1/2 round. 2 1 3



{{explanation}}

Note:  Dance has been revised since it was first published in the Reel issue 309', 0);
INSERT INTO 'dancecrib' VALUES (11650, '2019-03-07 13:33:34.618369+00', '2019-03-08 14:50:12.341965+00', 14478, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c S&Link ; 1c+4c RHA, and middles face ends (2,1,4,3)

9--::

  Set to opposite | Turn opposite RH and 1c face 4c ; 1c turn 4c LH 1½ and middles face ends (2,4,1,3)

17--::

  Reels4 on the sides, but middles (4c+1c) join LH when meeting and form line across NHJ 

25--::

  1c+4c BiL | middles turn ends LH 1¼ | All wait{2} (2,4,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (10794, '2018-05-27 00:34:17.171719+00', '2020-09-24 13:21:46.654088+00', 13942, 2, 106, 'ace', '1-8::

   1st and 2nd couples dance a double figure of eight; 1st couple cross down, 2nd couple cast up, to begin. Finish in the middle, nearer hands joined with partner, 1st couple facing down, 2nd couple facing up.

9-12 ::

   Set and link with partner, finishing in the middle of the set on partner’s side, facing up and down.

13-16 ::

   1st and 2nd couples dance right hands across, finishing in the middle of the set on partner’s side, 1st couple facing down, 2nd couple facing up.

17-24 ::

   1st and 2nd couples dance rights and lefts up and down the set.

25-28 ::

   Set and link with partner, finishing in the middle of the set on own side, 1st couple facing down, 2nd couple facing up.

29-32 ::

   Circle four hands once round.

33-34 ::

   Chase clockwise two places into progressed places on opposite sides.

35-36 ::

   All set.

37-40::

    All turn partner with a right hand one and a half times to finish on own sides in progressed places.', 4);
INSERT INTO 'dancecrib' VALUES (11653, '2019-03-08 18:13:28.192994+00', '2019-03-08 18:16:37.951953+00', 19228, 2, NULL, 'ace', '*Couple face couple round the room*     

1-8::

   Turn RH with opposite partner, turn LH with partner (men always loop at changing)

9-16::

  Turn BH with opposite partner (men loop at the end) and dance Back to Back with partner

17-24::

   Men''s Chain

25-32::

   Circle Allemande (dance anticlockwise outside, clockwise inside with allemande hold and pass 3 couples with LSh in 4 bars and dance the 5th and the 6th bars of a ordinary Allemande and finish the figure with half LH turn to face your opposite partner ready to dance again - men loop at the end again) ', 5);
INSERT INTO 'dancecrib' VALUES (11900, '2019-06-20 08:03:03.590604+00', '2019-06-20 12:31:16.735768+00', 19410, 1, 202, 'ace', '1--::

  1c cross down below 2c, cast below 3c ; dance up to top and cast to 2plx (2c up on [7-8]) (2,1,3)

9--::

  2c+1M & 1W+3c RHA ; 1c turn P LH to face 3cnrs[pos]

17--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag, pass RSh to 2plx (3x,1x,2x)

25--::

  All chase clw ½ ;  all turn P RH (or birl) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2623, '2012-01-22 19:29:50.448218+00', '2020-12-19 15:22:16.585519+00', 8730, 1, NULL, 'ace', '1–::

  1M set to 2W, cast off to 2pl (2M up) ; 1M+3W turn BH

9–::

  1W set to 2M, cast off to 2pl (2W up) ; 1W+3M turn BH

17–::

  1c dance up between 2c, cast off ; dance down between 3c, cast up to 2pl

25–::

  2c+1c+3c set, cross RH ; set, 2c+3c cross back RH and face out _while{2}_ 1c turn RH to face 2cnr

33–::

  Reels3{6} on the sides (Rsh to 2cnrs) | 1c cross to 2pl', 2);
INSERT INTO 'dancecrib' VALUES (11903, '2019-06-20 21:53:06.542053+00', '2019-06-20 21:55:25.045511+00', 17151, 1, 1645, 'ace', '1-::

  1c set | cast off ; turn 1&frac14; LH to centre line

9-12::

  2c+1W & 1M+3c RHA, 1c end BtoB, 1M/1W facing down/up

13-24::

  Revolving Double Triangles: all set as DTr, on [14] 1c pull RSh back | 1c quickly pass P RSh to 2cnr place _while{2}_ 2cnrs cast off/up on side _while{2}_ 1cnrs petronella turn (skip change) to end BtoB in centre ;

  repeat [13-16] twice, 1c ending BtoB in centre, 1M/1W facing down/up

25-::

  1c cast RSh round 4cnr to 2pl ; all turn P RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11645, '2019-03-04 17:36:35.461574+00', '2019-03-09 00:35:46.842441+00', 19223, 1, NULL, 'ace', '1--::

  1c set | cast off 2 (2c+3c up) ; 1c set | cast up to face 1cnr (3c down)

9--::

  1c+1cnr ½ diag Reel4, pass Rsh ; 1c+2cnrs repeat (3x,1x,2x)

17--::

  1c cross up and cast to 2pl _while{4}_ 3c+2c ½ R&L starting up/down ; All turn P RH (2,1,3)

25--::

  Circle6 and back (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (13573, '2021-01-22 19:34:16.933972+00', '2021-01-22 19:42:52.756139+00', 12357, 1, 202, 'ace', '1--::

  All set twice ; 1c & 4c turn RH (1,2,3,4)

9--::

  1c & 4c turn LH to centre facing in ; 1c+4c ½ R&L (4x,2,3,1x)

17-20::

  4c & 1c cast inwards (2c & 3c step out) | 1c turn 4c on sides, 1c in and up (2,4x,1x,3)

21-28::

  Reels4 (2,4x,1x,3)

29-32::

  4c cross down to 3pl _while{2}_ 1c cross down to 4pl _while{2}_ 3c cast up to 2pl | all set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11654, '2019-03-08 23:53:27.151705+00', '2019-03-09 08:56:01.800529+00', 19236, 1, NULL, 'ace', '1--::

  1c set | cast off into promhold facing up (2c up) ; 1c+2cnrs ½ Rsh diag. Reel3, 

9--::

  1W+1cnrs ½ diag Reel3 (1W Rsh to 1cnr) _while{4}_ 1M cast Lsh round 3Wpl to join P in promhold facing down ; ½ diag. Reel3 on 2diag,, Rsh to 3Mpl

17--::

  1M+1cnrs ½ diag. Reel3, Lsh to 1Mpl _while{4}_ 1W cast Lsh round 3Wpl, 1c finish in 2pl ; 2c+1W & 1M+3c RHA (2,1,3)

25--::

  1c+3c Bourrel (2,3,1)



', 4);
INSERT INTO 'dancecrib' VALUES (11902, '2019-06-20 21:21:16.395833+00', '2019-06-20 21:57:54.38821+00', 16133, 1, 1645, 'ace', '1-::

  1c &frac12; turn RH into promhold | dance down (2c up) ; cast RSh round 3M to face W side NHJ

9-::

  Ruby Triangles: 1c with NHJ set as DTr with 2W+3W, 1M/1W pull LSh/RSh back | 2c+1M & 1W+3c set as crown triangles ; 1c NHJ set as DTr with 2M+3M | 1c set turning in to end NHJ facing W side

17-::

  1M/1W Fig8 round 2c/3c _while_ 2c & 3c R&L, end in facing lines across 1M/1W between 2c/3c

25-::

  All set twice ; 1c turn 1&frac34; RH to (2,1,3)

33-::

  All Circle6 & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11904, '2019-06-21 21:44:46.882201+00', '2019-06-21 21:44:57.534868+00', 10019, 1, 1645, 'ace', '1-::

  1M+2c & 3M+4c &frac12; LSh Reels3 across ; 1M & 3M take P in promhold to complete the reels

9-::

  1c & 3c dance in & down as 2c & 4c dance up sides | 1c & 3c cross LH below 4c/5c ; cast up (2,1,4,3,5) | &frac12; turn LH to face 1cnrs

17-::

  1c & 3c Corners Pass & Turn with 1cnrs, pass RSh ; repeat with 2cnrs, pass RSh to face across in centre

25-::

  1c & 3c cross RH | cast off (2c & 4c up) ; &frac12; Fig8 up between 4c/5c (2,4,1,5,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11907, '2019-06-24 13:40:39.111453+00', '2020-09-19 09:35:04.283361+00', 19411, 1, 202, 'ace', '1--::

  1c+2c The Knot (2,1,3)

9--::

  2c & 1c Allemande Right ; chase clw ½ (1x,2x,3)

17-28::

  3C R&L. 1c face out  (1x,2x,3)

29-32::

  1c cast (2c up) | 2c & 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3806, '2013-07-13 15:56:09.99518+00', '2020-09-27 08:08:03.134156+00', 14242, 1, NULL, 'ace', '1–::

  1c set | turn BH 1½ and face 2c ; 1c set to 2c and turn BH on the side (1x,2,3,4,5,6)

9–::

  Snowball G-Chain, start 1c RH to 2c, on [4] 1c (in 4plx) + 2c (in 2plx) take »L-Tulloch«hold (Lsh to Lsh, L arms linked, holding P''s R hand behind his back) make 2 or 3 turns, finish facing up (order 3c,2x in middle,4, 1x in middle,5)

17–::

  3c+2c & 4c+1c RHA 1½ ; 3c+1c LHA 1½

25–::

  2c+1c & 3c+4c RHA 1½ (1,2x,4,3x,5,6) ; all set | 1c+4c cast off as 2c+3c turn 1 ½ moving up (2,1,3,4,5,6)



{{explanation}}

For second time through, 1c starts anew from 2pl, finish (2,3,1,4,5,6).  Next time, 2c starts from 1pl and 1c gallop to the bottom (4c+5c+6c up on [3-4].  

Alternative: dance in a 5c set, new couple starts from the top each time.  

This version, published in »Dance-on«, issue 45, p. 22-23, is close to the military version', 3);
INSERT INTO 'dancecrib' VALUES (11916, '2019-06-25 05:48:52.352859+00', '2019-06-27 11:40:58.218295+00', 19419, 1, 202, 'ace', '1--::

  1c dance down | cast round 2c to 1pl ; ½ Fig8 down round 2c (1x,2,3)

9--::

  Mirror Reels3 on sides, joining hands where possible, 1c starting down and in, and 2c dancing up and out. On [11-12] 2c cross down to 2plx (1x,2x,3)

17--::

  1c+3c M-Chain (1x,2x,3)

25--::

  1c+2c The Spiral (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11345, '2018-11-19 11:22:00.097033+00', '2021-01-22 20:54:15.413121+00', 11616, 1, 1645, 'ace', '1-::

  1c dance in{1} & down{1} | turn BH down to 3pl ; long cast up to 1pl  

  _while{8}_ 2c cast up | dance in{1} & down{1} ; turn BH down to 3pl | dance down & cast back to 3pl  

  _while{8}_ 3c long cast up to 1pl ; dance in{1} & down{1} | turn BH (1,3,2)

9-::

  1c+3c DblFig8 taking hands, 1c cross down to start

17-::

  Mirror reels3{6}, 3c start out & up | 1c dance down _while_ 3c cast up _while_ 2c turn BH (3,1,2)

25-::

  3c turn BH & face down _while{2}_ 1c & 2c set facing down/up NHJ with P | 3c & 2c set facing down/up _while{2}_ 1c turn BH ;

  1c & 3c dance down & cast to sides _while{2}_ 2c cast up to 1pl | all set (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11906, '2019-06-24 04:59:01.035756+00', '2019-06-24 05:08:27.400989+00', 529, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c ½ R&L ; all turn P RH (2x,1x,4x,3x)

9--::

  1c+4c LHA ; 2c+1c & 4c+3c ½ R&L (1,2,3,4)

17--::

  1M+2M and 1W+2W cross NHJ (W under men''s arch) | change places on sides, 1c dancing out and down, 2c passing under joined arms ; 1M+3W and 1W+3M cross NHJ (1M+3W making arch) | change places on sides, 1c dancing out and down, 3c passing under joined arms (2x,3x,1,4)

25--::

  1M+4M & 1W+4W repeat [17-20] (to 2x,3x,4x,1x) ; all set | cross RH (2,3,4,1)

33--::

  3c+4c+1c Circle6 and back



*Note:  

1. The first man always makes the arch, the first woman always goes under,

also first couple always dance down outside to progress.  

2. Last time through all couples dance eight hands round and back, and finish with hands raised as in The Bumpkin.*', 2);
INSERT INTO 'dancecrib' VALUES (11908, '2019-06-24 14:22:48.94111+00', '2019-06-27 11:39:38.80634+00', 19412, 1, 202, 'ace', '1--::

  1c set | 1W cast (2W up) ; 1W&2M set | 1W cast (3W up) (1M,2M,3M on Mside, 2W,3W,1W on Wside)

9--::

  3C Bourrel. 1c face out (3,1,2)

17--::

  3C Chain Progression (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11909, '2019-06-24 16:47:14.874087+00', '2019-06-27 11:39:48.098955+00', 19413, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; 1c+3c turn RH into Allemande hold (2,1,3)

9--::

  1c+3c 6 bars of Allemande (to 2,3,1). On [15-16] 3c cast to 3pl _as_ 1c lead up LHJ to face 1cnrs

17--::

  Corner Chain on 1diag

25--::

  Corner Chain on 2diag', 2);
INSERT INTO 'dancecrib' VALUES (9618, '2017-02-25 08:49:51.133752+00', '2020-02-10 15:42:01.366802+00', 4435, 1, 202, 'ace', '1--::

 1c+2c Circle4 and back

9--::

 1c+2c RHA{3}, LHA{3} | 1c cast to 2pl, 2c dance to top (2,1)

17--::

 2c+1c A&R ; dance BtoB

25--::

 2c+1c R&L (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11854, '2019-05-18 23:01:04.414615+00', '2019-09-09 09:57:46.084652+00', 19357, 1, 1645, 'ace', '1-::
  1M/1W each dance Fig8 round 2c/3c starting down & out between side cpls
9-::
  1c+2M+3W dance lefts and rights ending with ½ RH turn to face that person
17-::
  Samara progression: 3M+2W ½ turn BH | petronella to 1M/3W pl ; chase ⅓ clw | set  
  _while{8}_ 2M+1W chase ⅓ clw | ½ turn BH ; petronella to 1M/3W pl | set  
  _while{8}_ 1M+3W petronella cclw to 1W/2M pl | chase ⅓ clw ; ½ turn BH ; cast away to 3M/2W pl (2,3,1)
25-::
  All circle6 & back (2,3,1).
', 5);
INSERT INTO 'dancecrib' VALUES (12678, '2020-03-22 00:08:44.182146+00', '2020-03-22 00:13:42.400109+00', 19861, 1, 202, 'ace', '1--::

  1c A&R, touching RH ; cross RH | cast off (2c up) (2,1x,3)

9--::

Diagonal R&L (3x,1x,2x)

17--::

  ½ Reels3 across, 1c LSh to 1cnrs[pos] (to 3,1,2) ; all set | all dance bars[3-4] of La Baratte (3x,1x,2x)

25--::

  All dance bars[5-8] of La Baratte (3x,1x,2x) ; all chase cclw ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8383, '2014-08-20 11:42:35.79274+00', '2020-02-08 13:40:27.956481+00', 15570, 1, 202, 'ace', '1--::

 1c cross RH | cast off _while{2}_ 2c dance up to 1pl and face out  ;  2c+1c turn EH ending 2c (having turn towards each other) facing 1c dn/up 

9--::

 2c+1c set | Circle4 L finishing on sidelines | 1W+2M & 1M+2W set (2,1x)

17--::

 The Swirl [2c+1c turn RH into allemande hold 2c facing 1c dn/up | set advancing to BtoB ; releasing RH, LHA to sidelines] (1,2x)

25--::

 1c+2c ½ R&L ; 1c turn BH 1 ½ (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (12994, '2020-07-28 05:19:25.814236+00', '2020-07-28 12:46:51.504051+00', 19163, 1, 202, 'ace', '*Form up set as a square; then on the chord, take hands as in a circle to bow and curtsey across the set.*

1--::
  Circle8 and back (1,2,3,4)
9--::
  All set to P | Petronella turn ; set | all turn P RH ½ ready for
17--::
  All M LHA ½ _while{2}_ all W chase clw as in M-Chain | all turn opposite person RH ½ ; All W LHA ½ _while{2}_ all M chase clw as in L-Chain | all turn P RH and face P (3,4,1,2)
25--::
  ½ Gr-Chain ; all turn P BH | turn cnrs LH ½ into promhold facing cclw
33--::
  All Promenade to the M''s original places', 4);
INSERT INTO 'dancecrib' VALUES (11910, '2019-06-24 17:37:05.776812+00', '2023-01-22 19:53:22.569194+00', 19414, 1, 202, 'ace', '1--::

  1c ½ Fig8 down round 2c ; cross RH | cast (2c up) (2,1,3)

9--::

  All set | Circle6 L ½ | set (3x,1x,2x)

17--::

  6 bars of »Chain R&L« [: mid dancers change place RH with cnrs diagonally R | new mid dancers repeat LH with cnrs to L ; repeat to the R (2x,1x,3x)] | 1c turn RH ¾ to midline _as_ 2c & 3c cross LH

25--::

  2c+1M & 1W+3c LHA, pass LSh ; 2c+1W & 1M+3c RHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10477, '2018-03-03 03:29:29.788785+00', '2020-09-01 08:39:02.67787+00', 14578, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 down round 3c (2,1x,3)

9--::

  2c+1c+3c set | La Baratte, 1c facing 3cnrs position at end

17--::

  ½ *Lsh* Reel4 in 1diag, 1c turn P RH to face 4cnrs ; ½ Reel4 in 2diag, 1c finishing BtoB in DTr position, 1W(1M) facing up(dn)

25--::

  DTr up/dn (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11911, '2019-06-24 19:10:58.113868+00', '2019-06-27 11:40:15.326392+00', 19415, 1, 202, 'ace', '1--::

  1c+2c ½ R&L ; ½ Parallel Reels3 on sides, 1c RSh to 3c (3,1x,2x)

9--::

  3c+1c La-Chain (3,1x,2x)

17--::

  All set | 3c+2c »The Capstan« [ : 3c (start inwards) + 2c (outwards) dance 1½ times LSh round 1c on sides (3c loop into 3pl)] (2x,1x,3)

25--::

  2c+1c ½ DblFig8, 2c crossing down ; turn EH on sides, 1c starting outwards (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11656, '2019-03-10 08:46:29.365918+00', '2019-03-21 00:07:48.103811+00', 19237, 1, 202, 'ace', '1--::

  1c Petronella turn | set ; repeat (1x,2,3)

9--::

  1c turn RH, 1M (1W following with RHJ) cast off 2 places round 3W to face 2M (2c up)

17--::

  ½ Reel3 in tandem (with lead change) RHJ on 1diag. On [19] 1c release hands and 1M taps 1W on shoulder. 1W leading face 3M ; ½ Reel3 in tandem (with lead change) on 2diag.  1M leading face 2M (in 3Wpl)

25--::

  ½ Reel3 in tandem (with lead change) on 1diag. On [27] 1M taps 1W on shoulder. 1W leading face 3M (in 1Wpl) ; ½ Reel3 in tandem (with lead change) on 2diag (2,1,3)

33--::

  1c+3c The Knot (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (8950, '2015-10-25 13:15:03.55502+00', '2015-10-25 13:15:03.55502+00', 16803, 1, NULL, 'ace', '1--::

  All dance BtoB ; turn P RH, 2c+3c finish RHJ facing up

9--::

  2c+3c Allemande (1,3,2,4)

17--::

  1c+4c cross RH | cast inwards (3c+2c to end) ; ½ Fig8 through end couple (3,1,4,2)

25--::

  Circle8 and back

', 2);
INSERT INTO 'dancecrib' VALUES (8949, '2015-10-21 16:19:06.589976+00', '2017-09-19 15:39:07.221504+00', 7149, 1, NULL, 'ace', '1--::

  1c cast behind own lines (2c up on [3-4]) ; and up to 2pl | turn P RH and face down

9--::

  1c+3c dbl Fig8, use best hand on crossing (2,1,3)

17--::

  2c+1c Non-progressive Allemande (1c starts in and up as 2c casts behind) (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11912, '2019-06-24 22:59:35.907198+00', '2019-06-27 11:40:27.190506+00', 19416, 1, 202, 'ace', '1--::

  1c+2c The Tournée (2,1,3)

9--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag (3x,1,2x)

17--::

  Pick-up chain, 2c crossing RH to start (2x,1x,3x)

25--::

  3C S&Link ; 3c+2c chase clw ½ _while{4}_ 1c turn BH 1¼ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10021, '2017-07-23 15:59:08.266265+00', '2023-02-04 01:23:11.488716+00', 7081, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up).  1L+2s also 1M+3s dance RH across end
    with 1s in centre, LH joined, facing opp sides
9-16::
    1s set, cast to Left (1M up round top Ladies'' place, 1L down round
    3M place) into lines of 3 across, 1M between 2s, 1L between 3s & all
    set
17-24::
    Reels of 3 across, 1s pass dancer on Right by RSh to start.  End 1s
    in centre, LH joined, 1L facing up, 1M facing down
25-32::
    1s set, 1M casts down round 3l place, 1L up round top Man''s place,
    into 2nd place opp sides.  2s+1s+3s set
33-40::
    RSh reels of 3 on sides (6 bars), 1M up, 1L down to start.  Bars
    39-40 1s cross RH to 2nd place own side  End 2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (3003, '2012-01-22 19:30:06.491884+00', '2020-12-20 23:53:38.938067+00', 9215, 1, NULL, 'ace', '{{explanation}}

Couples numbered 1,2,3,4,5 clw, M has W on right.



1–::

  1c set advancing to 3c+4c ; 1M+3c LHA _while{4}_ 1W+4c RHA

9–::

  1c+3c+4c in promhold Reel3 across (1c starts out and to the right (towards 4c)

17–::

  1c dance out between 3c & 4c, split and dance up 1M (1W) passing inwards through 3c(4c) and outwards through 2c(5c)

25–::

  Circle10 and back



{{explanation}}

Repeat for 2c, 3c, 4c, 5c, then Finale:



1–::

  All W RHA, pass in front of P and Lsh round him to places

9–::

  All M LHA, pass in front of P and Rsh round her to places

17–::

  (face P) interlocking Reels4 on the circle

25–::

  Circle10 and back', 2);
INSERT INTO 'dancecrib' VALUES (14073, '2021-06-16 23:31:22.97735+00', '2021-06-16 23:33:04.183763+00', 20340, 1, 1645, 'ace', '1-::

  All 4 slip steps cclw (say "HoHoHo") | repeat back clw ; set twice turning away from P

9-::

  All dance BtoB ; turn P RH (once or twice)

17-::

  All set to P "jingling hands" | &frac12; turn RH ; lead cclw

25-::

  Repeat [17-24] leading clw

', 2);
INSERT INTO 'dancecrib' VALUES (9620, '2017-02-25 17:00:54.737699+00', '2020-11-04 10:38:46.151374+00', 17620, 2, 1, 'ace', '1–::

  1c dance down the set in prom hold, between 3c and to the left, back into

  the set between 2c, and curving right back to place.

9–::

  Circle8 and back.

17–::

  Big star (W in center RH across, M on outside) ; come back with M in

  center LH across, W on outside

25–28::

  All prom anticlockwise around the set progressing 3 pl [to 2341]

29–32::

  All turn ptr RH (or birl)', 3);
INSERT INTO 'dancecrib' VALUES (11657, '2019-03-10 12:59:03.805339+00', '2019-03-10 13:04:03.137877+00', 18099, 2, 2697, 'ace', '1-4::
  1s cast 1 place | 1s set advancing to face 1st corners 
5-16::
   2s+1s+3s Dance to Each Corner and Set: 
::
    _5-6_ 1s change places with 1st corners passing RSh & 1st corners pass RSh with a 1/4 turn to right in middle to face 2nd corners (as 2nd corners set)
::
    _7-8_ Original 1st crnrs change places with 2nd crnrs passing RSh & 2nd crnrs pass RSh with a 1/4 turn to right to face 1s in 3rd crnr (pstn) as 1s set
::
  _9-10_ Original 2nd corners change places with 1s passing RSh & 1s pass RSh with a 1/4 turn to right to face 2nd corner (pstn) as orig 1st corners set
::
  _11-16_ Repeat this Fig once more until 1s meet again in middle with 3s & 2s in 1st & 3rd places opposite sides
17-20::
  1s turn RH in the middle to 2nd pl opp sides _while_{2} corners chase 2 places clockwise to own sides | 1s dance 1/2 Fig of 8 (L round 2s, M round 3s) 
25-32::
  1s dance RSh reels of 3 across (L with 2s, M with 3s) to finish in 2nd pl own sides', 2);
INSERT INTO 'dancecrib' VALUES (11913, '2019-06-25 05:08:38.658946+00', '2019-06-27 11:40:38.068102+00', 19417, 1, 202, 'ace', '1--::

  1c+2c set | Petronella in tandem ; Petronella in tandem | cross RH (2,1,3)

9--::

  3C S&Link ; ½ diagonal R&L

17--::

  3C S&Link ; ½ diagonal R&L (3x,1x,2x)

25--::

  All A&R {1+1} | repeat ; all turn P BH, face P and cast away to exchanged places (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (11914, '2019-06-25 05:22:06.202583+00', '2019-06-27 11:40:48.838221+00', 19418, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; turn RH (2,1,3)

9--::

  1c+3c Espagnole (2,3,1)

17--::

  3C Set&Rotate (1,3,2)

25--::

  3c+2c turn P RH ½ | ½ RHA (to 1,2,3) ; 1c+2c repeat [25-28] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8399, '2014-09-04 13:27:47.720427+00', '2021-05-24 11:27:33.078351+00', 3388, 2, 2088, 'ace', '1–4::

  1c, 3c & 5c set cross RH.

5–8::

  1c & 2c and 3c & 4c change places LH on side; 2c & 4c cross RH while 1c & 3c advance to centre of set giving RH and turn clockwise to finish back to back with partner (1L & 3L facing up, 1M & 3M facing down).

9–16::

  Double Crown Triangles. (4c remain facing each other throughout setting - bars 15-16 1c & 3c using Pas De Basque turn clockwise to face partner Ladies facing up Men facing down)

17–24::

   Rsh Reel of 4 in centre of set (finishing 1c in 2nd place and 3c in 4th place on partners side facing out).

25–28::

  1c & 3c cast down 1 place (4c & 5c step up bars 25-26) all set to partner - finish 2,4,1,5,3 opposite sides.

29-32::

  All turn partner 1 1/2 times RH.', 2);
INSERT INTO 'dancecrib' VALUES (3297, '2012-01-22 19:30:19.494143+00', '2019-03-10 15:14:33.366309+00', 6209, 1, NULL, 'ace', '1–::

  1c+4c set | 1c cross in RH & 4c cross in LH (2c+3c step to ends) to (2,1x,4x,3) ; 1c+4c pass LH on sidelines and chase clw into 1W followed by 1M between 2c facing 2W, and 4M followed by 4W between 3c facing 3M for

9–::

  1c as tandem +2c & 4c as tandem +3c Lsh Reels3 across (Lead change at each loop)

17–::

  1c+4c ½ RHA (2,4x,1x,3) | set to P ; ½ Fig8 round end couple to (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2717, '2012-01-22 19:29:54.409216+00', '2014-11-22 20:26:50.677151+00', 12089, 1, NULL, 'ace', '1–::

  2c+4c diagonal Reel4 with 1cnrs, at end pass P Lsh to face 2cnrs

9–::

  2c+4c diagonal Reel4 with 2cnrs (2cnr loop by the R) (to 1,2,3,4,5)

17–::

  »Cumulative G-Chain« (1c+3c cross RH | 1c+2c & 3c+4c pass LH on the side (2,1x,4,3x,5) ; 2c cross RH and 1c+4c & 3c+5c pass RH on the sides) | 2c+4c & 1c+5c pass LH on the side as 3c cross LH (4,2x,5,1x,3)

25–::

  4c+2c & 1c+5c ½ R&L ; 4c+5c ½ Fig8 to the R (4W & 5M pass Rsh in the middle) (2,4,1,5,3)



{{explanation}}

(adapted from Derek Haynes »MacDonald of the Isles«', 3);
INSERT INTO 'dancecrib' VALUES (1746, '2012-01-22 19:29:00.162453+00', '2020-09-27 08:19:51.4059+00', 14270, 1, NULL, 'ace', '1–::

  1M ½ Lsh Reel3 with 2c ; 1W joins in front of 1M and dance next ½ Reel3 with 2c together (1,2)

9-12::

  1M sets advancing to 1W+2W joining hands as DTr | all three petronella 1 place cclw round the triangle, 1W finishing in 1M place

13-16::

  2M sets advancing to 1W+2W (in 1pl) joining hands as DTr | all three petronella 1 place cclw round the triangle, finish (2x,1x)

17–::

  1c (leading)+2c lead down ; the W turn above M and under M''s arm and all lead up (2,1)

25–::

  1c set | turn RH ½ ; ½ Fig8 through 2c (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (8457, '2014-11-20 01:47:11.84756+00', '2015-03-30 15:43:59.614799+00', 15706, 1, NULL, 'ace', '1--::

  1c+2c ½ DblFig8 (1c cross down) : 1c+2c Set&Link (2x,1x,3)

9--::

  1c+3c repeat (2x,3x,1)

17--::

  3c+1c “Rose Progression”: 3M+1M change place RH | cast 1 place clw ; turn BH ½, face and twirl away while{8} 3W+1W set | turn BH ½, face and twirl away | cross to other side (2x,1,3x)

25--::

  ½ Diag R&L to the R ; ½ Diag R&L to the L (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (8445, '2014-11-14 21:21:42.817735+00', '2015-04-10 21:47:38.212769+00', 15701, 2, 160, 'ace', '*3c and 4c start on opposite side* 



1–::

  1C2C also 3C4C set and rotate.

 9–::

  8 Hands round and back.

 17–::

  2C1C also 4C3C dance poussette right round. To end - 1C 4C turn ptnr BH 1_ 1/4 round to end in line up/down dance (the men are back to back) as 2C3C half turn & retire to sidelines.

 25–::

 1C4C  Highland Schottische Poussette.  To end - all pull right shoulder back and cast to sides. The women directly to the sidelines but the men cast around one another to end on sidelines opposite prtnr. 2, 4, 1x, 3x.

', 4);
INSERT INTO 'dancecrib' VALUES (2847, '2012-01-22 19:29:59.89945+00', '2014-11-24 16:09:33.447835+00', 8573, 1, NULL, 'ace', '1–::

  M ½ Fig8 to the R (round W facing him) ; M+the two W on his R RHA

9–::

  M set with LHJ | turn LH ½ ; each M+the other two W RHA

17–::

  In Trios A&R ; pass person opposite Rsh to face next trio | all set

25–::

  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (9623, '2017-02-26 17:45:12.525266+00', '2017-02-26 17:55:57.831334+00', 17621, 1, NULL, 'ace', '1--::

  1c facing 2c set | change place RH ; 1c set | turn BH ½ and twirl to face 1cnr

9--::

  Set to and turn corners (2,1x,3)

17--::

  Circle6 and back (2,1x,3)

25--::

  1c ½ Fig8 R (M up, W down) finishing on 1diag. for ; 1c+3c ½ Poussette (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (15186, '2022-10-25 16:13:51.1465+00', '2022-10-26 08:02:23.589982+00', 15139, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; ½ Fig8 up round 2c (2,1,3)
9--::
  Mirror  Reels3 on sides, 1c in and down (2,1,3)
17--::
  1c lead down ; lead up to 2pl centre. On [24] 3c step in
25--::
  1c+3c Allemande (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (9622, '2017-02-26 16:30:04.392591+00', '2021-11-24 09:33:52.439376+00', 17621, 2, 1, 'ace', '1–4::

  1M+2M, 1W+2W set | change RH on sides

5–8::

  1c set | ½ turn BH & twirl to face 1st corners

9–::

  1c set to and turn corners [2,1x,3]

17–::

  Circle6 (and back)

25–28::

  1c ½ fig of 8 (1M going up & 1W down)

29–32::

  1c+3c ½ poussette [to 231]', 3);
INSERT INTO 'dancecrib' VALUES (9626, '2017-02-27 16:54:26.133742+00', '2017-02-27 16:54:26.133742+00', 7389, 1, NULL, 'ace', '1--::

  All Circle8 and back

9--::

  1c+3c in promhold dance round each other Rsh, to places ; 2c+4c repeat

17--::

  All W RHA ; All M LHA and face P

25--::

  All set | All turn P BH into 1c facing 4c and 2c facing 3c diagonally (W on R of M) ; 1c+4c & 2c+3c ½ La-Chain 



*All W have progressed, 1W+3W clw; 2W+4W cclw.  1W and her P (in 4pl) are new 1st couple*

', 3);
INSERT INTO 'dancecrib' VALUES (8264, '2014-05-12 08:09:13.443621+00', '2014-11-24 19:50:29.474664+00', 15428, 1, NULL, 'ace', '1--::

  All A&R ; repeat but “middles” stay in middle

9--::

  “outsides” R&L _while{8}_ “middles” dance solo free choice (from bar [7])

17--::

  EITHER in each trio Reels3 , Rsh to R   OR   “middles” turn RH on R ; LH on L 

25--::

  All turn opp. RH 1½ and finish BtoB ; set to next trio | pass RH to face new trio



', 3);
INSERT INTO 'dancecrib' VALUES (8951, '2015-10-27 21:24:08.090083+00', '2019-09-03 21:32:07.958149+00', 12508, 1, NULL, 'ace', '1--::

  1c cross down RH (2c up), cast behind 3c, cross RH and cast up | turn P LH and join RH with 3cnr into diagonal line

9--::

  1c+3cnrs set R (change hands with cnr) {1}, 1c+3cnrs turn LH ½, 1c joining RH in middle {1} | 3cnrs set along the diagonal _while{2}_ 1c set R {1} and turn LH ½ to face 3cnr {1} ; ½ Reel4 on 1diag, finish on 2diag, 1c LHJ to P and RHJ to 4cnr 

17--::

  Repeat [9-16] with 4cnrs, 1c at the end crossing LH to (3x,1x,2x) 

25--::

  All S&Link3 twice (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3097, '2012-01-22 19:30:11.14256+00', '2014-11-25 09:07:51.628739+00', 5529, 1, NULL, 'ace', '1–::

  1W+2W (1M+2M) turn LH (RH) ½, finishing 1c BtoB in 2pl | All set as in DTr ; 1W+3W (1M+3M) turn RH (LH) ½ | 2c+3c+1c set as in DTr

9–::

  1c followed by 3c dance up between 2c, cast off ; dance NHJ down through 3pl, cast up to face 1cnrs, 3c looping into 3pl

17–::

  1c turn 1cnrs RH, pass Rsh (cnrs dance for {4}) ; turn 2cnrs RH (same), and cross Rsh to (2,1,3)

25–::

  All circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (8473, '2014-12-02 19:34:05.877082+00', '2018-09-07 14:28:25.234065+00', 15401, 2, 160, 'ace', '1–::

 Six hands Round and back.

9–::

 Set, cast ; turn LH 1+1/4 to face 1crnr.

17–::

 Set to 1crnr, dance R round ptnr to face 2crnr ; set to 2crnr, dance R half round ptnr to end in center facing own side, (1L above/1M below)

25–::

1L2C/1M3C dance LH Across once round - 1C end on opp. sides ; All set, 1C cross to own sides.', 2);
INSERT INTO 'dancecrib' VALUES (8469, '2014-11-25 16:18:27.826684+00', '2014-11-26 15:30:37.173658+00', 15707, 2, 1, 'ace', '1–::
  1c cross R | cast off [2s up] ; turn R
9–::
  2c+1c dance Ladies'' Chain
17-20::
  1c dance ½ fig 8 (1M down, 1L up)
21–24::
  All turn R to fin in middle in Allemande hold facing up
25–::
  3-couple Allemande (to 312)', 5);
INSERT INTO 'dancecrib' VALUES (3430, '2012-01-22 19:30:25.203881+00', '2014-11-27 11:17:03.295703+00', 3300, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  1W followed by 2W+3W cross at top, cast behind 1M, in front of 2M, (but 2W passes behind 2M and overtakes 1W), behind 3M, cross back and dance up own side to order 2,1,3

17–::

  1M+2M+3M repeat

25–::

  2c+1c+3c circle6 and back.', 3);
INSERT INTO 'dancecrib' VALUES (8485, '2015-01-14 11:01:56.810606+00', '2015-01-14 11:01:56.810606+00', 7313, 1, NULL, 'ace', '1--::

  1c set | cast (2c up) ; ½ Fig8 round 2c (2,1x,3)

9--::

  All S&Link ; 1W+3c & 1M+2c ½ Reels3 across, 1c Lsh to 4cnr

17--::

  All S&Link (3,1,2) ; ½ Reels3 on the sides 1c Lsh to 3cnr, 1c finish facing 1cnr

25--::

  Set H&G (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (14469, '2021-11-28 03:50:52.341345+00', '2021-11-28 03:50:52.341345+00', 16657, 2, 963, 'ace', '1-4::  
  1C&2C & 3C&4C set and link, 1M&4M face out  
5-8::  
  1M&4W, 1W&4M LH turn moving to diag line on 1st crn diag: 4W with 1M behind facing 2M & 1W with 4M behind facing 3M  
9-12::  
  1/2 R4 with lead switch, passing Lsh to 2nd crn diag: 1M with 4W behind facing 3W & 4M with 1W behind facing 2W  
13-16::   
  1/2 R4 with lead switch, finish on the sides 3,(4),1,(2)  
17-20::  
  All set TWICE  
21-24::  
  4W&1M, 4M&1W turn BH 1-1/2 on sides WHILE 3C&2C turn partner BH 3,1,(4),(2)   
25-28::  
  All dance Rsh around partner back to side 3,1,(4),(2)  
29-32::  
  All chase cw halfway 2,4,(1),(3)
   
', 5);
INSERT INTO 'dancecrib' VALUES (12998, '2020-07-29 05:57:27.170212+00', '2020-07-29 05:58:00.813794+00', 19161, 1, 202, 'ace', '1--::

  3C Promenade (1,2,3)

9--::

  1c+2c The Knot. 1c face 1cnrs (2,1,3)

17--::

  Turn CPCP to 2pl facing out and down (2,1,3)

25--::

  Mirror Reels3 on sides, 1c out and down. 1c & 3c continue the Reel to exchanged places (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2909, '2012-01-22 19:30:02.494876+00', '2020-09-01 14:19:48.789625+00', 4903, 1, NULL, 'ace', '1–::

  1c turn RH | cast behind 2c, dance between 3c & 4c and cast to 4pl (other Cs up) (2,3,4,1)

9–::

  3W+1M change places RH | 1c cross with person opposite RH ; 1c change places RH with persons diagonally above | 1c cross with person opposite RH

17–::

  1c change places RH with persons diagonally above | 1c cross with person opposite RH ; | 1W change places diagonally up with 2M | All set (1,2,3,4)

25–::

  1c+2c & 3c+4c R&L

33–::

  1c cast to bottom (other Cs up) ; All A&R (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (2310, '2012-01-22 19:29:31.005782+00', '2021-10-11 22:34:17.862803+00', 2428, 1, NULL, 'ace', '1–::

  1M sets to 2W and casts off (2M up) ; 1W sets to 2M and casts off (2W up)

9–::

  1c turn 1cnr RH | pass Rsh ; turn 2cnr LH | pass Rsh to face 1cnr

17–::

  SetH&G , finish BtoB, 1M facing up / 1W down

25–::

  Reels3{6} with cnrs (Rsh to 2cnr) | 1c cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1898, '2012-01-22 19:29:08.716082+00', '2019-01-11 00:23:53.255934+00', 7284, 1, NULL, 'ace', '1–::

  1c cross down (no hands) to 2plx (2c up) | change places with 3c EH ; 1c turn RH ½ | lead to top (2c+3c down) and face up in promhold

9–::

  1c with 2c Rsh Reel3 across, at the end 1c pivots inwards into 1pos on own side facing down NHJ, with 2c in 2pl,  on [16] 3c step in and face up NHJ

17–::

  All set, all Petronella (1c+3c in tandem) ; all set advancing {1} to join hands in circle, _while_ setting {1} pull Rsh back tightly | and cast clw (to 1,2,3)

25–::

  1c+2c the Knot', 4);
INSERT INTO 'dancecrib' VALUES (9624, '2017-02-26 23:58:18.593142+00', '2017-02-27 22:23:54.887075+00', 5256, 1, NULL, 'ace', ' 

1--::

  1c+4c cross RH and face out _while{2}_ 2c+3c set | 1c+2c & 3c+4c ¾ Dbl Fig8 (2,1,4,3)

9--::

  1c+4c RHA ; set facing diagonally in | ½ LHA and face cnrs on diagonal (2,4x,1x,3)

17--::

  4c+1c fig8 round own cnr and next cnr clw. start Rsh to cnr (2,4x,1x,3) 

25--::

  4c+1c LHA _while{4}_ 2c+3c set to P and cross RH ; All set | and cross RH (2,4,1,3) 

 

', 3);
INSERT INTO 'dancecrib' VALUES (15156, '2022-10-05 00:22:23.320518+00', '2023-02-04 01:23:05.393511+00', 21027, 3, NULL, 'ace', '1-8::
    1s turn 2H, cast one place (2s step up bars 3-4). 1s dance 1/2 Fig
    of 8 up round 2s.  2 (1) 3
9-16::
    2s+1s+3s dance »Ripple«:
::
    _9-10_   2s+3s face diagonally Adv+Ret 1 step _while_ 1s 1/2 turn 2H
    & retire to 2nd place own sides
::
    _11-12_ 2s+1s+3s circle 6H round to the left 1/4 for 1 step, retire
    1 step to form line of 3 across (3 men at top, 3 ladies at bottom)
::
    _13-16_ 2s+1s+3s dance »Ripple« repeating bars 9-12 ending (3) 1 (2)
17-24::
    3s+1s+2s dance »Wave«:
::
    1s pull back RSh, cast round 3rd corner, pass RSh up/down middle of
    set, dance RSh round 4th corner to 2nd place opposite sides (8 bars)
    _while_ 3s+2s dance diagonally in, dance 1/2 4H (2 bars) to the left
    & retire diagonally (2 bars), 2s+3s repeat bars 17-20 (4 bars) (3)
    (1) (2)
25-32::
    3s+1s+2s turn 2H for 3 bars & circle 6H round to the left 1/2 way (3
    bars) & all set. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8439, '2014-11-11 16:02:20.813951+00', '2020-10-12 11:27:49.390025+00', 15640, 2, 1, 'ace', '1–::

  1c cross R | cast off [2c up] ; 1c turn R [to 2x]

9–::

  All set twice in sidelines ; 1c turn R 1¼ [to 1L+2c, 1M+3c facing in lines across]

17–::

  All set twice in lines across ; 1c turn R 1¼ [to 2pl; 1M face up, 1L down]

25–::

  All dance clockwise once round', 3);
INSERT INTO 'dancecrib' VALUES (11917, '2019-06-25 15:13:02.770343+00', '2019-07-13 17:56:45.511969+00', 19421, 1, 202, 'ace', '1--::

  ½ Reel4 on 1diag, 2c passing P LSh into facing Lines3 across ; ½ Reel4 on 2diag, 2c passing P LSh (3x,2x,1x)

9--::

  All set | Triple Petronella ; repeat (1,2,3)

17--::

  1c+2W & 2M+3c Circle3 L opening into ; Circle6 L ½ (3x,2x,1x)

25--::

  All turn P BH 1½ ; 2c (1c following) dance up to top and cast (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (3593, '2012-07-21 11:45:22.055591+00', '2014-12-03 18:03:17.854217+00', 11763, 1, NULL, 'ace', '1–::

  1c set | turn RH ½ into promhold ; dance to bottom, cross and cast up (2c up) to (2,1,3)

9–::

  Mirror Reels3 on the sides (join NH when possible), 1c starts in and up

17–::

  1c half Fig8 up ; ½ Fig8 down (2,1,3)

25–::

  Teapots R (2c+1W & 1M+3c RHA) ; all chase ½ clw (3x,1x,2x)

33–::

  3c+1M & 1W+2c Circle L, at end 1c pivot R to face P on midline ; 1c set | 1c cast up on opposite side (3c down) (1x,3x,2x)

41–::

  All A&R {2} | Link3 ; A&R {2} | Link3 (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (8474, '2014-12-04 21:15:30.296564+00', '2014-12-04 21:15:30.296564+00', 15711, 2, 1, 'ace', 'Couples in a big circle facing anticlockwise, nearer hands joined

1–4::
  Starting on outside foot, walk forward (4 walking steps) | set
5–8::
  Walk forward (4 walking steps) | change sides (L going under M''s arm) to face clockwise
9–12::
  Walk forward (4 walking steps) | full turn while walking forward
13–16::
  Set | change sides (L going under M''s arm)', 2);
INSERT INTO 'dancecrib' VALUES (3698, '2013-02-06 00:26:04.007599+00', '2014-12-05 07:58:14.869243+00', 14712, 1, NULL, 'ace', '1–::

  1c+2c set | ½ RHA ; set | cross RH (2,1,3)

9–::

  1c turn 1cnr RH and face 1cnr ; ½ Reel4 on 1diag, 1c finish on sides in 2pl

17–::

  1c turn 2cnr LH and face 2cnr ; ½ Lsh Reel4 on 2diag, finish on sides (3x,1,2x)

25–::

  All chase ½ cclw ; 1c set | cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8455, '2014-11-18 23:06:07.486064+00', '2016-04-18 22:48:56.308713+00', 15705, 2, 160, 'ace', '1–::

 1C cross down RH, cast up to ptnr''s place ; (1x,2)

5–::

 Diamond Poussette ;

13–::

 2C cross up LH and cast down to ptnr''s place. (1x, 2x)

17–::

 Set & Link -  1L2M  give LH in passing to face ptnr on 1st crnr diagonal ;

21–::

 Diagonal Reel4 ;

29–::

 Hands4 to the left, 1M leading 1L and 2L leading 2M.', 2);
INSERT INTO 'dancecrib' VALUES (1809, '2012-01-22 19:29:03.498356+00', '2017-02-28 08:52:57.422312+00', 699, 1, NULL, 'ace', '1-::

  1c cross RH, cast off (2c up) ; Teapots R (2c+1M & 1W+3c RHA), 1c face out on own side  

9-::

  1c cast L round 4cnr and into the centre ; 1W+2M+3M & 1M+2W+3W RHA

17–::

  1c (LHJ) +1cnrs BiL | 1c turn LH 1¼ {4} | 1c+2cnrs BiL

25–::

  Reels3{6} across, Lsh to 3cnr | 1c cross RH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8138, '2013-12-21 23:02:09.670766+00', '2014-12-16 14:24:20.730064+00', 15314, 1, NULL, 'ace', '1--::

  1c cross down into mirror Reels3 on the sides, 1c finish NHJ (1x,2,3)

9--::

  2c+3c make arches and 1c dances down under them to below 3pl | 1c turn BH 1½ {4} |1c dance to top and face out (1,2,3) 

17--::

  1c+2c change places EH on the side, 1c passing outside 2c | 1c dance La Barratte , at end turn LH to face 1cnr

25--::

  1c set “H&G”, finish with petronella turn to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8481, '2014-12-22 23:24:58.258594+00', '2014-12-22 23:24:58.258594+00', 6709, 1, NULL, 'ace', '1--::

  1c+2c set | ½ RHA and 2c face 1c RHJ ; 2c+1c+3c ½ Rsh Reels3 on the sides (3,1x,2x,4)

9--::

  1c+2c set | ½ LHA and 2c face 1c LHJ ; 2c+1c+4c ½ Lsh Reels3 on the sides (3,4,1,2)

17--::

  1c+2c set | ½ RHA and 2c face 1c RHJ ; 4c+2c+1c ½ Rsh Reels3 on the sides (3,1x,2x,4)

25--::

  2c+1c set | ½ LHA ; 2c+3c & 1c+4c S&Link (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8480, '2014-12-17 16:32:27.876104+00', '2014-12-17 16:36:01.453829+00', 15708, 1, NULL, 'ace', '1--::

  1c+2c set | 1c turn RH ½ into promhold facing 3M _while{2}_  2c cast up ; 2W+1c+3M ½ Rsh diag. Reel3, and 1c face 3W

9--::

  2M+1c+3W ½ Rsh diag. Reel3, and 1c face up in promhold ; 1c dance to top and cast to 2pl (3x,1,2x)

17--::

  1c+2c ½ DblFig8 (1c cross down, 2c cast up) ; 3c+1c ½ DblFig8 (1c cross up, 3c cast off) (3,1,2)

25--::

  3c+1c+2c 3C Knot (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12995, '2020-07-28 13:13:49.353077+00', '2020-07-28 16:12:06.597874+00', 5279, 1, 202, 'ace', '1--::
  1c turn P BH 1½ and face out ; 1c turn 2c EH ½ on sides, 2c long loop to 1pl | turn 3c EH ½ on sides, 1c long loop to 3pl (2,3,1x)
9--::
  1c repeat same pattern [1-8] back to 1pl (1,2,3)
17--::
  1c+2c set | turn P BH ready for ; ½ Poussette (2,1,3)
25--::
 1c+3c RHA, ending RHJ with P ; turn P RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2153, '2012-01-22 19:29:22.851547+00', '2020-12-20 23:58:22.602428+00', 9372, 1, NULL, 'ace', '1–::

  1c long cast to 2pl (2c up) ; 1c turn RH 1½ to sidelines

9–::

  Reels3 on the sides, Rsh to 1cnr (to 2,1x,3)

17–::

  2c+3c RHA _while{4}_ 1c dance Rsh around 1cnr positions, into facing lines across, 1W between 2c facing 1M between 3c ; lines advance {1} retire {1} | set

25–::

  2c+3c LHA _while{4}_ 1c pulling Rsh back cast to 2pl ; 2c+1c+3c advance {1} retire {1} | set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8477, '2014-12-06 17:21:28.675879+00', '2019-02-11 18:28:01.77485+00', 15585, 2, 160, 'ace', '1–::

	1M 2L 3M 4L half diagonal Reel4 - 2L 3M pass Rsh in center to face 2crnr ;

		1L 3M 2L 4M half diagonal Reel4 - 2L 3M end on opp. sides.

		Note: 2M 3L have not moved. 1C 4C 2L 3M have changed ends and sides.



9–::

	2M 3L (on diagonal) change places with HalfTurn and Cast *while* 4C with 2M and 2L with 1C dance RH Across once round ; (4x 3x 2x 1x)

		Hands 8 to Left - Half round.      All home.



17–::

	All set, top2/bottom2 petronella in tandem ; circle 4hands round to left.



25–::

	All set, petronella in tandem (2x 1x 4x 3x);

		end Cs (2C 4C) set and cross over *while* middle couples (1C 4C) Half Rights & Lefts. 2 4 1 3.



', 2);
INSERT INTO 'dancecrib' VALUES (11918, '2019-06-25 15:38:42.135592+00', '2019-06-27 11:41:28.300499+00', 19422, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; turn P LH to 2plx (2,1x,3)

9--::

  All Advance | 2c & 3c Retire _as_ 1c Petronella Turn into facing lines3 across ; all repeat [9-12] (2,1,3)

17--::

  3C Slip Knot (1,3,2)

25--::

  3c (2c following) dance up to top and cast (to 1,2,3) ; 2c (1c following) dance down and cast round 3c (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3408, '2012-01-22 19:30:24.157677+00', '2014-12-30 00:14:42.987734+00', 13077, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; Teapots L, finish BtoB facing 4cnr 

9--::

  SetH&G to 4cnr and P, and face 1cnr ; Turn 1cnr RH and face 2cnr 

17--::

  ½ Reel4 on 2diag and face 3cnr ; SetH&G to 3cnr and P and face 4cnr 

25--::

  Turn 4cnr RH and face 1cnr ; ½ Reel4 with 1cnrs to meet in centre Rsh to Rsh facing up/dn

33--::

  1c cast Rsh round 2cnr to 2plx ; ½ Fig8 round 4cnr to 2pl while{8} corners set to P | cross RH ; set facing up/dn and change places RH to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8160, '2014-01-26 14:42:55.21019+00', '2015-10-28 15:05:48.143706+00', 15268, 2, 223, 'ace', '1-8::   Figure of eight

9-16::   Poussette  

17-24::   Diagonal Dolphin reel of 3 start to 1st L corner

25-32::   Diagonal Dolphin reel of 3 start to 2nd L corner

33-40::   Set to Corners and Partner ', 0);
INSERT INTO 'dancecrib' VALUES (3527, '2012-01-22 19:30:29.356811+00', '2017-11-09 00:07:21.872381+00', 7104, 1, NULL, 'ace', '1–::

  1c+2c+3c set | 1c+2c ½ RHA as 3c cross RH ; 2c+1c+3c set | turn P ½ RH, (2,1,3) ready for

9–::

  2c+1c+3c Allemande, at end 1c Turn LH 1¼ for

17–::

  3c+1W & 1M+2c Reels3 across, Lsh to 1cnr

25–::

  3c+1W & 1M+2c RHA ; Lsh Snake Pass (unwind the RHA, 1c leading, pass other snake Lsh through 2plx and chase cclw to) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2246, '2012-01-22 19:29:27.679947+00', '2015-01-05 13:09:59.233339+00', 2228, 1, NULL, 'ace', '1–::

  1M+2M+3M Fig8 Rsh round W below, Lsh to P

9–::

  1W+2W+3W Fig8 Lsh round M below, Rsh to P

17–::

  1M+2W cross RH | 1W+2M & 1M+3M cross LH ; 1W+3W & 1M+4W cross RH | 1W+4M cross LH (to 2x,3x,4x,1x)

25–::

  All advance Rsh past P and face P | retire to own side ; turn P RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2243, '2012-01-22 19:29:27.54036+00', '2015-01-08 09:52:44.540812+00', 11483, 1, NULL, 'ace', '1–::

  1M+3W (and 1W+3M) Fig 8 round 2c (4c) (W crossing in front of M), to own places

9–::

  1c & 3c in promhold Rsh Reels3 across with the nearest members of 2c & 4c, to places.

17–::

  All C S&Link (to face P) ; turn RH ½ | chase 1 place clw. (4,1,2,3)

25–::

  All Circle8 and back (4,1,2,3)', 3);
INSERT INTO 'dancecrib' VALUES (13685, '2021-02-22 00:32:14.923771+00', '2021-02-22 00:37:00.083293+00', 19138, 1, 202, 'ace', '1--::

  1c+2c Poussette (2,1,3)

9--::

  1W & 2M advance to centre {1}, pivot R to original place {1} | chase 1 place clw _while{4}_ 1M & 2W stand still | advance to centre {1}, curve to the R to own sides (to 2,1) ; Circle4 L (2,1,3)

17--::

  All set | dance BtoB | set (2,1,3)

25--::

  1c cross RH | cast off (3c up) ; 1c turn P BH 1½ (2,3,1)



*Deviser''s note:  

Bars 13-16: After the four hands round to the left, the two women and the two men stay holding hands on the side and they just collect the third couple so that the flow from hands round and the setting can blend into one smooth movement.*', 2);
INSERT INTO 'dancecrib' VALUES (2893, '2012-01-22 19:30:01.869643+00', '2015-01-11 12:47:00.903499+00', 13299, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; ½Fig8 up (2,1,3)

9–::

  2c+1c+3c The Knot. (3,1,2)

17–::

  Set&Rotate for three [= All Set | all cast clw to lines across ; all C change place RH | all chase clw to (2,1,3)].

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (2611, '2012-01-22 19:29:49.882347+00', '2015-01-11 23:09:27.100471+00', 3616, 1, NULL, 'ace', '1–::

  1c+2c+3c circle6 and back

9–::

  G-Chain (1c crosses)

17–::

  1c leads down the middle and up

25–::

  1c+2c ½ R&L ; 1c+2c turn BH 1½ (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3768, '2013-07-13 15:55:56.744181+00', '2015-01-11 23:21:42.034405+00', 14557, 1, NULL, 'ace', '1–::

  1c cross | cast off 2 (2c+3c up) ; 1c cross | cast up (3c dn) (2,1,3)

9–::

  2c+1c set | ½ RHA ; set | ½ LHA

17–::

  1M+3W turn BH ; 1W+3M turn BH

25–::

  All Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (11919, '2019-06-25 16:35:04.412376+00', '2019-06-27 11:41:08.214196+00', 19420, 1, 202, 'ace', '1--::

  1c turn RH and stay in centre RHJ ; 1W crosses down RSh round 2M _as_ 1M dance RSh round 2W, 1c finishing BtoB between 2c facing opp sides

9--::

  6 bars of The Spurtle | 1c cross RH to 3pl (2x,3x,1)

17--::

  3c+1c set | ½ RHA (to 2x,1x,3) ; 2c+1c set | ½ LHA. 1c & 2c stay in centre ready for (1,2,3)

25--::

  2C Progressive Promenade (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11137, '2018-09-23 21:29:16.81694+00', '2019-06-27 21:28:48.150336+00', 18540, 1, 1645, 'ace', '{{title}}

Strathspey

1-::

  All M Fig8 round P and W to her R, starting passing P RSh

9-::

  All W Fig8 round P and M to his L starting by casting behind P

17-::

  All M repeat [1-8] _while_ all W repeat [9-16]: after passing P, pass next dancer LSh, end passing P RSh

25-::

  All set facing P | turn BH & open out ; all circle6 to L to original places (1,2,3)



{{title}}

Reel

1-4::

  All set to P | turn 1&frac14; RH & M join LH in centre keeping RH with P

5-16::

  Interrupted spoke: M set R and set adv L to next W | turn RH ; repeat twice to original P

17-::

  Circle6 & back

25-::

  All set to P | petronella to W BtoB in centre facing P ; all turn P RH (1,2,3) with W still BtoB in centre

', 2);
INSERT INTO 'dancecrib' VALUES (11921, '2019-06-28 19:20:23.067016+00', '2019-06-28 19:21:14.763586+00', 19440, 1, 202, 'ace', '1--::

  1c lead down ; and up. 1M faces out (1,2,3)

9--::

  1c+2c LHA ; 1c (1M leading) cast off | dance across to 2plx (2c up) (2,1x,3)

17--::

  1c+3c RHA ; 1c (1M leading) cast off | dances across to 3pl (3c up) (2,3,1)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (3547, '2012-01-22 19:30:30.346399+00', '2015-01-11 23:26:46.089329+00', 7180, 1, NULL, 'ace', '1–::

  1c cross down, 1W / 1M Figs8 round 2c / 3c (pass between, meet & touch NH, out between same couple, cast up, turn RH ½ to place.

9–::

  All C face P for Rsh interlocking Reels4 (acknowledge P on [12], on [16] turn ¾ RH into:

17–::

  Men LHA 2/3 cclw _while_{2} women dance clw one place | all C turn RH ; repeat to new places (2,3,1).

25–::

  All C set NHJ | ½ circle6 left ; all C turn BH | ½ circle6 left (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12679, '2020-03-22 00:43:00.094096+00', '2020-03-22 00:47:47.066256+00', 19877, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 3C S&Link

9-12::

  All set | 1c set advancing and face 2cnrs[pos]

13-24::

  All Dance to Corners and Set. 1c face 4cnrs[pos] (2x,*1*,3x)

25---::

  1c pulling RSh back turn RH ½ to between ends facing opposite sides _while{2}_ 2c & 3c pass RSh | Reels3 {6}, 1c RSh to 2cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3378, '2012-01-22 19:30:22.852956+00', '2021-02-22 17:04:51.409013+00', 9536, 1, NULL, 'ace', '1–::

  All circle8 and back.

9–::

  1c & 3c change places: 3c arch, 1c dancing under ; repeat back to places, 1c making arch

17–::

  1M+3W turn (or spin) RH ; 1M+2W & 3W+4M turn LH (ie with person on left) | 1M+3W turn ¾ RH.

25-36::

  1M & 3W turn P LH | 1M+3W turn ¾ RH ; 1M+4W & 3W+2M turn LH |  1M+3W turn (or spin) RH for 6 bars

37-40::

  All C turn LH into promhold (direction not stated in original text)

41–::

  All Promenade round the set.



{{explanation}}

Repeat with 2M & 4W (2c & 4c doing arches), 3M & 1W (1c making arch first), and 4M & 2W (4c & 2c doing arches).  

Note: the turns on bars 21-32 should be danced with elbow grip, as in »Strip the Willow«.', 2);
INSERT INTO 'dancecrib' VALUES (8760, '2015-05-02 23:02:59.328249+00', '2015-05-02 23:02:59.328249+00', 15861, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c Set&Rotate (2,1,4,3)

9--::

  Parallel reels4 on the sides

17--::

  2c+1c & 4c+3c ½ Circle4 L | Turn P BH ; ½ Circle4 L | set to P (2,1,4,3)

25--::

  1c+4c Tourbillon (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3319, '2012-01-22 19:30:20.377322+00', '2015-01-11 23:31:09.22439+00', 9967, 1, NULL, 'ace', '1–::

  1c cast into 2pl (long cast, give hands) (2c up) ; turn LH to face 1cnr

9–::

  1c turn 1cnr RH | pass P Rsh ; turn 2cnr RH | pass P Rsh.

17–::

  2c+1c+3c circle6 and back.

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (8238, '2014-04-08 11:09:34.635802+00', '2015-01-11 23:33:00.827287+00', 10048, 1, NULL, 'ace', '1–::

  1c long cast to 2pl (2c up) ; long cast to below 3c

9–::

  1c lead up LHJ to Crown Triangles position (1W faces up, 1M down) | 6 bars Crown Tringles, finish facing out in 2plx

17–::

  1c dance Rsh round 1cnr, who A&R diagonally (touch hands), 1c pass Rsh ; repeat with 2cnr (to 2,1,3)

25–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (14074, '2021-06-16 23:35:13.739228+00', '2021-06-16 23:36:07.228126+00', 20338, 1, 1645, 'ace', '1-::

  1c cross RH & face down | loop LSh round 2c | cross RH & face out

9-::

  1c Fig8 on sides, starting out & up, down NHJ, out between 1c & 2c pos, round 2c, up & out, curve back to 1pl facing in

17-::

  1c+2c Double Fig8, 1c start crossing down

25-::

  1c cross down below 2c (2c up) | curve into 2pl ; turn 1&frac12; RH (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (3405, '2012-01-22 19:30:24.001985+00', '2015-01-11 23:37:47.526298+00', 9998, 1, NULL, 'ace', '1–::

  1c turn RH ; cast off 2 (2c up) and dance up to face 2M

9–::

  Set to 2M, turn inwards, set to 3W ; in promhold Rsh ½ Reel3 with 2M+3W

17–::

  1c set to 2M, turn inwards, set to 3M ; in promhold Lsh ½ Reel3 with 2W+3M (3x,1,2x)

25–::

  Circle6 and back

33–::

  2c+3c ½ R&L passing between 1c ; All Turn P RH', 3);
INSERT INTO 'dancecrib' VALUES (8759, '2015-05-01 23:06:59.819328+00', '2015-05-01 23:06:59.819328+00', 16255, 1, NULL, 'ace', '1--::

  1c turn RH | cast off (2c up) ; cross RH and cast R into lines across (1W+2c face 1M+3c) 

9--::

  All A&R up/down , Circle ½ L into lines across

17--::

  All A&R up/down ; 1c turn RH 1¼  to face 1cnr

25--::

  1c+1cnrs ½ diag Reel4 1c pass Rsh ; repeat with 2cnrs, finish 1M below 1W

33--::

  2c+1W & 1M+3c LHA ; 2c+3c turn LH as 1c turn RH 1½ (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (9338, '2016-09-29 12:30:41.402709+00', '2017-07-07 15:41:05.334881+00', 8479, 1, 202, 'ace', '1--::

 Circle6 and back

9--::

 1c lead down between 3c, cross and cast to 2plx (2c up) ; lead up between 2c, cross and cast to 2pl (2,1,3)

17--::

 All set | cross RH ; set | 2c+3c cross RH _while{2}_ 1c pass Rsh, finish to

25--::

 2c+1c+3c DTr

', 3);
INSERT INTO 'dancecrib' VALUES (8489, '2015-01-16 00:44:20.377104+00', '2015-01-18 10:16:52.601467+00', 1600, 1, NULL, 'ace', '1--::

  1c+5c cross into Fig8 round 2c/4c resp., finish in own place in the middle facing dn/up 

9--::

  2c+3c+4c Reels3 on own side, 3c start in and R 

17--::

  1c+5c dance in to meet | RHA | 1c dance to the top in the middle and turn inwards _while{2}_ 5c dance to own places

25--::

  1c(start inwards)+2c change places EH | 1c(outwards)+3c repeat ; 1c(inwards)+4c repeat | 1c(outwards)+5c repeat (2,3,4,5,1)

', 4);
INSERT INTO 'dancecrib' VALUES (3792, '2013-07-13 15:56:07.669988+00', '2016-12-23 23:43:44.804304+00', 2723, 1, NULL, 'ace', '1–::

  1c set and cross RH ; 1c+2c set | all chase one place clw (the M casting)

9–::

  All set across | all dance »La Baratte« with new P [turn P RH ½ to full arms'' length | change back sideways, W passing in front with her back to M, changing hands overhead to LH | turn LH ½ to exchanged places]

17–::

  All set | dance 1¼ RHA (to 1,2x) | 1c cast off as 2c turn RH ½ moving up (2,1)

25–::

  All set | CircleL ½; Turn P BH into | CircleL ½ (2,1)







', 3);
INSERT INTO 'dancecrib' VALUES (9339, '2016-09-29 23:56:41.917301+00', '2017-02-28 12:18:06.911555+00', 17195, 1, NULL, 'ace', '1--::

  All turn P RH | all W dance clw one place ; all turn new person LH | All M dance cclw one place 

9--::

  1c+3c (now on sides) set adv | turn P BH ; Circle4 L to face top & bottom

17--::

  Parallel reels4, 1c+3c finish again on sides

25--::

  All set | All petronella in tandem one position cclw ; All dance interlocking S&Link [All set | All travel one place round, M cclw through the middle, W cast clw] (4,1,2,3)



*note: dance modified in 2016.  Previously [25-26] was All A{1}&R{1}*', 3);
INSERT INTO 'dancecrib' VALUES (3477, '2012-01-22 19:30:27.071284+00', '2020-11-30 22:31:52.018605+00', 6912, 1, NULL, 'ace', '1–::

  1c+2c Set&Rotate (set | cast 1 place clw ; change place RH with P | chase 1 place clw)

9–::

  2c+1c+3c set, turn BH ½, staying close ; set, pull Rsh back and dance to sidelines (to 2x,1x,3x)

17–::

  Circle6 L and back

25–::

  2c+1c+3c set, Petronella Turn to centre line ; repeat to own side (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3673, '2013-01-01 23:01:32.564592+00', '2019-10-03 22:48:26.571824+00', 1426, 2, 82, 'ace', '1- 8::

  1C mirror reels of 3 on own sides (in and down to start)

9-16::

  1C and 2C turn on sides 1½ times (Men RH and Ladies LH); 1C dance between 3C and cast up to 2nd place on own sides

17-24::

  1C and 1st corners Adv &amp; Ret; 1C and 1st corners turn RH

25-32::

  1C and 2nd corners Adv &amp; Ret; 1C and 2nd corners turn LH



', 2);
INSERT INTO 'dancecrib' VALUES (1765, '2012-01-22 19:29:01.201662+00', '2015-01-13 21:41:39.884384+00', 11366, 1, NULL, 'ace', '{{explanation}}

on 2nd chord, 3c+4c cross to opp. sides



1–::

  (1c face 2c & 3c face 4c) ½ Reels4 on the sides ; turn (the same) facing person RH 1¼ into lines across

9–::

  All dance ½ Reels4 across ; turn (the same) facing person RH 1¼  (4,3,2x,1x)

17–::

  1c+4c chase clw half round _while_{4} 3c+2c set and ½ LHA (to 1,2,3x,4x) (no polite turns for 2M & 3M) ; 1c+2c & 3c+4c RHA

25–::

  1c+4c cross RH and cast in (2c+3c to end) (2,1x,4,3x) ; All C turn RH, 2c+3c finish on sideline, 1c+4c finish for

33–::

  1c+4c Poussette (both M start moving forward) (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (2654, '2012-01-22 19:29:51.729758+00', '2015-09-29 12:44:37.232203+00', 11219, 1, NULL, 'ace', '1–::

  All set | 1c+2c ½ RHA _while{2}_ 3c cross RH ; All set (2x,1x,3x) | 2c+3c petronella to midline facing P _while{2}_ 1c cross RH and face out

9–::

  »Weasel reel«: All continuously dance ½ Reel4 on the midline, dancers who reach the end cast clw on own side _{4}_ and rejoin the reel at the other end.  (1c casts ¼ clw _{2}_ | dances ½ reel _{4}_ | and casts clw to 2pl facing in _{2}_) (All others finish as at bar 9.)  Dancers entering and leaving the reel pass Rsh.

17–::

  1c set to P _while{2}_ 2c+3c turn RH ¾ (2,1,3) | 1c turn RH ¾ _while{2}_ 2c+3c set to P ; In facing lines across set up/down | Cnrs set diagonally as 1c turn RH and face 3W in promhold

25–::

  1c+1cnrs Reel3 on 1diag., Rsh to 3W ; on [29-32] 1cnrs continue the reel but 1c dance up, split and cast from top to (2,1,3)



{{explanation}}

On second time through 1c cast directly to 4pl (4c up)', 3);
INSERT INTO 'dancecrib' VALUES (11922, '2019-06-28 21:49:47.206495+00', '2019-06-28 21:49:58.187823+00', 19431, 1, 1645, 'ace', '1-::

  1c+2c & 3c+4c S&Link, 1M & 4W face out ; 1W+4M set adv | &frac12; turn BH & twirl away _while{4}_ 1M & 4W dance &frac12; way cclw round them

9-::

  4M+1M+2W & 1W+4W+3M RHA, 4M+1M & 1W+4W dance down/up sides ; 4M+1M+3W & 1W+4W+2M LHA, 4M & 1W end in 2plx & 3plx, 4W & 1M face 1cnrs

17-::

  H&G chase: 4W & 1M set H&G _while{8}_ 4M & 1W set adv | follow P 2 bars behind, 1c & 4c end on centre line, M facing down, W up

25-::

  1c+4c &frac12; Reel4 ; 4c & 1c turn P 1&frac14; BH to (2,4,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (12999, '2020-07-29 06:24:19.81793+00', '2020-07-29 12:02:16.497524+00', 4632, 1, 202, 'ace', '1--::
  1M+2W & 3M+4W turn RH ¾ | chase clw to places ; Circle4 L (1,2,3,4)
9--::
  1W+2M & 3W+4M turn LH ¾ | chase cclw to places ; Circle4 R (1,2,3,4)
17--::
  1c lead down (2c+3c+4c face down on [20]) ; 1c (4c, 3c & 2c following) lead up into
25--::
  4C Allemande (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (8486, '2015-01-15 11:01:35.705008+00', '2015-01-15 23:43:00.265191+00', 1466, 1, NULL, 'ace', '1--::

  1c Fig8 on own side round 2c & 3c (start inwards, lead RH when possible)

9--::

  1c Fig8 round 2c

17--::

  1c lead down and cross (2c up) ; 1M cast up round 3W and 2W to face 2M _while{4}_ 1W casts up round 3M to face 2W 

25--::

  1c+2c Reel4 across, 1c finish in 2pl (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8482, '2015-01-04 11:16:43.43458+00', '2020-08-31 16:16:23.285292+00', 15311, 2, 81, 'ace', '1- 8::

  1s+2s dance double Fig. of 8, 2s dance up side to start & finish

facing out

  9-16::

  1s+2s+3s dance Inveran reels with all three couples crossing down

from 1st place & up from 3rd place

17-24::

   1s cross RH, cast off, cross down LH between 3s, cast up, pass LSh

to finish facing 1st corners (2s step up on bars 19-20)

25-32::

   1s dance Corners Pass & Turn with 1st corners, then with 2nd

corners, finishing passing RSh to 2nd place own sides

33-40::

   2s+1s+3s circle 6H round and back', 4);
INSERT INTO 'dancecrib' VALUES (8487, '2015-01-15 12:21:28.860022+00', '2015-01-16 00:16:21.884714+00', 9711, 1, NULL, 'ace', '*Form two 4C sets side by side*

1--::

  All set to P | cross RH (centre lines face each other) ; centre lines turn person opposite LH, finish all middle couples facing end couples | Taking hands across both sets, all set to person opposite and face P

9--::

  Repeat [1-8] from new positions (both sets to 1,2,3,4)

17--::

  Both sets: ½ G-Ch ; ½ Reel4 on the sides (both sets to 1x,2x,3x,4x)

25--::

  ½ Reels4 across both sets ; both 1c turn BH, moving down to 4pl (others step up on [31-32]) (both sets to 2,3,4,1 in exchanged places)

', 4);
INSERT INTO 'dancecrib' VALUES (13819, '2021-03-16 12:32:54.554274+00', '2021-03-16 12:42:43.74963+00', 3254, 1, 202, 'ace', '1--::

  1c set | lead down between 3c (2c up) ; cross and cast up into lines3 across, 1W between 2c, 1M between 3c, 1c facing 4cnrs

9--::

  Reels3 across, 1c RSh to 4cnrs. On [15-16] 1c dance LSh round 1cnrs and face 1cnrs

17--::

  4 bars of Set to and Turn Corners into lines3 across. 1W between 2c faces down, 1M between 3c faces up ; 1c set | pass P RSh and face 2cnrs

25--::

  Last 4 bars of Set to and Turn Corners (to 2,1x,3x) ; 1c set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2774, '2012-01-22 19:29:56.866254+00', '2019-02-20 22:54:55.917548+00', 10593, 1, NULL, 'ace', '1–::

  1c lead down the middle and up

9–::

  Mirror Reels3 on the sides, 2c start in and up, 1c+3c cast

17–::

  1c+2c+3c Promenade (1,2,3)

25–::

  1c+2c »Helix«: Both C set passing Rsh | Cast R to own place ; turn P RH ½ | ½ RHA (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3637, '2012-08-19 19:48:20.87546+00', '2015-01-19 21:41:02.756086+00', 14542, 1, NULL, 'ace', '1–::

  1c+2c Poussette

9–::

  1c set | cast (2c up) ; set | cross and face out (2,1x,3)

17–::

  2c+3c Reels3 on sides _while{8}_ 1c Reels3 across, start 1c Rsh to 1cnr, at end 1c cross up/dn RH to 1M facing up, 1W down

25–::

  2c+3c Reels3 across _while{8}_ 1c Reels3 on opposite sides, start 1c Rsh to 2cnr, at end 1c cross RH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8491, '2015-01-16 21:35:00.965867+00', '2018-12-12 20:42:43.010717+00', 15046, 2, 1, 'ace', '1–::

  1c cross RH | 1L+2M turn L 1½ _while_ 1M+2L turn R 1½ |

  1L+3M change places RH _while_ 1M+3L change places LH

9–::

  1c+3c dance The Swirl (3c fin dancing out to own places,

  1c dance in pulling LS back to fin facing 1st corners)

17–::

  1c dance track of Reel4 with 1st corners _while_ 1st corners dance

  ½ turn and twirl twice (1c pass LS to face 2nd corners)

25–::

  1c+2nd corners repeat 17–24 (1c fin w/NH joined in middle facing up,

  1L on 1M''s right)

33–36::

  1c dance up to the top and cast off 2 places (3c up on 35–36)

37–40::

  All set and turn partner RH, melting into …

41–::

  Circle6 (fin 2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (8490, '2015-01-16 21:19:21.82253+00', '2015-01-16 21:19:21.82253+00', 3209, 2, 1, 'ace', '1–::
  1c+2c Circle4 (and back)
9–::
  1c+2c RA+LA
17–::
  1c lead down (RH) crossing over | cast up round 2c ;
  cross LH at top | cast off (2c up)
25–28::
  2c+1c turn RH
29–32::
  2c+1c turn LH', 3);
INSERT INTO 'dancecrib' VALUES (3025, '2012-01-22 19:30:07.364974+00', '2020-09-27 08:24:46.247583+00', 14274, 1, NULL, 'ace', '1–::

  1c turn RH ½ and 1W twirls under arms to face M side | 1c (1W leading) cast off round 2M (2c up), cross, cast off round 3W (3c up and in), finish 3c facing 1c NHJ (2,3,1x)

9–::

  3c+1c set | ½ RHA, finishing on sidelines, 3c facing M side, 1c facing W side ; Parallel ½ Reels3 on the sides, 1c Lsh to 2c (3x,1,2)

17–::

  3c+2c dance as if leading couple in a 3c knot, into exchanged places (3c moving first upwards and to M side).  Meanwhile 1c turn RH ½ and twirl to towards 2cnr positions ; set and finish in 2plx | turn LH ½ to finish W in front of M facing W side  (2,1x,3x)

25–::

  1c in tandem +3c ½ Rsh Reel3 across, 1c finish near middle in 2plx ; 1c turn BH 1 ½ (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8493, '2015-01-16 22:12:57.020703+00', '2020-09-08 17:10:33.609377+00', 9297, 2, 1, 'ace', '1–::

  1c set | cast off (2c up) ;

  1c set | turn ¾ LH (fin in middle, 1M facing up, 1L down)

9–::

  1M+2c & 1W+3c Reels3 across (1c give LS to person on L)

  [on 15–16, 1c turn LH to face 1st corners]

17–::

  1c turn C, P, C, P (fin facing 1st corners)

25–::

  Reels3 w/corners (1c give RS to 1st corner, dance to 2pl own sides on 31–32)', 3);
INSERT INTO 'dancecrib' VALUES (8492, '2015-01-16 21:43:45.644631+00', '2020-10-07 16:29:21.824259+00', 15320, 2, 1, 'ace', '1–4::

  1c+2c advance 1 step (skip-change), set on LF (PdB) | retire 1 step (skip-change),

  set on LF (PdB) _while{4}_ 3c cross RH | cast up 2 places

5–8::

  2c followed by 1c lead down the middle |

  1c followed by 2c lead up the middle (fin facing

  partners w/BH joined) _while{4}_ 3c cross RH at top | cast off 2 places

9–::

  1c+2c poussette (w/extra half turn on 7, retire to opposite sides on 8)

17–::

  2c dance ½ fig 8 down round 1c ; 1c dance ½ fig  down round 3c

25–::

  Mirror reels3 on own sides (1c dancing in and up to begin)', 3);
INSERT INTO 'dancecrib' VALUES (13687, '2021-02-22 19:05:55.65997+00', '2021-02-22 19:05:55.65997+00', 20227, 2, NULL, 'ace', '*Two circles, men inside facing out to partners facing in.*



1-4:: 3 steps away from your partner, clap, 3 steps back, keep to the left.



5-8:: In Balance-in-Line all set, turn person on the left half way



9-12:: All set, turn person on the right half way



13-16:: Turn third partner with the left ready to start again.

', 0);
INSERT INTO 'dancecrib' VALUES (12680, '2020-03-22 01:04:15.86237+00', '2020-09-28 09:30:21.663906+00', 19871, 1, 202, 'ace', '1--::

  1W & 2M set | cast to midline facing up/down ; turn RH into exchanged places

9--::

  1M & 2W set | cast to midline facing up/down ; turn LH into exchanged places (2x,1x)

17--::

  1c (2c following) lead down. On [4] Men dance below P who turn under joined arms ; 2c (1c following) lead up (2,1)

25--::

  Circle4 and back', 2);
INSERT INTO 'dancecrib' VALUES (3483, '2012-01-22 19:30:27.347236+00', '2021-02-22 20:13:29.89334+00', 9505, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c DblFigs8 (1c+3c cross, 2c+4c cast up to begin) (1,2,3,4,5)

9–::

  1c+3c lead down {3} (2c+4c up) , turn RH and cast round 4c / 5c to face 1cnr

17–::

  1c+3c set to and turn 1cnr BH, repeat with 2cnr

25–::

  2c+1M & 1W+4c+3M & 3W+5c RHA (»Teapots and samovar«) 1c+3c finish BtB facing own side for ; All set as in DTr | 1c+3c cast off (4c+5c up) (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (2785, '2012-01-22 19:29:57.305198+00', '2020-09-01 11:18:39.817701+00', 4371, 1, NULL, 'ace', '1–::

  1c+2c set | RHA | 1c cast to 1cnrs (2c up)

9–::

  1c+1cnrs ½ Reel4 ; 1c+2cnrs ½ Reel4, 1M/1W finish at top/bottom between 3c/2c

17–::

  S&Link3 twice, into facing lines across (1W above, 1M below)

25–::

  2c+3c R&L _while{8}_ 1c Fig8 across, starting Lsh to 4cnr , finish (2,1,3)

33–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (8478, '2014-12-09 11:03:41.772824+00', '2020-09-21 19:11:57.572673+00', 13785, 2, 1007, 'ace', '1-8:: 1C+2C & 3C+4C RHA and LHA (finish on diag. ready for 1/2 poussette 

9-12:: 1C+2C & 3C+4C 1/2 modified poussette (eg end is similar to opening out at end of tourbillon, finish on M''s side 1M, 1W, 3M, 3W, on W''s side 2M, 2W, 4M, 4W);

13-16:: 1C+2C & 3C+4C set and overlink (finish lines of four across the dance)

17-24:: All Reels of 4 across the dance

25-32:: 1C+2C & 3C+4C Isobirl

33-36:: 2W+1M & 4W+3M followed by partner dance CW chase round each other to progressed positions (2,1,4,3); 

37-40:: All take hands on sides set, 1C+4C link (finish 2,4,1,3).', 0);
INSERT INTO 'dancecrib' VALUES (8499, '2015-01-24 00:51:55.630127+00', '2018-05-05 22:25:28.274036+00', 15422, 1, NULL, 'ace', '1--::

  1c+3c dance down 3 (4c up) ; 4c+1c & 5c+3c Circle4 L ( ,2,4,1,5,3) (1pl is empty)

9--::

  1c+3c turn P RH moving to between 4c/5c | on both sides 1c turn 4c & 3c turn 5c LH ; 1c+3c turn P RH moving up to between 2c/4c | on both sides 1c turn 2c & 3c turn 4c LH (corners finish in 2pl, 4pl, 5pl)

17--::

  1c+3c dance up and cast off round 2c/4c (2c+4c up) ; 1c+3c turn LH 1½ to face 1cnrs 

25-40::

  In each “square” dance to each corner and set 8 times.  At the end, 1c+3c loop R onto midline (3M,1M,3W,1W), 2c+4c+5c finish in diagonally opposite places 

41--::

  5c+4c+2c chase ½ clw _while{4}_ 3c+1c ½ Reel4 on midline, the middle two finish with loop R to face P ; 1c+3c Turn LH ¾ and cast off (4c+5c up) (2,4,1,5,3)

', 4);
INSERT INTO 'dancecrib' VALUES (8498, '2015-01-23 00:02:31.875909+00', '2015-01-23 01:22:36.79128+00', 10077, 1, NULL, 'ace', '1--::

  1+3c set | dance between 2c/4c (2c+4c up) | cast on own side behind 3c/5c and lead up to face 2W/4W in promhold

9--::

  1c & 3c with 2cnrs diagonal Reel3

17--::

  1c+2M & 3c+4M LHA (1W leading) ; 1c+4W & 3c+5W RHA to (2,1x,4,3x,5), 1c & 3c facing out

25--::

  1c+3c turn their 2cnr LH ; turn P RH ¾ | cast off one (4c+5c up)  (2,4,1,5,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14831, '2022-05-18 12:44:54.186167+00', '2022-05-18 12:45:17.454833+00', 20860, 2, NULL, 'ace', '*Partners stand side by side facing across the other couple*



 _Foursome Reel – 32 bar Strathspey_

1-8::

  Reel of 4 across. W pass L shoulder to begin. M wait 2 bars and join in the reel. M finish by curving in back to back to face opposite W.

9-16::

  All set.

17-24::

  Reel of 4 across. M finish back to back to face partner.

25-32::

  All set.  



_Half Reel of Tulloch – 64 bar Reel_



1-8::

  M pas de basque out to the side lines passing partner by right on bars 1-2. As W advance towards each other to set in centre.

9-12::

  W turn R once and half in Tulloch hold.

13-16::

  W turn L twice in Tulloch hold to face opposite man.

17-24::

  All set.

25-28::

  All turn R once and half in Tulloch hold.

29-32::

  All turn L twice in Tulloch hold. M finish facing in centre.

33-64::

  Repeat bars 1-32 above but with M in centre and on bars 61-64 partners turning L twice and a quarter in Tulloch hold to finish beside partners on opposite side of the set.', 3);
INSERT INTO 'dancecrib' VALUES (15187, '2022-10-25 16:22:37.163792+00', '2022-10-25 16:23:00.847952+00', 12019, 1, 202, 'ace', '1--::

  1c cross RH | cast off ; dance down between 3c | cast up to 2plx (2,1x,3)

9--::

  All turn P RH ½, face P ; cast R to exchanged places (to 2x,1,3x) ; all turn RH into promhold 1c facing up and 2c & 3c facing down (2x,1,3x)

17--::

  3C Circulating Allemande (3x,1,2x)

25--::

  1c ½ Fig8 up round 3c ; all turn P BH 1½ (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (2378, '2012-01-22 19:29:34.370114+00', '2015-01-19 22:10:25.525912+00', 11985, 1, NULL, 'ace', '1–::

  1c set | cross ; cast (2c up) | turn LH to 1cnr

9–::

  1c+1cnrs in promhold promenade cclw halfway and face in diagonally NHJ _while{4}_ 2cnrs turn LH to places ; 1c+1cnrs set diagonally | pass person opposite LH, 1cnrs to places as 1c loops L to take 2cnr in promhold on the R

17–::

  Repeat with 2cnr to (2,1,3), 1c facing out

25–::

  2c+1c+3c Lsh Reels3{6} on the sides | 1c+3c change places EH (1c pass outside) (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (8089, '2013-10-15 11:07:54.969175+00', '2019-02-04 09:57:54.47925+00', 15217, 1, NULL, 'ace', '1–::

  1c cast behind 2c, dance between 3c, cast up, dance up between 2c, cast to 2pl (2c up)

9–12::

  1c advance, turn BH ½ and retire _while_{4} 2c+3c A&R (2,1x,3)

13-24::

  R&L for 3 couples , finish 1c facing 1cnr

25–::

  1c+1cnrs set as H&G {2} | 1c turn RH to face 2cnr ; 1c+2cnr set as »H&G« {2} | 1c turn RH to 2pl (and face out to cast) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14753, '2022-04-10 17:40:41.523831+00', '2022-04-12 22:09:57.402085+00', 17420, 1, 1645, 'ace', '1--::
  2c Petronella | set ; all Petronella (2c to opp side, 1c & 3c to centre line) | set
9--::
  *Sash Pin Reel:* 2c (sides) set | set adv RSh to P ; &frac12; turn RH | curve R out to starting place  
  _while{8}_ 1W & 3M (ends) dance track of &frac12; Reel4 ; chase &frac12; way clw to starting place  
  _while{8}_ 1M & 3W (middles) dance &frac14; Reel4 | chase &frac12; way clw | pass LSh & turn &frac14; LH into line across, 1M/3W are now facing 2W/2M (the new "ends"), 1M & 3W are rotated &frac14; L from where they started
17--::
  Repeat Sash Pin Reel from new places to end on centre line, 1M/3W now facing 3M/1W
25--::
  Repeat Sash Pin Reel to end in line across, 1M/3W now facing 2M/2W
33--::
  Repeat Sash Pin Reel to end on centre line in places as at bar 9, 1c & 3c facing P
41--::
  1c+3c &frac12; Reel4 on centre line ; 3c & 1c turn &frac34; RH _while_ 2c set | 3c cast off _while_ 2c cross up RH (2,3,1)
', 2);
INSERT INTO 'dancecrib' VALUES (11658, '2019-03-10 17:10:32.524526+00', '2019-03-10 17:11:21.243719+00', 18093, 1, 202, 'ace', '1--::

  1c+2c Set&Rotate (2,1,3)

9--::

  1c Fig8 R, LSh to 1cnrs. On [16] 1c pivot R facing own side into DTr[pos]

17--::

  DTr. 1c in 2pl face out, 1M/1W up/down (2,1,3)

25--::

  Reels3 on sides, 1c RSh to 3cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3799, '2013-07-13 15:56:08.747333+00', '2020-12-25 12:32:21.834619+00', 12279, 1, NULL, 'ace', '1–::

  1W long cast to 2W pl (2W up) ; 1M cast and cross to 2W place (2M up) _while{4}_ 1W ½ Fig8 round 3M (2,1x,3)

9–::

  Reels3 on the sides, 1M goes out and R, 1W in and L

17–::

  1c meet in the middle and lead down {3}, change sides and face up, M crossing below W who passes under arms, 1c dance up behind 3c and face 1cnr

25–::

  Corners pass and turn (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2451, '2012-01-22 19:29:39.559879+00', '2020-09-27 08:31:16.460892+00', 14276, 1, NULL, 'ace', '{{explanation}}

3c + 4c start on opp. side: 1,2,3x,4x



1–::

  1c+4c set | turn P ½ RH into allemande hold ; dance to meet (2c+3c step to ends) | cast out to sidelines (2,1x,4,3x)

9–::

  2c+1c M-Chain _while_ 4c+3c L-Chain, 1c+4c finish in the middle facing diagonally out (2,1x,4,3x)

17–::

  1c+4c set ½ »H&G for 4« (set to cnr, finish between two cnrs | set to P, finish BtoB in middle facing next cnr) ; Parallel Rsh ½ Reels4 on sidelines, at the end 1c+4c turn BH ½ and open to sideline facing in (1c on M side, 4c on W side, M on the R)

25–::

  1c+4c (facing across) S&Link ; 1M+4M turn RH 1½. all C finish NHJ in middle facing end or middle (3x,4,1x,2)

33–::

  3c facing 4c & 1c facing 2c S&Link ; 4c+1c ½ Fig8 round end cpl (3,4,1x,2x)



{{explanation}}

this dance is danced twice through only', 3);
INSERT INTO 'dancecrib' VALUES (9627, '2017-03-01 00:36:36.056835+00', '2020-02-01 22:09:27.697032+00', 10384, 2, 1824, 'ace', '1-8:: 1s+2s dance 4H across with RH back LH while 3s+4s dance 4H across with LH back RH.

9-16:: 1s+2s and 3s+4s dance rights & Lefts

17-18:: 1m & 2m change places LH while 1L & 2L change places RH

19-20::  1m & 3m change places RH while 2L & 3L change places LH

21-22::  2m & 3m change places LH while 2L & 3L change places RH

23-24::  All set

25-32:: 3s with 2s and 1s with 4s dance tournée', 5);
INSERT INTO 'dancecrib' VALUES (13688, '2021-02-22 19:09:19.457188+00', '2021-02-22 19:09:19.457188+00', 20228, 2, NULL, 'ace', '*Couples facing round the room anticlockwise.*



1-4:: 2x heel-toe (men start with left, partners with right), 4 slip step forward



5-8:: Repeat backwards



9-12:: Clap 3x: right-left-knee-on partners both hand



13-16:: Polka

', 0);
INSERT INTO 'dancecrib' VALUES (14075, '2021-06-17 00:40:53.599651+00', '2021-06-17 00:59:44.115251+00', 15871, 1, 202, 'ace', '1--::

  1c turn RH | cast off (2c up) ; ½ Fig8 R round 1cnrs (2,1x,3)

9--::

  Reels3 on sides, 1c RSh to 2cnrs (2,1x,3)

17--::

  All cross RH | chase clw into facing lines3 across ; all cross RH up/down | chase clw to sides (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8502, '2015-01-25 16:56:39.566473+00', '2015-01-25 16:56:39.566473+00', 15274, 2, 160, 'ace', '1–::
 1C set, cast 1pl ; L up, M down half fig.8 across - end B-to-B facing 1cnrs.
9–::
 Set to & turn 1cnr BH - face 2cnr ; set to & turn 2cnr BH - end 1M btwn 2C facing up and 1L btwn 3C facing down!
17–::
 1C cast to 2pl own sides, Rsh Reel3 on own sides (6 bars!).
25–::
 2 1 3 adv 1 + retire 1, 2C 1C turn ptnr BH ; hands 4 to the left.', 0);
INSERT INTO 'dancecrib' VALUES (8503, '2015-01-26 11:47:15.604911+00', '2015-01-26 11:47:15.604911+00', 15365, 1, NULL, 'ace', '1--::

  All set | turn BH ½, finish 1c facing 3c NHJ and 2c face out in 2plx ; Mirror half Reels3 on sides (2c out and up), 2c+1c add a final loop to finish (3x,1x,2x) with 1c in DTr position facing opposite side

9--::

  “Petronella DTr” (1c dances DTr to finish facing 1cnr, while 3c+2c Petronella 1 place cclw on [3-4] and [6-8], to own places)

17--::

  1c+1cnrs “Pass and Back-to-Back” (“Turn” replaced by “Dance BtB”) ; 1c+2cnrs repeat (2,1,3)

25--::

  Circle6 and back (2,1,3) 

', 3);
INSERT INTO 'dancecrib' VALUES (1578, '2012-01-20 13:06:12.745737+00', '2018-01-13 23:00:31.440373+00', 13450, 2, 29, 'ace', ' Forget Me Knot (3x32S)3C set	      Brian Youngman

 

1-8::  1C set, cross RH, cast one place (2C step up), turn RH to face 1st corners.

9-12::  RS pass & turn with 1st corners, (corners turn RH) end 2nd place on own side, 1L facing down and 

      1M facing up.

13-16:: 1/2 reel of 3 on the sides, RS to begin.  On bar 16 1C turn LH to face 2nd corner

      positions.

17-20:: LS pass & turn with 2nd corner positions,(corners turn LH) end 2nd place own sides, 1L facing up and

      1M facing down.

21-24:: 1/2 reel of 3 on the sides, LS to begin.  On bar 24 1C turn RH to end in 2nd place

      opp side facing out.

25-30:: 1C cast, cross up RH,cast to 3rd place, while 3C cross up LH, cast,cross up RH to 

      2nd place. (3/4 of double fig of 8)

31-32:: 1C turn BH once round to place.', 4);
INSERT INTO 'dancecrib' VALUES (3194, '2012-01-22 19:30:15.201322+00', '2015-01-27 23:22:15.773994+00', 9725, 1, NULL, 'ace', '1–::

  1c set | set advancing ; turn RH 1½ moving down to 2pl BtB facing opposite side (2c up)

9–::

  DTr, finish facing 1cnr

17–::

  1c dance round 1cnr Rsh, pass P Rsh in the middle and dance Rsh round 2cnr to 2plx

25–::

  All chase clw {8} ; but on [29] 1c break into turn RH to 2pl



{{explanation}}

»The Meeting, The Kiss; Two inter-twining hearts, The Ring«', 2);
INSERT INTO 'dancecrib' VALUES (3532, '2012-01-22 19:30:29.595328+00', '2015-01-28 10:51:12.771045+00', 7124, 1, NULL, 'ace', '{{explanation}}

Pronounced: Whittader



1–::

  1c+2c S&Link | RHA (2,1,3)

9–::

  1c set, ½Reels3 across (Lsh to 1cnr) {3}, into ½Reels3 on the sides (Rsh to 2cnr) {3}, (to 3x,1x,2x) (loops permitted)

17–::

  S&Link3, into lines across ; all turn opposite person RH

25–::

  S&Link3 to sidelines, all turn P RH', 2);
INSERT INTO 'dancecrib' VALUES (2083, '2012-01-22 19:29:18.877158+00', '2022-05-20 22:12:28.104917+00', 13852, 1, NULL, 'ace', '1–::

  All G-Chain

9–::

  All Set | cross ; Set | Turn RH ½ into

17–::

  1c+2c+3c Allemande (3,2,1)

25–::

  3c set | cast (2c up) ; All A&R

33–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (8513, '2015-02-01 21:46:08.20705+00', '2015-02-01 21:46:08.20705+00', 14447, 1, NULL, 'ace', '1--::

  All set | turn BH ½ to opposite side ; repeat (to 1,2,3)

9--::

  1c cross down into Mirrror Reels3 on the sides (1x,2,3)

17--::

  1c dance down NHJ | change sides, M crossing below W who passes under their joined arms ; 1c Turn BH | dance up to (1,2,3)

25--::

  1c+2c The Knot (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2301, '2012-01-22 19:29:30.623432+00', '2018-04-02 17:29:52.56145+00', 2394, 1, NULL, 'ace', '1–::

  1c cross RH | cast off 2 (2c+3c up) ; 1c cross RH and cast up (3c down) to (2,1,3)

9–::

  1c set passing Lsh | turn 1cnrs BH ; ½Reel4 with 2cnrs, at end 1c curve R to between end cpl (M above facing W below)

17–::

  1c set passing Lsh, turn 4cnr (2cnr persons) BH ; ½Reel4 with 1cnrs, at end curve R to end as (3x,1x,2x)

25–::

  All S&Link3 ; repeat (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3137, '2012-01-22 19:30:12.863099+00', '2015-01-28 22:25:39.581837+00', 5667, 1, NULL, 'ace', '*Strathspey*

1–::

  1c+3c S&Link ; cross RH (M moves L, W moves R) pass between that side couple and cast round own corner into a longwise set up/down, 2c facing 4c in the middle and 1c+3c facing P at the ends. 

9–::

  In lines of 4, all set | [1W+3W Petronella into midline BtoB ; Petronella to P''s place | cast clw to the other end of the set] _while{6}_ [1M+3M cast clw  to other end ; Petronella | Petronella (same route)] 1c+3c ending in the diagonally opposite places (3c at top, 1c at bottom, 2c+4c in own places)

17–::

  Reels4 on the sidelines

25–::

  On the sidelines the Middles turn the Ends BH to same positions, facing across | All set, 1c+3c advancing, finish in a square set facing P ; All turn P RH ¾ | All promenade clw one place (4,3,2,1).



*Reel*

33–::

  4c+2c (top and bottom) S&Link ; 4c+2c cross and dance between 1c+3c who dance apart, 4c+2c turn corner EH, finish in square set, all facing P (4,3,2,1)

41–::

  2c+4c BHJ set (start on inside foot) | slip across to exchanged places, the M passing BtoB ; set | slip back to own place, the W passing BtoB.

49–::

  All set RHJ | M set while W turn R about under joined arms ; all turn RH 1¼ to promhold, M inside

57–::

  All Promenade cclw once round (4,3,2,1)



Repeat [1-64], to (1,2,3,4) 

', 3);
INSERT INTO 'dancecrib' VALUES (8506, '2015-01-30 13:09:52.536882+00', '2015-01-30 13:24:53.719356+00', 10104, 1, NULL, 'ace', '1--::

  1c dance behind own lines and back

9--::

  1c cross RH, cast off one, cross LH, cast up to places

17--::

  1c+2c half R&L ; set, cross RH

25--::

  1c+2c set facing diagonally, set to P ; 1c+2c turn RH

', 3);
INSERT INTO 'dancecrib' VALUES (8507, '2015-01-30 18:00:57.024876+00', '2015-01-30 18:00:57.024876+00', 4873, 1, NULL, 'ace', '1--::

  1M+2W set advancing | turn RH to places ; 1W+2M set advancing | cast R round standing dancers to places

9--::

  1c+2c chase clw to (2x,1x.3) ; 1c+2c turn P 1½ (2,1,3)

17--::

  2c+3c set advancing | turn P RH to places ; 1c set advancing | turn RH ¾, finish Lsh to Lsh, M facing up, W dn.

25--::

  1c dance out the ends and cast L to 2pl ; 1c turn LH _while{4}_ 2c+3c turn RH on sideline (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8508, '2015-01-30 21:48:21.535779+00', '2015-01-30 22:04:37.747539+00', 9231, 1, NULL, 'ace', '1--::

  1c cross down into Mirror Reels 3 on opposite side, finish 1c facing 3c, both NHJ (1x,2,3)

9--::

  1c+3c A&R ; with opposite turn RH ½ and twirl, to exchanged places, again NHJ (3,2,1x)

17--::

  All advance {1} to circle joining hands high, stamp R foot 3 times | retire to same places and stamp 3 times ; 3c turn P RH 1½ _while{4}_ 1c turn 2c on sides RH 1½  (2,3,1)

25--::

  Circle6 and back (2,3,1)



*Drewry’s Note: This dance should not be taken too seriously.*

', 5);
INSERT INTO 'dancecrib' VALUES (3182, '2012-01-22 19:30:14.757247+00', '2015-01-30 22:35:48.834793+00', 8154, 1, NULL, 'ace', '{{explanation}}

Couples in circle RR in Ballroom hold, men on inside



1–::

  3 steps sideways (W Right, M Left), stamp both feet ; 2 steps back | two steps towards centre (M start L foot, W R foot)

9–::

  2 steps back in | W turns about on the spot under the joined hands ; Waltz onwards round the room', 2);
INSERT INTO 'dancecrib' VALUES (13689, '2021-02-23 00:57:36.570506+00', '2021-02-23 01:01:01.195739+00', 8919, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 2c+1M & 1W+3c RHA (2,1x,3,4)

9--::

  1c cross LH | cast off (3c up) ; 3c+1M & 1W+4c LHA (2,3,1,4)

17--::

  2c+3c & 1c+4c DblFig8, 2c & 1c crossing down (2,3,1,4)

25--::

  1c cross RH | cast off (4c up) ; 1c ½ Fig8 up round 4c (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2459, '2012-01-22 19:29:40.088976+00', '2021-06-17 10:00:31.243857+00', 3046, 1, NULL, 'ace', '1–::

  1W casts off 2, 1M following, to 3pl opposite sides (2c+3c up) ; 1M casts up 2, 1W following, to own places (2c+3c down)

9–::

  1c cross RH, cast off one (2c up) ; cross LH, cast off one and lead up to 1cnrs

17–::

  1c set to and turn corners

25–::

  Reels3{6} on the sides | 1c cross (2,1,3).', 2);
INSERT INTO 'dancecrib' VALUES (9630, '2017-03-03 23:11:56.750302+00', '2017-03-03 23:11:56.750302+00', 17627, 2, NULL, 'ace', '1-4::

  1st and 3rd couple set and, giving right hands, cross down to 2nd and 4th place respectively, on the opposite side.  2nd and 4th couple step up on bars 3-4.

5-8::

  1st and 3rd couple cast off one place and dance up to finish back to back facing opposite side of the dance in 2nd and 4th place respectively.

9-16::

  1st couple with 2nd and 4th couple, 3rd couple with 4th and 5th couple dance double triangles.  1st and 3rd couple finish facing opposite sides.

17-20::

  1st couple with 2nd man and 4th woman, 3rd couple with 4th man and 5th woman, dance corner pass and turn,  2nd man and 4th woman, 4th man and 5th woman giving right hands to turn.  1st and 3rd couple pass partner with right shoulder to face 2nd woman and 4th man, 4th woman and 5th man respectively.	

21-24::

  1st couple with 2nd woman and 4th man, 3rd couple with 4th woman and 5th man, dance corner pass and turn,  2nd woman and 4th man, 4th woman and 5th man giving right hands to turn.  On bar 24 1st and 3rd couple finish in 2nd and 4th place, respectively, facing own side with partner on the right.

25-26::

  1st and 3rd couple, giving right hands, turn partner ½ way round.  1st woman and 3rd man join left hands to form a line in the center of the set.

27-28::

  1st and 3rd couple balance in line.

29-32::

  1st and 3rd couple turn right hand ¾ way round and cast off to 3rd and 5th place, 

respectively.  4th and 5th couple step up on bars 31-32.	

', 5);
INSERT INTO 'dancecrib' VALUES (8139, '2013-12-25 23:20:20.36317+00', '2016-01-05 12:00:13.077793+00', 15177, 1, NULL, 'ace', '1–::

  1c turn RH ; cast (2c up) | cross LH and face out (2,1x,3)

9–::

  Reels3 on the sides, Lsh to 2cnr, 1c finish facing 1cnr

17–::

  ½ Reel4 with 1cnrs, pass Rsh ; ½ Reel4 with 2cnrs, finish (3x,1x,2x)

25–::

  All turn P RH ; All chase ½ clw (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (9631, '2017-03-04 09:05:34.64342+00', '2019-02-03 21:17:44.596103+00', 17629, 1, 202, 'ace', '1--::

 1c+2c set | cross RH ; repeat

9--::

 1c lead down and up, 2c step in on [8]

17--::

 1c+2c allemande

25--::

 2c+1c Circle4 and back', 2);
INSERT INTO 'dancecrib' VALUES (5237, '2013-08-21 08:31:03.112673+00', '2023-02-04 01:23:05.516063+00', 6957, 3, NULL, 'ace', '1-8::
    1L followed by 2L +3L cross & dance down behind 1+2+3M cross & dance
    back to places
9-16::
    1M+2M+3M repeat dancing round behind Ladies back to place
17-24::
    1M+2M also 1L+2L, set to each other & change places RH, set & change
    back LH ready for ...
25-32::
    1s+2s dance Poussette, 1s end BtoB in centre facing own sides ready
    for Double Triangles
33-40::
    1s dance Double Triangles & end side by side facing out on Ladies''
    side between 2L+3L
41-48::
    1s lead out between 2L+3L, cast 1L up & 1M down, meet in middle &
    lead out between 2M+3M, 1s cast 1L up & 1M down to end in 2nd place
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (2186, '2012-01-22 19:29:24.594012+00', '2015-02-01 12:15:10.547798+00', 14388, 1, NULL, 'ace', '1-4::

  1c+4c cross RH, cast to middle (2c+3c step to end) (2,1x,4x,3)

5-12::

  1c+4c full fig8 round own end cpl

13-16::

  1c & 4c dance to own end and turn end cpl EH ¾ (W turns M, M turns W) (2,1x,4x,3)

17–::

  All set | 1c+4c ½RHA and hold P ; 4c+1c turn RH

25–::

  All Circle8 and back (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3000, '2012-01-22 19:30:06.340152+00', '2015-10-29 23:07:55.553015+00', 9640, 1, NULL, 'ace', '1–::

  1c+2c RHA, 1W faces out ; 1W with 1M following, cast off 2 and cross (2c+3c up) (2,3,1x,4)

9–::

  2c+3c+1c Circle6 and back, finish 2c facing 1c NHJ

17–::

  2c+1c R&L up/dn, 1c finish facing in and R (2,3,1x,4)

25–::

  1c ½ Fig8 R (M up, W down), meet in 3pl facing down ; 1c turn 4c EH 1½ (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (8509, '2015-02-01 20:49:34.872276+00', '2015-02-01 20:49:34.872276+00', 15929, 1, NULL, 'ace', '1--::

  1c set | cross RH ; cast off (2c up) | 2c+1c+3c Adv{1} & Ret{1} 

9--::

  Mirror Reels3 on the sides, 1c starts in and up (2,1x,3)

17--::

  2c+1c L-Ch (2,1x,3)

25--::

  1c dance between 3c and cast up ; dance between 2c and cast off (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8510, '2015-02-01 21:07:02.092734+00', '2015-02-01 21:07:02.092734+00', 15956, 1, NULL, 'ace', '1--::

  1c+2c the Tourbillon, 1c pass Rsh on [7-8] and face out (2,1,3)

9--::

  Reels3 on the sides, 1c Rhs to 3cnr (2,1,3)

17-28::

  R&L for 3 couples (2,1,3)

29-32::

  2c+1c Circle4 L

', 3);
INSERT INTO 'dancecrib' VALUES (8512, '2015-02-01 21:33:18.349939+00', '2015-02-01 21:33:18.349939+00', 15958, 1, NULL, 'ace', '1-4::

  All set | 1c cast off (2c up) 

5-16::

  2c+1c+3c R&L for 3 couples

17--::

  2c+1c+3c Promenade, at end 1c face 1cnrs

25--::

  1c Set “H&G”, finish (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8515, '2015-02-01 23:22:28.569837+00', '2015-02-01 23:22:28.569837+00', 8546, 1, NULL, 'ace', '1--::

  1W+2M dance BtoB ; 1M+2W repeat

9--::

  1c lead down the middle and up

17--::

  1c set | cast off (2c up) ; 2c+1c+3c A&R

25--::

  All Circle6 and back

33--::

  All turn P RH ; repeat LH

', 3);
INSERT INTO 'dancecrib' VALUES (8511, '2015-02-01 21:25:37.607479+00', '2015-02-01 22:13:44.030827+00', 15957, 1, NULL, 'ace', '1--::

  All Circle6 and back

9--::

  1c+2c S&Link ; 1c cross RH | cast off (2c up) (2,1x,3)

17--::

  2c+1c DblFig8 (2,1x,3)

25--::

  1c cross below 3c and cast up ; 1c turn RH (2,1,3) (alternative: All turn P RH)



*On second repeat, 1c should finish at the bottom to allow 4c to enter the circle.*', 3);
INSERT INTO 'dancecrib' VALUES (11925, '2019-06-29 16:58:22.908293+00', '2019-06-30 03:19:18.791593+00', 19463, 1, 202, 'ace', '1--::
  2c & 4c set advancing swiveling R into DTr position facing own sides | all dance 6 bars of Double DTr. 2c & 4c face 1cnrs
9--::
  Reels4 on 1diag. Pass P LSh to face 2cnrs
17--::
  Reels4 on 2diag to own sides (1,2,3,4,5)
25--::
  1c+2c & 3c+4c RHA ½. 2M faces out (to 2x,1x,4x,3x,5) | 1c+4c & 3c+5c LHA ½. 5W faces out (to 2x,4,1,5x,3) ; 2c (2M leading) chase clw to 5pl (4c up) _while{4}_ 5c (5W leading) chase clw to 2pl (4,5,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (13821, '2021-03-16 23:16:38.84291+00', '2021-03-17 15:43:06.609009+00', 4529, 1, 202, 'ace', '1-4::
  1c long cast to 2pl (2c up)
5-12::
  Reels3 across, 1c RSh to 2cnrs (2,1,3)
13-16::
  1c turn P LH 1½ and face 1cnrs
17--::
  1c turn 1cnrs RH, pass P RSh ; turn 2cnrs RH, pass P RSh to 2pl (cnrs dance 4 bars) (2,1,3)
25--::
  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (13000, '2020-07-29 07:01:05.620176+00', '2020-07-29 11:04:20.338565+00', 4149, 1, 202, 'ace', '1--::
  1c+2c RHA ; LHA. 1c & 2c in centre face up (1,2)
9--::
  1c dance up {1} and cast off _while{4}_ 2c dance up and loop to 1pl (to 2,1) ; 2c & 1c turn P RH (2,1)
17--::
  1c lead down {3}, turn P RH ½ {1} ; lead up to 2plx (2,1x)
25--::
  1W+2W cross RH | 1W+2M & 1M+2W cross LH ; 1W+2W cross RH | 2c cross LH (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (13822, '2021-03-17 06:58:05.306111+00', '2021-03-18 19:01:01.52191+00', 10858, 1, 202, 'ace', '1--::
  1c+2c & 3c+4c The Knot (2,1,4,3)
9--::
  2c+1c & 4c+3c Circle4 R and back
17--::
  2c+1c & 4c+3c Allemande (1,2,3,4)
25--::
  Circle8 L (4x,3x,2x,1x) ; all Turn P RH 1½ (4,3,2,1)
33--::
  4c+3c+2c ½ Gr-Chain ; set | cross RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13287, '2020-10-19 20:54:25.520094+00', '2021-04-20 18:58:36.044891+00', 20131, 2, 963, 'ace', '1-8::  
  1c flwd by 2c dance down: 2c flwd by 1c dance up, cast to orig plc  
9-24::  
  1&2c dance red house reels to progress; 1c+2M Reel3 on M sideline (1M & 2M pass Lsh to begin, 1W entering below them ; 1M+2M end in exchanged places, 1W in own place; 1c+2W Reel3 on W sideline (1W & 2W pass Rsh to begin, 1M entering below them, 1W+2W end in exchanged places, 1m facing out (2,1)  
25-32::  
  1m, flwd by 1w, cast up around 2m & down btwn 2s: 1m turn 1w BH 1-1/4 to 2nd plc  
  ', 5);
INSERT INTO 'dancecrib' VALUES (13690, '2021-02-23 01:25:15.077694+00', '2021-02-25 00:16:05.574948+00', 20229, 1, 202, 'ace', '1--::

  1c+2c change places EH, 1c in and down | 1c+3c change places EH, 1c out and down (to 2,3,1) ; 1c lead up between 2c | cross and cast to face 1cnrs (3c down)

9--::

  Set to And Turn Corners. On [15-16] 1c turn 2cnrs BH to between ends facing 3cnrs

17--::

  Reels3 across, 1c LSh to 3cnrs. 1c pass P RSh to 2pl (2,1,3)

25--::

  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (13966, '2021-04-20 00:06:20.27597+00', '2021-04-20 15:56:31.909945+00', 20330, 1, 202, 'ace', '*On 2nd chord, 4c+5c+6c cross to opposite side (1,2,3,4x,5x,6x)*



_Strathspey_

1--::

  1c+2c & 3c+4c & 5c+6c The espagnole, dancers on Wside crossing to Mside (2,1,4x,3,6x,5x)

9--::

  2c+1c & 4c+3c & 6c+5c S&Link ; 1c+2c & 5c+6c RHA _while{4}_ 3c turn P RH | set _while{4}_ 4c cross RH | set (1,2,3,4,5x,6x)

17--::

  1c set twice ; cross down between 2c, cast off behind 3c to 6plx (2c+3c+4c+5c+6c up) (2,3,4,5x,6x,1x)

25--::

  2c+3c+4c & 5c+6c+1c Inveran Reels, 2c & 5c crossing down (2,3,4,5x,6x,1x)  



Repeat twice in Strathspey time then three times in Jig time.', 2);
INSERT INTO 'dancecrib' VALUES (8516, '2015-02-02 00:44:14.849691+00', '2015-02-02 00:44:14.849691+00', 9050, 1, NULL, 'ace', '1--::

  1c+3c turn RH ¾ into promhold, 1c (W on L) facing W side and 3c (W on R) facing M side | 1c+3c promenade clw round 2W/2M and meet | ½ RHA to places, 1c facing out, 3W facing up (1,2,3)

9--::

  1M followed by 2M+3M & 1W followed by 2W+3W cast off to bottom, 1c leading up to 2pl, 2c finish in 3pl, 3c cast into 1pl ; 1c turn P RH 1½ _while{4}_ 3c+2c set and cross (3x,1x,2x) 

17--::

  1c+2W Circle3 L, to sidelines ; 1c+3M Circle3 R, to sidelines

25--::

  3c+1c Circle4 L ; 3c+1c+2c Circle6 R ½ (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3425, '2012-01-22 19:30:24.952134+00', '2017-06-08 20:51:55.002742+00', 14244, 1, NULL, 'ace', '1–::

  All set | cross RH ; All set | 2c cross RH and face out _while{2}_ 1c+3c turn RH ¾ to midline

9–::

  »Weasel reel«: All continuously dance ½ Reel4 on the midline, dancers reaching the end cast clw on own side {4} and rejoin the reel at the other end.  (2c casts ¼ round clw {2}, dances the ½ reel {4}, and casts clw to 2pl facing in {2}) (1c+3c finish on midline)

17–::

  1M & 3W, with P following, chase clw round the set to finish (1x,2,3x) 

25–::

  Diag R&L (first R ; then L) (3,2,1)

33–::

  1c set | cast up one (2c down) ; All turn P RH (3,1,2)', 4);
INSERT INTO 'dancecrib' VALUES (8517, '2015-02-03 00:35:24.984444+00', '2015-02-03 00:35:24.984444+00', 15959, 1, NULL, 'ace', '1--::

  1c turn BH and open facing up | cast to 2pl (2c up) ; 1c dance Rsh round P to 2pl facing out | 1c cast to 3pl and face up NHJ while{2} 3c dance up to 2pl facing out while{2} 2c dance out, up and in to 1pl facing down NHJ (2,3,1)

9--::

  Mirror Reels3{6} on the sides, 3c starts down and out, 2c slows at the end | 3c change place with 1c EH {1} , 2c change place with 1c EH (1,2,3) 

17--::

  1c+2c “La Girandole” (2,1,3) [1c+2c set to P | 1W+2M Turn RH ¾ while{2} 1M+2W cast cclw to make RH wheel ; 1c+2c RHA ¾ | 2c+1c cross RH to own side]

25--::

  1c+3c “La Girandole” (2,3,1)

', 4);
INSERT INTO 'dancecrib' VALUES (1650, '2012-01-22 19:28:53.014229+00', '2015-02-03 15:28:32.449821+00', 109, 1, NULL, 'ace', '1–::

  1c+2c set | turn BH, into ; 1c+2c ½Poussette, finishing in the middle, facing down

9–::

  2c+1c lead down the middle ; (2c divides) 1c+2c lead up to (1,2)

17–::

  Reel4 across the dance, 1W and 2M pass Lsh to begin, and finish with a loop on own side

25–::

  Tournée', 3);
INSERT INTO 'dancecrib' VALUES (2770, '2012-01-22 19:29:56.70655+00', '2015-05-04 12:54:24.153281+00', 4303, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; Turn 1cnr LH, finish BtoB facing 1cnr

9–::

  SetH&G , finish BtoB on midline M facing up, W down

17–::

  1c dance out ends, cast R round 2cnr to sideline ; turn 2cnr RH to face 3cnr

25–::

  Lsh Reels3 across, at the end 1c cross Rsh to own side (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8128, '2013-12-02 18:37:31.759399+00', '2019-04-03 20:16:40.086264+00', 14738, 2, 160, 'ace', '1-8::

  1C set, dance NH down the center + cast up to 2pl & cross to face 1crnr.

9-16::

  Reel 3 on sides - 1C pass 1crnr Rsh to begin.

17-24::

  1C+1crnr set , 1C spiral Rsh rnd ptnr to face 2crnr ; 1C+2crnr set , 1C spiral Rsh to face out 2pl own side.

25-32::

 All dance Chaperoned Chain Progression. End 3 1 2.', 2);
INSERT INTO 'dancecrib' VALUES (1613, '2012-01-22 19:28:50.981504+00', '2015-02-09 01:23:02.409209+00', 10820, 1, NULL, 'ace', '1–::

  1c set to 3c | change places with opposite person RH ; face R and chase clw outside the set to partner''s place

9–::

  2c+4c repeat

17–::

  2M & 4M join NH with W on their R (=1W & 3W respectively) and A&R on diagonal ; 3M & 1M repeat with W on their R.

25–::

  Circle8 and back. all M to original places, with new partner.', 3);
INSERT INTO 'dancecrib' VALUES (8519, '2015-02-09 05:41:58.564368+00', '2015-02-09 06:01:26.434861+00', 3066, 1, NULL, 'ace', '

*Trio face trio RR*



1--::

  Circle6 and back

9--::

  Reels3 across, M starting Rsh to W on his R

17--::

  each M with both W on his R RHA ; [+ see note]

25--::

  All dance BtoB with opposite ; turn opposite 1½ times and face next trio



*Note: should “then LHA with both W on his L” not be added? (missing in the original instructions)*

', 2);
INSERT INTO 'dancecrib' VALUES (8520, '2015-02-10 12:43:12.208819+00', '2015-02-10 12:45:15.513957+00', 16025, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 1c ½ Fig8 through cpl on L (2,1,3)

9--::

  All dance the arandel [All cross RH | on 2diag set diagonally _while{2}_ 1c+1cnr (pos) change place LH ; All cross RH | on 1diag same dancers set diagonally _while{2}_ 1c+same dancers change back LH] (2,1,3) 

17--::

  Reels3 on own sides, 1c starting out and to the R (2,1,3)

25--::

  Circle6 and back

', 3);
INSERT INTO 'dancecrib' VALUES (11927, '2019-06-30 04:11:25.384605+00', '2019-06-30 04:16:22.892229+00', 9496, 1, 202, 'ace', '_Strathepsey_



1--::

  1c+2c set | turn P BH opening into ; Circle4 L (1,2,3,4,5)

9--::

  1c cross RH | cast (2c up) ; ½ Fig8 up round 2c (2,1x,3,4,5)



_Reel_



17--::

  1c+3c set | turn P RH ; Circle4 L (2,1x,3,4,5)

25--::

  1c cross RH | cast (3c up) ; ½ Fig8 up round 3c (2,3,1,4,5)

', 2);
INSERT INTO 'dancecrib' VALUES (11928, '2019-06-30 07:06:53.285807+00', '2019-06-30 07:11:00.425917+00', 19461, 1, 202, 'ace', '1--::

  1c+2W Reel3 across, 1W passing RSh to 1M (1,2,3)

9--::

  1c+2M Reel3 across, 1M passing LSh to 1W (1,2,3)

17--::

  1c dance down (2c up) | cast up round 3c to 2pl ; turn P LH 1¼ to finish LSh to P facing opposite sides

25--::

  2c+1W & 1M+3c RHA. 1c pass P RSh ; 2c+1M & 1W+3c LHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8521, '2015-02-11 11:24:41.44231+00', '2015-02-11 11:30:57.80908+00', 6552, 1, NULL, 'ace', '1--::

  1c full petronella (1x,2,3) 

9--::

  1c full petronella, finishing in 2pl (2c up on [13-14])

17--::

  2c+1c+3c A&R twice

25--::

  Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8522, '2015-02-11 22:24:07.11065+00', '2016-06-03 14:06:17.025304+00', 16044, 2, 1, 'ace', '1–::

  1c dance figure of 8 round standing 2c

9–::

  1c&2c turn RH ; 1c&2c turn LH

17–::

  1c followed by 2c lead down the middle ;

  2c followed by 1c lead up to progressed places

25–::

  2c+1c dance Rights and Lefts', 5);
INSERT INTO 'dancecrib' VALUES (2707, '2012-01-22 19:29:53.914092+00', '2015-02-12 23:34:14.755112+00', 7811, 1, NULL, 'ace', '1–::

  1c lead down {3}, up {3} | cast to 2pl (2c up) (2,1,3,4)

9–::

  1c+3c RHA, finish W facing down, M up ; 3W+1W following & 1M+3M following dance behind sideline and cast in between end couple, on meeting 1M & 3W pass Rsh and all swivel R to stand Bto B with P, on [16] 2c face down, 4c up (order 2,3,1,4)

17–::

  2c+3M & 1W+4c taking hands as in DTr, and 3W facing 1M set | All set, 1c+3c changing place with P as in DTr ; All set (2c+3W & 1M+4c in DTr position and 3M facing 1W) | 1c+3c Petronella Turn to own sides, _while{2}_ 2c+4c set, and all face in (2,3,1,4)

25–::

  1c ½Fig8 round 3c casting to 4pl (4c up) ; 1c A&R with change of side (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (8523, '2015-02-12 11:08:42.853224+00', '2015-02-12 23:46:32.552862+00', 14582, 1, NULL, 'ace', '1--::

  1c+4c set | turn RH ; cast inwards (2c+3c step to end) | ½ RHA (2,4x,1x,3)

9--::

  Axum Reel of Eight (3x,1,4,2x)

17--::

  3c+1c & 1c+4c Circle4 R ; set facing up/down | turn opposite EH, 2c+3c going between middles (3x,1,4,2x)

25--::

  3c+2c ½ Fig8 through the middle couple ; All turn P BH (3,1,4,2)



*Axum Reel: Every 2 bars all dance to the next position along the path 1M, 2W, 1W, 3W, 4W, 3M, 4M, 2M, 1M, etc., passing other dancers Lsh.*



', 3);
INSERT INTO 'dancecrib' VALUES (8524, '2015-02-13 00:51:41.531969+00', '2015-02-13 00:54:20.581443+00', 10105, 1, NULL, 'ace', '1--::

  1c long cast to 2pl _while{2}_ 2c set and cross up (no hands or loops) ; 1c+3c repeat and 3c face out  (2x,3x,1)

9--::

  Reels3 on the sides, 3c starts out and down as 1c cross up, finish (2x,3x,1x)

17--::

  1c dance up the middle and cast to 2pl (3c down) ; All set | All turn P RH ½ into

25--::

  2x+1c+3c Promenade (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8953, '2015-10-29 10:05:48.383439+00', '2020-12-29 12:21:32.291087+00', 16801, 2, NULL, 'ace', '1 – 4::

	   1s+3s petronella turn and set. (2s+4s step up slightly)



5 – 8::

	   1s+2s,3s+4s RA.  1s+3s remain in centre



9–16::

	1s+3s reel of 4. (2s+4s step to original places)



17–20::

	1s+3s petronella turn and set while 2s+4s set and cross passing right shoulder





21–24::

	   All chase clockwise half way, to 4 3 2 1.



25–28::

	   4s+3s+2s dance half reel of 3 on side, 3s left shoulder to 1st corner position to begin. 1s may spin



29-32::

	   All ‘spin’ (Tulloch turn).', 3);
INSERT INTO 'dancecrib' VALUES (2249, '2012-01-22 19:29:27.818667+00', '2016-12-16 21:51:29.166432+00', 12803, 1, NULL, 'ace', '1–::

  All set | turn P RH ¾ ; All M chase clw ½ round _while{4}_ All W LHA, stay in centre facing new P

9–::

  All set | Turn new P RH ½ ; All W chase clw ½ round _while{4}_ All M LHA, finish (3,4,1,2) with M facing ou

17–::

  All mirrored half Schiehallion Reel (1,2,3,4)

25–::

  All Set to C opposite | set 1c facing 2c & 3c facing 4c ; 1c+2c & 3c+4c ½ R&L on diagonal (2,1,4,3)

33–::

  All Set to C opposite | set 1c facing 4c & 2c facing 3c ; 1c+4c & 2c+3c ½ R&L on diagonal (3,4,1,2)

41–::

  Circle8 and back (3,4,1,2).



{{explanation}}

Repeat once.', 3);
INSERT INTO 'dancecrib' VALUES (11929, '2019-06-30 07:23:31.47409+00', '2019-07-02 20:59:46.333112+00', 19460, 1, 202, 'ace', '1--::

  1c cast (2c up) | dance down between 3c ; cast up round 3c and face 1cnrs

9--::

  4 bars of Turn CPCP ; ½ Reel4 on 2diag. On [16] 1c pivot R to face 2cnrs[pos]

17--::

  4 bars of Turn CPCP. 1c face 1cnrs ; ½ Reel4 on 1diag. On [24] 1c pivot R to face 1cnrs[pos]

25--::

  3c+1W & 1M+2c RHA to 2plx ( to 3x,1x,2x) ; all chase clw ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11660, '2019-03-10 20:58:19.871338+00', '2019-05-06 11:48:02.563599+00', 18091, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; dance down between 3c and cast to 2pl passing P LSh to face 1cnrs

9--::

  1c+1cnrs set | turn 1cnrs RH ; turn P LH and face 2cnrs

17--::

  1c+2cnrs set | turn 2cnrs RH ; turn P LH 1½ to 2pl

25--::

  Circle6 and back (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (9634, '2017-03-04 13:27:48.585109+00', '2017-08-26 10:12:39.702764+00', 8472, 1, 202, 'ace', '1--::

 1c+2c Poussette

9--::

 1c+2c set | cross RH ; set | cross LH

17--::

 1c set | cast (2c up on 19) ; 1c dance BtoB (2,1)

25--::

 Circle4 and back', 2);
INSERT INTO 'dancecrib' VALUES (3568, '2012-01-22 19:30:31.519064+00', '2023-02-28 15:52:34.295735+00', 9809, 1, NULL, 'ace', '1—::

  1c turn RH | cast off (2c up) ; turn LH, 1M face out (2,1,3)

9--::

  1M, 1W following, cast up round 2M and down the middle to finish 1W above and facing 2c and 1M above and facing 3c ; 1W+2c & 1M+3c BiL twice

17--::

  2c+1W & 1M+3c Reels3 across, 1c giving Rsh to the M to start, 1c finish on midline facing down

25--	::

  1M, 1W following, dance down and cast up round 3M to 2plx ; 1c turn RH 1½ _while{4}_  2c+3c turn RH (2,1,3)

33--::

  Circle6 and back.

', 4);
INSERT INTO 'dancecrib' VALUES (8765, '2015-05-17 22:10:11.993618+00', '2015-05-17 22:10:11.993618+00', 15691, 1, NULL, 'ace', '1--::

  1c cross down into Reels3{6} on opposite sides, touch NH when possible | all dance on, 1c to face 1cnr, 2c cast to 1pl, 3c loop into 3pl 

9--::

  Set “H&G”, 1c finish with petronella turn (2,1,3)

17--::

  1c dance ½ Fig8, Lsh to 1cnr ; repeat Lsh to 3cnr while{8} 2c+3c R&L, starting along the sides.  Finish (2,1,3) with 2W+3M facing out

25--::

  Reels3 on both sides, 1c Rsh to 4cnr (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11661, '2019-03-10 22:00:57.496505+00', '2019-03-10 22:01:52.756355+00', 15635, 2, NULL, 'ace', '1-8::

  1s cast one place, dance down the middle, NHJ. 1M dances below his partner, passing her under his arm. 1s dance up on opp. sides to 2nd position in middle, facing up. 

9-16::

  1s dance up through the top of the set into mirror reels of 3 on opp sides (2s cast down and dance between 3s as 3s cast up). (1s finish level with 2nd place, passing right shoulders to face their partner''s 2nd corner). 

17-32::

  1s set to and turn partner''s 2nd corner by right hand, moving on anticlockwise round the set, to set to and turn each corner in sequence. 

32-40::

  All dance reels of 3 across the dance, 1W with 3s, 1M with 2s, passing left shoulders to begin. 1s finish facing out, ready to repeat . . . 

', 0);
INSERT INTO 'dancecrib' VALUES (1950, '2012-01-22 19:29:11.507428+00', '2015-10-29 15:25:13.265368+00', 13270, 1, NULL, 'ace', '1–::

  1c+2c Snowball G-Chain (4 hands of 2 bars), to start 1c+2c change place RH on the side (3x,1x,2x) (1W no polite turn at the end)

9–::

  1c cross Rsh | Turn 3cnr pos. RH ½ ; with cnr following pass Lsh on the diagonal and curve into 2plx, the cnrs returning to own 1cnr positions

17–::

  1c cross Lsh | Turn 4cnr pos. LH ½ ; with cnr following pass Rsh on the diagonal and curve into 2plx, the cnrs returning to own 2cnr positions (2,1x,3)

25–::

  All turn P RH ; 1c ½ Fig8 L (W up, M dn) (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8162, '2014-02-01 02:57:48.618343+00', '2019-06-30 13:45:43.030954+00', 1038, 2, 160, 'ace', ' 1–4:: 

 1W+2W+3W set & crossover  (W 1x, 2x, 3x) WHILE 1M+2M+3M chase half round (M 3x, 2x, 1x)



 5–8:: 

 Repeat - M set and cross over WHILE W chase half round. (3 2 1)



 9–16:: 

 1C turn RH 1.1/2 ; cast up 1pl, turn LH 3/4 



 17–24:: 

 1W+3C (above) & 1M+2C (below) RH Across ; change ends LH Across



 25–28::

 Rsh Snake Pass (unwind LHA, 1C leading pass other snake Rsh through 2pl(x) and chase clw to ) (2, 1, 3)



 29-32::

 All turn partner RH



*(Bars 29-32 added by editor as they were missing from the original crib).*



', 0);
INSERT INTO 'dancecrib' VALUES (11930, '2019-06-30 07:47:44.307795+00', '2019-06-30 07:54:03.161146+00', 10241, 1, 202, 'ace', '1--::

  1c set | cross down (2c up) BtoB in centre ; 1M+2W+3W & 1W+2M+3M Circle3 L. On [8] 1c pass P LSh in centre to 2pl (2,1,3)

9--::

  2c+1W & 1M+3c RHA. 1c pass P RSh ; 2c+1M & 1W+3c LHA to 2pl (2,1,3)

17--::

  Reels3 across, 1c LSh to 1cnrs (2,1,3)

25--::

  2c+1c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2786, '2012-01-22 19:29:57.345386+00', '2015-10-30 11:49:32.529176+00', 4374, 1, NULL, 'ace', '1–::

  1W (1M follows) cast and cross to below 2c ; 1M, followed by 1W, cast up (both swivel L) and cross to (1,2,3)

9–::

  1c cross down (no hands) _while_{2} 2c dance up | 1c+2c turn EH (1W+2M RH & 2W+1M LH), 2c ends in 1pl, and 1c meet in2pl ; 1c cross down (no hands) _while_{2} 3c dance up | turn 3c EH (1W+3W LH & 1M+3M RH) bringing 3c to 3pl, 1c to face 1cnrs)

17–::

  1c SetH&G , finish facing P up/down

25–::

  1c dance to meet (M swivels R, takes P on L) and lead up, cross over and cast to 2pl ; 1c+3c circle4 to the left (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11931, '2019-07-02 17:17:55.778194+00', '2019-07-02 17:17:55.778194+00', 19261, 2, 2929, 'ace', '1-:: 1C long cast to 2nd place. 1C dance half Fig8 around 2C
9-:: 1M with 2+3W advance, retire, advance, 1M petronella right between 2C while W retire. Meanwhile 1W with 2+3M set, advance, retire. 1W petronella right between 3C while M set.
17-20:: 1W pull back RSh and dance down, followed by 1M
21-24:: 1W pull back RSh while 1M pull back LSh, lead LH up to face first corners
25-:: Corners pass and turn', 0);
INSERT INTO 'dancecrib' VALUES (13574, '2021-01-23 02:49:29.564859+00', '2021-01-23 02:56:18.560377+00', 12293, 1, 202, 'ace', '1--::

  1W casts off to 4pl (2W+3W+4W up) _while{4}_ 4M casts up to 1pl (1M+2M+3M down) ; all turn opposite person RH (4M,1M,2M,3M on Mside, 2W,3W,4W,1W on Wside)

9--::

  2W casts off to 4pl (3W+4W+1W up) _while{4}_ 3M casts up to 1pl (4M+1M+2M down) (to 3,4,1,2) ; all turn P RH (3,4,1,2)

17--::

  3c+4c & 1c+2c ½ R&L (to 4x,3x,2x,1x) ; 4c+3c+2c ½ Mirror Reels3, 3c out and down (2x,3x,4x,1x)

25--::

  All NHJ A&R ; All turn P RH 1½', 2);
INSERT INTO 'dancecrib' VALUES (14712, '2022-03-28 01:46:31.304811+00', '2022-03-28 01:57:22.931905+00', 13315, 1, NULL, 'ace', '1-::

  1c turn RH  ½ | lead down (2c up) and cast up round 3c to DTr position on opposite side

9-::

  Set in DTr | 1c move to face own side as all cnrs chase one place clw ; Set in DTr | all cnrs chase again and 1c finish in promhold facing up

17-::

  ½ Rsh Reel3 on 2diag ; ½ Reel3 on 1diag (1c Rsh to 1M pos)

25-::

  Repeat [17-24] (Rsh to 3M pos ; Rsh to 3W pos), 1c finish facing 1cnr (in 3cnr pos)

33-::

  1c turn 1cnr LH, into NHJ with 1cnr on the L | face diagonally and set ; ½ LHA, cnrs to own side, 1c continue LH turn to face 2cnr (in 4cnr pos)

41-::

  1c turn 2cnr RH, into NHJ with 2cnr on the R | face diagonally and set ; RHA finishing (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13282, '2020-10-16 00:22:26.69838+00', '2023-02-04 01:23:05.532021+00', 19643, 3, NULL, 'ace', '1-8::
    1s cross down to dance mirror reel of 3s on opp sides. 1s end in 1st
    place opp sides
9-16::
    1s dance down & out through 2nd place (2s dance to top place bars
    9-10), down behind 3s; dance up & out through 2nd place opp sides &
    1s+2s turn LH ready for …
17-24::
    1s+2s dance Ladies'' Chain
25-32::
    1s+3s turn RH on sides, 1M casts down to 3rd place as 1L dances down
    centre (3s step up 27-28); 1s cross LH & 2s+3s+1s set', 0);
INSERT INTO 'dancecrib' VALUES (10146, '2017-09-24 15:49:58.438696+00', '2020-09-02 11:44:18.931948+00', 5070, 2, 160, 'ace', '1-8::  1s+2s set, cross over RH; set, cross back RH.

9-16::  1s+2s RHA; 1s cast as 2s dance up NHJ, 1s turn BH - end NHJ facing down.

17-24::  1s fig.8 on own sides - in+down to begin.

25-32::  1s+3s set, turn BH; 4 hands round to the left. ', 3);
INSERT INTO 'dancecrib' VALUES (8762, '2015-05-12 14:44:40.099154+00', '2017-07-27 13:04:00.35471+00', 16339, 2, 1, 'ace', '1–::

  1c cross RH | cast off (2c up) ; 1c dance down between 3c | cast up to 2plx

9–::

  Reels3 across (1L w/3c, 1M w/2c, LS to 3rd corner, fin 21x3)

17–20::

  2M+3M dance RS round 1L _while_ 2L+3L dance RS round 1M

21–24::

  2c+3c ½ chase _while_ 1c dance RS round ptr

25–::

  2c+3c dance as in Set & Link for 3 _while_ 1c cross RH, cast to R, cross RH

  up/down, cast to R', 3);
INSERT INTO 'dancecrib' VALUES (2552, '2012-01-22 19:29:47.357187+00', '2015-07-13 19:09:05.1172+00', 7561, 1, NULL, 'ace', '1–::

  1c+3c set | cross RH ; cast off (2c+4c up) | turn LH ¾ to face 1cnr

9–::

  1c+3c with 1cnrs ½ corners pass and turn ; 1c+3c Turn P LH 1¼ to face 2cnr

17–::

  1c+3c with 2cnrs ½ corners pass and turn ; 1c+3c Turn P LH 1¾ to midline, W above M, facing opp. side

25–::

  2c+1W & 1M+4c+3W & 3M+5c RHA ; 1c+3c turn LH and cast off on own side (4c+5c up) (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (8764, '2015-05-14 22:14:37.257893+00', '2015-05-14 22:20:56.944218+00', 5054, 1, 106, 'ace', '1--::

  1c turn RH ½ moving down as 2c dance up, finish NHJ 2c facing 1c | 2c+1c set ; 2c+1c LHA (2,1x,3)

9--::

  1c turn LH ½ moving down as 3c dance up, finish NHJ 3c facing 1c  | 3c+1c set ; 3c+1c RHA and 1c face out(2,3,1)

17--::

  1c cast up (3c down) | 1c set ; 1c turn LH 1½ to face 1cnrs

25--::

  1c+cnrs pass and turn, at end 1c meets on midline and twirls R to face 4cnr ; 1c+4cnrs pass and turn, to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2260, '2012-01-22 19:29:28.338682+00', '2015-05-14 23:06:00.689038+00', 2263, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; 1c ½ Fig8 R (M up, W down) _while{4}_ 2c+3c set, cross RH and face out (2x,1,3x)

9–::

  Reels3{6} on the sides (Rsh to 4cnr position) | 1c finish on midline, 1M in 3pl facing 1W in 1pl _while{2}_ 2W+3W & 2M+3M loop to meet NHJ on the sidelines

17–::

  1c set and petronella into 2plx _while{4}_ 2c+3c cross (M arch) and cast to the ends (2,1x,3) ; all C turn RH, finish 2c facing 3c with 1c in centre facing down, woman on the R,

25–::

  2c+3c R&L (starting RH along the sides) _while{8}_ 1c dance down, divide and cast up round 3pl ; cross through the top and cast off  (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14058, '2021-06-01 06:36:13.900769+00', '2023-02-28 19:25:16.99551+00', 8449, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; turn P RH 1½ to 2pl (2,1,3)

9--::

  2c+1W & 1M+3c RHA ; LHA (2,1,3)

17--::

  1c cast off | turn P RH ½ ; lead up to top | cross and cast to 2pl (2,1,3)

25--::

  2c+1c R&L (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (7843, '2013-08-21 08:31:49.636934+00', '2023-02-04 01:23:05.547256+00', 14118, 3, NULL, 'ace', '1-8::
    1s set & turn RH, 1s cast 1 place & turn LH to end in middle facing
    Ladies side
9-16::
    1s lead out crossing & cast 1 place (1L up, 1M down), 1s dance 1/2
    reels of 3 (1L RSh to 2M, 1M LSh to 3M) & end in lines across
17-24::
    2s+1s+3s Set+Link for 3 (2 1 3), all turn partners RH
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (3309, '2012-01-22 19:30:19.9475+00', '2015-05-29 00:06:29.109622+00', 13282, 1, NULL, 'ace', '1–::

  1c+2c dance The Tourbillon (2,1,3), 1c face out

9–::

  1c cast to the R (W down, M up) pass Rsh in middle, dance out the other end, cast R through 2pl own side and pass Rsh to (2,1x,3)

17-32::

  All dance R&L for 3 couples ; 1c turn BH 1½ to (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (2365, '2012-01-22 19:29:33.580807+00', '2021-06-15 05:23:43.694699+00', 2631, 1, 202, 'ace', '1--::

  1c+2c set | cross RH ; repeat (1,2,3)

9--::

  1c lead down {3}, lead up {3} | cast and face 1cnrs (2c up)

17--::

  Set to and Turn Corners (2,1x,3)

25--::

  All A&R ; 1c turn P BH 1½ (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2199, '2012-01-22 19:29:25.443033+00', '2015-10-30 11:50:18.494946+00', 2042, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; turn 1¼ LH into facing lines across (1M with 3c and 1W with 2c)

9–::

  All set twice ; 1c turn 1¼ RH to (2,1,3)

17–::

  All set | cross RH ; set | cross LH but 1c turn LH to face 1cnr.

25–::

  1c set to 1cnr | to 2cnr swiveling R to finish between cnrs ; turn RH 1½ (to 2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3455, '2012-01-22 19:30:26.225186+00', '2015-10-30 11:52:34.106094+00', 6824, 1, NULL, 'ace', '1–::

  1W+2W+3W dance Rsh round P {6} | all set

9–::

  1M+2M+3M dance Rsh round P {6} | all dance in ready for

17–::

  1c+2c+3c Promenade

25–::

  1c cross down (no hands) | 1W+3M & 1M+3W turn RH (2c up) ; 1c cross back (no hands) | 2W+1W & 1M+2M turn LH', 3);
INSERT INTO 'dancecrib' VALUES (2740, '2012-01-22 19:29:55.468272+00', '2015-10-30 11:55:41.810805+00', 4126, 1, NULL, 'ace', '1–::

  1c+2c set twice ; RHA

9–::

  1c lead down | flowing into ½ RH turn to face up (2c up) ; 1c lead up to between and facing 2c | set to 2c (finish facing 1cnr)

17–::

  Corner, P, corner, P to 2pl facing down (1W short turn into:)

25–::

  2c+1c+3c G-Chain', 2);
INSERT INTO 'dancecrib' VALUES (14710, '2022-03-24 22:22:13.115487+00', '2022-03-28 01:59:31.630847+00', 13315, 2, 963, 'ace', '1-8::  

  1C 1/2 RH turn, face down, lead down below 3C (2c up 5/6), cast up through 2nd plc to finish b/b facing opp side  

9-16::  

  1C dance dbl triangles with corners chasing cw to next corner position on 11/12 and 15/16.  1C finish in prom hold facing up. 1W is on partner''s left  3x1x2x  

17-32::  

   1C dance 4 half R3 starting on 2nd corner diag.  Finish with a quick RH turn to face 1st corner person  3x12x

33-40::  

  1C turn 1st corner person LH to finish with corner on left facing in diagonally and set.  Dance LH across 1/2 way. Corners return to own side as 1c turn LH to face 2nd corners  

41-48::  

  1C turn 2nd corner RH to finish with corner on right facing in diagonally and set.  Dance RH across 1/2 way.  Corners return to own side as 1c turn RH to finish in 2nd place own side  213

  

  ', 0);
INSERT INTO 'dancecrib' VALUES (13967, '2021-04-21 11:17:31.786107+00', '2021-04-21 15:32:19.17192+00', 7144, 1, 202, 'ace', '1--::
  Mirror Reels3 on opposite sides, 1c crossing down (1x,2,3)
9--::
  1c+2c L-Chain. 1c finish LHJ in 1plx centre, 1M facing up, 1W facing down (1x,2,3)
17--::
  1c turn P LH ½, cast off (2c up) ; dance down between 3c (touching hands briefly) and cast up to face 1cnrs
25--::
 1c Set to Corners. 1 face P in 2plx centre ; 1c set to P | cross RH

*Deviser''s note* : at the end of their second turn 1c may cross with left hand to the bottom of the set.', 2);
INSERT INTO 'dancecrib' VALUES (14076, '2021-06-17 14:08:31.300487+00', '2021-06-17 14:22:04.081247+00', 15880, 1, 202, 'ace', '1--::

  1c set | cast off (2c up] ; 2c+1W & 1M+3c RHA. 1c hold RH to 1cnrs

9--::

  1c turn 1cnrs RH | pass P RSh ; turn 2cnrs RH ¾ into promhold and promenade 2cnrs across to 4cnrs[pos] (2M,1M,2W on Mside, 3M,1W,3W on Wside)

17--::

  ½ diagonal R&L (to 3x,1x,2x) ; all cross R | chase clw into facing lines3 across

25--::

  All cross RH up/down | chase clw to sides ; all dance BtoB (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2267, '2012-01-22 19:29:28.727953+00', '2015-10-30 21:36:51.45842+00', 9105, 1, NULL, 'ace', '1–::

  1c make NH arch with 2c and set | 1c+2c+3c (arches) repeat ; 1c+2c+3c+4c (arches) repeat twice

9–::

  1c+2c ½RHA | 1c+3c ½LHA ; 1c+4c ½RHA | all couples cross LH (2,3,4,1)

17–::

  2c+3c+4c+1c set | 2c+3c+4c facing up make arches and set _while{2}_ 1c set advancing and join RH ; 1c lead up under the arches, 2c+3c+4c step back on bar 24

25–::

  1c cast off behind 2c, dance in front of 3c, behind 4c and turn RH to 4pl', 3);
INSERT INTO 'dancecrib' VALUES (3506, '2012-01-22 19:30:28.285785+00', '2018-10-10 12:37:45.127686+00', 7037, 1, NULL, 'ace', '1–::

  1c+2c dance BtoB ; turn RH 1½ 

9–::

  1c+2c dance BtoB ; ½ R&L

17–::

  2c+1c+3c set twice ; turn P RH

25–::

  1c dance down between 3c, cast up ; up between 2c, cast off to 2pl ', 3);
INSERT INTO 'dancecrib' VALUES (8954, '2015-10-31 00:40:13.610946+00', '2015-10-31 00:40:13.610946+00', 3466, 1, NULL, 'ace', '1--::

  1c+2c turn P RH ½ | lead down ; turn P RH ½ | lead up ready for

9--::

  1c+2c Allemande, 1c turning LH to face 1cnr (2,1,3) 

17--::

  1c+1cnrs ½ diag. Reel4, pass Lsh and face same cnr person ; 1c turn cnr RH ¾ and face other pair diagonally NHJ | pairs set 

25--::

  Pairs A&R diagonally ; 1c+cnrs ½ RHA, corners finish in places and 1c turn on to face 2cnr

33--::

  1c+2cnrs ½ diag Reel4 ; 1c turn cnr RH ¾ and face other pair diagonally NHJ | pairs set

41--::

  Pairs A&R diagonally ; 1c+cnrs ½ RHA, corners finish in places and 1c turn on to 2pl (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (7844, '2013-08-21 08:31:49.645083+00', '2023-02-04 01:23:05.558974+00', 10178, 3, NULL, 'ace', '1-8::
    Ladies set advancing & retire _while_ Men set & advance setting
9-16::
    All dance Allemande
17-24::
    All dance 1/2 reel of 3 on sides (1s in & up), 1s+2s turn on sides
    (RH on Men''s side & LH on Ladies ), 1s dance down to 2nd pl as 2s
    cast to top
25-32::
    1s cast down behind 3s, lead up to top & cast to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (10938, '2018-08-05 12:01:12.129659+00', '2020-09-27 20:10:04.862764+00', 14374, 1, 202, 'ace', '*3c & 4c start on opposite sides*

1--::

  1c & 4c advance diagonally (4 walking steps) | set, 1W(4W) pivot R on PdB L to face up(dn) (2c & 3c step out) ; 1W(4W) followed by 4M(1M)  dance up(dn) and cast L to M(W)side (2,4,1x,3x)

9--::

  Rsh Reels3 in tandem on sidelines (2,4,1x,3x)

17--::

  4c+1c set | RHA | set

25--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (11934, '2019-07-02 20:24:10.511232+00', '2019-07-02 20:25:04.270817+00', 18117, 1, 1645, 'ace', '*On 2nd chord 3c & 4c cross to opposite side (1,2,3x,4x)*
1-::
  1c+2c & 3c+4c S&Link ; all chase &frac12; way clw (3,4,1x,2x)
9-::
  Reels4 on the sides
17-::
  All set facing up/down | set to P ; 4c+1c &frac12; RHA | turn RH into promhold facing 1cnrs
25-::
  4c+1c &frac12; diag RSh Reel4 with 1cnrs, pass LSh ; repeat with 2cnrs, 1c/4c end on M/W side
33-::
  1c & 4c set | petronella in tandem to facing lines across ; S&Link across (2,4,1x,3x)
', 2);
INSERT INTO 'dancecrib' VALUES (9833, '2017-05-08 13:27:54.920475+00', '2020-09-01 15:27:11.536023+00', 17732, 2, 160, 'ace', '1-8::

  1C 2C Set&Rotate.

9-16::

  Rsh Reel3 across [6] Man up-Lady down. 1C set adv + end b-t-b facing own side.

17-24::

  Double Triangles.

25-32::

  6 hands round&back.', 3);
INSERT INTO 'dancecrib' VALUES (3141, '2012-01-22 19:30:13.051915+00', '2021-04-21 20:19:21.740619+00', 5691, 1, NULL, 'ace', '1–::

  1M+2M dance between 1W+2W, cast round own partners to original places ; 1W+2W dance between 1M+2M, cast round own P to original places

9–::

  1c+2c DblFig8, 1c cross down to start, 2c finish in 1pl as 1c starts to cross down into

17–::

  1c+3c DblFig8 (2,1,3)

25–::

  1c+3c R&L.', 3);
INSERT INTO 'dancecrib' VALUES (11958, '2019-07-06 03:08:45.943118+00', '2019-07-06 03:08:45.943118+00', 15015, 2, 963, 'ace', '  Strathspey  
1-8::
  1&2c dance modified Maurice progression (1m&2w btob as 1w&2m cast cw 1 place & retire with their prtn to line on diag; dance half pousette) to finish facing dn, nearer hands joined  
9-16::
  1c flwd by 2c dance dn; 1c flwd by 2c cast up own sides back to orig place  

  Reel

17-24::
  Circle 4 hands round and back  
25-32::
  1&2c set & rotate
', 3);
INSERT INTO 'dancecrib' VALUES (2011, '2012-01-22 19:29:14.885498+00', '2015-06-06 20:01:45.966575+00', 1430, 1, NULL, 'ace', '1–::

  Mirror Reels3{6}on opposite sides (2c start out and up), on [7-8] 1c dance to 1cnrs, 2c to 1pl

9–::

  Set to and turn corners, end between corners (2,1x,3)

17–::

  Circle6 {2} | M turn W on R BH ; continue circle6 to (2,1x,3)

25–::

  All Petronella to midline | 2c+3c turn BH ½ _while_{2} 1c full turn BH ; all C petronella to own side, set (2,1,3)

33–::

  End couples pass Lsh and 1c cast Rsh (1M up, 1W down) for Reels3{6} across | 1c (passing outside) turn 3c EH to (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (2020, '2012-01-22 19:29:15.297102+00', '2015-06-06 20:21:10.502788+00', 1453, 1, NULL, 'ace', '{{explanation}}

Demo dance. 1c faces the audience.  

1st part



1–::

  All C set to P | change places RH ; all W LHA to partners'' places

9–::

  All C set | turn ¾ RH bringing the men BtoB in centre of set ; all set, turn ¾ RH to own places

17–::

  All M Fig8 round P and next W cclw, passing in front of P to begin

25–::

  Circle6 L | all C turn BH ; circle6 L to places



{{explanation}}

2nd part



1–::

  1c turn BH advancing to the middle of the dance and open up | 1M+2c set ; LHA _while_{6} 1W+3c set, RHA , all C finish in promhold (1c in middle facing down)

9–::

  Rsh reel of the 3 couples, ending in straight line across facing audience (end couples extra loops)

17–::

  All C S&Link with partners ; repeat, finishing by 1c facing each other and 2c & 3c face own end of line

25–::

  1c form double arch, ─ _while_{8} ─ 2M+3W, followed by 2W+3M, dance forwards, meet in the middle, dance up through arch, through 1c places and cast back to original places. 1c dance up to places on the last 2 bars.



{{explanation}}

3rd part



1-4::

  All C set to P | turn RH (W finishing facing out)

5-16::

  »Celtic Brooch formation«: all M RHA 2/3 round to that W''s place _while_{2} all W wide cast to P''s place | W RHA 2/3 round to that M''s place _while_{2} men cast to M''s places (now next to P again) ; Repeat [5-8] twice, to original places, all W stay facing out.

17–::

  All W Fig8 round P and her corner M, passing behind P to begin

25–::

  Circle6 L | all C turn BH ; circle6 L to places



{{explanation}}

Name taken from the ornamental crown topping the tower of King''s College, Aberdeen', 4);
INSERT INTO 'dancecrib' VALUES (3689, '2013-01-22 13:52:52.837006+00', '2018-02-27 21:54:07.233902+00', 5122, 2, 1, 'ace', '*3c+4c start on opp sides [two chords]*



1–4::

  1c set | turn BH to fin in ctr, 1W facing out, 1M behind 1W _while_ 4c dance likewise [4W face out]

5–8::

  1W (followed by 1M) casts off [2c up], dances across towards M''s side and then down the middle

  _while_ 4W (followed by 4M) casts up [3c down], dances across towards W''s side and then up the middle

  [1c and 4c pass LS]

9–::

  4c dance RH across with 2W _while_ 1c dance RH across with 3W ;

  4c dance LH across with 2M _while_ 1c dance LH across with 3M

  [4c fin facing up in 2pl, NH joined; 1c fin facing down in 3pl, NH joined; 2M & 3M fin facing out]

17–20::

  2c dance down sides to 2pl | dance up NH to 1pl

  _while_ 4c dance up to 1pl | cast off to 2pl own sides

  _while_ 1c dance down to 4pl | cast up to 3pl opp sides

  _while_ 3c dance up sides to 3pl | dance down NH to 4pl

21–24::

  4c+1c [center couples] Circle4 to L

25–::

  All Circle8 to L {2} | S retaining hands ; chase to L {1} and cast back to own sides {3}', 3);
INSERT INTO 'dancecrib' VALUES (10147, '2017-09-24 16:07:08.062549+00', '2020-09-02 11:46:07.325142+00', 5082, 2, 160, 'ace', '1-8::  1s set, cast (2s up); turn RH 1_1/2 to end in line with 1corner (keep RH joined).

9-16:: Join LH with 1corners & Balance, 1s turn RH 3/4 to form line btwn 2corners; join LH and Balance, 1s turn RH to 2place own sides.

17-24::  6 hands round & back,

25-32::  1s pass Lsh to turn 1corner RH; pass Lsh to turn 2corner RH & pass Lsh to 2place own sides.', 3);
INSERT INTO 'dancecrib' VALUES (8767, '2015-06-12 17:03:11.087879+00', '2015-06-12 17:03:11.087879+00', 16457, 2, NULL, 'ace', '1-::

   1c&2c S&Link ; 1c&3c S&Link

9-::

   1c turn RH | cast up ; dance to top | cast off to (2,1,3)

17-::

   All A&R (1step) twice ; half Grand Chain (to start: 2c cross, 1c&3c change on sides)

25-::

   All A&R (1step) twice ; half Grand Chain (to start: 1c&3c change on sides, 2c cross)

', 2);
INSERT INTO 'dancecrib' VALUES (8768, '2015-06-14 17:57:43.437049+00', '2015-06-14 17:57:43.437049+00', 7972, 2, NULL, 'ace', '{{title}}

Strathspey



1-4::

   1s set & cast off 1pl

5-8::

   half fig 8 round 1st corner

9-16::

   set to corners and partner, finish with petronella turn in 2nd pl opp side facing out

17-24::

   2s,1s,3s reel 3 on sides, 1s start to their left. 1s finish with half LH turn & 3s meet

25-32::

   1s & 3s dance allemande



{{title}}

Reel



Repeat the same figures with new couple leading', 2);
INSERT INTO 'dancecrib' VALUES (2932, '2012-01-22 19:30:03.453815+00', '2015-06-14 21:06:32.114118+00', 4894, 1, NULL, 'ace', '{{explanation}}

The couples stand in lines of four across the room, 2c+1c facing 4c+3c, W to the right of their M.



1–::

  1c+2c+3c+4c circle8 and back

9–::

  1c+3c R&L _while{8}_ 2c+4c set twice to partners and turn partners once RH

17–::

  2c+4c R&L _while{8}_ 1c+3c set twice to partners and turn partners once RH

25–::

  1W+2W+3W+4W Reel4 along middle of the set, 2W+4W and 1W+3W passing Rsh to begin (4W+1W go to middle of reel)

33–::

  1M+2M+3M+4M repeat

41–::

  Joining hands in lines of 4, A&R ; drop hands and passing opposite dancer Rsh advance to face next line', 2);
INSERT INTO 'dancecrib' VALUES (2635, '2012-01-22 19:29:50.924522+00', '2015-10-30 11:53:44.434471+00', 3685, 1, NULL, 'ace', '1–::

  1c lead down, cross below 2c, cast round 3c, lead to top, cast to 2plx (2c up) (2,1x,3).

9-14::

  2c+1c+3c:  5 hands of G-Chain (2c cross to start) (1x,2,3x)

15-16::

  1c+ 3c turn BH ½ opening to form

17–::

  1c+2c+3c circle6 and back

25–::

  1c+2c Allemande', 3);
INSERT INTO 'dancecrib' VALUES (11936, '2019-07-03 19:13:32.152663+00', '2019-07-03 19:14:52.548607+00', 19465, 1, 202, 'ace', '1--::

  1c (2c, 3c & 4c following) cast off to 4pl and dance up NHJ. On [8] 1c & 3c turn outwards and face 2c/4c on sides (1,2,3,4)

9--::

  Reels4 on sides (1,2,3,4)

17--::

  1c+2c Tourbillon _while{8}_ 3c+4c Poussette (2,1,3,4)

25--::

  All set | 1c dance to 4pl (3c+4c up) _while{2}_ 2c set ; all turn P BH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11937, '2019-07-03 20:44:29.157372+00', '2019-07-03 20:46:50.338562+00', 19469, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Reels3 across, 1c RSh to 4cnrs (2x,1,3x)

9--::

  Reels3 on sides, 1c LSh to 3cnrs[pos] (2x,1,3x)

17--::

  ½ Reels3 across, 1c RSh to 2cnrs[pos] (to 2,1x,3) ; 1c turn P BH 1½ _while{4}_ 2c & 3c turn P BH (2,1,3)

25--::

  2c+1W & 1M+3c RHA. 1c pass P RSh ; 2c+1M & 1W+3c LHA (2,1,3)

33-44::

  3C R&L (2,1,3)

45-48::

  All set | 1c cast to 3pl _as_ 3c dance up (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11939, '2019-07-05 00:17:31.639843+00', '2019-07-05 00:19:09.375087+00', 12632, 1, 202, 'ace', '1--::

  1c+2c RHA ; LHA (1,2,3)

9--::

  1c set | cast (2c up) ; turn LH to face 1cnrs

17--::

  Reel4 on 1diag. 1c face 1cnrs

25--::

  Reels3 on sides, 1c RSh to 1cnrs. On [31-32] 1c pass LSh to 2pl (2,1,3)

33--::

  All set twice ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11938, '2019-07-04 06:41:18.855754+00', '2019-07-04 06:44:35.045011+00', 19466, 1, 202, 'ace', '1--::
  1c set | cast (2c up) ; turn RH to face 3cnrs
9--::
  1c turn 3cnrs LH ; turn 4cnrs RH into lines3 across facing 1cnrs
17--::
  Reels3 across, LSh to 1cnrs. 1c finish in centre, LHJ to P, RHJ to 4cnrs
25--::
  The Spoke (2,1,3)
33--::
  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11940, '2019-07-05 18:42:53.31421+00', '2019-07-05 18:44:48.215859+00', 15158, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c in and down, 2c out and up (1,2,3)

9--::

  1c+2c DblFig8, 1c crossing down (1,2,3)

17--::

  1c lead down ; and up. 1c face down NHJ, 2c step in on [24]

25--::

  1c+2c The Rondel (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11959, '2019-07-06 03:20:38.821928+00', '2019-07-06 03:21:48.457458+00', 15016, 2, 963, 'ace', '1-8::
  1c cast (2s up)|x RH, cast Rt to btwn 2&3c (4)|1/2 turn RH to face opp sides  
9-16::
  1m w 2c/1w w 3c LHA; Rt shld snake pass to 3,1,2  
17-24::
  1c turn 1st crn position RH|pass prtn R shld|turn 2nd crn position RH|RH 1/2 turn prtn to face opp sides  
25-32::
  1c rpt 9-16 to 2,1,3  ', 3);
INSERT INTO 'dancecrib' VALUES (11941, '2019-07-05 19:14:30.191502+00', '2019-07-05 19:24:03.224428+00', 6811, 1, 202, 'ace', '1--::

  1W+2W NHJ advance to finish in front of their P | set to P. On [4] turn inwards to face Wside ; dance across to Wside, turn outwards and dance across to P places _while{8}_ 1M+2M stand still ; follow P to Wside, turn outwards and dance to P places (1x,2x)

9--::

  1c+2c repeat, 1W+2W starting from Mside (1,2)

17--::

  1M+2W turn RH ; 1W+2M turn RH. 1W(2M) faces down(up)

25--::

  1M (2M following) & 2W (1W following) chase clw ¼ and face up/down NHJ | all set ; 1c & 2c change places RH | chase clw ¼ (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (9636, '2017-03-04 21:48:48.801351+00', '2021-03-19 10:58:33.055148+00', 8473, 1, 202, 'ace', '1--::

 1c cross RH | set ; 1c+2c cross RH | 1c+2c set (1,2x,3)

9--::

 1c+2c+3c cross RH | all set ; all cross RH | all set (1,2x,3)

17--::

 1c+2c ½ R&L ; 1c ½ Fig8 to R around 3cnr (2,1,3)

25--::

 Circle6 and back ', 2);
INSERT INTO 'dancecrib' VALUES (8961, '2015-11-05 10:22:51.283113+00', '2019-05-03 16:53:39.092503+00', 16817, 2, NULL, 'ace', '1-4::

  	        All set, cross right hand 

5-8::

  	        All set; 1s and 3s cross right while 2s turn both hands to face 1st corners 

9-16::

  	2s with 1st corners dance ‘corner pass and turn’ (turn both hands); pass right shoulder, repeat with 2nd corners. Pass right to 2nd place own sides

17-24::

  	1s and 2s dance espagnole. Is finish in a diagonal line with 3s, who step in on bar 24, ready for half poussette

25-28::

  	1s and 3s dance half poussette

29-32::

  	All turn both hands

', 3);
INSERT INTO 'dancecrib' VALUES (3744, '2013-05-23 12:01:16.659941+00', '2015-11-03 01:43:44.495098+00', 14892, 2, 106, 'ace', 'Original description added at request of the author:



1- 4::

  1st  and 3rd couples advance into the middle (2 pas de basque),  All join hands to make a line of four (right hand with partner) and set. 2nd and 4th couples step up on bars 3 – 4. 

5- 8::

  1st and 2nd , 3rd and 4th couples dance right hands across once round

9-10::

  1st man dance round 2nd woman and down, 3rd woman dance round 4th man and up, while 1st woman and 3rd man dance a ¾ turn with the left hand

11-12::

  1st and 3rd couples join in a line across the dance and balance in line

13-16::

  1st couple with 2nd and 4th women, and 3rd couple with 2nd and 4th men, dance right hands across once round

17-18::

  1st and 3rd couples turn partners with the right hand halfway round

19-20::

  1st man and 3rd woman dance a ¾ turn with the left hand, while 1st woman dance round 4th woman and 3rd man dance round 2nd man to meet in the middle for a reel of four

21-24::

  1st and 3rd couples dance a half reel of four down the middle of the set

25-28::

  1st and 3rd couples turn partners with the right hand 1¼ times, 3rd couple finish in their own place

29-32::

  1st couple lead to the top and cast off to the bottom.



Repeat, with a new top couple.

', 5);
INSERT INTO 'dancecrib' VALUES (11942, '2019-07-05 20:02:55.964104+00', '2020-12-30 10:43:42.923459+00', 15908, 2, 963, 'ace', '1-4::

  1c followed by 2c dance down middle  

5-8::

  2c followed by 1c dance up to finish 2c facing down, 1c facing up  

9-16::

  2c & 1c dance the rondel  

17-24::

  1c & 2c dance a poussette right round  

 25-32::

    1c & 2c dance the tournée  ', 5);
INSERT INTO 'dancecrib' VALUES (13576, '2021-01-23 07:03:30.491923+00', '2021-01-23 07:08:22.116034+00', 12265, 1, 202, 'ace', '1--::
  1c+2c set | cross RH ; chase clw ½ (2,1)
9--::
  2c+1c set facing on sides | change places EH, 1c in and up (to 1,2) ; 1c cast off, meet below 2c into promhold
17--::
  Reel3 across, 1c RSh to 2W. 1c in 1pl centre face up, 2c behind 1c
25--::
  2C Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (13968, '2021-04-21 23:00:53.182318+00', '2021-04-27 07:59:22.980083+00', 20335, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; ½ Fig8 up round 2c (2,1x,3)

9--::

  Mirror Reels3 on sides, 1c in and down, all giving hands where possible. On [16] 1c turn RH to face 1cnrs

17--::

  Corners Pass and Turn BH (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (1656, '2012-01-22 19:28:53.332915+00', '2015-11-04 22:56:04.721411+00', 7339, 1, NULL, 'ace', '1–::

  1c cross RH | cast off two (2c+3c up) ; 2c+1c A&R on the diagonal

9–::

  1c cross RH | cast up two (2c+3c down) ; 1c+3c A&R on the diagonal

17–::

  1c lead down the middle ; and up to 1pl facing out

25–::

  1c & 2c change place EH on sideline | 1c (inwards) & 3c repeat ; 1c (outwards) & 4c turn EH 1½ (to 2,3,4,1)



{{explanation}}

can be danced in a 3c set with only this change



25–::

  1c & 2c turn EH 1½ on sideline ; 1c (inwards) & 4c turn EH 1½ (to 2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (1989, '2012-01-22 19:29:13.776952+00', '2015-11-08 21:55:09.567647+00', 1358, 1, NULL, 'ace', '1–::

  All circle8 and back

9–::

  1c followed by 2c+3c+4c cast off behind sidelines {3} each cpl cross upwards, W passing in front of M, and dance up sidelines to (1x,2x,3x,4x) facing up

17–::

  All slip across into NHJ, M passing behind W | all C advance up ; retire | slip back to opposite side, M passing behind W (1x,2x,3x,4x)

25–::

  1W+2M cross RH | 1W+3W cross LH ; 1W+4M cross RH | All clap and swivel R on the spot (2 PdB), 

33–::

  1M+2W cross LH | 1M+3M cross RH ; 1M+4W cross LH | all clap and swivel R (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (8960, '2015-11-05 08:03:02.516858+00', '2015-12-27 15:16:50.752158+00', 16816, 1, NULL, 'ace', '1--::

  All set | cross RH ; set | turn P RH to face up in promhold (1,2,3)

9--::

  3C Allemande  (3,2,1) 

17--::

  All turn RH ½ and cast to opposite side ; Chase clw ½ (1,2,3)

25--::

  1c+2c Set and mirror link (1c cast, 2c dance up and curl into 1pl) ; 1c+3c turn EH 1½ (2,3,1)



', 3);
INSERT INTO 'dancecrib' VALUES (3138, '2012-01-22 19:30:12.902158+00', '2021-10-11 22:32:07.662619+00', 5671, 1, NULL, 'ace', '1-4::

  1c lead down, cross below 3c and cast up into 2plx (2c up)

5-16::

  2c+1c+3c R&L for 3 couples

17–::

  1c set to and turn corners, to finish BtoB in the centre, 1M facing up, 1W facing down

25–::

  1M+2c & 1W+3c Circle3 L (at end 1c pull Rsh back to face P) ; 1c set, petronella to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9644, '2017-03-05 03:36:20.160857+00', '2017-07-07 15:29:48.238496+00', 8468, 1, 202, 'ace', '1-- ::

 1c+2c set | cross RH ; set | turn RH ½ into promhold

9-- ::

 1c+2c Promenade

17-- ::

 1c cast (2c up on 17) | 2c+1c Circle4 L | 1c set advancing to face 1cnrs

25-- ::

 1c turn CPCP (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13208, '2020-09-28 04:20:16.0709+00', '2020-09-28 04:29:11.935502+00', 19867, 1, 202, 'ace', '1--::

  1c & 2c Petronella Turn to midline | ½ Reel4 | Petronella Turn to sides (2,1,3)

9--::

  All set | all pass P RSh to opposite sides | all chase clw ½ (3,1,2)

17--::

  All turn P RH ; turn P LH (3,1,2)

25--::

  3c+1W & 1M+2c RHA. 1c end in centre LSh to P ; LSh »Snake Pass« [unwind the RHA, 1c leading, pass other snake LSh through 2plx and chase cclw] (2,1,3)



*Deviser''s note:  

Second time through couples need to anticipate the transition from the snake pass into the petronella reel progression.*', 2);
INSERT INTO 'dancecrib' VALUES (8855, '2015-08-13 20:34:13.968264+00', '2023-02-04 01:23:05.71235+00', 14290, 3, NULL, 'ace', '1-8::
    All 4 Ladies join hands, dance across top of set, behind Men, across
    bottom & back to places
9-16::
    Men repeat bars 1-8
17-24::
    RSh reels of 4 on sides
25-32::
    1s lead down and back
33-40::
    1s+2s also 3s+4s circle 4H round & back
41-48::
    1s cast to 4th place & birl _while_ 2s+3s+4s dance RH across then
    lead up 1 place', 0);
INSERT INTO 'dancecrib' VALUES (9648, '2017-03-07 09:38:29.826945+00', '2019-03-03 12:43:50.94726+00', 10651, 1, 202, 'ace', '1--::
 1W+2M & 3W+4M set | turn RH to midline, finish M facing up, W dn ; ½ Reel4, finish 4M/3W/2M/1W (on middle) facing 2W/1M/4W/3M (on sidelines)
9--::
 1M+3W+3M+1W & 4M+2W+2M+4W Parallel Rsh Reels4 on M/W sides
17--::
 1M+2W & 3M+4W set | turn LH to midline, finish W facing up, M dn ; ½ Reel4, finish in middle
25--::
 4c+3c (4M facing 3W on opposite sides) & 2c+1c (2M facing 1W on opposite sides) RHA to (4x,3x,2x,1x) ; 4c+3c+2c chase clw ½ way _while {4}_ 1c swing (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11482, '2019-01-01 01:58:07.330627+00', '2023-02-04 01:23:05.94835+00', 18963, 3, NULL, 'ace', '1-8::
    1s set, set again advancing, passing partners to finish back-to-back
    facing 2s. 1M+2L and 1L+2M turn 2H twice (4 bars)
9-16::
    1s+2s dance reel of 4 across, 1s do not pass at end but take Left
    hands to…
17-24::
    1s (on opp sides) lead down (3 bars), lead up (3 bars), cross and
    cast to 2nd places own side (2s step up 23-24)
25-32::
    2s+1s dance all-round (diamond) Poussette', 0);
INSERT INTO 'dancecrib' VALUES (10497, '2018-03-10 18:03:16.84989+00', '2022-07-03 19:51:17.05809+00', 10563, 2, 202, 'ace', '1-8::

  1s cross  Rhand, cast off 1 place. 1L 1/2 fig of 8 up through 2s while 1M 1/2 fig of 8 through 3s.   Finish facing 1st corner.

9-12::

  1s dance 1/2 Rshldr reel of 4 with 1st corners. 1s finish in the middle, pull Rshldrs back and face 4th corners – partner’s 2nd corner.

13-16::

  1s dance 1/2 Rshldr reel of 4 with 4th corners.  1s finish in the middle, pull Rshldr back and face 3rd corners – partner’s 1st corner.

17-20::

  1s dance 1/2 Rshldr reel of 4 with 3rd corners.  1s finish in the middle, pull Rshldr back and face own 2nd corner.

21-24::

  1s dance 1/2 Rshldr reel of 4 with 2nd corners.  1s finish in the middle ready for …

25-32::

  1s turn Rhand for 4 bars while 2s and 3s chase clockwise for 8 bars – 1s join chase on bar 29 – 1L between 2L & 3L, 1M between 2M and 3M to finish on own sides (2,1,3,4)

33-40::

  Circle 6 hands round and back.', 2);
INSERT INTO 'dancecrib' VALUES (3057, '2012-01-22 19:30:08.67247+00', '2020-01-22 18:17:52.998568+00', 11723, 1, NULL, 'ace', '{{explanation}}

This dance also works in a 5C set; in a 4c set the Men should from [17] (once or twice) dance 1 place cclw, so that the women advance 3 places w.r.t. the Men.



1–::

  NHJ with P advance to the centre | NHJ with cnr retire ; turn cnr RH

9–::

  NHJ with cnr advance to the centre | NHJ with P retire to place ; Turn P LH

17–::

  (Two hands of a 3c L-Chain:): All W RHA 2 places | Turn new man LH ; Repeat (all W have moved one place clw).

25–::

  With new P promenade at will, finding two new couples to face in time to start again.', 2);
INSERT INTO 'dancecrib' VALUES (11946, '2019-07-05 21:17:06.551121+00', '2019-07-05 21:21:23.621648+00', 15923, 1, 202, 'ace', '1--::

  1c, 2c & 3c turn P RH ½, face P and cast away to exchanged places ; all chase clw ½ (3,1,2)

9--::

  2c (1c following) dance up and cast round 3c (to 3,1,2) ; 1c (3c following) dance down and cast round 2c (1,3,2)

17--::

  3c+2c turn EH 1½ on sides, 3c in and down (to 1,2,3) ; 1c+2c turn EH 1½ on sides, 2c in and up. 2c face out (2,1,3)

25--::

  Mirror Reels3 on sides, 1c in and down (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11944, '2019-07-05 20:35:47.977402+00', '2020-12-30 10:36:42.88529+00', 15910, 2, 963, 'ace', '1-4::

  1c 2H 1/2 turn; dance down one place  2s up 3&4

5-8::

  2c,1c,3c 3 hands across 1c finish btob facing opp side  

9-16::

  All set; 1c dance rt shld round each other to face own side WHILE  

  2c&3c dance ccw one place on; repeat 13-16  3x,1x,2x  

17-24::

  3,1,2 rt shld reel of 3 across, 1c cross to own sides on 23&24  

25-32::

  diag r&ls twice, w up, man down

  ', 3);
INSERT INTO 'dancecrib' VALUES (9641, '2017-03-05 03:09:37.442943+00', '2021-03-19 11:00:24.9687+00', 8471, 1, 202, 'ace', '1--::

 1c+2c Poussette

9--::

 1c lead down (2c up on 11) ; 1c lead up to face 1cnrs

17--::

 1c set and turn BH 1cnrs ; 1c set and turn BH 2cnrs (2,1x,3)

25--::

 1c lead to top, cross and cast in centre ; 1c dance down (3c up on 29) | turn BH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (13577, '2021-01-23 09:54:51.597953+00', '2021-01-23 10:24:22.545309+00', 12159, 1, 202, 'ace', '1--::

  1c turn RH | cast off (2c up) ; turn LH 1½ to 2plx facing 2cnrs and out (2,1x,3)

9--::

  ½ Reels3 on sides, 1c LSh to 2cnrs, pass LSh in centre ; ½ Reels3 on sides, 1c LSh to 4cnrs[pos] into facing lines3 across, 1M between 3c facing up

17--::

  All A&R ; 1c turn RH 1¼ to 2pl (2,1,3)

25--::

  All A&R ; 1c turn RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9640, '2017-03-05 02:48:30.816115+00', '2021-03-19 11:02:12.747057+00', 8469, 1, 202, 'ace', '1--::

 Circle6 and back

9--::

 1c lead down (2c up on 11) ; 1c lead up to face 1cnrs

17--::

 1c turn CPCP to 2pl facing out (2,1,3)

25--::

 1c+3c turn EH 1 ½ ; 1c turn RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (1853, '2012-01-22 19:29:06.156546+00', '2021-01-23 11:40:21.426552+00', 11561, 1, NULL, 'ace', '1–::

  1M+2M+3M A&R _while_{4} 1W+2W+3W stand {2} | advance ; 1W+2W+3W dance Lsh round P to places, 2W facing out

9–::

  Reels3 on own side, 2c starts out and up

17–::

  1c long cast to 2pl (2c up) ; all set | All set, 1c passing Lsh into BtoB facing cnrs

25–::

  All set as in DTr | All set, 1c advancing to 2plx ; 1c turn RH 1½  (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3011, '2012-01-22 19:30:06.812969+00', '2020-09-02 17:50:15.869087+00', 5238, 1, NULL, 'ace', '1–::

  1c dance between 2c and cast to place ; dance between 3c and cast up to face 1cnr (2c up)

9–::

  1c+1cnrs Reel4, at end 1c turn LH ¾ to face 2cnr

17–::

  1c+2cnrs Reel4, to (2,1,3) (omit last Lsh)

25–::

  2c+1W & 1M+3c Reels3{6} across, Lsh to 1cnr | All set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8972, '2015-11-12 00:28:47.639544+00', '2016-01-21 14:07:54.269955+00', 15275, 1, NULL, 'ace', '1--::

  1c ½ Fig8 round 2c ; ½ Fig8 round 3c (2c up on [7-8]) (2,1,3)

9--::

  All dance Rsh round P, to own side ; All chase clw ½ (3x,1x,2x)

17--::

  3c+1M & 1W+2c RHA ; 3C+1W & 1M+2c LHA (3x,1x,2x)

25--::

  All chase cclw ½ ; All dance Lsh round P, to own side (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8964, '2015-11-08 23:16:32.164823+00', '2015-11-08 23:16:32.164823+00', 14427, 1, NULL, 'ace', '1--::

  1c+4c cast inwards (2c+3c to end) | 1c+4c cross, W NHJ passing between the M ; cross back, M NHJ passing between W | 1c+4c set (2,1,4,3)

9--::

  2c+3c repeat (1,2,3,4)

17--::

  1c+2c & 3c+4c RHA ; All turn P RH, finish BHJ with P, for

25--::

  4C Poussette (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8965, '2015-11-09 13:15:00.348338+00', '2015-11-09 13:15:00.348338+00', 16785, 1, NULL, 'ace', '1--::

  1c+2c R&L (1,2,3)

9--::

  1c cross RH | cast (2c up) ; turn RH 1½ to (2,1,3)

17--::

  1c (cross down) Fig8 round 3c (2,1,3)

25--::

  2c+1c Circle4 L ; 1c+3c Circle4 R (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8966, '2015-11-09 14:11:50.454693+00', '2015-11-09 14:14:04.305142+00', 16709, 1, NULL, 'ace', '1--::

  1c cross RH | cast (2c up) ; ½ Fig8 round 2c (2,1,3)

9--::

  Mirror Reels3 on sides, 1c start in and down, 2c dance in and cast off, join hands when possible

17--::

  1c lead down | turn RH (2c down) ; and lead to top (1,2,3)

25--::

  1c+2c Poussette (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8967, '2015-11-09 20:22:22.701442+00', '2015-11-09 20:22:22.701442+00', 10028, 1, NULL, 'ace', '1--::

  1c turn RH | cast off (2c up) ; ½ Fig8 round 2c (2,1x,3)

9--::

  1c+2cnr holding NH, 1c dance forward ¼ turn as 2cnr sets | 1c+2cnrs set pivoting R ½ into facing lines across (1M between 2c, 1W between 3c) ; 1c+2cnrs ½ diag. R&L up/down

17--::

  1c repeat [9-12] with 1cnrs ; 1c+2cnrs ½ diag. R&L (3x,1,2x)

25--::

  1M+2W & 1W+3M in promhold pass RSh to change places diagonally, 1c looping to finish in 2plx ; 1M+3M & 1W+2W in promhold pass LSh to change places diagonally, 1c looping to finish in 2pl (2,1,3) 

', 3);
INSERT INTO 'dancecrib' VALUES (8968, '2015-11-09 21:18:51.80803+00', '2015-11-09 21:18:51.80803+00', 3202, 1, NULL, 'ace', '1--::

  1c+3c turn RH | cast off (2c+4c up) ; turn P LH 1½ to finish 1c between 2c and 3c between 4c, all M facing up and W facing down

9--::

  All BiL with PdB/Coupé

17--::

  All start Rsh into Reels4 across, 3c finish in 4pl and 1c pass Lsh to face 1cnr 

25--::

  1c with cnrs CPCP, finish (2,1,4,3,5)

*Bottom four couples repeat, finishing (2,4,1,5,3)*

*Ten times through in all.*

', 3);
INSERT INTO 'dancecrib' VALUES (8969, '2015-11-09 22:18:54.837359+00', '2015-11-09 22:18:54.837359+00', 4266, 1, NULL, 'ace', '1--::

  All set | 1c turn RH ½ into ; RHA 1 1/8 times, finish M on sidelines and W on midline

9--::

  Double “Highland Schottische Petronella”: All on R foot, facing in, finish on sideline facing out | All L foot, finish in diamond ; repeat .  Finish in diamond in opposite place

17--::

  1c+2c L-Chain on 2diag

25--::

  LHA 1 1/8 ; 2c turn LH ½ | All set (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8970, '2015-11-09 23:10:45.248531+00', '2015-11-09 23:10:45.248531+00', 8335, 1, NULL, 'ace', '1--::

  1c turn RH and cast (2c up) ; All set | 2c+3c set as 1c Petronella to midline

9--::

  All set in lines across | 2c+3c set as 1c petronella to face 1cnr ; ½ Reel4 with 1cnrs, pass Rsh, and face 2cnr

17--::

  1c+2cnrs ½ Reel4 , 1c pass through 2plx ; 1c dance Rsh round P 1½ (Gypsy turn) (3x,1,2x)

25--::

  All chase clw ½ ; All turn P RH (1c 1½ times) (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2099, '2012-01-22 19:29:20.008531+00', '2021-01-23 20:50:25.25046+00', 11512, 1, NULL, 'ace', '1–::

  All dance parallel Reels4 on own sides

9–::

  All set to P | 1M+2W & 3M+4W cross RH ; 1W+2M & 3W+4M cross LH | 2c+3c cross RH _while_{2} 1c+4c turn RH 1¼ to the midline facing P

17–::

  1c+4c H.Schottische Poussette (2,4,1,3)

25–::

  2c+4c & 1c+3c circle4 and back', 3);
INSERT INTO 'dancecrib' VALUES (8952, '2015-10-28 22:36:18.246627+00', '2015-11-11 11:34:50.302459+00', 3483, 1, NULL, 'ace', '1--::

  1c ½ Fig8 round 2c ; 1c+2c RHA, finish 1M between the W in line across in 1pl and 2M (no polite turn) on midline in 2pl, all facing down

9--::

  All dance down, on [12] 1M+2M pivot R to face up ; dance on, 1W+2W pivoting on [13] to join 2M in line across dancing up, on [16] 1M pivots R to face 2M on midline while both W finish on sides, in diamond formation

17--::

  All set | Circle4 L ½ ; All turn P BH and open into | Circle4 L ½ , to the same diamond

25--::

  All set | 1W+2W set as 1M+2M change places Rsh and face P ; All turn P BH to sidelines, 2c (above) turning twice, 1c turning 1½, cover at the end. (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8971, '2015-11-09 23:47:12.496127+00', '2015-11-12 00:06:29.900466+00', 11842, 1, NULL, 'ace', '1--::

  1c+2c+3c+4c Circle8 and back while{8} 5c dance ad lib

9--::

  1c+5W & 5M+3c RHA ; 5c turn LH 1¼ 

17--::

  5W+4c & 5M+2c RHA ; 5c turn LH

25--::

  1c+5c+3c all in promhold Reel3, 5c Lsh to 3c 

33--::

  2c+5c+4c all in promhold Reel3, 5c Rsh to 4c

41--::

  1c+2c+3c+4c petronella in tandem one place cclw and set _while{4}_ 5c in promhold set twice rotating L to face top ; 2c+5c ½ RHA and set (5,3,4,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (8973, '2015-11-14 16:36:49.446636+00', '2015-11-14 16:36:49.446636+00', 13118, 1, NULL, 'ace', '1--::

  Circle4 and back

9--::

  R&L

17--::

  1c set to 2c | change places, 1c making arch ; repeat back, 2c making arch 

25--::

  1c set to 2c | change places with opposite RH ; Pivot P in elbow grip to face new couple

', 3);
INSERT INTO 'dancecrib' VALUES (8974, '2015-11-15 00:29:42.478575+00', '2015-11-15 01:10:51.637655+00', 13931, 1, NULL, 'ace', '1--::

  1c+2W & 2M+3c Reels3 across, to start 1c & 3c pass P Rsh, 2c finish in 2pl as 1W & 3M face P on 1diag. 

9--::

  1c+3c Reel4 on 1diag, on [15-16] 1W & 3M cast cclw to own place (1,2,3,4)

17--::

  1c+2c ¾ DblFig8 | 2c cross RH as 1c cast to 3pl (3c up) (2,3,1,4)

25--::

  1c, 4c following, dance up between 3c and cast off 2 ; 4c+1c RHA (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8137, '2013-12-19 22:47:24.897539+00', '2019-03-11 19:45:07.530827+00', 15313, 1, NULL, 'ace', '1–::

  1c set | 1M cast off 2 and dance up the middle (2c up) _while_{4} 1W dance down the middle and cast up (to 2,1,3) | All set

9–::

  Teapots R ; and L (2c+1W & 1M+3c RHA ; 1c LHA with other end), at the end the corners face out (2,1,3)

17–::

  Reels3 on the sides, 1c Rsh to 4cnr (2,1,3)

25–::

  1c+3c set | ¾ of R&L (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (10720, '2018-05-01 05:20:33.971542+00', '2020-09-28 18:59:42.236588+00', 14422, 1, 202, 'ace', '1--::

  Circle8 and back

9--::

  ½ Gr-Chain starting Rsh to P, no hands ; all turn P LH (3,4,1,2)

17--::

  1c+3c ½ R&L ; 2c+4c ½ R&L (omit polite turn)

25--::

  All turn cnr RH into promhold {2} | chase cclw, M (with new P) progressing one place clw



*Deviser''s note:  

Can be danced either 32S+32J twice or 2x32S+2x32J*', 4);
INSERT INTO 'dancecrib' VALUES (11663, '2019-03-12 22:44:28.373394+00', '2019-03-12 22:44:28.373394+00', 19241, 2, NULL, 'ace', '1-8::

  1C lead down, 1W turns under 1M arm & lead up to 2nd place (2C up on 3-4), 2C+3C step in & all take promenade hold on 7-8

9-16::

  2C+1C+3C Promenade, finish with 1C facing 2W with nearer hands joined, 1W on 1M’s Left

17-24::

  1C sets to 2W, pulling back RSh sets to 3W, 3M & 2M, finishing facing up

25-32::

  1C dance up & cast to 2nd place still on opposite sides, 1C dance 1/2 turn and twirl, while 2C+3C turn RH once round', 5);
INSERT INTO 'dancecrib' VALUES (8407, '2014-09-25 12:43:20.54791+00', '2017-03-09 16:11:10.062101+00', 7313, 2, 274, 'ace', '1-8:: 

  1c set, cast down ; 1/2 fig8 around 2c

9-16::

 2c+1c+3c set&link ; 1l+3c and 1m+2c 1/2 LSH Reel3 across the set. 1l start to 3l, 1m start to 2m

17-24::

 1c+2c+3c set&link ; 3l+1l+2l and 3m+1m+2m 1/2 LSH Reel3 on sides. 1c finish facing 1st corner

25-32::

 Hello Goodbye setting

', 5);
INSERT INTO 'dancecrib' VALUES (8975, '2015-11-15 22:46:25.92614+00', '2015-11-15 22:46:25.92614+00', 13119, 1, NULL, 'ace', '1--::

  1c set | cross RH ; cast off (2c up) and turn P LH for 1W with her P behind her to face 2M 

9--::

  2M+1c +3W lead-change diag. Rsh Reel3, 1c changing lead at each end, and finish facing 3M

17--::

  2W+1c+3M lead-change diag Lsh Reel3, finish (2,1x,3)

25--::

  S&Link3 twice (3x,1,2x)

33--::

  Diagonal R&L (2,1,3)





', 3);
INSERT INTO 'dancecrib' VALUES (9649, '2017-03-07 15:49:57.387175+00', '2022-08-13 21:33:55.967788+00', 17631, 1, 202, 'ace', '1--::

  1c+2c R&L

9--::

 1c lead down between 2c, cross and cast up ; cross RH and cast (2,1)

17--::

 2c+1c set | cross RH ; set | turn P RH ½ into promhold facing up

25--::

 2c+1c Promenade', 2);
INSERT INTO 'dancecrib' VALUES (2919, '2012-01-22 19:30:02.926152+00', '2019-03-12 11:37:15.777576+00', 4929, 1, NULL, 'ace', '1–::

  1c+3c RHA, LHA, to own places, but 3c facing 2c and 1c facing 4c, all taking NHJ and forming two facing diagonal lines

9–::

  All A&R (towards other line) ; half R&L with couple opposite (to 4,3,2,1)

17–::

  1c+3c ½L-Chain (across) ; 2c+4c repeat

25–::

  Repeat 17-24

33–::

  Repeat 9-16 to original places, finishing in promhold facing cclw

41–::

  All Promenade once round cclw.



{{explanation}}

2nd turn of dance



1–::

  2c+4c RHA, LHA to finish in lines on other diagonal, 2c facing 1c and 4c facing 3c

9–::

  All A&R (towards other line) ; half R&L with couple opposite (to 2,1,4,3)

17-32::

  As above, 2c+4c starting

33-48::

  As above, Promenade is again cclw.', 2);
INSERT INTO 'dancecrib' VALUES (3409, '2012-01-22 19:30:24.198602+00', '2021-03-27 19:31:57.517902+00', 6657, 1, NULL, 'ace', '1-4::

  1c+3c set | and cast clw to 2pl/4pl facing in, _while_{4} 2c+4c advance NHJ (skip change) | set facing centre swiveling R to face side, (to 1,2,4,3 across dance).

5-12::

  Reels4 across

13-16::

  1c+2c & 3c+4c ½ LHA | 1c+3c ¾ RHA to original places, but having changed places with P.

17–::

  ½ G-Chain, 2 steps per hand

25-48::

  Repeat 1-24 with 2nd and 4th Cs leading

49–::

  All W ½ LHA, turn opposite man RH, ½ LHA, turn P ½ to put men in centre

57–::

  Men repeat. Finish with W facing out

65-80::

  Schiehallion reels.

81–::

  Circle8 and back.

', 2);
INSERT INTO 'dancecrib' VALUES (3019, '2012-01-22 19:30:07.128827+00', '2020-09-02 17:52:25.492189+00', 5264, 1, NULL, 'ace', '1–::

  1c dance between 2c, cast up ; cross RH, cast off (2c up) (2,1x)

9–::

  2c+1c L-Chain, finish LHJ in sidelines, M facing out (2,1x)

17–::

  2c+1c BiL | change places LH on sides ; repeat, the M with a polite turn to face in (2,1x)

25–::

  1c ½Fig8 between 2c ; turn RH', 3);
INSERT INTO 'dancecrib' VALUES (2313, '2012-01-22 19:29:31.126496+00', '2015-11-18 10:27:07.887547+00', 2437, 1, NULL, 'ace', '1–::

  2c step up as 1c turn BH to face P between them in line4 across | 1c+2c set, 1c advancing and passing  on the second step ; ½Reel4, at end 1c pass LH to face down NHJ

9–::

  1c dance down to face P between 3c, repeat set and ½Reel4 with 3c, finish between 3c on own side LHJ

17–::

  1c lead to top, cross and cast to 2plx ; ½Reels3 across, Rsh to 4cnr (W up, M dn) (to 2,1,3)

25–::

  2c+1c Poussette.', 4);
INSERT INTO 'dancecrib' VALUES (8976, '2015-11-18 23:51:07.131939+00', '2015-11-18 23:51:07.131939+00', 14025, 1, NULL, 'ace', '1--::

  1c dance between 2c and cast up to place ; dance ½ Fig8 round 2c (1x,2,3)

9--::

  1c cross down into mirror Reels3 on own side, 2c starting out and up (1,2,3)

17--::

  1c (start inwards) change place with 2c EH and face out | 1c turn 3c EH to face up in the middle ; 1c dance to top and cast off (2,1,3)

25--::

  All A&R and clap on last beat of [28] ; All turn P RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8208, '2014-03-13 23:29:18.220607+00', '2022-04-15 10:29:04.105382+00', 13132, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c R&L

9–::

  1c+4c set and cast to middle (2c+3c to end) ; 1c+4c LHA and stay facing cclw

17–::

  1W +4W following ½ Reel3 across with 2c (1W Lsh to 2M) _while_{4} 4M +1M following likewise with 3c (2x,4x,1x,3x) ; All set and cross RH

25–::

  Circle8 and back (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11984, '2019-07-27 11:52:32.10394+00', '2022-10-26 07:55:49.13663+00', 19491, 1, 1645, 'ace', '1-::
  1c & 4c cross RH | cast inwards (2c & 3c to ends) ; 2W+1M+4W+3M &frac12; diag RSh Reel4 _while_ 2M+1W & 4M+3W set | turn BH
9-::
  2M+1W+4M+3W &frac12; diag RSh Reel4 _while_ 2W+1M & 4W+3M set | turn BH ; 1c/4c lead down/up between 2c/3c, cross and cast inwards (3x,4x,1x,2x)
17-::
  1c lead down | lead up{4} above 3c (4c down [19-20]) | cast off (3x,1x,4x,2x)
25-::
  Circle8 &frac12; way to L ; 4c+1c Circle4 to R (2,4,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (2637, '2012-01-22 19:29:51.004377+00', '2015-11-29 21:24:24.540211+00', 3695, 1, NULL, 'ace', '{{explanation}}

2c is dancing couple, corners refer to 1c and 3c positions



1–::

  2c turn ¾ RH | 1c+2W & 2M+3c ½ LHA ; 2M&2W cast left round their 1cnr pos. to face 1cnr pos. _while{4}_ 1c+3c ½ R&L starting along sidelines (to 3, 2x,1)

9–::

  2W+3M & 2M+1W (1cnr pos) ½ LH turn | 1W+3M ½ RH turn _while{2}_ 2c set ; 2W+1W & 2M+3M ½ LH turn | 2c RH turn to face 2cnr pos. _while{2}_ 1W+3M set

17–::

  Repeat figure with 3W & 1M (i.e. 2cnr positions), finish (1x,2,3x)

25–::

  1c+2c ½ RHA | 1c+3c ½ LHA ; 2c turn RH 1½ _while{4}_ 1c turn LH 1½ (to 2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2141, '2012-01-22 19:29:22.24885+00', '2015-11-30 08:59:16.600481+00', 1864, 1, NULL, 'ace', '1–::

  1c lead down the middle (2c up on [3-4]), on [4] 1c change side while facing down, 1W passing below P under their joined R arms as 1c turn inwards ; 1c lead up on opposite side to (2,1x,3) 

9–::

  2c+1c R&L, to face 1cnr

17–::

  1c turn corner, P, corner, P

25–::

  2c+1c circle4 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (8979, '2015-11-27 08:27:17.882906+00', '2016-11-12 23:36:09.233722+00', 16824, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c 1/2 RHA | 1c+4c LHA _while{4}_ 2c+3c chase clw half round | 3c+1c & 4c+2c Turn opposite RH ½,  taking 1c/4c to 1plx/4plx, and 3c/2c into 2pl/3pl in the middle facing them

9--::

  Half Schiehallion Reel {8} (modified phrasing, starting from the middle and from the end places), 

17--::

   4c & 1c (outers) turn 2c & 3c (inners) RH 1½ ; 3c+2c set | cross RH (2,4,1,3)

25--::

  Circle8 and back (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9650, '2017-03-12 23:05:07.145597+00', '2017-03-14 13:19:47.203642+00', 17637, 1, NULL, 'ace', '1--::

  1c+2c set | ½ RHA ; set | 2c cross RH to own side as 1c turn LH to face 1cnr

9--::

  1c+1cnr turn RH and face ; ½ Reel4 on 1diag, 1c pass Lsh to face 2cnr

17--::

  1c+2cnr turn RH and face ; ½ Reel4 on 2diag, finish (2,1x,3)

25--::

  2c+1M & 1W+3c ½ Reels3 across, Lsh to 3cnr ; ½ Reels3 on sides, Rsh to 4cnr (at end the corners loop) (2,1,3)

33--::

  1c dance to top and cast off, dance down between 3c and loop to 3pl (3c up) | 1c set (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (8978, '2015-11-23 15:12:18.002669+00', '2017-04-02 19:08:07.226779+00', 8047, 2, 2781, 'ace', '1-::

  1s+2s+3s dance mirror reels of 3 on own sides



9-::

  1s turn RH and cast to 2nd place, 1s dance back to back and face down 



17-::

  All dance Grand Chain 



25-::

  2s+1s+3s circle 6H round and back 

', 2);
INSERT INTO 'dancecrib' VALUES (3035, '2012-01-22 19:30:07.757405+00', '2020-09-02 18:01:08.644067+00', 5327, 1, NULL, 'ace', '1–::

  1c facing 2c set, change places on sides RH, 1M (1W following) facing out casts up and across to 1plx (2c down) (1x,2)

9–::

  1c facing 2c set, change places on sides RH, ½ M-Chain (1c now on M side, 2c on W side)

17–::

  1c followed by 2c lead (RHJ) down the middle (M on L) ; change sides, M dances below W who inwards under his arm, lead up (2c leading) (2,1)

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (8046, '2013-09-22 18:48:13.455401+00', '2017-03-09 16:19:18.482202+00', 14484, 1, NULL, 'ace', '{{explanation}}

5c starts in the middle facing P, 5M above 5W



1–::

  1c+2c+3c+4c making arches advance to centre | set turning towards corner and join NH ; with cnr dance out making arch | set advancing to original places _while_{8} 5c dances through arch on the R (5M between 4c, 5W between 2c) | cast L to diagonal ; dance in through the arch to the centre | Gypsy Turn (pass Rsh, face P and 5M swivel R) to face 2c, 5M with 5W behind

9–::

  4c+2c in promhold + 5c Rsh lead-change Reel3, finish 5c (5M leading) facing 1c

17–::

  Repeat with 1c+3c, using Lsh, 5c finish in middle 5M leading,

25–::

  2c+5c RHA ; 5c+4c LHA, 5c finish facing 1c, 5W on R

33–::

  5c (centre couple) NHJ dance under arch by 1c (outside couple) | 5c change places, 5W dancing under joined arms and 5M round behind, _while_{2} 1c Gypsy Turn to face 2c ; 1c+2c repeat, and 2c face 3c

41–::

  2c+3c repeat ; 3c+4c repeat, finish 4M above and facing 4W (5,1,2,3,4)



{{explanation}}

Repeat 4 times', 3);
INSERT INTO 'dancecrib' VALUES (8913, '2015-09-22 14:25:39.411407+00', '2021-06-18 20:50:13.310938+00', 1481, 2, 160, 'ace', '1-8::

  1C dance down, cast up round 3C; dance in & up, cast round 2C.

9-16::

  1C (in&down) turn 3C HH; 1C (in&up) turn 2C HH.

17-24::

  1C3C RH Across ; 2C1C LH Across.

25-32::

  Grand Chain.', 0);
INSERT INTO 'dancecrib' VALUES (3202, '2012-01-22 19:30:15.516612+00', '2021-01-16 20:19:47.289397+00', 12059, 1, NULL, 'ace', '1-–::

  1c turn BH | cast to face 1cnr (2c up) ; ½ Reel4 with 1cnrs, pass Rsh to face 2cnr

9-–::

  ½ Reel4 with 2cnrs, Rsh Gypsy Turn to opposite side (3x,1x,2x) ; S&Link3 to lines across

17-28::

  R&L for 3 couples, end as started

29-32::

  S&Link3 to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9672, '2017-03-19 16:28:57.356914+00', '2018-08-17 12:28:44.082529+00', 17663, 1, NULL, 'ace', '1--::

  1c set | cast (2c up) ; All set | All cross RH and face right (2x,1x,3x)

9--::

  All chase clw half round ; 1c dance ½ Fig8 to the L (M up, W down) and meet, pivoting R into DTr position facing opp. side

17--::

  All DTr {for 6 bars} | 1c set, first pivoting R to face P, then pivoting to face up, _while{2}_ 3c+2c set advancing and face up (3,1,2)

25--::

  3C Allemande (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9657, '2017-03-18 04:50:54.625953+00', '2017-08-25 06:13:41.098627+00', 17658, 1, 202, 'ace', '1--::

 1W followed by 1M cast off one |cross to 2plx (2c up) ; 2c+1c RHA, at end 1W & 2W finish facing out (2,1x,3)

9--::

 Parallel Rsh Reels3 (2,1x,3)

17--::

 1W followed by 1M cast off one |cross to 3pl (3 up) : 3c+1c LHA, at end 1W & 3M finish facing out (2,3,1)

25--::

 Parallel Lsh Reels3, at end 2W finishes facing out (2,3,1) ', 5);
INSERT INTO 'dancecrib' VALUES (13122, '2020-09-03 14:18:16.257178+00', '2020-09-11 11:06:08.250453+00', 1765, 2, 2784, 'ace', '1-::

  1c+2c set and 1c cast _while{2}_ 2c cross up giving LH ; 2c+1c 1/2 LHA and change places on the sides (no hands) (2,1x,3,4)

9-::

  2c+1c+3c Reel3 on sides (1c+3c give RS)

17-::

  2c+1c L-chain

25-::

  1c+3c turn RH to finish in line across, W BtoB in middle ; 1c+3c 1/2 Reel4

33-::

  3W+1W dance out to sides _while{2}_ 1M+3M pass RS to meet P | 1c lead down to 4pl _while{2}_ 3c lead up to 2pl _and_ 4c step up ; 3c+1c turn RH ', 2);
INSERT INTO 'dancecrib' VALUES (14713, '2022-03-28 17:33:07.121673+00', '2022-03-28 17:36:20.712937+00', 15172, 1, 202, 'ace', '1--::

  Reels3 on sides, 1c in and down (1,2,3)

9--::

  DblFig8, 1c crossing down (1,2,3)

17--::

  1c (+2c who dance up to follow) lead down ; 2c (+1c following) lead up. On [24] 1c in 2pl centre face down NHJ, 3c step in and face up NHJ (2,1,3)

25--::

  1c+3c Rondel (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11330, '2018-11-07 12:57:12.183668+00', '2022-11-13 18:18:02.035795+00', 18357, 1, 202, 'ace', '1--::

  1c+2c+3c 6 bars of »Criss, Cross and Cast«  [1c cross down to 2plx _as_ 2c cross down to 3plx and face out _as_ 3c cast to 1pl (to 3,1x,2x)  | all repeat twice same pattern (to 1,2,3), all face in] | 1c set advancing to centre (1,2,3)

9--::

  1c slip down (2c up) | change places BH with 2 PdB ; slip back to 2plx centre |  Pivot R to face 1cnrs

17--::

  2 bars of SetH&G | turn P LH to face 4cnrs[pos] _while{4}_ cnrs stand still | chase clw one place ; 1c turn 4cnrs[pos] RH and face 4cnrs[pos]

25--::

  2 bars of SetH&G | turn P LH to face 3cnrs[pos] _while{4}_ cnrs stand still | chase clw one place ; 1c turn 3cnrs[pos] RH to 2pl (3x,1,2x)

33--::

  3c+2c ½ DblFig8, 3c crossing down _while{4}_ 2c set twice (to 3,1,2) ; all turn P RH', 2);
INSERT INTO 'dancecrib' VALUES (14833, '2022-05-21 23:24:31.867542+00', '2022-05-29 10:49:58.552385+00', 20390, 1, 1645, 'ace', 'Set of 5 dancers: 1-4 in a diamond, 5 facing 1 at the top

1--::
  1+5+3 Reel3 up/down, 5 starts RSh to 1, 5 ends in centre facing out between 4 & 1
9--::
  5 sets as in DTr with 4+1 | then with 3+4 ; then 2+3 | then 1+2
17--::
  4+5+2 Reel3 across, 5 starts LSh to 4, 5 ends facing 1
25--::
  5+1 change pl RH | 1+3 LH ; 3+4 LH | 4+2 RH, 2 ends facing up to 5 (5,4,1,3,2)
', 2);
INSERT INTO 'dancecrib' VALUES (7845, '2013-08-21 08:31:49.654714+00', '2023-02-04 01:23:05.960777+00', 10302, 3, NULL, 'ace', '1-8::
    1s+2s+3s cross RH, chase clockwise 1/2 way & set
9-16::
    3s+2s+1s cross LH, chase anticlockwise 1/2 way & set
17-24::
    1s cast 1 place, dance 1/2 Fig of 8 round 3s & cross RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13692, '2021-02-24 00:27:00.465333+00', '2021-02-24 00:32:00.69339+00', 8916, 1, 202, 'ace', '1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) (to 2,1x,4x,3) ; 1c+4c change places LH (to 2,4x,1x,3) | 2c+4c & 1c+3c changes places RH into reel4 position (4x,2,3,1x)

9--::

  Parallel Reels4 on sides (4x,2,3,1x)

17--::

  4c & 1c turn P RH ½. 4c & 1c both RHJ finish 4c facing down and 1c facing up) | 4c & 1c lead to centre and meet ; 4c+1c RHA. 4c & 1c both RHJ finish 1c facing down and 4c facing up

25--::

  4c & 1c lead out through ends places | cast inwards (2c & 3c step out) ; all turn P RH (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8409, '2014-09-26 22:37:43.652225+00', '2021-03-17 23:37:19.010186+00', 15281, 1, NULL, 'ace', '1--::

  1M+2M & 3W+4W dance Rsh round P and face P ; set to P | cast away (Rsh back) to own place 

9--::

  1W+2W & 3M+4M S&Link on the side ; 1W+3W & 2M+4M S&Link [positions now: 1M,4M,2M,3M facing 2W,3W,1W,4W]

17--::

  “4C Bourrel”:  2W & 3M cross and cast L to other end on midline _while{4}_ 1M+4M+2M who face 3M+1W+4W (diagonally) set advancing | turn opposite BH ½, twirl R to face P along the midline ; All set | turn BH ¾ to (3,1,4,2)

25--::

  Circle8 and back

', 3);
INSERT INTO 'dancecrib' VALUES (11664, '2019-03-12 22:52:09.464276+00', '2021-01-17 00:22:35.078871+00', 17563, 2, NULL, 'ace', '1-8::

  1C+2C set, 1C cast one place while 2C dance up into 1st place & face out; 1M+2M turn LH while 1W+2W turn RH, 2C finish in 1st place in a line across facing down with 1C between them nearer hands joined, facing up

9-16::

  1C+2C set, 1M+2M turn LH while 1W+2W turn RH to bring 1C into 2nd place; 1C cross down (nohands) to below third place and turn 3C; 1M+3W with LH and 1W and 3M with RH to finish with 1C in 2nd place opposite sides

17-24::

  1C cross RH, cast to their right to finish in centre facing up or down while 2C+3C set to each other & cross RH; 1C change places LH up or down & cast to their left to finish 2nd place opposite sides while2M+3M and 2W+3W set up and down & change LH on sides

25-32::

  1C passing LSh dance 1/2 diagonal reel of four with 1st corners; 1C pass LSh and dance 1/2 diagonal reel of four with 2nd corners; 1C finish in 2nd place own sides', 5);
INSERT INTO 'dancecrib' VALUES (9652, '2017-03-16 23:32:57.561583+00', '2017-03-16 23:45:10.137651+00', 1033, 2, NULL, 'ace', '1-8::

  Four hands round and back

9-16::

  Ladies'' Chain, finishing in ''ballroom waltz'' hold for

17-24::

  Diamond shape Poussette, using Highland Schottische step. men begin with left foot. Finish by opening out to face other couple.

25-32::

  Bonnie Brux '' figure.

::  /     Dance two steps forward to meet other couple 

::  /     two steps out to side with opposite person, 

::  /     face them and retire from them two steps. 

::  /     face partner and advance two steps. 

::     *Use nearer hands for first four bars. Finish figure in Allemande hold facing other couple*.

33-40::

  Double - toe - off setting step 

41-48::

  Four hands across and back.  On bars 47-48, ladies drop hands and dance out to finish beside partner.

49-56::

  Large LH wheel once round

57-64::

  Ladies dance Figure of Eight through arch retained by men, crossing right shoulder the first time and left shoulder on return.

65-72::

  Allemande once round in a circle.



*(On the Isle of Wight, the couples finish the dance by taking the right arm over and retaining hand for the bow and curtsey)*', 5);
INSERT INTO 'dancecrib' VALUES (9651, '2017-03-15 05:02:41.225311+00', '2017-08-26 07:45:02.996783+00', 17657, 1, 202, 'ace', '1--::

 1c+2c+3c 3C Knot, 2c & 1c finishing on the diagonal for

9--::

 2c+1c ½ Poussette ; 3c+1c+2c set | All set advancing to promhold facing up

17--::

 3c+1c+2c 3C Allemande (2,1,3)

25--::

 1c+3c ¾ R&L | 2c+3c+1c set', 2);
INSERT INTO 'dancecrib' VALUES (11948, '2019-07-05 21:38:57.143264+00', '2019-07-05 21:42:29.676749+00', 15921, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c crossing down. 1c finish BtoB facing opposite sides (2,1,3) (2,1,3)

9--::

  DTr. On [15-16], 1c pull RSh to face up NHJ (2,1,3)

17--::

  Mirror Reels3, 1c in and up. All finish as on [17], 2c facing 3c on sides (2,1,3)

25--::

  2c+3c R&L starting on sides _while{8}_ 1c dance up | cast off to 2pl ; dance down | cast up to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9658, '2017-03-18 21:39:19.342929+00', '2017-03-18 21:39:19.342929+00', 16706, 1, NULL, 'ace', '1--::

  1c+2c Set | RHA | 1c cast as 2c leads up (2,1,3)

9--::

  1c+3c repeat (2,3,1)

17--::

  1c lead to top (3c down), cross and cast to 2plx ; 1c ½ Fig8 round 2c (2,1,3)

25--::

  Mirror Reels3 on the sides, 1c starts down and in, touch hands when possible (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11949, '2019-07-05 21:57:01.028652+00', '2019-07-05 21:57:01.028652+00', 15916, 2, 963, 'ace', '1-4::
  1c,2c,3c adv/ret for one twice  
5-8::
  1c,2c,3c turn partner BH twice  
9-16::
  1c,2c,3c dance a 3 cpl knot  3,2,1
17-20::
  2c change RH with 1st crn posn (2), new middles change LH with 2nd crn posn  
21-24::
  3m, flwd by 3w, cross to dance up w''s side to top place WHILE 1w, flwd by 1m,  
  cross to dance dn m''s side to bottom WHILE 2c spiral L shld round each other  
  1-1/2 times to 2nd place to face out  
25-30::
  L shld reel of 3 on sides, 2w up/2m dn to begin  
31-32::
  2c&1c change places, m LH, w RH   3,1,2  
  Note: 2nd c is the dancing c
  ', 3);
INSERT INTO 'dancecrib' VALUES (9673, '2017-03-20 23:14:45.704112+00', '2017-03-20 23:14:45.704112+00', 4763, 1, NULL, 'ace', '1--::

  All set twice ; turn P BH ½, face and cast away to (1x,2x,3x,4x)

9--::

  Repeat [1-8], finish all facing clw along own side (1,2,3,4) 

17--::

  1W dance down own side to 4pl as other W cast into the middle, dance to top and follow 1W down own side _while{4}_ the M do likewise, 4M dancing to 1pl as the others cast inwards to bottom and follow up (4,3,2,1) ; Half Reels4 on both sides, start middles facing ends (1,2,3,4)

25--::

  1c lead down and cross between 2c, cast up, lead down RH to bottom and cross LH to 4pl (2c+3c+4c up on [29-30]) (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (9670, '2017-03-19 01:00:16.842557+00', '2017-03-19 21:38:30.222964+00', 17659, 1, NULL, 'ace', '1--::

  All set | cross RH ; set | All turn RH ½ and face up in Allemande hold

9--::

  3C Allemande (3,2,1)

17--::

  3c+2c S&Link ; Circle4 L (2,3,1)

25--::

  3c+1c Poussette (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (9653, '2017-03-16 23:51:34.726714+00', '2017-03-27 18:49:44.738923+00', 15170, 2, 1505, 'ace', '1-8:: 1s lead down for 3, up for 3, cast to 2nd place (2s step up)

9-12:: 1M with 3s and 2W with 2s RHA

13-16:: 1M with 2s and 2W with 3s LHA

17-24:: 1s cross down and 3s cast up for double figure of 8

25-26:: 2s turn 1s in and up

27-28:: 2s, 1s and 3s take hands on the sides to balance in line

29-32:: 3s turn 1s in and down 1 1/2 times to progress

', 0);
INSERT INTO 'dancecrib' VALUES (13694, '2021-02-24 17:36:27.233827+00', '2022-08-07 10:56:51.610686+00', 8914, 1, 202, 'ace', '1--::

  1c lead down | face P and set (2c up) ; lead down between 3c | cast up to face 1cnrs

9--::

  ½ Reel4 on 1diag, pass LSh ; ½ Reel4 on 2diag (3x,1x,2x)

17--::

  ½ Reels3 across, 1c LSh to 3cnrs[pos] (to 3,1,2) ; ½ Reels3 on sides, 1c RSh to 4cnrs[pos] (2,1,3)

25--::

  Circle6 and back (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11950, '2019-07-05 22:07:32.839872+00', '2019-07-05 22:07:32.839872+00', 15917, 2, 963, 'ace', '1-4::
  1p R shld round 4p to face 3p  
5-8::
  1p turn 3p LH 1-1/2 to face 2p  
9-12::
  1p turn 2p RH back to orig place  
13-16::
  All set & point  
17-20::
  All adv 2, ret 2  
21-24::
  All set; RHA 1/2  
25-28::
  All adv 2, ret 2  
29-32::
  All set and cast one place cw  ', 3);
INSERT INTO 'dancecrib' VALUES (3866, '2013-07-21 22:12:14.482837+00', '2017-03-21 12:51:23.560279+00', 11897, 1, NULL, 'ace', '1–::

  2c & 3c ½ Fig8 round end cpl, finish 2c facing 3c ; 2c+3c set | ½ LHA (1,3,2,4)

9–::

  Rsh Reels4 on the sides (1,3,2,4)

17–::

  1c+3c & 2c+4c change place RH on side | All set to P ; 3c+1c & 4c+2c RHA (3,1,4,2)

25–::

  Circle8 and back (3,1,4,2)', 4);
INSERT INTO 'dancecrib' VALUES (15243, '2022-11-13 18:21:53.592926+00', '2022-11-13 18:21:53.592926+00', 21159, 2, NULL, 'ace', '1-8:: 1s+2s+3s dance mirror reels of 3 on own sides (1s in & down to begin)

9-16:: 1s set, cross over RH, cast 1 place as 2s step up, cross back to own sides & face out

17-24:: 2s+1s+3s dance a chaperoned chain progression, finish in order 312

25-32:: 6 hands round & back. ', 5);
INSERT INTO 'dancecrib' VALUES (9655, '2017-03-17 00:08:36.528104+00', '2020-11-02 09:36:24.586557+00', 17506, 2, 1505, 'ace', '1-4:: 1s set advancing and cast to 2nd place as 2s step up

5-8:: 1s set advancing and cast to top as 2s step down

9-16:: Mirror reels of 3 beginning with 1s dancing in and down; 2s out and up, 3s in and up

17-20:: 1s and 2s set and link up and down, ending crossed over

21-22:: 1s Turn both hands

23-24:: 1s and 2s dance 4 hands around to the left halfway

25-32:: 2s, 1s, and 3s circle 6 hands around to the left, on bar 30 (6 of the phrase), they step into the center, pull right shoulder back to turn about, and chase to progressed places.', 0);
INSERT INTO 'dancecrib' VALUES (12996, '2020-07-28 16:38:38.979265+00', '2020-07-28 20:24:22.917921+00', 19162, 1, 202, 'ace', '1--::
  1c turn P BH ½ and pivot R to face P''s place | cast off to 2plx _while{2}_ 2c lead up to 1plx ; 1c turn P BH to 2plx centre 1W(1M) facing up(down) (2x,1x,3)
9--::
  ½ Reels3 across, 1c RSh to 4cnrs[pos] ; ½ Reels3 across, 1c RSh to 2cnrs[pos] | 1c in 2pl turn P BH ½ and face down NHJ (2x,1,3)
17--::
  Mirror Reels3 on sides, 1c in and down, all taking hands when possible, cnrs with long loop to places
25--::
  1c+3c repeat [1-4] (to 2x,3x,1x) ; all turn P BH 1½ (2,3,1)

*Deviser''s note:  
On [9-16] 2c & 3c dance an 8-bar Reel3.*', 4);
INSERT INTO 'dancecrib' VALUES (13970, '2021-04-22 23:57:30.552263+00', '2021-04-23 00:00:15.709443+00', 6207, 1, 202, 'ace', '1--::

  1c dance down between 3c (2c up on [1-2]) and cast up to 2pl ; ½ Fig8 down round 3c (2,1x,3)

9--::

  2c repeat [1-8] _while{8}_ 1c set | turn RH moving up to 1plx | set (1x,2x,3)

17--::

  2c Reels3 across {6}, 2c RSh to 4cnrs[pos] (to 1x,2x,3) | 1c & 2c turn RH ½ ready for

25--::

  2C Allemande (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13693, '2021-02-24 13:08:24.138515+00', '2021-02-24 20:14:28.906036+00', 8915, 1, 202, 'ace', '1--::
  1c & 3c Petronella turn to midline | set (2c & 4c up ½ place) ; ½ Reel4 on midline
9--::
  3c+2c & 1c+4c RHA ; LHA. 3c & 1c on midline face own sides
17-20::
  3c & 1c dance LSh round opposite person, pass P LSh into 2 lines4 across, 3c & 1c BtoB to P face opposite sides
21-28::
  3c+2c & 1c+4c Parallel Reels4 across. On [27-28] 3c & 1c turn P RH ½ and face up. 2c finish in 1pl, 4c finish in 3pl (2,3x,4,1x)
29-32::
  3c lead up into Fig8 round 2c _while_ 1c lead up into Fig8 round 4c (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (11951, '2019-07-05 22:15:41.739611+00', '2019-07-05 22:15:41.739611+00', 15918, 2, 963, 'ace', '1-4::
  1c lead dn, x below 2c, cast up to partner''s place  
5-8::
  1m cross 2w RH btwn 1w&2m, cast to other''s place  
9-12::
  2m cross 1w btwn 2w&1m, cast to other''s place  
13-16::
  2c lead dn, x below 1c, cast up to other''s place  2x,1x  
17-20::
  2c and 1c dance btob with partner  
21-24::
  2 & 1c 1/2 turn prtn RH, pull back R shld and cast to own side  
25-32::
  2c & 1c chase cw once round  ', 3);
INSERT INTO 'dancecrib' VALUES (11952, '2019-07-05 22:20:18.663404+00', '2019-07-05 22:20:18.663404+00', 15919, 2, 963, 'ace', '1-4::
  1c x RH, cast to 2nd place  2sup 3&4  
5-8::
  1c&3c RHA  
9-16::
  2,1,3 L shld reels on the side, l shld to 3c to begin  
17-20::
  1c 1/2 fig 8 up around 2c  
21-24::
  All turn ptnr RH  
25-32::
  6 hands round and back', 3);
INSERT INTO 'dancecrib' VALUES (11953, '2019-07-05 22:25:13.586751+00', '2019-07-05 22:25:13.586751+00', 15920, 2, 963, 'ace', '  advanced version  
1-2::
  1c & 4c lead in, 2c up, 3c dn  
3-4::
  1c&4c RHA 1/2  
5-8::
  4c&2c/1c&3c LHA 1/2  
9-16::
  L shld reel 4 on sides  
17-20::
  4c up, 1c dn 1/2 fig 8  
21-24::
  All turn ptnr RH  
25-32::
  8 hands round and back', 3);
INSERT INTO 'dancecrib' VALUES (11666, '2019-03-13 11:18:08.896404+00', '2019-03-13 11:39:47.277576+00', 18322, 1, 202, 'ace', '1--::

  Circle6 and back (1,2,3)

9--::

  1c dance down (2c up) ; on [13] 1c change sides, 1W crossing above P and under the joined 	arms, and dance up to 2plx centre facing up

17--::

  1W+2M+3M LHA _while{4}_ 1M+2W+3W RHA ; 1c dance up and cast to 2plx, turn LH to face 1cnrs

25--::

  1c SetH&G | On [31-32] 1c turn P RH ¾ to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9678, '2017-03-22 23:46:45.273196+00', '2017-03-22 23:51:24.639921+00', 11987, 1, NULL, 'ace', '1--::

  1c long cast to 2pl (2c up) and Rsh gypsy turn to face 3cnr (2,1,3)

9--::

  Reels3 on the sides, Rsh to 3cnr

17--::

  All W set, Advance, Retire, Set while{8} All M Set, Set, Advance, Retire

25--::

  Circle6 and back

', 3);
INSERT INTO 'dancecrib' VALUES (9676, '2017-03-22 20:19:30.909862+00', '2017-03-24 20:59:39.10204+00', 7617, 2, 3311, 'ace', '1–8::
   1c cast off one, half fig8 up through 2c; turn LH to 1st corner.
9-12::
   ½  turn 1 cnr  RH; and balance in line.
13-16::
   2M & 3L turn LH ¾ to face 2nd cnrs; ½ turn 2 cnrs RH. 
17-20::
   2M, 2L, 3M, 3L balance in line; 2L & 3M turn LH ¾
21-24::
   2L, 3M turn 1c ½ RH; Balance in line.
25-30::
   turn LH 1½ to 2nd place; meanwhile 2c and 3c dance clockwise ¾. 
31-32::
   All set.', 5);
INSERT INTO 'dancecrib' VALUES (9677, '2017-03-22 23:18:26.858087+00', '2017-03-22 23:18:26.858087+00', 7617, 1, NULL, 'ace', '1--::

  1c cast (2c up) | ½ Fig8 up ; turn LH to face 1cnr 

9--::

  1c+1cnr turn RH ½ | BiL ; middles turn LH ¾ to 2diag | middles turn 2cnrs RH ½ 

17--::

  3W+2W+3M+2M BiL | middles turn LH ¾ to 1diag ; Middles +1c turn RH ½ | BiL

25--::

  1c turn LH 1½ to 2pl while{6} 2c+3c chase clw ¾ | All set (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9680, '2017-03-26 23:48:43.923339+00', '2017-03-26 23:48:43.923339+00', 17675, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c ¾ DblFig8 (1c+3c dance down to start) | 1c+3c cross RH (2,1,4,3,5)

9--::

  1c+4c & 3c+5c DblFig8 (1c+3c cast to start), at end 1c+3c face 1cnr

17--::

  1c &3c with 1cnrs Corners Pass and Turn; repeat with 2cnrs

25--::

  1W+4c+3M RHA while{4} 2c+1M  & 3W+5c Circle3 L ; 1c+3c pass Lsh, cast to the end and dance through end couple to face the other couple NHJ

33--::

  1c set to 3c as 4c set to P | 1c+3c set to P ; 1c+3c lead down NHJ (4c+5c up) and turn RH to (2,4,1,5,3)

', 2);
INSERT INTO 'dancecrib' VALUES (9497, '2016-11-14 19:44:15.145736+00', '2017-03-26 00:44:01.49758+00', 12455, 1, NULL, 'ace', '1--::

  1c+4c cross RH and cast in (2c+3c to end)(2,1x,4x,3) ; 2c+1c & 4c+3c RHA, finish 1W (P following) facing 1Mpos & 4W (P following) facing 4Wpos

9--::

  ½ lead-change Reel4 on 1diag ; at end 1c+4c RHA to finish 1W (4M following) facing 1Wpos & 4W (1M following) facing 4Mpos 

17--::

  ½ lead-change Reel4 on 2diag ; at end 1c+4c RHA to finish 1W (P following) facing 4Wpos & 4W (P following) facing 1Mpos 

25--::

  ½ lead-change Reel4 on 1diag ; at end 1c+4c RHA to finish 1W (4M following) facing 4Mpos & 4W (1M following) facing 1Wpos

33--::

  ½ lead-change Reel4 on 2diag ; at end 1c+4c RHA to finish (2,4,1x,3)

41--::

  1c turn RH | 1c ½ Fig8 L across | 1c turn RH (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (8045, '2013-09-21 22:37:45.854771+00', '2017-03-27 00:32:53.055127+00', 11970, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; Turn LH ¾ | cast L round 3cnr to (2,1,3)

9–::

  1c+1cnrs Cnrs Pass&turn using Lsh/LH, at end turn LH ¾ to face 2cnr ; repeat with 2cnr, to (2,1,3)

17–::

  1c+3c S&Link, finish on sides, 3W facing down, 3M up (no long turns) ; 2c+3M & 3W+1c Circle3 L, 3c drop hands early to face out and up (2,3,1)

25–::

  Mirror Reels3 on the sides, touch hands when possible (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2551, '2012-01-22 19:29:47.31592+00', '2022-11-13 23:02:03.602444+00', 3397, 1, NULL, 'ace', '1–::

  1c+2c the Knot

9–::

  1c & 1cnrs set, 1c advancing to end BtoB | 1c turn corner BH ; open into circle4 L, ending with 1cnrs in places and 1W+2c & 1M+3c forming lines across

17–::

  1c repeat with 2cnrs, to finish between corners

25–::

  Lsh Reels3{6} on opposite sides with cnrs | 1c cross to own side', 3);
INSERT INTO 'dancecrib' VALUES (11671, '2019-03-15 08:09:31.906546+00', '2019-03-15 11:10:25.110761+00', 17494, 1, 202, 'ace', '1--::
  1c set | cast (2c up) ; set | cast back (2c down) (1,2,3)
9--::
  1c+2c Espagnole. On [16] 1c face 4cnrs
17--::
  ½ Reel4 on 2diag, 1c RSh to 4cnrs. 1c danceLSh to face 3cnrs ; ½ Reel4 on 1diag, 1c RSh to 3cnrs. 1c pass LSh (3x,1,2x)
25--::
  3c+1W & 1M+2c Circle3 L {3}, open (1c leading) into Circle6 L {3} | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (7911, '2013-08-21 08:31:51.221962+00', '2023-02-04 01:23:11.510444+00', 12627, 3, NULL, 'ace', '1-8::
    1s cross down to dance reels of 3 on opposite sides.  (1)2 3
9-16::
    1s set to 2s on sides & change places with nearer hand to double
    triangle position, set & change places with 3s.  2 3(1)
17-24::
    1s cross up to dance reels of 3 on own sides.  2 3 1
25-32::
    1s cross RH, cast up to 2nd place & dance 1/2 Fig of 8 round 3s (2nd
    time through 1s cast down & dance 1/2 Fig of 8)', 0);
INSERT INTO 'dancecrib' VALUES (11667, '2019-03-13 12:58:31.893683+00', '2019-03-14 13:52:18.45112+00', 6805, 1, NULL, 'ace', '1--::

  1M+3W Fig8 on opposite side, Rsh to 2W/2M, then Lsh round P.  On [1-4] 2c set, turning to keep facing the dancer ; on [5-8] 1W+3M do likewise.

9--::

  All turn P RH into Allemande hold facing up ; 1c set twice, turning R to 1Wpl facing in diagonally 

17--::

  2c set twice, turning L to 1Mpl facing in diagonally ;  3c set twice, turnng R about to face up, on [24] all face P

25--::

  All petronella turn and set ; All W LHA 1 1/3 _while{4}_ all M set (high cuts and points)

33--::

  All W set facing out _while{4}_ all M chase 2 places cclw ; all turn P LH to own sides (2,3,1)

', 4);
INSERT INTO 'dancecrib' VALUES (13695, '2021-02-24 19:35:54.282318+00', '2021-02-26 22:11:33.566673+00', 8910, 1, 202, 'ace', '1--::

  Circle8 and back

9--::

  1W Fig8 LSh round 2M then RSh round 4M to original place (1,2,3,4)

17--::

  1c lead down between 3c, cross and dance up behind sides to centre facing down

25--::

  2c+1W LHA _while{4}_ 1M+4c RHA. 1c in centre face down ; 1c dance out through sides up to 1plx (1x,2,3,4)

33--::

  All W LHA _while{4} all M chase clw ½ ; all turn new P RH 1½

41--::

  All M LHA _while{4} all W chase clw ½ ; all turn P RH 1¾. All M in P''s place face out, all W face in (3,4,1,2)

49-64::

  Schiehallion Reels (3,4,1,2)

65--::

  All turn P RH ½ | turn cnrs LH ; ½ Gr-Chain (to 1,2,3,4). On [72] all meet P LHJ and all M pivot to face clw into promhold (1,2,3,4)

73--::

  All Promenade clw (1,2,3,4)', 5);
INSERT INTO 'dancecrib' VALUES (11955, '2019-07-05 22:37:00.407928+00', '2019-07-06 14:33:54.930007+00', 15178, 2, 963, 'ace', '1-4::
  1c&2c set| turn prtn BH  
5-8::
  Solo R&Ls - 1m RH with 1w, LH with 2w, RH 2m, LH 1w.  1m face out  
9 -16::
  1c&2c ladies chain to finish line across: 1m&2w facing dn, 1w&2m facing up  
17-24::
  modified Targe to finish 2m,1w facing dn, 2w&1m facing up  
25-28::
  chase, 2m flwd by 2w, 1m flwd by 1w, ccw 3/4 - 2,1x  
29-32::
  1c LH 1-1/2 to own side  
    
  ', 0);
INSERT INTO 'dancecrib' VALUES (13971, '2021-04-23 16:12:28.0316+00', '2021-04-23 18:15:11.576026+00', 20332, 1, 202, 'ace', '1--::

  1c+4c Petronella turn to midline | set ; ½ Reel4

9--::

  Petronella turn to sides | set (to 4,2,3,1) ; 2c+3c ½ RHA | set (4,3x,2x,1)

17--::

  3c+2c Set&Rotate (4,2x,3x,1)

25--::

  All set | 4c & 1c turn P RH and face P ; cast R to places  _while{4}_ 2c & 3c turn P RH ½ and face P ; cast R to exchanged places | all set (4,2,3,1)

33--::

  4c+2c & 3c+1c Poussette (2,4,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (13969, '2021-04-22 06:54:54.414363+00', '2021-04-24 06:05:43.132078+00', 20334, 1, 202, 'ace', '1--::

  1c turn LH ½ | lead down LH ; cross below 3c and cast up to 1pl (1,2,3)

9--::

  Mirror Reels3 on sides, 1c in and down (1,2,3)

17--::

  1c ½ Fig8 up round 2c ; 1c+2c ½ R&L (2x,1,3)

25--::

  1c+3c ½ R&L ; all turn P BH ½, face P and cast R to own sides (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (2687, '2012-01-22 19:29:53.10185+00', '2020-12-08 23:11:41.222523+00', 3901, 1, NULL, 'ace', '1–::

  2c (= dancing C) turn BH and face out ; dance Rsh round 1cnr and cross RH up/down to finish 2W between 1c and 1M between 3c both facing out

9–::

  2W+1c & 2M+3c ½Reels3 across, Rsh to 4cnr, on [12] 2c fast turn LH into the other reel ; 2M+1c & 2W+3c ½Reels3 (Lsh to 3cnr pos) , on [15-16] 2c turn LH to face 2cnrs

17–::

  ''corners pass and turn'': 2c with 2cnrs ; 2c turn RH into ; repeat with 1cnrs, 2c cross to 2pl (1,2,3)

25–::

  All set | 1c cross RH _while{2}_ 2c+3c ½RHA ; all set |1c+3c ½ RHA _while{2}_ 2c cross RH (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (11670, '2019-03-14 16:51:00.805631+00', '2020-10-31 12:16:38.435761+00', 17499, 1, 202, 'ace', '1--::

  1M Fig8 round 2c (2c up on [1-2]), LSh to 2W _while{8}_ 1W Fig8 on Mside, LSh to 3M then RSh to 2M. 1W between 2c and followed by P face down

9--::

  1c+2c ½ Reel3 in tandem, 1W leading LSh to 2W ; 1c+3c ½ Reel3 in tandem, 1W leading RSh to 3M. 1c finish in 2pl centre, 1W pivoting R to face P back to own sides

17--::

  1c dance RSh round P 1½, on [19] join RH turning to 2plx (to 2x,1x,3x) ; all chase clw ½ (3,1,2)

25--::

  All turn P RH. Retain hands | all set in middle with RHJ ; 3c followed by 1c & 2c cast to 3pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13210, '2020-09-28 09:30:21.667053+00', '2020-09-28 09:48:34.906773+00', 19871, 2, 160, 'ace', '1-8::  1W2M set, cast (1W down 2M up) ; 1W2M turn RH  into other''s place.

9-16::  1M2W set, cast (1Mdown, 2W up) ; 1M2W turn LH into other''s place. (2x1x)

17-24::  1C, followed by 2C, lead down [3 steps], Turn (men below ptnr W under joined hands) to change places with partner [4]; 2C, followed by1C, lead up to places (2, 1).

25-32::  4 Hands round & back.', 3);
INSERT INTO 'dancecrib' VALUES (11872, '2019-06-02 20:55:00.633001+00', '2020-09-04 07:51:38.046555+00', 6656, 2, 13151, 'ace', '1-4:: 1C cross right hand and set. 

5-8:: “The Splat”: 1C + 2C turn partner right 1/2 way with ladies turning under the raised hands (as if about to take an allemande hold), finish with 1C facing up back to back with 2C facing down; on 7&8 all continue turning to their right and dance ½ RA with first couple finishing back to back facing first corners.

9-16:: “Set to and turn corners”: 1C set to first corners and turn corners with two hands, finish facing second corners, then 1C set to second corners and turn corners with two hands, to finish on the sides facing first corners.

17-22:: 1C dance LS reels of three on the sidelines.

23-24:: 1C cross giving right hand.

25-32:: Six hands round and back. ', 4);
INSERT INTO 'dancecrib' VALUES (13691, '2021-02-23 01:37:35.257511+00', '2021-02-25 00:17:26.303255+00', 10273, 1, 202, 'ace', '1--::
  1c (+2c+3c who dance up to follow) lead down ; 3s separate and 2c followed by 1c+3c lead up, 2c to 1pl, 3c to 3pl. 1c face 1cnrs
9--::
  Reel4 on 1diag, 1c pass LSh to face 2cnrs
17--::
  Reel4 on 2diag. 1c in 2pl centre face down NHJ
25--::
  1c dance down between 3c | cast up and meet ; dance up between 2c | cast off to 2pl _while{8}_ 2c+3c R&L up/down (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11668, '2019-03-13 23:29:49.906928+00', '2019-03-19 11:15:49.65986+00', 5129, 1, NULL, 'ace', '1--::

  1c RHJ lead down, cross in 3pl and cast up to 2plx _while{4}_ 2c set | cross to 3plx _while{4}_ 3c cast to top, cross and face out ; ½ Reels3 on the sides (1c in and up) (2x,1x,3x)

9--::

  1c+3c ½ DblFig8 (1c cross down) (2x,1,3) ; 1c dance up and cast off to midline in 2pl, Lsh to P _while{4}_ 2c dance down on side and cross up (2,1,3)

17--::

  1c+1cnrs Cnrs Pass&Turn (cnrs turn RH), on [4] 1c meet in middle and twirl R to face 4cnr ; 1c+4cnrs repeat, 1c finish BtoB in middle facing own side

25--::

  1c dance Rsh round 3cnr, meet and turn P 1¾ RH _while{8}_ 2c+3c advance diagonally to form circle and retire ; and wait {4} (2,1,3)





', 4);
INSERT INTO 'dancecrib' VALUES (14472, '2021-12-04 23:29:51.034584+00', '2021-12-04 23:29:51.034584+00', 18524, 2, 1645, 'ace', '1–8:: Four hands round and back
9–12:: All dance back to back with person opposite
13–16:: All dance right hands across once round
17–20:: All dance back to back with partner
21–24:: All dance  left hands across once round
25–32:: Couples facing clockwise make arch for anti-clockwise – then anti-clockwise make arch then repeat over and under again to face next couple.
:: *Crib supplied by Zsófia József*', 2);
INSERT INTO 'dancecrib' VALUES (11669, '2019-03-14 15:09:05.898083+00', '2019-03-14 15:20:11.774173+00', 17498, 1, 202, 'ace', '1--::

  1M+2W set | cross Rsh ; 1W+2M set | cross RSh (2x,1x,3)

9--::

  Parallel Reels3 on sides, 1c RSh to 2c (2x,1x,3)

17--::

  2c+1c change places RH on sides | cross RH ; turn RH 1½ on sides to change places (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11956, '2019-07-06 02:42:59.549948+00', '2019-07-06 02:42:59.549948+00', 15922, 2, 963, 'ace', '1-8::
  1c&2c/3c&4c set and link for 2 twice to opp sides  
9-16::
  Reel 4 on sides  
17-24::
  1w fig 8 around 2c WHILE 4m fig 8 around 3c (1w out & up, 4m down & out to start   
25-28::
  middle cpls LHA WHILE crns set twice on diag  
29-32::
  middle cpls chase ccw 1/2 round AS crns x LH on 31&32    2413

  
  ', 5);
INSERT INTO 'dancecrib' VALUES (8108, '2013-11-16 20:59:16.585992+00', '2022-03-28 17:36:20.710655+00', 15172, 2, 160, 'ace', '1-8::

  Reels of 3 on sides. Begin 1s in and down.

9-16::

  1s 2s double Fig. Eight. 1s cross down, 2s dance up.

17-24::

  1s followed by 2s lead down for 4; 2s followed by 1s lead up to top. 1s face down.

25-32::

  1s 3s Rondel.', 2);
INSERT INTO 'dancecrib' VALUES (13696, '2021-02-25 14:45:03.487106+00', '2021-02-25 14:48:02.69719+00', 17149, 1, 202, 'ace', '1--::

  1c+2c set | turn P BH opening into ; Circle4 L ½ | cross RH (2,1,3)

9--::

  1c+3c set | turn P BH opening into ; Circle4 L ½ | turn P RH ½ ready for

17--::

  ½ Poussette (to 2,1,3) ; 2c+1c S&Link. 2c face down (1,2,3)

25--::

  ½ Gr-Chain, 1c crossing (to 3x,2x,1x) ; all set | 1c cross RH _while_ 3c+2c ½ RHA (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2149, '2012-01-22 19:29:22.647528+00', '2021-02-25 16:00:31.290203+00', 9385, 1, NULL, 'ace', '1–::

  1c+2c S&Link ; circle4 left

9–::

  2c+1c dance BtoB ; turn BH into

17–::

  2c+1c Allemande, but replace last two bars by RH turn, and keep RH hold for

25–::

  1c+2c the Knot', 3);
INSERT INTO 'dancecrib' VALUES (2878, '2012-01-22 19:30:01.255953+00', '2021-02-25 19:56:16.693+00', 9352, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; ½Fig8 up round 2c (2,1x,3)

9–::

  2c+1c L-Chain, 1c finish facing 1cnr

17–::

  1c+1cnrs Pass & Turn (cnrs make BH turn) 1c pass Rsh into ; 1c+2cnrs Pass & Turn, to (2,1,3)

25–::

  1c+3c Set & Link ; RHA to (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3084, '2012-01-22 19:30:10.553259+00', '2021-04-24 18:42:55.203167+00', 5496, 1, NULL, 'ace', '1–::

  1c cross between 2c, cast behind 3c ; cross down and cast up round 4c

9–::

  1c cross up between 3c and cast behind 2c to top ; turn RH 1½ to 1pl

17–::

  1c+2c ½R&L ; 1c+3c ½R&L

25–::

  1c+4c ½R&L ; All turn RH (2x,3x,4x,1x)

33–::

  All set | All »La Baratte« [turn P RH ½ to full arms'' length | change back sideways, W passing in front with her back to M, changing hands overhead to LH | turn LH ½ to own side] (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11961, '2019-07-08 17:52:50.114765+00', '2019-07-08 17:56:12.2174+00', 18233, 1, 1645, 'ace', '1-::

  1c dance down | cast up round 3c (2c up) ; turn 1&frac14; LH to face 1cnrs

9-::

  1c turn 1cnrs RH | turn 2cnrs LH ; turn P RH | turn 3cnrs LH

17-::

  1c turn 4cnrs RH | P LH ; 2c+1M & 1W+3c RHA, 1c face out own side

25-::

  1c chase &frac12; way clw ; turn 1&frac12; RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2933, '2012-01-22 19:30:03.493995+00', '2020-12-21 00:16:45.543079+00', 9391, 1, NULL, 'ace', '{{explanation}}

Note: Throughout »in« means towards the middle (down from 1pl and up from 4pl) and »out« is the opposite way  

On 2nd chord, 3rd and 4th couples change sides.



1–::

  1c+4c cross RH and cast in (2c+3c step out) ; 1c+4c ½ LH turn into ½ LHA. Finish in a St. Andrews cross, LHJ in the centre, RHJ with cnr.

9–::

  1c+4c double spoke:- set RHJ with each cnr in turn, rotating one place cclw each time (2 bars per corner).

17-20::

  4M followed by 4W and 1M followed by 1W dance out the M / W side and cast to the right _while{4}_ 2c+3c cross RH and set. Finish with 4c (1c) side by side at the top (bottom) of the dance, facing down(up) , men on the left of their partners.

21-24::

  All change place RH up/down (2W with 3M, 4W with 1M, 4M with 1W, 2M with 3W), 1W followed by 1M & 4W followed by 4M cast to their right and in _while{2}_ 3rd and 2nd couples set. Finish with 3M, 4W, 4M, 2W (on M side) facing 3W, 1M, 1W, 2M (on W side).

25-28::

  All cross RH with person opposite, 4M followed by 4W and 1M followed by 1W cast to the right _while{2}_ 3c+2c set. Finish with 1c at the top facing 4c at the bottom, men on the left.

29-32::

  All change place RH with person opposite (3W with 2M, 1W with 4M, 1M with 4W, 3M with 2W), 4c+1c separate and cast in _while{2}_ 2c+3c set. (to 2,4,1x,3x).



{{explanation}}

(On bar 19-20, 23-24, 27-28, 31-32 2c+3c set as in »J.B. Milne«, one bar facing the person with whom they have just crossed, and one bar facing the person with whom they are about to cross. On bar 20, 24, 28 the dancers form lines, the corners forming a big square).', 2);
INSERT INTO 'dancecrib' VALUES (12682, '2020-03-22 01:53:38.000114+00', '2020-08-26 23:37:45.644408+00', 19896, 1, 202, 'ace', '1--::
  1c lead down {3}, lead up {3} and cast off (2c up on [7-8])  (2,1,3)
9--::
  Mirror ½ Reels3 on sides, 1c in and down ; ½ Reels3 across, 1c RSh to 2cnrs[pos] (3x,1x,2x)
17--::
  3C S&Link ; 4 bars of diagonal R&L
25--::
  Repeat [17-24] from new positions (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11673, '2019-03-15 16:56:54.71888+00', '2020-09-28 19:02:31.409939+00', 14433, 2, 595, 'ace', '1-4:: All set, 1M & 2M take nearer hands and dance between their partners & cast into their partners’ places while 2s dance across the set & curve into their partners’ places

5-8:: 1s turn LH twice, moving down the set to finish facing 1st corners, while 2s cross RH and cast up one place.

9-12:: 1s set to 1st corner & face their partner across the dance (2 bars of Hello Goodbye), then turn their partner RH to face 2nd corner

13-16:: Repeat bars 9 - 12, setting to 2nd corners & setting up & down (Hello Goodbye), turn RH to finish in the middle of the set facing up

17-20:: 1s & 2s dance four hands round, finishing in the sidelines on opposite sides

21-24:: 1s & 2s turn RH  to finish in the center ready for …

25-32:: 1s & 2s dance a half Poussette, 3s dance in on Bar 28, then 1s & 3s dance a half Poussette  231

 

Dance Information The dance is repeated in Reel time, the only variation being that on Bar 24 3s step in to the centre ready to join the other 2 couples for a 3-couple Poussette.  As each couple reaches the top of the dance, they will dance in the other rhythm. ', 0);
INSERT INTO 'dancecrib' VALUES (2546, '2012-01-22 19:29:47.121096+00', '2019-03-17 22:17:56.017024+00', 3396, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  1c+3c petronella turn _while{2}_ 2c+4c cast up | All set ; All petronella turn | All set, and 2c+4c face R into

9–::

  1c+2c & 3c+4c Rsh Reels4 across, finish as on [9]  

17–::

  2M+4W Turn RH 1½ _while{4}_ 2W+1c & 3c+4M chase cclw half round ; 4c+3c & 2c+1c LHA, (4,3,2,1, with 4c+2c on midline)  

25–::

  All set to P | 3c+1c set _while{2}_ 2c+4c set advancing to meet (W pivots L) and face down NHJ, M on R ; 4c+2c dance down and cast up to (2,3,4,1)  



*Repeat in Reel time*', 3);
INSERT INTO 'dancecrib' VALUES (2621, '2012-01-22 19:29:50.368776+00', '2019-03-15 10:20:13.404509+00', 3635, 1, NULL, 'ace', '1–::

  1c set, cross, cast behind 2c, dance between 3c, cast behind 4c, ½ RH turn and face up (2,3,4,1)

9–::

  1c lead up followed by 4c, 3c and 2c ; all cast off from the top (2,3,4,1)

17–::

  1c 1½ RH turn ; turn 4c LH | P RH (i.e. Strip the Willow)

25–::

  1c turn 3c LH | P RH ; 2c LH | P RH, finish 1c+2c facing up for

33–::

  1c+2c Allemande, 1c dancing down to 4pl on the last two bars (2c & 3c up)

41–::

  2c+3c & 4c+1c R&L (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (10852, '2018-06-19 01:44:09.361909+00', '2019-03-14 22:29:48.025269+00', 4216, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c ½ RHA (to 2x,1x,4x,3x) | 1c+4c ½ LHA _while{2}_ 2c & 3c cross RH (to 2,4,1,3) ; 2c+4c & 1c+3c ½ RHA (to 4x,2x,3x,1x) | 2c+3c ½ LHA _while{2}_ 4c & 1c cross RH (4,3,2,1)

9--::

  All repeat 1-8 from new positions (1,2,3,4)

17--::

  Parallel Reels4 on sidelines, 1W face out (1,2,3,4)

25--::

  1W followed by 1M casts off and crosses to 2plx (2c up) ; 1M followed by 1W casts off two places to 4pl (3c+4c up) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11962, '2019-07-09 23:40:09.823271+00', '2019-07-09 23:43:38.725337+00', 16637, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; cross RH | cast R into facing lines3 across

9--::

  All turn opposite person RH ; Circle6 L ½

17--::

  All A&R ; 1c change places RH | cast R to 2plx (3x,1x,2x)

25--::

  All turn P RH ; Circle6 L ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2563, '2012-01-22 19:29:47.784649+00', '2019-03-15 10:30:47.942906+00', 3461, 1, NULL, 'ace', '1–::

  All circle8 and back

9–::

  All turn P RH 1¼ ; turn P LH 1¼

17–::

  All W RHA ; LHA

25–::

  All W chase once round set cclw to face corner

33–::

  All turn Cnr RH 1¼ ; turn LH 1¼

41–::

  All M RHA ; LHA

49–::

  All M chase once round set cclw to place

57–::

  All C in promhold cclw round set, all W finish BtoB in the centre.', 2);
INSERT INTO 'dancecrib' VALUES (13697, '2021-02-26 00:22:25.960099+00', '2021-03-10 15:31:34.31303+00', 2134, 2, 82, 'ace', '1-8::

 1C couple turn RH; 1C couple turn LH

9-16::

 1C Lead down the middle {3} and up {3}, and cast off (2c up) (to 2, 1)

17-24::

 21+1C+3C promenade.

25-32::

 2C+1C R&L', 4);
INSERT INTO 'dancecrib' VALUES (13823, '2021-03-18 20:24:29.796301+00', '2021-06-02 19:21:44.089154+00', 7455, 1, 202, 'ace', '1--::
  1c set | cast off 2 places (2c up) ; meet and turn LH ½ | dance up NHJ to 2pl centre BtoB as for DTr
9--::
  DTr. 1c face 2cnrs
17--::
  Reels3 on sides, 1c LSh to 2cnrs (2,1,3)
25--::
  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (13972, '2021-04-24 09:09:12.366337+00', '2021-04-24 23:32:22.000567+00', 20336, 1, 202, 'ace', '1--::

  All set | cross RH ; set | cross RH (1,2,3)

9--::

  1c lead down ; and up (1,2,3)

17--::

  1c turn RH | cast off to 3pl (2c+3c up) ; all turn RH (2,3,1)

25--::

  Circle6 and back



*Deviser''s note* : May be danced in a four couple set with progression 2341 by casting below the fourth couple in bars 19 and 20.', 4);
INSERT INTO 'dancecrib' VALUES (14757, '2022-04-13 17:30:15.793558+00', '2022-04-15 17:00:55.248976+00', 16645, 2, 963, 'ace', '1-8::

  1c adv, raising arms to touch| retire; repeat AS 2c wait 2 bars| adv raising arms to touch; retire| adv and face up (the wave)  

9-16::  

  1c, flwd by 2c, cast| meet in 2nd place and dance up; cast |2c&1c set (the play and face off)  

17-24::  

  1c half figure 8 up around 2c; 1c turn RH 1-1/2 to 2,1 (goal!)  

25-32::

  2c&1c circle 4 hands round (3), dance in touching hands and shouting YAY; pull back Lsh and chase ccw back to 2,1 (celebration)

', 5);
INSERT INTO 'dancecrib' VALUES (9317, '2016-09-20 18:34:37.208766+00', '2020-09-01 10:50:40.905537+00', 4017, 2, 177, 'ace', '1-8:: 1s set, cast off 1 place as 2s step up, cross over passing RSh and cast left (M up, L down) to finish 1M between 2s (all facing down) and 1L between 3s (all facing up).

9-12:: 2s+1s+3s set & change places up/down giving RH

13-16:: 3s+1s+2s set, 3s+2s change places up/down giving RH as 1s turn RH ¾ to face 1st corners.

17-20:: 1s dance ½ reel of 4 with 1st corners, while 2nd corners chase clockwise ½ way

21-24:: 1s turn 1st corners RH once round and turn partner LH to face 4th corners.

25-32:: 1s repeat 17-24 with 2nd corners: dance ½ reel of 4 while 1st corners chase clockwise ½ way (back to own side); 1s turn 4th corners RH, and cross to own side in 2nd place giving LH.  	



', 0);
INSERT INTO 'dancecrib' VALUES (11672, '2019-03-15 16:54:48.624758+00', '2019-03-15 19:16:10.264089+00', 14432, 2, 595, 'ace', '1–4::

  All set, 1M & 2M take nearer hands and dance between their partners & cast into their partners’ places while 1L & 2L dance across the set & curve into their partners’ places, 4th & 5th couple dance similarly, except that the Ladies take nearer hands & pass between the Men.

5–8::

  1s turn LH twice, moving down the set to finish facing 1st corners, 5s turn LH twice moving up the set to finish facing their 1st corners, while 2s & 4s cross RH and cast up or down one place.

9–12::

  1s and 5s set to 1st corner & face their partner across the dance (2 bars of Hello Goodbye), then turn their partner RH to face 2nd corner

13–16::

  Repeat bars 9 - 12, setting to 2nd corners & setting up & down (Hello Goodbye), turn RH to finish in the middle of the set facing up

17–20::

  1s 3s & 5s dance six hands round, finishing in the sidelines 

21–24::

  1s 3s & 5s turn RH  5s finish in 4th place, and 1s & 3s finish in the centre ready for …

25–32::

  1s & 3s dance a half Poussette, 5s dance in on Bar 28, then 1s & 5s dance a half Poussette  23514

 

{{explanation}}

The dance is repeated in Reel time, the only variation being that on Bar 24 1s 3s & 5s finish in the middle and then dance a 3-couple Poussette.  As each couple reaches the top of the dance, they will dance in the other rhythm.

', 0);
INSERT INTO 'dancecrib' VALUES (3355, '2012-01-22 19:30:21.839802+00', '2020-09-03 17:57:08.967272+00', 6417, 1, NULL, 'ace', '1–::

  1c dance between 2c and cast to place ; 2c dance up between 1c and cast to place (1,2)

9–::

  1W sets to 2M | change place RH ; The W face up as their P dance round them Rsh

17–::

  All set to P | turn P BH ½ opening into ; Circle4 L 1¼ (1,2)

25–::

  1W+2W dance round P Rsh ; All set | 1c cast off as 2c dance up', 3);
INSERT INTO 'dancecrib' VALUES (4492, '2013-08-21 08:30:49.589933+00', '2023-02-04 01:18:59.902699+00', 902, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back to places
9-16::
    1s lead down (for 1 step) & up, cast 1 place, lead down between 3s,
    cast up behind 3s to face 1st corners
17-24::
    1s 1/2 set & dance 1/2 reels of 4 with 1st corners, 1/2 set to 2nd
    corner & dance 1/2 reels of 4  (3)(1)(2)
25-32::
    3s+1s+2s 1/2 set, circle 6H round to left 1/2 way & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (8958, '2015-11-02 05:17:30.519851+00', '2017-03-27 13:34:18.780208+00', 16390, 2, 2452, 'ace', '*Circle: men with partner on right all facing centre*

1-8:: ALL SET facing the centre using Glasgow Highlanders setting step;

9-16:: MEN FIGURE OF 8: men dance a figure of 8 right shoulder round partner to begin, then dancing left shoulder round corner back to place;

17-24:: DO-SI-DO & TURN: back-to-back with partner then right hand turn 1½ to change places;

25-32:: WOMEN FIGURE OF 8: women dance a figure of 8 right shoulder round partner to begin, then dancing left shoulder round corner who becomes new partner.



REPEAT with new partner', 0);
INSERT INTO 'dancecrib' VALUES (8397, '2014-09-03 12:44:11.07358+00', '2017-03-27 16:42:30.052418+00', 6633, 2, 2088, 'ace', '1-4::

  1c & 4c cross RH (finish side by side 1c facing down 4c facing up) and set.

5-8::

   1c & 4c dance 1/2 R&L (up and down set finishing 1C in 3rd place, 4c in 2nd place - 2c & 3c step up/down bars 5-6).

9-16::

   2c & 3c repeat bars 1-8 (Finish 4,3,2,1 - 3c & 2c facing out).

17-24::

   Two Double Figures 8 (4c and 1c lead up/down and cross, 3c & 2c cast up/down)

25-28::

   4c, 3c and 2c dance 1/2 Reel 3 on sides (2L & 3L pass RSh, 2M & 3M pass Lsh - Finish 2,3,4,1).

29-30::

   2c & 4c face down, 3c & 1c face up - all set.

31-32::

   2M & 3M, 4L & 1L turn RH while 2L & 3L, 4M & 1M turn LH', 2);
INSERT INTO 'dancecrib' VALUES (12683, '2020-03-22 23:30:38.59404+00', '2020-03-22 23:35:02.841284+00', 19874, 1, 202, 'ace', '*Couples stand in a double circle RR, M inside facing P*



1--::

  All turn P RH ; all chase, outside clw, inside cclw

9--::

  All pulling RSh back chase back to P ; all turn P LH

17--::

  All dance BtoB ; all inside dancers acknowledge P then dance RSh around dancer diagonally to their right into promhold with that new P

25--::

  All Promenade cclw and finish as on [1]', 2);
INSERT INTO 'dancecrib' VALUES (8794, '2015-06-17 17:31:22.585975+00', '2020-09-28 21:17:06.028359+00', 14476, 2, 274, 'ace', '1-:: 1C+2C & 3C+4C dbl fig8. 2C and 3C start up/down crossing (1,2,3,4)

9-:: 2C+3C tourbilink (1,3x,2x,4)

17-:: 1C+3C & 2C+4C tourbilink (3,1x,4x,2)

25-:: Reels4 on the sides (3,1x,4x,2)

33-:: 1C+4C 1/2 RHA, 1L to 4L and 1M to 4M set and 1/2 turn RH; 1C and 4C set to partner (3,1,4,2)



Tourbilink: 

1-:: 1C+2C 1/2  turn ptnrs BH; 1M & 2L lead ptnrs by nearer hand 1 place clw (end 1C on Ladies side & 2s Men''s side)

3-:: 1C+2C set&link2

7-:: 1C+2C 1/4 chase clw

', 5);
INSERT INTO 'dancecrib' VALUES (8454, '2014-11-18 20:02:49.653973+00', '2021-01-03 12:50:43.503223+00', 13307, 2, 942, 'ace', '1- 4:: 1C with 2C and 3C with 4C dance RHA

5- 8:: 2C with 3C dance LHA

9-16:: 1C with 2C and 3C with 4C dance a double Fig-of-8, top and bottom couple (1C & 4C ) start to cross

17-18:: 1C lead down for two steps while 4C lead up for two steps at the same time 2C cast up to top place while 3C cast to bottom place

19-24:: 1C and 4C dance RHA halfway, they turn own partner halfway and pulling back right shoulder twirl back to own sides

25-32:: 2C with 4C and 1C with 3C dance Poussette', 2);
INSERT INTO 'dancecrib' VALUES (14714, '2022-03-28 22:00:39.91682+00', '2022-03-29 14:55:56.394353+00', 19476, 1, 1645, 'ace', '1--::
  1c dance Fig8: pass P LSh, 1M/1W dance RSh round 3M/2W & end in original pl facing own cnr
9--::
  All set to cnr | turn cnr RH & face P ; set to P | turn P &frac34; LH so M end in centre NHJ with P, all facing clw
17--::
  All, NHJ with P, dance &frac23; RHA ; M drop RH & all, still facing clw, S&Link with P, turning slightly more to end on the sides (2,3,1)
25--::
  Circle6 to L & back (2,3,1)
', 2);
INSERT INTO 'dancecrib' VALUES (11659, '2019-03-10 17:23:04.890766+00', '2020-12-12 13:44:51.842074+00', 19220, 2, 2929, 'ace', '1-4:: 1C slip down the middle between 3C, set and open to face up
5-8:: 1c dance 1/2 tandem reel of 3 with 3C, passing 3W by RSh to begin, finish B2B in second place, W facing up, M facing down
9-16:: 1/2 DT, 1/2 alternating tandem reel of 3 with 2C, passing 2W by RSh to begin, finish B2B in second place, facing opposite sides
17-24:: 1/2 DT, cast around 3rd corner positions to finish in lines across (M up, W down)
25-32:: Set and Link for 3, 1C turn RH once around to finish on opposite sides

Dance repeats from partner''s position as opposite role', 2);
INSERT INTO 'dancecrib' VALUES (10386, '2018-01-19 00:58:13.4415+00', '2021-02-09 11:57:37.425775+00', 17950, 2, 963, 'ace', '1-8::

  1c+2c+3c turn RH; chase clw halfway (3x2x1x)    

9-16::

  3c+2c+1c mirror R3 on side, 3c in + down (2m cast out and up)      

17-24::

  3c followed by 2c+1c dance down middle; W under M''s arm to change sides dance back to original places    

25–32::

  1c+2c poussette  

  *Note: if only 3 couples, do a 3 couple poussette*

', 5);
INSERT INTO 'dancecrib' VALUES (13698, '2021-02-26 08:44:29.858324+00', '2021-02-27 09:13:57.943767+00', 8912, 1, 202, 'ace', '1--::
  1c Parallel Fig8 on sides, RSh to 2c, into Reel4 position (1,2,3,4)
9--::
  Reels4
17--::
  1c+2c & 3c+4c RHA ; LHA (1,2,3,4)
25--::
  1c turn P LH ½ into promhold and face down | 1c dance to 4plx (2c+3c+4c up) ; 1c turn P RH 1½ (2,3,4,1)', 5);
INSERT INTO 'dancecrib' VALUES (9684, '2017-03-27 16:42:30.053265+00', '2017-03-27 16:42:30.053265+00', 6633, 1, NULL, 'ace', '1--::

  1c+4c cross but remain in middle, 1c facing 4c and set ; 1c+4c ½ R&L inside the set, start up/down, (2c+3c step to end on [5-6]) (2,4,1,3)

9--::

  2c+3c repeat [1-8]  (to 4,3,2,1, 2c+3c facing out)

17--::

  4c+3c & 2c+1c DblFig8, 2c+3c cast to end to start (4,3,2,1)

25--::

  4c+3c+2c ½ Reels3 on sides, 3c start by passing outside 2c, finish 2c facing 3c and 4c facing 1c ; All set | All turn opposite EH, the end couples starting inwards. 

', 3);
INSERT INTO 'dancecrib' VALUES (3671, '2012-12-23 14:02:16.314302+00', '2017-03-27 16:59:27.789932+00', 4233, 2, NULL, 'ace', '1-8:: 1s cross down, turn 3s (1s out sides), cross up, turn 2s (1s out sides) - finish back to back, facing own sides

9-16:: [4] All set in double triangles, 1s turn RH person to finish back to back facing opposite side  [4] All set in double triangles, 1s turn RH person RH - finish 1M facing 3M, 1L facing 2L

17-24:: Reels of three across, (1s pass L Sh to start) - 1s finish in 2nd place, own side, man facing up / lady down

25-32:: Reels of three on the side, (1s pass R Sh to start) 1s cross to second place, opposite side, on 3&4, and cross back to second place, own side on 7&8', 4);
INSERT INTO 'dancecrib' VALUES (7912, '2013-08-21 08:31:51.229929+00', '2023-02-04 01:23:11.524548+00', 7085, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Grand Chain
9-16::
    1s+2s+3s set HS to R & cross LH with partner, all set HS to L &
    cross RH with partner
17-24::
    1s+2s+3s circle 6H round & back
25-32::
    1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (9685, '2017-03-27 20:59:48.124402+00', '2017-03-27 22:26:18.576867+00', 16749, 2, 238, 'ace', '1-:: 1c+2c Set and 1/2 RHA; 1c+2c Set and Turn LH 1/2

9-:: 1c+3c Set and 1/2 RHA; 1c+3c Set and Turn LH 1/2

17-:: 1c+3c Set, 1c dance up while 3c cast down; 1c+2c Set (1c face up, 2c face down nearer hands joined), Turn NH 3/4

25-:: 1c+2c double Fig of 8



(Cribs taken from Danciemation video)', 2);
INSERT INTO 'dancecrib' VALUES (9687, '2017-03-28 00:56:58.852676+00', '2019-08-10 21:55:50.308524+00', 15440, 1, 202, 'ace', '1--:: 1c set | cast off (2c up) ; turn RH 1½ to face 1cnrs

9--:: 1c ½ Reel4 with 1cnrs, at end pass Rsh to face 2cnrs ; 1c ½ Reel4 with 2cnrs to 2plx (3x,1x,2x)

17--:: All S&Link3 twice (2,1,3)

25--:: Circle6 and back ', 4);
INSERT INTO 'dancecrib' VALUES (3805, '2013-07-13 15:56:09.93789+00', '2017-03-29 11:04:42.180051+00', 14677, 1, NULL, 'ace', '{{explanation}}

3c start on opposite side (1,2,3x).  The »Active Couple (AC)« starts alternately from opposite ends.  When the »bottom« couple is active, »down« means towards the top of the set.  To start, 1c is the AC.  Six times through in all.



1–::

  1c lead down {3}, up {3} | cross and cast off (2c up) (2,1x,3x)

9–::

  1c+3c RHA ; 1M+2W & 1W+2M Turn LH (2,1x,3x)

17–::

  2c+1c L-Chain (2,1x,3x)

25–::

  All A&R to P ; all turn RH (2,1x,3x)



{{explanation}}

Continue with 3c as AC.', 3);
INSERT INTO 'dancecrib' VALUES (11375, '2018-12-12 20:55:43.958306+00', '2019-07-14 22:22:16.920491+00', 19116, 2, 1645, 'ace', '1-4::
  1s & 3s set & ¾ turn partners RH into line of 4 up/down
5-8::
  2s & 4s set & ¾ turn partners RH while 1s+3s dance first half of reel of 4. All now in cross formation, M at ends, 3214 clockwise from top
9-12::
  1s & 3s second half of reel of 4 while 2s & 4s ½ reel of 4 across (all M touch LH on Bar 10, W on Bar 12), all now in cross, 1432 clockwise 
13-16::
  1s & 3s set & ¾ turn RH to face in, W on left, while 2s & 4s pass partners RSh, 2M+4M turn LH (2 bars) while 2W, 4W loop tightly to R to end on R of partners with NHJ, then (1 bar) 2s, 4s dance left to end BtoB in line up/down, 1s facing 4s (M-M, W-W), 2s & 3s likewise 
17-24::
  Rose Rondel formation - same timing as Rondel, all arches made by dancers at ends.  
  - 17      - all NHJ, 1s&4s, also 2s&3s change places with 1s/3s making arches for 4s/2s  
  - 18-19 - facing out, 2W/4W pass in front of 2M/4M, all ¼ round set to form new pairs NHJ at sides facing in while 1s+3s ½ circle to L & turn sharply away from partners (M to R, W to L) to form new pairs NHJ facing sides. (All now in line across, all W on left: 2W+4M face 3W+1M, 1W+3M face 4W+2M)  
  - 20-22 - repeat pattern of 17-19 but turned sideways, end back with original partners NHJ in line up/down, 1s/3s (in original places) facing 2s /4s (with W on left), so M-M, W-W again facing.  
  - 23-24 - 1s&2s, 3s&4s change places with 1s/3s making arches, turn inward to face couple just passed  
25-32::
  2s&1s, 3s&4s LHA; then from centre 1s, 3s dance out past adjacent side person LSh & M follow W ¼ anticlockwise to side places.    End 2341 clockwise. 
', 3);
INSERT INTO 'dancecrib' VALUES (2721, '2012-01-22 19:29:54.568787+00', '2020-12-21 11:06:52.235759+00', 9468, 1, NULL, 'ace', '1–::

  1c+3c advance, set and face R ; 2c+4c advance making arch, retire hands low _while{4}_ 1c+3c, M behind W, dance out under arch and cast L to exchanged places

9–::

  1c+3c repeat from exchanged places

17-32::

  Repeat 16 bars, 2c+4c leading

33-48::

  1c+3c repeat [1-16] _while_ 2c+4c repeat [17-32] delayed 4 bars (»Canon«)

49–::

  2c+4c dance out and cast L _while{4}_ 1c+3c advance (arch) and retire ; All advance to centre joining hands high | retire

57–::

  All C change place by »Califonia Twirl«: with NHJ M ½ loop R _while{2}_ W ½ loop L under arms (face out) | repeat to places ; All set | turn RH

65–::

  All W RHA ; loop once round P Lsh to places

73–::

  All M LHA ; loop once round P Rsh into promhold (1c face 4c, 2c face 3c)

81–::

  (Interlocking Reels3) 1c+4c & 2c+3c loop Rsh, to places ; 1c+2c + 3c+4c repeat Lsh, all C finish facing cclw

89–::

  All promenade cclw , at end put W into the middle and bow/curtsey holding RH.', 2);
INSERT INTO 'dancecrib' VALUES (11674, '2019-03-15 19:35:41.433781+00', '2019-03-16 23:32:19.156023+00', 10737, 1, 202, 'ace', '1--::
  1c+2c RHA and stay in the middle facing up ; 1c cast to face 1cnrs _while{4}_ 2c dance up and loop to 1pl (2,1,3)
9--::
  Set H&G. On [15-16] 1c turn RH ¾ to 2pl facing 3cnrs (2,1,3)
17--::
  All chase clw ½ (to 3x,1x,2x) ; all set | turn P RH ½ into promhold facing up (3,1,2)
25--::
  4 bars of 3C Promenade R to W sideline and face P across ;  all Turn P
RH ½ moving to midline facing P | with R twirl cast to (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2912, '2012-01-22 19:30:02.645472+00', '2020-09-04 13:40:30.844624+00', 7474, 1, NULL, 'ace', '1–::

  1c touch NH into long cast (2c up) ; ½ Fig8 up (2,1x)

9–::

  L-Chain, end 2c facing 1c

17–::

  All set | set to P ; 1c ½ Fig8, crossing up

25–::

  2c+1c RHA ; LHA', 3);
INSERT INTO 'dancecrib' VALUES (2943, '2012-01-22 19:30:03.915349+00', '2021-02-26 00:50:35.245344+00', 9388, 1, NULL, 'ace', '1-4::

  1c turn P RH 1½ moving down to 2plx and face out (2,1,3)

5-12::

  1c Mirror Fig8 on sides, 1c out and down, taking hands where possible. 1c face 1cnrs _while{8}_ 2c+3c R&L

13-16::

  Set to Corners (2,1x,3)

17--::

  Reels3 {6} on sides,1c RSh to 2cnrs | 1c cross RH (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13211, '2020-09-29 01:22:05.447108+00', '2020-09-29 01:27:51.651192+00', 20086, 2, NULL, 'ace', '1-8::

  1C dance ½ Petronella to finish in partner''s place.

9-12::

  1C lead down the middle.  2C step up on bars 11-12.

13-16::

  1C turn each other ½ way round, moving up the set in the process, then lead up to corners.  1M presents his partner under his right arm to face her corner.

17-24::

  1C set to and turn corners.

25-30::

  1C dance a reel of three with corners, beginning L.sh to 1st corners.

31-32::

  1C cross over, giving RH, to 2nd place on own sides.

  

Repeat having passed a couple



', 5);
INSERT INTO 'dancecrib' VALUES (9696, '2017-04-01 18:20:47.656441+00', '2017-04-07 14:51:02.219528+00', 17688, 1, NULL, 'ace', '1--::

  1c+2c turn RH | lead down 2 places, finishing on midline between 3c and 4c, with M above W ; 1c+2c ½ Reel4 on midline, looping into 3pl and 4pl (3c+4c step up twice) and all face up (3,4,2,1)

9--::

  3c (other cpls dance up the side and follow) lead down to 4pl and cast back to top (3,4,2,1)

17--::

  2c turn RH ½ and 2W, P following, casts up behind 4M, crosses, casts up behind 3W and crosses | 2c turn LH ½ (3c+4c down) (2,3,4,1)

25--::

  All set | 2x+3c & 4c+1c ½ RHA ; 3c+2c+1c+4c all swirl R to opposite sideline and chase clw ½ (4,1,2,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3300, '2012-01-22 19:30:19.613891+00', '2017-03-30 15:44:11.55362+00', 10655, 1, NULL, 'ace', '1–::

  1c+2c »Espagnole«, finishing the LH turn with 1M behind 1W facing 2M for

9–::

  1c+1cnrs Rsh lead-change Reel3 on 1diag. (1c changes lead at each end loop)

17–::

  1c+2cnrs lead-change Reel3 on 2diag. (Rsh to 2W), finish facing up between 3c, 1W on L of 1M

25–::

  1c join RH, cross out through 2pl own side, cast to 3pl (3c up) and into (4c step in) ; 1c+4c ½ Poussette



{{explanation}}

Espagnole: both W lead RHJ to M side, cross and cast back to exchanged places while{4} Men cross to W side, lead RHJ back to M side and cross to exchanged places ; all turn P EH (2,1)  

Original description is ambiguous; the deviser specifies Rsh for both reels (private communication, Eric Ferguson)', 2);
INSERT INTO 'dancecrib' VALUES (3432, '2012-01-22 19:30:25.285037+00', '2018-10-09 14:26:30.735283+00', 8487, 1, NULL, 'ace', '1–::

  1c+2c+3c petronella figure half way (1x,2x,3x)

9–::

  1c+2c ½ RHA _while_{2} 3c cross RH | all set ; 1c ½ Fig8 R (W up, M down) (2,1x,3)

17–::

  2c+1M & 1W+3c Reels3{6} across (Lsh to 3cnr) | 1c cross RH and face out (2,1,3)

25–::

  1c cast behind 3c, meet and dance to top, and cast to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2482, '2012-01-22 19:29:42.034575+00', '2019-03-15 20:06:48.294093+00', 3147, 1, NULL, 'ace', '1–::

  2c+3c set | advance, meet and face end NHJ ; dance out the and and cast to places (1,2,3,4)

9–::

  All A&R ; 1c+2c & 3c+4c RHA

17–::

  All Circle8 L, to (4x,3x,2x,1x) ; All A&R

25–::

  4c+3c & 2c+1c LHA ; All Circle8 R, to (1,2,3,4)

33–::

  2c+3c cross RH | cast around the end (ie 2c up, 3c down) ; ½ Fig8 round end C (1c+4c step to middle) (2,1,4,3)



{{explanation}}

Note: after twice through all are back in original places.', 3);
INSERT INTO 'dancecrib' VALUES (9688, '2017-03-31 00:18:25.048987+00', '2017-08-26 07:18:25.737758+00', 8483, 1, 202, 'ace', '1--::

 1c lead down the middle (2c up) ; and up to face 1cnrs

9--::

 1c+1cnrs set and turn BH to face 2cnrs ; 1c+2cnrs set and turn BH to 2plx (2,1x,3)

17--::

 Reels3{6} on sides (Lsh to 1cnr) | 1c cross RH (2,1,3)

25--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11966, '2019-07-15 04:00:13.584056+00', '2019-07-15 04:08:49.016807+00', 8489, 1, 202, 'ace', '1--::

  1M+2W set | cross RH ; 1W+2M repeat (2x,1x)

9--::

  1c+2c set | ½ RHA ; turn P RH (1,2)

17--::

  1c lead down ; and up. 2c step in ready for

25--::

  Poussette', 2);
INSERT INTO 'dancecrib' VALUES (9686, '2017-03-28 00:29:26.139761+00', '2017-04-01 08:51:36.279186+00', 17676, 1, NULL, 'ace', '1--::

  1c+2c & 3c+4c with NHJ A&R and face up/down ; All dance BtoB along sidelines 

9--::

  All Rsh Reels4 on the sides 

17--::

  1c+2c set | ½ RHA ; 1c+3c set | ½ LHA (2x,3x,1,4)

25--::

  1c+4c set | ½ RHA ; All turn P RH ½, face P close, and cast R to own side (2,3,4,1)

33--::

  Circle8 and back

', 5);
INSERT INTO 'dancecrib' VALUES (9697, '2017-04-01 19:17:25.802848+00', '2017-04-01 19:17:25.802848+00', 15677, 1, NULL, 'ace', '1--::

  1W, 1M following, cast off and cross (2c up) ; 1c+3c LHA and 1W face out (2,1x,3)

9--::

  1W, 1M following, cast up and cross (2c down) ; 1c+2c RHA (1,2,3)

17--::

  Reels3on the sides, 1c Rsh to 2c, finish for (1,2,3)

25--::

  1c set to 2c | change place RH ; 2c+1c Circle4 L (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (9690, '2017-03-31 00:56:07.474964+00', '2021-03-19 10:45:29.803265+00', 8486, 1, 202, 'ace', '1--::

 Circle6 and back

9--::

 Gr-Chain (1c cross to start)

17--::

 1c cross RH | cast 2 places ; turn RH ½ | dance up NHJ to 2pl in centre facing up

25--::

 1W+2W+3W teapots R _while{4}_  1M+2M+3M teapots L ; 1c dance up and cast off one (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3060, '2012-01-22 19:30:08.795713+00', '2021-04-24 19:33:15.536228+00', 5410, 1, NULL, 'ace', '1–::

  1W advance to 3M | set H.Schottische | 1W pulls Rsh back and dances to own place

9–::

  1M repeats with 3W

17–::

  1c followed by 2c+3c (who dance up) cast off behind own lines, turn in and lead up to places

25–::

  1c+3c DblFig8 round 2c (1c starts by crossing down) (1,2,3)

33–::

  1c+2c ½ Poussette (ending on sidelines or in middle?) ; 1c Turn BH twice

41–::

  1c+3c ½ Poussette ; All Turn BH twice (to 2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (9699, '2017-04-01 20:02:00.773826+00', '2017-04-01 20:02:00.773826+00', 16963, 1, NULL, 'ace', '1--::

  All W set advancing as all M set | All W cast R to own side as all M set advancing ; All W set twice as all M cast R to own side and set (1,2,3)

9--::

  1c (cross down) + 3c (cast) DblFig8 (1,2,3)

17--::

  2c+1c following dance between 3c, cast up on own side, touch hands and cast off to own places | All set

25--::

  “La Spirale”: 1c+2c Turn BH ¾ | All spiral R to (2,1,3) ; 2c+1c Turn BH

', 3);
INSERT INTO 'dancecrib' VALUES (11675, '2019-03-15 20:56:07.792019+00', '2019-03-17 00:31:31.498873+00', 19060, 1, NULL, 'ace', '

1--::

  1c long cast 2 places (2c+3c up) ; 2c+1c turn RH to finish in middle, facing other couple

9--::

  2c+1c R&L, starting up/down, end as at start

17--::

  Circle6 and back, to sidelines (2,3,1)

25--::

  Reels3 across, 3c start Rsh to 2cnr, 3c finish BtoB on midline, 3M facing up, 3W down

33--::

  Crown Triangles {6} | 3c petronella to own side (2,3,1)

', 4);
INSERT INTO 'dancecrib' VALUES (10558, '2018-03-29 09:40:43.998068+00', '2020-03-23 11:07:33.262984+00', 17050, 1, 202, 'ace', '1--::

  All M dance RSh round P to places ; all W repeat

9--::

  1c set | cast off (2c up) ; 1c pass P LSh, dance RSh round 1cnrs to finish BtoB facing 1cnrs

17--::

  Set to Corners (to 2,1x,3) ; 1c ½ Fig8 L (2,1,3)

25--::

  Reels3 on sides, 1c LSh to 3cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9695, '2017-03-31 12:05:33.792249+00', '2020-12-28 11:08:45.051896+00', 17687, 1, 202, 'ace', '1--::

 1c followed by 2c lead down ; 2c followed by 1c lead up to 1pl _while_ 1c finish facing 1cnrs

9--::

 1c turn CPCP to finish facing 1cnrs

17--::

 1c SetH&G to finish BtoB facing 2cnrs

25--::

 1c Reels{6} on sides, Rsh to 2cnr |1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14938, '2022-07-04 16:22:46.667523+00', '2022-07-05 10:13:37.980411+00', 20930, 1, 202, 'ace', '*Couple face couple RR*

1--::

  All turn opposite RH, face P (polite turn) ; turn P LH, face opposite (polite turn)

9--::

  R&L. All M face out

17--::

  L-Chain

25--::

  All dance BtoB ; all pass opposite RSh to meet next couple', 4);
INSERT INTO 'dancecrib' VALUES (9692, '2017-03-31 10:11:34.6198+00', '2022-10-04 19:01:31.660428+00', 8484, 1, 202, 'ace', '1--::

 Mirror Reels3 on the sides, 1c crossing down to start

9--::

 Repeat, 1c crossing back to own sides

17--::

 1c long cast to 3pl (2c+3c up) ; 1c set | cast (4c up) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (8200, '2014-02-14 10:36:55.084458+00', '2020-09-04 13:56:22.005655+00', 7554, 2, 776, 'ace', '_Formation:_ couples around the room facing anti-clockwise, ladies on the right.

_Music:_ 32 bar waltzes.



Bars:: 	_Description_

1-4:: 	Nearer hands joined, swing the inner leg (and joined hands) forward and back, then walk forwards.

5-8:: 	Repeat in the opposite direction.

9-10:: 	Facing partner, both hands joined, and heading clockwise, cross trailing leg over leading leg (ie right over left for ladies, left over right for men), then point with leading leg.

11-12:: 	Repeat in opposite direction.

13-16:: 	Take four steps anti-clockwise, pulling leading shoulder back to face alternately away from and towards your partner with each step.

17-24:: 	Joining both hands, swing together (slightly to the right of partner) and away, then change places, turning the lady under the man''s left arm while doing so. Repeat.

25-28:: 	In ballroom hold, take two steps anti-clockwise, then two clockwise.

29-32:: 	Waltz round the room.



Repeat ad lib. 

', 0);
INSERT INTO 'dancecrib' VALUES (2638, '2012-01-22 19:29:51.044522+00', '2020-09-05 10:10:40.006195+00', 7793, 1, NULL, 'ace', '{{explanation}}

Waltz step: small step right, pass left, close ; continue with left. Step goes up (as in PdB) not down (as in Strathspey) 



1–::

  1c dance BtoB ; cross RH and cast off (2c dance up)

9–::

  2c+1c dance BtoB ; 2c+1c+3c turn BH, 1c to face 1cnr

17–::

  1c ½Reel4 with 1cnrs ; repeat with 2cnrs and 1c pass Lsh into

25–::

  3c+1M (above) & 1W+2c (below) ½ circle3 to L | set in lines across ; all change places RH | 1c cast R to 2pl', 2);
INSERT INTO 'dancecrib' VALUES (3525, '2012-01-22 19:30:29.26195+00', '2020-12-21 11:11:18.690889+00', 9484, 1, NULL, 'ace', '1–::

  1c set | cast below 3c (2c up) and lead up to face 1cnrs

9–::

  1c+1cnrs set | change place RH ; set again to same person, corners pivoting R | 3W+2M turn RH ¾ to face corners on 2diag

17–::

  Repeat figure on 2diag (2W+3W & 2M+3M start), finish 2W/3M facing 2M/3W positions (1diag)

25–::

  Repeat figure on 1diag (1W+2W & 3M+1M start), on [31-32] 1c turn RH _while{2}_ 2c+3c chase 1 place clw. (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13973, '2021-04-24 11:03:41.585657+00', '2021-04-24 23:32:22.001859+00', 20336, 2, 30976, 'ace', '1-8::

  All 3 [4] couples set, Cross over giving RH, set, cross back RH

9-16::

  1s lead down middle and back

17-24::

  1s Turn RH (2 steps), cast to bottom of set (2s & 3s [& 4s] step up on 3&4), all turn RH (4 steps)

25-32::

  All circle 6 [8] hands round and back



*Deviser''s note* : May be danced in a four couple set with progression 2341 by casting below the fourth couple in bars 19 and 20.', 3);
INSERT INTO 'dancecrib' VALUES (2212, '2012-01-22 19:29:26.082056+00', '2020-03-24 13:20:32.924705+00', 12020, 1, NULL, 'ace', '_Strathspey_   



1–::

  1c cross RH | cast (2c up) ; 2c+1c+3c turn P RH ½, twirl R and dance out (2x,1,3x)

9–::

  1c cross RH | cast R (W up, M down) into facing lines across ; with opposite all turn RH ½, twirl R and out into lines across  (3c+1M now at top, 1W+2c at bottom)



{{title}}

Reel



17–::

  All Clap.  1M+2M+3M (W side) & 1W+2W+3W (M side) LHA ; 1c turn RH 1½, finishing a little inside sidelines _while{4}_ cnrs chase half round cclw

25–::

  2M+1M+3M (M side) & 2W+1W+3W (W side) LHA ; 1c turn RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (9703, '2017-04-02 22:18:36.88403+00', '2018-07-08 13:27:23.474882+00', 17679, 1, NULL, 'ace', '1--::

  1c set | cast (2c up) ; set | 1W casts up (2W down) as 1M casts off (3M up) (W: 1,2,3; M: 2,3,1)

9--::

  “1st-Couple Chain”: 1W+2W+3M+1M dance a La-Chain on the diagonal shape formed by their positions, 1c dancing as ''The Ladies''.  

17--::

  1c dance across Lsh round 1 cnr[pos], in from sides ; 1c Circle2 L (slip step) and face up NHJ on opposite side _while{4}_ 2W+3M step to end | 2c+3c set 

25--::

  1c dance to top, | cast off ; cross down RH and cast up to (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (9701, '2017-04-02 19:03:11.116306+00', '2017-04-02 19:08:07.227338+00', 8047, 1, NULL, 'ace', '1-::

  All dance mirror reels3 on the side, 2c starting out and up

9-::

  1c turn RH | cast off (2c up) ; 1c dance BtoB and face down (2,1,3)

17-::

  Grand Chain (2c cross to start)

25-::

  All Circle6 and back (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9702, '2017-04-02 19:25:18.725946+00', '2017-04-02 19:32:42.458833+00', 5291, 1, NULL, 'ace', '1-::

  Parallel RSh Reels3 on the sides, at end 1W faces out

9-::

  1W with 1M following cast off, cross up between 2c, cast off, and cross to 2pl (2c up) (2,1,3)

17-::

  Grand Chain (2c cross to start) 

25-::

  1c dance up | cast off ; turn RH (2,1,3)



*2nd time through: 1c casts to 4pl and 4c step up on [31-32]*

', 3);
INSERT INTO 'dancecrib' VALUES (3251, '2012-01-22 19:30:17.616685+00', '2017-04-03 00:19:23.691636+00', 6051, 1, NULL, 'ace', '1–::

  1c+3c cross down RH (2c+4c up) to sidelines (2,1x,4,3x,5), the W face up and M face down, and 2W faces 5M | all set ; 2W+5M stand _while{2}_ on the sidelines all turn person facing ¾ RH into lines across of 3 (facing down), 4 (facing alternately) , 3 (facing up) | all set

9–::

  Rsh Reels3 or 4 across, 1c+3c start to the R and finish LHJ facing 2cnrs (1M+3W passing Rsh)

17–::

  Set to 2cnr, and swivel inwards into RHJ | set to 4cnr ; set to 3cnr and swivel inwards into LHJ | set to 1cnr

25–::

  1W+2c, 1M+4c+3W, 3M+5c RHA ; 1c+3c turn LH and cast off  (4c+5c up) (2,4,1,5,3)', 4);
INSERT INTO 'dancecrib' VALUES (2758, '2012-01-22 19:29:56.230528+00', '2017-04-03 12:27:51.521778+00', 7457, 1, NULL, 'ace', '{{explanation}}

A new couple starts every 40 bars. For [1-40] only 1c dance, for [161-200] only 4c dance



1–::

  1c lead down {3}, up {3} and cast (2c up) (2,1,3,4)

9–::

  1c ½Fig8 up ; set advancing | turn BH ½ to own side into DTr formation (2,1,3,4)

17–::

  2c+1c+3c Set as in DTr | 1c+2c change place EH ; all set as in DTr | all set, 1c+2c advancing for

25–::

  1c+2c Allemande

33–::

  All Circle8 and back (2,1,3,4)



{{explanation}}

New top cpl (2c) repeats [1-40] while original 1c continues as follows



41–::

  1c cast to bottom (3c up) , turn RH and cast up into 3pl (3,2,1,4)

49–::

  1c ½Fig8 down round 4c ; set advancing | turn BH into extended DTr formation (3,2,1,4), (2c join NH with 1c in the middle and join hands with 3c+4c on own sides

57–::

  Set in DTr | 1c change places with 4c EH (2,3,4,1) ; all set | bottom couples change places EH again into allemande position

65–::

  2c+3c & 1c+4c Allemande

73–::

  All Circle8 and back (3,2,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (12681, '2020-03-22 01:22:21.419854+00', '2020-03-25 19:23:34.760868+00', 19876, 1, 202, 'ace', '1--::
  1c+2c Circle4 L ; 1c set | cast off (2c up) (2,1,3)
9--::
  1c+3c RHA ; LHA into facing Lines3 across (1M between 3c)
17--::
  1c set | turn RH ¾ to 2plx ; set | turn RH ½ to between ends _while{8}_ 2c+3c change places RH on sides | set ; cross RH | set
25--::
  1c set | cross RH ; dance RSh round 4cnrs[pos] to 2pl {2} _while{6}_ 3c+2c change places RH on sides | set ; cross RH | all set

', 2);
INSERT INTO 'dancecrib' VALUES (11679, '2019-03-16 11:32:28.159269+00', '2019-03-16 11:35:25.764732+00', 15048, 1, 1645, 'ace', '1-::

  1c &frac12; fig8 on sides starting in & down (2c up on [1-2]) ; 1c &frac12; fig8 up round 3c (3c up on [7-8]) ending (2,3,1x)

9-::

  3c+1c Swirl: &frac12; turn P RH into allemande hold facing down/up | change places LSh ; LHA, 1c end facing 1cnrs, 3c in 3pl

17-::

  1c set to & turn 1cnrs ; repeat with 2cnrs, end facing 1cnrs (2,1x,3)

25-::

  2c+1c+3c LSh Reels3{6} on sides | 1c cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11677, '2019-03-16 04:04:41.901408+00', '2019-03-16 04:16:03.417081+00', 5966, 1, NULL, 'ace', '1--::

  1c cast behind own line and back (1,2,3)

9--::

  1c+2c RHA ; LHA

17--::

  1c lead down and up and stay in middle (1,2,3) [Alternative: slip down and back]

25--::

  1c cast off to 3pl (2c+3c up on [27-28]) ; 1c turn RH (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (1987, '2012-01-22 19:29:13.689569+00', '2021-06-20 09:50:26.470606+00', 1350, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; cast Rsh round 4cnr and pass P Lsh to face 1cnr

9–::

  1c+1cnrs ½ Reel4, 1c pass Rsh to face 2cnr pos _while_{4} the other corner dancers chase ½ clw ; Repeat with 2cnrs

17–::

  Repeat with 3cnrs ; repeat with 4cnrs, but pass Lsh into

25–::

  Teapots R ; and L (2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11678, '2019-03-16 04:27:47.74338+00', '2019-03-16 04:45:41.492488+00', 13101, 1, NULL, 'ace', '*Set: 4 dancers in square, numbered clw 1,2,3,4, with 5 in middle facing 1*

1--::

  1+5 turn RH ; 5 Lsh round 4pos, to place _while{4}_ cnrs ½ R&L (start 1 with 2, 3 with 4) (3,4,1,2,5)

9--::

  3 (at top) +5 Turn LH ; 5 Rsh round 2pos to place _while{4}_ cnrs ½ R&L (start 4 with 1, 3 with 2) (1,2,3,4,5), 

17--::

  5 Fig8 round 1 + 3, Lsh to 3

25--::

  5+3 change place LH | 3+1 change RH; 1+4 change LH | 4+2 change RH (3,4,5,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (2416, '2012-01-22 19:29:36.740995+00', '2019-03-16 12:51:50.39016+00', 2842, 1, NULL, 'ace', '1–::

  1W+2W+3M+4M ½R&L ; 1M+2M+3W+4W ½R&L (4x,3x,2x,1x)

9–::

  4c+3c RHA _while_{4} 2c+1c LHA ; Continue, 2M+3M changing wheels on [13], the next two on [14], and so till all have changed

17–::

  1c+2c RHA _while_{4} 3c+4c LHA, finish on sides, 1c facing 3c and 2c & 1c facing P ; All set H.Schottische  (1x,2x,3x,4x)

25–::

  1c+3c & 2c+4c R&L (overlapping)

33–::

  All set | 1c+2c ½ RHA ; 1c+3c ½ LHA | 1c+4c ½ RHA', 3);
INSERT INTO 'dancecrib' VALUES (11681, '2019-03-16 13:51:40.364191+00', '2019-03-16 13:51:40.364191+00', 8146, 2, NULL, 'ace', '*Couples with nearer hands joined facing counter-clockwise around the room, Men on the Left*

Start with outside foot - instructions for man

1-2::   Walk 3 steps forward and point (L,R,L and point)

3-4::   Woman crosses in front of her partner with 3 steps and point, while man crosses behind 3 steps and point (R,L,R and point). Rejoin nearer hands after crossing.

5-6::   Repeat 3-4 with man crossing in front of woman (no turns on the crossings).

7-8::   Walk backward 3 steps and touch, finishing in ballroom hold.

9-12::   2 side steps along LOD, 2 side steps'' back;

13-16::   2 waltz turns along LOD', 0);
INSERT INTO 'dancecrib' VALUES (9713, '2017-04-06 05:04:35.665286+00', '2020-06-28 21:11:38.671791+00', 17307, 1, 202, 'ace', '1--::

 All A&R{2} touching RH | cross RH ; repeat with LH (1,2,3)

9--::

 2c Petronella | set advancing ; turn RH 1 ¼ to 2pl 2W facing out | 1c+2c change places LH (2,1,3)

17-- ::

 Parallel Reels3 on sidelines, 1c Rsh to 3c

25-- ::

 3C Allemande (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (11968, '2019-07-18 17:20:25.589679+00', '2019-07-18 17:26:22.691731+00', 15309, 1, 202, 'ace', '1--::

  1M+2W & 3M+4W cross RSh to P and cast R to exchanged places ; all cross RH with opposite person | set 

9--::

  1W+2M & 3W+4M repeat same pattern [1-8] (2x,1x,4x,3x)

17--::

  1c & 4c dance out through ends and cast back to places ; 1c & 4c turn P RH ½ | 1c+4c ½ RHA (2x,4x,1x,3x)

25--::

  All set | all La Baratte and face cclw (2,4,1,3)

33--::

  All chase cclw ½ ; Circle8 R (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11422, '2018-12-22 19:42:31.447923+00', '2020-09-05 10:17:04.494562+00', 7892, 1, 202, 'ace', '*3-couple set with No7 facing down between 2c*

1--::

  1c & 3c turn P RH _as_ 2c+No7 LHA ; 1c & 3c turn P LH _as_ 2c+No7 RHA

9--::

  ½ Reel3 on 1diag ; ½ Reel3 on 2diag _while{8}_ 2c set | cast and chase cclw to exchanged places (3x,2x,1x and No7 in original place)

17--::

  2c+1c advance and join NH with P | 2c dance to 3plx under 1c arch _while{4}_ No7 dance to top above 1pl | set to face down ; 3c+1c advance and join NH with P | 1c dance to 1plx under 3c arch _while{4}_ No7 Highland steps (No7, 1x,3x,2x)

25--::

  1c+No7 RHA 1½ to original places _while{4}_ 2M & 3M pass their P in front of them to own side | 2c+3c set ; 1W+No7 followed by 1M dance down to 3pl, 1M as new No7 to centre (2c+3c up) ; all set', 2);
INSERT INTO 'dancecrib' VALUES (13820, '2021-03-16 22:34:14.525413+00', '2021-03-18 20:43:39.565929+00', 6766, 1, 202, 'ace', '1--::

  1c cross RH |cast off (2c up) ; 2c+1M & 1W+3c RHA (2,1x,3)

9--::

  1c cross LH | dance LSh round 4cnrs to midline outside the set ; 1W+2c & 3c+1M LHA

17--::

  1c dance LSh round 1cnrs to 2plx ; 1c ½ Fig8 L round 4cnrs (to 2,1,3)

25--::

  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (14834, '2022-05-21 23:26:56.94763+00', '2022-05-22 09:08:06.597273+00', 11443, 1, NULL, 'ace', '1--::

  1c set | dance down the middle (2c up) and cast up round 3c to face 1cnrs 

9--::

  ½ Reel4 on 1diag, 1c pass Rsh to face 2cnrs ; ½ Reel4 on 2diag, finish (3x,1,2x)

17--::

  All set | [Snake Pass] 1W leading 3M+3W & 1M leading 2W+2M pass Lsh, dance L to end, cross and finish (2x,1,3x)

25--::

  Reels3 on the sides, 1c starting inwards and to the R, 2c & 3c cross to own side when passing down through 2pl (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (8956, '2015-11-02 04:49:37.712161+00', '2020-09-07 08:53:03.686685+00', 8607, 2, 2452, 'ace', '1-4:: SET TWICE: set to partner (with two pas de basque, or a Highland step)

5-8:: TULLOCH TURN: turn partner with right arm & Tulloch turn twice around;

9-12:: SET TWICE: set to partner

13-16:: TULLOCH TURN: turn partner with left arm & Tulloch turn twice around;

17-24:: IN & OUT: women advance & retire twice AS men set, advance, retire & set:

25-32:: GRAND CHAIN: starting with right hands to partner, dance a Grand Chain with 2 steps to each hand: end facing the 5th person who is your new partner.



REPEAT with new partner ', 0);
INSERT INTO 'dancecrib' VALUES (11680, '2019-03-16 11:40:28.742091+00', '2020-12-06 10:26:04.99836+00', 15052, 1, 1645, 'ace', '1-::

  1c lead down & 1M crossing 1W in front they cast RSh up round 3M (2c up) ; 1c dance across & cast LSh round 2W to end BtoB facing opposite side

9-::

  1W+2M+3M & 1M+2W+3W circle3 & back

17-::

  1W+2M+3M set in DTr & LHA _while{6}_ 1M+2W+3W set in DTr & RHA | 1c cross up (1W with a loop) _while{2}_ 2M+3M turn LH _while{2}_ 2W+3W turn RH ending (1,2,3)

25-::

  1c+2c dance the Helix (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3139, '2012-01-22 19:30:12.941488+00', '2020-12-21 11:20:16.546237+00', 9563, 1, NULL, 'ace', '1–::

  1c+2c+3c Mirror Reels3{6}, 2c start out and up | 1c dance on to DTr position own side _while{2}_ 2c dance on to 1pl

9–::

  All set as in DTr | on [10] 1c face ¼ R | 2c+1M & 1W+3c set as DTr ; 1c cast R round 2cnr and meet, swiveling R to DTr position facing opp. side

17–::

  Repeat [9-12] with new corners ; 1c casts R round 4cnr (2,1,3)

25–::

  Reels3 across, Lsh to 1cnr.', 3);
INSERT INTO 'dancecrib' VALUES (9706, '2017-04-05 00:32:56.882482+00', '2017-04-08 21:12:39.976535+00', 16475, 1, NULL, 'ace', '1--::

  1c set | turn RH ½ into promhold (2c up) ; dance between 3c, cross and cast up to (2,1,3)

9--::

  Circle6 and back (2,1,3)

17--::

  1c+3c “Divided Knot”: 1c+3c set | Turn P BH ½ and face down ; 3c with 1c following split and cast up on opposite side | 3c+1c cross RH (2,3,1)

25--::

  1c dance to top and cast to 3pl ; All “gypsy” Rsh round P to (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (2995, '2012-01-22 19:30:06.056628+00', '2021-04-25 12:58:36.358293+00', 5204, 1, NULL, 'ace', '1–::

  1c set, cross down RH (2c up) ; behind 3c and dance up the middle to face 1cnrs

9–::

  1c set to 1cnrs, turn 1cnr RH to face 4cnr ; ½ Lsh Reels3 across, at the end 1c pass Rsh to face 3cnr pos. (2c+3c make loop)

17–::

  1c set to 3cnr pos. and turn cnr RH to face 2cnr pos. ; 1M+2c & 1W+3c ½ Lsh Reels3 across, 1c finish facing P up/down (2c+3c make loops)

25–::

  1c 1½ LH turn ; 1W+2c & 1M+3c RHA (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3080, '2012-01-22 19:30:10.366043+00', '2022-05-22 14:10:54.224045+00', 5480, 1, NULL, 'ace', ' *Starting positons (1,2x,3,4x)*  

1–::

  1c+4c cross RH | cast to middle (2c up, 3c down) ; ½ Fig8 round end couple (2x,1,4x,3)

9–::

  1c+4c ½R&L, no polite turn; All ½Reels4 on sides, 1c start dn, 4c up (3,1x,4,2x) & W face out

17–::

  3c+1c and 4c+2c, M-Chain

25–::

  Circle8 and back (3,1x,4,2x)', 3);
INSERT INTO 'dancecrib' VALUES (12997, '2020-07-28 20:28:18.462748+00', '2020-07-29 04:28:25.662455+00', 5174, 1, 202, 'ace', '1--::
  2C Set&Rotate (2,1,3)
9--::
  1c pass P RSh, dance RSh round 1cnrs into facing lines3 across ; pass P LSh, dance LSh round 3cnrs to 2pl (2,1,3)
17--::
  ½ Reel4 on 1diag, 1c pass P LSh to face 2cnrs ; ½ Reel4 on 2diag (3x,1x,2x)
25--::
  All turn P RH flowing into ; Circle6 L ½ (2,1,3)

*Deviser''s Note:  
1st couple, who have just finished their second time through, cast to the bottom of the set on bars 1 and 2, as the new 1st and 2nd couples start the dance.*', 4);
INSERT INTO 'dancecrib' VALUES (9707, '2017-04-05 00:35:07.833345+00', '2019-07-02 02:39:18.274129+00', 13078, 1, 202, 'ace', '1--::
 1c & 3c ½ Fig8 down round 2c/4c  ; 1c & 3c dance down one and turn inwards to face up NHJ _while{2}_ 2c & 4c dance up one on sides, turn inwards to face down NHJ | all set
9--::
 2c+1c & 4c+3c Circle4 L ; ½ Reels4 on sides, on [16] 1c+4c turn LH ¾ to finish in line4 across, W in centre, ready for
17--::
 1c+4c The Targe (3x,1,4x,2)
25--::
 ½ Reels4 on sides ; all set | 4c&3c cross RH (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9708, '2017-04-05 11:20:40.979402+00', '2017-04-05 11:20:40.979402+00', 16456, 1, NULL, 'ace', '1--::

  2c+3c set to P | La Baratte, finish (1,2x,3,4x), 2W+3W facing out

9--::

  2c+3c (W leading) cast R round their 1cnr and change lead, pass Lsh in the middle ; cast R round their 2cnr and change lead, dance into middle _while{8}_ 1c+4c dance in ½ LHA, and out to opposite cnr ; repeat (1,3x,2,4x)

17--::

  1c+4c chase clw ½ _while{4}_ 3c+2c LHA and finish in middle ; All middles set to cnrs and change place RH 

25--::

  3c+2c chase clw ½ _while{4}_ 1c+4c LHA and finish in middle 4c facing up, 1c down ; 2c+3c set to P and cross RH _while{4}_ 4c+1c dance out the end and cast to middle (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (9712, '2017-04-05 22:42:46.842387+00', '2017-04-05 22:47:39.483304+00', 11110, 1, NULL, 'ace', '1--::

  1c+2c set | 1c cross into 1M+2W & 1W+2M turn BH  on sideline (1c pass P Rsh on [5]) , finish on midline 1c above 2c, M facing down and facing P | 1c+2c set to P

9--::

  1c+2c ½ Reel4 ; Spiral Rsh round P to (2,1,3), 1c facing out

17--::

  1c cast R, cross the set, cast to 2plx _while{4}_ 2c+3c ½ R&L ; All cross RH and set (3,1,2)

25--::

  3C knot (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11969, '2019-07-19 06:47:08.666416+00', '2019-07-19 07:10:57.63528+00', 18438, 1, 202, 'ace', '*Starts (1,2x,3). 2c is the dancing couple.*



1--::

  3C S&Link ; all change places RH | chase clw 2 places

9--::

  2M+1M+3M & 2W+1W+3W RHA : 2c ½ Fig8 L to 2pl

17--::

  ½ diagonal R&L starting on 2diag (to 3,2x,1) ; 2c+1c set | ½ RHA (3,1x,2)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2971, '2012-01-22 19:30:05.095932+00', '2020-12-21 12:12:03.004164+00', 9647, 1, NULL, 'ace', '1–::

  All C A&R ; 1c slips to bottom (other Cs up)

9–::

  All C A&R ; 2c slips to bottom (other Cs up)

17–::

  3c+4c circle4 and back _while{8}_ 5c+6c RHA ; LHA _while{8}_ 1c+2c R&L

25–::

  1c+2c slip to top (other C step down one) ; 1c casts to 6pl _while{4}_ other Cs RH turn



{{explanation}}

This is in fact an ECD dance', 2);
INSERT INTO 'dancecrib' VALUES (9714, '2017-04-06 05:41:30.599993+00', '2020-10-26 18:37:23.459808+00', 17308, 1, 202, 'ace', '1--::

 1c+2c & 3c+4c Poussette (1,2,3,4))

9--::

 2c+3c Set&Rotate (1,3,2,4)

17--::

 3c+2c RHA to sidelines _while{4}_ 1W & 4M followed by P chase clw ½ (to 4x,3,2,1x) ; 4c+1c RHA to sidelines (4c in 2plx, 1c in 3plx) _while{4}_ 3W+2W leading & 2M+3M leading chase clw ½ to sidelines (2c in 1plx, 3c in 4plx) (to 2x,4x,1x,3x)

25--:: 

 All turn RH ½ and cast to own sides ; 2c+4c & 1c+3c Circle4 L (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (7920, '2013-08-21 08:31:51.304076+00', '2023-02-04 01:23:11.996236+00', 8174, 3, NULL, 'ace', '1-8::
    1s set advancing & turn RH to face 2s diagonally NHJ, 1s+2s set &
    turn (Men RH, Ladies LH) into centre for Poussette
9-16::
    1s+2s dance Poussette 1s ending in middle for Double Triangles
17-24::
    2s+1s+3s dance Double Triangles 1s ending in 2nd place own sides
25-32::
    _1/2_ reels of 3 across,1L with 2s & 1M with 3s, 1s pass LSh to
    dance 1/2 reels across with other couple', 0);
INSERT INTO 'dancecrib' VALUES (11682, '2019-03-16 13:58:34.262661+00', '2019-03-16 14:04:11.204715+00', 7548, 2, NULL, 'ace', '*In couples round room. Ballroom hold. Men with back to centre of room. Man begins left foot, woman right foot.*  

1-4::

  Highland Schottische setting steps in line of dance then against line of dance    

5-6::

   Common Schottische setting steps with half a turn on the hop at the end of each setting   

7-8::

   Step hop placing the free foot on the hopping leg and turning as you dance. Man may have hands on partner''s waist and she has hands on partner''s shoulders.  







', 0);
INSERT INTO 'dancecrib' VALUES (2865, '2012-01-22 19:30:00.717827+00', '2020-09-06 09:51:33.140477+00', 8127, 1, NULL, 'ace', '1–::

  1c set and cast (2c up) ; 2c+1c ½ R&L (1x,2x)

9–::

  1c set and cross down to 2pl (2c up), 1M face out ; 2c+1c RHA ¾ (1c now on W side).

17–::

  1c + 2c L-Chain (across).

25–::

  1W+2W change places RH | 1c set ; 1c ½ Fig8 up (2,1).', 3);
INSERT INTO 'dancecrib' VALUES (9710, '2017-04-05 18:17:57.024558+00', '2020-10-26 18:30:18.322052+00', 17305, 1, 202, 'ace', '1--::

 All set | cross RH ; set | 1c+3c turn RH ¾ to midline

9--::

 1c+3c Reel4 to sidelines (1x,2x,3x)

17--::

 1c+2c+3c chase clw ½ ; All turn BH (3,2,1)

25--::

 2c+1c set | ½ R&L | cross RH (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (11972, '2019-07-23 00:05:46.848616+00', '2019-07-23 13:03:31.087383+00', 16878, 1, 202, 'ace', '1--::
  1c+2c+3c set | 1c+3c ¾ DblFig8, 1c casting _as_ 3c cross up. On [8] 3c loop to 1pl and face down (3,2,1x)
9--::
  Gr-Chain, 1c crossing RH (3,2,1x)
17--::
  1c dance up | change sides, 1M crossing above 1W with 1W under 1M''s arm ; dance down | cast up to 2pl (3,1,2)
25--::
  3c+1M & 1W+2c LHA ; RSh »Snake Pass« [: unwind the LHA, 1c leading, pass other snake RSh through 2plx and chase clw] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9715, '2017-04-06 06:18:22.518762+00', '2020-01-27 11:37:14.295504+00', 17309, 1, 202, 'ace', '1--::

  1c set | cross RH ; cast (2c up) | set advancing pulling RSh back to face 1cnrs

9--::

  Set H&G. On [15] all clap (2,1,3)

17--::

  1c turn 1cnrs RH, pass RSh ; turn 2cnrs RH to 2plx | all set  (2,1x,3)

25--::

  1c turn 1cnrs LH | turn 2cnrs RH ; cross LH to 2pl | all set (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (13213, '2020-09-30 04:44:21.910336+00', '2020-09-30 08:41:59.176527+00', 13289, 1, 202, 'ace', '1--::
  1c+2c set | 1c dance down to 2pl _while_ 2c cast to 1pl ; 1c cast down behind 3c, meet, dance up and cross (no hands) to face 1cnrs
9--::
  SetH&G. On [15-16] 1c dance to centre BtoB facing own sides
17--::
  DTr. 1c finish BtoB in centre, 1M facing up
25--::
  Reels3 {6} on sides, 1c RSh to 2cnrs | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9814, '2017-04-28 07:46:57.340034+00', '2020-10-01 10:39:57.460168+00', 14496, 1, 202, 'ace', '1--::

 1c+2c DblFig8, 1c crossing down

9--::

 Inveran Reels3, 1c crossing down (1,2,3)

17--::

 1c turn BH | cast (2c up) ; cross RH | cast round 1cnr into facing lines across

25--:: 

 Diag R&L (up/dn)

33--:: 

 S&Link3 ; all turn BH (3,1,2)

41--:: 

 1c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (13376, '2020-11-23 15:37:21.096543+00', '2020-11-23 15:41:07.20346+00', 15542, 1, 202, 'ace', '1--::

  1c+2c the Knot (2,1,3)

9--::

 2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA (2,1,3)

17--::

  1c cross RH | turn 1cnrs LH ; turn P RH | turn 2cnrs LH and face up/down

25--::

  1c turn P RH ¾, lead up (3c step up on [27-28]) and cast off to 3pl (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (13580, '2021-01-24 19:44:43.8426+00', '2021-01-24 19:48:20.696237+00', 12358, 1, 202, 'ace', '1--::

  Reels3 on opposite sides (1x,2,3)

9--::

  Reels3 on own sides (1,2,3)

17--::

  1c cross RH | cast off (2c up) ; cross LH | cast off (3c up) (2,3,1)

25--::

  Circle6 and back (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (1897, '2012-01-22 19:29:08.66175+00', '2019-03-17 11:54:37.018032+00', 2050, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c Tournée (2,1,4,3)

9–::

  All C advance {1} and retire {1}, repeat ; all C dance BtoB

17–::

  4 diagonal crossings: top 3 persons on M side cross RH with bottom 3 on W side | top 3 on W side cross LH with bottom 3 on M side ; repeat (3x,4x,1x,2x).

25–::

  3c+4c & 1c+2c set | ½ circle4 to the left (4,3,2,1) ; 1c making an arch dance up and cast round 4c to 2pl _while_{4} 3c+2c dance down under the arch, 2c casting up to 3pl and 3c into 4pl (finish 4123).', 2);
INSERT INTO 'dancecrib' VALUES (12049, '2019-08-27 07:06:48.850292+00', '2021-05-15 20:34:19.860759+00', 4421, 1, 202, 'ace', '1--::

  All set | 1c dance down _while{2}_ 2c cast to 1pl & 3c face out : 1W+2W+3W LHA _while{4}_ 1M+2M+3M RHA

9--::

  1c dance down ; on [13] change sides {1} to face up, W twirling under M''s arm, and dance up {3} to 3plx _while{8}_ 2c+3c DblFig8 2c crossing down and 3c casting up (2,3,1x)

17--::

  Gr-Chain, 2c crossing RH (2,3,1x)

25--::

  Circle6 and back (2,3,1x)', 4);
INSERT INTO 'dancecrib' VALUES (11683, '2019-03-16 14:16:19.362971+00', '2019-03-16 14:30:59.874087+00', 8157, 2, NULL, 'ace', '*Couples round the room. Ballroom hold, men with back to centre.*  

*Three 16 bar parts*  



A::

  Polka round the room, opening out to face the line of dance.  



B::

  Man takes partner round the waist, his right hand in her right hand, resting on her right hip, woman''s left hand on man''s right shoulder; he places his left hand on left shoulder of man in front: march round circle  



C::

  Let go of partner. Man faces inwards. Man stands and claps using both hands in rhythm as in note below: own thighs once, own hands twice, then hand of both neighbours at head-height (own right to right hand neighbour''s left, left to left hand neighbour''s right), then own hands above own head once. Repeat to end of C music.   Meanwhile, women dance round outside of circle.  



Notes   

  *When A music begins again, men turn to face out ready to polka with a new partner.*   



  *At the end of the last time through, bands usually play 16 bars of A music so as to finish with a polka.*   



  *Clapping (in 2/4 rhythm) goes 1-2 -and 1-2 ; 1-2 and 1-2, etc.*

', 0);
INSERT INTO 'dancecrib' VALUES (11684, '2019-03-16 14:34:36.00412+00', '2019-03-16 14:52:20.640783+00', 11388, 1, NULL, 'ace', '

1--::

  All set and cross RH ; all set | Turn P LH ½ to centre facing up  

9--::

  3C Allemande (3,2,1)

17--::

  1c cross RH | cast up (2c down) ; dance up between 3c and cast off to 2pl (3,1,2)

25--::

  1c set and cross RH _while{4}_ 2c+3c cross RH and chase one position clw ; Set and Link3  



*The set has now turned 90 deg clw, (3,1,2)*  



*repeat 3 times*', 3);
INSERT INTO 'dancecrib' VALUES (10256, '2017-11-13 16:54:45.377161+00', '2020-09-05 11:05:26.637788+00', 18072, 2, 160, 'ace', '1-8::  Interlocking Reels4 on the periphery.

9-16::  Circle left 3/4 - 1M+3M break the circle and 1C lead 4C + 3C lead 2C to straight lines on sides, all set. (1C + 4C facing 2C + 3C respectively)

17-24::  Dance La Baratte with opposite, all set.

25-32::  1C 2C also 3C 4C dance LHA once round - 2M+4M lead wheels into a RH chase part way around the other Wheel - end 4 1 2 3, 4C in top place.

33-40::  Circle left [4] ; all face out of set and chase (women lead) back to progressed places. ', 3);
INSERT INTO 'dancecrib' VALUES (6283, '2013-08-21 08:31:21.69817+00', '2020-09-07 08:58:22.389773+00', 8688, 3, NULL, 'ace', '{{title}}

Strathspey



1-8::

    All dance interlocking reels of 4 round the set

9-16::

    Men dance LH across 1/2 way, into centre & turn loop left to dance

    out opp place, Ladies repeat with 1/2 RH across & loop right to opp

    pl

17-24::

    3s+1s lead into centre, lead out (with opp partner) between side

    couples, cross & dance to meet partner & turn RH to orig places

25‑32::

    2s+4s repeat but turn partner RH 1.1/2 times



{{title}}

Reel



1-8::

    Men dance behind partner & next Lady, dance in to end BtoB facing

    the Lady just passed, all set & 1/2 turn RH

9-16::

    All dance double reels of 4 (Ladies giving LH in centre to start)

17-24::

    Ladies dance LH across once round & all turn RH 1.1/4 times to sides

    (Men now in new places with new partner)

25-32::

    All circle 8H round & back



{{explanation}}

Repeat three times to return to original places', 0);
INSERT INTO 'dancecrib' VALUES (2326, '2012-01-22 19:29:31.634362+00', '2020-12-19 14:18:48.82841+00', 8129, 1, NULL, 'ace', '1–::

  1c set | turn RH 1 ½ | cast off to 2plx (2c up)

9–::

  2c+1c+3c Reels3 on the sides (1c starts in and down), 1c finish in tandem on midline facing up, 1W leading 1M

17–::

  1c cast Rsh round 1W position into middle at 2pl, and final fast pivot R to face out W side, 1M leading _while{4}_ 2cnrs (2W+3M) dance in, Turn RH, and return to places ; repeat: 1c cast Rsh round 3W position, and pivot, to face downwards, 1W leading, _while{4}_ 1cnrs make the RH turn

25–::

  Repeat round 3M position with 2cnrs ; round 1M position with 1cnrs, 1c finishing in 2pl.', 3);
INSERT INTO 'dancecrib' VALUES (3308, '2012-01-22 19:30:19.915008+00', '2020-12-21 12:16:57.305515+00', 9648, 1, NULL, 'ace', '1–::

  Circle8 and back.

9–::

  2c+3c ½RHA _while{2}_ 1c&4c chase cclw to next corner position, centre couples change places LH with corners ; repeat from new positions (1c+4c ½ RHA _while{2}} 2c+3c chase, change places LH)

17–::

  Repeat bars 9-16 from new positions to (4x,3x,2x,1x) with 3c+2c in the middle

25–::

  3c+2c ½ RHA into | turn P RH ½ to opposite side (4x,2x,3x,1x) ; 4c+2c & 3c+1c ½ R&L (to 2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2317, '2012-01-22 19:29:31.284419+00', '2021-04-02 10:31:13.013016+00', 2453, 1, NULL, 'ace', '1–::

  1W+2M & 3W+4M set facing diagonally and cast clw (W down, M up) (Partners step R) ; 2c+1c & 4c+3c RHA

9–::

  2M+1W+4M+3W half Reel4 on midline ; at top and bottom RHA 1¼ to bring other dancers onto midline

17–::

  1M+2W+3M+4W half Reel4 on midline ; at top and bottom RHA to 4,3,2,1, 1c dancing to sidelines, the others stay together for

25–::

  4c+3c+2c Allemande (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (13824, '2021-03-18 22:12:07.403875+00', '2021-03-19 13:04:12.064191+00', 15766, 1, 202, 'ace', '1--::
  1c set | cast off to 3pl (2c+3c up) ; 2c & 1c Petronella Turn | set
9--::
  2c & 1c repeat [5-8] (to 2x,3,1x) ; 1c dance up between 2c | cast off (3c down) (2x,1x,3)
17--::
  1c ½ Fig8 up round 2c (to 2x,1,3) ; 2c ½ Fig8 down round 1c (2,1,3)
25--::
  2c+1c R&L (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (12518, '2020-01-19 22:02:01.925914+00', '2020-01-19 22:14:59.318476+00', 5615, 1, NULL, 'ace', '1--::

  1c set | cast (2c up) ; 2c+1W & 1M+3c RHA

9--::

  1c cast Rsh round 1cnr, meet P on midline and pivot R, cast Rsh round 4cnr to sideline facing 4cnr [= Pass Half Round]

17--::

  Reels3{6} on the sides, 1c Rsh to 4cnr | 1c turn LH to face 3cnr

25--::

  2c+1M & 1W+3c Reels3{6} across, 1c Lsh to 3cnr | 1c cross down RH to 3pl (3c dance up)  (2,3,1)   





*Note: If dancing in a 4C set (8 x 32), 1c cross to 2pl on [31-32] (2,1,3)*

', 3);
INSERT INTO 'dancecrib' VALUES (7889, '2013-08-21 08:31:50.589251+00', '2023-02-04 01:23:09.733206+00', 7036, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH to end facing own sides
9-16::
    1s dance Double Triangles ending with 1s 1/2 turning 1st corners RH
17-24::
    1st corners dance reels of 3 on sides (RSh to 1s to start)
25-32::
    1s dance RH across (1L with 2s & 1M with 3s) until 1s meet in
    centre, 1s turn LH to Lady facing up & Man down _while_ 2s & 3s 1/2
    RH to own sides
33-40::
    All set as double triangles, 1s 1/2 turn 4th corners & dance reels
    of 3 across (Lady with 2s & Man with 3s) 1s end 2nd places.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14077, '2021-06-19 20:54:46.832853+00', '2021-06-19 20:54:57.222508+00', 281, 1, 1645, 'ace', '1-::

  1c set | cast off (2c up) ; turn 1&frac12; LH to face 1cnrs

9-::

  1c &frac12; diag RSh Reel4 with 1cnrs, pass RSh ; repeat with 2cnrs & pass RSh to own sides (3x,1,2x,4)

17-::

  1c set | cast off to 3pl (2c up) ; turn 1&frac12; LH to face 1cnrs

25-::

  1c &frac12; diag RSh Reel4 with 1cnrs, pass RSh ; repeat with 2cnrs & pass RSh to own sides (3x,4x,1,2)

33-::

  1c+2c &frac12; RHA | 4c+2c &frac12; LHA ; 3c+2c &frac12; RHA | 2c & 1c &frac12; turn RH (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11687, '2019-03-17 01:25:29.036614+00', '2019-03-17 01:45:48.976007+00', 19242, 1, NULL, 'ace', '1--::

  1c set | turn RH ; Mirror ½ Reels3 on the sides (2c out and up) (3,2,1)

9--::

  1c in promhold + 2c ½ Reel3 across, Rsh to 2W (2c to 3plx) | 3c+1c ½ RHA | All set (1x,3x,2x)

17--::

  All chase half round clw ; All turn P RH, 2c to 1pl and 3c+1c ready for

25--::

  3c+1c Poussette (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9991, '2017-07-04 03:43:06.730554+00', '2020-10-01 11:45:24.45566+00', 14590, 1, 202, 'ace', '1-- ::

 1c+2c ½ R&L ; 2c ½ Fig8 RHJ to 1pl (2,1x,3)

9-- ::

 2c+1c La-Chain

17-28 ::

 3C R&L

29-32 ::

 1c ½ Fig8 RHJ to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10888, '2018-07-12 21:10:59.127142+00', '2023-02-28 21:46:07.226649+00', 18393, 1, NULL, 'ace', '*On 2nd chord, 3c & 4c cross to opposite sides (1,2,3x,4x)*

1-::  All set | 1c & 4c dance La Barratte with partners to end facing up/down (1x,2,3x,4)

9-::  1c+2c & 3c+4c dance La Barratte on the sides | 1c+2c & 3c+4c chase 1pl cclw in own &frac12; of set

17-:: 1c+2c & 3c+4c dance &frac12; _gender reversed_ L-Chain (M turn &frac34; RH) to (2x,1,4x,3) ;

      2c & 3c chase cclw &frac12; way _while{4}_ 1c+4c RHA (3x,1,4x,2)

25-:: All &frac12; LSh Reels4 on the sides (2,4x,1,3x) ; 4c & 1c &frac12; Fig8 out the ends to (2,4,1x,3x)', 5);
INSERT INTO 'dancecrib' VALUES (11686, '2019-03-16 19:38:59.572358+00', '2019-03-16 23:22:58.419839+00', 6807, 1, 202, 'ace', '1--::
  1c turn RH | cast (2c up) ; turn LH to face 1cnrs
9--::
  1c dance RSh round 1cnrs to centre, pivot R to face 4cnrs _while{4}_ 1cnrs A&R ; 1c & 4cnrs repeat [9-12]. 1c face 3cnrs
17--::
  1c & 3cnrs repeat [9-12]. 1c face 2cnrs ; 1c & 2cnrs repeat [9-12]. On [24] 1c turn P LH to face 1cnrs
25--::
  Reels3 across, 1c LSh to 1cnrs (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (11676, '2019-03-15 23:03:21.170238+00', '2019-03-17 00:35:11.15481+00', 11178, 1, NULL, 'ace', '*Start (1,2,3x,4x)*   

1--::

  1c+2c & 3c+4c Circle4 L, finish middles facing ends, NHJ with P ; All set, 1c & 4c turning inwards to face out the ends | 1c+4c cast inwards as 2c+3c dance to end and cast into end places (2,1,4x,3x)

9--::

  1c+4c ½ La-Chain and face P ; ½ M-Chain (2,4,1x,3x)

17--::

  All set to P | 2c+4c & 1c+3c RHA | All set (2,4,1x,3x)

25--::

  Reels4 on the sides (2,4,1x,3x)

', 4);
INSERT INTO 'dancecrib' VALUES (11975, '2019-07-23 17:01:17.862593+00', '2019-07-23 17:10:57.130335+00', 19062, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c crossing down. 1c finish in 1plx NHJ facing down, 2c in 2pl facing up, 3c in 3pl centre facing P (1,2,3)

9--::

  1c A&R up/down ; advance | turn P LH to 2pl (2c dance up on [9-10]) _while{8}_ 3c turn RH ½ and face up NHJ | A&R up/down | turn P LH to 3pl (2,1,3)

17--::

  ½ diagonal R&L ; repeat (3x,1,2x)

25--::

  All set | 1c turn RH _while{4}_ 3c & 2c chase cclw ½ | all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11978, '2019-07-24 09:27:15.275814+00', '2019-07-24 09:32:01.914435+00', 18606, 1, 1645, 'ace', '1-::

  Grand chain

9-::

  1c & 3c in promhold cross passing LSh (3,2,1,4) ; &frac12; R&L (1,2,3,4)

17-::

  2c & 4c repeat

25-::

  2W+1c+4M & 2M+3c+4W "Crescent" Reels4 across, 1c & 3c pass P LSh to start

33-::

  1M+2c+3W & 1W+4c+3M repeat up/down, 2c & 4c pass P LSh to start

41-::

  All S&Link ; turn corner 1&frac12; BH

49-::

 Advance NHJ with corner | retire with neighbour (2M+4W, 3M+1W, 4M+2W, 1M+3W) ;

 all W petronella to centre & face out | all set

57-::

  Intersecting Reels4, &frac12; LHA in centre

65-::

  W continue LHA to face P _while_ M set (2,3,4,1) | turn P RH into promhold | promenade 1 place clw (1,2,3,4)

73-::

  Circle8 & back ending with W BtoB in centre facing P

', 2);
INSERT INTO 'dancecrib' VALUES (11980, '2019-07-27 10:02:08.925038+00', '2019-07-27 12:17:28.382323+00', 19479, 1, 1645, 'ace', '1-::
  1c+2c set | cast RSh back into chase &frac12; way clw | cross RH, 1c face out (2,1,3)
9-::
  RSh Reels3 on sides, 1c end taking LH with P & RH with 1cnrs
17-::
  Balance with 1cnrs | 1c turn 1&frac14; LH | balance with 2cnrs
25-::
  1M+2c & 1W+3c LSh Reels3 across | 1c cross to own side (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (12235, '2019-09-23 00:01:58.838435+00', '2020-01-19 22:31:09.870481+00', 14185, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; 1c+3c RHA (2,1,3)

9--::

  Reels3 on the sides, 1c starts in and up, give hands, at the end 2c face out

17--::

  2c+1c (cross up) DblFig8 (2,1,3) 

25--::

  Grand Chain, 2c cross to start (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (2058, '2012-01-22 19:29:17.51427+00', '2019-03-17 23:30:09.082191+00', 1549, 1, NULL, 'ace', '1–::

  All M advance to centre | set pivoting R to face out ; dance out and cast clw to next M place

9–::

  All W advance to centre | set pivoting L to face out ; dance out and cast cclw to next W place (all now face P across the set)

17–::

  The W on the sides (1W+3W) Turn RH 1¼ ; ½LHA with top/bottom pairs | cast 1 place cclw round the set _while_{2} these couples Turn LH ½ (all finish as they started)

25–::

  The M on the sides (1M+3M) Turn LH 1¼ ; ½RHA with top/bottom pairs | cast 1 place clw round the set _while_{2} these couples Turn RH ½ (all finish as they started)

33-64::

  repeat [1-32] from new positions (side couples leading in [49-64] as before).  Finish (3,4,1,2)

65–::

  1c+3c ½ R&L ; All change places RH with cnr | set to next person

73–::

  2c+4c (now facing P up/dn) repeat (finish 1,2,3,4)

81–::

  All Circle8 and back.', 2);
INSERT INTO 'dancecrib' VALUES (11982, '2019-07-27 10:47:36.165675+00', '2019-07-27 10:47:46.361357+00', 19488, 1, 1645, 'ace', '1-::

  1c long cast to 2pl (2c up on [3-4]) ; turn 1&frac12; RH to face 1cnrs on diagonal

9-::

  Set H&G, end facing 3cnrs

17-::

  1c+3cnrs turn RH ; 1c+4cnrs turn LH, 1c end facing out (2,1,3)

25-::

  RSh Reels3 on own sides

33-::

  2c+1c+3c Circle6 just over &frac12; way ; step in{1} turning to R, chase{3} clw to own side (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14715, '2022-03-30 02:17:24.037439+00', '2022-03-31 00:41:30.368005+00', 20744, 1, 202, 'ace', '1--::
  All turn P RH and face cnrs ; all turn cnrs LH to original places. All W face out
9-24::
  Schiehallion Reels to original places. All face P
25--::
  All set to P | turn P RH 1¼ into promhold facing cclw | all dance one place cclw and face P (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2009, '2012-01-22 19:29:14.789518+00', '2019-09-08 11:06:35.878262+00', 1424, 1, NULL, 'ace', '1–::

  1c lead down {3}, up {3}, cast off to 2pl (2c up)

9–::

  2c+1c ¾ R&L | 2c facing 1c set

17–::

  1c (start in) turn 2c EH 1½ on the sideline ; 1c+3c repeat (1c out)

25–::

  1c+4c repeat (1c in) ; all couples dance BtoB (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11689, '2019-03-18 00:47:28.133007+00', '2020-02-16 12:21:14.202085+00', 17320, 1, NULL, 'ace', '1--::   Circle6 and back, and face P    



9--::   All dance BtoB with P ; All turn P RH and face cnr



17--::   All dance BtoB with cnr ; all turn cnr LH, finish in promhold



25--::   All new couples promenade in hall and join 2 new couples.

', 3);
INSERT INTO 'dancecrib' VALUES (2880, '2012-01-22 19:30:01.334431+00', '2020-12-21 12:22:10.305809+00', 9672, 1, NULL, 'ace', '1–::

  1M+2W A&R ; change places RH | rest {2} _while{8}_ 1W+2M rest {2} | A&R | change places RH, into

9–::

  2c+1c RHA ; LHA

17–::

  1c ½ Fig8 up around 2c ; 2c ½ Fig8 down around 1c

25–::

  2c+1c circle4 L and back', 2);
INSERT INTO 'dancecrib' VALUES (13212, '2020-09-29 09:06:35.524089+00', '2020-09-29 09:07:22.064548+00', 17718, 1, 202, 'ace', '1--::

  Circle4 L ; RHA

9--::

  Circle4 R ; LHA

17--::

  Men dance BtoB ; Women repeat

25--::

  All cast out into promhold (1M+2W & 1W+2M) | Promenade anywhere to meet a new couple', 2);
INSERT INTO 'dancecrib' VALUES (11979, '2019-07-27 09:52:35.103686+00', '2019-07-27 09:52:45.896382+00', 19483, 1, 1645, 'ace', '*On 2nd chord 3c & 4c cross to opposite side (1,2,3x,4x)*

1-::

  1M+2c & 3M+4c &frac12; LSh Reels3 across, 1c & 3c take promhold for ; &frac12; Reels3 across

9-::

  1c & 4c dance inwards (2c & 3c to ends) | 1c+4c &frac12; RHA ; LHA, ending 1M+4W & 4M+1W in promhold facing 1cnrs (2M & 3M)

17-::

  1M+4W & 4M+1W pass & turn with 1cnrs & change to promhold with P facing 2cnrs ; repeat LSh with 2cnrs who turn LH, 1c/4c end between 2c/3c

25-::

  1c+2c & 4c+3c set across | 1c+4c change RH up/down ; Circle4 (2,4,1x,3x)

', 2);
INSERT INTO 'dancecrib' VALUES (11981, '2019-07-27 10:24:34.581898+00', '2019-07-27 10:26:40.274316+00', 19486, 1, 1645, 'ace', '*On 2nd chord 3c & 4c cross to opposite side (1,2,3x,4x)*
1-::
  1c+2c & 3c+4c set | RHA | 1c & 4c cast inwards, 2c & 3c lead to ends (2,1,4x,3x)
9-::
  1c+4c RHA, 1M+4W face up, 4M+1W face down for ; &frac12; LSh alternating tandem Reels3 on sides, corners add loops
17-::
  Repeat [9-16] with LHA then &frac12; RSh Reels3 (2,1,4x,3x)
25-::
  1c & 4c in promhold RSh Reels3 across with 2c & 3c, 1c/4c end on M/W sides
33-::
  1W+4W cross & retain RH _while_ 1M+4M set | 1c+4c &frac12; RHA ; turn P RH (2,4,1x,3x)
', 2);
INSERT INTO 'dancecrib' VALUES (12840, '2020-05-18 01:59:05.540481+00', '2020-05-18 13:07:50.387684+00', 11078, 1, 202, 'ace', '1--::

  1c+2c Circle4 L ; 1c & 2c turn P BH | 1c cast off _while_ 2c dance up (2,1,3)

9--::

  Diagonal R&L (3x,1,2x)

17--::

  All set advancing | cnrs retire _while{2}_ 1c Petronella Turn info facing Lines3 across ; repeat from new positions (3x,1x,2x)

25--::

  3C S&Link twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11983, '2019-07-27 11:28:42.482103+00', '2019-07-27 11:31:08.800882+00', 14603, 1, 1645, 'ace', '1-::
  1c+2c set | &frac12; RHA ; 1c+3c set | &frac12; RHA (2x,3x,1,4)
9-::
  S&Link figure for 4 couples (M cast outside, W petronella inside):  
  1-2: all set  
  3-4: 3W+2W & 1W+4W petronella in tandem _while_ 2M+3M & 4M+1M cast in tandem ending in lines across 4W+1W+1M+4M facing down to 2M+3M+3W+2W  
  5-8: repeat ending on sides (4x,1x,3,2)
17-::
  1c+4c RHA ; 1c & 4c turn P 1&frac12; RH, 3c step in
25-::
  4c+1c+3c Allemande (3,1,4,2)
', 2);
INSERT INTO 'dancecrib' VALUES (11985, '2019-07-27 12:15:55.309956+00', '2019-07-27 12:16:25.76881+00', 19493, 1, 1645, 'ace', '1-::
  1c long cast to 2pl (2c up on [3-4]) ; 1c set | dance in & cast RSh back to own sides (2,1,3)
9-::
  2M+1M & 1W+3W S&Link ; 1M+2M+3M & 2W+3W+1W S&Link to lines across
17-::
  1W+2M+3M & 2W+3W+1M S&Link ; 1W+3W & 2M+1M S&Link (3x,1x,2x)
25-::
  All set | 1c pass &frac34; LSh to 1W above 1M _while_ 3c & 2c pass RSh to own sides ; 1W+3W+3M & 1M+2M+2W LSh snake pass (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (15188, '2022-10-25 18:09:13.942352+00', '2022-10-25 18:12:47.58284+00', 21126, 1, 1645, 'ace', '*Five dancers in a square: 1,2,3,4 at the corners, 5 in the centre facing 1 & 2*

1--::

  1+5+2 set in a triangle | 5 sets turning to face 3 & 4 ; repeat with 3 & 4

9--::

  5+1+2 RHA ; 5+3+4 LHA, 5 faces 4 retaining LH with 3 & joins RH with 1

17--::

  *Spoke:* 5 BiL with 3+1 & faces 3 _while{2}_ 2 & 4 also set | repeat with 2+4, 1+3 & 4+2, 5 ends facing 1

25--::

  5+1 &frac12; turn RH | 1+2 &frac12; turn LH ; 2+3 &frac12; turn RH | 3+4 &frac12; turn LH & 4 ends facing 1 & 2 (5,1,2,3,4)

', 2);
INSERT INTO 'dancecrib' VALUES (13699, '2021-02-26 10:02:46.248017+00', '2021-02-26 10:09:25.390375+00', 2617, 1, 202, 'ace', '1--::

  1c set | cross down between 2c, behind 3c, meet and lead up to face 1cnrs (2c up on [5-6])

9--::

  1c+1cnrs set | Reel4 on 1diag. On [15-16] 1c pass RSh to face 2cnrs

17--::

  1c+2cnrs set | Reel4 on 2diag into facing lines3 across, 1M between 3c

25--::

  All set twice ; ½ Reels3 on sides into facing lines3 across. 1c have changed places

33--::

  All set twice ; ½ Reels3 on sides, 1c LSh to 4cnrs[pos] (2,1,3)

41--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1963, '2012-01-22 19:29:12.277386+00', '2019-03-18 15:39:02.298424+00', 1282, 1, NULL, 'ace', '1–::

  All C set, 1c+2c & 3c+4c circle4 left, 1c to 2c & 3c to 4c set on sidelines

9–::

  Rsh Reels4 on sidelines, except that (on bars 2,4,6,8) instead of each Lsh pass in the middle the two dancers on the inside of the set swap places Lsh into the other reel and continue to the R (M cross in 3pl, W in 2pl) (4x,3x,2x,1x)

17–::

  4c to 3c & 2c to 1c set on sidelines, turn BH ; all C half G-Chain (to 1,2,3,4)

25–::

  1c lead to 4pl (long way in) (others up) ; all C turn RH', 2);
INSERT INTO 'dancecrib' VALUES (11722, '2019-03-20 23:38:23.293438+00', '2019-07-27 16:20:59.960095+00', 5589, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; cross LH | cast off (3c up and face down) (2,3,1)

9--::

  Reels3 on the sides, to start 3c dance out and down and 1c cross up (2,3,1x)

17--::

  All set | 2c cross RH _while{2}_ 1c cast up _while{2}_ 3c cross down RH (2x,1x,3x) ;    

  All set | 2c cross down LH and face out _while{2}_ 1c cast up _while{2}_ 3c cross RH (1x,2,3)

25--::

  1c+2c ½ DblFig8 ; 2c dance up the side and cross RH _while{4}_ 1c turn RH into 2pl (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11685, '2019-03-16 15:14:15.022507+00', '2019-03-18 17:27:37.665518+00', 15244, 1, NULL, 'ace', '1--::

  1c cross RH and cast (2c up) ; turn LH ¾ to face 1cnr

9--::

  1c+1cnr set | change place RH and face ; ½ diag. Reel4, at end 1cnrs pass Rsh to face the 2cnr on their own side

17--::

  ½ diag. Reel4, at end 1cnrs face 3cnr pos (opposite own starting pos) (pass Lsh) ; 1cnrs+1c set and change place RH 

25--::

  1c turn LH ¾ ; All set and cross (3,1,2)   



#Variant: on [5-8] and [25-28] turn LH 1¾ *', 3);
INSERT INTO 'dancecrib' VALUES (12685, '2020-03-24 00:43:27.11314+00', '2020-03-24 00:56:27.189305+00', 19883, 1, 202, 'ace', '1--::
  3C Gr-Chain, 1c crossing (1,2,3)
9--::
  1c+2c turn RH on sides ; 1W (1M following) casts off one place, dances across to 2plx (2c up). 1W faces out (2,1x,3)
17--::
  Parallel ½ Reels3 on sides, 1c LSh to 3c (to 3,1x,2) ; 1W (1M following) casts up, dances across to 1pl (3c down). 1W faces out (1,3,2)
25--::
  Parallel ½ Reels3 on sides, 1c RSh to 3c (to 2,3,1) ; 1c+3c turn LH on sides (2,3,1)

*Note (as a 3/4L):*  
29-32::
  1c+3c turn LH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11990, '2019-07-30 15:59:52.938441+00', '2019-07-30 16:55:55.570218+00', 3677, 1, 202, 'ace', '1--::

  Reels3 on opposite sides, all crossing from top. 1c in 1pl centre face down NHJ (1x,2x,3x)

9--::

  1c set turning to face P BHJ | set turning to face up NHJ ; cast (2C up) | cross LH to face 4cnrs[pos]

17--::

  ½ Reel4 on 1diag, turn LH to face 3cnrs[pos] ; ½ Reel4 on 2 diag, turn LH to 2plx (3,1x,2)

25--::

  ½ Reels3 on sides, LSh to 2cnrs[pos] ; 1c chase clw ½ to 2pl _while{4}_ 2c & 3c turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11989, '2019-07-30 14:51:37.655028+00', '2019-07-30 16:06:46.652455+00', 14173, 1, NULL, 'ace', '1--::

  Reels4 on sides. On [8] middle couples give RH to pass (1,2,3,4)

9--::

  Circle8 and back (1,2,3,4)

17--::

  1c+3c set advancing and give RH to P, 1W+3M join LH | BiL ; 1c & 3c turn P RH ¾ | 1c cast to 3pl _while{2}_ 3c lead up to 1pl (3,2,1,4)

25--::

  3c+2c & 1c+4c (start facing in diagonally) Set&Rotate (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (11992, '2019-07-31 14:31:45.228842+00', '2019-08-01 14:19:16.256511+00', 5597, 1, 202, 'ace', '1--::
  1c Fig8 down round 2c (1,2)
9--::
  DblFig8, 1c crossing down (1,2)
17--::
  1c dance down ; and up (1,2)
25--::
  2C Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (13974, '2021-04-25 16:36:42.478901+00', '2021-04-25 16:38:44.721052+00', 17150, 1, 202, 'ace', '1--::

  1c set | turn P BH ½ opening to face down NHJ ; 1c dance down (2c up) | turn P BH (no extra turn) and face 1cnrs

9--::

  Set to and Turn Corners into lines3 across facing down, 1M between 2c, 1W between 3c

17--::

  All dance down ; dance up. On[24] 1M faces down

25--::

  Reels3 across {6}, 1c RSh to 3cnrs | 1c Petronella turn to 2pl (2,1,3)



*Deviser''s note* : At the end of bar 16, 1st man, pulling back his right shoulder, turns quickly and strongly to end facing down.', 2);
INSERT INTO 'dancecrib' VALUES (11991, '2019-07-31 13:51:07.973738+00', '2019-07-31 14:44:47.812613+00', 1065, 1, 202, 'ace', '1--::
  1c cross RH ; cast (2c up) ; cross LH | dance LSh round 4cnrs into facing lines3 across
9--::
  All set twice, on [11-12] 1c Petronella Turn to 2plx ; all set twice (2,1x,3)
17--::
  Gr-Chain, 2c crossing RH to start (2,1x,3)
25--::
  Mirror Reels3 {6} on sides, 1c down between 3c | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11993, '2019-07-31 15:07:24.357199+00', '2019-07-31 15:19:00.489629+00', 3999, 1, 202, 'ace', '1--::

  ½ R&L ; RHA (2x,1x)

9--::

  2c & 1c cross LH | change places RH on sides ; LHA (1,2)

17--::

  All Highland Schottische step to P ; turn P RH  (1,2)

25--::

  2C Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11987, '2019-07-27 14:57:33.881099+00', '2019-08-13 10:10:26.563736+00', 19498, 1, 1645, 'ace', '1-::
  1c set | cast off (2c up) ; set | cast off (3c up)
9-::
  1c cross | cast up (3c down) ; cross | cast up (2c down) to original places
17-::
  1c+2c change LH | 1c cross RH ; 1c+3c change LH (2,3,1x) | 3c dance down to 3pl as 1c lead up & take LH with 1cnrs
25-::
  Balance with 1cnrs | 1c turn &frac34; RH & take LH with 2cnrs ; balance with 2cnrs | 1c turn ending BtoB facing own side
33-::
  Double triangles (2,1,3)
', 4);
INSERT INTO 'dancecrib' VALUES (14939, '2022-07-04 16:57:33.473807+00', '2022-07-04 22:33:47.196748+00', 6903, 1, 202, 'ace', '1--::

  1M casts off | turns 3W RH ½ ; crosses to Mside ; casts up to original place (1,2,3)

9--::

  1W casts off | turns 3M LH ½ ; crosses to Wside ; casts up to original place (1,2,3)

17--::

  Circle6 and back (1,2,3)

25--::

  1c Fig8 on sides, 1c in and down (1,2,3)

33--::

  1c+2c RHA ; LHA (1,2,3)

41--::

  1c+2c ½ R&L (to 2x,1x,3) ; 1c & 2c cross RH | 1c+2c set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11994, '2019-07-31 16:01:41.789425+00', '2019-08-02 13:26:33.413154+00', 16900, 2, 29817, 'ace', '1-8::

  1s cross RH & cast LHT 1½ to finish in centre facing own side, 2s step up on bars 3-4

9-16::

  1W with 2W & 3W and 1M with 2M & 3M RHA. 1s LHT 1½ to finish 1W behind 1M facing out 2nd place woman’s side.

17-24::

  In tandem 1s cast to R dance up between 3s, dance out through 2nd place man’s side, cast R to finish in centre in promenade hold facing down. (1W on 1M’s right) WHILE 2s & 3s dance Rs & Ls to finish with NHJ 2s facing down & 3s facing up.

25-32::

  2s & 3s make arches for 6 bars, 1s down through arch, divide & cast up to meet in promenade hold, dance up through arch, crossing & casting to 2nd place own sides. 2s cast to 1st place, 3s to own place

', 3);
INSERT INTO 'dancecrib' VALUES (13123, '2020-09-07 11:36:53.59487+00', '2020-09-07 11:48:00.099813+00', 12839, 1, 1645, 'ace', '1-::
  1c cross RH | cast off (2c up) ; circle4 to L (2,1x)
9-::
  1c+2c RHA ; as W turn to start LHA, M dance on passing P RSh & turn in to join the LHA, M end facing out (M side: 1M,1W; W side: 2W,2M)
17-::
  L-Chain, end facing in diagonally
25-::
  All set | W set _while_ M change places RH (2,1x) ; 2c turn BH _while_ 1c turn 1&frac12; BH (2,1)
', 2);
INSERT INTO 'dancecrib' VALUES (2874, '2012-01-22 19:30:01.067824+00', '2020-12-29 11:49:04.514815+00', 9757, 1, NULL, 'ace', '1–::

  1c+3c DblFig8 around 2c,1c crossing down to begin.

9–::

  1c lead down the middle and up to finish in 1pl NHJ facing 2c who dance in on [16] to 2pl facing up NHJ

17–::

  1c+2c dance ''The Surge'' (see below)

25–::

  2c+1c+3c circle6 and back.



{{explanation}}

The Surge (a new progression):  

To start, 1c+2c face each other NHJ as for the Rondel.



1-2::

  1c+2c NHJ advance {1}, retire {1}

3-4::

  1c dance down to 2pl _while_ 2c separate and dance up to 1pl, both C ending BHJ in the middle for

5-6::

  2c+1c turn BH

7-8::

  Pulling Rsh back, all cast out to their own sidelines (similar to ''Argyll Strathspey'', bars 7-8) to order 2,1.

', 2);
INSERT INTO 'dancecrib' VALUES (3823, '2013-07-13 15:56:15.630982+00', '2020-10-01 17:11:50.204083+00', 14665, 1, NULL, 'ace', '1–::

  1c cross and cast (2c up) ; cross between 3c and cast up to face 1cnr

9–::

  1c+1cnrs ½ Reel4 _while_ 2cnrs set twice ; ½ Reels3 on the sides, 1c Lsh to 2cnr

17–::

  1c+1cnrs (=2cnr persons) ½ Reel4 _while_ 2cnrs set twice ; ½ Reels3 on the sides, 1c Lsh to 2cnr (pos.)

25–::

  1c turn LH and dance out the end (M up, W down) _while_ 2c+3c cross RH and set ; 1c cast L _while_ 2c+3c change places on the side | All set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11995, '2019-07-31 16:14:28.150797+00', '2019-07-31 21:43:51.089156+00', 16901, 2, 29817, 'ace', '1–8::

  1s RHT and cast, 1s RHT 1¼ to face 2nd corners

9–16::

  1s ½ Diag RSh reel of 4 with 2nd corners, pass R to face 3rd corners, ½ Diag RSh reel of 4 with 3rd corners finish with 1M facing down between 3s, 1W facing up between 2s.

17–24::

  1s change places by dancing to Left out between 2s & 3s & finish 1M facing up between 2s, 1W facing down between 3s

	1s LHT 1¼ to face 2nd corner positions

25–32::

  1s ½ Diag LSh reel of 4 with 2nd corner positions, pass L to face 1st  corner positions, ½ Diag LSh reel of 4 with 1st  corner positions, 2M & 3W finish by curving to Rt to face ACW. 1s pass LSh to 2nd place own sides facing ACW.

33–40::

  All chase ACW for 4 bars, 1s LHT 1½ as 2s & 3s chase to place, finish 2,1,3.



', 3);
INSERT INTO 'dancecrib' VALUES (13700, '2021-02-26 12:12:37.876269+00', '2021-02-26 12:23:21.887658+00', 2997, 1, 202, 'ace', '1--::
  1c turn RH and face down | lead down between 3c ; cast up (2c up) | and face 1cnrs
9--::
  Set H&G. On [15-16] 1c dance BtoB to centre, 1M facing up _while{2}_ 2c & 3c make arches with PdB. 2c face down, 3c face up (2,1,3)
17--::
  1c dance RSh round 2cnrs under end arches, pass P RSh ; RSh round 4cnrs under end arches to 2pl _while{8}_ 2c & 3c set | cross RH (skip ch.) ; make arches and set | cross RH (skip ch.) (2,1,3)
25--::
  3C Promenade (2,1,3)

*Deviser''s note:  
The second time through, 1st couple swing wide to allow the 4th couple to progress into third place.*', 2);
INSERT INTO 'dancecrib' VALUES (13579, '2021-01-24 15:40:48.816276+00', '2021-01-24 15:46:31.140284+00', 12153, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; dance down between 3c | cast up to 2pl (2,1,3)

9--::

  1c set advancing | pivot R BtoB in centre facing own sides _while{4}_ 2c & 3c chase clw ½ and face clw ; 1c EHJ with cnrs, all dance clw ½ with PdB (1c) and Skip-ch (cnrs)

17--::

 Turn CPCP (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12517, '2020-01-19 14:33:52.708007+00', '2020-01-20 00:02:00.077798+00', 10678, 1, 202, 'ace', '1--::

  1c cross RH | cast off ; 1c ½ Fig8 up round 2c. 2c step up on [7-8] (2,1,3)

9--::

  Reels3 on sides, 1c RSh to 4cnrs (2,1,3)

17--::

  1c ½Fig8 R, LSh round 1cnrs ; repeat, LSh round 3cnrs to 2pl (2,1,3)

25--::

  2c+1c R&L (2,1,3)  

   



*Deviser''s note: Advanced version*  



17--::

  ½ Reels3 across, 1c LSh to 1cnrs ; ½ Reels3 across, 1c LSh to 3cnrs[pos]  (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (13825, '2021-03-19 00:27:37.384202+00', '2021-03-19 13:07:58.026504+00', 15775, 1, 202, 'ace', '1--::
  1c lead down {3}, lead up {3} | cast off (2c up on [7-8], pass LSh and face 1cnrs
9--::
  ½ Reel4 on 1diag, pass LSh ; ½ Reel4 on 2diag (3x,1x,2x)
17--::
  All dance BtoB ; set | cross RH (3,1,2)
25--::
  3C Set&Rotate (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (7921, '2013-08-21 08:31:51.312012+00', '2023-02-04 01:23:12.013122+00', 9904, 3, NULL, 'ace', '1-8::
    1M dances "Solo R&L": 1M changes places RH with partner, LH with 2L,
    RH with 2M & partner LH
9-16::
    1s+2s dance Ladies'' Chain
17-24::
    1L dances 1/2 "Solo R&L": 1L changes places RH with 2M & LH with 2L,
    1s+2s turn RH ending in centre
25-32::
    1s+2s dance Poussette.  2 1

{{explanation}}
Note: can be danced 8x32 in 4 Couple sets', 0);
INSERT INTO 'dancecrib' VALUES (9694, '2017-03-31 11:45:45.929918+00', '2021-03-19 10:42:17.644761+00', 8488, 1, 202, 'ace', '1--::

 1c followed by 2c lead down ; 2c followed by 1c lead up to 1pl _while_ 1c finish facing 1cnrs

9--::

 1c turn CPCP to finish facing 1cnrs

17--::

 1c SetH&G to finish BtoB facing 2cnrs

25--::

 1c Reels{6} on sides, Rsh to 2cnr |1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13826, '2021-03-19 13:29:25.95086+00', '2021-03-19 16:39:06.217289+00', 20281, 1, 202, 'ace', '1--::
  1c (+2c+3c who dance up to follow) lead down ; 3c (+2c+1c following) lead up. 3c cast off to 3pl centre facing up. 2c cast off to 2pl on sides. 1c in 1pl centre turn inwards and face down (1,2,3)
9--::
  1c+3c R&L up/down to sides (1,2,3)
17--::
  1c+2c set | RHA | 1c cast off to 3pl _while_ 2c lead up to 1pl (3c up) (2,3,1)
25--::
  All A&R ; turn P RH (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (11997, '2019-08-01 06:10:30.124543+00', '2019-08-01 06:18:55.516072+00', 16902, 1, 202, 'ace', '1--::

  1c long cast (2c cross up to 1plx) ; turn BH opening to face up | cast to 3pl into promhold _while{2}_ 3c cross up to 2plx and face out (2x,3x,1)

9--::

  1c+3c ½ Reel3 across, 1c RSh to 3M ; 1c+2c ½ Reel3 across, 1c LSh to 2W. On [16] 1c in centre turn P LH and face opposite sides, LSh to P (2,1,3)

17--::

  2c+1W & 1M+3C RHA. 1c LHJ face opposite sides ; 1c turn P LH ¾ | cast to 3pl (3c up) (2,3,1)

25--::

  ½ Circle4 L {3}, dance in on L foot into centre and all swivel R {1} ; spiral out to chase clw ½ (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (11998, '2019-08-01 11:30:48.954139+00', '2019-08-01 11:30:58.638416+00', 4065, 1, 1645, 'ace', '1-::

  1c cross down into Fig8 round 2c

9-::

  1c cast off into Fig8 on own sides through 2pl & around 3c taking NH where possible & end facing out in 1pl  

  _while_ 2c cross up into Fig8 round 1c position

17-::

  1c cast off into Fig8 round 2c position & end in 1pl facing down NHJ  

  _while_ 2c quickly cast off into Fig8 on own sides through 3pl & around 4c taking NH where possible & end facing out in 2pl  

  _while_ 3c cross up into Fig8 round 2c position

25-::

  1c set twice advancing NHJ just below 2pl ; set separating | cast off to 4pl  

  _while_ 2c cast up | cross down to 2plx ; cast up | cross RH to 1pl  

  _while_ 3c+4c &frac12; DblFig8, 3c casting & 4c crossing up to start ; set NHJ | cross up RH (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (13219, '2020-10-05 16:55:02.340678+00', '2020-10-05 18:32:17.441553+00', 20092, 1, 202, 'ace', '1--::
  1c set | cast off (2c up) ; ½ Fig8 up round 2c (2,1x,3)
9--::
  Mirror Reels3 on sides, 1c in and down, 3c out and up (2,1x,3)
17--::
  1c Petronella turn | set ; repeat [17-20] to 2pl (2,1,3)
25--::
  1c Fig8 down round 3c', 5);
INSERT INTO 'dancecrib' VALUES (11996, '2019-07-31 16:27:20.611534+00', '2019-08-01 06:18:55.464474+00', 16902, 2, 29817, 'ace', '1–8::

  1s dancing in towards each other cast to 2nd place. 2s cross up on bars 3-4.  1s turn BH, face up & cast to 3rd place. 3s cross up and face out on bars 7-8

9–16::

  In promenade hold 1s dance ½ RSh reel of 3 with 3s then ½ LSh reel of 3 with 2s to finish in centre lhj 1W facing M side, 1M facing W side.

17–24::

  1W with 2s, 1M with 3s RHA, 1s ¾LHT and cast to 3rd place

25–32::

  6 hands round to the left, all dance in on bar 28, pull back Rsh and spiral out to finish 2,3,1.

', 3);
INSERT INTO 'dancecrib' VALUES (9683, '2017-03-27 12:45:28.809039+00', '2020-09-07 14:06:07.204432+00', 32, 2, 3069, 'ace', '1-2:: All set and face 1st & 3rd C down, 2nd & 4th C up

3-4:: 1C with 2C and 3C with 4C change place R hand

5-8:: All set, cross R hand with partners to face diagonally in 1C with 2C, 3C with 4C

9-12:: All set and dance Petronella turn 1 place to right.

13-16:: repeat 9-12 to original place

17-18:: 1st M with 2nd W while 3rd M with 4th W change place R hand

19-22:: 1st M, 2nd M, 3rd W and 4th W dance L hand wheel, while 3rd with 4th M and 1st with 2nd W turn L hand once round

23-24:: repeat bars 17-18 to original place

25-32:: 1st W followed by 2,3,4 W dance down middle & up the sidelines to place while 4th M followed by 3,2,1 M dance up the middle & down the sidelines to place

33-34:: 1st W with 2nd M while 3rd W with 4th M change place L hand

35-38:: 1st W, 2nd W, 3rd M and 4th M dance R hands across, while 3rd with 4th W & 1st with 2nd M turn R hand

39-40:: repeat bars 33-34 to original place

41-44:: 4th C followed by 3,2 & 1C lead down 2 steps and up 2 step

45-48:: 1st C cast off into 4th Place, while 2,3 & 4 C dance up to new places', 0);
INSERT INTO 'dancecrib' VALUES (11999, '2019-08-02 12:24:15.925759+00', '2019-08-02 12:24:26.618268+00', 4112, 1, 1645, 'ace', '1-8::

  1c dance down NHJ ; 1c dance up making arch for 2c who dance down NHJ

9-12::

  1c set | cast off _while_ 2c dance up NHJ & face out (2,1)

13-16::

  1c cross up | cast off _while_ 2c cast off | cross & lead up to face down NHJ (2x,1x)

17-20::

  2c dance down under 1c arch | 1c dance down under 2c arch

21-24::

  1c cast up | cross down to face up NHJ _while_ 2c cross down | cast up (2,1)

25-28::

  1c dance up crossing under 2c arch | 1c cast off _while{2}_ 2c lead up (2,1x)

29-32::

  1c &frac12; Fig8 up round 2c (2,1)

::

  *On [5-8] when all are dancing 1c may have to let more than one 2c under their arches.*

', 2);
INSERT INTO 'dancecrib' VALUES (3255, '2012-01-22 19:30:17.766575+00', '2020-09-07 22:31:20.849352+00', 9012, 1, NULL, 'ace', '1–::

  1c lead down (2c up) ; turn in on [5] and lead up to 2pl in the centre

9–::

  1c in promhold +2W+3M ½ Rsh Reel3 ; 1c+2M+3W ½ Rsh Reel3, 2M loops at the end

17–::

  1c (promhold) +2c (in 3plx) ½Reel3 across, Lsh to 2M ; 1c+3c (in 1plx) ½Reel3 across, Lsh to 3W, 1c finish on midline facing P, M above W

25–::

  1c set to P | petronella to sideline ; 3c+1c+2c turn RH into

33–::

  3c+1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (1939, '2012-01-22 19:29:10.872526+00', '2020-09-08 08:41:32.941448+00', 9203, 1, NULL, 'ace', '1–::

  1W+2M cross RH and cast R to P''s place _while_{4} 1M+2W set facing, dance 1 pl along sideline and pull Rsh back ; 1c+2c RHA

9–::

  1W+2M cross LH | cast L to original place _while_{4} 1M+2W set facing, dance 1 pl along sideline and pull Lsh back) ; 1c+2c LHA

17–::

  All Lsh reels3 on own sides

25–::

  1c+2c turn LH 1½ on side ; 1c+3c RHA', 2);
INSERT INTO 'dancecrib' VALUES (3839, '2013-07-13 15:56:20.124222+00', '2020-10-01 18:16:18.898184+00', 14671, 1, NULL, 'ace', '1–::

  1c+2c »Tourbillon« (2,1,3)

9–::

  1c »Gypsy« (dance ¾ Rsh round P and face P up/dn | 1c set ; Gypsy to 2plx | cross RH

17–::

  2c+3c repeat (2,1,3)

25–::

  1c+3c »Tourbillon« (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2491, '2012-01-22 19:29:44.767413+00', '2020-12-21 16:28:57.796003+00', 9803, 1, NULL, 'ace', '1–::

  Mirror Reels3 on sidelines, 1c crossing to opposite sides

9–::

  Mirror Reels3 on sidelines, 1c crossing to own sides

17–::

  1c Petronella Turn to centre line (M faces up, W down) | 2c repeats ; 3c repeats, _while{2}_ 1c+2c set | 1c+2c+3c set, turning BH ¼clw on the second setting step into position for

25–::

  1c+2c+3c 3-couple Poussette, (1c moves down 2 places, 2c+3c move up one) (to 2, 3, 1)', 2);
INSERT INTO 'dancecrib' VALUES (2689, '2012-01-22 19:29:53.202365+00', '2020-12-29 11:47:35.481921+00', 9515, 1, NULL, 'ace', '1–::

  1c set adv | set ret. ; 1M+2W Turn RH ¾ _while_ 1W casts off and 2M casts up (2,1,3)

9–::

  1c set | cross RH ; 1M+3c RHA _while_ 2c turn RH _while_ 1W dances Rsh loop round 2c to (2,1,3)

17–::

  1c set | cross LH ; 2c+1M LHA _while_ 3c turn LH _while_ 1W dances Lsh loop round 3c to (2,1,3)

25–::

  1W followed by 1M+2W NHJ followed by 2M dance down | 2c followed by 1c dance up (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9638, '2017-03-04 22:21:28.954454+00', '2021-03-19 10:55:28.751664+00', 8476, 1, 202, 'ace', '1--::

 1c set | cast off (2c up) ; lead down between 3c and cast up to 2pl (2,1,3)

9--::

 1c dance BtoB with 1cnrs ; dance BtoB with 2cnrs (2,1,3)

17--::

 1c turn 1cnrs RH to between cnrs ; 1c turn 2cnrs LH to 2pl (corners dance for 4 bars!)

25--:: 

 2c+1c+3c set, 1c finishing facing to R | Rsh Reels3 {6} (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2980, '2012-01-22 19:30:05.468246+00', '2021-04-25 18:27:12.112451+00', 5147, 1, NULL, 'ace', '1–::

  1c in promhold (W on the R) dance behind 2M, cross, cast behind 3W to midline facing up

9–::

  1c dance up NHJ to 1pl facing out | 1c+2c turn EH on sidelines 1½ | [2 bars missing in the original text ??] (2,1,3)

17–::

  Mirror Reels3 in the sides 1c start in and down

25–::

  1c cross RH, cast R round 1cnr, cross LH up/down, cast L round 3cnr, to (2,1,3)

33–::

  2c+1c R&L



{{explanation}}

Note ETF: For [9-16] the original (1980) description (dance up and turn) only fills 6 bars, unless the turns are made excessively slowly', 3);
INSERT INTO 'dancecrib' VALUES (2586, '2012-01-22 19:29:48.706016+00', '2020-12-21 16:38:03.835282+00', 9829, 1, NULL, 'ace', '1–::

  All set | turn P RH {4} | set to face up/down for

9–::

  Mirror Reels4 on own side, 1c in and down (Rsh on M side. Lsh on W side), Finish 1c+3c facing in, 2c+4c out

17–::

  All turn ½ EH on sides (M RH, W LH) | 1W+4W & 1M+4M turn ½ EH (to 2,4,1,3, 4c facing out, 1c in) ; 4c+1c »Linked double ½Fig8« (4c dance outside set round 3c and cross up into 3plx _while{4}_ 1c cross up between 2c and cast into 2plx (to 2,1x,4x,3)

25–::

  1M+4M turn RH _while{4}_ 1W+4W turn LH, 1c finish facing out, 4c in ; 1c+4c »Linked double ½Fig8« (to 2,4,1,3)

33–::

  All circle8 L and back.

', 2);
INSERT INTO 'dancecrib' VALUES (3645, '2012-08-28 13:12:56.967119+00', '2020-10-01 20:57:06.871436+00', 14537, 1, NULL, 'ace', '1–::

  All set to P with Glasgow Highlanders step (right foot), pull back Rsh | Set to cnr (GH, left foot), pull back Lsh and M face out ; All M dance cclw half round

9–::

  Repeat [1-4] and W face out ; All W dance clw half round  (3,4,1,2)

17–::

  All turn P RH ; All M cross diag to R and cast R round that W to next M''s place

25–::

  All turn new P RH ; All W cast behind the M and cross diag to R to beside own P and face out (4,1,2,3)

33–::

  Half Schiehallion Reel (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (13703, '2021-02-26 20:16:29.692647+00', '2021-04-05 11:37:39.558675+00', 12411, 2, 963, 'ace', '1-8::  

  1s cross RH, cast one place (2s up); RHA with 3s, 1s finish btob facing 1st crn  

9-16::

  1s 1/2 hello/goodbye to finish btob facing 2nd crn; 1s 1/2 R4 with 2nd crns to finish passing Lsh to btob facing 4th crn position

17-24::  

  1s 1/2 hello/goodbye to finish btob facing 1st crn; 1s 1/2 R4 with 1st crns, 1s finish by veering right to finish in 2nd place opp side facing cw  3x,1x,2x

25-32::  

  3s,1s,2s chase cw 1/2 way to own side; all turn RH  2,1,3

  ', 2);
INSERT INTO 'dancecrib' VALUES (8239, '2014-04-08 11:16:25.574247+00', '2023-02-04 01:23:09.747981+00', 10048, 3, NULL, 'ace', '1-8::
    1s dance in, cast to 2nd place (2s step up), 1s dance in, cast to
    meet below 3s
9-16::
    1s lead up (LH)  to end BtoB (Lady facing up & Man down) & dance
    Crown Triangles & end facing 1st corners
17-24::
    1s dance round 1st corners passing RSh, Corners Adv+Ret touch hands
    briefly; 1s repeat with 2nd corners, 1s pass RSh to end in 2nd place
    own side
25-32::
    2s+1s+3s circle 6H round & back', 4);
INSERT INTO 'dancecrib' VALUES (12000, '2019-08-02 20:48:48.775038+00', '2019-08-02 21:05:13.639837+00', 7197, 1, 1645, 'ace', '*The first 32 bars are a fugue with 1st, 4th, 2nd and 3rd couples successively dancing all or part of a 24 bar sequence:*
*figure of 8 on the sides; turn, cross down/up, cast, cross; set, cross, set, cross.*
1-::
  1c Fig8 on sides starting in and down
9-::
  1c turn RH | lead down and cross ; cast up | cross down (2c up)  
  _while_ 4c Fig8 on own sides starting in and up (2,1,3,4)
17-::
  1c set | cross RH ; set | cross RH  
  _while_ 4c turn LH | lead up and cross ; cast off | cross up (3c down)  
  _while_ 2c Fig8 on own sides starting in and down (2,1,4,3)
25-::
  4c set | cross RH ; set | cross RH and face out  
  _while_ 2c turn RH | lead down and cross ; cast up | cross RH  
  _while_ 3c Fig8 on own sides starting in and up (2,1,4,3)
33-::
  1c+4c+3c &frac12; mirror Reels3, 4c start out and down (2,3,4,1) ;  
  2c+3c+4c &frac12; mirror Reels3, 3c start in and up (4,3,2,1)
41-::
  1c & 3c set | cross RH ; set | 1c turn RH & face up RHJ _while{2}_ 3c cross RH & face out  
  _while_ 2c & 4c stand | set advancing ; 2c & 4c turn RH | stand
49-::
  3c+4c change pl, M RH, W LH _while{2}_ 2c set | 2c+4c change pl, M LH, W RH _while{2}_ 3c set ;  
  2c+3c change pl, M RH, W LH _while{2}_ 4c set | 2c+3c+4c set  
  _while_ 1c cross above 2c (3pl), cast off, cross up, cast off, cross up towards 3c & 4c
57-::
  2c+3c+4c mirror Reels3 on sides, 3c start up and out  
  _while_ 1c dance out above 4c, cast to top, cross down 1pl, cast to 4pl & cross RH (2,3,4,1)
', 2);
INSERT INTO 'dancecrib' VALUES (13701, '2021-02-26 14:22:36.475824+00', '2021-02-28 20:31:00.363426+00', 4738, 2, 3069, 'ace', '1-4::
  1st C set, cast off 1 place, 2nd C step up 3-4. 
5-8::
  1st C cross down between 3rd C and cast up to 2nd place on opposite sides. 
9-12::
  1st W with 2nd C & 1st M with 3rd C dance RH acr.
13-16::
  1st W with 3rd C & 1st M with 2nd C LH acr to 2nd place on opposite sides.
17-22::
  1st, 2nd & 3rd C Set, Cross RH, Set
23-24::
  1st, 2nd & 3rd C turn RH finish in Promenade hold, W on P right, as follows:  
	2nd C, in 1st place, face down & slightly to their left.  
	1st C, in 2nd place, face down & slightly to their right.  
	3rd C, in 3rd place, face up & slightly to their right
25-32::
  2nd, 1st & 3rd C dance L-sh Promenade Reels of 3, 1C cross LH to place on 32.  
Repeat having passed a couple.', 3);
INSERT INTO 'dancecrib' VALUES (2272, '2012-01-22 19:29:29.006302+00', '2021-03-27 19:06:54.743419+00', 9535, 1, NULL, 'ace', '{{explanation}}

3c+4c begin the dance on opposite side (1,2,3x,4x)



1–::

  All C cross RH, set ; repeat to place.

9–::

  1c+4c 1½ RH turn ; cast to the middle (2c+3c step to the ends) | ½ LHA staying in the middle

17–::

  1c+4c change places RH with "corner" (1M with 3W, etc) putting cnrs BtB in the centre | all set, facing diagonally ; change back RH | 1c+4c ½ LHA

25–::

  Repeat [17-22] with "opposite corner" (1M with 2W, etc), at end 1c faces 4c on sideline | 1c+4c change places LH. (to 2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (13827, '2021-03-19 18:09:52.392372+00', '2021-03-20 19:08:09.605127+00', 7484, 1, 202, 'ace', '1--::
  1c (+2c+3c who dance up to follow) lead down ; 1c (2c+3c following) lead up to places. 2c face down, 3c face up (1,2,3)
9--::
  Gr-Chain (1,2,3)
17--::
  1c lead down and face P | set advancing passing LSh and face 1cnrs (2c up) ; ½ Reel4 on 1diag, pass P LSh and face 2cnrs
25--::
  ½ Reel4 on 2diag (to 3x,1x,2x) ; 1c turn P BH 1½ _while{4}_  3c+2c change place LH on sides | cross RH (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (12010, '2019-08-08 06:55:48.199938+00', '2019-08-08 07:04:22.726072+00', 19516, 1, 202, 'ace', '1--::

  1c dance down | set facing down ; cast up round 4c to 1pl (1,2,3,4)

9--::

  All set | dance across, RSh to P, W under M''s arches ; chase clw ½ (4,3,2,1)

17--::

  4c+3c+2c Set&Rotate _while{8}_ 1c turn P RH ; LH (2,3,4,1)

25--::

  1c slip up | and back ; all birl', 2);
INSERT INTO 'dancecrib' VALUES (14078, '2021-06-19 21:21:37.149111+00', '2021-06-19 21:21:46.207611+00', 1561, 1, 1645, 'ace', '1-::

  1c set | cast off (2c up) ; 2c+1c+3c set | 1c &frac12; turn BH & end BtoB facing opp sides _while{2}_ 2c & 3c petronella, 2M & 3W to 2pl own side, 2W & 3M to centre line facing clw

9-::

  Weasel Reel across: RSh Reel4 in 2pl, on reaching ends

  pass RSh, chase &frac12; way clw (M/W through 3pl/1pl) & rejoin reel, finish in starting place

17-::

  1c &frac12; turn RH _while{2}_ 2c & 3c chase 1pl clw (2,1,3,4) | all set ; 1c cast off below 3pl | 3c dance up & face out _while_ 4c cast up & face in _while_ 1c dance down to 4pl & face out

25-::

  3c+4c+1c mirror Reels3 on sides (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (10367, '2017-12-29 08:43:37.071297+00', '2020-10-02 09:36:36.419505+00', 14904, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c 1/2 R&L (with polite turn) ; 2c & 1c & 4c & 3c turn P BH 1 ½ (2,1,4,3,5)

9--::

  All A&R{1+1} | 2c & 4c & 5c turn RH ending in middle RHJ _while{2}_ 1c & 3c turn LH ¾ ; 1M+2c & 1W+4c+3M & 3W+5c RHA

17--::

  1M+2c & 1W+4c+3M & 3W+5c Circle3 or Circle4 L, on [20] all dance towards centre and pull Rsh back ; 2c & 4c & 5c cast R round P to opposite sides _while{2}_ 1c & 3c set passing Lsh and pull Rsh back to face P | 1c & 3c turn P RH ¾ and face out (2x,1x,4x,3x,5x)

25--::

  1c & 3c cast (4c & 5c up) | all set ; all turn P RH ½, face P | cast R to exchanged places (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (3443, '2012-01-22 19:30:25.744774+00', '2020-12-21 16:41:47.606574+00', 9833, 1, NULL, 'ace', '1–::

  1W+2W turn LH ½ _while{2}_ 1M+2M turn RH ½ into DTr position | All set ; 1c cast below 3c and cross up into DTr position facing opposite sides.

9–::

  2c+1c+3c set | 1c dance out and cast R ; and in through end Cs, swiveling R about into DTr position (1W facing up, 1M down) | All set.

17–::

  Continue DTr (1c turning R about into DTr, 1M facing up, 1W facing down | all set ; 1c dance out the ends and cast R (2,1x,3)

25–::

  Opposing Reels3{6} on sides, Lsh to 1cnr | cross RH to 2pl.

', 3);
INSERT INTO 'dancecrib' VALUES (12006, '2019-08-03 22:21:38.499996+00', '2019-09-26 17:23:34.284649+00', 12996, 1, 1645, 'ace', '1-::

  1c set | turn RH to face down ; lead below 3c | cast up (2c up) to (2,1,3)

9-::

  All dance &laquo;Dolphin&raquo; Fig8: M set _while_ W advance to P & pull RSh back | W followed by P return to W side & all pull LSh back ;

  M followed by P return to M side & M pull RSh back to face P | all turn RH & face up

17-::

  2c+1c+3c progressive promenade (1,2,3)

25-::

  1c+2c &frac12; R&L ; turn P 1&frac12; BH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12012, '2019-08-09 12:35:46.660775+00', '2019-08-09 12:39:44.979667+00', 12703, 1, 202, 'ace', '1--::

  1c+2c Set&Link ; 1c ½ Fig8 up round 2c (2,1x,3)

9--::

  1c+3c Set&Link ; 1c ½ Fig8 up round 3c (2,3,1)

17--::

  1c dance up to top (3c down on [17-18]) ; cast off to 2pl | turn RH and face up in centre (2,1,3)

25--::

  1c+2c Circle4 L, 1c turn inwards and face down ; 1c+3c Circle 4 R to sides (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13706, '2021-02-26 23:11:12.37284+00', '2021-02-26 23:14:59.253791+00', 16632, 1, 202, 'ace', '1--::

  1c cross RH ; cast off (2c up) ; ½ Fig8 up round 2c and face 1cnrs

9--::

  ½ Reel4 on 1diag, pass P RSh ; ½ Reel4 on 2diag (3x,1x,2x)

17--::

  All turn P RH ; chase clw ½ (2,1,3)

25--::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (3170, '2012-01-22 19:30:14.27336+00', '2022-07-05 10:36:26.131024+00', 9561, 1, NULL, 'ace', '1–::

  1W+2W & 3M+4M cross Lsh past P | cast two L (M and W swap places) ; all M (top) and W (bottom) LHA

9–::

  1M+2M & 3W+4W cross Rsh to person opposite | cast two R ; 3c+4c (top) & 1c+2c (bottom) RHA (to 3x,4x,1x,2x)

17–::

  ½Reels4 on the sides ; 2c waits in 1plx _while{4}_ the others continue in ½Reel3 (to 2x,3x,4x,1x)

25–::

  All Set, cross RH, 2c+3c & 4c+1c circle4 left', 3);
INSERT INTO 'dancecrib' VALUES (12004, '2019-08-02 23:24:15.858612+00', '2019-08-02 23:39:42.892433+00', 1781, 1, 1645, 'ace', '1-4::

  1c clap & cross RSh | cast off (2c up)

5-8::

  1c cross below 3c | cast off (3c+4c up) & face up NHJ (2,3,4,1)

9-12::

  1c advance up | retire down  

  _while_ 2c clap & cross RSh | cast off (3c up)

13-16::

  1c set | &frac12; turn BH moving up to 3pl & face down NHJ  

  _while_ 2c cross below 4c (in 3pl) | cast off & face up NHJ (3,4,1x,2)

17-20::

  1c retire up | advance down & face P  

  _while_ 2c advance up | retire down & face P

21-24::

  1c+2c &frac12; R&L, end facing up/down on sidelines (3,4,2x,1)

25-28::

  2c+1c set facing up/down | 1c dance up _as_ 2c cast off  

  _while_ 3c clap & cross RSh | cast off (4c up) to (4,3x,1,2x)

29-32::

  1c dance out round 3c | dance up NHJ inside 4c & face out in 1pl  

  _while_ 2c dance in & up NHJ | set advancing NHJ up to 2pl centre  

  _while_ 3c cross below 1c (3pl) | cast off & face up NHJ  

  _while_ 4c clap & cross RSh | cast off (1,4,2,3)

33-36::

  1c cast off to 2pl | set  

  _while_ 2c dance up & loop into 1plx | set NHJ with 1c  

  _while_ 3c set | &frac12; turn BH moving up to 3pl & face down NHJ  

  _while_ 4c cross below 3pl | cast off & face up NHJ (2x,1,3x,4)

37-40::

  3c retire up | advance down & face P  

  _while_ 4c advance up | retire down & face P

41-44::

  2c+1c & 3c+4c &frac12; R&L (1x,2,4x,3)

45-48::

  1c clap & cross RSh | cast off to 4pl  

  _while_ 4c clap & cross RSh | stand  

  _while_ 3c set | dance up NHJ to 2pl (2c up) ending (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (12003, '2019-08-02 21:10:24.87393+00', '2019-08-02 21:15:59.245559+00', 3398, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; turn P RH 1½ (2,1x)

9--::

  2c repeat [1-8] (1x,2x)

17--::

  1M+2W cross RH | 1W+2M turn RH ½ retaining hands ; 2c+1c RHA (2,1)

25--::

  R&L (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (12005, '2019-08-03 22:16:28.430045+00', '2019-08-03 22:20:07.931468+00', 2493, 1, 1645, 'ace', '{{explanation}}

Strathspey



1-::

  1M+2W &frac12; turn RH | 1c+2W &frac12; Circle3 L (W: 2,1) ; 1c &frac12; turn LH | 1c+2M  &frac12; Circle3 R (2,1)

9-::

  1c & 2c set adv | &frac12; &laquo;RSh&LSh&raquo;: pass P RSh & other M/W LSh on side (1x,2x) ; repeat (2,1)



{{explanation}}

Reel



17-::

  2c+1c DblFig8, 1c cross up to start

25-::

  Repeat [9-16]

', 2);
INSERT INTO 'dancecrib' VALUES (7891, '2013-08-21 08:31:50.614015+00', '2023-02-04 01:23:09.835819+00', 7037, 3, NULL, 'ace', '1-8::
    1s & 2s dance DoSiDo & turn partners RH 1.1/2 times
9-16::
    1s & 2s dance DoSiDo & dance 1/2 R&L
17-24::
    2s+1s+3s set twice & turn partners RH
25-32::
    1s dance down below 3s, cast up behind 3s, dance up between 2s &
    cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (12007, '2019-08-04 10:49:28.362419+00', '2019-08-04 10:58:30.300923+00', 19513, 2, NULL, 'ace', '1-8::

  1s dance Mirror reels on own side, 1st man giving right shoulder to 2nd man, 1st lady giving left shoulder to 2nd lady. 

9-12::

  1s cross RH and cast off one place, 2nd couple move up on bars 11-12 

13-16::

  1s dance half figure of 8 round 2s 

17-18::

  1s and 2s cross RH. 

19-20::

  1st man and 2nd lady cross, RH while 1st lady and 2nd man set 

21-22::

  1s and 2s cross RH 

23-24::

  1st man and 1st lady cross LH, while 2s set 

25-32::

  1s and 2s dance the Tournée 



*SCDDB Editor''s note: the transition on [24-25] is impossible, there must be a misprint.*', 1);
INSERT INTO 'dancecrib' VALUES (12008, '2019-08-04 16:13:49.754067+00', '2019-08-04 16:14:00.269797+00', 3265, 1, 1645, 'ace', '1-::

  1c cross RH | cast off (2c up) ; set advancing | turn LH (2,1x,3)

9-::

  All cross RH | 1c chase &frac12; way cclw _while{4}_ 2c & 3c change LH on sides & set advancing | all turn P LH, 1c face out (3x,1x,2x)

17-::

  1c cast LSh round 2cnr | set advancing & touch RH facing opposite side ; cast up | dance down NHJ (3x,1x,2x)

25-::

  &laquo;&frac12; reel3 at &frac12; speed&raquo;

  3c set _while_ 1c+2c change places, 1c outside | 3c+2c change places, 2c outside _while_ 1c set ;

  2c set _while_ 1c+3c change places, 3c outside | all set (2x,1x,3x)

33-36::

  All &frac12; turn BH | fall back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2484, '2012-01-22 19:29:43.86311+00', '2020-09-09 09:40:49.216999+00', 9637, 1, NULL, 'ace', '1–::

  1c+2c+3c set | cross RH ; set | 1c cast one _while_ 2c cross up _while_ 3c cross and face up (2,1x,3)

9–::

  2c+1W & 1M+3c DblFigs8: 2c & 3c dance as a full DblFig8, casting to start, _while{8}_ 1W & 1M dance the figure singly, crossing to start (W up, M dn).  1c finish facing 1cnr

17–::

  1c set to and turn 1cnrs ; repeat with 2cnrs, finish (2,1x,3)

25–::

  Teapots R (2c+1M & 1W+3c RHA) ; 1c Turn BH 1½ to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12001, '2019-08-02 21:02:38.188786+00', '2020-11-26 10:37:04.881371+00', 19511, 2, NULL, 'ace', '1-8::

  1C Dance a fig of 8 down round 2C.

9-16::

  1C lead dn the middle & back, finish facing up.

17-24::

  1C cast to the bottom (2+3+4C step up on 19&20) All 4Cs turn RH.

25-32::

  Bottom 3Cs ONLY 6hands round & back.



', 5);
INSERT INTO 'dancecrib' VALUES (13377, '2020-11-24 03:23:54.388435+00', '2020-11-24 03:30:59.434522+00', 4160, 1, 202, 'ace', '1--::

  1c+2c RHA{3}, LHA{3} | 1c cast to 2pl, 2c dance to top (2,1,3)

9--::

  1c+3c DblFig8, 1c crossing down, all EH joined when crossing. On [16] 1c pass P LSh to face 1cnrs

17--::

  SetH&G (2,1,3)

25--::

  3C Gr-Chain (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12002, '2019-08-02 21:09:26.826021+00', '2020-11-26 10:39:54.048611+00', 19512, 2, NULL, 'ace', '1-8::

  1C lead down the middle & back, finish facing up.

9-16::

  1C cast to the bottom, (2+3+4Cs step up), all 4Cs turn RH.

17-24::

  8 hands round & back.

25-32::

  Bottom 2Cs RH’s across & LH’s back.

', 5);
INSERT INTO 'dancecrib' VALUES (12009, '2019-08-06 09:11:15.405892+00', '2021-01-01 20:16:44.582058+00', 19514, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c Set&Rotate (2,1,4,3)

9--::

  Reels4 on sides (2,1,4,3)

17--::

  1c+4c+3c chase clw ½ ; cross RH | 2c+3c+4c+1c set (2,3,4,1)

25--::

  Circle8 and back (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13582, '2021-01-25 07:53:51.805873+00', '2021-01-25 07:58:59.021906+00', 12205, 1, 202, 'ace', '1-4::

  1c & 3c cross RH | 1c+2c & 3c+4c change places LH on sides, all M facing out (2,1x,4,3x,5)

5-12::

  2c+1c & 4c+3c L-Chain (2,1x,4,3x,5)

13-16::

  1c ½ Fig8 down round 4c _while_ 3c ½ Fig8 down round 5c. 1c & 3c face 1cnrs

17--::

  Set to And Turn Corners (2,1x,4,3x,5)

25--::

  All set | 1c & 3c turn P RH 1½ | cast off (4c & 5c up) (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (13704, '2021-02-26 22:35:50.535543+00', '2021-02-26 22:43:11.936447+00', 4738, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; lead down between 3c | cross and cast to 2plx (2,1x,3)

9--::

  2c+1M & 1W+3c RHA ; 2c+1W & 1M+3c LHA (2,1x,3)

17--::

  All set | cross RH ; set | turn P RH into promhold, each W on P''s right. 2c & 1c face down, 3c face up, 2c slightly left, 1c & 3c slightly right

25--::

  Reel3 on midline, 1c LSh to 3c (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13378, '2020-11-26 21:31:46.888346+00', '2021-11-11 19:04:21.641717+00', 20149, 2, 963, 'ace', '1-8::

  1M&2W change places RH and set WHILE 1W&2M set and change places RH; 1W leads a chase cw 1/2 way back to orig place

9-16::

  1s&2s RHA;  2c dance in, up and cast into 1st place WHILE 1W leading 1M casts to 2nd place, crossing to 2,1x,3

17-24::

  1M&3M change places LH and set WHILE 1W&3W set and change places LH; 1W leads a chase ccw 1/2 way back to 2,1x,3

25-32::

  1s&3s LHA; 3c dance in, up and cast into 2nd place WHILE 1W leading 1M casts to 3rd place, crossing to 2,3,1', 5);
INSERT INTO 'dancecrib' VALUES (13708, '2021-02-27 12:22:31.939073+00', '2021-03-09 23:22:54.397588+00', 20230, 1, 202, 'ace', '1--:: 

  1c Fig8 down round 2c (1,2,3)

9--::

  1c BHJ slip down (2c up) ; slip up to 2pl (2,1,3)

17--::

  2c+1c LHA ; 1c+3c RHA (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15183, '2022-10-24 17:02:02.847555+00', '2022-10-25 18:31:23.68842+00', 21121, 1, 1645, 'ace', '*3c & 4c start on opposite sides (1,2,3x,4x)*

1--::

  2c+3c RHA _while{4}_ 1M & 4M, followed by P, chase &frac12; way cclw ; 4c+2c & 3c+1c S&Link (2,4,1x,3x)

9--::

  2c+4c & 1c+3c Circle4 to L ; all set on sides | 4c & 1c dance LSh round P ending in tandem, M leading, facing 2M/3M

17--::

  4c & 1c alternating tandem LSh Reels3 across with 2c/3c, ending on sides facing up/down (2,4,1x,3x)

25--::

  RSh Reels4 on sides, at the end 1c+4c &frac12; turn RH instead of passing LSh (2,4,1x,3x)

', 2);
INSERT INTO 'dancecrib' VALUES (2731, '2012-01-22 19:29:55.02987+00', '2019-08-11 10:22:04.658669+00', 4075, 1, NULL, 'ace', '*4c+5c+6c cross on 2nd chord (1,2,3,4x,5x,6x). The dance is symmetrical from both ends.*



1–::

  All clap as all W dance Rsh round P to centre facing P ; All c set | All W cast away R to places

9–::

  All clap as all M repeat (again Rsh)

17–::

  1c and 6c dance NHJ towards the middle | 1c+6c ½ RHA, finish NHJ facing other end, W on the R ; lead to exchanged places and cast 2 places towards middle (2c+3c+4c+5c step towards end of set) (2,3,6,1x,4x,5x)

25--::

  All Circle12 and back



*The original (1990) version had*



25–::

  6c+1c turn RH, turn LH.', 3);
INSERT INTO 'dancecrib' VALUES (2972, '2012-01-22 19:30:05.133808+00', '2019-08-12 08:20:50.62427+00', 12530, 1, NULL, 'ace', '{{explanation}}

Couple face couple RR



1–::

  1c to 2c A&R ; RHA

9–::

  1c+2c A&R to P ; LHA

17–::

  L-Chain,

25–::

  All dance parallel interlocking Reels3{6}, start Rsh round facing person ; Lsh round person behind | pass Rsh to meet new couple', 2);
INSERT INTO 'dancecrib' VALUES (11857, '2019-05-23 13:41:57.138157+00', '2020-11-25 10:05:44.691286+00', 19328, 2, 26003, 'ace', '1-8:: 1st and 3rd couples lead down for two, 3/4 turn and set facing, lady pulling right shoulder back to face up, man behind lady dance up on 7 & 8 (2nd and 4th Couples step up on 1 & 2)

9-16:: 1st couple dance tandem reel across with 2nd couple, 3rd couple with 4th couple finish in the centre facing up, men behind ladies

17-24:: 1st and 3rd couples dance up and cast on own sides. 1st lady with 2nd couple, 1st man with 4th couple and 3rd lady with 4th couple and 3rd man with 5th couple dance right across once round.

25-28:: 1st couple dance half figure of eight between 4th couple, 3rd couple between 5th couple.

29-32:: 1st and 3rd couples cross and cast one place. 4th and 5th couples step up on last 2 bars.



Finish 24153 ready to repeat from new places

', 2);
INSERT INTO 'dancecrib' VALUES (11923, '2019-06-28 21:58:10.868032+00', '2020-10-02 19:56:05.68174+00', 19429, 1, 1645, 'ace', '*On 2nd chord, 3c & 4c cross to opposite sides (1,2,3x,4x)*

1-::

  1c & 4c cross RH | cast inwards (2c & 3c out) ; 1c+4c LHA (2,1x,3x,4)

9-::

  2c+1c & 4c+3c RHA, 1c & 4c end facing down/up on sides ;

  1c & 4c pass LSh, loop LSh round cnr on same side, pass LSh to face 2c/3c on sides

  _while{4}_ 2c & 3c set adv on diagonal | retire (2,1x,3x,4)

17-::

  2c+1c & 4c+3c turn 1&frac12; BH on sides and open out | 1c+2c & 3c+4c circle4 to L, end facing down/up NHJ with P (1x,2,3x,4)

25-::

  *Through the mirror rondels:* 1c+2c & 3c+4c each start rondels with 2c & 3c making arches on [1]. On [2-3] 2c & 3c continue as normal but 1c+4c &frac12; circle4 to L to join other rondel for [4-8] with M making arches on [4] and 2c & 3c again making arches on [7] to finish as (2,4,1x,3x).

', 5);
INSERT INTO 'dancecrib' VALUES (13216, '2020-10-02 22:59:57.131488+00', '2020-10-02 23:00:06.740332+00', 20031, 1, 1645, 'ace', '1-::

  1c cross down RH (2c up) | &frac12; turn 3c EH ; 3c+1c set facing on sides | 1c slip step to own sides, 1M below 1W (2,3,1,4)

9-::

  3c+1c Circle4 to L ; 3c break circle & with 3M leading slip step up to line of 4 across 1pl with 1c in centre _while{4}_ 2c & 4c birl moving down/up to 2pl/3pl centre

17-::

  2c+4c Poussette _while{8}_ 1c dance down between them to 4plx as 3c stand{4} in 1plx ; 3c & 1c set adv{1}, take BH & join last 3 bars of Poussette (3,4,2,1)

25-::

  Circle8 & back (3,4,2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (13707, '2021-02-27 09:37:40.309335+00', '2021-02-27 09:42:42.252657+00', 16629, 1, 202, 'ace', '1--::

  1c+2c set | 6 bars of DblFig8, 1c casting (2,1x,3)

9--::

  1c+3c S&Link ; Circle4 L (2,3,1x)

17--::

  3c+1c »The Swirl« [: 3c & 1c turn P RH into allemande hold 3c facing down, 1c facing up | turn around each other to change places ; releasing RH, LHA. On [24] 1c face 1cnrs _while_ 3c dance to 3pl] (2,1x,3)

25--::

  1c+1cnrs set | 1c dance RSh round P to face 2cnrs ; 1c+2c repeat [25-28] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11843, '2019-05-11 16:01:06.014752+00', '2022-11-15 22:17:16.182768+00', 19310, 1, 1645, 'ace', '1--::
  2c+3c mirror S&Link, 3c casting up (1,3,2) ; 1c+3c mirror S&Link, 3c casting up, 1c end facing out (3,1,2)
9--::
  1c cast R round 3cnr to face P down/up on 2cnr diagonal _while{4}_ 3c+2c adv&ret diagonally briefly taking hands in a circle ;
  1c pull RSh back & cast R round 2cnr to 2plx _while{4}_ 3c+2c repeat [9-12] to (3,1x,2) & 3c face 2c on sides
17--::
  LSh "push-me pull-you" Reels3 on sides: 1c dance track of LSh Reels3, ending on centre line RSh to P, 1M below 1W
  _while{8}_ cnrs dance BtoB on sides passing LSh ; repeat passing RSh
25--::
  3c+1W & 1M+2c LHA, 1c pass LSh to face down/up on centre line ; 1c set | turn &frac34; BH to (3,1,2)
', 5);
INSERT INTO 'dancecrib' VALUES (13581, '2021-01-25 02:40:35.789033+00', '2021-01-25 02:48:23.290756+00', 12187, 1, 202, 'ace', '1--::

  1W+2M set | cross RH _while{4}_ 3c Petronella turn | set ; 1c+2c ½ R&L up/down _while{4}_ 3c passing LSh dance RSh round 3M->4W & 3W->4M into line4 across, 3c BtoB between 4c

9--::

  1M+2W set | cross RH ; 1c+2c RHA _while{8}_ 3c+4c Reel4 across to sides (1,2,4,3)

17--::

  1c dance down to 4pl _while{4}_ 3c cast up to 1pl (to 3,2,4,1) ; 3c+2c set | ½ RHA _while{4}_ 4c+1c RHA (2x,3x,4,1)

25--::

  2c+3c set | cross RH ; turn P RH _while{8}_ 4c+1c LHA ; turn P LH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12022, '2019-08-16 20:05:16.020271+00', '2020-03-09 11:02:58.765229+00', 432, 1, 202, 'ace', '1--::

  All circle8 and back, end in a square set

9--::

  All dance double R&L, all starting RH with P (1,2,3,4)

17--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; ½ Fig8 round end couples (2,1,4,3)

25--::

  4C Gr-Chain (2,1,4,3)

33--::

  1c+4c Rondel (2,4,1,3)

41--::

  Reels4 (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13215, '2020-10-01 23:01:20.516285+00', '2022-03-07 18:13:10.907167+00', 19717, 1, 1645, 'ace', '*3c & 4c cross to opposite sides (1,2,3x,4x)*

1-::

  1M & 4M A&R to P ; 1M & 4M cross & dance RSh round P _while{4}_ 1W & 4W set | set turning to end in tandem behind P

9-::

  1c & 4c, M leading, pass RSh & curve to face up/down in centre |

  1M+4W & 4M+1W set RHJ, turning into allemande hold facing out on M/W sides ;

  cast up/off to ends of centre line & M turn W under R arm to face up/down with W BtoB

  _while{8}_ 2c & 3c cast up/off to ends, dance in & down, out through original pl & cast back to ends

17-::

  1M+4W+1W+4M &frac12; Reel4 in centre, on [20] W turn &frac34; LH as M dance &frac12; clw to face P ;

  &frac12; Reel4 across ending on sides (2,1,4x,3x)

25-::

  1c+4c *&laquo;Eddy&raquo;:* 1W+4W turn RH _while{3}_ 1M & 4M chase clw &frac12; way round them,

  1M+4W turn RH _while{3}_ 1W & 4W chase clw &frac12; way to sides (2,4x,1,3x) | 4c & 1c cross RH (2,4,1x,3x)

', 2);
INSERT INTO 'dancecrib' VALUES (14760, '2022-04-15 22:29:22.72567+00', '2022-04-23 21:32:55.233432+00', 17121, 1, 1645, 'ace', '1--::
  1c set | cast off (2c up) ; turn 1&frac14; LH to face 1cnrs
9--::
  *3C Chain Progression on 1diag:*  
  _9-10:_ 1c+1cnrs change pl RH _while{2}_ 2cnrs chase 1pl clw  
  _11-14:_ 1cnrs turn 1&frac12; LH in centre _while{4}_ 1M+2W & 1W+2M in promhold chase &frac12; way clw  
  _15-16:_ 1c+1cnrs change pl RH, 1c end facing 4cnrs _while{2}_ 2c chase 1pl clw
17--::
  1c set H&G, end facing 2cnrs
25--::
  Repeat 3C Chain Progression on 2diag, 1c end facing 1cnr[pos]
33--::
  1c+1cnrs &frac12; diag RSh Reel4, 1c pass RSh ; 1c+2cnrs &frac12; diag RSh Reel4, 1c pass RSh (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (15189, '2022-10-26 08:14:42.145387+00', '2022-10-26 08:26:05.572921+00', 4185, 1, 202, 'ace', '1--::
  Circle8 and back (1,2,3,4)
9--::
  All W RHA to places ; turn P RH
17--::
  All M LHA to places ; turn P LH 1¼ into promhold facing clw
25--::
  All promenade clw (1,2,3,4)
33--::
  1c & 3c in promhold pass opposite couple RSh and pivot R ¼. 1c dance out RSh round 4c to 1pl _while_ 3c dance out RSh round 2c to 3pl
41--::
  2c & 4c repeat same pattern [33-40]
49--::
  1c+3c A&R ; 2c+4c A&R
57--::
  All RHA, W in centre, NHJ with P on their L. On [64] all W BtoB in centre face P (1,2,3,4)', 2);
INSERT INTO 'dancecrib' VALUES (14925, '2022-06-27 13:01:04.673235+00', '2022-07-05 13:18:01.582952+00', 13933, 1, 202, 'ace', '1--::
  1M+3W advance diagonally to centre | set pulling RSh back to face P ; change places RH with P. Retaining RH, 1W gives LH to 2M & 3M gives LH to 2W | all BiL
9--::
  Parallel Reels3 on diag, 1M & 3W passing P RSh. 1M & 3W face out
17--::
  1M & 3W (P following) chase clw ½ to exchanged places (to 3,2,1) ; all turn P RH into allemande hold
25--::
  *Modified 3C Allemande* : On [31-32] 1c in 1pl cast off _while_ 2c in 2pl dance up to top (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12019, '2019-08-15 00:31:27.110939+00', '2019-08-16 06:52:35.05525+00', 19547, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; 1W+3W & 2M+1M S&Link. 3W & 2M face out (W: 2,3,1, M: 1,2,3)

9--::

  ½ Reel3 on sides, 3W LSh to 2W, 2M LSh to 3M (to W: 1,3,2, M: 3,2,1) ; 1c set to P _while{2}_ 3M+2M & 3W+2W turn BH | Circle6 L into facing lines3 across, 1M between 2c in 1plx facing down, 1W between 3c in 3plx facing up

17--::

  All set | change places RH ; 1c dance RSh round 4cnrs[pos] to 2pl _while{2}_ 3c & 2c cross RH (to 3,1,2) | all set

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10701, '2018-04-28 09:45:52.790615+00', '2019-08-16 06:54:11.077856+00', 18097, 2, 10819, 'ace', '1–2:: 1s advance one step, joining RH, lead down & turn in to face up _while_ 2s dance up on sidelines for one step, advance for one step, joining RH.

3-6:: 1s+2s dance RH across, pull RS back to finish all back to back in the middle.

7-8:: 1s+2s dance out to sidelines, facing in

9–16:: 1s repeat bars 1-8 with 3s, 1s face out at the end

17–20:: All dance 4 bars of "Muirland Willie": 3s lead down middle & cross over to cast up to 2nd _while_ 2s set & cross RH to 3rd pl _while_ 1s cast up to 1st place & cross RH

21-24:: 1s dance 1/2 Fig of 8 around 2s

25-28:: 1L+2L change places LH, then 1L+3M change places RH

29-32:: 1M+2M change places RH, then 1M+3L change places LH ', 5);
INSERT INTO 'dancecrib' VALUES (12020, '2019-08-15 23:57:08.548174+00', '2019-08-16 00:02:41.259511+00', 2582, 1, 202, 'ace', '1--::

  1c set | cast off to 3pl (2c+3c up) ; cross RH | cast up (3c down) to 2plx centre LHJ facing 3cnrs

9--::

  1c set to 3cnrs, turn inwards RHJ | set to 1cnrs ; ½ Reel4 on 1diag to 2plx centre LHJ facing 4cnrs

17--::

  1c set to 4cnrs, turn inwards RHJ | set to 2cnrs ; ½ Reel4 on 2diag. Turn P LH and face opposite sides LHJ

25--::

  3c+1W & 1M+2c RHA. 1c end as on [24] ; 3c+2c chase clw ½ _while{4}_ 1c LHJ set | turn P LH ¾ to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12021, '2019-08-16 19:38:30.397488+00', '2019-08-16 19:46:03.670133+00', 2701, 1, 202, 'ace', '1--::

  1c cast (2c up) | ½ Reels3 across, 1c LSh to 1cnrs | 1c turn P LH and face 1cnrs[pos]

9--::

  Reel4 on 1diag into facing lines3 across, 1M between 2c face down, 1W between 3c face up

17--::

  All set | ½ Reel3 on sides, 1c LSh to 4cnrs[pos] | 1c turn P LH and face 4cnrs[pos]

25--::

  Reel4 on 2diag. 1c face 3cnrs[pos]

33--::

  Set to and Turn Corners (3x,1,2x)

41--::

  All A&R ; 1c turn P RH 1½ _while{4}_ 3c+2c ½ R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1843, '2012-01-22 19:29:05.427223+00', '2020-05-18 22:55:01.125835+00', 11260, 1, NULL, 'ace', '1–::

  Circle4 and back

9–::

  Cclw facing cpl lead through other cpl and cast back ; Turn P RH

17–::

  Clw facing cpl repeat

25–::

  All Progress, passing 4 couples in same direction. making 4 alternating arches: the clw facing cpls  Make arch | Dance under arch ; Make arch | Dance under arch, to meet a new C', 2);
INSERT INTO 'dancecrib' VALUES (12027, '2019-08-19 14:43:51.61377+00', '2020-11-13 20:50:24.794832+00', 3896, 1, 202, 'ace', '1--::
  1M+2M & 3M+4M turn RH ½ _while{2}_ 1W+2W & 3W+4W turn LH ½ | all NHJ balance ; all NHJ A&R (2,1,4,3,5)
9--::
  1c & 3c dance LSh round 4cnrs to midline, pass P RSh into Dbl Crown Triangles ; 4 bars of Crown Triangles (2,1x,4,3x,5)
17--::
  Reels4 on 1diag. 1c & 3c face 1cnrs
25--::
  SetH&G. On [31-32] 1c set to P
33--::
  Reel4 on midline
41--::
  1c & 3c turn P RH ¾ facing own sides into Dbl Crown Triangles ; 4 bars of Crown Triangles
49--::
  Reels4 on 2diag, 1c(3c) ending in 2plx(4plx) facing out (2,1x,4,3x,5)
57--::
  1c & 3c cast off (4c & 5c up) | cross RH ; cast up | lead down to 3pl/5pl (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (12024, '2019-08-18 10:37:03.225044+00', '2019-08-18 10:51:59.14283+00', 4841, 1, NULL, 'ace', '1-::

  All M advance to centre | W advance as M retire ; W Circle3 L ⅔ as M slip R ⅔ | All set, W pivoting L to face P

9-::

  Reel6: Pass P Rsh | Outers (W) chase 1 place clw as Inners (M) dance 2/3 cclw (as LHA with no hands) ; repeat (M as outers, W as inners) 

17-32::

  Repeat [9-16] twice, to where reel started (W inside, facing P)

33-::

  All turn P RH ½ | All slip L {1}, W join RH in middle and LH with P,  All set L{1} ; R{1} , All Slip L{1} | Turn P RH 1¼ (2,3,1)



', 3);
INSERT INTO 'dancecrib' VALUES (13124, '2020-09-08 09:25:31.449402+00', '2020-09-11 20:01:05.259461+00', 704, 2, 2784, 'ace', '_The Border Reiver’s Bride	4/4Sq • 32R,32Sx4,32R_



{{explanation}}

Reel



1-::

  Circle8 to finish with W BtoB in middle facing P

9-::

  All set (Highland step) ; turn P RH 1.1/2 to finish with M in middle facing P

17-::

  All set (Highland step) ; turn P LH 1.1/2 to finish with W in middle, M facing cclw

25-::

  W 1/2 RHA _while{4}_ M dance 1/2 way round set to meet P ; M dance in to give LH _while{1}_ W dance out round P to face clw NHJ (or arm round P waist) 1/2 LHA back to pl {3} to finish with 1c facing cclw



{{explanation}}

Strathspey



1-::

  1c+2M in ‘Triumph’ hold dance cclw inside set {6} then 2M+1W return to place _while{2}_ 1M+3M dance into middle BtoB facing P

9-::

  1c+3c Reel4 finishing in original places

17-::

  1c+3c promhold cross, W passing RSh and curve to face in ; repeat back to pl

25-::

  All set (Highland Schottische) to cnrs and turn RH to finish with 2c facing cclw

33-64::

  Repeat bars 1-32 with 2c leading and finishing with 3c facing cclw

65-96::

  Repeat bars 1-32 with 3c leading and finishing with 4c facing cclw

97-128::

  Repeat bars 1-32 with 4c leading and finishing back in pl



{{explanation}}

Reel



1-32::

  Repeat the reel-time figure finishing back in pl



*For demonstrations it is suggested that the strathspey figure is only danced once, with 1c leading*', 2);
INSERT INTO 'dancecrib' VALUES (1735, '2012-01-22 19:28:59.054914+00', '2021-01-25 15:22:31.993762+00', 11373, 1, NULL, 'ace', '1–::

  1W+2M turn RH ¾ to give LH to P | BiL ; 1W(2M) each followed by P dance up(down) casting L and down(up) opposite side, crossing to (2,1,3)

9–::

  2c+1c+3c Rsh Reels3 on own side, 1c start down.

17–::

  1c+3c repeat [1-8] to (2,3,1)

25–::

  1c ¾ Fig8 on own side give Lsh to 3c and Rsh to 2c (3c down) to (2,1,3) | 2c+1c+3c set', 3);
INSERT INTO 'dancecrib' VALUES (12289, '2019-10-16 03:29:17.077875+00', '2020-11-27 18:41:42.523481+00', 19699, 1, 202, 'ace', '1--::

  Mirror Reels3 {6} on sides, 1c in and down, all joining hands when possible | 1C dance down to 2pl centre into promhold (1W on L) _while{2}_ 2c continue the reel to 1pl (1,2,3,4)

9--::

  3W (1c following) dances down between 4c and cast up to 2Wplace ; 3M (1c following through 3Wplace) casts off LSh round 4M and dance up the middle. 3c NHJ in 2pl centre face down _as_ 1c NHJ in 3plx centre face up

17--::

  3c & 1c set | Circle4 L | set, 1c turning inwards to face down (2,3,1,4)

25--::

  3c+1c+4c Mirror Reels {6} on sides, 1c in and down, all joining hands when possible | 1c cross down to 4pl _as_ 4c continue the reel to 3pl (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (14761, '2022-04-17 08:11:11.035497+00', '2022-04-17 08:17:22.412488+00', 12633, 1, 202, 'ace', '1--::

  1c turn RH | cast off (2c up) ; dance down | cast up round 3c to 2pl (2,1,3)

9--::

  ½ Reel4 on 1diag. 1c pass RSh ; ½ Reel4 on 2diag to 2plx (3x,1x,2x)

17--::

  1c Petronella turn _while{2}_ 3c+2c change places RH into facing lines3 across | all set ; 1c Petronella turn to 2pl _while{2}_ 2c & 3c cross RH | all set (2,1,3)

25--::

  1c dance up to top | cast to 2pl ; 1c+3c ½ Poussette (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10988, '2018-08-15 01:32:19.108553+00', '2022-04-26 09:21:16.269441+00', 17321, 1, 202, 'ace', '1--::

  1c+2c Bourrel, 1M+2W turning BH with PdB on [3-4], all turning RH on [7-8], 1c face out (2,1,3)

9--::

  ½ Reels3 on sidelines, 1c Rsh to 3cnrs ; 1c turn 4cnrs[pos] EH (3,1,2)

17--::

  ½ Reels3 on sidelines, 1c Rsh to 3cnrs[pos] ; 1c turn 4cnrs EH (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (13975, '2021-04-25 22:17:18.492748+00', '2021-04-25 22:20:29.624373+00', 16628, 1, 202, 'ace', '*3c & 4c start on opposite sides*
1--::
  1c+2c & 3c+4c Circle4 L ; 1c & 4c turn P RH ½, face P | cast R to exchanged places _while{4}_ 2c+3c set | dance in to meet P, out to between nearest ends and pivot to finish BtoB 2c facing own sides, 3c facing opposite sides
9--::
  Reels4 across. On [15-16] 2c & 3c turn P LH ½ and face out the end
17--::
  2c & 3c lead out the end, cross and cast inwards (to 1x,2x,3,4) ; 2c+3c ½ R&L (1x,3x,2,4)
25--::
  1c+3c & 2c+4c set diagonally | Petronella turn 1 place cclw ; repeat [25-28] (3,1,4x,2x)', 2);
INSERT INTO 'dancecrib' VALUES (12484, '2020-01-06 22:50:17.89097+00', '2020-11-28 10:49:11.637296+00', 19816, 2, NULL, 'ace', '1-8::

   Women thread the needle

9-16::

   Men thread the needle

17-24::

  All join hands circle left and back.

25-32::

  Bottom couple gallop up to the top, the top couple up their hands of the waists of the bottom couple, all gallop down to the bottom with the top couple now taking the bottom place', 2);
INSERT INTO 'dancecrib' VALUES (12023, '2019-08-17 01:08:05.89746+00', '2020-03-09 10:57:38.264747+00', 3400, 1, 202, 'ace', '1--::

  1M+2W & 2M+3W cross RH | all set ; 2W+1c & 2M+3c ½ Reels3 across, 1W RSh to 2W & 3M RSh to 2M (1,2,3)

9--::

  1W+2M & 2W+3M cross RH | all set ; 2M+1c & 2W+3c ½ Reels3 across, 1M LSh to 2M & 3W LSh to 2W (1,2,3)

17--::

  1c set | cast (2c up) ; 1c lead down | cast round 3c to 2pl (2,1,3)

25--::

  2c+1c RHA ; LHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3522, '2012-01-22 19:30:29.139886+00', '2020-05-19 00:47:48.321336+00', 7087, 1, NULL, 'ace', '1–::

  1M+2M+3M advance | retire ; set [in 6 PdB] _while{6}_ 1W+2W+3W set | advance ; retire [again 6 PdB] | 1c+2c+3c cross RH (1x,2x,3x)

9–::

  1c+2c+3c set | La Baratte starting with RH,  finish (1,2,3) with 1c on the midline facing down

17–::

  1c lead down, cross between 3c, cast up, lead up and cross between 2c, and cast off (2c up) to (2,1,3)

25–::

  2c+1c R&L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13217, '2020-10-03 19:44:31.560504+00', '2020-10-03 19:50:16.385939+00', 18807, 1, 202, 'ace', '1--::

  1c+2c ½R&L (to 2x,1x,3) ; 1c+3c ½R&L (2x,3x,1)

9--::

  2c+3c ½R&L (to 3,2,1) ; 2c+1c ½R&L (3,1x,2x)

17--::

  3c+1c RHA ; set | cross LH (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13705, '2021-02-26 22:59:29.765155+00', '2021-02-26 23:04:54.921485+00', 16627, 1, 202, 'ace', '1--::
  1c+2c Circle4 L finishing in centre ready for ; ½ Poussette (2,1,3)
9--::
  All set | cross RH ; set | turn P RH into promhold facing up (2,1,3)
17--::
  3C Allemande (3,1,2)
25--::
  1c+2c turn RH on Wside, LH on Mside 1½ (to 3,2,1) ; 3c+2c turn EH on sides 1½ (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (13976, '2021-04-28 00:29:57.788618+00', '2021-04-28 06:29:49.486711+00', 9630, 1, 202, 'ace', '1--::

  1M,2M & 3M dance RSh round 2W,3W & 4W to midline and face them ; all M set | cast R to places (1,2,3,4)

9--::

  1W,2W & 3W dance LSh round 2M,3M & 4M to midline and face them ; all W set | cast L to places (1,2,3,4)

17--::

  All turn P RH ; turn P LH into promhold (1,2,3,4)

25--::

  4C Promenade. On [28] 1c in 4pl make an arch _while_ 2c+3c+4c dance up under arch (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (12032, '2019-08-21 11:52:28.571917+00', '2019-08-21 11:57:49.799655+00', 14516, 1, 202, 'ace', '1--::

  1c lead down | cross and cast round 3c to 2plx (2c up) ; turn P RH (2,1x,3,4)

9--::

  4c lead up LHJ | cross and cast round 1c to 3plx (3c cross down to 4plx on [11-12]) ; turn P LH (2,1x,4x,3x)

17--::

  1c+4c+3c S&Link ; repeat (2,3,4,1)

25--::

  Mirror Reels4 on sides, RSh on Mside, LSh on Wside (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12031, '2019-08-21 02:22:13.691794+00', '2019-08-21 02:45:20.333382+00', 14512, 1, 202, 'ace', '1--::

  1c set | turn RH ; cast (2c up) | cross LH to 2plx (2,1x,3)

9--::

  Reels3 on sides, 1c LSh to 2cnrs (2,1x,3)

17--::

  Reels3{6} across, 1c RSh to 1cnrs | 1c turn P LH ½

25--::

  1c turn{3} P LH, dance{3} LSh round 3cnrs to 2pl | all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12033, '2019-08-21 22:07:07.961386+00', '2019-08-21 22:22:30.96101+00', 14506, 1, 202, 'ace', '1--::

  1c+2c RHA ; LHA (1,2,3)

9--::

  1c+2c set | 1c cast to 2pl _while{2}_ 2c cross up to 1plx (to 2x,1,3) ; Mirror ½ Reels3 on sides, 1c cross down RHJ to 3pl, 2c out and down, 3c out and up (3,1x,2x)

17--::

  3c+1c 6 bars of DblFig8, 1c crossing up | 1c+3c turn EH on sides (1x,3x,2x)

25--::

  3C S&Link ; repeat (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12035, '2019-08-21 22:53:02.857835+00', '2019-08-21 23:24:39.281099+00', 1898, 1, 202, 'ace', '1--::

  Gr-Chain (1,2,3)

9--::

  »Snowball Wheel« [: 1c turn P RH ¾ | 1c+2M ½ RHA, 2M ending in 1W place ; 1c+2c ¾ RHA] (2,1,3)

17--::

  Parallel Reels3 on sides, 1c LSh to 3c (2,1,3)

25--::

  »Drop Out Wheel« [: 1c+3c ¾ LHA (to Wside: 2W,1M,1W Mside: 2M,3M,3W) ; 1c+3W ½ LHA, 3W ending in 2W place | 1c turn P ¾ LH to 3pl] (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12036, '2019-08-22 16:53:19.162549+00', '2019-08-22 16:58:14.37437+00', 14514, 1, 202, 'ace', '1--::

  1c set | turn P RH 1½ | cast to 2plx (2c up) (2,1x,3,4)

9--::

  1c+3c+4c Mirror Reels3 on sides, 1c in and down, 3c up and out (2,1x,3,4)

17--::

  2c+1c+3c Mirror Reels3 on sides, 1c in and up, 2c out and down (2,1x,3,4)

25--::

  1c turn P RH 1½ to 2pl ; cast to 4pl (3c+4c up) | all set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13125, '2020-09-08 12:50:26.566401+00', '2023-01-05 23:08:46.901871+00', 3649, 2, 2784, 'ace', '{{explanation}}

Strathspey



1-::

  All set {2} W adv and dance round P Rsh back to pl

9-::

  1c+2W and 2M+3c Reel3 across, to start 1c pass RSh, 2W dances up, 2M dances down, 3c pass RSh

17-::

  All set {2} M adv and dance round P Rsh then turn P RH to finish in line facing W side, M above P

25-::

  All set facing W side {2}, set facing P {2} ; start Reel6 giving Rsh to P…

33-::

  …complete Reel6

41-::

  All petronella to own sides {2} circle6 to original positions



{{explanation}}

Reel



1-::

  1c Fig8 round 2c & 3c, dancing in to start

9-::

  1c Fig8 round 2c, casting off to start and finishing ready for allemande

17-::

  1c+2c allemande finishing in crown triangles posn, 1W facing up, 1M facing down

25-::

  All set and invert ; all set twice, 2c & 3c move close to P on last 2

33-::

  1W+2c promhold+3c promhold+1M start Reel4…

41-::

  …complete Reel4

49-::

  2c+3c RHA ; 2c+3c LHA to finish in original pl

57-::

  1c adv to join in lines across (1W+2c, 1M+3c), set ; 1s adv to meet and dance up to original pl (2c+3c down)



{{explanation}}

Strathspey



1-::

  All set {2} W adv and dance round P Rsh back to pl

9-::

  R3 across, to start 1c pass RSh, 2W dances up, 2M dances down, 3c pass RSh

17-::

  All set {2} M adv and dance round P Rsh back to pl

25-::

  1M+2c+3W diagonal Reel4, 2c give LSh to start

33-::

  1W+2c+3M diagonal Reel4, 1W+2W and 2M+3M give RSh to start, finish in original pl

41-::

  Circle6

', 2);
INSERT INTO 'dancecrib' VALUES (12037, '2019-08-23 01:29:35.316548+00', '2019-08-23 01:31:54.938932+00', 6087, 1, NULL, 'ace', '_1st Figure_

1--::

  All petronella turn and set to P ; All dance ½ Reel4, start Rsh to P, and pass Lsh in the middle.  Finish facing P (W inside)

9--::

  All set to P | petronella to square and face P ; ½ Gr-Chain to P’s place (1x,2x,3x,4x)

17--::

  All M turn P LH, join RH in middle, and W pivot L to form star facing clw | Wheel clw, at end the M turn P RH to own places (1,2,3,4)

25--::

  Circle8 and back (1,2,3,4) 

 

_2nd Figure_

33-48::

  All M pass Lsh in centre and turn W on the R with RH, leaving her in her place ; repeat 3 times, to (1,2,3,4).  On [33] all W step L to face opposite W.

49-64::

  All W pass Rsh in centre and turn M on the L with LH, leaving him in his place ; repeat 3 times, to (1,2,3,4).  On [49] all M step R to face opposite M   

 

_3rd Figure_

65-96::

  Repeat [1-32]   (1,2,3,4)





', 3);
INSERT INTO 'dancecrib' VALUES (3569, '2012-01-22 19:30:31.56629+00', '2020-12-22 23:20:51.034292+00', 7265, 1, NULL, 'ace', '1–::

  1c+2c Petronella and set ; turn ¾ RH, ½RHA (2,1)

9–::

  2c+1c+3c mirror Reels3 on opposite sides, 1c crossing down through 3c to start, 1c finish facing 2crs and 2c+3c loop into place

17–::

  ½Reel4 with 2cnrs, pass Lsh, ½Reel4 with 1cnrs, at end 1c pass Lsh to stand BtoB, facing M up, W down, corners face in diagonally

25–::

  3c+1M & 1W+2c Set, Circle3 L ; break (1c leading) into ½ Circle6 (to 2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (9161, '2016-06-11 14:03:40.384995+00', '2020-10-04 10:34:00.386988+00', 16889, 1, NULL, 'ace', '1--::

    1W dances down, out between 2W & 3W | casts round 3W to centre below 3pl _while{4}_ 1M crosses | casts to centre above 3pl ; 1c in tandem (1W leading) cast up around 3M & across to face 3W (2c up on 7-8)

9--::

    1c (1W leading) ½ alternating tandem RSh Reel3 with 1cnrs (RSh to 3W) to 1M facing 3W, 1W facing 2W ; 1M+3W set RH joined | turn RH _while{4}_ 1W ½ LSh Reel3 on W side with 2c

17--::

    1c (1M leading) ½ alternating tandem RSh Reel3 on 2cnr diagonal (RSh to 3M) to 1W facing 3M, 1M facing 2W ; 1W+3M set RH joined | turn RH _while{4}_ 1M ½ LSh Reel3 across in 3pl with 2c, 1c end in 2pl on W side in tandem (W leading) facing M side

25--::

    1c dance across | cast round 3M place to 3pl centre _while{4}_ 2c+3c set | cross (W casting) ; 1c dance up side by side (no hands) | cast to 2nd place _while{4}_ 2c+3c set | change places on the sides (3s casting) to (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (3328, '2012-01-22 19:30:20.730853+00', '2021-01-25 15:24:52.317624+00', 11371, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c RHA ; all chase ½ round clw (4x,3x,2x,1x)

9–::

  4c+3c & 2c+1c Reels4 across  (those in front in the chase pass Lsh first)

17–::

  4c+3c & 2c+1c RHA ; all chase ½ round clw (1,2,3,4)

25–::

  1c+2c & 3c+4c S&Link ; 1c+4c S&Link (2,4,1,3)

33–::

  All circle8 and back', 3);
INSERT INTO 'dancecrib' VALUES (12507, '2020-01-14 07:55:22.99754+00', '2021-03-19 23:04:33.69744+00', 8375, 2, 3085, 'ace', '1--::

  1s dance Inveran Reels with 2s+3s, 1s finish in centre facing down, 3s up

9--::

  1s+3s set and ½ RH across, dance up cross RH 3s to 3rd place, 1s to 2nd place (2s step up 15+16)

17--::

  1s cross RH, dance round 1st corner position, 1s cross RH up/down and dance round 2nd corner position to 2nd place opposite sides while 2s+3s set cross RH, set change RH on sides

25--::

  3s+1s+2s Chase ½ way to own side and all TRH', 0);
INSERT INTO 'dancecrib' VALUES (12034, '2019-08-21 22:09:04.135471+00', '2020-01-12 22:24:20.123704+00', 19551, 2, 1, 'ace', '1–:: 1c cross RH | cast off 2pl [2c+3c up] ; cross RH | cast up to 1pl [2c+3c down]

9–:: 1c+2c poussette

17–:: 1c+2c+3c dance slip knot [to 231]

25–:: All set | All turn BH {4} | All set', 1);
INSERT INTO 'dancecrib' VALUES (12134, '2019-09-02 01:30:56.434432+00', '2020-01-20 00:31:40.86043+00', 19592, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; dance between 3c, cast up to 2pl and pass P LSh to face 1cnrs (2,1,3)

9--::

  Corners Pass and Turn. On [15-16] 1c turn P RH ¾ into lines3 across and face 2cnrs

17--::

  ½ Reels3 across, 1c RSh to 2cnrs ; ½ Reels3 across, 1c RSh to 4cnrs (2,1,3)

25--::

  1c (2c following) dance down | cast up round 3c ; dance up | cast off to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2963, '2012-01-22 19:30:04.744841+00', '2021-04-28 23:09:57.834476+00', 5080, 1, NULL, 'ace', '1–::

  1c set, cross RH ; set, ¾ RH turn

9–::

  1c+2M RHA ; 1c+2W LHA

17–::

  1W followed by 1M dance down the middle | and up (1M leading) ; cast off round 2W (2c up) (2,1)

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (13001, '2020-07-30 20:50:05.263595+00', '2020-08-08 23:59:52.887163+00', 19898, 1, 202, 'ace', '*Deviser''s note:  

  Do not use hands.*

1--::

  1c+3c DblFig8, 1c crossing down (1,2,3)

9--::

  Circle6 and back

17--::

  Gr-Chain

25--::

  1c dance down ; and up to 3pl (2c+3c up on [31-32]) (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2655, '2012-01-22 19:29:51.769929+00', '2020-12-23 10:20:20.314699+00', 9387, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  1c lead down RHJ, on [4] 1M crosses above 1W who passes under his arm pulling Lsh back ; 1c (opp side) lead up | flowing into RH turn to face 1cnr

9–::

  ½Reel4 on 1diag, 1c not passing but on meeting turn BH ½ and twirl R to face 2cnr ; repeat with 2cnrs, 1c finish in DTr position facing own side



{{title}}

Reel



17–::

  1c dance as in DTr, but at end dance ¾ BtoB round each other to face out the ends (1M up, 1W down) _while{8}_ 3c+2c set as in DTr, petronella 1 position cclw in the square ; set as in DTr, petronella 1 position cclw again

25–::

  1M+2c & 1W+3c Reels3 across, Rsh to 2cnr (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12038, '2019-08-23 06:24:16.924949+00', '2019-08-23 06:29:39.143479+00', 14513, 1, 202, 'ace', '1--::

  1c+2c Set&Rotate (2,1,3)

9--::

  2c+1c set | cross RH ; »Double Diagonal Change« [: 1M+2W dance RSh ½ round each other, face each other | cast away to exchanged diagonal places _while{4}_ 1W+2M chase cclw ½] (1,2,3)

17--::

  1c+2c set | cross RH ; repeat »Double Diagonal Change« same pattern (2,1,3)

25--::

  1c+3c Rondel (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12040, '2019-08-23 17:17:43.125056+00', '2019-08-23 17:17:43.125056+00', 19554, 1, NULL, 'ace', '1--::

  1c+2c turn RH ½ | ½ RHA ; 1c set | cross RH and face out (2,1x,3)

9--::

  1c+1cnrs ½ diag. Reel4, 1c pass RH and face out the ends ; 1c+2cnrs repeat, 1c finish facing out (3x,1,2x)

17--::

  1c+3cnrs repeat, 1c finish facing out the ends ; 1c+4cnrs repeat, 1c finish facing out (2,1x,3) 

25--::

  1 cast off to 3pl (3c up) | 1c lead down ; 1c turn RH 1½ moving up to (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (12041, '2019-08-24 09:10:49.047491+00', '2019-08-24 18:11:58.182714+00', 476, 1, 202, 'ace', '1--::
  1c lead down (2c up) | lead up to between 2c, BtoB facing own side
9--::
  1c set | dance (PdB) to the R round P to exchanged places _while{4}_ 2c Petronella Turn | set ; repeat [9-12]
17--::
  ½ Reel4 across. 1c pass LSh to face 1cnrs ; 1c turn 1cnrs RH | turn P LH ending between 3c, BtoB facing own side
25--::
  1c+3c repeat [9-16]
33--::
  ½ LSh Reel4 across. 1c pass RSh to face 2cnrs ; 1c turn 2 cnrs LH | turn P RH to 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (12039, '2019-08-23 16:31:12.461899+00', '2019-08-24 10:19:26.884618+00', 336, 1, 202, 'ace', '1--::
  1c & 3c cast off | cross RH ; cast up one place | cross LH (1,2,3,4)
9--::
  Mirror Reels4 on sides, RSh on Wside, LSh on Mside (1,2,3,4)
17--::
  1c+2c & 3c+4c DblFig8, 2c & 4c crossing up (1,2,3,4)
25--::
  1c & 3c cast off _as_ 2c & 4c lead up one place (to 2,1,4,3) | 1c+4c ½ R&L | 4c & 1c cross RH (2,4,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (12044, '2019-08-24 22:21:46.769327+00', '2019-08-24 22:22:40.666789+00', 17250, 1, NULL, 'ace', '1--::

  1W+1M+2M Reel3, 1W Lsh to 2M, at end 1W loops R to face in (1,2) 

9--::

  1M+1W+2W Reel3, 1M Rsh to 2W, at end 1M crosses to face down (1,2) 

17--::

  1c+2c LHA ; RHA

25--::

  1c cross RH and cast off (2c up) ; 1c ½ Fig8 up (2,1)

', 3);
INSERT INTO 'dancecrib' VALUES (12043, '2019-08-24 19:54:08.680681+00', '2019-08-26 19:48:42.497793+00', 606, 1, 202, 'ace', '1--::
  1c cross down to 2plx (2c up)  | turn 2c EH on sides ; all NHJ set H.Schottische (2,1x,3)
9--::
  Circle6 L ; 1c cross down to 3pl (3c up) | turn 3c EH on sides. 1c face out (2,3,1)
17--::
  1c cast up ¼ round outside _while{2}_ 3c dance down to 3pl and face out | 1W+3W+2W LHA 1½ _while{6}_ 1M+3M+2M RHA 1½
25--::
  1c followed by 3c+2c dance down ; 2c followed by 3c+1c dance up to sides (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (3159, '2012-01-22 19:30:13.82762+00', '2021-01-25 15:27:11.069057+00', 11369, 1, NULL, 'ace', '1–::

  1c set | dance (touch NH) out through 2pl (2c up) ; cast L round 4cnr into the middle for

9–::

  Teapots R ; and L on the sides (1c+1cnr+2cnr RHA ; 1c+3cnr+4cnr LHA), face 1cnr

17–::

  Set to 1cnr | 1c dance (Sk-Ch) ¾ R round P to face 2cnr ; set to 2cnr | dance (Sk-Ch) R round P to face out in 2pl

25–::

  Rsh Reels3 on the sides

33–::

  2c+1c+3c circle6 and back.', 3);
INSERT INTO 'dancecrib' VALUES (15190, '2022-10-26 18:13:08.404714+00', '2022-10-26 18:13:24.674193+00', 1606, 1, 202, 'ace', '1--::

  Circle4 and back. Retain NHJ on sides

9--::

  1c+2c A&R ; turn P RH

17--::

  RHA ; LHA

25--::

  1c lead down {3}, lead up {3} | cast off (2c up) (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (12045, '2019-08-24 23:09:30.100735+00', '2019-08-25 07:30:39.066032+00', 3110, 1, NULL, 'ace', '*Set: trio WMW facing trio WMW*



1-16::

  *[Chorus]  All set {4} (any step) | All M turn W on the R RH ; M turn W on the L LH ;; Each trio Reel3, M Rsh to W on the R*

  

  

17-32::

  Modified Crown Triangles: All W face opposite W, each M joining hands with the two W on his L, and all set | all set, the M stay BtoB and progress ¼ clw and the W face partner W ; repeat these 4 bars 3 times (M with opposite W, with the W on the R; with own W, finish in places), 

33-48::

  Repeat chorus

49-64::

  Men set “H&G” all round, to original places

65-80::

  Repeat chorus

81-96::

  Men + 1cnrs ½ Reel4 (pass opposite Lady RSh) ;  Men + 2cnrs ½ Reel4 ;repeat with 3cnrs ; repeat with and 4cnrs, to places

97-112::

  Repeat chorus

113-128::

  Men petronella turn R | join hands with both W on the R and set in line of 3 ; repeat 3 times, back to places

129-144::

  Repeat chorus

', 3);
INSERT INTO 'dancecrib' VALUES (11400, '2018-12-17 12:50:12.527755+00', '2020-10-04 20:26:42.380325+00', 19126, 1, 1645, 'ace', '*On 2nd chord, 1c (RH) & 4c (LH) cross to opposite sides (1x,2,3,4x)*

1-::

  2c+3c dance bars 1-4 of the Espagnole (1x,3,2,4x), 3W & 2W (RSh & LSh back) curve towards each other & turn away for ; 1c+3c RHA _while{4}_ 2c+4c LHA, staying in the centre



9-::

  2W+4M+4W+2M each cross up & chase clw at top _while{4}_ 3W+1M+1W+3M cross down & chase cclw at bottom (those crossing up pass in front) & end facing up/down in from the sides (4x,2,3,1x) ; 4c+2c turn facing person RH 1&frac14; _while{4}_ 3c+1c turn LH 1&frac14; to lines across with W BtoB facing M who is not their partner

17-::

  2M+4W+2W+4M (top) RSh Reel4 across _while{8}_ 3M+1W+3W+1M LSh Reel4 across, 4W+2W & 1W+3W end facing each other

25-::

  4c+2c & 3c+1c reflected Targe figures: 4c+2c start with LH turn and clw chase, 3c+1c start with RH turn and cclw chase (2x,4,1,3x)

', 5);
INSERT INTO 'dancecrib' VALUES (13218, '2020-10-05 16:36:31.215435+00', '2020-10-05 18:32:02.879554+00', 20091, 1, 202, 'ace', '1--::
  1c cast behind own lines and back to 2pl passing LSh to face 1cnrs (2c up on [3-4]) (2,1,3)
9--::
  Reels3 on sides, 1c RSh to 1cnrs. 1c face 1cnrs
17--::
  SetH&G. On [23-24] 1c Petronella turn to 2pl (2,1,3)
25--::
  1c Fig8 up round 2c (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (13223, '2020-10-06 00:59:11.985993+00', '2020-10-06 07:47:23.080051+00', 20096, 1, 202, 'ace', '1--::
  1c+2c 4 bars of S&Rotate ; repeat [1-4] (2x,1x,3)
9--::
  Reels3 on sides, 1W(1M) RSh(LSh) to 1cnrs[pos] (2x,1x,3)
17--::
  2c+1c Petronella in tandem (no hands) | set ; repeat [17-20] (1,2,3)
25--::
  1c+2c 4 bars of Espagnole (to 2,1,3) ; 2c dance BtoB _while{4}_ 1c dance LSh BtoB (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (13222, '2020-10-05 19:11:39.893089+00', '2020-10-08 11:17:52.951058+00', 20094, 1, 202, 'ace', '1--::
  1c cross RSh | cast off (2c up) ; ½ Fig8 up round 2c to face 1cnrs
9--::
  ½ Reel4 on 1diag, pass P RSh ; ½ Reel4 on 2diag to 2plx (3x,1x,2x)
17--::
  ½ Reels3 on sides, 1c LSh to 1cnrs[pos] ; ½ Reels3 across, 1c LSh to 3cnrs[pos] (2,1,3)
25--::
  All A&R ; »RSh Turn« [: dance RSh round P to places] (2,1,3)

*Note:  
»RSh Turn« (Right Shoulder Turn) is also known as Gypsy Turn, a term now considered offensive by some.*', 2);
INSERT INTO 'dancecrib' VALUES (12048, '2019-08-27 02:29:17.201144+00', '2019-08-27 07:52:49.868686+00', 6123, 1, 202, 'ace', '1--::
  1c & 3c turn P RH | cast off (2c & 4c up) | 1c & 3c turn P LH 1½ ending BtoB between nearest top couple
9--::
  2W+1M & 1W+2M & 4W+3M & 3W+4M change places RH | 2c & 4c turn P LH ; same couples as on [9] change places RH | 1c & 3c turn P LH into same lines4 across but facing down NHJ
17--::
  All dance down ; and up
25--::
  1c & 3c cross and cast round 2c/4c (to 2,1,4,3) ; 1c+4c+3c ½ Mirror Reels3 on sides, 1c in and down, 4c out and up (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (12046, '2019-08-25 06:13:23.592342+00', '2019-08-25 21:53:24.43479+00', 482, 1, 202, 'ace', '1--::
  1c lead down ; and up to 1pl facing out (1,2,3)
9--::
  1c cast behind own lines ; and back _while{8}_ 2c+3c RHA ; LHA (1,2,3)
17--::
  1c cross RH | cast off (2c up) (to 2,1x,3) ; 1c dance down | cross and cast round 3c to the top behind own lines (2,1,3)
25--::
  1c lead down | cross and cast round 3c to the top behind opposite lines | cross down to 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (12051, '2019-08-27 20:23:30.066972+00', '2019-08-28 07:50:40.372129+00', 6181, 1, 202, 'ace', '1--::
  1c & 3c set | cast off behind nearest couple ; cross RH | cast up to P''s original place (1x,2,3x,4)
9--::
  1c+2c & 3c+4c RHA ; 2c+3c LHA finishing in centre facing nearest cnrs
17--::
  2c & 3c turn cnrs RH | 2c+3c ½ LHA to face opposite cnrs ; 2c & 3c turn opposite cnrs RH | 2c+3c ½ LHA to sides as on [9] (1x,2,3x,4)
25--::
  1c+2c & 3c+4c La-Chain up/down. 1c & 3c retaining LH face down (1x,2,3x,4)
33--::
  1c & 3c lead down LHJ below nearest couple, cross and cast up to original places ; 1c dance down to 4pl (2c+3c+4c up) (2,3,4,1)
41--::
  Circle8 and back', 4);
INSERT INTO 'dancecrib' VALUES (3513, '2012-01-22 19:30:28.619966+00', '2020-08-16 10:33:29.218863+00', 7534, 1, NULL, 'ace', '1–::

  1M+2W cross, passing P Rsh | cast R to exchanged places ; all petronella one place cclw | All set facing in (1x,2x)

9–::

  Repeat, 1W+2M crossing to start (to 1,2)

17–::

  Circle4 and back, the M finishing side by side on the sideline

25–::

  Tournée (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (10467, '2018-02-27 15:40:03.615078+00', '2021-04-28 23:25:19.331717+00', 5039, 1, 202, 'ace', '1--::

  1c & 5c cross RH | cast inwards (2c & 4c step out) (to 2,1x,3,5x,4) ; 1c+5c ½ LHA | turn P LH to face 1cnrs (2,5,3,1,4)

9--::

  ½ Parallel Reels4 in 1diag ; ½ Parallel Reels4 in 2diag

17--::

  ½ Parallel Reels4 in 1diag ; 5c+1c turn P LH and cast off on own side (3c+2c up) (4,3,5,2,1)

25--::

  4c+3c & 2c+1c The Knot (3,4,5,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (12053, '2019-08-28 13:31:31.228009+00', '2019-08-28 13:31:44.386632+00', 3965, 1, 1645, 'ace', '1-::

  1W+2W & 2M+3M Set&Link _while_ 1M & 3W set twice ; 1M+2c+3W (ends) &frac12; R&L _while_ 1W+3M (middles) turn 1&frac14; RH to lines of 3 across

9-::

  Repeat from new orientation: 3c & 1c Set&Link _while_ 2c set twice ; 3M+2c+1W (ends) &frac12; R&L starting on sides _while_ 3W+1M (middles) turn 1&frac14; RH & face out

17-::

  1M & 3W cast R & cross over _while_ 2c turn RH to own place (1x,2,3x) ; 1M+2M & 2W+3W cross diag LH | 1W+3W & 1M+3M cross diag RH

25-::

  3c+2M & 2W+1c circle3 1&frac13; L to (3,2x,1) ; 2c+3c change pl RH _while_ 1c turn RH | 2c cross LH _while_ 1c+3c turn LH on sides (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (12050, '2019-08-27 13:30:12.787475+00', '2019-08-28 17:24:42.297997+00', 7218, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 up round 2c and face 1cnrs

9--::

  1c turn 1cnrs RH into DTr position ; 4 bars of Crown Triangles starting across. Finish BtoB, 1W(1M) facing up(down)

17--::

  Reels3 on sides {6}, 1c LSh to 1cnrs | 1c turn P RH and face 2cnrs

25--::

  1c turn 2cnrs LH into DTr position ; all set | 1c dance (PdB) to the R round P to 2pl _while{2}_ cnrs set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12054, '2019-08-28 13:49:18.381466+00', '2019-08-28 13:49:33.227657+00', 19562, 1, 1645, 'ace', '1-::

  1c &frac12; Fig8 down round 2c & take promhold facing 2M ;

  1c(promhold)+2c &frac12; RSh Reel3 across in 2pl, 1c end facing 2M, 2W ends in 1plx

9-::

  1c+2M LHA, 1M ends in 1plx, 2M+1W take promhold facing 3M ;

  2M+1W(promhold)+3c &frac12; RSh Reel3 across in 3pl, 2M+1W end facing 3M, 3W ends in 2plx

17-::

  2M+1W+3M LHA (M: 1x,2x,3x; W: 2x,3x,1x) ;

  1M+2M & 3W+1W turn 1&frac12; RH (2x,1x,3x)

25-::

  Reels3 on sides, all cross up to own sides from 2nd place & end with loops (2,1,3).

', 5);
INSERT INTO 'dancecrib' VALUES (14079, '2021-06-19 22:21:57.627129+00', '2021-06-19 22:22:07.406608+00', 1180, 1, 1645, 'ace', '1-::

  1c lead down | &frac12; turn RH ; lead up | &frac12; turn RH, 2c & 3c step in for

9-::

  1c+2c+3c Allemande, 3c & 1c end turning &frac34; LH to centre line

17-::

  3c+1c &frac12; RSh Reel4, 1M+3W end passing &frac34; LSh to face own side ; 2M+1M+3W+2W &frac12; RSh Reel4 across, 1M+3W end passing &frac34; LSh to face P

25-::

  1c & 3c &frac34; turn RH | 1c+2c &frac12; RHA _while{2}_ 3c &frac12; turn RH, all retain RH with P ; all turn RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12055, '2019-08-28 13:58:01.922443+00', '2019-08-28 13:58:12.154041+00', 19561, 1, 1645, 'ace', '1-::

  1c dance below 3c | cast up (2c up) ; turn LH (or birl) to face 1cnr

9-::

  1c+1st cnrs &frac12; RSh diag Reel4, 1c pass LSh ;

  1c+2nd cnrs &frac12; RSh diag Reel4, 1c pass LSh to 3cnr [pos]

17-::

  1c "Corners Pass and Back to Back" with 3cnrs:

  1c normal "Pass and Turn", pass RSh to 4cnr [pos] _while{4}_ 3cnrs dance BtoB ;

  repeat with 4cnrs (3x,1,2x)

25-::

  1c turn 1&frac12; RH (or birl) & face out in 2plx _while{4}_ 3c+2c chase &frac12; way clw (2,1x,3) ;

  1c chase &frac12; way clw _while{4}_ 2c & 3c adv&ret diagonally (2,1,3)  

  *After their 2nd turn, 1c wait 4 bars in 3pl & step down on [5-6] of the next repeat.*

', 5);
INSERT INTO 'dancecrib' VALUES (2516, '2012-01-22 19:29:45.89198+00', '2020-12-23 10:23:08.502413+00', 10075, 1, NULL, 'ace', '1–::

  1c+2c set twice ; 1M+2W turn RH ¾ and chase clw to own place _while{4}_ 1W+2M cast clw one place and turn LH ½ to join RH with P

9–::

  BiL | turn P RH ½ and join LH in middle ; BiL | turn P RH ½ and face P

17–::

  Reel4 on first diagonal, but at end 1W+2M pass Rsh in middle

25–::

  1W & 2M with P following chase clw to (2x,1x) ; All C turn RH 1½, 1c face out

33–::

  1c cast up round 2c | dance down crossing and behind 3c (3c up) | cross RH (to 2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (13220, '2020-10-05 17:03:05.357055+00', '2020-10-05 17:04:37.928399+00', 20088, 1, 1645, 'ace', '1-::
  1c set | cast off (2c up) ; pass P LSh & round 1cnr RSh to lines of 3 across, 1W/1M between 2s/3s
9-::
  All set facing up/down | pass facing person RSh & turn to R in lines of 3 across in 2pl ;
  all chase clw back to lines across in 1pl/3pl, 2c & 3c now on opp sides
17-::
  1c &frac12; diag R&L up/down starting to R ; repeat to L
25-::
  1c change pl RH | cast to R round 2cnr[pos] _while{4}_ 3c+2c set facing down/up | change pl RH ;
  1c turn 1&frac12; RH (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (12060, '2019-08-28 23:36:51.945235+00', '2019-08-29 08:09:59.123879+00', 489, 1, 202, 'ace', '1--::
  1c cross down to 2plx _as_ 2c cast up | turn 2c EH ½ on sides ; cross down to 2pl _as_ 2c cast up | turn 3c EH on sides and face out (2,1,3)
9--::
  1c Mirror Fig8 on own sides, 1c out and up _while{8}_ 2c+3c R&L. On [15-16] 1c dance up to centre BtoB facing own sides
17--::
  DTr (2,1,3)
25--::
  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (12062, '2019-08-29 10:21:56.174798+00', '2019-08-29 10:30:12.000749+00', 1742, 1, 202, 'ace', '1--::
  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 1c+4c Circle 4 L. On [8] 1c+4c pivot R to face nearest cnrs (2,1x,4x,3)
9--::
  »Corners Petronella round a Double Hello Goodbye Setting« [: All 4 cnrs Petronella Turn to next cnr place cclw while{2} 1c+4c 2 bars of SetH&G | NHJ in circle, all set. On [11] 1c+4c release LH to dance strathspey setting step L  of SetH&G back to centre facing again same cnr ; repeat bars 9-12] (3x,4,1,2x)
17--::
  4c & 1c turn facing cnrs RH ; 4c+1c LHA _while{4}_ 3c & 2c chase clw ½ (to 2,4,1,3) |  4c & 1c turn new facing cnrs RH to sides into Reel4 position (2,4,1,3)
25--::
  Reels4 on sides', 2);
INSERT INTO 'dancecrib' VALUES (12059, '2019-08-28 19:56:21.826626+00', '2019-08-29 10:25:06.224814+00', 3088, 1, 1645, 'ace', '1-::
  1c cross RH | cast off (2c up) ; all turn P RH & face clw (2,1x,3)
9-::
  All chase &frac12; way clw ; 1c turn 1&frac14; RH to face 1cnr _while_ 3c & 2c continue chase to original places
17-::
  1c cast RSh round 1cnr, pass P RSh in the middle, cast RSh round 2cnr (2,1x,3)
25-::
  Reels3{6} on sides, 1c start LSh to 1cnrs | 1c cross RH (2,1,3)
', 4);
INSERT INTO 'dancecrib' VALUES (12056, '2019-08-28 14:01:01.610152+00', '2019-08-29 09:40:28.607862+00', 19560, 1, 1645, 'ace', '1-::

  1c dance down NHJ below 3c | turn 3c M RH, W LH | cast back to 1pl (1,2,3)

9-::

  1c+2c Untie the Knot: &frac12; RH turn to allemande hold facing down on W side |

  2c+1c turn to R, dance up centre & turn to face P still BHJ | face down & cast away to sides (2,1,3)

17-::

  1c+3c set on sides | pull RSh back & rotate 1 place clw (M side: 2M, 3M, 3W; W side: 2W, 1M, 1W) ;

  3M+1M & 3W+1W dance BtoB

25-::

  3M+1M & 3W+1W Knot with same sex partner (M side: 2M, 3W, 3M; W side: 2W, 1W, 1M)

33-::

  3W+1W & 3M+1M diamond poussette{6} | &frac12; turn BH & open out, 1W & 3M leading, to own sides (2,3,1)  

  *The final 3c & 1c dance full diamond poussette in [33-40] to end opposite new partner for the closing chord.*

', 5);
INSERT INTO 'dancecrib' VALUES (11248, '2018-10-04 19:48:25.59465+00', '2022-05-23 08:18:23.928976+00', 3133, 1, NULL, 'ace', '1--::

  1c cross RH and cast off (2c up) ; 2c+1c ½ R&L (1,2x)

9--::

  1c+2c L-Chain (1,2x)

17--::

  (Highland Schottishe Petronella): All face in diagonally. All HS set R and pivot ¼ R (i.e. face out) | HS set L and pivot  ½ R (face in: all have moved one place cclw) ; repeat this figure to (2,1x)  

25--::

  1c lead down | lead up to top, cross and cast off (2,1)   

  





', 3);
INSERT INTO 'dancecrib' VALUES (13379, '2020-11-28 00:05:09.022179+00', '2020-11-28 00:23:02.564403+00', 17872, 1, 202, 'ace', '_Strathspey_

1--::

  All cross RH | set ; 1c+2c & 3c+4c ½ RHA | set (2,1,4,3)

9--::

  1c & 4c ½ Fig8 round ends (to 2,1x,4x,3) ; ½ Reel4 on 1diag, 1M RSh to 2M and 4W RSh to 3W, ending as on [13]except 2M & 3W to exchanged places

17--::

  ½ Reel4 on 2diag, 1W LSh to 2W and 4M LSh to 3M, ending as on [17] except 2W & 3M to exchanged places (to 3x,1x,4x,2x) ; 1c+4c turn LH on sides _while{4}_ 3c & 2c turn P LH (3x,1x,4x,2x)

25--::

  All set, pull RSh back and chase one place clw ; all cross RH  | chase one place clw (3,1,4,2)



*Repeat once in Strathspey time then twice in Jig time.*', 2);
INSERT INTO 'dancecrib' VALUES (11837, '2019-05-08 14:17:42.365333+00', '2020-11-28 10:52:48.897924+00', 14979, 2, 26003, 'ace', '1-8:: 1s and 2s dance modified chain progression - 1s2s turn R3/4, 1M2L turn L 1-1/2 while 1L2M chase 1/2 way clockwise, 1’s ½ turn and twirl out on 7-8 to face 1st corners while 2s turn R3/4 to end 1st place own side.

9-10:: 1’s turn 1st corners R1/2  as 2nd corners set. 

11-12:: 1’s and 2nd corners chase one place clockwise as 1st corners turn ¾ lh to face 2nd corner positions.

13-14:: 1’s turn 1st corner persons  R1/2 as 2nd corner persons (in 1st cnr positions) set.

15-16:: 1’s turn ¾ lh to face 3rd corner position as  corners chase 1 place clockwise.

17-24:: 1’s dance ½ diagonal reel with 3rd corners posn, pass right and dance ½ diagonal reel with 4th corner posn to end 2nd place own side.

24-32:: 2s1s3s Circle 6 hands round and back', 1);
INSERT INTO 'dancecrib' VALUES (12058, '2019-08-28 19:13:18.508272+00', '2019-08-28 23:55:21.076799+00', 4777, 1, 202, 'ace', '1--::
  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 1c+4c LHA finishing in centre facing nearest cnrs (2,1x,4x,3)
9--::
  1c & 4c turn cnrs RH | 1c+4c ½ LHA to face opposite cnrs ; 1c & 4c turn opposite cnrs RH | 1c+4c ½ LHA to sides as on [5] (2,1x,4x,3)
17--::
  Reels4 on sides (2,1x,4x,3)
25--::
  2c+1c & 4c+3c RHA ; 1c+4c ½ R&L (2,4,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14762, '2022-04-17 08:25:33.544772+00', '2022-04-17 08:26:34.415662+00', 11908, 1, 202, 'ace', '1--::
  1c+2c ½ RHA (to 2x,1x) | 1c+3c LHA | 2c+1c ½ LHA (1,2,3)
9-20::
  3C R&L (1,2,3)
21-24::
  1c set | cast off (2c up)
25--::
  1c+2c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (7892, '2013-08-21 08:31:50.631012+00', '2023-02-04 01:23:09.863259+00', 12694, 3, NULL, 'ace', '1-8::
    1L+2M change places RH & dance reel of 3 on opposite sides (RSh to
    partner to start)
9-16::
    1M+2L change places LH & dance reel of 3 on opposite sides (1s LSh
    to 2s to start)
17-20::
    2s+1s set & 1/2 turn partners 2H to face down in middle
21-24::
    1s followed by 2s dance down below 3s & cast up own sides ending
    with 1s curving in to face down in middle & 2s to top
25-32::
    1L dances LH across with 2L+3L _while_ 1M dances RH across with
    2M+3M, 1s turn 3s on sides with nearer hand 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (2568, '2012-01-22 19:29:47.982376+00', '2020-12-08 09:52:43.410992+00', 3493, 1, NULL, 'ace', '1–::

  1c cross RH, cast off (2c up) ; turn ¾ LH, dance Lsh round 1cnr to end beside cnr facing in diagonally

9–::

  1c+1cnrs S&Link ; ½Reels3 on own side, 1c dance in to finish again beside 1cnr person facing in diagonally

17–::

  1c+1cnr (persons) S&Link (to 3,1x,2) ; ½Reels3 across, Rsh to 4cnr pos, finish (3x,1,2x)

25–::

  1c ½ Fig8 L (M up, W down) _while{4}_ 3c facing 2c set and change places RH ; 2c+1c+3c set and cross RH.', 2);
INSERT INTO 'dancecrib' VALUES (12800, '2020-05-07 08:47:43.340843+00', '2020-09-09 14:32:37.069765+00', 19971, 2, 1645, 'ace', '1-8::
  1s set, cast, 1/2 Fig 8 across around 2s.
9-16::
  1s dance reflection Fig 8s on opp side (in & down to begin).  
  *When danced with people instead of traffic cones, dance reflection Reels3*
17-24::
  1s cross LH, dance down around 3s, NHJ dance up the middle, dance around 2s to face 1st corners.
25-32::
  Set to Corners & Partner (Hello-Goodbye setting), finishing with a petronella turn into 2nd place.', 0);
INSERT INTO 'dancecrib' VALUES (12894, '2020-06-23 13:49:00.998026+00', '2020-08-12 08:50:54.121348+00', 19903, 2, 10819, 'ace', 'This is a hands free dance.

1C successfully brought to a hold after 16 bars, yay, after a fugal start spreading the pattern all over the place.



1-2:: 1C petronella turn.

3-4:: 1C set facing up and down _while_ 2C petronella turn (2L between 1C)

5-6:: 1C petronella turn to opp. side _while_ 2C set _while_ 3C petronella turn (3L between 2C)

7-8:: 1C set _while_ 2C petronella to opp. side _while_ 3C set.



9-10:: 1C pass LS back to own side, facing out _while_ 2C set _while_ 3C petronella to opp. side.

11-12:: 1C start casting into 3rd place, 2C cross up (no hands) to top place facing in _while_ 3C set.

13-14:: 1C finish casting into 3rd place, 2C pass LS facing out and 3C cross up to 2nd place (no hands) facing in.

15-16:: 1C set _while_ 2C cast down to 2nd place facing in _while_ 3C pass LS to finish back to back facing partner''s side; 2C+3C forming a line across the dance.



17-24:: 2C+3C reel of four across the dance, finishing shoulder to shoulder facing down with men on the left of their partner, 3C in the lead.

25-32:: 2C+3C cross down below 1C, cast up, meet in the center to face up. 3C cast into second place, 2C finish in 1st place turning inwards. Finish in the order 2, 3, 1.', 5);
INSERT INTO 'dancecrib' VALUES (1752, '2012-01-22 19:29:00.545138+00', '2020-09-11 08:51:47.466299+00', 10689, 1, NULL, 'ace', '1–::

  All A&R ; dance BtoB and clap

9–::

  1c turn RH ; cast off (2c up) and set

17–::

  1c lead down the middle and up

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (3247, '2012-01-22 19:30:17.371248+00', '2020-09-12 21:56:55.752874+00', 10707, 1, NULL, 'ace', '{{explanation}}

C face C RR



1–::

  Dance BtoB with person opposite (Clap) ; turn same person RH

9–::

  Repeat with P

17–::

  1c, NHJ dance through 2c and cast to place ; 2c repeat

25–::

  1c+2c A&R (Clap) ; pass Rsh to next C', 2);
INSERT INTO 'dancecrib' VALUES (13221, '2020-10-05 17:23:56.074128+00', '2020-11-06 16:13:09.590199+00', 20093, 1, 202, 'ace', '1--::
  1c set | cast off (2c up) ; ½ Fig8 up round 2c (2,1x,3)
9--::
  1c set | cast off (3c up and face out) ; ½ DblFig8, 1c crossing up, 3c casting off (2,3x,1)
17--::
  3c+1c set | Petronella turn  in tandem ; repeat [17-20] (2,1x,3)
25--::
  ½ Reels3 on sides, 1c RSh to 1cnrs. 1c pass RSh to 2pl ; ½ Reels3 on sides, 1c RSh to 3cnrs[pos] (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (12067, '2019-08-29 22:18:33.064599+00', '2019-08-30 14:51:58.182206+00', 1590, 1, 1645, 'ace', '1-::

  1c set | cross RH ; cast off (2c up) | turn RH to face 2cnrs

9-::

  1c Pass&Turn with 2cnrs, 1c twirl away to face 1cnrs ;

  repeat with 1cnrs, 1c end LSh to P facing opposite sides

17-::

  2c+1W & 1M+3c &frac12; RHA | 1c chase clw to 2pl _while{2}_ 2c & 3c set RHJ ;

  2c+1M & 1W+3c &frac12; LHA | 1c chase cclw to 2pl _while{2}_ 2c & 3c set LHJ & swivel to face down/up

25-::

  2c+1c+3c Reels3 on own sides, 1c start RSh to 4cnrs (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3198, '2012-01-22 19:30:15.358921+00', '2020-12-23 11:15:15.324016+00', 10381, 1, NULL, 'ace', '1–::

  1M+2W & 3W+4M turn BH 1½ to change places ; all M LHA, at end drop LH and form star pattern, all C facing cclw NHJ

9–::

  All S&Link to change places with P ; repeat, finish facing P along sidelines (1W+2M+3M+4W are in own positions)

17–::

  Parallel Reels4 on the sides

25–::

  1W+2M & 3M+4W turn BH 1½ to change places (2x,1x,4x,3x) ; 2c+3c cross RH _while{2}_ 1c+4c ½ LHA (2,4,1,3) | all set', 3);
INSERT INTO 'dancecrib' VALUES (12066, '2019-08-29 21:55:00.790956+00', '2019-08-30 16:33:00.507051+00', 3753, 1, 1645, 'ace', '1-::
  Circle8 & back, 1c & 4c end facing down/up in centre
9-::
  1c & 4c dance towards centre, turn towards P & dance back to ends ; cast in (2c & 3c to ends) | &frac12; LHA to face corners
17-::
  4c & 1c change RH with corners | all set RHJ ; repeat [17-20], 4c & 1c finish facing nearest end (2,4x,1x,3)
25-::
  4c cross up RH | cast off _while{4}_ 1c cross down LH | cast up ; all turn P RH (2,4,1,3)
', 4);
INSERT INTO 'dancecrib' VALUES (13231, '2020-10-14 21:46:15.016254+00', '2020-11-28 10:59:22.768653+00', 19879, 2, 963, 'ace', '1-4::  

  1m, flwd by 1w, cast below 2m and cross to 2w plc and face out, 1w in 2m plc, 2s up 3&4  

5-12::  

  2c and 1c ladies'' chain, 1m stays facing out  

13-16::   

  1m, flwd by 1w, cast below 3w and cross to 3m plc, 1w in 3w plc, 3s up 15&16

17-24::  

  3c & 1c RHA, LHA   

25-28::  

  all adv & retire  

29-32::

  all turn P BH once round  2,3,1

  

  ', 5);
INSERT INTO 'dancecrib' VALUES (14835, '2022-05-26 17:27:22.524381+00', '2022-05-26 17:27:22.524381+00', 20867, 2, NULL, 'ace', '1-8::  1s2s3s set, cross over, set and cross back. (No hands)

9-14:: Partner1 leads Partner2 in a chase down behind own line, below 3s, Partner1 dance up behind opp. line into 2nd place while partner2 dances up the center to 2nd place opp. side.

15-16:: 1s adv 1 step, retire 1 step. - Face Right to 2nd corner.

17-24:: 1s with 2nd corner set advancing to pass, cast L to places, 1s with 1st corner Repeat.

25-32:: Reels of 3 on sides [6] - 1s R shoulder to 2nd corners, cross L shoulder to own sides', 2);
INSERT INTO 'dancecrib' VALUES (10229, '2017-11-04 23:36:05.116982+00', '2020-10-06 15:16:47.848189+00', 15103, 1, 202, 'ace', '1--::

  1c+2c set | 1c+2c A&R{1+1} ; 1c+2c S&Link, 1M end facing out (2,1,3)

9--::

  1c »dolphin chase« [1M followed by 1W cast L round 3M, change lead, 1W followed by 1M dance up between 3c, cast R round 2W, change lead to 2pl] (2,1,3)

17--::

  1c+2M RHA ; 1c+3W LHA, finish facing down 1W behind 1M

25--::

  1c (1M leading) dance down between 3c, separate and cast off to 2plx _while{4}_ 2c & 3c set | cross RH (to 2x,1x,3x) ; 1c turn RH 1 ½ _while{4}_ 2c & 3c set | cross RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (13467, '2020-12-24 03:37:15.201701+00', '2020-12-24 03:41:30.593884+00', 10697, 1, 202, 'ace', '1--::

  1c lead down {3}, lead up {3} | cast off (2c up) (2,1,3)

9--::

  2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA, pass LSh to face 1cnrs

17--::

  SetH&G. On [23-24], 1c Petronella turn to 2pl (2,1,3)

25--::

  1c dance down between 3c | cast up ; dance up between 2c | cast off (2,1,3)



*Deviser''s note:  

For more advanced dancers, a mirror reel of three may be substituted on bars 25-32, with 1st couple starting by dancing in and down, other couples going out.*', 0);
INSERT INTO 'dancecrib' VALUES (11542, '2019-01-25 22:17:25.833838+00', '2021-08-02 09:02:15.501056+00', 10802, 2, 1, 'ace', '1–::

  1M “solo R&L”: change pl w/1L RH | 2L LH | 2M RH | ½ turn 1L LH [keep hands]

9–12::

  1c dance between 2c, separate, cast back to M''s side

13–16::

  2c dance between 1c, separate, cast back to L''s side

17–::

  All: set | ½ RH across ; ½ turn ptr RH | chase 1 pl clw [2,1x]

25–::

  1c lead up crossing over | cast off ; dance between 3c | cast up', 3);
INSERT INTO 'dancecrib' VALUES (13474, '2020-12-25 06:17:39.324617+00', '2020-12-25 06:22:45.380804+00', 10715, 1, 202, 'ace', '1--::

  1c+2c RHA ; LHA (1,2,3)

9--::

  1c Parallel Fig8 on sides, LSh to 2c (1,2,3)

17--::

  1c lead down {3}, lead up {3} | cast off (2c up) (2,1,3)

25--::

  1c+3c R&L (2,1,3)



*Deviser''s note:  

On bars 9-16, a reel of three on the sides may be substituted.*', 2);
INSERT INTO 'dancecrib' VALUES (14716, '2022-03-31 17:28:54.664687+00', '2022-03-31 17:31:50.836368+00', 20146, 1, 202, 'ace', '1--::
  1c+2c set | RHA | 1c cast off _as_ 2c dance up to top and face out (2,1,3)
9--::
  Mirror Reels3 on sides, 1c in and down (2,1,3)
17--::
  1c ½ Fig8 down round 3c ; ½ Fig8 up round 2c (2,1,3)
25--::
  1c+3c Rose Progression (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12064, '2019-08-29 20:12:27.343552+00', '2019-08-30 16:52:25.492584+00', 261, 1, 1645, 'ace', '1-::

  All petronella | set ; 1c & 3c slip BHJ to M side as 2c & 4c slip to W side | all set NHJ on sides

9-::

  1c+2c & 3c+4c DblFig8 across the set, to start 1c & 3c cross diagonally to W side between 2c & 4c who cross straight over to M side

17-::

  1M+2W & 3M+4W cross RH (1x,2x,3x,4x) | 1c+2c & 3c+4c &frac12; RHA (2,1,4,3) ; 2c+1c & 4c+3c LHA

25-::

  1c dance down to 4pl _while_ 3c cast up 2pl (2,3,4,1) | 1c cast up to top & dance back down (2,3,4,1)

', 4);
INSERT INTO 'dancecrib' VALUES (12065, '2019-08-29 21:41:12.265654+00', '2019-08-29 21:41:23.174571+00', 2762, 1, 1645, 'ace', '1-::

  1c cross down RH (2c up) | set RHJ ; spin (R elbow grip) to face 1cnrs

9-::

  1c+1cnrs &frac12; diag RSh Reel4 but 1c end twirling away to face 2cnrs ;

  repeat with 2cnrs, 1c end BtoB facing own sides

17-::

  1c cast RSh round 3cnr[pos] & face P in centre _while{4}_ 3c+2c &frac12; R&L ;

  1c turn &frac34; RH to 2pl _while{4}_ 2c & 3c spin (R elbow grip) to face down/up in centre

25-::

  Circle6 & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2384, '2012-01-22 19:29:34.711558+00', '2020-12-06 18:37:47.321706+00', 2709, 1, NULL, 'ace', '1–::

  All set | 1c cross RH _while{2}_ 2c+3c ½ RHA ; All set | 2c cross RH _while{2}_ 1c+3c ½ RHA (3,1,2)

9–::

  1c Petronella (to 2plx), but finishing BtoB facing 2cnr position (1cnr person)

17–::

  1c+1cnr persons pass Rsh, cnrs turn RH to places _while{2}_ 1c cast R, meet and pivot R to face 1cnr pos. ; repeat with 2cnr persons , 1c finish BtoB facing M down W up

25–::

  Reels3{6} across, Rsh to 4cnr pos | 1c cross Lsh to (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (2656, '2012-01-22 19:29:51.810414+00', '2020-10-05 17:30:22.339182+00', 3748, 1, NULL, 'ace', '1–::

  1c turn RH 1½ ; 1M+2M turn LH 1½ to finish facing partners

9–::

  1c+2c Rsh Reel4 across, men finish using LH and give RH to partners to end in line of 4 across the dance 1M+2W facing down, others facing up

17–::

  All set in line of 4 across and turn P RH ½ way round ; set again in lines of 4 across, men set and women move to nearest sideline with setting step to join P

25–::

  1c (from men''s side) followed by 2c down the middle, women turn under, 2c+1c up the middle.', 2);
INSERT INTO 'dancecrib' VALUES (13126, '2020-09-12 22:14:35.656213+00', '2020-09-13 08:07:47.662144+00', 19978, 2, 2784, 'ace', '1-::

  1c+2c+3c Reel3 on sides, 1c cross down to start, 2c & 3c cross when they reach 1pl (1x,2x,3x)

9-::

  1c+2c set, 1/2 RHA; 1c+3c set, 1/2 LHA

17-::

  1c set, lead up, cross RH and cast to 2pl (2 up)

25-::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (1923, '2012-01-22 19:29:10.011252+00', '2021-01-25 15:30:50.662021+00', 11368, 1, NULL, 'ace', '1–::

  1c+2c »Chain&Turn« (1M+2W turn RH ¾ to the diagonal | 1M+2M & 1W+2W Turn LH ½ ; 1W+2M Turn RH 1 ¼ (2,1,3)

9–::

  2c+1c set | turn RH ½ and face down ; lead down, M pass below P and turn P under their arm, to both face up | lead up, 2c face out (2,1,3)

17–::

  Mirror Reels3 on the side, to start 1c cross up and 3c cast up, 2c+3c finish with loops (2,1x,3)

25–::

  All advance {1} retire {1} | 1c petronella turn ; In lines across advance {1} retire{1} | 1c petronella turn to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (15245, '2022-11-15 22:41:02.813962+00', '2022-11-15 22:44:28.062748+00', 9670, 1, 1645, 'ace', '1--::

  1W dances clw loop to P & back to place | 1W followed by P casts off (2c up) ; crosses up, casts off round 2M & crosses to 2pl facing out (2,1,3)

9--::

  1c+3c RHA, 1W faces out ; 2c+1c LHA, 1W faces in (2,1,3)

17--::

  1c set adv passing LSh to face 1cnrs | 1c+1cnrs turn BH to lines of 3 across ; 1c repeat with 2cnrs & end on sides facing 1cnrs

25--::

  Reels3{6} on sides, 1c start LSh to 1cnrs | 1c cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13466, '2020-12-23 11:27:11.35247+00', '2020-12-23 11:35:24.923075+00', 10696, 1, 202, 'ace', '1--::

  1c+2c RHA ; PdB R to partner. On [6] PdB L and pivot to face on sides | 1c+2c turn RH on sides (1,2,3)

9--::

 Parallel Reels3 on sides, 1c RSh to 2c (1,2,3)

17--::

  1c lead down {3}, lead up {3} | cast off (2c up) (2,1,3)

25--::

  All dance BtoB ; turn P RH (2,1,3)



*Deviser''s note:  

On bars 7 & 8, care should be taken not to rush entry into the reel. This is a slightly more challenging dance for beginners.*', 2);
INSERT INTO 'dancecrib' VALUES (13709, '2021-02-27 12:49:28.011286+00', '2021-02-27 12:58:31.20547+00', 16630, 1, 202, 'ace', '1--::

  1c & 3c set | turn P RH ½ moving toward centre into ; RHA ½ | turn P RH ½ to exchanged places and face out (3x,2,1x)

9--::

  Mirror Reels3 on sides, 2c in and down, 3c out and up (3x,2,1x)

17--::

  2c turn P LH to face 2cnrs[pos] | turn 2cnrs[pos] RH ; turn P LH | turn 1cnrs RH into facing lines3 across, 2M between 1c

25--::

  3C S&Link (to 3,2,1) ; all set | 3c cast to 3pl (2c+1c up) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14080, '2021-06-19 23:13:33.371572+00', '2021-06-19 23:14:39.595091+00', 2467, 1, 1645, 'ace', '1-::
  1W & 4M, followed by P, cast off/up 2 pl | cross (2c & 3c out) ; 1c+4c RHA & face cnrs (2,4x,1x,3)
9-::
  4c & 1c change pl LH with cnr | 4c & 1c set _while_ 2c+3c &frac12; RHA ;
  change pl LH with cnr | 3c & 2c set _while_ 4c+1c &frac12; RHA (3x,1,4,2x)
17-::
  Repeat [9-16] to (2,4x,1x,3)
25-::
  4c & 1c set to cnrs | &frac34; turn cnr, dancing out through ends ; &frac12; Fig8 through ends (2,4,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (10131, '2017-09-15 09:11:48.466883+00', '2021-07-03 16:28:32.55005+00', 15124, 1, 202, 'ace', '1--::

 1c cross RH | cast (2c up) ; ½ Fig8 through 2c finishing facing 1cnrs

9--::

 1c+1cnr Pass and Turn, 1c pass Rsh ; 1c+2cnr Pass and Turn to 2pl (2,1,3)

17--::

 2c+1c+3c chase clw ½ round ; all turn P 1 ½ (3,1,2)

25--::

 1c+2c S&Link ; 3c+2c S&Link (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (14085, '2021-06-20 20:56:37.280903+00', '2021-06-20 20:56:49.848014+00', 3860, 1, 1645, 'ace', '1-::

  1c+2c+3c &frac12; Reels3, 1c+2c passing RSh, 1c end facing up ; 2c+1c+4c &frac12; LSh Reels3 (3,4,1,2)

9-::

  1c & 4c &frac12; Fig8 out the ends (3,4x,1x,2) ; RHA, end facing cnr

17-::

  4c & 1c set to cnrs | change pl with cnrs RH ; set to cnrs | change back LH & face in

25-::

  4c+1c set | &frac12; RHA, retaining RH with P ; turn P RH | all set (3,1,4,2)

', 2);
INSERT INTO 'dancecrib' VALUES (8090, '2013-10-15 13:38:35.415978+00', '2020-10-05 18:10:27.347126+00', 15030, 2, 1, 'ace', '1–::

  1c cast off (2c up on 3–4) ; 1c dance ½ Fig8 round 3c

9–12::

  All advance 1 step, set (LF then RF), retire 1 step

13–16::

  All turn BH to own sides (1c: 1½ times, 2&3c: once), finish 1c facing down, 3c up

17–20::

  ½ Grand Chain, all finish facing CW (1M, 2W, 3W curve round by R)

21–24::

  All chase CW to own sides

25–::

  3-couple Knot', 3);
INSERT INTO 'dancecrib' VALUES (10987, '2018-08-15 00:47:35.289549+00', '2020-10-06 15:46:15.78032+00', 15290, 1, 202, 'ace', '1--::

  3c Fig8 to the R, 3W(3M) round 2c(4c) (1,2,3,4,5)

9--::

  Circle10 and back

17--::

  2c+4c »modified Espagnole« [same as Espagnole except that 2W&4W on [17-18] then 2M&4M on [19-20] cross between standing 3c] (1,4,3,2,5)

25--::

  4W+1c & 4M+3c+2W & 2M+5c RHA ; LHA

33--::

  1c+3c+5c Parallel Reels3 on sidelines round standing 4c & 2c, starting with 1c & 3c Lsh to 4c, 5c Rsh to 2c (1,4,3,2,5)

41--::

  Circle10 and back

49--::

  1c+4c & 2c+5c The Tournée (4,1,3,5,2)

57--::

  1W+4c & 1M+3c+5W & 5M+2c RHA ; LHA

65--::

  3c Petronella Turn twice ; cross and set _while{8}_ 4c+1c & 5c+2c Poussette (4,1,3,5,2)

73--::

  Circle10 and back  (4,1,3,5,2)', 2);
INSERT INTO 'dancecrib' VALUES (8494, '2015-01-16 22:25:06.972188+00', '2020-10-07 14:24:42.829831+00', 15317, 2, 1, 'ace', '1–::

  1c lead down below 3c (2c up on 3–4) |

  turn RH ; cast up round 3c to fin facing 1st corners

9–::

  Hello-goodbye setting (on 15–16, 1c turn ½ LH to fin facing 1st corners)

17–::

  1c+1st corners ½ Reel4 (1c pass RS to 2nd corners) ;

  1c+2nd corners ½ Reel4 (1c fin 2pl own sides)

25–::

  All chase clockwise halfway round the set ; 1c turn 1½ RH', 3);
INSERT INTO 'dancecrib' VALUES (14084, '2021-06-20 13:52:12.869919+00', '2022-07-31 20:33:45.539235+00', 20314, 1, 202, 'ace', '1--::

  1c ½ Fig8 down round 2c RHJ ; turn 2c on sides EH (1x,2,3)

9--::

  1c long cast ; 1c turn P BH 1½ _while{4}_ 2c+3c chase clw ½ (3x,1,2x)

17--::

  Reels3 on sides, 1c RSh to 3cnrs[pos]. 1c pass P LSh and face 1cnrs[pos]

25--::

  *Corners Pass, Half-turn and Cast Away* : same as Corners Pass and Turn except cnrs turn BH ½, face each other and cast away to exchanged places (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13127, '2020-09-13 08:41:11.84769+00', '2020-09-13 08:44:00.889077+00', 12493, 1, 202, 'ace', '*Square set, with 5c in centre facing 1c. 5c is dancing couple.*

1--::
  Reel3 in tandem (no lead change), 5c RSh to 1C with 5W, 1M & 3W leading. On [8] 5c change leader, 5W dancing behind 5M
9--::
  Reel3 in tandem (no lead change), 5c LSh to 4C with 5M, 4M & 2W leading. All end as on [1]
17--::
  1c+5c ½ R&L ; 1c+2c ½ R&L
25--::
  2c+3c ½ R&L ; 4c+3c ½ R&L (5,1,2,3 with 4c in centre facing 5c)', 2);
INSERT INTO 'dancecrib' VALUES (13556, '2021-01-16 19:49:01.237832+00', '2021-01-23 21:57:05.464973+00', 20205, 1, 1645, 'ace', '*7 dancers, 1c, 2c & 3c in a triangular set with 7th dancer ("No7") in the centre facing up to 1c. NB crib derived from the video*

1-::

  1c+No7 RHA three times, but on bars 1-2, 3-4 and 5-6 first 1W, then 1M, then No7 dance under arches made by the other two. 1c end in P''s place, No7 ends facing 2c (1x,2,3,7)

9-::

  2c+No7 repeat [1-8] but with LHA, No7 ends facing 2c (1x,2x,3,7)

17-::

  3c+No7 repeat [1-8] with RHA again, No7 ends facing 3W in 3M place (1x,2x,3x,7)

25-::

  3W+No7+2W+1W Reel4 across, 3W+No7 & 2W+1W start passing RSh, No7 ends facing 3M (in 3W place)

33-::

  3M+No7+2M+1M diagonal Reel4, 3M+No7 & 2M+1M start passing RSh, No7 ends facing up to 1c

41-::

  1c, 2c & 3c petronella to place of dancer to their R _while{2}_ No7 sets pulling RSh back to face down to 3c (now in 3W & 2M places) | all set NHJ with P, No7 joining hands with 3c ; repeat, No7 joining hands with 2c at the top

49-::

  Repeat [41-44], No7 joining hands with 1c at the bottom ; 2c, 3c & 1c turn 1&frac12; RH _while{4}_ No7 dances out between 1c & 2c and casts R around 2c to top between 2c & 3c

57-::

  All circle7 & back ending on the sides (7,3,1,2)

', 0);
INSERT INTO 'dancecrib' VALUES (14836, '2022-05-26 21:56:32.291425+00', '2022-05-26 21:56:32.291425+00', 20868, 2, 160, 'ace', '1-8:: Mirror Fig.of 8 on own sides - in and down to begin.
9-16:: 1s 2s RH Across [3], LH back [3]. 1s cast  as  2s dance up.
17-24::  1s 3s dance R&L.
25-32:: 6hands round and back.', 0);
INSERT INTO 'dancecrib' VALUES (15246, '2022-11-17 00:21:38.773664+00', '2022-11-17 00:22:00.272701+00', 21144, 1, 1645, 'ace', '1--::

  1c cross RH | cast off (2c up) ; turn LH (2,1x,3)

9--::

  1c &frac12; Fig8 LSh round 3cnrs & end BtoB facing 4cnrs ; 1c set to & turn 4cnrs BH ending on sidelines (2,1,3)

17--::

  All circle6 to L & back, 1c end BtoB facing 3cnrs

25--::

  1c set to & turn 3cnrs BH ending in lines across ; 1c &frac12; Fig8 on own side, LSh round 4cnrs to 2pl own sides (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (1759, '2012-01-22 19:29:00.926306+00', '2020-09-14 15:46:13.886093+00', 11198, 1, NULL, 'ace', '1–::

  1c+2c set | ½ RHA ; Set, 2c cross LH and 1c turn LH to face 1cnr

9–::

  SetH&G , finish facing 3cnr

17–::

  ½Reel4 on 1diag, pass Rsh to face 4cnr ; ½Reel4 on 2diag, finish (3x,1,2x)

25–::

  Diagonal ½R&L with 1cnrs ; repeat with 2cnrs', 2);
INSERT INTO 'dancecrib' VALUES (13714, '2021-02-28 01:18:16.425342+00', '2021-02-28 01:25:31.759441+00', 4152, 1, 202, 'ace', '1--::

  1c & 4c turn P BH | 1c & 4c cast inwards (2c & 3c step out) (to 2,1,4,3) ; all A&R {1+1} | 1c & 4c turn P BH ½ _while{2}_ 2c & 3c turn P LH into Reel4 position. 2W & 3M face out (2,1x,4x,3)

9--::

  Parallel Reels4 on sides (2,1x,4x,3)

17--::

  1c+4c Circle4 L ½ _while{2}_ 2c & 3c turn P BH all opening into | Circle8 L ½ (to 3x,1x,4x,2x) | all cross RH (3,1,4,2)

25--::

  3c+1c & 4c+2c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (10470, '2018-02-27 20:04:04.635815+00', '2021-04-28 23:30:52.145146+00', 5037, 1, 202, 'ace', '1--::

  Circle8 and back

9--::

  All Petronella in tandem 1 place clw (2,3,4,1) ; 1c+3c ½ R&L, finish facing cnrs (2,1,4,3)

17--::

  Interlocking Reels4, Rsh to cnrs (2,1,4,3)

25--::

  All set | 1c & 3c cast, M leading chase clw ¾ _while{6}_  2c+4c 1 ¼ RHA (1,2,3,4)

33--::

  All Petronella in tandem 1 place clw (2,3,4,1) ; 2c+4c ½ R&L, finish facing cnrs (4,3,2,1)

41--::

  Interlocking Reels4, Rsh to cnrs (4,3,2,1)

49--::

  All set | 4c & 2c cast, M leading chase clw ¾ _while{6}_  3c+1c 1 ¼ RHA (1,2,3,4)

57--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (2939, '2012-01-22 19:30:03.754322+00', '2021-04-30 10:36:57.205823+00', 4968, 1, NULL, 'ace', '1–::

  1c turn RH, cast off (2c up) ; turn 1¼ LH to finish 1W/1M between 2c/3c

9–::

  Set twice in lines across, on [11-12] 1c petronella to opposite sidelines ; 2c+1c+3c set twice (2,1x,3)

17–::

  Reels3 on sidelines (Rsh to 2cnrs), 1c finish BtoB between 2c facing opposite side (no loops at the end)

25–::

  1c+2c Reel4 across, at end 1c meet as 2c curves down into

33–::

  1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13711, '2021-02-27 18:10:37.262133+00', '2021-02-28 20:29:15.560321+00', 2877, 2, 3069, 'ace', '1-2::	1st & 2nd C set advance to join RHA,
3-4:: 1st & 2nd C RHA 1/2 way
5-6:: 1st & 2nd C set
7-8:: 1st & 2nd C RH across to place
9-10::       1st C cross RH
11-12::	2nd C cross RH
13-14::	1st & 2nd C 4 hands round 4 slip steps left
15-16::	1st & 2nd C set, 1st C adv finish BTB facing 1st Crn
17-24::	1st C & 1st Crns dance diagonal Reel of 4, 1st pass RH at the end
25-30::	1st W with 2nd C & 1st M with 3rd C Rsh Reels of 3 across the dance,         1st & 2nd W and 1st & 3rd M pass Rsh.
31-32::	1st C cross RH into 2nd place.', 3);
INSERT INTO 'dancecrib' VALUES (13717, '2021-02-28 08:19:55.786671+00', '2021-02-28 16:15:21.782856+00', 10279, 1, 202, 'ace', '1--::
  1M+2M & 1W+2W turn RH on Mside, LH on Wside ½ into DTr position (2c up) | 6 bars of DTr. 1c face 1cnrs
9--::
  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag. 1c in promhold face 2W
17--::
  Reel3 across, 1c RSh to 2W. 2c finish in 2plx, 1c finish facing 3cnrs[pos] (1M face 2W, 1W face 4W)
25--::
  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag (3x,4x,1,2)
33--::
  3c+4c & 1c+2c set in pairs | RHA ½ (to 4,3,2x,1x) ; 4c+3c+2c ½ Reels3 on sides taking hands where possible, 2c crossing up, 3c out and down, 4c in and down _while{4}_ 1c turn P RH ½, face P and cast R to exchanged places (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (3444, '2012-01-22 19:30:25.784482+00', '2020-12-24 10:11:51.228287+00', 10534, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c S&Link ; Circle4 L (2,1,4,3,5)

9–::

  »5c Eddy«:  All NHJ advance 2 | Retire {1} and set L {1} ; all cross Rsh and curve R | 2c+4c+5c return to their new places _while_ 1c+3c finish between thse Cs facing 1cnr

17–::

  2c+1W & 5c+3M Rsh Reels3 across _while{8}_ 1M+4c+3W Reel4 across, 1c+3c finish facing 1cnr on 1diag.

25–::

  1cnrs pass and turn ; pass Rsh ; 2cnrs pass and turn (2,1,4,3,5)

33–::

  1c+4c & 3c+5c »Tourbillon«  (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (2694, '2012-01-22 19:29:53.397094+00', '2020-09-13 22:20:53.115335+00', 11001, 1, NULL, 'ace', '1–::

  1c cast off two and dance up the middle _while{6}_ 3c dance up the middle and cast off two | all set (1,2,3)

9–::

  2c ½ Fig8 round 1c ; 2c ½ Fig8 round 3c, 1c step in for

17–::

  1c+2c Poussette (2,1,3)

25–::

  All Circle6 and back.', 3);
INSERT INTO 'dancecrib' VALUES (12841, '2020-05-20 17:02:24.493278+00', '2021-04-07 11:10:23.459354+00', 5324, 2, 116, 'ace', '01-08::

  1C & 3C cross over RH, cast off 1 place; then they dance a half figure of 8 "up" (2C & 4C step up on bars 3 & 4).



09-16::

  1C & 4C (middles) dance RH across once round; then 1C cast off 1 place while 4C lead up 1 place and all set.



17-24::

  2C & 4C and 1C & 3C dance LH across once round; then 2C & 1C cast off 1 place while 4C & 3C lead up 1 place and all set.



25-32::

  2C & 3C (middles) dance RH across once round; then 2C cast off 1 place while 3C lead up 1 place and all set (top 3 couples set advancing).



33-40::

  4C & 3C & 2C allemande.', 4);
INSERT INTO 'dancecrib' VALUES (13477, '2020-12-26 03:31:28.968045+00', '2020-12-26 03:59:28.674697+00', 10714, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; cross LH (2,1,3)
9--::
  1c+1cnrs dance BtoB ; 1c+2cnrs dance BtoB (2,1,3)
17--::
  1c ½ Fig8 down between 3c ; ½ Fig8 up between 2c (2,1,3)
25--::
  All dance BtoB ; all turn P LH

*Deviser''s note:  
An 8 bar reel of three, on the sides, may be substituted in the 1/2 figures of eight, bars 17-24.*', 2);
INSERT INTO 'dancecrib' VALUES (14941, '2022-07-05 15:35:15.527048+00', '2022-07-05 15:35:53.24748+00', 20782, 2, 1, 'ace', '1–::
  1c+2+3c dance Inveran Reels3
9–::
  1c set | dance between 2c ; dance behind 3c | lead up to 1crnrs
17–::
  1c dance round 1crnrs RH | turn RH 1½ [to 2crnrs]  
  _while_ 1crnrs cross to diag opp pl RH ; ½ chase cw to orig pl [4 bars]; S diag
25–:: R 17–24 w/2rnrs [1c fin in 2pl own sides]', 3);
INSERT INTO 'dancecrib' VALUES (2344, '2012-01-22 19:29:32.342162+00', '2020-12-25 10:46:33.405313+00', 11217, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; 1c+3c ½ R&L (2,3x,1x)

9–::

  2c set | cast off (3c up) ; 2c+1c ½ R&L (3x,1,2x)

17–::

  1c lead down the middle and up, to 2pl in promhold facing up, 3c+2c stepping in into promhold facing down

25–::

  »Circulating Allemande« (each C dances as if in a 3c Allemande, starting in the direction they face) (2x,1,3x)

33–::

  1c ½Fig8 up _while{4}_ 2c set & cross RH ; 1c ½Fig8 down _while{4}_ 3c set & cross RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13478, '2020-12-26 23:08:06.909512+00', '2021-11-15 14:19:13.176718+00', 20197, 2, 963, 'ace', '1-4::
  1c long cast thru 2nd place to face 1st crnrs  
5-16::  
  2s,1s,3s dance ''dance to corner and set''; 1s finish facing 3rd crn positions 3x,1,2x
17-24::  
  R3 on the side; 1s Rsh to 3rd crn position; 1s finish facing out  3x,1,2x
25-28::
  3s&2s dance RHA WHILE 1s dance cw to 2nd plc opp side
29-32::
  3s,1s,2s, passing prtn by the right, cross to own sides; all set   3,1,2

  ', 5);
INSERT INTO 'dancecrib' VALUES (13578, '2021-01-23 22:47:30.470088+00', '2021-01-24 05:20:11.228098+00', 12131, 1, 202, 'ace', '1--::

  Circle6 and back (1,2,3)

9--::

  1c dance down | cast up round 2c to 1pl centre. On [12] 2c step in ready for ; 1c+2c ½ Poussette. 1c in 2pl centre face down (2,1,3)

17--::

  1c dance down | cast up round 3c to 2pl centre. On [20] 3c step in ready for ; 1c+3c ½ Poussette (2,3,1)

25--::

  1c turn P RH | cast up (3c down) ; 1c dance up between 2c | cast off (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13226, '2020-10-08 16:32:28.313203+00', '2020-10-08 16:35:58.771001+00', 20097, 1, 202, 'ace', '1--::

    2W sets to 1M | A&R diagonally | sets _while{8}_ 1M A&R diagonally to 2W ; sets | casts off (2M up)

9--::

  2M sets to 1W | A&R | sets _while{8}_ 1W A&R ; sets | casts off (2W up) (2,1,3)

17--::

  1c+3c DblFig8, 1c crossing down (2,1,3)

25--::

  Mirror Reels3 on sides, 1c in and up, 2c out and down (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13583, '2021-01-27 04:25:08.691716+00', '2021-01-27 07:18:35.990502+00', 9552, 1, 202, 'ace', '1--::
  1c set advancing | turn BH ½ opening to face down NHJ ; dance to 2pl centre (2c up) | turn BH ½ opening to face down NHJ (2,1,3)
9--::
  Mirror Reels3 on sides, 1c in and down, 3c up and out, 2c may cast, all taking hands where possible (2,1,3)
17--::
  »Circulating A&R« [: Taking hands, all advance {1}, 2c & 3c retire pivoting to face each other on sides _while_ 1c retire ¼ L between ends (1M between 2c, 1W between 3c) {1} |  repeat [17-18] 2c & 3c facing P and 1c retiring to 2plx ; repeat [17-20] 1c progressing clw] (2,1,3)
25--::
  Circle6 L {6} | all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1644, '2012-01-22 19:28:52.709782+00', '2020-12-27 16:57:59.548152+00', 93, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; Petronella Turn (1M up, 1W down) into facing lines across | all set.

9–::

  The lines A&R up/down ; 1c Petronella Turn to 2pl | all set (2,1,3)

17–::

  Reels3 on own sides, 1c start Rsh to 4cnr, 2c+3c finish with loops, 1c finish between end couples facing 4cnr,

25–::

  Reels3{6} across, 1c start Rsh to 4cnr | 1c cross RH to 2pl', 3);
INSERT INTO 'dancecrib' VALUES (9503, '2016-11-25 14:26:01.971421+00', '2020-12-27 18:47:24.744001+00', 128, 2, NULL, 'ace', '1-4:: Set to partner | Petronella Turn (W BtoB in the middle)

5-12:: Double Reel4, with ½ LHA in the middle

13-16:: Turn 1 ¼ RH to pl

16-24:: All S&Link ; All S&Link with next person (M have moved 1pl cclw and face out, W have moved 1pl clw and face in)

25-28:: ½ Double LChain, with 1/2 RHA in the middle

29-32:: ½ G-Chain no hands, starting Lsh to partner (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (13977, '2021-05-01 07:53:16.772987+00', '2021-05-01 13:11:09.399157+00', 20325, 1, 202, 'ace', '1--::
  Circle8 and back
9--::
  1c dance out (no cast) behind 2c and wave on sides to bottom, cross RH ; cast up round 4c and wave on sides to 1plx, cross RH (1,2,3,4)
17--::
  1c(+2c+3c+4c following) dance behind own lines to 4pl and make an arch ; 2c+3c+4c dance up under the arch and stay in centre. 2c & 4c NHJ face down _while_ 3c & 1c NHJ face up (2,3,4,1)
25--::
  2c & 4c dance down under arches made by 3c & 1c who dance up {1} (to 3,2,1,4]. New ends turn inwards and face the other way _while_ 1c dance up under arch made by 2c who dance down {1} (to 3,1,2,4) | repeat same pattern [25-26] three times, all couples dancing or turning inwards (ends) with arches made alternatively on each bar (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (13718, '2021-02-28 12:59:54.020486+00', '2021-02-28 13:06:25.013307+00', 2877, 1, 202, 'ace', '1--::

  1c+2c set advancing into RHA position | RHA ½ ; set RHJ | RHA ½ (1,2,3)

9--::

  1c cross RH | 2c cross RH ; Circle4 L ½  (to 2,1,3) | 2c & 1c set, 1c advancing to face 1cnrs

17--::

  Reel4 on 1diag. On [24] 1c pass P RSh

25--::

  Reels3 across {6}, 1c RSh to 4cnrs | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1863, '2012-01-22 19:29:06.732058+00', '2020-10-09 18:08:22.603771+00', 888, 1, NULL, 'ace', '1–::

  mirror Reels3 on own sides, 1c starting in and down

9–::

  mirror Reels3 on opposite sides (1c cross down) finish (2,1x,3) with 1c BtoB facing opposite sides

17–::

  DTr, 1c finish in 2plx facing down NHJ

25–::

  1c dance down the middle ; change sides (W twirl under M''s arm) and dance up to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2793, '2012-01-22 19:29:57.624343+00', '2020-12-24 10:15:20.510062+00', 10565, 1, NULL, 'ace', '1–::

  1c ½ Fig8 down round 2c ; 1c cross down between 2c (step up on 5-6) | 1W+3W turn LH _while{2}_ 1M+3M turn RH (to 2,1,3)

9–::

  1M+3c & 1W+2c Reels3 across (Lsh to 1cnr), finish passing P Lsh to face out to the opposite side ready for .

17–::

  DTr for 6 bars | 1c retain hold of 2c''s hands and make half turn to finish with 1c in 1pl facing in and down and 2c in 2pl facing out and up.

25–::

  Crossing Reels3: all C crossing from top and bottom. 1s cross down and 3s cross up to start.

33–::

  1c cross RH, cast off one (2c up) ; ½ Fig8 up round 2c

', 2);
INSERT INTO 'dancecrib' VALUES (3488, '2012-01-22 19:30:27.548314+00', '2020-12-24 18:02:25.492007+00', 10791, 1, NULL, 'ace', '1–::

  1c+2c+3c Rsh Reels3 on the sides, 1c finish facing W side

9–::

  1W (1M following) cast behind 2W, cross, cast behind 3M, then 1W crosses and casts up round 3W _while_ 1M dances up round 3M (2c up), (to 2,1,3)

17–::

  1c Fig8 across, Rsh to 2cnr (M up, W down)

25–::

  2c+1c R&L



{{explanation}}

After 1st turn, 1W may omit the polite turn to flow straight into the reel  

', 3);
INSERT INTO 'dancecrib' VALUES (2471, '2012-01-22 19:29:40.772295+00', '2020-12-25 11:00:21.30063+00', 11365, 1, NULL, 'ace', '1–::

  1c+3c lead down (2c+4c up) ; and up to face cnrs

9–::

  1c+3c with 1cnrs »cnrs pass and turn«, swivel R to face 4cnr ; repeat with 4cnrs, dancing C finish BtoB facing out own side

17–::

  2c+4c+5c 8 bars of Petronella _while{8}_ 1c+3c dance out, cast R, cross between setting Cs, cast R to finish (2x,1x,4x,3x,5x) all setting on [23-24]

25–::

  2c turn ½ RH _while{2}_ 1c+4c & 3c+5c ½ RHA | All set ; All C turn RH (or birl) 2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (2376, '2012-01-22 19:29:34.232139+00', '2020-12-26 09:56:17.543459+00', 13751, 1, NULL, 'ace', '1–::

  1c dance down (2c up) | set to P ; cast Rsh round 4cnr and P to face 1cnr with Rsh to P

9–::

  Dance to each cnr and set {6} (centre and cnr change place Rsh, these cnrs pass Rsh in the middle to face cnr to the R _while{2}_ the other cnrs set | repeat 2 times) | 1c turn RH to face 2cnr position (2c is now on M side, 3c on W side, the W in 1pl, the M in 3pl)

17–::

  ½ Reel4 on 2diag, 1c pass Lsh to face 1cnr ; ½ Reel4 on 1diag, 1c pass Rsh to face 2cnr

25–::

  Dance to each corner and set {6} | 1c turn RH to 2pl and face out (2,1,3)

33–::

  1c dance Lsh round 2cnr, meet in middle in 2pl, own side, facing P ; Set | dance down and loop into 3pl (3c up) (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (2888, '2012-01-22 19:30:01.665435+00', '2020-12-29 11:50:04.112406+00', 11529, 1, NULL, 'ace', '1–::

  1c+3c cast off (2c+4c up) | 1c+3c 1½ LHA to face (3c above, 1c below) 1cnrs (1M-5W, 1W-4M, 3M-4W, 3W-2M)

9–::

  1c & 3c ½ Diag. Reel4 with 1cnrs ; repeat with 2cnrs

17–::

  Repeat with 3cnrs, all to own side ; all set & cross RH (5x,3x,4x,1x,2x)

25–::

  5c+3c & 4c+1c S&Link ; RHA (3x,5x,1x,4x,2x)

33–::

  All dance 5c S&Link twice: as 3c S&Link, but two C on left pass inside _while_ the other 3 cast & chase (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (10264, '2017-11-20 15:20:21.225632+00', '2020-12-28 11:14:26.86764+00', 17666, 2, 645, 'ace', '*3c & 4c start from opposite sides, 1,2,3x,4x*



1–8::

  1c & 4c Turn R{2} |  1c Cast off & 4c Cast up (2c StepUp, 3c StepDwn) ; 1c & 4c Turn L{4},  M lead and face 1st corners

9–16::

  1c+2M & 4c+3M RA, M lead and face 2nd corners ; 1c+3W & 4c+2W LA, M lead and face 1st corners

17::

  1c Set RF to 2M, 4c Set RF to 3M

18::

  1c & 4c  Set LF to partner

19::

  1M Set RF to 4W, 4M Set RF to 1W

20::

  1M+4W Set LF to 3W, 4M+1W Set LF to 2W

21::

  1M+4W Set RF to 3W, 4M+1W Set RF to 2W

22::

  1M Set LF to 4W, 4M Set LF to 1W

23::

  1c & 4c  Set RF to partner

24::

  1c Set LF to 2M, 4c Set LF to 3M

25-32::

  Reel3 on the sides{8} 1c(prom)+2M+3W & 4c(prom)+3M+2W  (1M at 2M’s place, 1W at 3M’s , 4M at 3W’s, 4W at 2W’s)

33-40::

  1M+4W & 1W+4M XR | 1W Cast off 1-Across the set- Cast up 1, 1M Cast off 2-Dance up 1, 4M Cast up 2-Dance down 1, 4W Cast up 1-Across the set- Cast off 1 (2,4,1x,3x)', 0);
INSERT INTO 'dancecrib' VALUES (13480, '2020-12-28 19:46:28.623139+00', '2020-12-28 19:52:33.550312+00', 16800, 1, 1645, 'ace', '*For nine dancers arranged in three lines in a square with 5 facing down & the rest facing in to start.*  

*7..8..9*  

*4..5..6*  

*1..2..3*

1-::

  Dancers 1+5+9 Reel3 on 2nd diagonal, 5 starting RSh to 9 _while{8}_ 3+2+6 & 7+8+4 RHA ; LHA

9-::

  Dancers 3+5+7 Reel3 on 1st diagonal, 5 starting LSh to 7 _while{8}_ 1+4+2 & 9+6+8 RHA ; LHA

17-::

  Dancers 1+2+3, 4+5+6 & 7+8+9 Reels3 across. 2, 5, & 8 start RSh to 3, 6 & 9. End with 1, 2 & 3 facing down to 4, 5 & 6

25-::

  1, 2 & 3 dance BtoB with 4, 5 & 6 ; change places RH | 1, 2 & 3 change places LH with 7, 8 & 9 (4,5,6,7,8,9,1,2,3). *Repeat twice to original places*



', 2);
INSERT INTO 'dancecrib' VALUES (2822, '2012-01-22 19:29:58.848261+00', '2020-12-29 11:38:33.588494+00', 4544, 1, NULL, 'ace', '1–::

  1W+3M change places RH and set _while{4}_ 1M+3W set and change places RH ; 3c+1c RHA finishing facing out (3x,2,1x)

9–::

  Reels3{6} on the sides, 2c start in and R | 3c & 1c cast to meet on opposite sidelines NHJ _while{2}_ 2W dances to middle of 1pl facing up and 2M to middle of 3pl facing down

17–::

  3M+1M & 3W+1W set and petronella in tandem _while{4}_ 2c cast R to 2pl ; 3M+1M & 3W+1W set and petronella in tandem _while{4}_ 2c cross RH and cast R to finish on midline, 2W at top, 2M at bottom

25–::

  1c+3c set _while{2}_ 2c meet, 2M pivoting R, to face down in 2pl RHJ on own side | 2c followed by 1c lead down through 3pl, cross and cast up to 1plx and 2plx _while{4}_ 3c dance up the sidelines and lead down to 3pl | 2c+1c cross RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (13587, '2021-01-27 15:20:11.740267+00', '2021-08-10 18:18:49.510052+00', 15768, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; ½ Fig8 up round 2c (2,1x,3)

9--::

  All set | cross RH ; repeat [5-12] (2,1x,3)

17--::

  All chase clw ½ ; all dance BtoB (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2977, '2012-01-22 19:30:05.349951+00', '2020-10-10 00:01:04.898836+00', 5136, 1, NULL, 'ace', '1–::

  1c set | cast off one (2c up) ; dance between 3c and cast up to 2pl

9–::

  2c+1c ½RHA | ½ RH turn ; 1c+2c ½LHA | turn LH, 2c to 1pl and 1c to face 1cnrs

17–::

  1c set to and turn corners

25–::

  Reels3 with the corners, (Lsh to 1cnr) | 1c cross', 2);
INSERT INTO 'dancecrib' VALUES (13584, '2021-01-27 09:21:16.465538+00', '2021-01-27 09:32:29.621991+00', 11683, 1, 202, 'ace', '1--::

  1c-2c The Espagnole. 1c face 1cnrs

9--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag. 1c face 3cnrs[pos]

17--::

  SetH&G. 1c face 1cnrs[pos]

25--::

  1c turn CPCP _while{8}_ 1cnrs[pos] turn 1c RH | 3c & 2c cross RH ; 2cnrs[pos] turn 1c RH | 3c+2c change places on sides (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13720, '2021-02-28 14:01:34.413495+00', '2021-02-28 16:38:05.198456+00', 10278, 1, 202, 'ace', '1--::
  Reels3 on opposite sides (1x,2,3)
9--::
  Reels3 on own sides (1,2,3)
17--::
  1c slip down | set to P ; slip up | set into promhold. [23-24] 2c step in (PdB) into promhold
25--::
  1c+2c Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13585, '2021-01-27 09:54:35.91501+00', '2021-01-27 10:01:24.080866+00', 11682, 1, 202, 'ace', '1--::

  1c set | turn P RH ½, face P ; cast R to exchanged places | cast off (2c up) (2,1x,3)

9--::

  1c set | Petronella turn ; repeat [9-12] (2,1,3)

17--::

  1c ½ Fig8 R round 1cnrs (to 2,1x,3) ; 1c cross RH | 2c+1c+3c BiL (2,1,3)

25--::

  Reels3 across, 1c retaing hands with 4cnrs to enter the reel. On [31-32] 1c pass RSh to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3094, '2012-01-22 19:30:11.009+00', '2020-12-24 10:17:58.339893+00', 10570, 1, NULL, 'ace', '{{explanation}}

Two rows (1,2x,3,4x) alongside (5,6x,7,8x) together form a 4 x 4 chessboard-patterned-set; all C face P  

All setting is Shetland backsteps, two steps per bar; all travelling is Highland style.



1–::

  All M kneel and clap _while{4}_ all W set ; W kneel and clap _while{4}_ the M set

9–::

  All pass P Rsh and face P| set {2} ; repeat

17–::

  All dance round P Rsh twice

25–::

  In each of the four »sub-squares« circle4 L 2½ times round, finish line facing line up/down (i.e. at right angles, side by side with P)

33-56::

  Repeat 1-24 from new positions and orientation

57–::

  The 12 »outers« circle12 L once round _while{8}_ the 4 »inners« circle4 R twice round.



{{explanation}}

End facing public and bow / curtsey  ', 3);
INSERT INTO 'dancecrib' VALUES (2493, '2012-01-22 19:29:44.960237+00', '2020-12-24 18:07:14.251063+00', 10792, 1, NULL, 'ace', '{{explanation}}

On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)



1–::

  1c+4c turn RH | cast to middle (2c & 3c step to end) ; 1c+4c ½ Fig8 round end couple (2,1x,4,3x)

9–::

  1W+4M & 1M+4W, in promhold (W on the L) ½Reels3 across with the end C on their R (Lsh to 2M & 3M) ; continue into ½ Lsh Reels3 with the other end couple (to 2,1x,4,3x)

17–::

  2W+1W & 4W+3W turn RH ½ to face each other, twirl R and dance to exchanged places _while{4}_ 2M+1M & 4M+3M dance clw round them to exchanged places ; 1M+2M & 3M+4M turn RH ½ to face each other | twirl R and dance to exchanged places _while{4}_ 1W+2W & 3W+4W dance clw round them to exchanged places (2,1x,4,3x)

25–::

  1c+4c S&Link ; circle4 L (to 2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (2046, '2012-01-22 19:29:16.84064+00', '2021-03-20 13:03:49.14191+00', 8344, 1, NULL, 'ace', '1–::

  All set | Turn P BH ½ opening for 1M, 2W, 3M & 4W to lead P 1 place clw (1c+3c to W side, 2c+4c to M side) ; all set | 1W+3W cast down 1 place _while_{2} 2M & 4M cast up 1 place as others cross to own side to face partner. (2,1,4,3)

9–::

  All set | 2c+3c cross RH _while_{2} 1c+4c ½ RHA ; all change places LH on side | end couples cross RH _while_{2} middle couples ½ RHA (to 4,3,2,1, end C facing middle couples)

17–::

  All turn facing person LH | set advancing passing Lsh ; 1c+4c (centre couples) turn facing person RH | set advancing passing Lsh (3,1,4,2)

25–::

  3c+1c & 4c+2c circle4 L, all dancing in to face P on the midline (W facing up & M down) ; all set | petronella turn to sides. (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (13481, '2020-12-28 20:22:43.079047+00', '2020-12-28 20:23:58.55055+00', 16791, 1, 1645, 'ace', '1-::

  All set | cross RH ; set | cross back RH ready for

9-::

  1c+2c+3c Promenade

17-32::

  W dance *Modified Sheepskin Hey* round standing M:  

  1W followed by 2W+3W cross over, behind 1M & in front of 2M.  

  1W+2W loop LSh round 3M but 3W loops RSh round 2M & takes the lead.  

  3W followed by 1W+2W dance up behind 2M, 3W+1W loop LSh round 1M but 2W loops RSh round 2M & takes the lead.  

  2W followed by 3W+1W dance down in front of 2M, behind 3M, cross over and dance up own side, ending (2,3,1) on W side.

33-48::

  M repeat mirror image of [17-32] round W (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (3010, '2012-01-22 19:30:06.772541+00', '2020-12-29 11:40:53.682626+00', 5237, 1, NULL, 'ace', '1–::

  1W+2M advance & take RH | 1W dances under R arm _while_ 2M moves forward and back ; turn RH

9–::

  1M+2W repeat

17–::

  1c+2c RHA ; set all facing diagonally | 1c cast _while{2}_ 2c dance up and face out

25–::

  2c+1c DblFig8 (1c cross up)', 2);
INSERT INTO 'dancecrib' VALUES (12891, '2020-06-21 13:50:21.670205+00', '2020-12-29 11:51:16.544022+00', 17664, 1, 202, 'ace', '1--::

  1c set | A&R[1+1] ; 1c+2c change places EH, 1c in | 1c+3c repeat (2,3,1)

9--::

  Mirror Reels3 on sides, 1c in and up, 3c out and down. On [16] 3c continue to 3pl _while_ 1c cross over to face 1cnrs

17--::

  1c turn 1cnrs RH into facing lines3 across | all set ; 1c turn P LH to face 4cnrs[pos] _while{4}_ cnrs change places RSh on sides | cross LSh with P (3x,*1*,2x)

25--::

  1c turn 4cnrs[pos] RH into (3x,1,2x) | all set ; 1c turn P RH _while{4}_ 3c+2c ½ R&L (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (14763, '2022-04-17 10:32:36.650643+00', '2022-04-17 10:47:17.119587+00', 12630, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c ½ R&L (to 2x,1x,4x,3x) ; 1W+2M & 3W+4M change places RH |1M+2W & 3M+4W change places LH into Reel4 position (1,2,3,4)

9--::

  Reels4 on sides (1,2,3,4)

17--::

  1c set | cast off (2cup) ; 1c+3c Circle4 L (2,1,3,4)

25--::

  1c dance down between 3c | separate and cast round 4c to 4pl (3c+4c up) ; all turn P RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13373, '2020-11-12 11:13:57.248591+00', '2020-11-28 11:03:35.041645+00', 19899, 2, 1645, 'ace', '1-8::

  All couples set and link twice (the “crown” of the virus)

9-16::

  1M followed by 1W chase toward 4th position; on bar 11 the 1s dance into 4th position as 4th man followed by 4th woman chase towards 3rd position; on bar 13 the 4th couple dance into 3rd position as 3rd man followed by 3rd woman chase towards 2nd position; on bar 15 3rd couple dance into 2nd position as 2nd man dances towards 1st position and loops in and 2nd woman dances to 1st womans place. On bar 16 all men dance in and finish back to back in the center. The Shape is that of a progressive schiehallion. (The spreading) .

17-22::

  Men dance six bars setting as in crown triangles (no hands), while W set, petronella turn to the right, set

23-24::

  All petronella turn changing place with own partner to finish Women, back to back in the center facing their partners.

25-30::

  Repeat bars 17-22

31-32::

  2M, 3M, 4M set while 2W, 3W 4W petronella turn to the side and 1s set curving left to finish inside the set, hands joined (The Development) 4 1 2 3.

33-40::

  1s dance all around one couple poussette (The quarantine).

41-48::

  All circle (no hands) to the left, pivot and circle back giving hands to new places (Back to Normal).

::

  *Crib prepared by the deviser*

', 2);
INSERT INTO 'dancecrib' VALUES (13715, '2021-02-28 01:36:01.87304+00', '2021-02-28 01:52:55.22008+00', 4760, 1, 202, 'ace', '1--::

  1c cross down RH to 2pl centre, BtoB facing opposite sides (2c up) _while_ 3c set | all set as in DTr ; 1c pivot R to face P (PdB) | 1c turn LH to face 2cnrs

9--::

  Reels3 across, 1c LSh to 2cnrs. 1c pass P RSh to face 1cnrs

17--::

  Reels3 across, 1c RSh to 1cnrs into BiL position with 1cnrs

25--::

  BiL on 1diag | 1c turn LH (PdB) into BiL position with 2cnrs ; BiL on 2diag | 1c turn LH to 2pl (2,1,3)



*Deviser''s note:  

At finish of second measure (bars 29-32), the leading couple, left hands held, turn each approximately a quarter turn to arrive facing down, woman on man''s left. They cross right hand into promenade position and dance down to bottom place.*', 2);
INSERT INTO 'dancecrib' VALUES (13721, '2021-02-28 19:35:58.40714+00', '2021-02-28 19:45:55.515168+00', 20181, 1, 202, 'ace', '1--::
  1M & 2W clap and dance RSh round P to exchanged places ; 1c+2c RHA 
9--::
  1M & 2M clap and dance LSh round P to exchanged places ; 1c+2c LHA (2,1,3)
17--::
  2c+1c ½ R&L (to 1,2,3) ; 1c cross RH | cast off (2c up) (2,1x,3)
25--::
  Reel3 on sides {6}, 1c in and down, 3c out and up | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13586, '2021-01-27 10:53:41.128101+00', '2021-01-28 12:25:07.573824+00', 11686, 1, 202, 'ace', '1--::
  1c lead down {3}, lead up {3} | cast off (2c up) and face 1cnrs (2,1,3)
9--::
  1c turn 1cnrs BH | turn P RH ; turn 2cnrs BH | turn P RH to 2pl (2,1,3)
17--::
  1c set | 2c+1c ½ RHA (to 1x,2x,3) ; 1c+2c ½ R&L (2,1,3)
25--::
  1c set | 1c+3c ½ RHA (to 2,3x,1x) ; 3c+1c ½ R&L (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (1854, '2012-01-22 19:29:06.206381+00', '2021-03-20 19:36:56.788198+00', 8331, 1, NULL, 'ace', '1–::

  1c+2c the Tourbillon, but 1c end facing 1st corners. (Tourbillon: 1c+2c turn P BH ½, opening out to one place clw in the square (1c to W side, 2c to M side) | 1c set to 2c ; repeat figure (to 2x,1x) | 2c+1c cross RH (to 2,1))

9–::

  Turn CPCP (to 2,1,3)

17–::

  2c+1c+3c Bubble Up: (i.e. 2c (in top place) cast off 2 places _while_{2} 1c+3c ½ RH turn moving up one place {2}, repeat from new places 3 times (end: 1x,3x,2)

25–::

  1c+3c S&Link _while_{4} 2c set and cross RH ; 3c+1c+2c set | 3c+1c+2c half circle6 L (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3332, '2012-01-22 19:30:20.889847+00', '2020-12-24 18:14:18.249804+00', 10817, 1, NULL, 'ace', '1–::

  1c set advancing and pass to BtoB (2c up) | 2W+1M turn LH _while{2}_ 1W+2M turn RH ; 1c turn LH to promhold and dance to 4pl (3c+4c up on [7-8]), end turning out to BtoB on sidelines (2,3,4,1x)

9–::

  ½ Mirror reels4 on sidelines, (1c+3c up and out), all give hand to P on inner loops ; 1c turn BH 1½ (to 1,4,3,2)

17–::

  All C set | cross RH ; 1c+4c ½ RHA into | 1c+3c ½ LHA into

25–::

  1c+2c full RHA ; 1c+2c turn BH 1½ (to 4,3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (3700, '2013-02-06 11:28:50.067771+00', '2020-12-25 12:08:06.486656+00', 11795, 1, NULL, 'ace', '1–::

  1c petronella in Sk-Change to midline and set _while_{4} 2c cast up and cross RH ; RHA, 2c faces out

9-12::

  1c petronella in Sk-Change to 1plx and set  _while_{4} 2c casts cclw to midline to face P and crosses LH up/down

13-16::

  1c+2c LHA, at the end 1c (in 1plx) loop R to face in _while_ 2c turn to face 1c in line across

17–::

  ½ Reel4 across ; 1M+2M & 1W+2W turn RH to (2,1)

25–::

  Circle4 and back (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (2120, '2012-01-22 19:29:21.162982+00', '2020-12-26 10:04:53.188136+00', 14249, 1, NULL, 'ace', '1–::

  All set | turn ¾ RH ; repeat to promhold facing down

9–::

  4c followed by others cross over at bottom, cast up to top, dance down NHJ

17–::

  Mirror Reels4 (2c+4c start by casting up), join hands when meeting P (1,2,3,4)

25–::

  1c dance down the middle and curve out to end of lines _while{4}_ 2c+3c+4c retire {2}, step up {2} ; all advance to meet P, and curve out R to sideline (2,3,4,1).', 3);
INSERT INTO 'dancecrib' VALUES (13722, '2021-02-28 19:59:21.532065+00', '2021-03-01 15:46:27.113088+00', 20182, 1, 202, 'ace', '1--::

  1c (+2c who dance up to follow) lead down ; 2c (1c following) lead up to 1pl and face out. 1c stay in 2pl centre (2,1,3)

9--::

  2c+1c DblFig8, 1c crossing to 1plx (2,1,3)

17--::

  1c+3c set | RHA ½ (to 2,3x,1x) ; 3c+1c set | turn P RH ½ into allemande hold

25--::

  2C Allemande (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (13482, '2020-12-28 23:38:20.807976+00', '2020-12-28 23:38:34.133972+00', 17176, 1, 1645, 'ace', '1-::

  1c+2c & 3c+4c S&Link ; 2c+1c & 4c+3c Circle4 L (2,1,4,3)

9-::

  1c+4c Rose Progression (2,4,1,3)

17-::

  All LSh Reels4 on the sides

25-::

  All set | turn 1&frac12; BH | pass RSh back to own sides

33-::

  All circle8 &frac12; way to L, pivot ; chase back (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3118, '2012-01-22 19:30:12.042015+00', '2020-12-29 11:44:43.300036+00', 5605, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; 1c turn 3c EH into line4 across in 2pl, 1c in the middle (3c with polite turn)

9–::

  In line4 dance down the middle, 2c following NHJ, on [12] 1c turn in and face up, 2c splitting and making line4 across ; in line4 dance up, 3c following NHJ finish (1x,2,3) with 1c+3c facing out

17–::

  Mirror Reels3{6} on the sides, 2c start in and up, join hands when possible | 1c cast off _while_ 2c dance up and face down _while_ 3c dance down and face up (2,1x,3)

25–::

  1c cross RH _while_ 2c+3c set | Circle6 L, dancing in on [30] | pivotR and chase back to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (14942, '2022-07-05 15:42:54.919285+00', '2022-07-05 15:42:54.919285+00', 20789, 2, 1, 'ace', '1–4::
  3c (followed by 1c) dance down below 4c and cast up [3c fin in 1pl, 1c in 3pl]
5–8::
  All turn RH [3c&1c fin facing down, 2c&4c up, w/NH joined]
9–::
  All S twice ; middle couples cast to end pls _while_ end couples dance to middle pls | all S [on sides]
17–::
  2c+3c & 4c+1c Rights and Lefts
25–::
  2c+3c & 4c+1c dance Double Figs8 [end couples cast to begin, middle couples cross] [to 2341]', 3);
INSERT INTO 'dancecrib' VALUES (14066, '2021-06-13 22:52:40.967426+00', '2021-06-20 21:26:28.79136+00', 6971, 1, 1645, 'ace', '1-4::

  1c & 3c set adv to centre (M above W) | 1c+3c BiL, 2c face clw

5-12::

  All dance Weasel Reel up/down: RSh Reel4 on midline (M down, W up), on reaching ends

  pass RSh, chase &frac12; way clw on opposite side & rejoin reel, finish in starting place

13-16::

  1c+3c BiL | turn P RH, 3c to sides, 1c stay in centre, 2c step in for

17-::

  1c+2c Allemande (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13713, '2021-02-27 18:39:01.98806+00', '2021-02-28 20:25:04.415172+00', 4760, 2, 3069, 'ace', '1-2::	1st C cross RH to btb in 2nd place facing opposite sides
	2nd C dance up to 1st place
	3rd C set in place

3-4::	1st,, 2nd & 3rd C set as in Double Triangles

5-8::	1st C set, pulling Rsh back, turn LH to opposite side facing 2nd Crn

9-16::	Reels of 3 across the dance, 1st M with 2nd C & 1st W with 3rd C. 2nd & 3rd C pass partner Rsh to begin. 1st C cross down into 2nd place opposite facing 1st Cnr

17-24::	Reels of 3 across the dance,1st W with 2nd C & 1st M with 3rd C. 2nd & 3rd C M pass partner Lsh to begin. 1st C with LH joined and RH with 1st Cnr, Balance in line.

25-32::	1st C balance in line with 1st Cnr, Adv 2 PDB, Balance in Line with 2nd Cnrs , turn LH to 2nd place own side.', 3);
INSERT INTO 'dancecrib' VALUES (13588, '2021-01-27 16:21:31.434345+00', '2021-01-27 16:22:46.010623+00', 12728, 1, 202, 'ace', '1--::
  1c set advancing | turn BH ; cast off (2c up) | cross LH (2,1x,3)
9--::
  Reels3 on sides, 1c LSh to 2cnrs. 1c face 1cnrs
17--::
  ½ Reel4 on 1diag, pass LSh ; ½ Reel4 on 2diag to 2plx (3x,1x,2x)
25--::
  3C S&Link twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13710, '2021-02-27 17:52:57.891033+00', '2021-02-28 20:23:02.097925+00', 4151, 2, 3069, 'ace', '1- 8:: 	   1st M with 2nd & 3rd W dance diagonal Reels of 3. 1st M & 2nd W pass Rsh

9-16::    1st W with 2nd & 3rd M dance diagonal Reels of 3. 1st W & 2nd M pass Lsh

17-22::	1st, 2nd & 3rd C Set, Cross RH, Set, taking nearer hands whilst setting

23-24::	1st C cast to face 1st Corner, 2nd C cross up RH to 1st place, 3rd C cross RH to place

25-32:: 1st C set to 1st Crn, turn Partner RH to face 2nd Crn, turn 2nd Crn LH, 1st C turn RH into 2nd place.
', 3);
INSERT INTO 'dancecrib' VALUES (13592, '2021-01-28 06:58:58.770884+00', '2021-01-28 07:06:57.795299+00', 4655, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c Circle4 R ; 1c & 4c cast inwards (2c & 3c step out) | 1c & 4c cross RH (2,1x,4x,3)

9--::

  1c & 4c set up/down _while{2}_ 2c & 3c cross RH (to 2x,1x,4x,3x) | 1c+4c ½ RHA _while{2}_ 2c & 3c set (to 2x,4,1,3x) ; 4c & 1c set up/down _while{2}_ 2c & 3c cross LH (to 2,4,1,3) | 1c+4c ½ LHA _while{2}_ 2c & 3c set (2,1x,4x,3)

17--::

  2c+1c+4c ½ Reels3 on sides, 1M RSh to 2cnrs[pos], 1W LSh to 2cnrs[pos] (to 4x,1x,2,3) ; 4c+1c ½ Circle4 L (1,4,2,3)

25--::

  All set | 2c+3c change places RH on sides ; ½ Reels4 (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13723, '2021-03-01 00:04:57.767077+00', '2021-03-01 01:05:26.054205+00', 20233, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; 1c pass P LSh | dance RSh round 1cnrs into facing lines3 across

9--::

  All set | turn 1cnrs RH ; set | turn 4cnrs LH to 2pl facing 3cnrs (2,1,3)

17--::

  Reel3 on sides, 1c RSh to 3cnrs (2,1,3)

25--::

  1c cast up to top, meet P and dance down to 3pl (3c up) ; 1c turn P BH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (13830, '2021-03-21 11:25:23.747921+00', '2021-03-21 11:32:09.401341+00', 1534, 1, 202, 'ace', '1--::

  1M+2W turn RH 1½ ; 1W+2M repeat (2x,1x,3)

9--::

  1M+3M turn RH 1½ ; 1W+3W repeat (2x,3x,1)

17--::

  3c+1c set | ½ RHA ( to 2x,1x,3) ; 2c+1c set | ½ RHA (1,2,3)

25--::

 1c+2c The Knot (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8288, '2014-06-23 14:00:43.34057+00', '2021-05-01 10:25:36.313778+00', 5013, 2, 1, 'ace', '1–10::

  Mirror reels of 5 on sides.

  (1c&3c start out and down, 5c out and up, 2c&4c in and up. 1c&3c fin facing out.)

11–12::

  1c&3c cast off (2c&4c up).

13–16::

  1c&3c dance ½ fig8 round 4c/5c (fin 21x43x5).

17–20::

  1c&3c dance ½ fig8 round 2c/4c (fin 21435).

21–30::

  Grand chain (1 step/hand – 2c cross RH at top, 1c+4c, 3c+5c cross R on sides).

31–40::

  1c&3c turn ¾ RH to 1st corners (join LH w/corners) | balance in line ; turn ¾ RH to 2nd corners

  (join LH w/corners) | balance in line | turn RH moving down (4c&5c up) to fin 24153.', 3);
INSERT INTO 'dancecrib' VALUES (13468, '2020-12-24 19:31:16.63317+00', '2020-12-24 19:31:33.483908+00', 20089, 1, 1645, 'ace', '1-::

  1c+3c &frac12; M-chain ; all dance BtoB on sides & face in

9-12::

  M adv{1} & set L _while{2}_ W set R & adv{1}, all end pulling LSh back to face corner |

  all turn corner &frac34; LH to promhold facing cclw

13-16::

  All promenade to next corner cclw (M in W places & vice versa) |

  M set R & adv{1} _while{2}_ W adv{1} & set L (2,3,4,1)

17-::

  All dance BtoB on sides ; 1c+3c &frac12; M-chain (2,3,4,1)

25-32::

  Interlocking reels of 4 (2,3,4,1)

', 5);
INSERT INTO 'dancecrib' VALUES (3072, '2012-01-22 19:30:09.471755+00', '2020-12-25 12:25:02.320188+00', 11885, 1, NULL, 'ace', '1–::

  1c+3c set | Petronella in tandem ; repeat  (to opp places)

9–::

  2c+4c (face P) Petronella turn into line across | set to P ; half Reel4 (to opp places)

17–::

  All M ½ LHA _while{2}_ all W set | the M promenade the opp W cclw one place ; repeat, finishing with the W in own place and the M BtoB in the middle facing the next W

25–::

  All set | dance one change of a Schiehallion Reel, finishing with the W BtoB in the middle facing own P ; all turn P RH 1¼  (in reel time this may be a swivel turn) (2,3,4,1)



{{explanation}}

The dance is repeated once more in strathspey and then twice in reel time', 2);
INSERT INTO 'dancecrib' VALUES (3449, '2012-01-22 19:30:25.976868+00', '2020-12-26 10:19:17.358081+00', 14352, 1, NULL, 'ace', '1–::

  1c+4c cross RH and cast to middle (2c+3c up/dn) ; 1c+4c RHA, finish RHJ facing own end (2,1x,4x,3)

9–::

  2c+1c & 4c+3c ½ Dbl Fig8, 1c & 4c cross to own end to start, all give easy hand in crossing ; 1c+4c ½ R&L (2x,4x,1x,3x)

17–::

  S&Link for 4c: All set NHJ | all link to form lines of 4 across ; all set up/dn | all link to own sidelines.  In each »link«, the two R end persons of each line cast to the two R end places of the new line (end person to the new end) _while_ the two L end persons dance through the middle, passing the others Lsh, to the two L end places of the new line, the non-end person going to the new end.  (3,1,4,2)

25–::

  Circle8 and back.', 3);
INSERT INTO 'dancecrib' VALUES (13589, '2021-01-27 16:43:07.598658+00', '2021-01-27 16:53:03.513246+00', 2529, 1, 202, 'ace', '1--::
  1c+2c & 3c+4c Circle4 and back (1,2,3,4)
9--::
  1c lead down to 4pl _while{4}_ 4c cast up to 1pl ; all set | cross RH (4x,2x,3x,1x)
17--::
  All repeat same pattern [9-16] (1,2,3,4)
25--::
  1c set | dance down between 2c, cast behind 3c & 4c to 4pl (2c+3c+4c up on [29-30]) | 1c set (2,3,4,1)
33--::
  2c+3c & 4c+1c R&L up/down (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11588, '2019-02-20 20:47:06.625563+00', '2020-12-29 11:46:05.570409+00', 8548, 1, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; 1c Petronella turn | set

9--::

  1c Petronella turn | all set ; 1c cross RH | cast to 3plx (3c up) (2,3,1x,4)

17--::

  1c Petronella turn | set ; Petronella turn | all set (2,3,1,4)

25--::

  4C Gr-Chain, 2c & 1c facing down, 3c & 4c facing up, one step per hand (2,3,1,4)

33--::

  1c lead down {2} | lead up to 1pl {6} (2c+3c down) (1,2,3,4)

41--::

  1c+2c ½ RHA | 1c+3c ½ LHA ; 1c+4c ½ RHA | 2c & 4c cross LH _while{2}_ 3c & 1c cross RH (2,3,4,1)

49--::

  All set | 1c followed by 4c+3c+2c cast up to1pl  into promhold facing up (1,4,3,2)

57--::

  4C Allemande (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11318, '2018-10-29 07:48:33.653862+00', '2021-01-28 10:52:32.549288+00', 11275, 1, 202, 'ace', '1--::

  1c+2c set | 1c advance to BtoB as 2c cast up ; ½ Reel4 across

9--::

  ½ Reels3 on sides, 1c out and down, 3c in and up (to 3,1,2x) ; 1c cast up to top | lead down and cross to 2plx centre BtoB facing opp sides _while{4}_ 2c cross LH | stand still (3,1x,2)

17--::

  1M+2W+3W & 1W+2M+3M Circle 3 L ; 1c loop RSh round 1cnrs and face 1cnrs _while{4}_ 2c & 3c continue the circle (no hands) to exchanged places | stand still (2,1,3)

25--::

  1c turn 1cnrs BH into lines3 across | cross RSh up/down into facing lines3 across ; all set | 1c Petronella Turn to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13483, '2020-12-29 14:02:00.770047+00', '2020-12-29 14:05:45.724736+00', 16337, 1, 1645, 'ace', '1-::
  1M+2W A&R{1+1} | cross RH ; 1W+2M repeat (2x,1x)
9-::
  2c+1c Circle4 L ; set | 2M & 1W cast off/up (as S&Link) _while{2}_ 2W+1M pass LSh to face P
17-::
  2c+1c RSh diagonal Reel4
25-::
  2c & 1c turn P 1&frac12; BH ; &frac12; poussette (2,1)
', 2);
INSERT INTO 'dancecrib' VALUES (13485, '2020-12-29 18:34:10.135212+00', '2020-12-29 18:37:37.165414+00', 16200, 1, 1645, 'ace', '1-4::

  1c set | 1c+2c change RH on sides{1} then 1c+3c change LH on sides _while{1}_ 2c cross LH (2x,3,1)

5-8::

  2c+3c change RH on sides _while{2}_ 1c cross RH | 3c cross LH _while{2}_ 2c+1c change LH on sides (3x,1x,2x)

9-12::

  All set | 1c set adv & turn to face opp side, BtoB with P _while{2}_ 3c & 2c set again

13-16::

  1M/1W cast RSh round 4cnr[pos] to centre line in 1pl/3pl _while{4}_ 3c & 2c dance in, pivot & curve out to next corner clw

17-::

  Repeat [9-16] from new places, 1c casting round 1cnr[pos] to (2,1,3)

25-::

  All chase tightly nearly once round ; all turn P RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (9293, '2016-09-17 19:46:53.522094+00', '2022-11-18 11:30:33.595067+00', 16186, 1, NULL, 'ace', '1-::

  1c dance down (2c up) | face P in middle and set ; With eyes joined dance Rsh round P to (2,1,3)

9-::

  All set | turn P LH ½ and stay close ; cast L to opposite side | cross Lsh to (2,1,3)

17-::

  2c+3c chase once round clw _while{8}_ 1c dance BtoB ; turn BH (2,1,3)

25-::

  2c+1c Poussette (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11945, '2019-07-05 20:47:27.505511+00', '2020-12-30 10:33:15.253895+00', 15912, 2, 963, 'ace', '  strathspey  

1-8::

  1,2,3 mirror reels on side, 1s in & dn to start, touch hands where poss  

9-12::

  1c 1/2 fig 8 around 2s, 2s face up&out  

13-16::

  1c turn 2c | 2c dance to top, 1c dance to face 1st crn  

 

  reel  

  

17-24::

  1c dance corner pass and turn with 1st crn, repeat with 2nd crn, finish 2nd   

  place own side  

25-32::

  6 hands round and back', 3);
INSERT INTO 'dancecrib' VALUES (13489, '2020-12-30 17:06:44.925439+00', '2020-12-30 17:06:59.051596+00', 14260, 1, 1645, 'ace', '1-::

  1c cast off | &frac12; turn LH ; cross down between 3c | cast up (2,1,3)

9-::

  Reels3 across, 1c start LSh to 1cnr & end passing LSh

17-::

  1c turn 2cnr LH (cnrs dance 4 bars) | pass LSh ; turn 1cnr LH | pass LSh to face out in 2pl

25-::

  Reels3 on sides, 1c start LSh to 4cnr (2,1,3)

::

  *After their 2nd time, dancing couple cast to 4pl as new top couple starts*

', 2);
INSERT INTO 'dancecrib' VALUES (10734, '2018-05-02 08:25:16.040762+00', '2020-12-30 21:26:56.149053+00', 15836, 1, 202, 'ace', '1--::

  1c & 4c long cast inwards (2c & 3c step out) ; 1c+4c set | ½ LHA (2,4x,1x,3)

9--::

  Parallel Reels4 on sidelines. On [16], 1c & 4c omit last Lsh and curve into centre BtoB facing nearest cnr (2,*1x*,*4x*,3)

17--::

  Double SetH&G, 1c & 4c finish in centre NHJ facing nearest ends (2,4,1,3)

25--::

  4c & 1c dance up/dn, casts inwards ; RHA

33--::

  Circle8 and back (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13590, '2021-01-27 17:01:16.424163+00', '2021-02-26 00:06:49.85095+00', 15764, 1, 202, 'ace', '1--::
  1c+2c set | RHA | 1c cast off to 2pl _while{2}_ 2c lead up to 1pl and face out (2,1,3)
9--::
  Parallel Reels3 on sides, 1c in and down, 3c out and up. 2c loop to 1pl and 3c face out (2,1,3)
17--::
  1c+3c DblFig8, 1c crossing down. 3c loop to 3pl (2,1,3)
25--::
  2c+1c R&L (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (13469, '2020-12-24 19:32:12.461415+00', '2020-12-25 10:42:54.038076+00', 20090, 1, 1645, 'ace', '*On 2nd chord, 2c & 4c cross to opposite sides (1,2x,3,4x)*
1-4::
  1M+2W & 3W+4M turn 1&frac14; RH to lines across, 1M & 4M between 2W+1W in 1pl & 4W+3W in 4pl
5-8::
  L-shape S&Link: 2W+1M+1W+2W & 3W+4M+4W+3M each set NHJ in an L-shape |
  2W & 3W cross to 1M & 4W places _while_ those in lines across pull RSh back & cast to next place clw in same L-shape
9-12::
  Repeat [5-8] from new places & end all facing clw
13-16::
  All chase &frac12; way clw ending opposite partner (3,4x,1,2x)
17-20::
  3c+4c & 1c+2c &frac12; RHA | 3c+2c &frac12; LHA & face corners on the diagonal (4,2x,3,1x)
21-24::
  2c & 3c loop RSh round facing corner & end facing in
25-28::
  2c+3c LHA in centre, 2W & 3W end facing out
29-32::
  4c+2c & 3c+1c each chase &frac12; way clw in each 2C set (2,4x,1,3x)
', 5);
INSERT INTO 'dancecrib' VALUES (2961, '2012-01-22 19:30:04.664343+00', '2020-12-25 12:27:46.992011+00', 11934, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; 1c cross down RH between 3c and cast up (2,1x,3)

9–::

  ½ Reels3 on sides, 1c starting in and up, 2c casting ; all set | 3c+2c cross RH _while{2}_ 1c turn RH 1¼ to face 4cnr (2cnr person)

17–::

  1c+2cnrs Pass&Turn, at end 1c pulls back Lsh to face 3cnr ; ½ Reel4 with 1cnrs, 1c swivel L to face 2cnr

25–::

  1c ½ Reel4 with 2cnrs, at end 1c swivel L to face 1cnr ; 1c+1cnrs Pass&Turn, 1c crossing to (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (2189, '2012-01-22 19:29:24.818714+00', '2020-12-26 10:29:01.17071+00', 14397, 1, NULL, 'ace', '1–::

  1c+2c & 4c+5c ½ R&L (2x,1x,3,5x,4x) ; 2c+4c set and cross RH _while{4}_ 1c+5c turn BH ¾, the W swivel R and the M swivel L to face 2cnr

9–::

  1c+5c turn 2cnr RH | P LH ; 1cnr RH | P LH to (2,1,3,5,4), 1c facing out

17–::

  2c+1c+3c ½ mirror Reels3 on the sides (1c out and up), no hands ; 2c+5c+4c repeat (5c out and up) to (3,1,4,5,2)

25–::

  3c+1c & 5c+2c Poussette', 3);
INSERT INTO 'dancecrib' VALUES (9083, '2016-01-21 21:47:29.752373+00', '2020-12-29 12:25:26.29814+00', 16495, 2, 1007, 'ace', '1-8:: 1s turn RH once & cast to 2nd place & turn LH about 1 1/2 times to face corners



9-16:: 1s and 1st corners change places RH, while 2nd corners set advancing slightly towards middle of set.1st and 2nd corners dance 1/2 LHA, while 1s dance CW round outside to next corner position.1W + 3M and 1M + 2W change place RH, while 3W and 2M cast by R dance out to their opposite corner position, 3W finish in 1st M''s place and 2M in 3rd W''s place (At end of bar 14, corners finish facing CW)1st + 2nd corners dance CW round outside to next corner position, while 1s turn LH 1 1/2 times to face their 1st corner in 2nd corner position.



17-24:: Repeat bars 9-14 from the new positions then 1s turn LH 3/4 round to finish in 2nd place on  own side while 1st and 2nd corners dance CW round outside to next corner position.



25-32:: 1s diagonal R&L (1W up and 1M down)





JIG

33-64:: 1s Repeat bars 1-32 beginning from 2nd place. In bars 15-16 1s may prefer to replace the turn 1 1/2 times with change place.



Repeat with a new top couple.', 0);
INSERT INTO 'dancecrib' VALUES (13484, '2020-12-29 14:58:19.830085+00', '2020-12-29 14:58:45.659615+00', 15430, 1, 1645, 'ace', '*For six couples in two side by side three couple sets:*  

*6W...6M....3W...3M*  

*5W...5M....2W...2M*  

*4W...4M....1W...1M*  

*...Set_2........Set_1...*

1-::

  1c+2c+3c also 4c+5c+5c Inveran Reels

9-::

  4c+5c+5c stand _while{8}_ 1c+2c+3c set | &frac12; turn RH ; M followed by W cross to Set_2 passing those couples RSh | 1M, 2M & 3M loop RSh round 4W, 5W & 6W & face them _while{2}_ 1W, 2W & 3W loop RSh round 4M, 5M & 6M who turn to face them

17-::

  4W+1M+4M+1W also 5W+2M+5M+2W & 6W+3M+6M+3W RSh Reels4 across Set_2, on [23-24] M pass RSh & on [24] W dance in, ending 4c above 1c, etc, ready for

25-28::

  4c+1c also 5c+2c & 6c+3c &frac12; RHA | 4M, 5M & 6M followed by P cross to Set_1 _while{2}_ 1c, 2c & 3c, retaining RH, &frac12; turn to sides in Set_2 (4,5,6,1,2,3)

29-32::

  4c, 5c & 6c turn RH to promhold facing up _while{4}_ 1c+2c+3c set | 1c & 2c cast off _while_ 3c lead up to top. 3c, 1c & 2c end in promhold facing down, W on M''s left

33-::

  All chase once round both sets (4,5,6,3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (13500, '2021-01-02 22:08:47.673506+00', '2021-01-02 23:30:49.176887+00', 16822, 1, 1645, 'ace', '1-::

  1c cross RH | cast off (2c up) ; &frac12; turn RH | twirl away (2,1,3)

9-::

  All &frac12; turn RH | twirl away (2x,1x,3x) ; chase &frac12; way clw (3,1,2)

17-::

  3C S&Rotate (2,1,3)

25-::

  Circle6 & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14840, '2022-05-29 21:01:34.40062+00', '2022-05-29 21:04:14.984553+00', 20454, 1, 202, 'ace', '1--::

  1c+2c Mirror Set&Link, 1c casting off (to 2,1,3) ; 1c dance down between 3c | cast up (2,1,3)

9-20::

  3C R&L (2,1,3)

21-24::

  1c turn 4cnrs RH (2,1,3)

25--::

  Reels3 on sides, 1c LSh to 3cnrs, cnrs looping to places (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13486, '2020-12-29 19:02:28.998715+00', '2020-12-29 19:02:43.36123+00', 15436, 1, 1645, 'ace', '1-::

  1c & 4c cross RH | cast in (2c & 3c to ends) ; &frac12; Fig8 round ends to face corner they just danced round (2,1,4,3)

9-::

  All set | 1c & 4c turn corner RH & retain RH ; BiL, 1c & 4c joining LH in centre | 1c+4c &frac12; LHA to face opp corner

17-::

  Repeat [9-14] with new corners | 4c & 1c set LHJ, 4W & 1M turning towards P, 4c/1c end facing up/down

25-::

  4c & 1c lead LHJ out ends, cross & cast in ; all turn RH (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11943, '2019-07-05 20:21:19.32884+00', '2020-12-30 10:41:08.468995+00', 15909, 2, 963, 'ace', '1-4::

  1w & 3m set adv, join left hand, join right hand with partners & bal in line

5-8::

  1w & 3m left hand turn to each other''s place  

9-16::

  1m & 3w repeat 1-8  3x,2,1x

17-20::

  2c & 1c dance 1/2 R&L with polite turn  3x,1,2x

21-24::

  1c 1/2 fig 8, woman up, man down  3x,1x,2x  

25-32::

  man up, woman down 1/2 rt shld reel on the side: man up, woman 

  down, 1/2 lt shld reel across  2,1,3



  2nd time thru, 1s cast as 4w sets adv up to begin

  

  

  

  ', 3);
INSERT INTO 'dancecrib' VALUES (3765, '2013-06-20 14:15:55.230899+00', '2020-12-31 11:42:48.90696+00', 14942, 2, 197, 'ace', '1–::

  1W followed by 1M casts to 3plx, 4M followed by 4W casts to 2plx (2,4x,1x,3); 4c+1c RHA

9-::

  4W with 1W in tandem +2M+3M & 1M with 4M in tandem +3W+2W,  Reels3 on the sides, (start Lsh to 2M & 3W) (at the ends of the reels 4W+1W & 1M+4M loop singly so the other takes the lead). (2,4x,1x,3)

17-::

  4c ½ Fig8 up round 2c, 1c ½ Fig8 down round 3c; 4c+1c turn RH (2,4,1,3)

25-::

  2c+4c & 1c+3c circle4 and back', 4);
INSERT INTO 'dancecrib' VALUES (13002, '2020-07-31 11:05:50.382537+00', '2020-07-31 20:32:29.039584+00', 20058, 1, 202, 'ace', '1--::
  1c set twice. On [4] 1W pull RSh back and face out ; 1W (1M following) casts off | 1c dance across to 2plx (2c up) (2,1x,3)
9--::
  All cnrs chase clw _while{8}_ 1c dance BtoB ; chase clw ½ (2,1,3)
17--::
  1c+1cnrs A&R ; 1c+2cnrs A&R (2,1,3)
25--::
  1c dance RSh round P ½, face P and cast away to 2plx ; chase clw ½ to 2pl (2,1,3)

*Deviser''s Note:  
On [17-24] dancing couples may slap, clap, clap.*', 4);
INSERT INTO 'dancecrib' VALUES (13380, '2020-11-30 18:20:39.055029+00', '2020-11-30 18:28:13.816288+00', 1869, 1, 202, 'ace', '1--::

  1c turn RH ½ to 2plx centre (2c up) and release hands | all set. On [4] 2W & 3M pull RSh back and face out ; 1c turn LH 1¼  and face 3cnrs[pos] _while{4}_ 2c+3c chase clw ½

9--::

  ½ Reel4 on 1diag, pass RSh and face 4cnrs[pos] ; ½ Reel4 on 2diag to 2pl (2,1,3)

17--::

  ½ Reels3 across, 1c RSh to 2cnrs (to 2x,1x,3x) ; all cross RH and set (2,1,3)

25--::

  ½ Reels3 across, 1c LSh to 1cnrs ; all cross LH and set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13724, '2021-03-01 22:11:18.12013+00', '2021-03-01 22:14:50.737663+00', 10281, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c S&Link twice (1,2,3,4)

9--::

  Mirror Reels4 on sides, RSh on Mside, LSh on Wside (1,2,3,4)

17--::

  1c long cast to 4pl (2c+3c+4c up) ; all set | turn P BH (2,3,4,1)

25--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (13470, '2020-12-24 22:06:32.455774+00', '2020-12-24 22:10:09.495208+00', 19842, 1, 1645, 'ace', '1-::
  W set | &frac12; RHA ; cast away to sides & face out | cast 1pl clw & face in _while{8}_ M &frac12; RHA to sides facing out | cast 1 pl clw ; set | dance into centre, pull RSh back & face P (2,3,4,1)
9-24::
  *Celtic Knot:* W (outside) facing M (inside) pass RSh, W ending in next inside pl cclw, M face in on sides | repeat [9-10] 7 times from new places to (2,3,4,1) with M back in centre
25-::
  All petronella to face P | Interlocking Reels3{6} as if from end place, start RSh to P, end facing P on sides (2,3,4,1)
33-::
  All &frac12; Gr-Chain (4,1,2,3)
', 2);
INSERT INTO 'dancecrib' VALUES (2845, '2012-01-22 19:29:59.816449+00', '2020-12-25 12:30:37.601432+00', 12090, 1, NULL, 'ace', '{{explanation}}

4c, 5c and 6c start on opposite side (1,2,3,4x,5x,6x)  The dance is centro-symmetric; »top« and »bottom« do the same figures throughout.



1–::

  1M+6M cast off/up one, (2c+5c step to end) cross and cast Rsh round 1cnr into middle facing 1cnr _while{8}_ 1W+6W cross, cast off/up, ½ Fig8 between 2c/5c to face 1cnr, BtoB with P

9–::

  1c+6c ½ Diag Reel4 with 1cnrs, pass Rsh, ½ Diag Reel4 with 2cnrs, finishing (3x,1x,2x,5,6,4)

17–::

  3c+4c cross and cast 2 places, to middle positions (other Cs step to ends) ; 3c+4c ½ R&L (1x,2x,4,3x,5,6)

25–::

  2c+4c & 3c+5c ½ R&L ; 1c+4c & 3c+6c ½ R&L  (4,1,2,5x,6x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (3856, '2013-07-13 15:56:24.449482+00', '2020-12-26 10:38:01.621696+00', 14646, 1, NULL, 'ace', '1–::

  1c cross down (no hands) and face out (2c up) | change places EH with 3c ; cross up and face out _while_ 3c cast back to 3pl | 1c change place EH with 2c (1,2,3)

9–::

  Mirror Reels3 on the sides, 2c starts out and up

17–::

  All A&R ; All couples turn BH

25–::

  1W+2M change places RH _while_ their P set diagonally | 1c+2c ¾ RHA and set (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13479, '2020-12-28 13:05:07.02526+00', '2020-12-28 13:21:52.82422+00', 12735, 2, 1645, 'ace', '1-4::

  Step three steps forward and kick. Repeat backwards.

5-8::

  Spring away and close, turn away from partner.

9-12::

  Four slip step forward, four back.

13-16::

  Polka.

', 0);
INSERT INTO 'dancecrib' VALUES (13487, '2020-12-29 19:20:52.158701+00', '2020-12-29 19:22:17.837777+00', 15431, 1, 1645, 'ace', '1-::

  1c & 2c cross RH | set{R} to P & set{L} facing on sides ;

  1c+2c change RH on sides | set{R} facing on sides & set{L} to P (2x,1x,3,4)

9-::

  2c+1c repeat [1-4] ; 2c+1c turn RH on sides, 1c end facing 3c (2,1,3,4)

17-::

  2c+1c+3c Reels3{6} on sides, 1c start LSh to 3c | 1c+3c change LH on sides (2,3,1,4)

25-::

  1c+4c chase &frac12; way clw (2,3,4x,1x) ; 4c+1c set | cross RH (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (10728, '2018-05-01 19:40:57.493281+00', '2020-12-30 10:52:20.379613+00', 15847, 1, 202, 'ace', '1--::

  ½ Mirror Reels3 on sidelines, 1c start in and down ; 1c turn 2c EH _while{4}_ 3c turn RH (3,2,1)

9--::

  3c set | cast (2c up) ; 2c+3c+1c turn LH (2,3,1)

17-28::

  3C R&L

29-32::

  All turn RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10939, '2018-08-05 13:37:02.593861+00', '2020-12-31 11:45:46.957354+00', 14341, 1, 202, 'ace', '1--::

  1W cast _while{2}_ 2W dance up and loop to 1pl | 1c+2c set diagonally ;  RHA

9--::

  1M cast _while[2}_ 2M dance up and loop to 1pl | 1c+2c set ; LHA (2,1,3)

17--::

  Parallel Reels3 {6} on sidelines, 1c Rsh to 3c, 1c & 3c face | 2c turn BH (skip change) _while{2}_ 1c+3c change places BH (skip change) (2,3,1)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2273, '2012-01-22 19:29:29.070252+00', '2020-11-30 22:32:46.31309+00', 2312, 1, NULL, 'ace', '1–::

  1c+2c Set&Rotate (set | cast 1 place clw ; change place RH with P | chase 1 place clw)

9–::

  Reels3 on own side, Rsh to 2c, finish facing 1cnr

17–::

  ½Reel4 with 1cnrs ; repeat with 2cnrs (to 3x,1x,2x)

25–::

  2c+1c+3c S&Link3 twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13716, '2021-02-28 02:05:38.54432+00', '2021-02-28 02:11:14.854026+00', 4151, 1, 202, 'ace', '1--::

  1M+2W+3W Reel3 on 1diag, 1M RSh to 2W (1,2,3)

9--::

  1W+2M+3M Reel3 on 2diag, 1W LSh to 2M (1,2,3)

17--::

  All set | cross RH ; set | 1c cast off and face 1cnrs[pos] _while_ 2c cross up to 1pl _while_ 3c cross RH

25--::

  1c+1cnrs set | 1c turn P RH to face 2cnrs ; 1c+2cnrs turn LH | 1c turn P RH to 2pl (2,1,3)



*Deviser''s note:  

At the end of the leading couple''s second sequence, on bars 31 - 32, they turn each other into bottom place; the couple below moving up.*', 2);
INSERT INTO 'dancecrib' VALUES (12886, '2020-06-11 10:50:18.106827+00', '2021-01-02 11:48:27.450935+00', 19543, 1, 1645, 'ace', '1-::

  1c+2c 6 bars of poussette | &frac14; turn BH, release & dance forward individually, pulling RSh back to centre line facing opp side, P on L, 1c above 2c

9-::

  1c+2c Targe starting from centre line, ending on opp side (2x,1x)

17-::

  2c+1c Circle4 to R ; 2c cross down | cast up _while{4}_ 1c cast up | dance down to end BtoB between 3c facing opp side

25-::

  1c+3c RSh Celtic Reel, 1c end facing own sides, 3c on opp sides

33-::

  1c+3c continue Celtic Reel, 1c to own sides, 3c end facing P in centre | 3c & 1c set ; 3c cross down LH | cast up (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (2499, '2012-01-22 19:29:45.225393+00', '2021-01-03 12:44:48.601977+00', 13318, 1, NULL, 'ace', '1–::

  All ½ Mirror Reels3 on own side, 2c start out and up ; 1c cross RH and cast up (3c+2c down) (1x,3,2)

9–::

  Repeat from new positions (1,2,3)

17–::

  1c (crossing down) +3c (cast up) DblFig8 round 2c

25–::

  2c followed by 1c dance down | set to P ; dance up | 1c cast to 2pl as 2c dance up (2,1,3)



{{explanation}}

note: at each 2nd turn the dancing couple casts to the bottom and 3c steps up to start again', 3);
INSERT INTO 'dancecrib' VALUES (13496, '2021-01-01 16:46:26.745943+00', '2021-01-01 17:02:13.2223+00', 7062, 1, 202, 'ace', '1--::

  3C Gr-Chain (1,2,3)

9--::

  1c cross RH | cast off (2c up) ; ½ Fig8 up between 2c (2,1,3)

17--::

  Mirror Reels3 on sides, 1c in and down, 3c out and up. 1c face 1cnrs

25--::

  SetH&G. 1c BtoB in centre face 2cnrs

33--::

  Reels3 on sides {6}, 1c RSh to 2cnrs | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3164, '2012-01-22 19:30:14.022835+00', '2021-03-21 14:21:07.952724+00', 8177, 1, NULL, 'ace', '1–::

  1c set, cast off one (2c up) ; 2c+1c RHA  (2,1,3,4)

9–::

  1c+3c set | turn BH, opening into ; circle4 left, end on sidelines for

17–::

  All circle8 and back

25–::

  1c set | cast off 2 ; all C turn RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13593, '2021-01-28 13:01:47.593906+00', '2021-01-28 16:51:47.764021+00', 11691, 1, 202, 'ace', '1--::

  1c cross down into DTr position (2c up) | all set ; 1c+3c change places EH | all set

9--::

  3c+1c change places EH. 1c face 2cnrs | 1c turn 2cnrs LH ; pass P LSh | turn 1cnrs LH

17--::

  1c pass P LSh | turn 4cnrs LH ; pass P LSh | turn 3cnrs LH to 2pl (2,1,3)

25--::

  1c ½ Fig8 L round 2cnrs ; 1c ½ Fig8 L round 4cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13471, '2020-12-24 22:08:17.290583+00', '2020-12-24 22:17:32.160384+00', 10704, 1, 202, 'ace', '1--::

  1c lead down {3}, lead up {3} to between 1pl | set to P, advancing and passing on the second step (2c up on [3-4])

9--::

  Reel4 across

17--::

  1c+2c turn BH ¾ (to 2,1,3) ; all set | A&R {1+1} (2,1,3)

25--::

  1c Fig8 on sides, RSh to 4cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2169, '2012-01-22 19:29:23.626498+00', '2020-12-25 15:28:35.878386+00', 12910, 1, NULL, 'ace', '1–::

  1c+2c »The Tourbillon« (1c+2c turn P BH ½, opening out to one place clw in the square (1c to W side, 2c to M side) | 1c set to 2c ; repeat figure (to 2x,1x) | 2c+1c cross RH) (2,1,3)

9–::

  S&Link3 to lines across ; all turn person opposite BH

17–::

  S&Link3 to sidelines ; all C turn BH (3x,1x,2x)

25–::

  All set | 1c turn RH ¾ and curl to finish BtoB in centre, W facing down, M up _while{2}_ 2c+3c change places RH on sideline ; 1c cast L through the ends to meet in 2pl facing down NHJ _while{4}_ 2c set and cross RH and 3c set and pass Rsh, swiveling R to face up NHJ

33–::

  1c+3c Rondel, finish (2,3,1) 3c facing up and out

41–::

  Reels3{6} on the sides | all set', 3);
INSERT INTO 'dancecrib' VALUES (9691, '2017-03-31 09:29:04.306923+00', '2020-12-26 10:56:34.396782+00', 17685, 1, 202, 'ace', '1--::

 1c+2c+3c Petronella to midline | set ; repeat (1x,2x,3x)

9--::

 1c+2c ½ RHA  _while{2}_ 3c cross RH | All set ; 1c ½ Fig8 R, W up, M down (2,1x,3)

17--::

 Reels3{6} across, 1c start Lsh to 3cnr | 1c cross RH to 2pl finish facing out (2,1,3)

25--::

 1c cast off, meet below 3c, dance up between 2c and cast off (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13488, '2020-12-29 19:31:35.723827+00', '2020-12-29 19:33:23.122564+00', 15441, 1, 1645, 'ace', '1-::

  1c+3c &frac12; turn opposite RH | cast away ; 3c & 1c in promhold dance &frac12; way clw outside set to original places

9-::

  Interlocking Reels4, starting RSh to corner

17-::

  All set HS to P ; dance in, NHJ with P, touch NH with corners, pull back RSh, dance out & chase 1 place clw (4,1,2,3)

25-::

  Circle8 round & back (4,1,2,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13595, '2021-01-29 00:00:21.461297+00', '2021-01-29 06:37:31.809296+00', 11695, 1, 202, 'ace', '1-16::

  All set | 3C R&L | all set (1,2,3)

17--::

  1c lead down between 2c, dance behind 3c, meet ; lead up between 3c, dance behind 2c to 1pl

25--::

  1c & 3c turn P BH ½ opening out to face down | 1c dance down {3} and cast up {1} to 3pl _while{4}_ 3c long cast up to 2pl (2c up on [27-28]) | 3c & 1c cross RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12843, '2020-05-24 09:04:19.857554+00', '2020-05-24 09:04:19.857554+00', 13089, 1, NULL, 'ace', '1--::

  1c set | 1c cross down RH and face M side (2c up) ; 1W, 1M following, cast Rsh round 2M , finish 1W between 3c and 1M between 2c

9--::

  1M+2c & 1W+3c ½ Rsh Reel3 across ; 1W, 1M following, casts Lsh round 3Wpl to finish (2x,1x,3x)

17--::

  ½ Reels3 on the sides, 1c Lsh to 2c ; 1W, 1M following, cast Lsh round 3Mpl to finish on 1diag facing 1cnr (pos)

25--::

  ½ diag. Reel4 on 1diag, pass Rsh to face 2cnr ; ½ diag. Reel4, 1c cross Rsh to own side (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (13227, '2020-10-10 00:55:39.440388+00', '2020-10-10 00:59:13.214292+00', 5437, 1, 202, 'ace', '1--::

  1c & 3c set | turn P RH ¾ ; ½ Reel4 on midline. On [8] 1M+3W turn LH ¾

9--::

  ½ Reel4 across. On [12] 1M+3W turn LH ¾ and face P on midline ; ½ Reel4 on midline

17--::

  1c & 3c set | turn P BH ¾, 3c to sides, 1c in centre NHJ facing down ; 1c+2c change places EH | 1c+3c change places EH (2x,3x,1x)

25--::

  Mirror Reels3 on sides, all crossing up RH from bottom, out and up from 2nd place, NHJ from top (2,3,1)', 0);
INSERT INTO 'dancecrib' VALUES (3306, '2012-01-22 19:30:19.838914+00', '2020-11-30 22:33:55.858432+00', 10153, 1, NULL, 'ace', '1–::

  2M+1W cross RH | 1c+2c half circle4 left ; 1M+2W cross RH | 1c+2c half circle4 left (to 2x,1x,3)

9–::

  2c+1c lead down the middle and up, crossing (no loops) to own side at end (2,1,3)

17–::

  1c (solo) set | Fig8 on own sideline, starting in and up (2,1,3)

25–::

  1c+3c Set&Rotate (set | cast 1 place clw ; change place RH with P | chase 1 place clw) (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (13497, '2021-01-01 18:00:05.646177+00', '2021-01-01 18:06:07.207915+00', 5530, 1, 202, 'ace', '1--::

  1c cast off (2c up) | set ; cast up (2c down) | set (1,2,3)

9--::

  1c Fig8 on sides, in and down to start (1,2,3)

17--::

  1c+2c RHA ; 1c+2c PdB R on sides, 1W+2M & 1M+2W PdB L | 1c+2c set advancing ready for

25--::

  2C Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13829, '2021-03-21 03:39:07.79493+00', '2021-03-21 14:29:46.353855+00', 7496, 1, 202, 'ace', '1--::
  All Promenade clw (1,2,3,4)
9--::
  All W dance in front of P, RSh round next M and face new P ; set | turn new P BH 1¼ (M: 1,2,3,4 W: 4,1,2,3)
17--::
  All M dance in front of new P, LSh round next W and face new P ; set | turn new P BH ½ (M: 2,3,4,1 W:4,1,2,3)
25--::
  All W LHA ; all W RHA _while{4}_  all M chase cclw ½, meet and face original P (4,1,2,3)
33--::
  Gr-Chain (4,1,2,3)', 5);
INSERT INTO 'dancecrib' VALUES (13501, '2021-01-02 22:29:42.012281+00', '2021-01-03 11:33:28.671646+00', 14601, 1, 1645, 'ace', '*1c & 3c start as in a square set with 2M in 2pl and 2W in 4pl, effectively as 1c & 2c crossed over*
1-::
  All petronella to next side | set ; repeat, all are now opposite original place
9-::
  3c & 1c in promhold Reel4 with 2W/2M who start passing LSh to give RSh to 3c/1c at top/bottom, 2c end in original places (as at bar 1)
17-::
  3c+2M (top) & 2W+1c (bottom) RHA, 2c pass RSh ; 3c+2W & 2M+1c LHA
25-::
  All set | 3M+2M & 3W+2W turn 1&frac12; BH _while{4}_ 1c turn BH once | all set in progressed places (2x,3x,1)
', 2);
INSERT INTO 'dancecrib' VALUES (13978, '2021-05-01 14:52:55.506777+00', '2021-05-01 18:52:02.065639+00', 9617, 1, 202, 'ace', '1--::
  All Petronella turn | set ; repeat (1x,2x,3x,4x)
9--::
  1c+2c & 3c+4c Circle4 L ; all advance {1}, turn P BH ½ {1} | retire (1,2,3,4)
17--::
  Poussette. All finish in centre facing up NHJ (1,2,3,4)
25--::
  1c (+2c+3c+4c following) cast off to 4pl ; 1c turn P BH _while{4}_ 2c (+3c+4c following) dance up from 3pl centre to top, looping to places (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13503, '2021-01-03 13:10:30.418945+00', '2021-01-03 13:16:03.487718+00', 14787, 1, 202, 'ace', '1--::

  1M/3M casts off _while_ 2W/4W casts up, pass RSh in centre. 1M/3M & 2W/4W dance RSh round own P to exchanged places {6} | 1c+2c & 3c+4c chase clw one place (2,1,4,3)

9--::

  1c+4c Set&Rotate (2,4,1,3)

17--::

  2c+4c & 1c+3c S&Link (to 4,2,3,1) ; 4c+2c & 3c+1c Circle4 L (4,2,3,1)

25--::

  4c+2c+3c ½ Mirror Reels3 on sides, 4c out and down, 2c in and up (to 3,2,4,1) ; 2c turn RH | cast up (3c down) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3177, '2012-01-22 19:30:14.569678+00', '2021-05-01 20:30:05.299809+00', 5807, 1, NULL, 'ace', '1–::

  1c+2c RHA ; LHA

9–::

  Women cross RH, set to other M ; turn him LH

17–::

  Women cross back, set to P ; turn P LH

25–::

  Men advance with 2 PdB, set to each other ; swivel turns {4} to finish BtoB facing own P

33–::

  Diagonal Reel4, ending in original places

41–::

  1c+2c Poussette to meet next couple.', 2);
INSERT INTO 'dancecrib' VALUES (13725, '2021-03-01 22:34:11.09084+00', '2021-03-01 22:40:31.944319+00', 10282, 1, 202, 'ace', '1--::

  Mirror Fig8 on sides, 1c in and down (1,2,3)

9--::

  1c+2c set | RHA ½ ; 2c+1c set | LHA ½ (1,2,3)

17--::

  1c lead down {3} and change sides [: 1M crosses below 1W who dances under joined arms], lead up {3} |cast to 2pl (2c up) (2,1x,3)

25--::

  1c ½ Fig8 up round 2c ; all turn P RH (2,1,3)



*Deviser''s note:  

After the second repetition, 4c step up immediately.*', 2);
INSERT INTO 'dancecrib' VALUES (14081, '2021-06-19 23:41:25.817562+00', '2021-06-19 23:43:22.28616+00', 6107, 1, 1645, 'ace', '1-::

  1c & 3c set | cross ; set | turn P &frac34; RH _while{8}_ 2c cross RH | set ; cross RH | set

9-::

  1c+3c RSh Reel4 on midline _while{8}_ 2c dance Fig8 through the reel: cross LSh, dance clw round end of reel, cross back LSh, cclw round other end

17-::

  1c & 3c &frac34; turn RH | 1c+2W & 2M+3c RHA ending on sides | all set, 1c & 2c advancing for

25-::

  1c+2c Poussette (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13726, '2021-03-01 23:03:42.270977+00', '2021-03-01 23:12:04.256113+00', 20236, 1, 202, 'ace', '_Strathspey_

1--::

  Mirror Reels3 on opposite sides, 1c crossing, all joining NH where possible (1x,2,3)

9--::

  1c+2c DblFig8, 1c crossing (1x,2,3)

17--::

  2c+3c set | turn P RH ½ and face P RHJ ; pass P RSh to original places | RHA ½ (1x,3x,2x)

25--::

  1c lead down (3c up) ; lead up to 2plx (3x,1x,2x)

33--::

  3C S&Link twice (2,1,3)



_Reel_

41-80::

  Repeat [1-40] in reel time', 2);
INSERT INTO 'dancecrib' VALUES (8142, '2013-12-28 01:05:08.297064+00', '2021-01-01 18:40:03.755495+00', 13709, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; All set | 2c turn RH ½ (keep hands joined) _while_ 1c+3c+4c cross RH (2x,1x,3x,4x)

9–::

  2c turn RH ½ | 2c+1c ½ RHA (1,2x,3x,4x) ; 1c+2c+3c chase clw ½ (3,2,1x,4x)

17–::

  All Circle8 and back

25–::

  2c+1c+4c chase cclw ½ round (3,4,1,2x) ; 1c+2c ½ LHA | 1c Turn LH ½ (3,4,2,1)', 3);
INSERT INTO 'dancecrib' VALUES (13472, '2020-12-24 22:26:48.201969+00', '2021-01-02 16:27:38.921004+00', 19843, 1, 1645, 'ace', '1-::
  1c+2c Reel4 on centre line, 1W & 2M start passing LSh as 1M & 2W curve L, end on centre line facing own side, W above P
9-::
  *Linear Chain Progression [9-24]:* 1W+1M+2W+2M BiL | &frac12; turn P RH ; 1W+2M &frac12; turn LH _while{2}_ 1M & 2W (ends) set | 1M+2M (top) & 1W+2W (bottom) &frac12; turn RH
17-::
  Repeat [13-16] from new places ; 2W+2M+1W+1M BiL | dance out to sides (2,1,3)
25-::
  1c+3c set | &frac12; RHA ; chase &frac12; way clw (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (13502, '2021-01-02 23:40:23.885891+00', '2021-01-02 23:40:35.640237+00', 5882, 1, 1645, 'ace', '1-::

  All &frac12; turn RH to centre | set ; M cast off & with 4M leading, cross to own side & dance up

  _while{4}_ W cast up & with 1W leading, cross to own side & dance down (4,3,2,1)

9-::

  4c & 1c &frac12; turn RH moving in | &frac12; RHA to original places ; 3c & 2c &frac12; turn RH | &frac12; RHA (1,2,3,4)

17-::

  1W+2M & 3W+4M cross passing RSh | all &frac12; turn P BH on sides & open out for ; 1c+2c & 3c+4c Circle 1&frac14; L ending with 1c & 3c facing down to 2c & 4c facing up NHJ

25-::

  All set adv past facing couple | 1c & 4c set adv past each other _while{2}_ 2c/3c cast into 1pl/4pl ;

  4c/1c dance out nearest end & cast back to 2pl/3pl (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13504, '2021-01-03 13:25:45.189326+00', '2021-01-03 13:29:10.17404+00', 14788, 1, 202, 'ace', '1--::

  All turn opposite person RH ; RHA

9--::

  Cicle4 and back

17--::

  All dance BtoB with opposite person ; all set | cross RH with opposite person

25--::

  All A&R ; all adv and turn inwards to face original direction| all adv to meet next couple', 2);
INSERT INTO 'dancecrib' VALUES (14086, '2021-06-20 21:13:49.329592+00', '2021-06-24 18:32:49.892296+00', 20351, 1, 202, 'ace', '1--::

  1c lead down {3}, lead up {3} | cast off (2c up and face out) (2,1,3)

9--::

  ½ Reels3 on sides, 2c out and down, 1c in and down, 3c out and up. 2c & 3c loop to places (to 3,1,2) ; all dance BtoB (3,1,2)

17--::

  All set | Petronella turn ; repeat (3x,1x,2x)

25--::

  All S&Link twice (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (13596, '2021-01-29 07:21:12.311565+00', '2021-01-29 07:26:25.184771+00', 11696, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; cross LH | dance RSh round 3cnrs into facing lines3 across

9--::

  All set | turn opposite person RH 1½

17--::

  Reels3 on opposite side, 1c LSh to 2cnrs[pos] (3,1x,2)

25--::

  All turn P RH ; 1c cross up to 1pl and cast off _while{4}_ 3c cast off to 3pl  _while{4}_ 2c leead up to 1pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2269, '2012-01-22 19:29:28.850056+00', '2021-03-21 19:49:26.228239+00', 8173, 1, NULL, 'ace', '1–::

  All set | 1c turn RH ½ as 2c cast halfway up ; 1M+2W & 1W+2M turn LH ½ into line across, 2c in the middle | all BiL & M turn to face down

9–::

  In line of 4 dance down the middle ; 2c turn inward and dance up, 1c following (2,1x)

17–::

  2M+1M change places RH | 2W+1W change places RH ; all set | all turn P RH ½, finish NHJ, 1c facing 2c (1x,2)

25–::

  1c+2c set | 2c dance up with arch & 1c dance under ; 1c dance down {1} 1W dances under her partners arm, 1M crossing below her | 1c dance up (2,1).', 3);
INSERT INTO 'dancecrib' VALUES (13473, '2020-12-24 22:52:18.874957+00', '2020-12-24 22:58:38.528904+00', 10711, 1, 202, 'ace', '1--::

  1c+2c set | cross RH ; set | ½ RHA (2,1,3)

9--::

  All A&R {1+1} twice ; 1c dance up, cast off and face 1cnrs

17--::

  1c turn 1cnrs BH, pass P RSh flowing in a wide arch and face 2cnrs ; repeat with 2cnrs to 2pl

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13727, '2021-03-01 23:42:28.545221+00', '2021-03-01 23:45:47.23605+00', 20235, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; turn P RH to 2plx (2,1x,3)

9--::

  Reels3 across, 1c RSh to 4cnrs (2,1x,3)

17--::

  1c Fig8 up round 2c ;  dance between 3c and cast up to 2pl (2,1,3)

25--::

  1c+3c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (13490, '2020-12-31 13:04:26.677394+00', '2020-12-31 13:04:42.421427+00', 11689, 1, 1645, 'ace', '1-::

  1c+2c+3c Mirror Reels3 on sides, 1c start out & down

9-::

  1c cast off _while_ 2c dance up | 2c+1c turn &frac34; LH, 1M/1W face up/down ; 2c+1M & 1W+3c RHA

17-::

  1c dance LSh round P 1&frac12; times ; 2c+1W & 1M+3c RHA (2,1,3)

25-::

  2c+1c Poussette (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13492, '2020-12-31 14:18:51.892379+00', '2020-12-31 14:26:55.306897+00', 10666, 1, 202, 'ace', '1--::
  1c+2c pass RSh (no hands) on sides | 1c+3c turn LH on sides (to 2,1,3) ; 2c+1c RHA (2,1,3)
9--::
  Parallel Reels3 on sides, 1c RSh to 2c (2,1,3)
17--::
  1c set | cross RH ; dance RSh round 1cnrs, meet in centre and turn RH. 1W (1M behind) faces out the top 
25--::
  Reel3 across in tandem, 1W RSh to 2W (2,1,3)

*Deviser''s note:  
On bars 1-2, 2nd couple should make a larger arc, looping into place. Do not to rush the right hands across. On the last 2 bars of the reel, 1st man should slow down and slightly separating to end in his own spot in second place.*', 2);
INSERT INTO 'dancecrib' VALUES (14943, '2022-07-05 15:50:14.498177+00', '2022-07-05 15:50:14.498177+00', 20785, 2, 1, 'ace', '1–::
  1c+2c Set and Rotate
9–12::
  All set advancing [NH joined] and pivot R to face ptr in a line of 6 [M facing down, W up]
13–16::
  2W followed by 1W+3W dance up and cast off W''s side _while_ 3M followed by 1M+2M dance down and cast up M''s side [fin 3c in 1pl, 2c in 3pl, 1c passing LS to 1crnrs]
17–::
  1c dance ½ diag Reel4 w/1crnrs [pass RS to fin facing 2crnrs] ;  
  1c dance ½ diag Reel4 w/2crnrs [fin 1c on 2diag, LH to ptr, RH to 2crnr pl]
25–28::
  1c and crnrs dance 4 bars of The Spoke
29–32::
  1c turn LH 1¼ _while_ 2c & 3c set and cross RH', 3);
INSERT INTO 'dancecrib' VALUES (11811, '2019-04-28 08:26:14.663683+00', '2021-01-01 18:42:15.74022+00', 13677, 2, 1645, 'ace', '1-8::

  1s & 3s dance down for 3, back for 3 and cast off 1 place. 2s & 4s step up on 7 & 8.

9-16::

  1s & 3s dance a fig of 8 – 1s round 2s and 3s round 4s. 2,1,4,3,5.

17-20::

  1s & 3s dance Rhands across once round and continue straight into bars 21-24.

21-24::

  1s & 3s dance a slow Rhand turn (4 bars) with partners. 1s finish facing ladies’ side in 2nd place, 1L in front of her partner. 3s continue moving up to 3rd place as 4s step down 1 place on 23 & 24. 2,1,3,4,5.

25-32::

  1s with 1L leading cast off round 3L, cross over (3s step up on 27 & 28) and dance behind 4M & 5M. 1s finish in 5th place on own sides of the dance. 2,3,4,5,1. On 27-32 (6 bars) 4s & 5s dance Rhands across once round ending up 1 place.

33-40::

  Couples in 1st & 2nd places circle 4 hand round and back. Couples in 3rd, 4th & 5th places circle 6 hands round and back. 2,3,4,5,1. Repeat from new positions. Last time through all dance 10 hands round and back.

:: *Crib courtesy of Peter Jamieson from the Glen Orrin Rally July 2019 crib sheet.*', 0);
INSERT INTO 'dancecrib' VALUES (13835, '2021-03-22 20:52:39.137168+00', '2021-03-26 12:53:05.595617+00', 20282, 1, 202, 'ace', '1--::
  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 1c+4c turn LH on sides. 1c face up, 4c face down (2,1x,4x,3)
9--::
  Parallel Reels4 on sides. On [15-16] 1M+4M & 1W+4W pass RSh and pivot R to face each other on sides. 2c & 3c face P (2,1x,4x,3)
17--::
  4C Gr-Chain (2,1x,4x,3)
25--::
  All set | 1c+4c ½ RHA ; all dance BtoB (2,4,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (12844, '2020-05-26 00:48:29.984557+00', '2020-05-26 01:02:28.678858+00', 19437, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 1c turn LH (2,1x,3)

9--::

  ½ Fig8 R round 3cnrs to 2pl ; ½ R&L, crossing RH with 1cnrs (3W,1W,3M on Mside, 2W,1M,2M on Wside)

17--::

  ½ Fig8 L round 4cnrs to 2pl ; ½ R&L, crossing RH with 2cnrs (3,1,2)

25--::

  3C S&Link twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14764, '2022-04-17 18:34:14.901905+00', '2022-04-17 18:44:05.641338+00', 20770, 1, 202, 'ace', '1--::
  1c set | cross RH ; cast off (2c up) |turn P LH to face 1cnrs
9--::
  1c set R to 1cnrs {1} and L to P {1} | turn ¾ RH ; set R to 2cnrs and L up/down to P | turn ¾ RH to 2pl facing out (2,1,3)
17--::
  3C Chain Progression (3,1,2)
25--::
  All set | cross RH ; chase clw ½ (2,1,3)
33--::
  1c+3c *Rose Progression* : 1W+3M change place RH | chase 1 place clw ; turn BH ½, face and cast away _while{8}_ 1M+3W set | turn BH ½, face and cast away | chase 1 place clw (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (13499, '2021-01-02 13:31:36.744341+00', '2021-01-02 13:39:01.725791+00', 2013, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA ; set | ½ LHA (1,2,3)

9--::

  1c lead down {3}, lead up {3} | cast off (2,1,3)

17--::

  All dance BtoB ; repeat passing LSh (2,1,3)

25--::

  3C RHA ; 3C LHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13475, '2020-12-25 16:39:07.146262+00', '2021-01-03 12:13:59.104526+00', 12366, 1, 1645, 'ace', '1-16::
  _*Chorus: 1-3 Broken Chain:*_ 1c+3c cross RH | change LH with corners ; repeat [1-4] 3 times _while{16}_ 2c & 4c dance as Gr-Chain 2 bars per hand, all ending in original places
17-::
  All set to P | change place RH ; set to P | change places LH
25-::
  Interlocking Reels4 as from centre places: start RSh loop round corner, through own place, LSh to P, etc. 1M & 3M end slipping into place
33-48::
  _*Chorus:*_ Repeat [1-16]
49-::
  1c+3c Reel4 up/down, M start passing LSh as W cast, W end facing out
57-::
  All W full Fig8 round P and corner, start RSh round P, 2W & 4W end slipping into place
65-80::
  _*Chorus: 2-4 Broken Chain:*_ Repeat [1-16] but with 2c+4c crossing & 1c+3c Gr-Chain
81-::
  2c+4c Reel4 across, M start passing LSh as W cast
89-::
  All M full Fig8 round P and corner, start RSh round P
97-112::
  _*Chorus:*_ Repeat [65-80]
113-::
  Intersecting (double) Reels4: W cast to start, all &frac12; LHA in centre, M end facing in on the sides, W end facing out at the corners of the square
121-::
  All circle8 clw & back with M facing in, W facing out. Retain RH with P for final chord
', 2);
INSERT INTO 'dancecrib' VALUES (13833, '2021-03-21 19:54:25.037901+00', '2021-03-22 12:54:03.422777+00', 12110, 1, 202, 'ace', '1--::
  1c+2c set | turn P BH opening to face up ; 1c cast off _while_ 2c dance to 1pl | 1c turn BH and face 1cnrs
9--::
  Corners Pass and Turn (2,1,3)
17--::
  All set | Reels3 across, 1c LSh to 1cnrs (2,1,3)
25--::
  1c+3c S&Link ; 3c+1c RHA (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (13834, '2021-03-22 12:01:16.711765+00', '2021-03-22 12:07:45.64534+00', 12117, 1, 202, 'ace', '1--::

  Circle10 and back

9--::

  1c & 3c lead down ; and up (1,2,3,4,5)

17--::

  1c & 3c cross RH | cast off (2c & 4c up) ; 2c+1M & 1W+4c+3M & 3W+5c RHA (2,1x,4,3x,5)

25--::

  1c & 3c cross LH | cast off (4c & 5c up) ; all turn P RH (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (13832, '2021-03-21 18:39:24.437358+00', '2021-03-24 17:35:35.273664+00', 7382, 1, 202, 'ace', '1--::
  1c+2c RHA ; LHA (1,2,3)
9--::
  1c cross RH | cast off (2c up) ; 1c turn LH 1¾ and face 1cnrs
17--::
  ½ Reel4 on 1diag, pass LSh ; ½ Reel4 on 2diag (3x,1x,2x)
25--::
  1c cross RH |dance RSh round 3cnrs[pos] into lines3 across ; change places RH on midline | dance RSh round 4cnrs[pos] to 2pl _while{8}_ 3c & 2c cross RH and face each other on sides | set ; change places RH | set to P (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13728, '2021-03-02 00:46:51.042766+00', '2021-03-07 14:56:09.842649+00', 10274, 1, 202, 'ace', '1--::
  All turn P RH ; chase clw ½ (4x,3x,2x,1x)
9--::
  All dance BtoB ; chase clw ½ (1,2,3,4)
17--::
  1c+2c & 3c+4c DblFig8, 1c & 3c crossing (1,2,3,4)
25--::
  ½ Reels4 (to 4,3,2,1) ; 4c+3c+2c ½ Reels3 on sides, 3c RSh to 4c (2,3,4,1)

*After four times through, Hoedown for Halloween is danced one more time as follows*:  
1--::
  All W face up and follow 1W  
  1W cross and face 1M | turn 1M BH and face next M ; repeat [3-4] with 2M then 3M and face down in front of 4M  
  _while_ 2W dance 1 place cclw | cross and face 1M ; turn 1M BH and face 2M | turn 2M BH and face down in front of 3M  
  _while_ 3W dance 2 places cclw ; cross and face 1M | turn 1M BH and face down in front of 2M  
  _while_ 4W dance 3 places cclw | cross and face down in front of 1M
9--::
  All W chase cclw ½ to places (1,2,3,4)

*E-crib in progress*', 2);
INSERT INTO 'dancecrib' VALUES (13597, '2021-01-29 08:16:09.873573+00', '2021-01-29 08:18:40.413547+00', 11697, 1, 202, 'ace', '1--::

  1c turn RH | cast off (2c up) ; 1c turn RH ½, face P and cast R to exchanged places. 1c face out (2,1x,3)

9--::

  1c dance RSh round 1cnrs to 2pl ; all turn P RH (2,1,3)

17--::

  Reels3 on sides, 1c RSh to 3cnrs. 1c face P on midline, 1M facing up

25--::

  1c Petronella turn to 2plx _while_ cnrs cross RH | all set (to 2x,1x,3x) ; all turn RH ½, face P and cast R to exchanged places (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3245, '2012-01-22 19:30:17.294811+00', '2021-03-21 19:57:48.072717+00', 8155, 1, NULL, 'ace', '{{explanation}}

All form one circle, M on the left of his P.  Walking step.



1–::

  All holding hands take 4 steps in | 4 back ; Repeat

9–::

  Men repeat (clap at end of bar 2) ; W repeat

17–::

  G-Chain for 7 bars (one hand per bar), finish with new P in promhold facing cclw

25–::

  All new C promenade cclw and form the circle again.', 2);
INSERT INTO 'dancecrib' VALUES (13491, '2020-12-31 13:58:43.322695+00', '2020-12-31 14:01:17.156576+00', 10253, 1, 1645, 'ace', '1-::

  1W followed by 1M dance down (2c up), out between 2W & 3W into tandem Fig8 round 3c, end facing up NHJ below 3c

9-::

  1c dance up to 2pl centre | turn BH to sides,  2c & 3c face clw on [12] ; all chase &frac12; way clw (3x,1x,2x)

17-::

  All S&Link3 twice (2,1,3)

25-::

  2c+1c *Non-progressive Rondel:*  

  [1-3] 1c dance up under arch by 2c dancing down, cross & meet NHJ on sides  

  [4-6] W cross under arch by M, cast up/down (_no crossing_) & meet NHJ facing down/up  

  [7-8] 1c dance down under arch by 2c dancing up *(both arches are made by 2c)*

', 2);
INSERT INTO 'dancecrib' VALUES (12846, '2020-05-26 11:38:53.405476+00', '2020-05-26 11:43:01.435814+00', 16769, 1, 202, 'ace', '1--::

  1c & 4c turn BH 1¼ to midline | 1c+4c ½ Reel4 to opposite sides | 4c & 1c set _while{2}_ 2c+3c ½ LHA (4x,3x,2x,1x)

9--::

  All chase cclw ½ | all dance BtoB (1,2,3,4)

17--::

  2c & 3c Fig8 out round ends (1,2,3,4)

25--::

  1c+2c change places, 1c in | 1c+3c repeat EH ; 1c+4c repeat EH | 1c set to P (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11374, '2018-12-12 18:30:16.742303+00', '2021-01-01 18:51:37.256086+00', 13640, 2, 342, 'ace', '{{title}}

Strathspey



1-8::

    All turn RH, all turn LH

9-16::

    All L Adv+Ret twice _while_ all M dance Figs of 8

    round prtnr and crnr (dancing behind prtnr to start)

17-24::

    All dance (interlocking) Ladies Chain across the

    set (L dance with half RA in the center)

25-28::

    1s & 3s dance 1/2 RL (end 1M & 3L facing 4s and

    1L & 3M facing 2s)

29-32::

    All dance 1/2 reels of 4 across

33-36::

    1s & 3s dance out through sides passing opp

    person RSh & chase round set clw to next place

    (3L follow 1M & 1L follow 3M)

37-40::

    3L & 1M and 1L & 3M turn RH 1 1/2

41-44::

    2s & 4s dance 1/2 RL (end 2M & 4L facing 1L &

    3M and 2L & 4M facing 1L & 3M)

45-48::

    All dance 1/2 reels of 4 across

49-52::

    2s & 4s dance out through sides passing opp

    person RSh & chase round set clw to next place

    (4M follow 2L & 2M follow 4L)

53-56::

    2L & 4M and 4L & 2M turn RH 1 1/2

57-60::

    All circle 8H round to left 1/2 way to the left

61-64::

    All turn prtnr 2H & circle 8H round to left 1/4 way



{{title}}

Jig



1-56::

    All repeat 1-56 with new partners

57-64::

    All circle 8H round & back

 ', 5);
INSERT INTO 'dancecrib' VALUES (2082, '2012-01-22 19:29:18.811591+00', '2021-01-02 13:44:08.141967+00', 13436, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; cross down through 3c and cast up (2,1x,3)

9–::

  ½ opposing Reels3 across, Lsh to 3cnr ; ½ opposing Reels3 across, Lsh to 1cnr

17–::

  Diagonal R&L, 1c starts with 3cnr, ie to the R (3x,1x,2x)

25–::

  All A&R ; ½ Circle6 L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13476, '2020-12-25 17:12:39.195078+00', '2021-01-02 16:06:32.657464+00', 12918, 1, 1645, 'ace', '1-::

  *Petronella progression:* 1c+2c Petronella 1 place cclw | set facing in diagonally ; Petronella 1 place cclw | cross LH with P (2,1,3)

9-::

  *Extreme crossover reels:* RSh Reels3 on sides, 1c starting in. On [11-12] 2c/3c cross down/up from 2pl, 2W & 3M passing in front of P, on [13-14] 1M/1W cross up/down from 2pl (2x,1x,3x)

17-::

  1W Fig8 up round 2c _while_ 1M Fig8 down round 3c

25-::

  Repeat [9-16] from opposite sides, 1c starting in, 2M & 3W passing in front of P when crossing (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3592, '2012-07-21 11:45:20.209309+00', '2021-03-22 12:39:42.776703+00', 8086, 1, NULL, 'ace', '1–::

  1c+2c Circle4 and back

9–::

  1c lead down the middle and up

17–::

  1c+2c Poussette

25–::

  2c+1c R&L (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (13228, '2020-10-10 02:01:55.198982+00', '2020-10-15 05:02:37.654946+00', 20121, 1, 202, 'ace', '1--::
  1c NHJ Fig8, 1M(1W) with 2c/3c, taking hands on [4] (1,2,3)
9--::
  »Triangular Knot« [: turn P RH ½ into allemande hold facing out | dance cclw one place releasing hands end of [12] ; turn P LH ¾ and face P, all M BtoB in centre]
17--::
  All set | All M dance clw two places _while{2}_ all W dance cclw one place, all M BtoB in centre facing P ; all set | turn P RH ¾ to places (3,1,2)
25--::
  Circle6 and back', 5);
INSERT INTO 'dancecrib' VALUES (12845, '2020-05-26 01:19:51.825956+00', '2020-05-26 01:26:51.756684+00', 18714, 1, 202, 'ace', '1--::
  Mirror Reels3, 1c crossing to 2pl (1x,2,3)
9--::
  1M+3M cross RH | 1M+2M change places LH ; 1W+3W cross RH | 1W+2W change places LH (3x,1,2)
17--::
  3c ½ Fig8 down round 1c ; 1W+2W & 1M+3M S&Link (1M,3M,2M on Mside, 3W,2W,1W on Wside)
25--::
  3C Bourrel. On [31-32] all turn P RH to sides (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3495, '2012-01-22 19:30:27.822933+00', '2020-05-26 19:54:37.471935+00', 11191, 1, NULL, 'ace', '1–::

  1c cross down behind 3c, cast up, lead up the middle cross and cast (2c up) to (2,1,3)

9-24::

  1c cross RH and cast R ; cross up/down RH and cast R . Repeat these 8 bars   _while{16}_ 2c+3c R&L with strathspey steps

25–::

  All Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (14944, '2022-07-08 14:00:10.695569+00', '2022-07-08 14:00:37.133687+00', 20938, 1, 1645, 'ace', '1--::

  *The Snail:* 1W leads other W across & into Circle4 to R (all but 1W+4W join hands) ;

  1W leads other W across & down M side

  _while{8}_ 4M leads other M across & into Circle4 to R (all but 4M+1M join hands) ;

  1M leads other M across & up W side (4x,3x,2x,1x)

9--::

  4c+3c & 2c+1c LHA ; RHA

17--::

  All &frac12; RSh Reels4 on sides (1x,2x,3x,4x) ; 1c cast to 4pl (2c+3c+4c up on [23-24])

25--::

  Circle8 to L (6 bars) | all cross RH (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (2417, '2012-01-22 19:29:37.227927+00', '2020-12-25 21:41:06.100175+00', 13500, 1, NULL, 'ace', '{{explanation}}

4 women + 2 men in a 3c set, W facing W in 1pl and 3pl, M facing M in 2pl.



1–::

  All W petronella to midline | Set to W facing ; turn that W RH to join LH in the middle

9–::

  The M+middle W LHA _while{4}_ the outer W chase ½ clw ; turn W RH ¾ to sidelines (all W have now moved 1 place clw round the square)

17-32::

  Repeat from new places (all W are now diagonally opposite starting places)

33–::

  The M turn RH ½ | BiL with 1cnrs ; turn 1cnr LH ¾ to finish in 2plx

41–::

  The M turn LH ½ | BiL with 4cnrs ; turn 4cnr RH to finish facing 1cnr

49–::

  Corners Chain: (change place RH with 1cnr | cnrs turn LH in the middle _while{2}_ the M set diagonally ; change back RH with cnr | the M turn LH 1¼ to face 2cnr _while{2}_ 1st corners set)

57–::

  Repeat with 2cnrs, finishing in 2pl

65-96::

  Repeat [1-32] from new positions (to starting positions)', 2);
INSERT INTO 'dancecrib' VALUES (10547, '2018-03-24 00:34:10.914273+00', '2021-05-01 21:04:27.069674+00', 2846, 2, 1, 'ace', '1–:: All BtoB twice

9–:: All turn R then L (linked arms)

17–:: 1c run down to 4c (1 step), turn R 1½ (1 step) | turn 4c L, ptr R  ;

    3c L, ptr R | 2c L, ptr R

25–:: 1c make arch, run down across kneeling Ms (who clap) ;

    1c run up across kneeling Ls (who clap)

33–:: _The Shuttle:_ All in middle w/BH hold. 1c dance towards Ms side

    and back in between 2c and 3c _while_ 2c+3c+4c dance towards Ws side

    and back ; R w/3c+4c | R to fin below 4c ; 2c+3c+4c retire as 1c run up to

    top

41–:: _The Loom:_ 1c&3c face down, 2c&4c up making arch.

   All dance under/over (1 bar per change);

  cpls at ends take 1 bar to turn about individually and start again.

49–:: _Threading:_ W move slightly to L, cross L arm over R,

  join LH w/ptr, RH w/next M (M do not cross arms).

  4L leads string of dancers up the middle under arms, then

  [from bar 53] acw behind M''s line into circle

57–72:: _Winding the Bobbin:_ 1M stands still while 4W leads string

  of dancers round him in a spiral (8 bars).  

  1M dives between 4c and leads string clockwise to reform circle.

73–:: All 1½ turn ptr RH (linked arms) | R w/next person LH ;

  R w/next person RH | R w/next person LH (meet ptr)

81–…:: All turn ptr BH (crossed arms) | going acw on circle move towards

  exit and leave



*8-bar phrasing is suggested but not always feasible.*', 3);
INSERT INTO 'dancecrib' VALUES (11887, '2019-06-11 21:11:17.929301+00', '2021-01-02 16:04:44.471877+00', 19394, 1, 1645, 'ace', '1-::
  1c & 5c cast in (2c & 4c out) | cross LH  ; cast LSh round 2cnr & end facing 1cnr RSh to P
9-24::
  *Dance to corners and set if you get there:*  
  _9-10_: Dancers in centre change places with 1cnrs passing RSh, 1cnrs pass RSh to face 2cnrs _while_ 2cnrs set in 1W[pos] & 5M[pos]  
  _11-12_: New dancers in centre repeat with 2cnrs _while_ those now in 1M[pos] & 5W[pos] set  
  _13-24_: Repeat pattern of [9-12] three more times, setting only in 1pl & 5pl. 1M & 5W never reach the far corners.
           4c, 3c & 2c end in 1plx, 3plx, 5plx. 1c & 5c end facing 1cnrs, M in top half, W in bottom half of set, 5c facing up, 1c down
25-28::
  5M & 1W, each followed by P, dance out nearest side, cast LSh round 3c & cross to (4x,1x,3x,5x,2x)
29-32::
  4c+1c+3c+5c &frac12; Reels4 on sides (5x,3x,1x,4x,2x)
33-36::
  3c+1c & 4c+2c S&Link, on [36] 3c & 2c pass RSh to (5x,1x,2x,3x,4x)
37-40::
  All set | cross to (5,1,2,3,4) with 5c & 4c facing out for the repeat
', 5);
INSERT INTO 'dancecrib' VALUES (13598, '2021-01-29 09:47:41.975113+00', '2021-01-29 09:56:54.385575+00', 11698, 1, 202, 'ace', '1--::

  1W+3M turn BH (Skip ch) ; 1M+3W repeat (1,2,3)

9--::

  2c  turn BH (Skip ch) ; 1c long cast to 2pl (2c up) (2,1,3)

17--::

  1c ½ Fig8 R round 1cnrs ; pass P RSh into DTr position | all set

25--::

  ½ Reels3 on sides, 1c RSh to 3cnrs ; ½ Reels on opposite side, 1c RSh to 1cnrs[pos]. 1c pass RSh to 2pl (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (12847, '2020-05-27 01:51:06.16947+00', '2020-05-27 01:53:41.905207+00', 19862, 1, 202, 'ace', '1--::

  All Adv {2} and clap | Retire {2} ; all turn P RH

9--::

  All M Fig8 cclw, in front of P, behind and around next W to places

17--::

  All W Fig8 clw, in front of P, behind and around next M to places

25--::

  All C change places LH | birl (elbow grip) with new P. All face in, W on M''s right 

', 2);
INSERT INTO 'dancecrib' VALUES (1576, '2012-01-20 13:06:12.735979+00', '2021-03-22 12:45:45.62356+00', 8084, 2, 1, 'ace', '1-8::

   1s and 2s set twice; 1s and 2s BtB

9-12::

   1s cross R, cast off (2s up)

13-16::

   1s turn 1½ R to own sides

17-24::

   Circle4

', 3);
INSERT INTO 'dancecrib' VALUES (13381, '2020-12-01 04:38:35.773528+00', '2020-12-01 04:43:15.727185+00', 7331, 1, 202, 'ace', '1--::

  1c set | dance down between 3c, cross and cast up to 2plx (2c up) (2,1x,3)

9--::

  1c Petronella Turn | set _while{4}_ cnrs  set up/down | change places RH (no polite turn) ; ½ Reels3 across, 1c RSh RSh to 3cnrs[pos]. 1c pass RSh and face 4cnrs[pos]

17--::

  1c turn 4cnrs[pos] LH ; turn 3cnrs[pos] RH ¾ into facing lines3 across

25--::

  1c Petronella Turn | set _while{4}_ 3c & 2c set to P | cross RH ; ½ Reels3 on sides, 1c RSh to 4cnr[pos] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13603, '2021-01-30 07:18:59.932483+00', '2021-01-30 07:22:44.681546+00', 11702, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; pass P RSh | 1c+3c change places EH (2,3,1)

9--::

  Mirror Reels3 on sides, 1c in and up, 3c out and down. 1c face up. 3c face down (2,3,1)

17--::

  3c+1c dance 6 bars of R&L up/down | turn LH ready for (2,3,1)

25--::

  3c+1c Poussette (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3270, '2012-01-22 19:30:18.361974+00', '2020-12-25 21:47:06.065875+00', 13517, 1, NULL, 'ace', '1-12::

  1W, the other W following, cross, cast behind 1M, in front of 2M & 3M, behind 4M, cross and dance up to places

13-16::

  1W+2W & 3W+4W Turn RH _while{4}_ 1M+2M & 3M+4M Turn LH

17-32::

  The M repeat [1-12] round the W ; All repeat [13-16]

33–::

  1c lead down (other C up on [35-36] ; 1c Turn RH (2,3,4,1)

41–::

  Circle8 and back.



{{explanation}}

At end of final circle dance into centre with hands in the air and shout Hooray', 3);
INSERT INTO 'dancecrib' VALUES (10594, '2018-04-07 19:54:25.282643+00', '2021-06-21 10:46:03.350932+00', 1192, 2, 1, 'ace', '1–:: 1c Fig8 round 2c

9–:: 1c set, cross R, set, cross R _while_ 2c Fig8 round 1c

17–:: 2c set, cross R, set, cross R _while_ 3c Fig8 round 2c

25–:: 3c set, cross R, set, cross R _while_ 4c Fig8 round 3c.

    On 29–32, 1c ½ Fig8 round 2c _while_ 2c set, cross R.

    [2c&3c fin facing out]

33–:: 2M+3L Fig8 round 1L&4L''s pls [dancing out to start, 3L has precedence]  

    _while_ 2L+3M Fig8 round 1M&4M''s pls

    [dancing out to start, 2L has precedence]  

    _while_ 1c&4c cross R | set facing up/dn | 1c dance to 4pl under arch

    made by 4c as 4c dance up to 1pl

41–:: 2M+3L, 2L+3M continue Fig8 ; meet ptr at end of set NH and set |

    ½ turn opp RH into sidelines in 2pl, 3pl [M have long turn]  

    _while_ 1c&4c set to ptr | set adv facing up/dn ; pass RS to orig pl | stand

49–:: 1c cross RS _while_ 2c+3c+4c set | 1c cast off

    _while_ 2c cross up, 3c+4c cross over RS ; 1c cross RS _while_ 3c+4c set

    | 1c cast off _while_ 3c cross up, 4c cross over RS

57–:: 1c cross RS _while_ 4c set | 1c cast off _while_ 4c cross up RS ;

    1c set | 1c cross RS [NB. On 49–64, no hands are given on crossing]', 3);
INSERT INTO 'dancecrib' VALUES (1770, '2012-01-22 19:29:01.442641+00', '2021-01-30 10:53:29.507006+00', 11109, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up), finishing just inside sidelines ; set | turn BH to finish NHJ (M on L) facing 2W

9–::

  1c+2W set | 1W dances under P''s arm so 1c face 3M ; in promhold Rsh ½ Reel3 with 3M+2W, finish NHJ facing 3W

17–::

  1c+3W set | 1W dances under P''s arm so 1c face 2M ; in promhold Rsh ½ Reel3 with 2M+3W, on [24] 3c+2c dance in so all C face down in the middle.

25–::

  3c+1c+2c »upside down« allemande {6}| 2c+1c+3c turn ½ RH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13836, '2021-03-22 22:03:22.002673+00', '2021-03-27 13:00:17.360949+00', 20256, 1, 202, 'ace', '1--::
  1c set | 1M set advancing to P (PdB) _while_ 1W set. 1c join RH ; 1c RHJ dance towards Mside (PdB) | 1c set, 1W pivoting R under RHJ to face Wside
9--::
  ½ Reel3 in tandem across (no lead change), 1W RSh to 2W. 2c finishes in 1plx, 1c finishes on 2diag facing 3M ; ½ Reel3 in tandem across (no lead change), 1W RSh to 3M (2x,1,3x)
17--::
  All chase clw ½ (to 3,1x,2) ; turn P RH into allemande hold. 3c & 2c face up, 1c face down (3,1x,2)
25--::
  3C Circulating Allemande. On [31-32] 1c turn outwards and face down NHJ (2,1x,3)
33--::
  1c dance down between 3c | cast up ; lead up between 2c | cross and cast to 2pl (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (13505, '2021-01-03 15:47:31.166205+00', '2021-01-03 15:48:20.427992+00', 13229, 1, 1645, 'ace', '*Start with four dancers (1,2,3,4) in a line up/down as if ready for a reel of four*

1-::

  All petronella to form a square | dancers 1+2 change RH ;

  1+3 cross diagonally LH | 1+4 turn &frac12; RH, end 1+4 NHJ facing up to 3+2 NHJ facing down

9-::

  *Modified S&Link:* All set | LH ends (3&4) turn &frac34; LH in centre

  _while_ RH ends (2&1) cast &frac14; clw to form line across (L to R: 2,3,4,1) ;

  all &frac12; RSh Reel4 across

17-::

  Dancers 1+4 & 3+2 turn _&frac34;_ RH | set facing up/down, on [20] turn to face across NHJ

  *(now in same formation as [9] rotated &frac14; cclw)* ; repeat modified S&Link to form line up/down (2,3,4,1)

25-::

  All &frac12; RSh Reel4 up/down ; dancers 1+4 & 3+2 turn _&frac12;_ RH | set facing up/down (4,1,2,3)

', 2);
INSERT INTO 'dancecrib' VALUES (8146, '2014-01-05 22:26:56.375366+00', '2022-11-18 11:51:31.868601+00', 14472, 1, NULL, 'ace', '1–::

  1W+3M set _while_ 1M & 3W dance in LSh to each other, 1M/3W facing down/up | ½ diag. Reel4 | 1W+3M cast clw behind 2c _while_ 1M+3W dance out to sideline pulling RSh back (1x,2,3x)

9–::

  Repeat from new positions (1,2,3)

17–::

  1c+2c turn 1½ RH on sides ; 1c dance between 3c and cast up (2,1,3)

25–::

  All Allemande R (advance & take RH, W dances under joined arms to face own side, dance to places, M retiring) ; All turn RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13508, '2021-01-04 04:10:04.53805+00', '2021-01-04 04:11:54.353836+00', 16512, 1, 202, 'ace', '1--::

  1c cross over RH between 2c, behind 3c, meet and cross up RH between 3c, behind 2c to 1pl centre. On [8] 2c step in

9--::

  2C Poussette (2,1,3)

17--::

  2c+1W & 1M+3c RHA ; 1c ½ Fig8 round2cnrs to centre BtoB, 1M facing 2c

25--::

  DTr (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11410, '2018-12-21 00:52:47.821807+00', '2021-01-04 12:05:19.853528+00', 11018, 1, 202, 'ace', '1--::

  All set | 1c & 3c turn RH ¾ to midline ; 1c+3c ½ Reel4

9--::

  3c & 1c turn RH ¾ | all set ; 3c+2c & 1c+4c ½ R&L (2x,3x,4x,1x)

17--::

  All set | 2c & 4c turn RH ¾ to midline ; 2c+4c ½ Reel4

25--::

  4c & 2c turn RH ¾ | all set ; 4c+3c & 2c+1c ½ R&L (3,4,1,2)

33--::

  4c+1c ½ R&L ; set | cross RH (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (13514, '2021-01-06 14:12:30.52179+00', '2021-04-02 22:02:19.519007+00', 11643, 1, 202, 'ace', '1--::

  1c cross RH | cast off to 3plx (2c+3c up) (to 2,3,1x) ; 2c cross RH | cast off to 3plx (3c+1c up) (3,1x,2x)

9--::

  3c cross RH | cast off to 3plx (1c+2c up) (to 1x,2x,3x) ; all turn P RH 1½ into promhold (1,2,3)

17--::

  3C Promenade (1,2,3)

25--::

  1c+2c turn EH 1½ on sides, 1c in ; 1c+3c turn EH 1½ on sides (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10041, '2017-08-09 14:04:24.291681+00', '2022-07-08 22:26:56.260689+00', 17918, 1, 1645, 'ace', '*On 2nd chord, 1c & 2c cross to opposite sides (1x,2x,3,4)*
1-::
  1c+2c & 3c+4c Set and Rotate, 1W & 4W end facing out
9-::
  1c+4c LHA, finish as pairs 1M+4W & 4M+1W facing out sides in promhold ; &frac12; LSh Reels3 on sides
17-::
  1c+4c RHA, finish in promhold with P facing out on sides _while{4}_ 3c & 2c cross RH | set ; &frac12; RSh Reels3 on sides, 4c & 1c separate and face down/up
25-::
  4M+1W & 4W+1M turn BH on sides _while{2}_ 2c & 3c cross RH | all set on sides (2x,4x,1,3) ; Circle 8H &frac12; way to L (3x,1x,4,2)
', 3);
INSERT INTO 'dancecrib' VALUES (10737, '2018-05-03 08:13:51.640161+00', '2021-01-06 16:25:13.120572+00', 4174, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; 1c+3c RHA (2,1,3,4)

9--::

  2c+1c+3c Parallel Reels3 on sidelines, 1c start Lsh to 2c (2,1,3,4)

17--::

  1c set | cast (3c up) ; 1c+4c LHA (2,3,1,4)

25--::

  3c+1c+4c Parallel Reels3 on sidelines, 1c start Rsh to 3c (2,3,1,4)

33--::

  1c set | dance up (4c up) ; cast off round 2c to 4pl (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (2036, '2012-01-22 19:29:16.345657+00', '2021-01-07 00:21:22.792898+00', 12106, 1, NULL, 'ace', '1–::

  All set | 1c+2c & 3c+4c LHA to finish NHJ, 1c facing 2c and 3c facing 4c | All set

9–::

  1c+2c & 3c+4c Rondel, with 1c finishing in the middle (2,1,4,3)

17–::

  1c ½Fig8 round 4c ; 1c cross down (no hands) and face out as 4c dance up | 4W+1W & 4M+1M turn once easy hand  (2,4,1,3)

25–::

  Mirror Reels4 on the sidelines (W Rsh, Men Lsh) (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13516, '2021-01-07 14:58:50.383597+00', '2021-01-07 15:02:39.320135+00', 11656, 1, 202, 'ace', '1--::

  1c dance down and cast up round 3c to 2pl (2c up) ; 2c+1W & 1M+3c RHA. 1c face 1cnrs 

9--::

  Corners Pass and Turn ; repeat with 2cnrs. 1c passing P LSh in centre finish BtoB, 1M facing up

17--::

  2c+1M & 1W+3c Circle3 L. On [20], 1c pivot R to face P ; 1c set | Petronella turn (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2357, '2012-01-22 19:29:33.071907+00', '2020-05-27 06:33:40.687666+00', 2593, 1, NULL, 'ace', '1–::

  1c+2c+3c G-Chain

9–::

  1c+2c Poussette

17–::

  2c+1c+3c circle6 and back. 1c ends facing 1cnrs

25–::

  Set to and turn corners, pass Rsh to face own side for

33–::

  DTr', 2);
INSERT INTO 'dancecrib' VALUES (13494, '2020-12-31 17:09:58.481668+00', '2021-01-01 13:02:58.547766+00', 16411, 1, 1645, 'ace', '1-::
  1W+2M set adv | turn BH ; 1M+2W repeat
9-::
  1c set adv | turn BH ; long cast (2,1)
17-::
  1c in promhold Reel3 across with 2c, 1c end at the top with 2c behind them for
25-::
  1c+2c Allemande (2,1)
', 2);
INSERT INTO 'dancecrib' VALUES (9619, '2017-02-25 09:22:51.939256+00', '2021-01-01 19:47:54.990614+00', 9858, 1, 202, 'ace', '1--::

 Circle6 and back

9--::

 Inveran Reels3, all C crossing down from the top and up from the bottom (1,2,3)

17--::

 1c+2c LHA ; 2c+3c RHA

25--::

 2c followed by 1c dance down & cast to (2,1,3) ; 1c followed by 3c dance up & cast to (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (13506, '2021-01-03 16:11:59.041888+00', '2021-01-03 16:12:10.43306+00', 16518, 1, 1645, 'ace', '1-::

  1c set | cross RH ; cast off (2c up) | turn LH to face 1cnrs

9-::

  *Interrupted H&G Setting:* Set R to 1cnr {1} and L to P {1} | turn ¾ RH ;

  set R to 2cnr and L up/down to P | turn ¾ RH to 2pl facing out

17-::

  Reels3 on sides, 1c start RSh to 3cnr, end facing same person up/down

25-::

  2M+1M & 1W+3W dance BtoB on sides ; 1c turn RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10973, '2018-08-11 20:24:58.286629+00', '2021-01-04 12:21:00.03934+00', 15303, 1, 202, 'ace', '1--::

  1c followed by 2c who dance up lead down, 2c divide ; 1c followed by 2c lead up (1,2,3,4)

9--::

  1c+2c & 3c+4c 2C Knot (2,1,4,3)

17--::

  All W NHJ A&R {1+1} | All M repeat ; 4c+3c ½ R&L _while{4}_ 2c turn P RH ½, face P | cast R to exchanged places (2x,1,3x,4x)

25--::

  1c+3c ½ R&L _while{4}_ 2c turn P RH ½, face P | cast R to exchanged places (to 2,3,1x,4x) ; 1c+4c ½ R&L _while{4}_ 2c+3c Circle4 L (2,3,4,1)

33--::

  Circle8 and back (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (13510, '2021-01-05 15:30:16.054345+00', '2021-01-05 15:31:29.166846+00', 16697, 1, 1645, 'ace', '1-::

  1c & 3c cross RH | cast off (2c & 4c up) ; 1c & 3c turn 1&frac14; LH into promhold facing 4W & 5W

9-::

  1c & 3c in promhold RSh Reels3 on 1st diagonal, end facing 2W & 4W

17-::

  1c & 3c in promhold RSh Reels3 on 2nd diagonal, end facing up retaining hands

25-::

  1c & 3c dance up | cast off ; turn RH | cast off (4c & 5c up) to (2,4,1,5,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13600, '2021-01-29 22:55:33.461161+00', '2021-01-29 23:00:48.43227+00', 20210, 1, 202, 'ace', '1--::

  1c+2c ½ R&L ; 1c+3c ½ R&L (2x,3x,1)

9--::

  1c set | lead up to top ; cross and cast off (3c down) (2x,1x,3x)

17--::

  Mirror Reels3 on sides, 1c in and down, all touching hands when possible (2x,1x,3x)

25--::

  ½ Reels3 across, 1c LSh to 3cnrs[pos] (to 2,1,3) ; 1c turn RH twice (or Birl) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14087, '2021-06-21 11:11:27.767839+00', '2021-06-21 11:13:30.443477+00', 1954, 1, 1645, 'ace', '1--::

  1c+2c & 3c+4c &frac12; R&L ; turn P RH, 1c & 3c to face 1cnrs, 2c & 4c 1&frac12; to own side (2,1,4,3,5)

9--::

  1c & 3c set to 1cnrs | turn 1cnrs RH & join LH with P ; BiL with 1cnrs | turn P LH to face 2cnrs

17--::

  Repeat [9-16] with 2cnrs, 1c & 3c end on midline W facing down, M up

25--::

  1c+3c Reel4 on midline

33--::

  1c & 3c turn &frac34; LH | lead up ; cast off 1pl | lead down 1pl (4c & 5c up)

41--::

  All A&R ; turn P RH (2,4,1,5,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12487, '2020-01-07 22:58:24.535202+00', '2021-01-08 11:49:35.036613+00', 12856, 2, 160, 'ace', '1-8::  1s+2s set, 1s cast as 2s dance up; 1s 3s hands round to the left.

9-16::  1s set, half fig.8 up round 2s [4], 1s turn BH face 1cors.

17-24:: 1s set to corner&partner (Hello-Goodbye) - Petronella turn to 2nd place own sides facing OUT.

25-32::  Rsh reels3 on own side.', 0);
INSERT INTO 'dancecrib' VALUES (13604, '2021-01-30 13:50:04.283393+00', '2021-01-30 13:53:24.308866+00', 14377, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; cross LH | cast L into facing lines3 across

9--::

  3C S&Link ; repeat

17--::

  All change places RH | 1c cast R to 2pl _while{2}_ cnrs cross LH (to 2,1,3) ; all set | A&R {1+1}

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13837, '2021-03-23 09:46:30.674716+00', '2021-03-26 10:16:45.566755+00', 7412, 1, 202, 'ace', '1--::
  1c cast off (2c up) | cross LSh ; 1c dance RSh round 1cnrs and face 1cnrs on 1diag
9--::
  1c+1cnrs set | change places RH ; 1cnrs (2M & 3W) turn LH 1¾ and face own P on 2diag
17--::
  2c & 3c set | change places RH ; 2cnrs (2W & 3M) turn LH 1¾ and face 1c on 1diag
25--::
  2cnrs (now in centre) & 1c (now in 1cnrs[pos]) set | change places RH ; 1c turn P LH 1¾ to 2pl _while{4}_ 2c & 3c set to opposite person and face cclw on PdB L | chase cclw 1 place (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (1873, '2012-01-22 19:29:07.375193+00', '2021-06-22 19:16:39.883681+00', 910, 1, NULL, 'ace', '1–::

  1c set | 1M, 1W following, cast off and cross to 2plx (2c up) | 2c+1c set (2,1x,3)

9–::

  1c set | 1W, 1M following, cast off and cross to 3pl (3c up) |3c+1c set (2,3,1)

17–::

  1c dance to top, cast off ; dance between 3c, cast up to face 1cnr (3c down)

25–::

  Set to and turn cnrs

33–::

  Lsh Reels3{6} with cnrs | 1c cross to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10310, '2017-12-12 15:11:22.489262+00', '2021-01-30 11:04:00.605763+00', 11046, 1, 202, 'ace', '1--::

  All set to P | turn P RH ; all set to cnrs | turn cnrs LH

9--::

  ½ Gr-Chain with 2 steps per H

17--::

  1c+3c ½ R&L ; 2c+4c ½ R&L (1,2,3,4)

25--::

  1M+2W & 1W+2M turn RH ½, into RHA position | RHA, ending with RHJ with P | turn P RH ½, 1c in 2pl, 2c in 1pl _while{8}_ 3M+4W & 3W+4M turn RH ½, into RHA position | RHA, ending with RHJ with P | turn P RH ½, 3c in 4pl, 4c in 3pl (2,1,4,3)

33--::

  Circle8 and back

41--::

  All Petronella turn with P | set ; repeat [41-44]

49--::

  Repeat [41-48] into promhold facing cclw (2,1,4,3)

57--::

  All Promenade cclw



Repeat 3 times from new positions.



* On [25-32] 2nd time, 1c+4c & 2c+3c dance in the other diagonal (to 3,4,1,2)

* On [25-32] 3rd time, 3c+4c & 2c+1c dance in the original diagonal (1st time) (to 4,3,2,1)

* On [25-32] 4th time, 3c+2c & 4c+1c dance in the other diagonal (2nd time) (to 1,2,3,4)', 4);
INSERT INTO 'dancecrib' VALUES (14839, '2022-05-29 07:28:37.019673+00', '2022-05-29 08:48:47.436712+00', 20869, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 2c+1M & 1W+3c RHA (2,1x,3)

9--::

  Circle6 and back (2,1x,3)

17--::

  1c set | turn P LH ¾ into facing lines3 across ; all set | change places RH with opposite person and face clw

25--::

  All chase clw ½ ; 1c turn P RH 1¼ to 2pl _while{4}_ 2c&3c set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15250, '2022-11-19 11:15:49.429316+00', '2022-11-19 11:25:13.346008+00', 20749, 1, 202, 'ace', '_Strathspey_

1--::

  1c+2c Tourbillon (2,1,3)

9-12::

  2c+1W & 1M+3c RHA

13-24::

  3C R&L 

25-32::

  Circle6 and back (2,1,3)



_Reel_

33-64::

  Repeat [1-32]', 2);
INSERT INTO 'dancecrib' VALUES (13515, '2021-01-06 17:40:35.9079+00', '2021-04-03 11:31:43.356203+00', 11644, 1, 202, 'ace', '1--::

  All A&R ; all dance BtoB with P

9--::

  All turn P RH ; all turn cnrs LH

17--::

  All M RHA ; all M turn P LH 1¼ to places

25--::

  All W RHA ; all W turn cnrs (new partner) LH ¾.



*Deviser''s note:  

On bars 3-4 & 7-8, Beginners may use walking steps to avoid the need to retire with skip change of step.*', 2);
INSERT INTO 'dancecrib' VALUES (14088, '2021-06-21 22:52:06.742785+00', '2021-06-21 22:54:00.997532+00', 1511, 1, 1645, 'ace', '*3c & 4c start on opposite side (1,2,3x,4x)*

1--::

  2c & 3c step to ends on [1-2] _while{8}_ 1c & 4c parallel "Figure of 6" (&frac34; Fig8) on sides: 1M & 4M start in RSh to 2M/3M as 1W & 4W cast round 2W/3W, give RH in passing & curve round other end to (2,4x,1,3x)

9--::

  2c+4c & 1c+3c turn LH on sides ; 4c+1c RHA & face cnrs _while{4}_ 2c & 3c chase &frac12; way cclw (3,4x,1,2x)

17--::

  Set to & turn 1cnrs/2cnrs LH/RH (4c & 1c out the ends) to sidelines ; 1c & 4c set | cross RH (3,4,1x,2x)

25--::

  3M+4M+1M+2M RSh Reel4

33--::

  3W+4W+1W+2W LSh Reel4

41--::

  4c+1c &frac12; R&L, retain LH & give RH to ends ; all BiL | 3c+1c & 4c+2c turn RH on sides ready to start again (3,1,4x,2x)

', 2);
INSERT INTO 'dancecrib' VALUES (10617, '2018-04-16 07:58:01.915657+00', '2021-01-01 20:04:00.308462+00', 13926, 1, 202, 'ace', '1--::

  1c+2c set | 6 bars of R&L. On [7-8], 1c turn RH to face 1cnrs

9--::

  1c 4 bars of SetH&G ; ½ Reel4 on 2diag, pass P Lsh to face 3cnrs

17--::

  1c 4 bars of SetH&G ; ½ Reel4 on 2diag, pass P Lsh to face 1cnrs

25--::

  1c+1cnrs Corner Chain with Setting. On [31-32] 1c turn LH ¾ to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12472, '2020-01-04 17:13:25.652954+00', '2022-01-14 20:38:51.232826+00', 11969, 1, NULL, 'ace', '1--::

  Circle8 L ½ round ; All W ½ RHA | Turn opposite M LH 

9--::

  All W ½ RHA | All turn P LH to square set ; Circle8 R ½ (1,2,3,4)

17--::

  All M ½ LHA | All turn opposite W RH ; All M ½ LHA | All turn P RH ¾, M face in and W out  (1,2,3,4)

25--::

  Half Schiehallion Reel, finish in big star, all M LHJ in centre and NHJ with P, all facing cclw (3,4,1,2)

33--::

  In big star 3/8 LHA | all M 3/8 LHA as all W cast back 1/8 clw and form new big star ; repeat figure, finish in square set, all in P''s place, W facing in, M facing out,  (1x,2x,3x,4x), 

41--::

  Half Schiehallion Reel, finish in big star, all W LHJ in centre and NHJ with P, all facing cclw (3,4,1,2)

49--::

  Repeat [33-40] , with W in the middle and M casting, finish all W in centre facing P outside (1,2,3,4) 

57--::

  1c+3c ½ Reel4 ; turn P RH _while{8}_ 2c+4c turn P RH ; ½ Reel4 (3,4,1,2)

65--::

  Repeat [57-64] (1,2,3,4)

73--::

  *You devise the ending!  (one event in 2004 chose: Circle8 and back.)*  





', 4);
INSERT INTO 'dancecrib' VALUES (13004, '2020-08-01 06:11:51.831922+00', '2021-08-02 03:21:17.815494+00', 20056, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; ½Fig8 R to 2plx (2,1x,3)

9--::

  Reels3 on sides, 1c RSh to cnrs on their right (2,1x,3)

17--::

  All dance BtoB ; all chase clw ½ (3x,1,2x)

25--::

  1c Petronella turn | set ; repeat (3x,1x,2x)



*Deviser''s Note:  

The second time through, 1st couple starts from 2nd place* _on partner’s side_*, finishes in 3rd place on own side and then moves to the foot of the set. The original 3rd couple starts next* _from partner’s side_*, then the second time through dances from own side, finishing in 3rd place* _on partner’s side_ *and moves to the foot of the set* _on that side_*. The original 2nd couple starts from partner’s side and the original 4th couple from own side.*', 5);
INSERT INTO 'dancecrib' VALUES (13507, '2021-01-03 16:31:42.180535+00', '2021-01-03 16:39:28.027621+00', 14791, 1, 202, 'ace', '1--::

  2c (1c following) slip down | set ; slip up | 1c cast off, 2c dance to 1pl (2,1,3)

9--::

  1c+3c turn EH, 1c in ; 1c+2c turn EH, 1c in. 1c face 1cnrs

17--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on2diag (3x,1x,2x)

25--::

  3C S&Link (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10232, '2017-11-06 23:14:44.386105+00', '2021-01-04 12:32:23.548819+00', 17694, 2, 1, 'ace', '1–::

  1c+2c dance Espagnole [1c fin facing 4th corners]

9–12::

  1c+4th corners dance ½ reel4

  [at end 1c pass RS to fin in ctr,  1M facing down, 1L up]

13–16::

  1c turn ¾ BH | set adv passing LS to 1st corners

17–::

  Dance to corners and set {6} [1c fin facing 2nd corner pos]

  | 1c turn ½ RH and pivot right about [fin in ctr facing opp sides]

   _while_ corners set to person diag opp

25–::

  1M+2c, 1L+3c dance RH across ;

  1L followed by 3C dance down to 3M''s place, across and up

  _while_ 1M followed by 2C dance up to 1L''s place, across and down

  – pass LS to begin (“snake” movement) [213]', 3);
INSERT INTO 'dancecrib' VALUES (13511, '2021-01-05 15:44:40.675855+00', '2021-01-05 15:46:56.325523+00', 9446, 1, 1645, 'ace', '1-::

  1c set | cast off (2c up) ; &frac12; Fig8 RSh round 2cnrs to face 1cnrs

9-::

  1c+1cnrs &frac12; LSh diag Reel4, 1c pass LSh ; 1c+2cnrs &frac12; RSh diag Reel4 to face 1cnr[pos]

17-::

  1c set to 1cnr[pos] | dance RSh round P to face 2cnr[pos] ; set to 2cnr[pos] |  dance RSh round P to sides (3x,1,2x)

25-::

  1c set, pulling RSh back to face clw _while{2}_ 3c & 2c cross RH | all chase &frac14; clw to lines across ; change pl RH with P |  chase &frac14; clw (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2093, '2012-01-22 19:29:19.39114+00', '2021-01-30 11:09:44.71964+00', 11013, 1, NULL, 'ace', '1–::

  1c cross down into 1c+2c+3c mirror Reels3 on the sides (to 1x,2,3, 1c facing down NHJ)

9–::

  1c dance down | 1M dances below 1W who passes under his arm ; 1c dances to top and casts off (2c up) (2,1,3)

17–::

  2c+1W & 1M+3c RHA ; 1c turn LH 1½ _while_{4} others chase clw ½ round

25–::

  3c+1M+& 1W+2c RHA ; 1c turn LH 1¼ and face up _while_{4} others chase clw ½ to places

33–::

  1c dance to top | cast off to between 3c (touch hands), Turn 3c EH ¾ to (2,1,3)



{{explanation}}

on 2nd time though turn 3c EH 1¼ to finish 2,3,1, flowing into the new reels for 2 & 3', 3);
INSERT INTO 'dancecrib' VALUES (10206, '2017-10-26 19:42:23.00526+00', '2021-01-08 18:00:04.218474+00', 12846, 2, 160, 'ace', '1-8::  1s set, cast ; dance between 3s & cast up to 2place.

9-16::  1s dance back-to-back ; 2s 1s 3s invert the lines- they set advancing & pull Rshoulder back to face away from partner, 2s+3s set advancing out to sideline while 1s set moving around partner to face 1corners.

17-24::  1s dance diagonal half reels of four with 1corner - pass Rshoulder in the middle; dance diagonal half reel of four with 2corners - end on opp. side.

25-32::  all dance Set&Link3 twice to end on own sides.', 3);
INSERT INTO 'dancecrib' VALUES (14945, '2022-07-08 14:20:56.288126+00', '2022-07-08 14:21:11.114889+00', 20941, 1, 1645, 'ace', '1--::

  1c cast below 3c | dance up to 2pl centre (2c up) ;

  1W dances up | casts off to 2pl facing in

  _while{4}_ 1M casts off round 3M | crosses up to 2pl facing out, 1c take LH with P

9--::

  2W+1c+3W BiL | 2W+3W dance track of &frac12; RSh Reel with 1c

  _while{4}_ 1W crosses up & casts off round 2M to 2pl facing in

  _while{4}_ 1M dances 2 bars of Reel | crosses up to 2pl facing out, 1c take RH with P |

  2M+1c+3M BiL

17--::

  2M+1c+3M &frac12; LSh Reel4 on sides, 1c end RSh to P on centre line facing own side ; 3c+1W (top) & 1M+2c LHA

25--::

  1W+3c & 1M+2c Snake Pass (2,1x,3) ; 1c turn 1&frac12; RH or swing (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12848, '2020-05-28 11:36:31.897014+00', '2020-05-29 07:22:39.342703+00', 1591, 1, 202, 'ace', '1--::
  1c+2c & 3c+4c Circle4 L ; 2c+3c ½ R&L (1,3x,2x,4)
9--::
  Mirror Reels4, RSh on Mside, LSh on Wside (1,3x,2x,4)
17--::
  1c+3c & 2c+4c DblFig8, 1c & 2c leading down (1,3x,2x,4)
25--::
  2c+3c ½ R&L ; 1c lead down to 4pl _while{4}_ 2c+3c+4c set | dance up one place (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (13601, '2021-01-29 23:10:43.739927+00', '2021-01-29 23:16:16.753524+00', 20211, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; turn P RH 1¼

9--::

  2c+1M & 1W+3c LHA to sides (to 2,1,3) ; all A&R (2,1,3)

17--::

  1c dance down ; and up to 2pl (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (1990, '2012-01-22 19:29:13.819336+00', '2021-06-21 23:16:12.901858+00', 1368, 1, NULL, 'ace', '1–::

  1c cast off 2 (2c+3c up) | set ; cast back to top (2c+3c down) | set

9–::

  1c lead down the middle (2c up) ; and up to face 1cnr

17–::

  1c set to and turn 1cnr ; set to and turn 2cnr

25–::

  1c 1½ RH turn to 2pl ; 2c+1c+3c Turn RH  (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13512, '2021-01-05 16:16:47.669549+00', '2021-01-05 16:17:00.757065+00', 15419, 1, 1645, 'ace', '1-::

  All adv NHJ with P | ret NHJ with corner ; all S&Link

9-::

  Repeat [1-8] from new places, W end facing out

17-::

  &frac12; Schiehallion reel

25-::

  W &frac12; RHA | complete loop LSh around opposite M & return to original place

33-::

  M &frac12; LHA | complete loop RSh around opposite W & return to original place

41-::

  1c+3c &frac12; R&L ; 2c+4c repeat (3,4,1,2)

49-::

  1c+3c &frac12; RHA | twirl, pulling RSh back, out to place ; 2c+4c repeat

57-::

  Circle8 & back (1,2,3,4)

', 2);
INSERT INTO 'dancecrib' VALUES (15099, '2022-09-13 22:55:31.321266+00', '2022-09-13 22:59:12.933168+00', 2535, 1, 1645, 'ace', '1--::
  1c+2c set | cross RH ; set facing down/up | change places, M RH, W LH (2x,1x,3)
9--::
  1c+3c &frac12; DblFig8, 1c cross down & 3c cast up to start ;
  1c cross up into &frac12; Reels3 on sides, 3c & 2c end with loops (3x,1x,2x)
17--::
  All A&R{1+1} | cross RH ; A&R{1+1} | 3c & 2c cross LH _while{2}_ 1c turn LH to face 3cnr pos (1cnr person)
25--::
  1c+1cnrs &frac12; diag RSh Reel4, pass LSh ; repeat with 2cnrs (2,1,3) 
', 2);
INSERT INTO 'dancecrib' VALUES (1733, '2012-01-22 19:28:58.964098+00', '2021-06-22 19:32:39.428585+00', 430, 1, NULL, 'ace', '1–::

  1M set advancing to 2W| 1M turn P LH ; 1W+2M repeat RH

9–::

  1c cross RH | cast off (2c up) ; cross LH | cast off and lead up to 1cnr

17–::

  1c Set to and turn corners, 1c finish on midline facing W side, 1M below 1W, NHJ

25–::

  1c dance between the W | cast (1M down, 1W up) ; meet in middle NHJ and dance between the M, cast as before to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13602, '2021-01-29 23:30:49.564268+00', '2021-01-31 10:11:25.808312+00', 20212, 1, 202, 'ace', '1--::

  1c lead down and up (1,2,3)

9--::

  1c set |cast off (2c up) ; 1c+3c RHA (2,1,3)

17--::

  2c+1c R&L (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (13606, '2021-02-01 16:44:52.145541+00', '2021-04-24 07:41:51.390015+00', 19194, 1, 202, 'ace', '1--::

  1c dance down to between 3c (2c up) | turn inwards (PdB) and face up ; turn 3c EH 1¼ | turn 2c EH ½ (1,2,3)

9--::

  Inveran Reels (1,2,3)

17--::

  1c cross RH | cast off 2 places (2c up on [19-20]) ; meet and dance up to face 1cnrs

25--::

  ½ Reel4 on 1diag, pass LSh ; ½ Reel4 on 2diag (3x,1x,2x)

33--::

  3C S&Link twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13513, '2021-01-05 16:52:26.596797+00', '2021-01-05 16:53:29.779399+00', 17781, 1, 1645, 'ace', '{{explanation}}
Strathspey

1--::
  Circle8 L ½ round ; All W ½ RHA | Turn opposite M LH 
9--::
  All W ½ RHA | All turn P LH to square set ; Circle8 R ½ (1,2,3,4)
17--::
  All M ½ LHA | All turn opposite W RH ; All M ½ LHA | All turn P RH ¾, M face in and W out  (1,2,3,4)
25--::
  Half Schiehallion Reel, finish in big star, all M LHJ in centre and NHJ with P, all facing cclw (3,4,1,2)
33--::
  In big star 3/8 LHA | all M 3/8 LHA as all W cast back 1/8 clw and form new big star ; repeat figure, finish in square set, all in P''s place, W facing in, M facing out,  (1x,2x,3x,4x), 
41--::
  Half Schiehallion Reel, finish in big star, all W LHJ in centre and NHJ with P, all facing cclw (3,4,1,2)
49--::
  Repeat [33-40] , with W in the middle and M casting, finish all W in centre facing P outside (1,2,3,4) 
57--::
  1c+3c ½ Reel4 ; turn P RH _while{8}_ 2c+4c turnP R ; ½ Reel4 (3,4,1,2)
65--::
  Repeat [57-64] (1,2,3,4)  
73--::
  Grand chain, start RH to P (1,2,3,4)

{{explanation}}
Reel

1--72::
  Repeat strathspey [1-72] in reel time
73--::
  All circle8 & back
', 2);
INSERT INTO 'dancecrib' VALUES (13498, '2021-01-01 21:52:19.1152+00', '2021-01-01 22:06:57.184586+00', 4684, 1, 202, 'ace', '_Strathspey_

1--::
  All W set | A&R {1+1} _while{4}_ All M A&R {1+1} | set ; 3c+4c ½ RHA (to 1,2,4x,3x) | 2c+4c ½ LHA (1,4,2x,3x)
9--::
  1c+4c & 2c+3c RHA ; 4c+2c ½ LHA (to 1,2,4x,3x) | 4c+3c ½ RHA (1,2,3,4)

_Reel_  

1--::
  ½ Reels4 on sides (to 4,3,2,1) ; 4c+3c+2c ½ Reels3 on sides, 4c+3c passing RSh (2,3,4,1)
9--::
  1c (4c+3c+2c dancing down to follow) lead up ; cast off to bottom (2,3,4,1)

*Deviser''s note:  
Bar 4, 2nd couple dance long way (complete loop), flowing half reel of four into half reel of three and again on Bar 8, dance long way blending the half reel of three into a "cast" to follow down on Bars 9-12.*', 2);
INSERT INTO 'dancecrib' VALUES (13605, '2021-01-30 22:49:51.410922+00', '2021-01-30 22:54:01.99405+00', 14370, 1, 202, 'ace', '1--::
  All A&R {1+1} twice ; 1c long cast to 3pl _while{4}_ 3c lead up and loop to 1pl (3,2,1,4)
9--::
  2c+1c R&L
17--::
  3c+2c & 1c+4c RHA ; LHA
25--::
  3c+2c & 1c+4c The Knot (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13599, '2021-01-29 19:20:19.335062+00', '2021-01-31 10:12:24.813175+00', 4656, 1, 202, 'ace', '1--::

  1c in promhold (1W on 1M''s left) ½ Reel3 on Mside to 3pl centre ; 1c separate and dance ½ Reels3, 1W on Mside, 1M on Wside (1W,2M,3M on Mside, 1M,3W,2W on Wside),

9--::

  1c in promhold (1W on 1M''s right) repeat same pattern [1-8] having changed sides (1,3,2)

17--::

  1c+3c ½ R&L (to 3x,1x,2) ; 1c+2c ½ R&L (to 3x,2x,1)

25--::

  3c+2c ½ R&L (to 2,3,1) ; all turn P RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2407, '2012-01-22 19:29:36.154402+00', '2021-01-31 11:28:54.230438+00', 2801, 1, NULL, 'ace', '{{explanation}}

This dance is for 1 Man & 3 women in a square set ; clw M, 1W (together the »top«), 2W, 3W. It can also be danced in a »2- or 3-harem« longwise set.



1–::

  Man leads 1W down the middle and up, 1W turning R for

9–::

  All RHA, finish facing in, close to the centre ; All pull Rsh back, dance through own place & chase one place clw, M & 3W meet in centre facing down

17–::

  M+3W in Promhold 6-bar reel across with 1W+2W (Lsh to 1W) | M leaves 3W in M position and dances diagonally into 2W position as 1W finishes in own place.

25–::

  All half R&L ; All turn the person opposite RH



{{explanation}}

The W have progressed one position cclw. M repeats with 2W, then with 3W  

', 2);
INSERT INTO 'dancecrib' VALUES (13003, '2020-07-31 23:15:20.005449+00', '2020-07-31 23:16:39.332209+00', 7360, 2, 1645, 'ace', '1-::
  1c cross down into Fig8 round 2c
9-::
  Top 3 on M side &frac12; Reel3 ; bottom 3 on M side &frac12; Reel3 _while{8}_ all W Reel4 (M: 3,4,1,2; W: 1,2,3,4)
17-::
  In two 2C sets: all set (no hands) | petronella 1 place cclw ; RHA (M side: 1W,3M,3W,1M; W side: 2W,4M,4W,2M)
25-::
  *4C diag R&L:*  
  Top 3 on M side (1W,3M,3W) cross diag RH with bottom 3 on W side (4M,4W,2M) |  
  ends (4M+2W & 1M+3W) cross LH _while_ middles (4W+2M & 1W+3M) change LH on sides ;  
  top 3 on W side (4M,3M,1W) cross diag RH with bottom 3 on M side (2M,4W,3W) |  
  ends (2c & 1c) cross LH _while_ middles (4M+3M & 4W+3W) change LH on sides (2,3,4,1)
:: *Crib derived from the video*
', 2);
INSERT INTO 'dancecrib' VALUES (14468, '2021-11-25 14:15:08.346697+00', '2022-05-30 21:35:17.48084+00', 20563, 1, 202, 'ace', '1--::

  1c dance down, turn 3c EH and cast up behind own lines to 1pl (1,2,3)

9--::

  1c+3c R&L _while{8}_ 2c turn P BH | set ; dance RSh round P and cast R to 2pl (1,2,3)

17--::

  1c (1M leading) cast off | cross to opposites sides ; cast off | cross to 3pl (2c+3c up on [23-24]) (2,3,1)

25--::

  1c dance up, turn 2c EH and cast off to 3pl (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (15185, '2022-10-24 22:28:17.497546+00', '2022-11-18 15:29:16.017793+00', 16771, 1, 202, 'ace', '1--::
  1c+2c Set&Link. 1M faces out ; 1c dance RSh round dancer above (2,1,3)
9--::
  Parallel Reels3 on sides, 1c LSh to 3c. On [8] 1c pass P LSh to face 1cnrs
17--::
  *Modified Corners Pass and Turn* : same as Corners Pass and Turn except that cnrs turn RH ½, face each other and cast away to exchanged places. 1c face 3cnrs
25--::
  ½ Reel4 on 1diag. 1c face 4cnrs ; ½ Reel4 on 2diag (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (15248, '2022-11-18 13:41:43.109562+00', '2022-11-18 13:46:56.493372+00', 21162, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 1c+3c RHA. 1M faces out (2,1x,3)

9--::

  2c+1c L-Chain. 1M & 2M face out (2,1x,3x)

17--::

  Parallel Reels3 on sides, 1c RSh to 3c (2,1x,3)

25--::

  1c ½ Fig8 down round 3c ; 1c dance up to top | cast off to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1697, '2012-01-22 19:28:57.199253+00', '2020-08-02 06:59:50.259272+00', 306, 1, NULL, 'ace', '1–::

  1c turn RH, cast off one (2c up) ; cross RH, turn BH to face down

9–::

  1c lead down between 3c, cross and cast to top own side (2c down) ; 1c+2c ½ RH turn | ½ circle4 left

17–::

  1c set advancing to 1cnr, turn 1cnr BH ; set to 2cnr, turn 2cnr BH and end between cnrs

25–::

  ½ Lsh Reels3 with cnrpersons ; 3c+2c cross RH _while_{2} 1c turn RH | 3c+1c+2c ½ circle6 L (to 2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8152, '2014-01-10 22:48:55.558773+00', '2021-01-04 16:17:11.427084+00', 13128, 2, 1, 'ace', '1–::

  1c set | cross R; cast off (2c up) | turn L to 1st corners

9–::

  1c dance ½Reel4 w/1st corners, pass LS, dance ½Reel4 w/2nd corners (to 3x,1x,2x)

17–::

  Set&Link for 3 ; ½Circle6 (finish 3c at top w/1M, 2c in 3pl w/1L)

25–::

  Set&Link for 3 ; ½Circle6 (to 213)

', 3);
INSERT INTO 'dancecrib' VALUES (1978, '2012-01-22 19:29:12.997532+00', '2021-03-23 21:41:43.825966+00', 7654, 1, NULL, 'ace', '1–::

  1c set advancing | turn BH ½ to face up NHJ ; cast off (2c up) | turn RH ½ to face 2W in promhold

9–::

  Reel3 with 2c (Rsh to 2W)

17–::

  Reel3 with 3c (Lsh to 3W), 1M passing 1W in front LH to finish BtB in 2pl facing own side

25–::

  DTr, finishing (2,1,3)

33–::

  Teapots L ; and R (2c+1M & 1W+3c LHA ; 2c+1W & 1M+3c RHA)

41–::

  All circle6 and back.', 3);
INSERT INTO 'dancecrib' VALUES (2595, '2012-01-22 19:29:49.117359+00', '2021-02-02 17:37:22.195581+00', 10900, 1, NULL, 'ace', '1–::

  1c turn RH | then 1W followed by 1M dance down the center of the set  (2c up) ; cast up behind 3W, and into 2plx

9–::

  1c+2c RHA  ; 1c+3c LHA ; 1c end facing 2M, 1M behind 1W.

17–::

  1c+1cnrs tandem reels3, 1c changing leads on the ends of the reel. 1c end facing 3M, 1M behind 1W.

25–::

  1c+2cnrs tandem reels3, 1c changing leads on the ends of the reel. 1c end in 2nd place on own sides. (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (15373, '2023-01-07 12:51:06.722057+00', '2023-01-07 12:51:17.313482+00', 5203, 1, 1645, 'ace', '1--::

  1W+2W+3W set | adv ; ret to midline _while{6}_ 1M+2M+3M adv | ret ; adv to midline & take RH with P | all set turning into allemande hold facing up

9--::

  1c+2c+3c Allemande (3,2,1)

17--::

  3c+2c &frac12; R&L _while{4}_ 1c cross RH & set (2x,3x,1x) ;

  2c cross RH | set R to P & set L turning to face down _while{4}_ 3c+1c &frac12; R&L (no polite turns)

25--::

  2c+1c+3c Gr-Chain, 2c+1c start on sides as 3c cross (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14947, '2022-07-09 11:32:12.843115+00', '2022-07-09 11:32:29.987003+00', 20018, 1, 202, 'ace', '1--::

  1c+2c Poussette (1,2,3,4)

9--::

  1c & 4c cross RH | 1c+2c & 3c+4c change places LH on sides ;  1c+4c ½ R&L into Reels4 position (2,4,1,3)

17--::

  Reels4 (2,4,1,3)

25--::

  1c+3c Set&Link ; 4c+3c Set&Link (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (8127, '2013-12-02 16:55:01.96632+00', '2021-01-04 17:12:17.882927+00', 13073, 2, 160, 'ace', '1-4::

  The Heart: 1C lead in&down (1step), up and out (1 step) , cast down&in to end btwn 3C (1C b-to-b) (2C up) ;

5-8::

  1C 3C set , 1W+3W turn LH 3/4 as 1M+3M turn RH 3/4.

9-16::

  Reel 3 on sides - 1C in&up to begin. 1C pass Rsh to end b-to-b, 1M facing up, 1L down.

17-24::

  Crown Triangles. 1C end 2pl own sides.

25-32::

  2C+1C+3C 6 hands round & back.', 2);
INSERT INTO 'dancecrib' VALUES (13954, '2021-04-14 11:22:57.305057+00', '2021-10-01 20:31:28.952988+00', 20310, 1, 202, 'ace', '1--::
  1c (+2c who dance up to follow) lead down ; 2c (+1c following) lead up to 1pl _while{4}_ 1c following cross to 2pl centre BtoB facing opposite sides (2,1x,3)
9--::
  DTr. 1c finish as on [8] (2,1x,3)
17--::
  1c cast off, meet, lead up to top, cross and cast off to 2pl
25--::
  1c+3c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12849, '2020-05-29 23:18:03.292779+00', '2020-05-29 23:23:55.117733+00', 11623, 1, 202, 'ace', '1--::

  1c+2c Circle4 L _while{4}_ 3c set | turn BH ; 1M+2M+3M Circle3 L _while{4}_ 1W+2W+3W ½ Reel3 on side, 1W & 2W passing RSh

9--::

  All set | 1c Petronella turn to midline _while{2}_ 2M+3M & 3W+2W Petronella turn in tandem to 3pl/1pl ; all set, ends NHJ | 1c Petronella turn _while{2}_ 2M+3M & 3W+2W Petronella turn in tandem (2W,3W,1W on Mside, 1M,3M,2M on Wside)

17--::

  2W+3W+1W Circle3 L _while{4}_ 1M+3M+2M ½ Reel3 on side, 1M & 3M passing RSh ; all turn BH twice (2x,3x,1x)

25--::

  All set | all La Baratte (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3419, '2012-01-22 19:30:24.702079+00', '2021-01-05 21:14:08.290451+00', 12905, 1, NULL, 'ace', '1–::

  1c+3c Reel4, the M pass Lsh and dance a full reel, the W dance to P''s place to start, and cross straight back on [7-8] (1,2,3,4)

9–::

  (2W+1M)+(4W+3M) dance a reel in the same pattern: the W pass Lsh and dance a full reel, the M dance to the corner W''s place to start, and cross straight back on [7-8]

17–::

  2c+4c repeat [1-8]

25–::

  (3W+2M)+(1W+4M) repeat [9-16]

33–::

  1c+3c turn P RH ¾ | 1W+3W turn LH ¾ the M dance clw behind cnr to meet P ; 2c+1c & 3c+4c RHA

41–::

  2c+1c & 3c+4c LHA ; 1W+3W turn RH ¾ _while_{2} the M dance cclw | turn P LH to places

49-64::

  2c+4c repeat [33-48]

65–::

  All W Fig8, in front of P, round P''s corner, and behind P to place

73–::

  The M repeat [65-72]

81–::

  All M set adv, swivel R to face P | All set ; All change places with P and set

89–::

  All turn P RH ; LH (or with Tulloch turns), W finish BtoB in centre.', 3);
INSERT INTO 'dancecrib' VALUES (14082, '2021-06-20 10:57:22.099451+00', '2021-06-23 00:07:27.119221+00', 20312, 1, 202, 'ace', '1--::

  All dance BtoB ; all turn P RH (1,2,3)

9--::

  All chase clw ½ (to 3x,2x,1x) ; 1M dances up _while_ 1W casts up both to 1plx (3c+2c down) (1x,3x,2x)

17--::

  1c+3c ½ RHA | 1c+2c ½ LHA (to 3,2,1x) ; 1M casts up _while_ 1W dances up both to 2plx (2c down) | 1c turn P RH ½, 3c & 2c step in ready for (3,1,2)

25--::

  3C Allemande (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (13006, '2020-08-02 17:50:52.388448+00', '2020-08-07 15:12:50.318843+00', 20060, 1, 1645, 'ace', '1-::

  Mirror Reels3, 2c start up and out, take hands where possible

9-::

  All set | cross RH ; all set | 1c cast off ending BtoB facing 1cnr _while_ 2c cross up RH _while_ 3c cross RH (2,1x,3)

17-::

  1c Corners Pass & Turn (RH) with 1cnrs, pass RSh ; repeat with 2cnrs, 1c pass RSh to end facing down to 3c NHJ ready for

25-::

  1c+3c Rondel (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (13509, '2021-01-04 17:37:38.520438+00', '2021-01-04 17:53:02.080999+00', 11642, 1, 202, 'ace', '*Couple face couple Round the Room*
1--::
  All RHA ; all W turn RH
9--::
  All LHA ; all M turn LH
17--::
  L-Chain into promhold
25--::
  All couple Promenade 1½ cclw round each other and face a new couple', 2);
INSERT INTO 'dancecrib' VALUES (10137, '2017-09-18 07:48:19.704914+00', '2022-04-26 09:12:48.984452+00', 17921, 2, 2605, 'ace', '1-8::

  1c+2c Bourrel (RH for turns) [1M+2W set adv.; Turn RH ¾ to end BtoB in middle 2W facing up & 1M facing down _while{4}_ 1W+2M chase cclw to face P ; set to P Turn RH ¾ (1c turn right about to face 1st cnrs)]

9-16::

  corners pass and advance and retire [1c pass 1cnrs; pass RSh, repeat with 2cnrs and join RH facing up the middle in 2nd place _while_ 1cnrs A&R (slap clap slap on bar 10) ; 2nd cnrs repeat (slap clap slap on bar 14)]

17-24::

  2c+1c+3c dance mirror Reels3 on the sides, 1c starts in and up and crosses over at the top

25-32::

  2c+1c dance non-progressive Allemande (1c dance up as 2c casts behind)', 0);
INSERT INTO 'dancecrib' VALUES (14838, '2022-05-27 11:27:05.643933+00', '2022-05-27 11:32:03.681555+00', 19711, 1, 202, 'ace', '1--::

  1c turn RH | cast off (2c up) ; cross RH | dance RSh round 1cnrs into facing lines3 across

9--::

  All set | change places RH with opposite person ; 1c dance RSh 2cnrs[pos] to 2plx _while{4}_ 2c & 3c set | cross LH (3x,1x,2x)

17--::

  All set | cross RH (to 3,1,2) ; 1c dance RSh round 3cnrs[pos] _while{4}_ 3c & 2c set | change places LH, into facing lines3 across, 1M between 2c facing down, 1W between 3c facing up

25--::

  Reels3 on sides, 1c RSh to 1cnrs. On [7-8] 1c pass P LSh to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15249, '2022-11-18 15:33:19.306982+00', '2022-11-18 15:58:25.565168+00', 21163, 1, 202, 'ace', '1-::

  1c+2c Set&Link ; RHA (2,1,3)

9--::

  3C Set&Link ; all A&R

17--::

  ½ Reels3 across, 1c LSh to 2cnrs[pos] ; 1c turn P LH 1¼ to 2pl (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12851, '2020-05-30 23:27:13.706895+00', '2020-05-30 23:33:04.034027+00', 18875, 1, 202, 'ace', '1--::

  1c & 2c set advancing to pass P LSh | chase clw ½ ; 2c+1c RHA (2,1,3)

9--::

  1c+3c LHA ; 1c lead up LHJ between 2c | cast  off to face 1cnrs 

17--::

  Corner Chain. 1c face 2cnrs

25--::

  Corner Chain to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13229, '2020-10-12 16:20:43.677929+00', '2020-10-12 18:46:48.840522+00', 20098, 1, 202, 'ace', '1--::

  Mirror Reels3 on opposite sides, 1c crossing down. 1c face 1cnrs

9-20::

  Dance to Corners and Set (3x,1x,2x)

21-24::

  1c dance RSh Turn ¾ to 2pl facing out _while{4}_ 3c+2c chase clw ½ (2,1,3)

25--::

  1c chase clw ½ to exchanged places _while{4}_ 2c & 3c A&R diagonally ; 1c ½ Fig8 L round 4cnrs (2,1,3)



*Note:  

»RSh Turn« (Right Shoulder Turn) is also known as Gypsy Turn, a term now considered offensive by some.*', 5);
INSERT INTO 'dancecrib' VALUES (14503, '2022-01-03 02:35:07.844985+00', '2022-01-03 02:35:07.844985+00', 10129, 1, NULL, 'ace', '1--::

  All circle8 and back

9--::

  All W dance Rsh round P to places {6} | All set

17--::

  All M, 1M leading, dance clw behind the W and back to places (1,2,3,4)

25--::

  1c change place RH with 2c | repeat LH with 3c ; RH with 4c | All turn P RH (2.3.4.1)', 2);
INSERT INTO 'dancecrib' VALUES (13840, '2021-03-24 10:01:14.669144+00', '2021-06-02 19:17:36.683782+00', 7440, 1, 202, 'ace', '1--::
  1M+2W & 3M+4W turn RH ; 1W+2M & 3W+4M turn RH, all ready for
9--::
  Reels4 on sides (1,2,3,4)
17--::
  1c cross RH | cast off behind 2c ; cross down between 3c | cast off behind 4c to sides (2,3,4,1)
25--::
  1c cross LH | cast up behind 4c ; cross up between 3c | cast up behind 2c to 1pl (1,2,3,4)
33--::
  1c+2c *Kingsmere Allemande* : same as 2C Allemande except [3-4] 1c dance to the bottom _while_ 3c+4c step up (2,3,4,1)', 5);
INSERT INTO 'dancecrib' VALUES (13839, '2021-03-24 02:39:34.794706+00', '2021-03-30 17:13:06.304751+00', 20283, 1, 202, 'ace', '1--::

  1c lead down {3}, lead up {3} | cast off (2c up) (2,1,3)

9--::

  3C Knot (3,1,2)

17--::

  All chase cclw ½ (to 2x,1x,3x) ; 3C S&Link

25--::

  All set | 1c turn LH _while{2}_ 3M+2M & 3W+2W change places LH ; 3C S&Link (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (10818, '2018-06-04 03:50:38.25734+00', '2021-01-06 00:01:40.63678+00', 15726, 1, 202, 'ace', '1--::

  1c cast (2c up) | cross LH ; cast L round 2cnrs | cross LH up/dn to face 1cnrs (2,*1*,3)

9--::

  Set to and Turn Corners (2,1x,3)

17--::

  1c Fig8 down (2,1x,3)

25--::

  Mirror Reels3{6} on sidelines, 1c in and up | 1c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13841, '2021-03-24 16:55:01.914873+00', '2021-06-03 15:45:27.514716+00', 7468, 1, 202, 'ace', '1--::
  All set to P | change places RH ; set to P | change places LH (1,2,3,4)
9--::
  All W dance in front of P to next M and face him | set to new P ; turn RH 1¼
17--::
  All M dance in front of new P to next W and face her | set to new P ; turn LH 1¼ (M: 2,3,4,1 W: 4,1,2,3)
25--::
  1W+3W pass each other RH and face original P back to centre | set to P into promhold facing clw ; 1c & 3c dance outside clw ½ to exchanged places
33--::
  2c & 4c repeat [25-32] (4,1,2,3)', 5);
INSERT INTO 'dancecrib' VALUES (11122, '2018-09-17 18:49:40.927586+00', '2022-01-05 02:26:18.008371+00', 18623, 1, 202, 'ace', '1--::
  1c turn LH | cast (2c up) | turn LH 1½ to face 1cnrs
9--::
  1c+1cnrs set | turn LH ; ½ Reel3 on sidelines, 1c RSh to 2cnrs, end BtoB facing 2cnrs
17--::
  1c+2cnrs set | turn LH ; ½ Reel3 on sidelines, 1c RSh to 1cnrs into lines3 across
25--::
  1c set | turn LH ¾ ; 1c lead down (3c up) | all turn LH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12852, '2020-05-30 23:41:44.100243+00', '2020-05-30 23:44:50.195813+00', 18940, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; 1c cross LSh | turn 1cnrs RH into lines3 across facing 4cnrs

9--::

  ½ Reels3 across, 1c LSh to 4cnrs into facing lines3 across ; 1c pass LSh | turn 2cnrs RH to 2plx (2x,1x,3x)

17--::

  ½ Reels3 on sides (to 3x,1x,2x) ; 1c turn P LH

25--::

  3C S&Link twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13838, '2021-03-23 12:08:15.994139+00', '2021-03-24 17:18:34.716389+00', 7416, 1, 202, 'ace', '1--::
  1c & 4c dance towards P, 1M pivoting L & 4W pivoting R into promhold, 1c facing Mside, 4c facing Wside {1}, 1c & 4c dance out to sides {1} | 1c+2c & 4c+3c Fig8 across starting LSh (2c & 3c step out on [3-4]). 1c finishes between 2W & 3W _while_ 4c finishes between 2M & 3M
9--::
  2c+1W+4M & 1M+4W+3c RHA ; 1c+4c LHA. On [16] 1c into promhold on Wside face 2W _while_ 4c into promhold on Mside face 3M
17--::
  Reels3 on sides, 1c RSh to 2W, 4c RSh to 3M. All finish on sides, as on [8], 1c & 4c in promhold ready for
25--::
  1c+4c The Tournée (2,4,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (8812, '2015-06-26 23:29:41.162261+00', '2021-01-06 00:13:44.273381+00', 16315, 2, 160, 'ace', '1-8::

  Cross RH, cast ; cross RH, cast R - end 1M btwn 2C facing down, 1L btwn 3C facing up.

9-16::

  Lines of 3 adv(1) ret(1) , 1C petronella turn to 2pl own sides ; all adv(1) ret(1), all turn RH into allemande hold.

17-24::

  Allemande3C. (3 1 2)

25-32::

  3C 1C poussette.', 2);
INSERT INTO 'dancecrib' VALUES (12189, '2019-09-08 09:28:54.642381+00', '2022-01-05 19:00:39.043764+00', 19635, 1, 1645, 'ace', '1-::

  1c+2c set adv & face up NHJ | 1c cast off _while_ 2c dance up & face out ; &frac12; mirror reels3 on the sides, 1c start in and down (3,1,2)

9-::

  1c turn P &frac34; RH | 1cnr LH ; P &frac34; RH | 2cnr LH to face 3cnr

17-::

  1c+3cnrs pass and turn BH, 1c end passing RSh ; repeat with 4cnrs, 1c end on own sides (3,1,2)

25-::

  *&laquo;3W+1W & 1M+2M accompanied R&L with 3M & 2W&raquo;:* 3c+1W & 1M+2c &frac12; RHA in 1pl & 3pl, 1c leading & ending outside 2M/3W | M & W &frac12; LHA on sides ;

  repeat from new places, 1c now following 2M/3W (3,1,2)

', 5);
INSERT INTO 'dancecrib' VALUES (14717, '2022-03-31 17:41:10.57554+00', '2022-03-31 17:44:39.051153+00', 1372, 1, 202, 'ace', '1--::

  1c+2c Espagnole. 1c face 1cnrs

9-32::

  Dance to Corners and Set ; repeat

33--::

  Reels3 on sides {6} | 1c cross RH to 2pl (2,1,3)

41--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14504, '2022-01-05 01:48:53.112442+00', '2022-01-09 07:50:24.850829+00', 20452, 1, 202, 'ace', '1--::
  1c+2c S&Link ; 1c+2c turn RH on sides (2,1,3)
9--::
  1c+3c Chain Progression (2,3,1)
17--::
  3C Grand Chain (2,3,1)
25--::
  3c+1c *Mixed L-Chain* : same pattern as for a L-Chain except 1M dancing as a Lady and 1W dancing as a Man (2,3,1) ', 5);
INSERT INTO 'dancecrib' VALUES (14767, '2022-04-18 20:09:33.707613+00', '2022-04-18 20:15:16.595807+00', 427, 1, 1645, 'ace', '1-::

  1c, 3c & 5c set | turn &frac34; RH ; repeat, end 1c+2c facing down, 4c+5c facing up, 3c facing out (1x,2,3x,4,5x)

9-::

  Alternating tandem Reels3 on sides, 3W/3M start RSh to 2M/4W & cross to own sides on [15-16], 1c+2c & 4c+5c change lead at each end (1x,2,3,4,5x)

17-::

  1c & 5c &frac12; Fig8 round 2c/4c ; turn P RH _while{8}_ 2c+3c+4c set | cross RH ; repeat (1,2,3,4,5)

25-::

  1W & 5M cast inwards | change pl RH ; cast to exchanged places | cross to own side as other M/W move down/up to face new P (M side: 5,1,2,3,4; W side 2,3,4,5,1)

', 2);
INSERT INTO 'dancecrib' VALUES (14765, '2022-04-18 08:16:58.258409+00', '2022-04-19 07:34:22.212202+00', 12631, 1, 202, 'ace', '1--::
  1c+2c The Espagnole. 1c face 1cnrs
9--::
  ½ Reel4 on 1diag. 1c pass P RSh ; ½ Reel4 on 2diag. On [16] 1c cross RH to 2pl (3x,1,2x)
17--::
  All chase clw ½ ; 2c+1W & 1M+3c RHA. On [24] 1c pass P LSh to 2pl facing 2cnrs (2,1x,3)
25--::
  Reels3 on sides, LSh to 2cnrs. On [31-32] 1c cross to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13005, '2020-08-02 00:36:22.831621+00', '2022-04-26 09:12:48.985538+00', 17921, 1, 202, 'ace', '1--::

  2C Bourrel (turning RH) (2,1,3)

9--::

  »Corners Pass and A&R« [: same as Corners Pass and Turn except that cnrs advance {2}, slap, clap, slap on 2nd skip change then retire {2}], pass RSh ; repeat [9-12] on 2diag (2,1,3)

17--::

  Mirror Reels3 on sides taking hands when possible, 1c crossing RH to 1pl, 2c in and down, 3c out and up (2,1,3)

25--::

  2c+1c Non-progressive Allemande (1c start in and up _while_ 2c cast behind) (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14948, '2022-07-09 13:09:29.628263+00', '2022-07-10 09:16:32.507274+00', 20021, 1, 202, 'ace', '1--::
  1c+2c & 3c+4c Set&Rotate. All M face out (2x,1,4x,3)
9--::
  Reels4 (2x,1,4x,3)
17--::
  All set | 1c (1W leading) + 3c (3M leading) chase clw ½ to exchanged places (to 2x,3x,4x,1x) | 2c & 4c cross RH (2,3x,4,1x)
25--::
  Circle8 and back (2,3x,4,1x)', 4);
INSERT INTO 'dancecrib' VALUES (9803, '2017-04-17 20:53:24.112442+00', '2021-08-03 17:50:42.737792+00', 15661, 1, 202, 'ace', '1--::
 1c set | cast (2c up) ; 1c turn RH 1 ¼ to midline facing opp side _while{4}_ 2c&3c chase clw ½ (3x,1mid,2x)
9--::
 Teapots L ; Rsh Snake Pass (unwind the LHA, 1c leading, pass other snake Rsh through 2plx and chase clw) (2x,1,3x)
17--::
 2c+1c+3c chase clw ½ (to 3,1x,2) ; 1c+3W+2M ½ diagonal Reel4, 1c passing Rsh to cnrs
25--::
 1c ½ diagonal R&L (to 2x,1x,3x) ; ½ Reels3 across, 1M/1W Lsh to 2W/3M (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (3567, '2012-01-22 19:30:31.478254+00', '2020-01-23 19:34:56.651209+00', 7247, 1, NULL, 'ace', '{{explanation}}

A slow «minuet« step is used throughout: step forward and a little to the R with the R foot, now straight forward with the L, then bring up the R foot close behind the L, repeat beginning L foot



1–::

  1c lead down to between 2c (2c up) ; turn BH

9–::

  1c dance BtoB ; then turn BH to (2,1,3,4)

17-32::

  2c repeat [1-16] (1,2,3,4)

33–::

  1c cast off one place ; lead up the middle and turn RH to 1pl

41–::

  1c dance BtoB ; cross over and both face W side

49–::

  On sidelines, 1c turn 2c RH 1½ ; 1c turn 3c LH 1½

57–::

  1c turn 4c RH 1½ ; 1c cross over (to 2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (12850, '2020-05-30 18:41:17.930777+00', '2020-05-31 09:01:56.619584+00', 19983, 1, 1645, 'ace', '{{explanation}}
Strathspey

1-4::
  1c+2c S&Link, 2W & 1M face out (2,1)
5-12::
  LH Mixed Chain (as M-Chain but 2M+1W turn &frac34; LH while 1M & 2W loop on sides)
13-16::
  2c+1c LHA
17-28::
  2c+1c repeat [1-12] from new places (1,2)
29-32::
  1c turn LH moving down to 2pl (2c up on [31-32])

{{explanation}}
Reel

1-32::
  Repeat in Reel time with 3c
', 2);
INSERT INTO 'dancecrib' VALUES (12853, '2020-05-30 23:54:14.339474+00', '2020-05-30 23:56:53.575417+00', 16291, 1, 202, 'ace', '1--::

  1W (1M following) cast off to 2plx (2c up on [3-4]) ; 1c+3c LHA (2,1x,3)

9--::

  Mirror Reels3 on side, 1c RSh to 2c. 1c face 1cnrs

17--::

  SetH&G. On [23-24] 1c turn P RH to 2pl

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (12500, '2020-01-12 12:40:00.152833+00', '2022-01-05 02:28:34.277747+00', 19729, 1, 202, 'ace', '1--::
  1W+3M set | cross RH ; 1M+3W set | cross LH. 1M faces out (3x,2,1x)
9--::
  2c+1c L-Chain (3x,2,1x)
17--::
  3c cross RH | cast off (2c up) (to 2,3,1x) ; 1c cross RH | cast up (3c down) (2,1,3)
25--::
  3C Allemande (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (14551, '2022-01-13 12:37:50.64306+00', '2022-05-29 11:46:16.241781+00', 20625, 1, 202, 'ace', '1--::

  1c lead down | cross and cast up to 2plx (2c up) ; set | turn P RH ½ (2,1,3)

9--::

  Cirlce6 L ½ (to 3x,1x,2x) ; 3c+1W & 1M+2c LHA (3x,1x,2x)

17--::

  Circle6 R ½ (to 2,1,3) ; 2c+1W & 1M+3c RHA (2,1,3)

25--::

  1c Petronella turn | set ; Petronella turn to 2plx | cross down LH to 3pl (3c up) (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (13842, '2021-03-24 22:10:05.046904+00', '2021-03-26 09:54:14.138051+00', 15776, 1, 202, 'ace', '1--::
  1c set | cast off (2c up) ; 1c ½ Fig8 R round 1cnrs (2,1x,3)
9--::
  2c+1M & 1W+3c RHA ; 1c turn P LH 1½ and face 1cnrs
17--::
  SetH&G. On [23-24] 1c set advancing to centre pulling RSh back, 1M facing up, 1W facing down
25--::
  Reels3 on sides, 1c RSh to 2cnrs | 1c cross RH (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14768, '2022-04-18 21:47:51.80312+00', '2022-04-18 21:49:19.323122+00', 9986, 1, 1645, 'ace', '1--::

  1M & 4W dance towards P, pull LSh back & followed by P, cast off/up to bottom/top & dance up/down the middle,

  1M+4W & 4M+1W end taking promhold & face out on M/W sides

9--::

  1M+4W & 4M+1W in promhold RSh Reels3 on M/W sides & end taking own P in promhold

17--::

  1c & 4c in promhold RSh Reels3 on M/W sides, M end passing W in front

25--::

  4c+1c RHA ; LHA back (2,4,1,3)



', 2);
INSERT INTO 'dancecrib' VALUES (12855, '2020-06-02 01:09:51.61023+00', '2020-06-02 01:12:33.086565+00', 14572, 1, 202, 'ace', '1--::

  1c+2c set | cross RH ; 1c+2c set | turn RH ½ into allemande hold facing up

9--::

  2C Allemande (2,1,3)

17--::

  Mirror Fig8 on sides, 1c in and up (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (14949, '2022-07-09 18:54:40.879036+00', '2022-07-09 18:55:23.588907+00', 20022, 1, 202, 'ace', '1--::

  1c+2c Mirror Set&Link, 1c casting off, 2c dancing up no hands ; 1c turn P LH to face 1cnrs

9--::

  Reel4 on 1diag. On [15-16] 1c turn P LH to face 2cnrs

17--::

  Reel4 on 2diag (2,1,3)

25--::

  1c Fig on own sides, LSh to 4cnrs (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (15251, '2022-11-19 11:24:52.611283+00', '2022-11-19 11:26:52.304468+00', 20749, 2, NULL, 'ace', '_Strathspey_
1-8::
  1s+2s tourbillon
9-12::
  1W+2s & 1M+3s right hands across
13-24::
  2s, 1s & 3s rights & lefts for 3 couples
25-32::
  2s, 1s, & 3s 6 hands round & back

_Reel_  
Repeat in reel time having passed a couple', 2);
INSERT INTO 'dancecrib' VALUES (12856, '2020-06-02 22:49:41.762845+00', '2020-06-02 22:52:32.924732+00', 14573, 1, 202, 'ace', '1--::

  1c lead down ; and up (1,2)

9--::

  2C promenade (1,2)

17--::

  1c+2c set | cross RH ; set | ½ RHA (2,1)

25--::

  Circle4 and back (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (13843, '2021-03-25 10:04:58.169409+00', '2021-03-27 14:49:32.527463+00', 15765, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; cross LH | dance LSh round 4cnrs into facing lines3 across
9--::
  All set | change places RH with opposite person ; chase clw ½
17--::
  All set | change places LH with opposite person ; chase cclw ½
25--::
  1c change places LH | dance LSh round 3cnrs to 2pl ; all turn P RH (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (13846, '2021-03-25 17:38:25.109814+00', '2021-03-29 18:15:57.333479+00', 15772, 1, 202, 'ace', '1--::
  1c cross down RH  (2c up) | all joining hands as for DTr set ; 1c dance RSh round 1cnrs and face 1cnrs on 1diag
9--::
  ½ Reel4 on 1diag. 1c pass P LSh ; ½ Reel4 on 2diag (3x,1x,2x)
17--::
  Reels3 across, 1c RSh to 4cnrs[pos] (3x,1x,2x)
25--::
  3C S&Link twice (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (9137, '2016-04-17 21:10:47.879076+00', '2020-09-13 14:33:25.183802+00', 10832, 2, 2954, 'ace', '1-8::

  	1s set, cast 1 place, 1L dances 3 hand across RH with 2C while 1M dances 3 hands across with 3C. 1C finish back to back in middle of dance ,1L facing up 1M facing down.



9-16::

	1C set as in double triangles,1L cast round 2L,1M cast round 3M and both dance into middle 1L facing down, 1M facing up. 1C set as in double triangles.



17-20::

1M cast round 1L position into 2L position. 1L cast round 3M position into 2M position Meanwhile 2C+3C dance 1/2 R&L starting dancing down sidelines



21-24::

1C dance 1/2 LS reel of three on opposite sides



25-28::

	1C turn 3/4 LH turn. 1M cast round 3M position into 2M position. 1L cast round 1L position into 2L position Meanwhile 2C+3C dance 1/2 R&L starting dancing down sidelines



29-32::

	1C dance 1/2 LS reel of three on own sides', 5);
INSERT INTO 'dancecrib' VALUES (14553, '2022-01-15 00:34:59.248189+00', '2022-01-15 00:37:01.414289+00', 3624, 1, 1645, 'ace', '1-::

  1M & 2W cast clw to opp side _while{8}_ 1W & 2M stand{4} ; dance BtoB ending one place to their L (beside P)

9-::

  Repeat from new places (2x,1x)

17-::

  2c+1c set | cross RH ; dance BtoB (2,1)

25-::

  2c+1c R&L (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (14766, '2022-04-18 12:17:33.741036+00', '2022-04-20 17:04:15.059288+00', 20771, 1, 202, 'ace', '1--::
  1c turn RH 1½ to 2plx and face out (2c up on [1-2]) ; 1c dance RSh round 1cnrs to 2pl and face out (2,1,3)
9--::
  3C Chain Progression finishing NHJ facing down (3,1,2)
17--::
  2c (+1c+3c following) dance down | change sides and face up, all W passing under joined arms, all M crossing below P ; 3c (+1c+2c following) dance up to sides (to 3x,1x,2x) | 1c set advancing into BtoB position, 1M facing up, 1W facing down _while{2}_ 3c & 2c set on sides
25--::
  3c+1M & 1W+2c Circle3 L {3}, opening (1c leading) into circle6 L {3} | all set (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (3065, '2012-01-22 19:30:09.028971+00', '2022-09-15 12:25:00.497807+00', 5441, 1, NULL, 'ace', '1–::

  1c (NHJ) set twice to 2W, turn P twice BH and open to face 2M

9–::

  1c (NHJ) set twice to 2M, turn P twice BH, and open to face down

17–::

  1c lead down the middle {3}, lead to top {3} | cast off (2c up) (2,1)

25–::

  2c+1c R&L (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (10949, '2018-08-08 03:32:30.130472+00', '2022-05-31 06:46:25.73045+00', 18492, 1, 202, 'ace', '1--::
  1c+2c S&Link ; 1c+3c S&Link. 1M & 3W face out (2,3,1)
9--::
  Parallel Reels3 on sides, 1c RSh to 3c. 1M face out (2,3,1)
17--::
  1c (1M leading) cast up | cross to 2plx (3c down), 1M looping RSh back to 2W place ; 2c+1M & 1W+3c RHA. On [24] 1c pivot R to finish facing P on midline
25--::
  1c set to P | Petronella turn to 2pl ; all turn P BH', 4);
INSERT INTO 'dancecrib' VALUES (14502, '2022-01-02 06:42:14.560248+00', '2022-01-07 11:28:14.054264+00', 2170, 1, 202, 'ace', '_Jig_

1--::

  2c set | cross RH and face 1cnrs ; 2c+1cnrs set | change place LH

9--::

  New middle couple (3W & 1M) set _while{2}_ cnrs chase cclw one place | middle couple cross RH and face 1cnrs[pos] _while{2}_ cnrs set diagonally ; middle couple+1cnrs[pos] set | change places LH

17--::

  All repeat same pattern [9-16]

25--::

  Cnrs chase cclw one place (to 1,2,3) | all set to P ; all Petronella turn to midline | set to P



_Strathspey_

33--::

  6 bars of Reel6, RSh to P | set to P (3M,3W,2M,2W,1M,1W)

41--::

  All W dance RSh round P ; all turn P RH

49--::

  All repeat same pattern [33-40] and finish as on [33]

57--::

  All M dance RSh round P ; all turn P RH to sides (1,2,3)



_Reel_  

65--::

  1W ½ Fig8 on Wside, LSh to 2W and finish in 3pl centre facing up _while{4}_ 3M ½ Fig8 on Mside, LSh to 2M and finish in 1pl centre facing down ; 2M dance RSh round 3M to 1Wpl _while{4}_ 2W dance RSh round 1W to 2Mpl

73--::

  All turn opposite person RH ; 1M ½ Fig8 across, LSh to 3M and finish in 2Wpl _while{4}_ 3W ½ Fig8 across, LSh to 1W and finish in 2Mpl

81--::

  3M dance RSh round 1M to 3Wpl _while{4}_ 1W dance RSh round 3W to 1Mpl (to 1W,3W,2W on Mside, 2M,1M,3M on Wside) ; all turn opposite person RH. 2c face out

89--::

  2c chase clw to original places _while{4}_ 1c & 3c turn P RH to original places ; Circle6 L (1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (13844, '2021-03-25 12:24:29.47851+00', '2021-03-29 18:19:29.829439+00', 15769, 1, 202, 'ace', '1--::
  1c+2c & 3c+4c DblFig8, 1c & 4c crossing (1,2,3,4)
9--::
  1c & 4c cross RH | cast inwards _while{4}_ 2c+3c set | dance out NHJ to nearest ends (to 2,1x,4x,3) as for Reel4 ; 2M+1W & 4W+3M & 2W+1M & 4M+3W set to each other | change places RH (1x,2,3,4x)
17--::
  Reels4 on sides (1x,2,3,4x)
25--::
  2M+1W & 4W+3M & 2W+1M & 4M+3W S&Link (to 2,1x,4x,3) ; 1c+4c ½ R&L (2,4,1,3)
33--::
  Cicle8 and back (2,4,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2337, '2012-01-22 19:29:32.066152+00', '2020-10-13 18:03:20.187919+00', 2510, 1, NULL, 'ace', '1–::

  1c lead down the middle and up.

9–::

  1c+2c Petronella Turn | set ; turn P 1¼ RH to finish 1c facing 2c within the set.

17–::

  Half -Rondel (in 4 bars dance 3 bars of the Rondel ; 1c+2c set | cross LH to own side)

25–::

  2c+1c R&L.', 2);
INSERT INTO 'dancecrib' VALUES (12454, '2019-12-31 16:56:15.23845+00', '2022-04-18 23:24:08.574611+00', 19803, 1, NULL, 'ace', '1--::

  1c+2c set | ½ RHA ; 1c+3c ½ LHA | set (2x,3x,1)

9--::

  1c cross RH | cast up (3c down) ; ½ Fig8 R and loop L to end BtoB facing own sides for (2x,1,3x)

17--::

  DTr. 1c finish between end couples facing 4cnrs[pos]

25--::

  ½ Reels3 across, 1c RSh to 4cnrs[pos] ; all turn P RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10865, '2018-06-24 22:57:36.586897+00', '2020-10-13 09:00:24.699776+00', 15667, 1, 202, 'ace', '1--::

  All set | turn P BH ; Circle6 L ½ pulling Rsh back to end in centre BtoB with P facing opposite side (3x,2x,1x)

9--::

  All set | dance to opposite side and chase clw ½ to places | set (1,2,3)

17--::

  Reels3 on sidelines, 1c crossing down to 2plx (1x,2,3)

25--::

  1c+2c change places EH on sidelines, 1c starting in | 1c+3c change places EH on sidelines, 1c starting out and down (to 2,3,1x) ; 1c turn BH ½, face P | cast R to 3pl (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (9446, '2016-10-27 19:59:26.293846+00', '2022-07-10 08:31:05.50186+00', 6405, 1, NULL, 'ace', '1--::

  1c+5c turn RH | cast in (2c+4c step to end ) ; 2c+4c turn RH 1¼ into promhold facing W side _while{4}_ 1c+3c+5c ½ Reels3 on the sides (3c start out and up, 5c finish in 1pl and 1c in 5pl) 

9--::

  2c (promhold)+5c & 1c+4c (promhold) reels3 across, 2c+4c dance in the end to start, and at end dance in to form circle with 3c (5,2x,3,4,1)

17--::

  2c+3c+4c in circle NHJ set, finish 2c facing 3c and 4c facing P | Pass first person RH {1}, next person LH {1} ; turn next person RH opening into circle | 3c+4c+2c Circle6 L ½ (5,2,4,3,1)

25--::

  All set | 5c+2c & 3c+1c ½ RHA as 4c cross RH ; All set and cross RH (2,5,4,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (1778, '2012-01-22 19:29:01.891339+00', '2020-10-13 18:16:20.158078+00', 583, 1, NULL, 'ace', '{{explanation}}

3c and 4c start on opposite side (1,2,3x,4x).



1–::

  1c+4c Figs8 on own side round the middle places, starting inwards _while_{8} 2c+3c cast into Figs8 across, round 1pl and 4pl respectively. 2c+3c finish in line across between 2pl and 3pl, the W on their starting sidelines, the M BtoB in the middle facing the other W

9–::

  2c+3c Reel4 across for 6 bars | 2M+3M turn LH ¾ to finish 2M in the middle in 3pl M-side facing down and 3M in the middle in 2nd place W-side facing up _while_{2} 2W+3W cast R to meet P (order 1,3x,2,4x)

17–::

  2c+3c cross RH between end couple and cast up/off to (1,3,2x,4x) ; All C set | All Turn P BH to finish in the middle for

25–::

  1c+3c & 2c+4c Rondel (to 3,1,4x,2x)', 2);
INSERT INTO 'dancecrib' VALUES (14506, '2022-01-08 08:56:46.71947+00', '2022-01-08 08:59:57.249631+00', 20552, 1, 202, 'ace', '1--::

  1c cast off and dance behind own lines ; cast outwards to places (1,2,3)

9--::

  Mirror Reels3, 1c in and down (1,2,3)

17--::

  1c (1M leading) cast off | cross to opposite sides (2c up) ; cast off | cross to own sides (3c up) (2,3,1)

25--::

  All chase clw, turn outwards and chase back to places (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (14554, '2022-01-15 00:41:37.086358+00', '2022-01-15 00:45:18.898828+00', 4101, 1, 1645, 'ace', '1-::

  1c+2c RHA ; LHA

9-::

  1c lead down & up

17-::

  1c+2c Allemande (2,1)

25-::

  2c+1c Circle4 to L & back (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (13845, '2021-03-25 13:10:53.92449+00', '2021-03-27 14:58:14.58038+00', 15771, 1, 202, 'ace', '1--::
  1c lead down {3}, lead up {3} | cast off (2c up). 1c & 3c face each other on sides (2,1,3)
9--::
  3C Gr-Chain (2,1,3)
17--::
  All set | 2c cross RH _while_ 1c+3c ½ RHA (to 2x,3x,1x) ; all set | cross RH (2,3,1)
25--::
  Circle6 and back (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (14507, '2022-01-08 17:00:55.22608+00', '2022-01-08 17:01:08.231449+00', 20605, 1, 1645, 'ace', '1-::

  1c+2c set | 1M crosses down, 2W crosses over, 2M casts up ; 1c & 2c set on sides | 1W casts off, 1M crosses over & faces out, 2W crosses up (2,1,3)

9-::

  1c loop LSh round 3c to 2diag between 3M & 2W all facing 2M ; 3M+1M+1W+2W NHJ set to 2M | 3M+1M & 1W+2W link & face 3W

17-::

  1M+3M+2W+1W NHJ set to 3W | 1M+3M & 2W+1W link & 1c pass RSh to face 1cnrs ; 1c+1cnrs set H&G (2 bars) | all set on sides (2,1x,3)

25-::

  1c turn &frac34; RH to face 2cnrs | 1c+2cnrs set H&G (2 bars) ; all set in lines3 across | 1c turn &frac34; RH (2,1,3)

::

  *Crib derived from the video*

', 2);
INSERT INTO 'dancecrib' VALUES (9986, '2017-06-29 07:08:21.028673+00', '2022-08-07 11:10:26.39071+00', 13159, 1, 202, 'ace', '1--::

 1c+2c & 3c+4c S&Link ; Circle4 L (2,1,4,3)

9--::

 1c+4c LHA ; 1c & 4c lead out through end cpls and cast to places (2,1,4,3)

17--::

 2M+1W & 1M+4W & 4M+3W set | turn BH ; 2W+1M & 1W+4M & 4W+3M set | turn BH, 1c & 4c ending in midline in Reel4 pos, W facing up

25--::

 1c+4c ½ Reel4 ; set | petronella (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14610, '2022-02-16 14:57:03.412287+00', '2022-09-19 04:44:56.187045+00', 17410, 2, 55, 'ace', '1-8::

  1s set, cast 2 places, lead up crossing to 2nd place on opposite side, facing out, 2s step up on bars 5 & 6.

9-16::

  2s, 1st, 3s reel of 3 on sides, 1s out & up, 2s in & down, 3s in & up,  1s finish facing 1st corner.

17-24::

  1s set & turn 1st corner RH, pass partner LSH, set & turn 2nd corner LH, finish in centre of set facing partner.

25-28::

  1s 3/4 TBH & twirl to own side in 2nd place.

29-32::

  2s, 1s, 3s TBH', 0);
INSERT INTO 'dancecrib' VALUES (14508, '2022-01-09 23:47:31.883187+00', '2022-08-22 23:30:34.366932+00', 20618, 1, 202, 'ace', '1--::

  ½ Mirror Reels3, 1c in and down (to 3,2,1) ; 1c dance to top and cast off _while{4}_ 2c stand still | dance down to 3pl (3,1,2)

9--::

  3c dance BtoB. On [10] 1c dance BtoB. On [12] 2c dance BtoB (3,1,2)

17--::

  All set | cross RH ; chase clw ½ (2,1,3)

25--::

  1c Fig8 on sides, LSh to 3cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14845, '2022-06-03 00:37:44.940517+00', '2022-06-03 00:37:44.940517+00', 16650, 2, 963, 'ace', '1-8::  
  1C&2C dance a double 8, 1C crossing dwn, 2C dancing up to begin  
9-16::  
  1C flwd by 2C lead dwn; 2C flwd by 1C lead up, 2C casting to 2nd plc, 1C finish btwn 2C facing up
17-24::  
  1C, in prom hold, dance Rsh R3 across with 2C  
25-28::  
  1C dance up and cast to 2nd plc, 2C step up on 27/28  
29-32::  
  2C and 1C turn partner RH 
33-40::  
  2C and 1C circle round and back', 5);
INSERT INTO 'dancecrib' VALUES (13850, '2021-03-26 07:29:58.439322+00', '2021-03-26 07:36:48.928623+00', 6613, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; ½ Fig8 RHJ down between 3c to 2plx (2,1x,3)

9--::

  Mirror Reels3 on sides, 1c in and up. 1c face 1cnrs

17--::

  Set to and Turn Corners with RH (2,1x,3)

25--::

  Reels3 across, 1c LSh to 3cnrs into DTr position

33--::

  DTr (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14505, '2022-01-07 13:28:48.914472+00', '2022-01-07 13:29:37.893221+00', 17188, 1, 1645, 'ace', '1--::

  1c set | cast off (2c up) ; 1c+3c turn EH, 1c starting between 3c (2,1,3)

9--::

  1c pass RSh & turn 1cnr RH ; pass RSh, turn 2cnr LH & face 2cnrs

17--::

  1c H&G setting to 2cnrs, partner, 3cnrs | all petronella to centre line

25--::

  2c+1c+3c &frac12; Reel6 on centre line | all turn P &frac34; to sides (3,1,2)

33--::

  Circle6 & back (3,1,2)

::

  *NB the original instructions give 8 bars of setting in bars 17-22 which is assumed to be a mistake*

', 2);
INSERT INTO 'dancecrib' VALUES (13851, '2021-03-26 07:41:22.95491+00', '2021-03-26 07:43:14.5626+00', 4350, 1, 202, 'ace', '1--::

  All A&R ; dance BtoB (1,2,3,4)

9--::

  1c+2c & 3c+4c R&L

17--::

  Reels4 on sides

25--::

  1c dance down to 4pl (2c+3c+4c up) ; all turn P RH', 2);
INSERT INTO 'dancecrib' VALUES (2918, '2012-01-22 19:30:02.886827+00', '2022-04-22 02:04:16.802737+00', 4928, 1, NULL, 'ace', '1–::

  1c+2c Circle4 and back (1,2,3)

9–::

 Parallel Reels3 on sides, 1c RSh to 2c (1,2,3)

17–::

  1c lead down the middle and up (1,2,3)

25–::

  1c cross RH, cast off {3}, cross LH, cast off {3} | lead up to 2pl centre

33–::

  1c cast off to face 1cnrs (2c up on [35-36]) ; Set to Corners

41–::

  Reels3 on sides{6}, 1c RSh to 2cnrs | 1c cross RH (2,1,3)



{{explanation}}

Note on 9-16: TACnotes says Rsh reels ; Foss in »Sundry writings anent SCD« says historically they were mirror reels', 3);
INSERT INTO 'dancecrib' VALUES (13849, '2021-03-26 00:20:08.814309+00', '2021-08-16 16:31:06.291352+00', 17148, 1, 202, 'ace', '1--::

  1c set | cross RH ; cast off (2c up) | turn LH ¾ as for BiL on 2diag ready for

9--::

  The Spoke. On [15-16] 1c BiL on 1diag

17--::

  Reels3 across, 1c RSh to 2cnrs. On [23-24] 1c pass P RSh into DTr position

25--::

  Last 4 bars of DTr ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14837, '2022-05-27 11:26:17.875473+00', '2022-05-27 11:28:40.086376+00', 19711, 2, NULL, 'ace', '1-8::

  1s turn Rhand and cast (2s step up). 1s cross Rhand & cast to right around 1st corners. 1L between 2s facing down, 1M between 3s facing up.

9-12::

  2s & 1L, also 3s & 1M set in lines of 3 across and change places Rhand up/down the dance.

13-16::

  1s continue to cast to the Right around 2nd corner positions to 2nd pl on opp sides, while 2s & 3s set and change places Lhands with partners.

17-20::

  3s, 1s & 2s 1s set on the sides and cross Rhands.

21-24::

  1s continue dancing out & to the Right to cast around 3rd corner, finishing 1M betwn 2s facing down, 1L betwn 3s facing up while 2L & 3L, also 2M & 3M set and change places Lhands.

25-32::

  1s dance reels of 3 on opp sides giving Rshldr to 1st corner & finishing by dancing across to 2nd pl on own sides – 1M down from top ladies’ side and 1L up from 3M’s pl while corners finish the reel in the last 2 bars. Repeat from 2nd pl.', 2);
INSERT INTO 'dancecrib' VALUES (13847, '2021-03-25 19:15:43.752532+00', '2021-03-26 13:53:31.607019+00', 15773, 1, 202, 'ace', '1--::
  1 cast behind own lines and cast back (1,2,3)
9--::
  Mirror Reels3 on opposite sides, 1c crossing. 2c face out (1x,2,3)
17--::
  1c+2c change places EH 1½ ; 1c+3c change places EH 1½ (2,3,1x)
25--::
  1c ½ Fig8 up round 3c ; all turn P RH (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (14474, '2021-12-05 05:01:17.032483+00', '2022-04-22 20:27:02.449883+00', 20543, 1, 202, 'ace', '1--::

  1W & 3M dance towards P and pull RSh to face own sides | 1c & 3c (1W & 3M leading) chase clw ½ round 2c to midline into Reel4 position, 3c at top, 1c at bottom, Ms facing up, Ws facing down

9--::

  ½ Reel4 on midline ; 1c dance to 1plx _while_ 3c dance to 3plx | 1c & 3c turn P RH ½ (1,2,3,4)

17--::

  1c+2c S&Link. 1M faces out ; 1c+3c turn LH on sides (2,1,3,4)

25--::

  1c set | cast to 4pl (3c+4c up) ; all turn P RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3573, '2012-01-22 19:30:31.753085+00', '2021-03-26 17:13:42.634111+00', 4799, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; turn LH to face 1cnr

9–::

  1c+1cnrs turn RH ½ _while{2}_ 2cnrs set | 1c+2cnrs chase 1 place clw _while{2}_ 1cnrs turn LH ¾ to face 1c on 2diag ; Repeat figure from new places (1c now faces 3cnr position)

17–::

  Repeat [9-16], 1c finish LH turn with M below W and facing 1cnr

25–::

  Teapots R ; and L (2c+1W & 1M+3c RHA ; 1c pass Rsh and repeat LHA with other couple) (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (14769, '2022-04-22 23:21:38.948593+00', '2022-04-23 12:10:43.539239+00', 20778, 1, 202, 'ace', '1--::
  1c+2c DblFig8, 1c crossing down. 1c NHJ face down, 2c face out and up (1,2,3)
9--::
  1c dance down _as_ 2c dance up on sides, all W LHA _while_ all M RHA. 1c in 2pl NHJ face down ; 1c dance down | cast up to 2pl and finish as on [12]. On [16] 3c step in and NHJ face up (2,1,3)
17--::
  1c+3c The Rondel. On [24] 3c & 1c turn inwards, 3c in 2pl NHJ face down. 1c in 3pl NHJ face up (2,3,1)
25--::
  3c & 1c set up/down | Circle4 L to sides | all set (2,3,1)
33--::
  Circle6 and back (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (3013, '2012-01-22 19:30:06.891748+00', '2020-12-14 09:48:22.00184+00', 5243, 1, NULL, 'ace', '{{explanation}}

On 2nd chord, 3c+4c cross (1,2,3x,4x)



1–::

  All set ; 1c+4c turn RH ½ into promhold _while{2}_ 2c & 3c cast to the ends ; 1c with 2c & 4c with 3c ½Reels3 across, Rsh to the M

9–::

  1c+4c ½RHA | turn RH ½ into promhold facing 2cnr _while{4}_ 2c+3c set | cross RH ; ½ Diag Reel4 on 2diag, (Rsh to W) , 1c+4c pass Rsh to face 1cnr

17–::

  ½ Diag Reel4 on 1diag. (Rsh to M) ; 1c+4c pass Rsh ; 1c/4c dance up/down between end C, split and cast to (3,1,4x,2x)

25–::

  3c+1c & 4c+2c, R&L (3,1,4x,2x)', 2);
INSERT INTO 'dancecrib' VALUES (14846, '2022-06-03 01:21:34.681285+00', '2022-06-03 01:21:34.681285+00', 16639, 2, 963, 'ace', '1-4::  
  1C with 2C, 3C with 4C RHA  1W & 4W finish facing out  
5-8::  
  1W flwd by her partner casts down one plc crossing to opp side WHILE 4W flwd by her partner casts up one plc crossing to opp side.  W stay facing out.  2C/3C up/down on 7&8  
9-16::  
  2C/3C turn partner RH then LH WHILE 1C&4C dance LHA then repeat bars 5-8 to finish on original side facing out    2,(4),1,(3)  
17-24::  
  4W with 1M, 4M with 1W, in prom hold, dance Lsh R3 on the side.  End facing out  
25-26::  
  All set, 4C&1C turning towards each other to face in  
27-28::  
  All joining hands on the side, set  
29-32::  
  4C half 8 up around 2C, 1C half 8 down around 3C     2,4,(1),(3)', 5);
INSERT INTO 'dancecrib' VALUES (2861, '2012-01-22 19:30:00.567759+00', '2021-03-26 23:41:44.531453+00', 7466, 1, NULL, 'ace', '1–::

  1W+2M set twice ; turn RH

9–::

  1M+2W repeat

17–::

  1c lead down the middle (2c up) ; and up to 2pl

25–::

  2c+1c set twice ; RHA (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (14555, '2022-01-15 22:25:59.753375+00', '2022-02-02 22:15:29.888015+00', 10016, 1, 202, 'ace', '1--::
  1c+2c S&Link ; 2c+1c RHA. 2W face out _as_ 1c RHJ in centre face up
9--::
  1c in promhold ½ Reel3 on 2diag, RSh to 2W. On [11] 1c release hands, 1W dance up to face 2M _as_ 1M face 2W in 3M place. 2W & 3M end with loops ; parallel Reels3 across, 1c LSh to 2c on Mside. On [16], 1c in promhold with 1W on P''s Left face Wside
17--::
  1c in promhold ½ Reel3 on 1diag, RSh to 2W in 3W place ; 1c dance up to top and cast off (2x,1x,3x)
25--::
  All set | Petronella turn to midline ; all set to P | all turn P BH ¾ to own sides (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14771, '2022-04-24 08:57:29.094887+00', '2022-04-24 22:34:14.541427+00', 20779, 1, 202, 'ace', '1--::

  1c & 2c cross RH | set ; ½ R&L (2M & 1W omit polite turn, face out and cclw) (2,1)

9--::

  2W+1M turn RH 1½ _while{4}_ 2M & 1W chase ½ cclw ½ (to 1x,2x) ; 2W+1M chase clw ½ _while{4}_ 2M+1W turn LH 1¼ to face P on 2diag

17--::

  Reel4 on 2diag to sides (2,1)

25--::

  Circle4 and back (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (10849, '2018-06-14 08:32:42.296612+00', '2021-11-08 19:03:22.374365+00', 18383, 2, 3129, 'ace', '1-:: 1M+2M+3M clap _while_ 1W+2W+3W turn around their partner (passing Rsh), twirl in front of them and go back to their place. All set.



9-:: 2c does the "figure of love" (= two inverted hearts): 2W crosses up and casts down 1 place, _while_ 2M crosses down and casts up 1 place. 2c meet in the middle, touch both hands and twirl (Lsh back). 2W casts off (behind 3M) and crosses back to original place, _while_ 2M casts off (behind 1W) and crosses back to place.



17-:: 1c set advancing (passing Rsh), then turn BH (about ¾ turn), at the end of the turn, 1W passes under 1M''s arm. 1W casts off 1 place behind 2M _while_ 1M casts off 1 place behind 2W (2c steps up) : 1c meet in second place, in the middle of the set, turn without hands (passing Lsh) and swivel left to face 1st cnrs.



25-:: 1c set and turn 1st cnr BH, repeat with 2nd cnr.



33-:: Reels3{6} on opposite side (Lsh to 1 crns). 1c turn in the middle without hands (passing Rsh) and swivel right to face their 1st cnr.



41-:: 1c set H&G (on the last petronella, all clap).', 5);
INSERT INTO 'dancecrib' VALUES (9890, '2017-05-28 22:58:16.126468+00', '2020-10-13 19:04:46.299362+00', 8559, 1, 202, 'ace', '*3c & 4c start on opp sides*

1--::

  1c+2c & 3c+4c set | 1M+2W turn BH ¾ to 2M/1W pl as 2M & 1W cast clw one _while{2}_ 3c & 4c dance a symmetric pattern ; 2c+1c & 4c+3c Circle4 L (2,1,4x,3x)

9--::

  2M+1M & 2W+1W & 4M+3M & 4W+3W change places BH | ½ parallel Reels4 | same persons change places BH (3x,4x,1,2)

17--::

  All M pass P Lsh | cast L to exchanged places ; all W pass opp M Rsh | cast R to exchanged places (1x,2x,3,4)

25--::

  1c+2c & 3c+4c ½ RHA (to 2,1,4x,3x) | 1c & 4c ½ Fig8 LHJ up/dn (to 2,1x,4,3x) | 1M+4W & 1W+4M change places RH (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (15252, '2022-11-19 11:59:53.80128+00', '2022-11-19 12:01:04.681747+00', 4390, 1, 1645, 'ace', '1--::

  1c+2c+3c G-Chain, 1c cross to start

9--::

  1c lead down & on [12] pull LSh back & take allemande hold (2c up on [11-12]) ; 1c dance up | turn LH to face 2cnrs

17--::

  1c Corners Pass & Turn with 2cnrs then 3cnrs & end in 2pl opp side (2,1x,3)

25--::

  Circle6 &frac12; way L | each M turns W to their L BH ; circle6 &frac12; way L | 1c cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2856, '2012-01-22 19:30:00.302925+00', '2021-03-26 23:43:21.950605+00', 7465, 1, NULL, 'ace', '1–::

  1c lead down (2c up) ; set to P | lead up to 2pl in promhold facing up

9–::

  1c+2W+3M Rsh Reel3, finish in same place

17–::

  1c+2M+3W Lsh Reel3, 1c finish own side in centre facing P

25–::

  1c set | petronella (Rsh back) to 2pl ; 2c+1c+3c turn RH', 3);
INSERT INTO 'dancecrib' VALUES (14847, '2022-06-03 01:34:23.255506+00', '2022-06-03 01:34:23.255506+00', 16652, 2, 963, 'ace', '1-8::  
  1M, flwd by 1W, Rsh to 2nd man dance a tandem R3 across with 2C.  2C finish at the top, 1C, pulling back Lsh, change leader on bar 8  
9-16::  
  1W, flwd by 1M, Rsh to 3W dance a tandem R3 across with 3C.  1C finish in 2nd plc on side, facing out  
17-24::  
  1C dance mirror R3 on the sides (1W Lsh to 2W, 1M Rsh to 2M) (3C dance a full loop on bar 16 to join the reel).  1C finish middle 2nd plc facing up  
25-32::  
  1C dance up, cast around 2C, meet, dance dwn below 3C and castup  to 2nd plc', 5);
INSERT INTO 'dancecrib' VALUES (14089, '2021-06-24 19:50:49.611664+00', '2021-06-24 19:52:00.118328+00', 20352, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; cross RH | dance RSh round 1cnrs into facing lines3 across

9--::

  All A&R ; turn opposite person RH into lines3 across facing down

17--::

  All dance down ; dance up. 1c face 3cnrs

25--::

  ½ Reels3 across, 1c LSh to 3cnrs. On [28] 1c turn P RH ¾ and face 4cnrs ; ½ Reels3 across, 1c RSh to 4cnrs (2,1,3)



*Deviser'' s note : for corners it is one continuous but slow eight bar reel.*', 2);
INSERT INTO 'dancecrib' VALUES (1955, '2012-01-22 19:29:11.854302+00', '2021-03-27 00:11:14.562434+00', 7369, 1, NULL, 'ace', '1–::

  1c cross down into ½ Fig8 and face in ; on sideline turn EH 1½ (2,1x)

9–::

  1c cast up into into ½ Fig8 and face out ; on sideline turn EH 1½ (1,2)

17–::

  1c lead down the middle and up

25–::

  1c+2c Allemande (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (15374, '2023-01-07 13:22:52.437566+00', '2023-01-07 13:40:45.892715+00', 21277, 1, NULL, 'ace', '1--::

  All A&R | Turn P RH

9--::

  All A&R | Turn P LH

17--::

  All A&R | All dance BtoB

25--::

  1c lead to 4pl (2c+3c+4c up) } | 1c Turn BH

33--::

  Circle 8 and back (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (13803, '2021-03-10 20:50:52.802753+00', '2021-03-27 09:59:00.093237+00', 16640, 2, 963, 'ace', '1-8::  

  1c set and cast (2s up 3&4); 1c 1/2 fig 8 up around 2s    

9-16::  

  1c dancing in turn 3c; 1c 1/2 fig 8 down around 3s passing Lsh to face 1st crns  

17-24::  

  1c dance corner pass and turn with 1st then 2nd crns, finish 2nd plc own side  

24-32::  

  2s,1s,3s, circle 6 hands round and back 

  ', 5);
INSERT INTO 'dancecrib' VALUES (1742, '2012-01-22 19:28:59.454897+00', '2021-03-27 11:20:27.38177+00', 7350, 1, NULL, 'ace', '1–::

  1c dance in to touch hands, cast to 3pl (2c up) , dance up to face own side for

9–::

  DTr (to 2,1,3)

17–::

  1c turn RH ; turn LH

25–::

  Teapots R ; and L (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14090, '2021-06-24 20:02:35.70176+00', '2021-08-09 07:40:44.818225+00', 20353, 1, 202, 'ace', '1--::
  1c Mirror Fig8 on sides, 1c in and down (1,2,3)
9--::
  Inveran Reels (1,2,3)
17--::
  1c lead down ; lead up (1,2,3)
25--::
  1c+2c Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1954, '2012-01-22 19:29:11.765978+00', '2021-03-27 00:12:30.522929+00', 7368, 1, NULL, 'ace', '1–::

  1c lead down the middle (2c up) and up to 2pl in the middle

9–::

  1c in promhold set to 2W | to 3W ; to 3M | to 2M and face up

17–::

  1c lead up and cast to 2pl ; All C turn RH into

25–::

  2c+1c+3c Promenade (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (7893, '2013-08-21 08:31:50.64301+00', '2023-02-04 01:23:09.89462+00', 11830, 3, NULL, 'ace', '1-8::
    1s set & dance 1/2 Fig of 8 round 2s, turn RH to end 1L facing 1st
    pl Mens side with partner behind her _while_ 2s wait 2 bars, set,
    cross RH & cast up
9-16::
    1s dance alternating tandem reel with 2s giving RSh to 2L (1st place
    Mens side) & end dancing down the middle
17-24::
    1s dance reflection reels on sides dancing between 3s to start
    _while_ 2s cross over at top & reel on own side, 2s+3s end BtoB
    facing own sides
25-28::
    2s+1s+3s set (Inverted Triangle formation), 1s PdB in _while_ 2s+3s
    PdB out all turning R about into normal Double Triangles
29-32::
    All dance 1/2 Double Triangles & 1s ending 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13848, '2021-03-25 23:40:54.437635+00', '2021-03-27 14:43:02.939174+00', 15774, 1, 202, 'ace', '1--::
  1M (1W following) casts off | crosses to 2plx (2c up) ; ½ Parallel Reels3 on sides, 1c RSh to 3c (3,1x,2)
9--::
  3c+1c LHA ; ½ Parallel Reels3 on sides, 1c RSh to 2c (2,1x,3)
17--::
  2c+1c LHA ; 1c set | cross RH (2,1,3)
25--::
  Circle6 and back (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (13854, '2021-03-27 09:55:15.6317+00', '2021-03-27 10:01:34.279633+00', 16640, 1, 202, 'ace', '1--::
  1c set | cast off (2c up) ; ½ Fig8 up round 2c (2,1x,3)
9--::
  1c+3c turn EH ; 1c ½ Fig8 down round 3c. 1c pass P LSh and face 1cnrs (2,1,3)
17--::
  Corners Pass and Turn (2,1,3)
25--::
  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8149, '2014-01-07 09:10:54.111206+00', '2022-09-19 06:34:26.119691+00', 15330, 2, 274, 'ace', 'Couples form big circle Round the Room,  L on the right of M



1-8::

  All circle left, pulling back left shoulder on bar 4 | circle back finish facing partner



9-16::

  Set to partner ; turn RH | men anticlockwise advance 2 places (pass partner RSH, pass next lady LSH)



17-24::

  Set to new partner ; turn RH | ladies clockwise advance 2 places (pass new partner RSH,  next man LSH)



25-32::

  BH joined: slip into the middle ; men under left arms turn ladies clockwise | slip out ; men under right arms turn ladies clockwise 

', 5);
INSERT INTO 'dancecrib' VALUES (14951, '2022-07-10 10:01:26.990876+00', '2022-07-10 10:18:12.434046+00', 20531, 1, 202, 'ace', '1--::

  1c turn RH ; cast off (2c up) | turn RH ½ to face 1cnrs

9--::

  Corners Pass and Turn

17--::

  Repeat [9-16] with 3cnrs then 4cnrs (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (14926, '2022-06-27 14:29:03.976629+00', '2022-07-10 10:59:25.138518+00', 20786, 1, 202, 'ace', '1--::
  1c+2c 6 bars of DblFig8, 1c dancing down on sides (to 2,1x,3) | 1c turn P LH ½ to 2pl centre LSh to P _while{2}_ 2c & 3c set
9--::
  All M RHA _while{4}_ all W LHA. 1c pass RSh ; 2W+1M+3W & 2M+1W+3M LHA. 1c BtoB in centre face opposite sides
17--::
   *Inverted DT* : all set as in DTr | all set advancing and right about into inverted DTr (2c+3c are BtoB) ; all set as in DTr | all set to finish on sides, 1c crossing RH to 2pl
25--::
  1c Allemande Turn R. On [27-30] 1c Allemande Turn R. On [29-32] 3c Allemande Turn R', 2);
INSERT INTO 'dancecrib' VALUES (14091, '2021-06-26 13:29:22.360765+00', '2021-06-27 11:36:39.857048+00', 20321, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

  All set | turn P BH ready for ; 1c+2c & 3c+4c ½ Poussette (2,1,4x,3x)

9--::

  1c+4c *Rose progression* : 1W+4W change place RH | chase 1 place clw ; turn BH ½, face and cast away _while{8}_ 1M+4M set | turn BH ½, face and cast away | chase 1 place clw (2,4x,1,3x)

17--::

  4c+1c RHA ; 4c & 1c lead out the end RHJ, cross and cast inwards (2,4,1x,3x)

25--::

  2c+4c & 1c+3c R&L (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (2773, '2012-01-22 19:29:56.826324+00', '2022-02-28 00:05:27.944753+00', 11797, 1, NULL, 'ace', '{{explanation}}

On 2nd chord 3c+4c cross to other side (1,2,3x,4x)



1–::

  1c+2c & 3c+4c ½R&L ; All set | all cross RH (2,1,4x,3x)

9–::

  2c+1c & 4c+3c RHA ; 1M (1W following) cast R round 2M and down the middle, to finish 1M/1W facing 3W/2M

  _while{4}_ 4M (4W following) cast R round 3M and up the middle, 1M+4M passing Lsh, to finish 4M/4W facing 2W/3M, all in lines across

17–::

  2c+1W+4M & 3c+4W+1M Reels4 across, on last Lsh pass take LH and the M make polite turn to finish 4M+1W between 2c facing 4W+1M between 4c, both NHJ

25–::

  4M+1W & 4W+1M set | petronella in tandem ; turn P RH (2,4,1x,3x)', 3);
INSERT INTO 'dancecrib' VALUES (9977, '2017-06-24 04:16:10.074133+00', '2022-04-25 20:12:17.702145+00', 16292, 1, 202, 'ace', '1--:: 1c+2c Knot (2,1)

9--:: 1c+2c Bourrel (1,2)

17--:: 1c set | Petronella ; set | turn RH ¾ into line of 4 across with 2c (2c up on [23-24])

25--:: Reel4 across (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (14093, '2021-06-27 08:31:17.704326+00', '2022-04-25 20:30:38.118233+00', 20360, 1, 202, 'ace', '1--::

  *2C Reverse Bourrel* : 1W+2M set advancing | turn BH ¾ and twirl R, finish BtoB on midline. 1M faces up, 2W faces down  _while{4}_ 1M+2W chase clw ¾ and face P on midline ; 1c & 2c set to P | turn BH ¾, 2c to 1plx  facing in and 1c to 2plx facing out (2x,1x,3)

9--::

  1c+3c turn EH on sides 1½ (to 2x,3,1x) ; all set | all turn P RH ½ into promhold. 2c & 1c face up, 3c face down

17--::

  3C Circulating Allemande (1,3x,2)

25--::

  All set | ½ Reels3 on sides, 3W RSh to 1M, 3M RSh to 2W (to 2,3x,1) | 3c cross RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (14094, '2021-06-27 22:37:24.415902+00', '2021-06-29 13:16:00.067144+00', 20361, 1, 202, 'ace', '1--::
  1c+2c 6 bars of R&L | 2c+1c set (2,1,3)
9--::
  *Swing Corners* : 1c turn P RH and face 1cnrs | turn 1cnrs LH and face P ; turn P RH and face 2cnrs | turn 2cnrs LH ¾ into lines3 across, 1c facing 3cnrs
17--::
  Reels3 across {6}, 1c RSh to 3cnrs | 1c turn P RH ¾ to 2pl (2,1,3)
25--::
  *Circle and Swirl* : Circle6 L ; on [29] all dance to centre bringing arms up, pivot R and chase clw to places (2,1,3)
', 5);
INSERT INTO 'dancecrib' VALUES (14628, '2022-03-02 00:35:24.78394+00', '2022-04-26 01:18:43.676166+00', 14456, 1, 202, 'ace', '1--::

  2C Set&Rotate (2,1,3)

9--::

  1c+3c Bourrel (2,3,1)

17--::

  *Muirland Willie formation* : 2c lead down to 3pl | cross and cast to 2plx _while{4}_ 3c set | cross RH to 3plx _while{4}_ 1c cast to top | cross RH (to 1x,2x,3x) ; all set | turn P BH ½ (1,2,3)

25--::

  1c set | cross RH ; cast to 3plx (2c+3c up) | cross LH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (14843, '2022-05-31 20:56:55.246716+00', '2022-05-31 20:57:59.033646+00', 20873, 1, 1645, 'ace', '1-::
  1c & 3c &frac12; Fig8 round 2c & 4c (1x,2,3x,4) ; all cross LH | 1c & 4c set _while{2}_ 2c+3c &frac12; LHA & face ends (1,3x,2,4x)
9-::
  RSh Reels4 on the sides
17-::
  1c+3c & 2c+4c RHA ; Snake Pass to end beside P (M side: 2M,2W,1M,1W; W side: 4W,4M,3W,3M)
25-::
  Modified tournee: All advance{1} diagonally R to centre taking promhold, 4M+2M & 3M+1M LSh to each other, then continue with bars 2-8 of tournee (2,4,1,3)
', 5);
INSERT INTO 'dancecrib' VALUES (14848, '2022-06-03 01:57:32.328265+00', '2022-06-03 01:57:32.328265+00', 19873, 2, 963, 'ace', '1-4::  
  1C dance dwn for 2, turn inward, dance back to place facing out  
5-8::  
  1C turn 2C, W RH, M LH 1-1/2 times to change places  2C face out  
9-16::  
  Lsh R3 on the side; 1W Lsh to 3W, 1M Lsh to 2M - 1C pass Rsh to finish in the middle 1W facing dwn/1M facing up as crns curl into plc  
17-20::  
  1C dance around 3rd crn Lsh and back in to center as 3rd crns dance in, turn LH and dance back to plc  
21-24::  1C turn LH 1-1/2 to finish in the middle facing own side  
25-28::  1C repeat 17-20 with 4th crns   
29-32::  1C LH birl to 2nd place own side
  ', 5);
INSERT INTO 'dancecrib' VALUES (10549, '2018-03-25 19:45:48.879338+00', '2020-10-13 19:26:52.224769+00', 12183, 1, 202, 'ace', '*2c & 4c start on opposite sides*



1--::

  All set | cross RH, 1M & 4M facing out ; 1c & 4c, M leading, chase clw ½ to exchanged places _while{4}_ 2c+3c LHA (4x,2,3x,1)

9--::

  Parallel Reels4

17--::

  Snowball Gr-Chain, 4c cross to start (3x,2x,1,4)

25--::

  3c & 4c ½ Fig8 round 2c/1c (to 3,2x,1,4x) ; 3c+2c & 1c+4c ½ R&L (2,3x,4,1x)', 2);
INSERT INTO 'dancecrib' VALUES (12514, '2020-01-18 02:19:33.653738+00', '2021-06-29 10:01:58.970679+00', 685, 2, 1, 'ace', '1–::

  1c+2c+3c S on RF,  then Circle6 L | 1c+2c+3c S

9–::

  1c+3c DblFig8 [1c cast off, 3c cross up; 1c fin facing out]

17–::

  1c cast (2c up) | 2c+1c+3c set ; 1c turn RH ¾ | 1W+2c & 1M+3c set facing

25–::

  1W+2c, 1M+3c Reel3{6} [starting RS to person on R] | 1c pass LS to 2pl own sides', 3);
INSERT INTO 'dancecrib' VALUES (2276, '2012-01-22 19:29:29.260108+00', '2022-04-26 09:08:19.300426+00', 2323, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  1c+2c circle4 and back

9–::

  1c+2c The Bourrel (1M+2W set adv. | turn BH and twirl to finish BtoB on the midline, 1M below 1W _while{4}_ 1W+2M chase cclw to face P up/down ; 2c+1c set, turn ¾ BH to (2,1,3))



{{title}}

Reel



17–::

  2c+3c set 4 times _while{8}_ 1c dance ½ petronella, (all set in trios across in [3-4] and on the sides in [7-8] (2,1x,3)

25–::

  Reels3{6} on the sides, Rsh to 2cnr | 1c cross.', 3);
INSERT INTO 'dancecrib' VALUES (15061, '2022-09-05 00:19:46.723506+00', '2023-02-04 01:20:04.296342+00', 20909, 3, NULL, 'ace', '1-8::
    1s dance down between 3s, separate & cast up, dance out between side
    couples back to place
9-16::
    1s+3s take prom hold to dance »Inveran Reels«:
::
    _9-12_    1s dance 1/2 LSh reel of 3 with 4s (LSh to 4L) _while_ 3s
    dance 1/2 LSh reel of 3 with 2s (LSh to 2L)
::
    _13-16_  1s dance 1/2 LSh reel of 3 with 2s (LSh to 2M) _while_ 3s
    dance 1/2 LSh reel of 3 with 4s (LSh to 4M). All end in original
    place
17-24::
    All dance Interlocking R&L, all changing places RH up/down to start
25-32::
    All set to partner, 3/4 turn RH into prom hold facing clockwise
    (Ladies on inside), promenade 1 place round & set facing in.  4 1 2
    3', 0);
INSERT INTO 'dancecrib' VALUES (14452, '2021-11-15 23:46:30.67827+00', '2022-06-05 10:40:25.27265+00', 20457, 1, 202, 'ace', '1--::
  All A&R ; all dance BtoB (1,2,3,4)
9--::
  All set | Petronella turn ; 1c+2c & 3c+4 ½ Reels4
17--::
  All set | Petronella turn (to 2,1,4,3) ; 2c & 3c turn P RH _while{4}_ 1c+4c S&Link (2,4,1,3)
25--::
  Circle8 and back (2,4,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9992, '2017-07-06 20:01:41.863972+00', '2022-04-25 17:02:02.689062+00', 17884, 1, 202, 'ace', '1--::

 1c+2c Knot (2,1,3)

9--::

 1c+3c Bourrel (2,3,1)

17-20::

 1c lead to top - cast to 2pl (3c dn) (2,1,3)

21-32::

 3C R&L', 2);
INSERT INTO 'dancecrib' VALUES (11371, '2018-12-10 14:16:26.415655+00', '2022-04-25 20:13:36.232184+00', 1173, 1, 202, 'ace', '1--::

  1c+2c set | RHA. 1c face out and 2c face up NHJ | 1c cast to 2pl _as_ 2c dance to 1pl (2,1)

9--::

  1c turn BH | cast to 1pl (2c down) ; 1c turn BH | cast to 2pl (2c up) (2,1)

17--::

  2c & 1c turn P RH ½ | Circle4 L ½ ; Circle4 R (1,2)

25--::

  2C Bourrel (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (10269, '2017-11-23 02:56:59.386878+00', '2022-09-27 23:05:30.203585+00', 18078, 1, 202, 'ace', '1--::

  1c+2c Bourrel (turning RH, not BH), 1c ending in tandem, 1W facing 2cnr, 1M behind P ready for

9--::

  1c+2cnrs, ½ Reel3 in tandem (with lead change), 1W Rsh to 3M to start ; repeat with 1cnrs, 1M Rsh to 3W to start (3x,1x,2x)

17--::

  All cross RH | chase clw ¼ ; change places RH | chase clw ¼ (2,1,3)

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2067, '2012-01-22 19:29:18.020007+00', '2021-03-27 21:36:21.679529+00', 1587, 1, NULL, 'ace', '1–::

  1c (starting inwards) turn 2c EH ; 1c (crossing down)+2c ½DblFig8 (1x,2x,3,4)

9–::

  1M+2M+W3 LHA _while_{4} 1W+2W+3M RHA (2c ends in 1plx) ; 1c (crossing down)+3c ½DblFig8 (2x,1,3x,4)

17–::

  1W+3M+4W LHA _while_{4} 1M+3W+4M RHA (3c ends in 2plx)  ; 1c (starting inwards)+4c Turn EH to (2x,3x,4,1)

25–::

  Mirror Reels4 on the sides (Rsh on M  side, Lsh on W side) (2x,3x,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (14849, '2022-06-03 02:13:09.968224+00', '2022-06-03 10:46:59.861965+00', 16653, 2, 963, 'ace', '1-4:: 
   All 3Cs set | pass prtn Rsh to opp side and face cw  
5-8::  
  All chase cw halfway   3,2,1  
9-12::  
1C turn RH  
13-16::  
  1C long cast up to 2nd plc  2C dwn on 15/16  
17-24::  
  Mirror R3 1C in and up to begin 
25-28::  
  All set |  All pass partner Lsh to opp side and face ccw   
29-32::  
All chase ccw halfway   2,1,3 
', 5);
INSERT INTO 'dancecrib' VALUES (12521, '2020-01-22 22:14:50.44014+00', '2020-01-23 23:05:28.977363+00', 14713, 1, NULL, 'ace', '*Couple face couple Round the room*  

 

*Strathspey*   

1--::

  Reel4 (the M wait 2 bars while the W pass Lsh)

9--::

  All set to opposite (H steps)

17--::

  Reel4, start Rsh to facing person, finish M standing BtoB facing P

25--::

  All set to opposite (H steps)

33--::

  Repeat Reel4

41--::

  All set to opposite (H steps)    

   



*Reel of Tulloch*  

1--::

  All dance round to the L, finish in line 1W 1M 2M 2W, facing P

9--::

  All set to P (H steps)

17--::

  All Tulloch with P, finish 1M  1W 2W 2M, W facing W

25--::

  W set to W (H steps)

33--::

  W tulloch and face non-partner

41--::

  All set (H steps) to opposite

49--::

  All pairs Tulloch, finish M facing M

57--::

  M set to M (H steps)

65--::

  M tulloch turn, finish facing P

73--::

  All set to P (H steps)

81--::

  All Tulloch turn with P, finish C facing C on opposite side of staring positions.', 2);
INSERT INTO 'dancecrib' VALUES (2146, '2012-01-22 19:29:22.510362+00', '2021-03-27 18:45:19.295334+00', 10367, 1, NULL, 'ace', '1–::

  1c Petronella into the middle | set ; Petronella turn (flirting) | set (1x,2,3)

9–::

  1c cross RH | cast off (2c up) ; turn LH to face 1cnr

17–::

  ½Reel4 with 1cnrs, touch RH into ; ½Reel4 with 2cnrs, finish with RH turn and face up NHJ (3x,1,2x)

25–::

  1c dance up and cast off to 2pl _while{4}_ 2c+3c ½ R&L (start along the sides), pulling Lsh back into ; 1M+3c & 1W+2c RHA (2,1,3)

33–::

  All Circle6 and back.

', 2);
INSERT INTO 'dancecrib' VALUES (12522, '2020-01-23 23:44:22.94352+00', '2020-01-23 23:44:22.94352+00', 19834, 1, NULL, 'ace', '1--::

  1c+2c RHA ; LHA

9--::

  1c lead down and up (1,2,3,4)

17--::

  1c, with 2c+3c+4c following, cast behind own lines and 1c makes arch ; other couples dance up through arch (2,3,4,1)

25--::

  All turn P RH ; and LH (2,3,4,1)



', 3);
INSERT INTO 'dancecrib' VALUES (10905, '2018-07-16 07:44:57.577978+00', '2020-10-13 19:28:45.334162+00', 12369, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

  1c & 4c ½ Fig8 round nearest cpl ; RHA, finish in Reel4 position (1x,2,3x,4)

9--::

  Parallel Reels4 on sidelines (1x,2,3x,4)

17--::

  1c+2c & 3c+4c change places RH | all BiL ; 1c+4c change places LH _while{2}_ 2W & 3W set and face in | 1c+4c BiL (2,4,1x,3x)

25--::

  4c & 1c, M leading, cast R round 2M/3M to centre. On [27], 4M & 1M meet, pivot R and pass P Rsh ; 4c & 1c, M leading, cast R round 2W/3W and cross to 2pl/3plx (2,4,1x,3x)

 ', 2);
INSERT INTO 'dancecrib' VALUES (12590, '2020-02-18 09:33:50.032351+00', '2021-06-28 10:35:17.218835+00', 802, 1, 202, 'ace', '1--::

  1c set | turn P LH ½ ; lead down between 3c (2c up) | cross and cast up into 1diag, RSh to 1cnrs, LHJ to P

9--::

  »Corner Targe« [: all cnrs chase clw 1pl _while_ 1c turn LH ¾ into 2diag | 1c turn 1cnrs (in 4cnrs[pos]) RH _while_ 2cnrs set ; all cnrs chase clw 1pl _while_ 1c turn LH ¾ into 1diag | 1c turn 1cnrs (in 3cnrs[pos]) RH into 2diag, LSh to P _while_ 2cnrs set]

17--::

  1c repeat same pattern [9-16] with 2cnrs. On [23-24] 1c turn 2cnrs RH to 2plx (2,1x,3)

25--::

  Circle6 L ; Circle6 R ½. All drop hands | 1c dance LSh round P to 2pl _while_ 3c+2c chase cclw ½ (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (13955, '2021-04-15 13:10:12.489746+00', '2022-06-07 09:48:22.862303+00', 20311, 1, 202, 'ace', '1--::

  1c cast off (2c up) | turn RH ; cast off behind 3c, meet and cross up to face 1cnrs

9--::

  Set H&G. On [15-16] all clap _as_ 1c Petronella turn to 2pl (2,1,3)

17--::

  Circle6 L ½ (to 3x,1x,2x) ; all set in line in threes | turn P RH ½ into promhold

25--::

  3C Allemande (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (14844, '2022-06-01 14:15:10.566774+00', '2022-06-07 21:29:31.181711+00', 9363, 2, 3069, 'ace', '1-4:: 1C & 5C cross RH, cast one place. 2C & 4C step up or down 3&4
5-8:: 1C & 5 C 1/2 Fig 8 around 2c or 4C.
9-12:: 1M with 2C, 1W& 5M with 3C, 5W with 4C dance LH across.
13-16:: 1W with 2C, 1M& 5W with 3C, 5M with 4C dance RH across.
17-22:: 1C & 5C set to corner & partner. *NB
23-24:: 1C & 5C pdb to opposite sides. 1C to 2nd & 5C to 4th places.
25-28:: 1C with 3C & 5C with 4C dance half LH across, set
29-32:: 1C with 4C half RH across, set.
33-36:: 1C with 5C half LH across, set.
37-40:: All turn Partner RH. 3C & 5C turn 1 1/2. (23451)
*NB:: either finish facing partner or facing 2nd Crn before dancing to oppostie sides. Your choice.', 3);
INSERT INTO 'dancecrib' VALUES (14950, '2022-07-10 08:34:07.243874+00', '2022-07-10 21:40:18.582632+00', 20017, 1, 202, 'ace', '*5 dancers in a square, 1 + 3 head, 2 + 4 on sides, 5 in middle facing 1 (1,2,3,4,5)*

1--::
 1+2+3+4 R&L, starting 1+2 & 3+4 _while{8}_ 5 Fig8 round 1[pos] & 4[pos], starting RSh to 1
9--::
  5 Reel3 with 1+3, RSh to 1
17--::
  5 Reel3 across with 2+4, LSh to 4
25--::
  5 turn 4 RH ½ | 4 turn 3 RH ½ ; 3 turn 2 RH ½ | 2 turn 1 RH ½. 1 faces 2 (2,3,4,5,1)', 2);
INSERT INTO 'dancecrib' VALUES (14852, '2022-06-08 22:25:14.585864+00', '2022-06-08 22:25:27.256278+00', 20888, 1, 1645, 'ace', '1-::

  1c Fig8 on own sides starting in & down

9-::

  1c+2c+3c Gr-Chain, 1c start by crossing

17-::

  3c Fig8 on own sides starting out & up

25-::

  1c cross RH | cast off to 3plx (2c+3c up) ; &frac12; Fig8 up round 3c (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (10404, '2018-01-25 20:43:21.144529+00', '2022-04-25 17:06:14.661258+00', 16635, 2, 963, 'ace', '1-8::

  1c+2c,3c+4c bourrel, finish 2c+4c facing down, 1c+3c facing up  

9-12::

  All set|turn facing dancer BH once round and face in  

13-16::

  1c+4C RH 1/2 turn and twirl to opp sides M face down, W face up  

17-24::

  4M,1M in tandem dance Rsh R3 across with 3c WHILE 1W,4Win tandem dance Rsh R3 across with 2c, dance down side lines to 2,4x,1x,3  2c facing 4c, 1c facing 3c

25-32::

  All set|turn facing dancer BH once round and face in; 4c+1c LH 1/2 turn and twirl to own sides

  ', 5);
INSERT INTO 'dancecrib' VALUES (11905, '2019-06-23 13:45:54.302231+00', '2022-04-25 20:17:07.978316+00', 12913, 1, 202, 'ace', '*On 2nd chord, 1c+3c cross to opposite side (1x,2,3x)*

1--::

  1c+2c 4 bars of 2C Bourrel. On [3-4], 3c Petronella turn ; all set | turn P BH ¾ to sides. 2c & 3c face out (2,1x,3)

9--::

  ½ Reels3 on sides, 1c RSh to 4cnrs (to 3,1,2) ; ½ Reels3 on sides, 1c LSh to 1cnrs[pos] (2,1x,3)

17--::

  1c+3c 4 bars of 2C Bourrel. On [3-4], 2c Petronella Turn ; all set | turn P BH ¾ to sides (2x,3,1x)

25--::

  All W RHA | All M LHA (2x,3,1x)', 2);
INSERT INTO 'dancecrib' VALUES (12524, '2020-01-25 13:56:57.67656+00', '2020-01-25 13:56:57.67656+00', 3360, 1, NULL, 'ace', '1--::

  Circle8 and back

9--::

  1c+3c, W leading, chase cclw to opposite places ; 3c+1c LHA (3,2,1,4) 

17--::

  3c+1c RHA ; ½ LaChain (M cast) 

25--::

  1c+3c Lsh Reel4

33-36::

  1c+3c ½ LaChain (M cast) _while{4}_ 2c+4c, W leading, chase cclw to opposite places (3,4,1,2)

37-60::

  2c+4c repeat [13-36]

61-64::

  All promenade ½ round, to places, and turn W into centre, BtoB

', 3);
INSERT INTO 'dancecrib' VALUES (14850, '2022-06-03 02:23:43.995468+00', '2022-06-03 02:23:43.995468+00', 16658, 2, 963, 'ace', '1-8::
  All 4 W dance across, passing prtn by the Rsh and face up| 1W flwd by 2W,3W,4W dance up, across the top and dwn women''s side  W 4,3,2,1  
9-16::
  All circle 8 hands round and back  
17-24::  
  All 4 M dance across, passing opp by Lsh | 1M flwd by 2M,3M,4M dance up, across the top and dwn men''s side  4,3,2,1  
25-28::  
  All set twice, 4C, 3C and 2C turn to face up on 27/28  
29-32::  
  4C cast to 3rd plc, 3C dance up and cast to 2nd plc, 2C dance up and cast to top plc  2,3,4,1', 5);
INSERT INTO 'dancecrib' VALUES (14853, '2022-06-09 10:35:06.903204+00', '2022-09-06 10:43:53.322361+00', 20804, 2, 2784, 'ace', '1-::

  1c set, 1W casts, dances across below 2c and casts up behind 2M to 1M pl _while{6}_ 1M dances across above 2c, casts off behind 2W and dances up middle to 1W pl (1x,2)

9-::

  1c+2c dance Men’s chain (1L+2L give LH to start), 1M ends by pulling L sh back to face down with P on R (1x,2)

17-::

  1c dance down, 1W dances under P’s R arm and 1c dance up to 2c pl (2c up on 7&8) (2,1)

25-::

  2c+1c R&L

', 3);
INSERT INTO 'dancecrib' VALUES (11976, '2019-07-23 19:17:14.433798+00', '2022-04-26 14:53:41.490527+00', 19084, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

  1c+2c & 3c+4c S&Link ; 2c+1c & 4c+3c RHA. 1M &M face out (2,1,4x,3x)

9--::

  1c+4c ½ LHA and stay in centre (to 2,4,1x,3x) | 4M+1W & 4W+1M change places LH (to 2,1x,4,3x) ; top 2 couples and bottom 2 couples turn RH on sides (2,1x,4,3x)

17--::

  Reels4 on sides. On [24] 4M+1W & 4W+1M turn BH ½ and open out to face across ready for

25--::

  1c+4c The Bourrel (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (1996, '2012-01-22 19:29:14.111947+00', '2021-03-27 21:37:33.622148+00', 1383, 1, NULL, 'ace', '1–::

  On sidelines 1c+2c & 3c+4c pass Rsh | 2c & 3c cross RH (the dancer crossing inside makes loops before and after) _while_{2} on the sides 1c+4c dance Lsh fully round the other ; repeat from new positions (to 1x,2x,3x,4x)

9–::

  Repeat from new positions (to 1,2,3,4)

17–::

  All set | 1c+2c & 3c+4c ½RHA ; all set | all cross RH (to 2,1,4,3)

25–::

  1W & 3M cast (Rsh back) with P following into ¾ Fig8 round 4c (pass Lsh between 4c) | and cross to exchanged places (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (12523, '2020-01-24 00:09:25.841187+00', '2020-01-24 00:11:16.340872+00', 19835, 1, NULL, 'ace', '1--::

  1c+4c cross RH | cast inwards (2c+3c to ends) ; 1c+4c ½ Fig8 round end cpl (2,1,4,3)

9--::

  1c+4c poussette, at end turn P BH to midline, M facing up and W down

17--::

  1c+4c Reel4 on midline

25--::

  1c+4c turn P BH 1¼ | ½ Circle4 L ; set | Cross RH (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1815, '2012-01-22 19:29:03.870346+00', '2021-06-29 09:33:25.07438+00', 717, 1, NULL, 'ace', '1–::

  1c+2c RHA{3}, LHA{3} | 1c cast and 2c dance up and face out (2,1,3)

9–::

  Mirror Reels3 on the sides, 1c start in and down, 2c+3c finish with loops and 1c BtoB facing opposite side between 2c

17–::

  1c+2c Reel4 across, finish in line across

25–::

  1c set to 2c | turn opposite RH to finish 2c in 1pl and 1c facing P on midline ; 1c turn LH ¾ moving down to 2pl (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9698, '2017-04-01 19:39:49.367064+00', '2021-03-27 15:57:14.177295+00', 7318, 2, 940, 'ace', '1-4:: All join hands and set; 1C link with 2C (1M remain facing out) and 4C link with 5C (5W remain facing out) and 3C cross RH.

5-8:: 1M followed by 1W dance down behind third place finishing in fourth place on the opposite sides as 5W followed by 5M dance up behind third place finishing in second place on opposite sides.

9-16:: 2C with 5C and 1C with 4C dance rights and lefts.

17-24:: 5C, 3C and 1C set and link for three; repeat to finish on own sides [2,1,3,5,4]

25-28:: 3C and 4C dance in to face down with NH joined; 4C cast up to third place while 3C dance down and cast into fifth place [2,1,4,5,3]

29-32:: 4C and 2C dance in to face up with NH joined; 2C cast off to third place while 4C dance up and cast into first place [4,1,2,5,3]', 2);
INSERT INTO 'dancecrib' VALUES (10196, '2017-10-21 07:09:24.484983+00', '2021-03-27 15:57:14.182236+00', 7318, 1, 202, 'ace', '1--::

  All set | 1c+2c & 4c+5c Link (at end 1M & 5W face out) _while{2}_ 3c cross RH (to 2,1,3x,5,4) ; 1M followed by 1W & 5W followed by 5M cast cclw to exchanged places (2,5x,3x,1x,4)

9--::

  2c+5c & 1c+4c R&L

17--::

  5c+3c+1c S&Link3 twice (2,1,3,5,4)

25--::

  3c dance in and down to 5pl _while{4}_ 4c dance in and cast up to 3pl (to 2,1,4,5,3) ; 4c dance in and up to 1pl _while{4}_ 2c dance in and cast down to 3pl (4,1,2,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (3777, '2013-07-13 15:56:03.164649+00', '2021-03-27 18:52:19.116537+00', 14554, 1, NULL, 'ace', '1–::

  1c+2c RHA ; 1c cast _while_{2} 2c dance to 1pl | 1c cross down and face out (3c up) (2,3,1x)

9–::

  Mirror Reels3 on the sides, 3c starts in and down, give hands when possible, loops at the end

17–::

  3c+1c ½R&L ; 3c ½ Fig8 up (2,1,3)

25–::

  Circle6 L and back

', 2);
INSERT INTO 'dancecrib' VALUES (1945, '2012-01-22 19:29:11.231817+00', '2021-03-27 21:39:40.402299+00', 1207, 1, NULL, 'ace', '1–::

  1c dance down (2c up) NHJ | turn 3c ¾ easy hand ; cross Rsh | turn 3c ¾ easy hand

9–::

  1c dance up and repeat with 2c

17–::

  1c dance down between 3c and cast up to 2pl ; 1c Petronella Turn (M down. W up) to between end couples in facing lines across | all set

25–::

  All change places RH with person opposite | all set ; change back RH (1c face out) | 1c cast R to 2pl.

', 2);
INSERT INTO 'dancecrib' VALUES (14851, '2022-06-07 21:34:49.800164+00', '2022-06-07 21:36:19.307562+00', 20876, 1, 1645, 'ace', '1--::

  1c starting between 2c &frac12; turn on sides (M RH, W LH) | 1c+3c turn (M LH, W RH) | 1c+2c &frac12; turn (M RH, W LH)

9--20::

  1c+2c+3c R&L for 3 couples

21--24::

  2c+3c RHA

25--::

  1c+2c Chase &frac12; way clw (2x,1x,3) ; &frac12; DblFig8 (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14772, '2022-04-26 09:12:39.222272+00', '2023-01-05 19:06:31.893811+00', 20780, 1, 1645, 'ace', '1-::

  1c & 3c turn RH | cast off (2c+4c up) ; dance down | cast up (2,1,4,3,5)

9-::

  1c+3c R&L (no polite turns) _while{8}_ 2c+4c+5c set | cross RH ; repeat

17-::

  1c+3c dance up | cast off ; turn LH | cast off (4c+5c up)

25-::

  2c+4c & 5c+3c circle4 to L & back _while{8}_ 1c cross LH | dance &frac12; way round cclw (2,4,1,5,3)

', 2);
INSERT INTO 'dancecrib' VALUES (3801, '2013-07-13 15:56:08.975969+00', '2021-03-27 18:56:02.142093+00', 14550, 1, NULL, 'ace', '1–::

  All W, 1W leading, dance cclw round the line of M, to places

9–::

  All A&R ; All C turn RH

17–::

  All M, 1M leading, dance clw round the line of W, to places

25–::

  1c, other Cs following, cast off behind own lines, 1c makes arch in 4pl ; other Cs lead up through arch (2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (10574, '2018-04-03 15:37:58.555552+00', '2020-10-13 19:55:14.088885+00', 13901, 1, 202, 'ace', '*3c & 4c start on opposite sides*

1--::

  1W(4W) Fig8 round 2c(3c) _while{8}_ 1M(4M) set | ½ Fig8 round 2c(3c) | dance across to original place facing out (1,2,3x,4x)

9--::

  Parallel Reels4 on sidelines, passing Lsh to start. On [16], 2W+3M & 2M+3W turn RH ½ instead of passing Rsh and retain hands, 1M & 4M end facing out

17--::

  1c & 4c, M leading, chase cclw ½ to exchanged places _while{4}_ 2W+3M & 2M+3W turn RH (to 4,2,3x,1x) ; 4c+2c & 3c+1c change places LH on sidelines (to 2,4,1x,3x) | 4W+1M & 4M+1W turn RH ¾ into line of 4 across as 2c & 3c set

25--::

  Reel4 across to sidelines (2,4,1x,3x) ', 5);
INSERT INTO 'dancecrib' VALUES (13128, '2020-09-13 09:54:52.98756+00', '2022-04-25 17:07:49.747061+00', 10269, 1, 202, 'ace', '1--::

  1c+2c »Modified Bourrel« [: same as The Bourrel but on [7-8] 1c turn BH 1¼ to 2plx, 1W facing out] (2,1x,3)

9--::

  1c in tandem (1W leading) Fig8 on 1diag, RSh to 2M, LSh to 3W into DTr position facing opposite sides

17--::

  DTr ending as on [17]

25--::

  1M+2W+3W & 1W+3M+2M Circle3 L. On [28] 1c pass LSh to exchanged places ; 1M+3M+2M & 1W+2W+3W Circle3 L. On [32], 1c curve into 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8032, '2013-09-10 21:38:08.066501+00', '2021-03-27 18:59:39.516334+00', 14247, 1, NULL, 'ace', '1–::

  1c+2c & 3c+4c R&L

9–::

  Reels4 on the sides

17–::

  1c+2c & 3c+4c set | ½ RHA ; all set | all cross RH, 2c to 1pl, the other couples keep RHJ and face up for

25–::

  1c+4c+3c Allemande (to 2,3,4,1)

', 3);
INSERT INTO 'dancecrib' VALUES (11238, '2018-10-02 00:58:30.570339+00', '2022-04-25 20:18:26.028061+00', 18683, 1, 202, 'ace', '1--::

  1c+2c The Knot (2,1,3)

9--::

  1c+3c 4 bars of Bourrel _while{4}_ 2c dance LSh round P ¾ ; all set | all turn P BH into midline

17-28::

  Reel6

29-32::

  All set | Petronella Turn to sidelines (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3216, '2012-01-22 19:30:16.076004+00', '2020-01-25 15:07:30.740654+00', 5927, 1, NULL, 'ace', '1–::

  1c+3c cross RH | cast off (2c+4c up) ; 2c+1M & 1W+4c+3M & 3W+5c all circle L

9–::

  1c+3c with 2cnrs pass and turn, turning RH to face 1cnr ; repeat with 1cnrs, turning RH to face P on midline, M above W

17–::

  1c+3c Reel4 in the middle, finish on opposite sides near sideline (2,1x,4,3x,5)

25–::

  2c+1W & 1M+4c+3W & 3M+5c RHA, 1c+3c pass Rsh to return to midline, M above W ; 1c+3c turn ¾ RH, cast off one (4c+5c up) (2,4,1,5,3)

', 3);
INSERT INTO 'dancecrib' VALUES (13230, '2020-10-14 01:37:04.875308+00', '2022-04-26 01:20:32.792218+00', 19872, 2, 963, 'ace', '  1-8::

  1&2c set. Pet in tandem to lines across: repeat to opp side  2x1x3 

  9-16::

  1c flwd by 2c dance down, m turn w under rt arm to own sides, dance back up 213  

  17-24::

  1w with 2s, 1m with 3s RHA: 1c with 3c LHA  

  25-32::

  1c&3c bourrel 231

  ', 5);
INSERT INTO 'dancecrib' VALUES (11015, '2018-08-19 21:56:20.763561+00', '2020-10-13 20:06:18.841559+00', 18510, 1, 202, 'ace', '*3c & 4c start on opposite sides*

1--::

  1c & 4c set | cast inwards (2c & 3c step out) ; ½ Fig8 through nearest end (2,1x,4,3x)

9--::

  1c turn 2c EH {4}, release hands and continue {2} into line4 across _while{6}_ 4c turn 3c EH {4} and Petronella turn {2} to midline | all set

17--::

  2c+1c Reel4 across _while{8}_ 4c+3c Reel4 up/dn. At the end, 1c pass P RSh to 2plx slightly in from sidelines and face down _while_ 4c finish in 3pl slightly in from sidelines and face up, 3c finish in 4plx (2,*1x*,*4*,3x)

25--::

  1c+4c set diagonally | ½ RHA (to 2,4x,1,3x) ; 4c+1c set | cross RH (2,4,1x,3x) ', 2);
INSERT INTO 'dancecrib' VALUES (8505, '2015-01-27 15:12:01.287541+00', '2020-10-14 11:36:02.598754+00', 15891, 2, 1, 'ace', 'Strathspey



1–::

  M advance and retire twice _while_ W stand | advance ; retire | advance and

  pull RS back to face corners

9–::

  W dance behind corners, in front of next M, behind next M,

  fin in front of partner

17–::

  W dance ½ LH across _while_ M chase clockwise one place

  | all ½ turn “new partner” R ; R with M dancing ½ LH across and W chasing

25–::

  R bars 17–24 to opposite places [W fin facing out]

33–48::

  Schiehallion reel (once round)

49–::

  M dance in front of corner, behind next W, in front of next W,

  behind partner back to places

57–::

  Circle8 round and back



Reel



1–64::

  Repeat bars 1–64 of strathspey.', 3);
INSERT INTO 'dancecrib' VALUES (14854, '2022-06-09 16:10:02.737147+00', '2022-06-09 16:10:02.737147+00', 15686, 2, NULL, 'ace', '1-8::

  1s & 3s Set to partner. 1s cast 2 places [2], dance to top on own sides [2] and Set while 3s dance to top [2], cast two 2 places to own sides [2] and Set.

9-16::

  1s dance 1/2 reel of 3 on sides (1s in & down) [4] ; 1s+2s+3s Set and Cross RH [321 on opposite sides]

17-24::

  1s+2s+3s clap 4 times [2], stamp right leg 4 times [2]. All dance 1/2 grand chain, 1s starting across the set [4] (123 on own sides, 1st and 2nd ladies omit polite turn, 1st Lady to end facing out)

25-32::

  1L followed by partner cast one place [2] (2s step up on bars 3-4). 1L crossing to 2nd place opposite side [2], 1s 1/2 turn RH, twirl & dance out to 2nd place own sides

', 5);
INSERT INTO 'dancecrib' VALUES (12779, '2020-04-26 00:23:44.386872+00', '2020-10-13 20:09:07.164988+00', 19958, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*



1--::

  1c+2c Set&Rotate. 1c face up (2,1,3x,4x)

9--::

  Reels4 on sides. On [16] middle persons turn LH ¼ into promhold, W on M''s L, 1M+3W facing up, 1W+3M facing down

17--::

  RSh Reels3 across to sides (2,3x,1,4x)

25--::

  3c & 1c ½ Fig8 round ends (to 2,3,1x,4x) ; all A&R (2,3,1x,4x)

33--::

  1c+4c Espagnole (2,3,4x,1x)', 2);
INSERT INTO 'dancecrib' VALUES (14092, '2021-06-26 22:24:16.816731+00', '2021-06-29 16:47:29.279929+00', 20359, 1, 202, 'ace', '1--::

  *3C Espagnole* : 1W+2W "top two W" & 2M+3M "bottom two M" lead RHJ to opposite sides and cross _while{2}_ 1M & 3W chase 1 place clw (to Mside: 2W,1W,3W, Wside: 1M,3M,2M) | repeat same pattern from new positions (to Mside: 3M,1M,2M, Wside: 2W,3W,1W) ; 3M+2W "top couple" & 2M+1W "bottom couple" turn RH while{4} 1M+3W "middle couple" turn LH and face out (Mside: 3M,1M,2M, Wside: 2W,3W,1W)

9--::

  Reels3 on sides, 1M LSh to 2M & 3W LSh to 2W. All face in (Mside: 3M,1M,2M, Wside: 2W,3W,1W)

17--::

  1M+2M "bottom two M" & 2W+3W "top two W" S&Link (to 3,2,1) ; 2c turn P RH | cast off (1c up) (3,1,2)

25--::

  Circle6 and back (3,1,2)', 5);
INSERT INTO 'dancecrib' VALUES (14855, '2022-06-09 23:41:33.792981+00', '2022-06-09 23:48:48.002378+00', 1906, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; set | turn P RH and face out (2,1x,3)

9--::

  Reels3 on sides, 1c RSh to 1cnrs (2,1x,3)

17--::

  1c chase clw ½ to 2pl _while{4}_ 2c+3c LHA and face cclw (to 2,1,3) ; 1c cross RH _while{2}_ 2c & 3c chase one place cclw | all set (2W,1W,2M on Mside, 3W,1M,3M on Wside)

25--::

  ½ diagonal R&L to the L (to 2x,1,3x) ; 1c set _while{2}_ 2c & 3c cross RH | all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14856, '2022-06-10 05:00:04.97352+00', '2022-06-10 05:11:22.81216+00', 20891, 1, 202, 'ace', '1--::
  *Pinwheel progression* : 1M+2W dance BtoB _while{4}_ 1W+2M chase one place clw | advance to P _as_ P retire into 1diag, 1W+2M LSh to LSh, NHJ with P all facing cclw ; all dance to midline. 2c face Mside, 1c face Wside | all dance to progressed places,  2M & 1W by curling and 1M & 2W by casting (2,1,3)
9--::
  All set | Petronella turn ; repeat (2x,1x,3x)
17--::
  All chase clw ½ ; turn P RH (3,1,2)
25--::
  Circle6 and back (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (2217, '2012-01-22 19:29:26.306494+00', '2022-06-11 16:22:19.050976+00', 2129, 1, NULL, 'ace', '{{explanation}}

Couples (M to left of W) form a big circle round the room, all face in



1–::

  All M advance towards centre and retire ; in circle NHJ all slip 4 L

9–::

  All W advance towards centre and retire ; in circle NHJ all slip 4 R and face P

17–::

  G-Chain, 2 bars/hand

25–::

  New couples M+W slip into centre {2}, out {2} ; turn P RH to form circle.', 4);
INSERT INTO 'dancecrib' VALUES (8672, '2015-02-17 08:41:08.05563+00', '2020-10-14 22:00:39.202851+00', 16069, 2, 1, 'ace', '1–10::

  1c set | dance down between 2c&3c | cast off | meet below 3c and lead up

  to the top | cast off to fin LS to LS in the middle in 2pl

11–14::

  1M+3c, 1L+2c dance RH across [fin in line on 1crnr diagonal, 1c LH joined

  w/partner, RH w/1st corner]

15–16::

  1c+1st corners balance in line _while_ 2nd corners set diagonally

17–20::

  1c turn LH _while_ corners chase clockwise half-way

21–24::

  1M+2M+3M [on ladies'' side], 1W+2W+3W [on men''s side] dance RH across

  [fin in line on 2crnr diagonal, 1c LH joined w/partner, RH w/2nd corner]

25–26::

  1c+2nd corners balance in line _while_ 1st corners set diagonally

27–30::

  1c turn LH [fin facing out in 2nd pl own sides] _while_ corners chase

  clockwise half-way

31–36::

  1c cast to their left [1L up, 1M down] | dance across | cast back to 2pl

  _while_ 2c&3c petronella | set | petronella [1M dances between 3c,

  1L between 2c]

37–40::

  All set | all cross RH back to own sides



  ', 5);
INSERT INTO 'dancecrib' VALUES (12525, '2020-01-25 18:34:43.020257+00', '2020-01-26 00:07:10.274416+00', 6206, 1, NULL, 'ace', '1--::

  1c set | cast (2c up) ; 2c+1W & 1M+3c RHA, on [8] 1c pass Rsh to face 2cnrs _while_ 2M & 3W cross the set keeping RHJ with P and take promhold facing out (at end of 2diag)

9-24::

  {Celtic Interlace}:  2c+3c dance in, pass Rsh and out to next cnr cclw _while{4}_ 1c pass 2cnr (pos) Rsh and dance in | Turn P LH ¾ to face next cnr positon clw ;  [repeat 4-bar figure 3 more times]  Finish 2c/3c in 1pl/3pl  facing out and 1c facing out the ends Lsh to 3cnr 

25--::

  2c+1M & 1W+3c Reels3 across, Lsh to 3cnr, at end 1c cross to 2pl  (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (11727, '2019-03-23 10:53:44.459512+00', '2022-04-26 01:29:25.265322+00', 19247, 1, 1645, 'ace', '1-::

  1c+2c set | &frac12; RHA ; set | &frac12; LHA

9-::

  1c+2c Bourrel (2,1,3)

17-::

  2c+1c+3c Reels3 on sides, 1c start RSh to 2M/3W

25-::

  1c+3c Espagnole (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (1699, '2012-01-22 19:28:57.324322+00', '2021-03-27 21:46:30.28691+00', 312, 1, NULL, 'ace', '1–::

  1c cross RH | cast off two (2c+3c up) ; 3c+1c RHA

9–::

  1c lead to top, cross and cast to 2pl (3c down) ; 2c+1c LHA (2,1,3)

17-32::

  2c+3c (»corners«) set and change place RH four times following the track of R&L (3M&2W make polite turns) _while_{16} 1c cross (across or up/dn) RH and cast R round the corner four times.



{{explanation}}

Note by the deviser in TacTalk of jan. 1986: on [17-32] the corners set »as written«; they do not split the setting as is customary in »J.B. Milne«.  ', 3);
INSERT INTO 'dancecrib' VALUES (3560, '2012-01-22 19:30:31.160371+00', '2021-03-28 13:59:20.651155+00', 7220, 1, NULL, 'ace', '1–::

  1c set and cast off 1 place (2c up), 2c repeat

9–::

  1W+2M cross over RH and 1M+2W repeat, 2c+1c turn RH 1½, 1c stays in the middle facing down

17–::

  1c lead down, cross and cast up ; 2c+1c+3c A&R

25–::

  Opposing Reels3{6} in sideline (Rsh to 2cnr) | 1c cross LH (on second turn, 1c crosses down LH to 4pl as 4c dances to 3pl)', 2);
INSERT INTO 'dancecrib' VALUES (10129, '2017-09-15 07:41:58.14302+00', '2020-08-02 23:13:20.820632+00', 371, 2, NULL, 'ace', '*Note: Bars 1-24 have a fugue with one subject: as danced by the 1s this comprises turns RH and then LH, then partners chasing each other down the M side to new places on opposite sides, and then to below the bottom of the set, own sides.*

1-8::

  1s turn once RH; then turn once LH _while_ the 3s turn RH

9-12::

  1M (1L following) casts 2 places and crosses to 3rd place opp. sides WHILE 3L (3M following) casts up 2 places and crosses to 1st place opp. sides AND 2s turn once RH

13-16::

  1L (1M following) casts 1 place and crosses to below bottom of set own sides facing each other WHILE 3s reverse their track of Bars 9-12 back to own places (i.e. 3M starts by casting, 3L follows) AND 2s turn once LH AND 4s turn once RH 

17-24::

  1s turn RH moving up to 3rd places own sides (2s & 3s step up); then 3s & 1s dance LH across once round ending on sides, WHILE 2s & 4s dance halfway clockwise around them to end places opp. sides

25-32::

  All dance ½ reels of 4 on sides with unusual starts: on L side initial order is 4M, 3L (these two pass RSh), 1L (moving slowly up) & 2M (looping to R), and end order is 1L, 2M, 3L, 4M ; while on M side initial order is 4L (looping to R), 3M (moving slowly down), 1M, 2L (these two pass R Sh), and end order is 2L, 1M, 4L, 3M. Then 2s & 4s turn RH about 1½ to end in orig. places own sides (1M & 3M step up)

33-40::

  1s ½ RH across with 2s, ½ LH across with 3s, ½ RH across with 4s,  then 4s & 1s cross RH to own sides (order now 2x, 3x, 4, 1)

41-48::

  2s part-set (1 pas-de-basque) RF, turn 1½ LH in 6 bars to own sides & dance 1 pas-de-basque LF WHILE 3s set for 2 bars, turn 1½ RH in 6 bars to own sides AND 4s dance 3 pas-de-basques RF, LF, RF, turn once LF in 4 bars to own sides & dance 1 pas-de-basque LF AND 1s set twice (4 bars) & turn once RF to own sides.



', 3);
INSERT INTO 'dancecrib' VALUES (15173, '2022-10-16 21:51:49.3972+00', '2023-01-07 16:18:56.907642+00', 21150, 1, 1645, 'ace', '*On 2nd chord, 3W & 4M change places so 3c & 4c are beside partner*

1--::

  1c cross RH | cast off (2c up) ; 1c dance down (3M+4M up) | cast to 4pl (3W+4W up) _while{4}_ 2c cross RH | cast off (3M+4M up)

9--::

  1c followed by 2c dance down (3W+4W up [11-12]) ; 2c followed by 1c dance up to 3pl & 4pl

17--20::

  3c+4c & 2c+1c &frac12; Circle4 to L | all turn P BH & reform circles

21--24::

  3c+4c & 2c+1c &frac34; Circle4 to R, all end facing P: 4c & 3c across, 2c & 1c up/down

25--28::

  4c cross RSh | cast off & join NH facing up

  _while{4}_ 3c A&R{1+1} | cross up LSh & face down NHJ

  _while{4}_ 2M+1M & 2W+1W A&R{1+1} up/down | &frac12; turn P BH to sides facing across & keeping NHJ

29--32::

  3c+4c S&Link across _while{4}_ 2c+1c S&Link on sides (M side: 3M,4M,2M,2W; W side: 3W,4W,1M,1W)

', 5);
INSERT INTO 'dancecrib' VALUES (1884, '2012-01-22 19:29:08.048841+00', '2021-03-27 19:22:38.6218+00', 9167, 1, NULL, 'ace', '1–::

  2c two ½Fig8, dancing Lsh round 1cnr and Rsh round 2cnr, to (1,2x,3) .

9–::

  1c+2c R&L, 1M & 2M finish facing down/up the dance for.

17–::

  Parallel ½Reels3 on the sides, 2c begins Lsh to 1c (3,2x,1) ; 2c set to 1c up/down, change places EH, 2c passing outside and stay facing out (3,1,2x)

25–::

  2c cast into ½ Fig8 round 1c, Finish facing P ; All C turn LH (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (14095, '2021-06-28 23:05:03.874063+00', '2021-08-10 18:44:20.144997+00', 18696, 1, 202, 'ace', '1--::

  1c & 3c Petronella turn | set ; turn P RH. 1W,1M,3W & 3M finish on midline facing own sides

9--::

  1M+3W turn LH 1½ _while{4}_ 1W+2W+3M+2M chase clw ½. 3c & 1c on midline face P ; all set to P | 3c & 1c turn P RH ¾ _while_ 2c turn P RH ½  (to 3,2,1) ready for

17--::

  3C Allemande. On [22] 1c & 2c face up _while_ 3c face down | 1c cast off to 2pl and face in _while_ 2c dance up to 1pl and face out _while_  3c turn outwards to 3pl and face out (2,1,3)

25--::

  Mirror Reels3 on sides, 1c in and down, 3c out and up (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (13648, '2021-02-05 20:03:44.421039+00', '2022-06-11 02:39:50.434168+00', 20215, 2, 963, 'ace', '1-6::

  1s,2s,3s dance mirror reels on the side. 1s, 3s cast to begin  2s dance up

7-8::  

  1s and 2s extra loop to change places while 3s long loop into 3rd plc.  1s finish Lsh/Lsh in the middle facing opp side 

9-12::  

  1s RHA, 1M with 3s, 1W with 2s  

13-16::

  2W and 3M leading, all chase cw 1/2 way, 1s merge into the chase and end facing down (3),1,(2) 

17-24::

  3s,1s,2s dance a grand chain, 3s crossing to begin  

25-28::  

  all adv and retire  

29-32::  

  3s and 2s set and cross while 1s dance down below 3s and cast up to 2nd plc finishing 3,1,2 with 3s and 2s facing out, ready to begin again', 5);
INSERT INTO 'dancecrib' VALUES (2619, '2012-01-22 19:29:50.289427+00', '2021-03-27 19:23:35.440126+00', 9090, 1, NULL, 'ace', '1–::

  1c+2c set | 2c cast to 1pl _while_{2} 1c dance down ; cast behind 3c and lead up to 2pl facing up in promhold

9–::

  1c with 2diag (2W+3M) ½Rsh Reel3 ; 1c swivel inwards to face out to W side in Promhold for ½Reel3 with 1diag (Rsh to 3W)

17–::

  Repeat starting down (Rsh to 3M position) ; repeat out M side (Rsh to 2M position)

25–::

  2c+3c set and cross twice _while_{8} 1c lead down, cross between 3c ; lead up crossing between 2c and cast to 2pl.

', 2);
INSERT INTO 'dancecrib' VALUES (8807, '2015-06-26 22:09:10.25311+00', '2022-04-25 20:21:50.949265+00', 16312, 2, 160, 'ace', '1-8::

  Mirror Reel3 on own sides - 1C in and down to begin

9-16::

  1C 2C Birl

17-24::

  1L+2C and 1M+3C Dance 3H round to the left - 1C face one another up-down in the center of the set ;   1C dance Rsh round each other to 2pl own sides.

25-32::

  1C 3C Birl.', 2);
INSERT INTO 'dancecrib' VALUES (2077, '2012-01-22 19:29:18.588285+00', '2021-03-27 19:25:14.436766+00', 8811, 1, NULL, 'ace', '1–::

  1c+2c set | half RHA ; set | half LHA, 1M& 2W remain facing down/up (1,2,3)

9–::

  1W+2M change places RH _while_{2} their P cast down/up one place | Turn P LH ½ (as for L-Chain). ; 1M+2W cast down/up | wait {2} _while_{2} 1W+2M turn 1¾ RH to finish 2c in 1pl and 1c BHJ in centre (3c step in) for .

17–::

  1c+3c Poussette (2,3,1)

25–::

  All circle6 and back .

', 3);
INSERT INTO 'dancecrib' VALUES (3133, '2012-01-22 19:30:12.70922+00', '2021-03-27 19:38:45.465108+00', 5658, 1, NULL, 'ace', '1–::

  1c+2c A&R ; all cross NHJ, the M making the arch | keeping hands joined change places on the sides, 2c passing outside as 1c twirls under the joined hands (2x,1x)

9–::

  2c+1c A&R ; all cross NHJ, the W making the arch | change places on the sides as before, 2c again passing outside (1,2)

17–::

  1c lead down the middle and up

25–::

  1c+2c Poussette (2,1)



{{explanation}}

Option: on [8] and [16] the turns under joined hands may be omitted.', 3);
INSERT INTO 'dancecrib' VALUES (14449, '2021-11-15 03:54:01.79328+00', '2022-09-19 06:38:36.186955+00', 14331, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; 2c+1W & 1M+3c RHA. 1c face 1cnrs

9--::

  *Modified Set to and Turn Corners* : same but on [11-12] 1c turn 1cnrs RH and pass P RSh. On [15-16] 1c turn 2cnrs LH, pass P LSh in centre and face up NHJ, 1M pulling LSh back.

17--::

  1c dance to top | cast off and meet ; dance to bottom | cast up to 2pl centre facing up _while{8}_ 2c & 3c set | cross RH ; set | turn P RH ½

25--::

  3C Promenade (2,1,3)



*Deviser''s note* : The final figure could be adapted to an allemande for a 3-couple set dance.', 2);
INSERT INTO 'dancecrib' VALUES (14857, '2022-06-11 02:32:47.214856+00', '2022-06-11 02:39:50.438331+00', 20215, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides {6}, 1c & 3c casting _as_ 2c dance up | 1c+2c continue the reel, 1c to midline LSh to P facing opposite sides, 2c to 1pl, 3c looping to 3pl.

9--::

  2c+1W & 1M+3c RHA ; 2W & 3M leading, all chase clw ½ (3x,1,2x)

17--::

  Gr-Chain, 3c crossing RH (3x,1,2x)

25--::

  All A&R ; 3c & 2c set | cross RH and face out _while{4}_ 1c dance down and cast up to 2pl (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (2315, '2012-01-22 19:29:31.205664+00', '2020-01-26 00:38:22.761826+00', 9040, 1, NULL, 'ace', '1–::

  1c cross down (no hands) and face out (2c up) | 1c+3c change places EH, 3c finish facing out & down and 1c facing in ; ½ Reels3 on the sides (1x,3,2)

9–::

  Repeat [1-8] from new places (to 1,2,3), 1c facing in ; 2c out and up.

17–::

  1c followed by 2c down the middle ; 2c+1c set to P | 2c dance to 1pl facing out and down _while{2}_ 1c dance to 2pl in the centre, -

25–::

  2W+1W+3W RHA _while{4}_ 2M+1M+3M LHA ; 1c dance to the top and cast to 2pl. (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14952, '2022-07-11 11:57:33.196283+00', '2022-07-11 12:05:11.250174+00', 20019, 1, 202, 'ace', '1--::

  1c+2c The Bourrel _while{8}_ 3c & 4 turn RH ½, face P and cast away to exchanged places ; set | cross LH. 1c & 3c face out (2,1,3,4)

9--::

  1c & 3c dance out through ends | cast inwards, meet and lead RH to centre ; 1c+3c RHA (2,1,3,4)

17--::

  1c+3c Mirror Set&Link, 1c casting away ; 1c+4c repeat [17-20] (2,3,4,1)

25--::

  Mirror Reels4 on sides, RSh on Wside, LSh on Mside (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3068, '2012-01-22 19:30:09.174325+00', '2021-03-27 19:43:01.729409+00', 5444, 1, NULL, 'ace', '1–::

  1c+2c set to P {1}, set down/up on side {1} | turn RH ½ on side ; into 2c+1c RHA (to 2,1,3,4)

9–::

  2c+1c half R&L ; 1c+2cl chase back cclw ½ round the square _while{4}_ 3c+4c R&L ending with a full LH turn (to 2,1,4,3)

17–::

  1c+4c+3c Reels3{6} on the sides (4c Rsh to 1c) | 1c+4c turn RH ½ on the sides (to 2,4,1,3)

25–::

  All circle8 and back.

', 2);
INSERT INTO 'dancecrib' VALUES (2565, '2012-01-22 19:29:47.863734+00', '2021-03-27 19:52:58.114487+00', 3473, 1, NULL, 'ace', '1–::

  1c+2c cross RH, set ; repeat

9–::

  1c+2c RHA ; LHA

17–::

  1c cast round 2c and dance down-the-middle ; and up

25–::

  1c cross RH, set, cross RH, cast off one (2c up)

', 2);
INSERT INTO 'dancecrib' VALUES (1763, '2012-01-22 19:29:01.120174+00', '2021-07-02 10:49:08.580636+00', 545, 1, NULL, 'ace', '1–::

  1c cast behind own lines and back

9–::

  1c cross over RH, cast off one place ; cross over LH and cast up (2,1)

17–::

  1c+2c A&R ; half R&L (2x,1x)

25–::

  2c+1c A&R ; turn P RH 1½ to (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (14953, '2022-07-11 15:11:56.580012+00', '2022-07-11 15:14:18.527266+00', 20025, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; cross LH | dance LSh round 4cnrs into facing lines3 across

9--::

  All set | chase clw ½ {4} | cross RH. 1c face out

17--::

  1c dance LSh round 1cnrs[pos] (to 2x,1x,3x) ; 1M+2W change places RH _while{2}_ 3c cross RH | 1W+2M change places RH (1,2,3)

25--::

  *Tandem R&L* : all cross RH | (2W (1W following) + 3W & 2M (1M following) + 3M change places LH (to 3x,1x,2x) ; all cross RH | 1W (3W following) + 2W & 1M (3M following) + 2M change places LH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (12666, '2020-03-15 18:18:40.334096+00', '2022-06-12 11:03:18.136355+00', 14995, 2, 963, 'ace', '1-8::
 1c&2c dance Pinwheel Progression  
9-12::
  1w with 2c, 1m with 3c, RHA. 1c finish facing 1st crn  
13-16::
  1c with 1st crn dance Rsh 1/2 R4.  1c finish 2 pl own side  
17-20::
  LHA, 1m up, 1w dn. 1c finish facing 2nd crn  
21-24::
  1c with 2nd crn dance _Lsh_ 1/2 R4. Finish in facing lines across, 1m top, 1w btm  
25-28::
  1c diag R&L once (1m&2w, 1w&3m)  
29-30::
  all chase ccw 1/2 way to opp sides  
31-32::
  All cross LH to own sides  
  Note:  Pinwheel progression - 1 - 4 1m&2w back to back while 1w&2m dance cw and advance with their partners as their partners retire. Finish 1w&2m Lsh to Lsh, facing ccw, nearer hands joined with partner 5-6 all dance 2 steps to line of 4 in ctr 7-8 2w casts to 1w place, 2m curls up to 1m place. 1m casts to 2m place, 1w curls to 2w place
  

  ', 3);
INSERT INTO 'dancecrib' VALUES (14097, '2021-06-30 09:18:24.682948+00', '2021-07-01 06:04:43.530208+00', 20245, 1, 202, 'ace', '1--::
  1c & 2c Petronella turn in tandem | set ; change places RH with P | chase clw ¼ (1x,2x,3)
9--::
  Mirror Reels3 on sides, 1c RSh to 2c (1x,2x,3)
17--::
  1c+2c RHA to sides ; chase clw ½ (2,1,3)
25--::
  1c+3c S&Link. On [28] 1c face up, 3c face down ; 3c+1c turn RH on sides (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (13286, '2020-10-17 23:01:40.009278+00', '2021-06-30 09:19:44.380737+00', 672, 2, 35787, 'ace', '1-8::

  Reels on opposite side, all 3 couples crossing at top.

9-16::

  Reels on own side, all 3 couples crossing at top.

17-24::

  C1 & C2 Rondel (C1 end facing 1st corners).

25-28::

  C1 cast off, dance below C3; dance up NHJ to face 1st corners.

29-32::

  Turn 1st cnr w both hands, Turn 2d corner w both hands; cross to 2d place own side.', 0);
INSERT INTO 'dancecrib' VALUES (14758, '2022-04-15 21:07:11.549852+00', '2022-04-26 01:36:53.094385+00', 13766, 1, 1645, 'ace', '1--::

  1c & 3c turn &frac34; RH | set _while{4}_ 2c &frac12; turn RH | cast away to opp side ;

  1c+3c &frac12; Reel4 on centre line, 1M/3W end facing 2W/2M

9--::

  2W+1M+3W+2M &frac12; Reel4 across, 3W & 1M end facing P on centre line ;

  3c & 1c set to P | turn &frac34; RH to sides (3,2,1)

17--::

  3c+2c dance first 6 bars of Bourrel | petronella to sides (2,3,1)

25--::

  3c+1c Poussette (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (3326, '2012-01-22 19:30:20.650825+00', '2022-09-19 06:43:55.446889+00', 13437, 1, NULL, 'ace', '1–::

  1c+4c set | long cast to middle (2c+3c to ends) | ½ RHA and join NH with cnrs, all facing clw in St.Andrew''s Cross

9-12::

  ½ RHA, finish in »Cross« centres facing corners ;

13-20::

  All set | change places RH ; repeat LH and reform the »Cross« facing clw

21-24::

  ½ RHA, to (2,4x,1x,3) with 4c&1c in the centre, NHJ, facing nearest end

25–::

  4c+1c lead out the end, cross and cast to (2,4,1,3) ; All turn P RH', 3);
INSERT INTO 'dancecrib' VALUES (14858, '2022-06-11 21:07:45.037321+00', '2022-06-12 05:00:07.487491+00', 14995, 1, 202, 'ace', '1--::
  *Pinwheel progression* : 1M+2W dance BtoB _while{4}_ 1W+2M chase one place clw | advance to P as P retire into 1diag, 1W+2M LSh to LSh, NHJ with P all facing cclw ; all dance to midline. 2c face Mside, 1c face Wside | all dance to progressed places, 2M & 1W by curling and 1M & 2W by casting (2,1,3)
9--::
  2c+1W & 1M+3c RHA. 1c face 1cnrs ; ½ Reel4 on 1diag (3W,1M,3M on Mside, 2W,1W,2M on Wside)
17--::
  2W+3W+1M & 1W+3M+2M LHA. 1c face 2cnrs ; ½ Reel4 on 2diag, 1c LSh to 2cnrs into facing lines3 across (1M between 3c, 1W between 2c)
25--::
  ½ diagonal R&L ; all chase cclw (to 2x,1x,3x) | cross LH (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (12688, '2020-03-28 11:02:26.268976+00', '2020-03-28 11:12:25.502264+00', 19908, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c RHA ; »4C Snake Pass« [: unwind the RHA, 2W & 3M leading, pass other snake LSh to opposite sides and chase cclw] (4,3,2,1)

9--::

  4c+3c & 2c+1c LHA ; 3c+2c S&Link into Reel4 position (4,2,3,1)

17--::

  ½ Reels4 (to 1,3,2,4) ; 1c+3c & 2c+4c RHA (1,3,2,4)

25--::

  ½ Reels4 (to 4,2,3,1) ; 4c+2c & 3c+1c LHA (4,2,3,1)

33--::

  4c+2c & 3c+1c S&Link (to 2,4,1,3) ; 2c+4c & 1c+3c Circle4L (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2490, '2012-01-22 19:29:44.696646+00', '2021-03-27 19:54:39.490267+00', 3180, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  All circle8 and back.

9–::

  1c+3c LHA {3}, swivel L and cast out to own place | all C set NHJ

17–::

  2c+4c repeat, with RHA and swivel R | all C set NHJ

25–::

  All turn cnr RH | P LH ; cnr RH | P ¾ LH to finish all M BtoB in the middle facing P on the outside

33–::

  All set to P with a suitable Strathspey setting step (e.g., Rocking Step). ; All ½Reels4 across, W giving brief LHA in the middle, the M end BtoB in the middle facing one position cclw from own place (ie facing their corner)

41–::

  Repeat 33-40 to finish all W in own place and M facing opposite W.

49–::

  All C turn RH ½  | all W ½ LHA _while{2}_ all M set ; All C 1 ¼ turn RH to finish M facing in, W out for

57–::

  Half Schiehallion reel, to original places.



{{title}}

Reel



1-64::

  Repeat bars 1-64 of Strathspey, substituting a suitable Reel setting step (e.g., two pas de basque and four spring points) in bars 33-36 and 41-44.

', 2);
INSERT INTO 'dancecrib' VALUES (8229, '2014-04-02 11:02:17.677724+00', '2020-01-28 21:41:34.04995+00', 13934, 1, NULL, 'ace', '1–::

  1c+3c Reel4 on 2diag, 1W+3M dance a full reel, 1M+3W cross to enter, dance ½Reel4, and on [7-8] cast clw behind own lines to places, (1,2,3)

9–::

  1c+2c Tournee (2,1,3)

17–::

  1c set »H&G«, finish (2,1,3) with 1c facing out

25–::

  Reels3{6} on the sides, 1c starting down | 1c cast off as 3c dance up (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (12482, '2020-01-05 11:18:41.59084+00', '2020-01-05 11:21:00.267935+00', 19810, 1, 1645, 'ace', '1-::
  1c cross RH | cast off (2c up) ; 2c & 1c cross RH | 2c & 1c cast off (1c below 3c)
9-::
  2c & 1c cross RH (1c retain RH) | 1c cross up RH _while_ 2c cast off below 3c ; 1c set | cast to 3pl (3c up) _while{4}_ 2c lead up & turn RH to 1pl (2,3,1)
17-::
  2c & 1c dance BtoB with P ; 2c+1c dance BtoB on sides round 3c
25-::
  All Circle6 & back (2,3,1)
', 2);
INSERT INTO 'dancecrib' VALUES (10925, '2018-07-26 15:48:52.794988+00', '2020-02-04 02:54:02.295769+00', 1273, 1, NULL, 'ace', '1--::

  All Rsh Reels4 on the sides (1,2,3,4)

9--::

  1c+2c & 3c+4c ½Circle4 L | Set holding hands ; ½Circle L to places | set (1,2,3,4)

17--::

  1c+2c & 3c+4c ½ RHA and all face clw round the set | All set R {1} passing P BtoB to own side and set R {1}  facing P ; repeat [17-20] to (1,2,3,4)

25--::

  1c+3c cross RH and cast off one (2c+4c up) ; 1c cross RH and cast off to 4pl _while{4}_ 3c turn RH ½ and lead up to 2pl (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (14954, '2022-07-13 01:16:49.307338+00', '2022-07-13 01:19:12.941751+00', 12695, 1, 202, 'ace', '1--::

  1c cross RH | cast off 2 places (2c+3c up) ; 2c repeat [1-4] (3,1x,2x)

9--::

  1c (2c following) ½ Fig8 up round 3c (to 3,2,1). On [12] 1c in 2pl centre face up ; 1c dance to top | cast off _while{4}_ 2c dance down to 3pl | stand still (3,1,2)

17--::

  All set | turn P RH ½ to centre facing clw ; all chase clw ½ to sides. On [24] 1c dance in to face 1cnrs

25--::

  Set to Corners. On [28] 1c dance PdB L into BtoB position facing ends ; 1c dance LSh round 3cnrs to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2462, '2012-01-22 19:29:40.269107+00', '2021-03-27 19:56:41.053923+00', 3065, 1, NULL, 'ace', '{{explanation}}



1-::

  Circle8 and back

9–::

  1c+3c BHJ slip past each other, men''s backs passing ; and back, women''s backs passing.

17–::

  2c+4c repeat.

25–::

  All W RHA ; LHA, finish in own place facing corners.

33–::

  All W turn corner RH ; turn P LH

41–::

  All M RHA ; LHA finish in own place facing parters.

49-64::

  ½ G-Chain with claps: pass partner RH {2} | stop and clap on the first beat {2} ; pass the next person LH {2} | clap (2) ; repeat, meeting P on [62], opposite original place.



{{explanation}}

Repeat once from the new position.  

', 3);
INSERT INTO 'dancecrib' VALUES (14102, '2021-07-02 11:06:09.325492+00', '2022-07-31 10:35:07.079785+00', 1711, 1, 1645, 'ace', '1--::

  1c cross in front of 2c into Fig8 round 2c & 3c, touching NH on meeting & end facing 1cnrs (2c up on 7-8)

9--::

  1c+1cnrs set HS ; turn BH, 1c pass RSh to face 2cnrs, cnrs dance 4 bars

17--::

  Repeat [9-16] with 2cnrs, 1c end passing RSh to own sides (2,1,3)

25--::

  2c+1c+3c A&R ; turn P RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (15167, '2022-10-11 14:08:29.708138+00', '2022-10-19 14:14:25.210036+00', 20566, 1, 202, 'ace', '1--::
  1c+2c RHA ; LHA
9--::
  1c dance down (2c up on [11-12]) ; dance up to 2pl (2,1,3)
17--::
  1c set advancing to 1cnrs | turn 1cnrs BH (skip change) and face 2cnrs ; set to and turn 2cnrs BH (skip change). 1c on midline face Mside, 1W on P''s Right
25--::
1c NHJ dance out and cast back to midline facing Wside ; dance out and cast back to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2719, '2012-01-22 19:29:54.488974+00', '2020-03-29 19:20:40.785912+00', 4026, 1, NULL, 'ace', '1–::

  1c+2c ½ L-Chain ; RHA

9–::

  LHA ; ½ L-Chain to original positions.

17–::

  All set H.Schottische to P with R foot {2} | turn LH ½ (L foot, R foot)  ;



{{explanation}}

All set H.Schottische to P with L foot {2} | turn RH ½ (R foot, L foot)



25–::

  1c+2c Rondel.  (couples facing cclw make the arch)', 2);
INSERT INTO 'dancecrib' VALUES (9132, '2016-04-08 16:45:26.576114+00', '2022-04-26 09:17:29.137185+00', 16626, 2, 160, 'ace', '1-8::

  1C 2C bourrel.

9-16::

  6 hands round and back.

17-24::

  Reel 3 across - 1L + 3M, 1M + 2L pass Rsh to begin - 1C turn LH on bar 24 to change reels and direction to finish in 2pl on opp. sides.  Order is 2 1x 3.

25-32::

  All adv & ret. ; 1C half fig. 8, 1L down, 1M up.', 0);
INSERT INTO 'dancecrib' VALUES (3537, '2012-01-22 19:30:29.843981+00', '2021-03-30 20:33:42.940061+00', 7142, 1, NULL, 'ace', '1–::

  All set | all circle R ¾ so M face down, W up | all cross RH with P

9–::

  All circle L ¾ to (1x,2x,3x) ; all cross RH | all set (1,2,3)

17–::

  1c cross RH | cast off (2c up) ; cross LH and cast L (L up, M down) and in through end couple

25–::

  1c cross RH to face 2cnr | 2c+1M & 1W+3c Rsh Reels3{6} across, to (2,1,3)

33–::

  1c+3c set | ½ RHA ; turn RH 1½ to (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (8023, '2013-09-07 14:03:52.248617+00', '2020-08-02 23:20:52.701136+00', 498, 2, 106, 'ace', ' Original Text (available online from Scottish Dance Archives)



The dancers stand in a single circle, boys with their partners on their right.



1 - 8::

  Circle round and back.



9 -16::

  Boys advance towards centre with two small skip change of step and join hands to make arches. Girls stand for two bars, dance under partner''s right arch, round in front of him under the left arch and out to place. Boys turn round to face partners on bar 16.



17-24::

  Back to back with partners, turn right hands to finish facing anticlockwise, hands crossed ready for:



25-32::

  Promenade with an allemande hold. On bar 32 the boy turns his partner under his arm to face him ready for:



33-40::

  Grand Chain. Taking two steps to each person and counting partner as No.1, pass 4 people. The 5th person (to whom they do not give hands) is the new partner.', 5);
INSERT INTO 'dancecrib' VALUES (1937, '2012-01-22 19:29:10.790025+00', '2021-03-27 20:00:44.257794+00', 2786, 1, NULL, 'ace', '1–::

  2c+4c set advancing joining RH with P | BiL ; turn RH ½ | BiL

9–::

  1c+2W & 2M+3c+4W & 4M+5c LHA ; 2c+4c pass Lsh into RHA with other couple, and pass Lsh to BtB facing own sides for

17–::

  All set in DDTr | 2c+4c change places RH (in PdB) with person on R _while_{2} others set ; all set in DDTr | centre dancers change places LH (in PdB or SkCh) with person on left _while_{2} others set , all finish on own side facing a new partner  Order Men (2,4,1,5,3) and W (3,1,5,2,4)

25–::

  Top 2 couples & bottom 2 couples R&L

', 3);
INSERT INTO 'dancecrib' VALUES (2071, '2012-01-22 19:29:18.229671+00', '2020-01-29 22:47:28.413886+00', 11477, 1, NULL, 'ace', '1–::

  1c set R {1} dance in and cast to 2pl facing down (2c up) ; ½ G-Chain (2c cross) with polite turns (3x,1x,2x)

9–::

  1c set R turning out {1} cast below 3c, dance up to top and cast to 1diag BtoB facing 3cnr pos.

17–::

  1c set R to 3cnr {1}, ½ diag. Reel4, passing Lsh to face 4cnr pos. ; 1c set R to 4cnr {1}, ½ diag. Reel4 (to 2,1,3)

25–::

  All set R {1}, circle6 L {3} ; Set L {1}, circle6 R (2,1,3)



{{explanation}}

Note:	After set R (on bars 1, 9, 17, 21) dance Sk-Change leading with L foot.', 3);
INSERT INTO 'dancecrib' VALUES (1777, '2012-01-22 19:29:01.832245+00', '2021-07-01 22:53:15.408811+00', 578, 1, NULL, 'ace', '1–::

  1c turn BH | cast (2c up) ; turn BH | cast L into lines across (1W up / 1M down)

9–::

  All set twice, on [11-12] 1c petronella to between corners ; 2c+1c+3c set twice , on [16] 1c dance L to face 1cnr

17–::

  1c set to and turn cnrs, finish in the middle facing the M side RHJ, W on the R

25–::

  1c lead out on M side, cross and cast to meet in the centre ; repeat on W side, finish in (2,1,3).', 3);
INSERT INTO 'dancecrib' VALUES (14101, '2021-07-01 18:09:57.92365+00', '2021-07-01 23:18:40.937106+00', 2850, 1, 202, 'ace', '1--::
  Mirror Reels3 on sides, 1c in and down (1,2,3)
9--::
  *Half Rondel* : 1-2 under arch | 3-4 cross and loop ; 5-6 set | 7-8 2c cross LH while 1c turn RH ¾ to face 2cnrs RHJ
17--::
  1c RHJ set to 2cnrs (swivel ½ inwards) | set to 4cnrs (turn LH to face 1cnrs) ; set to 1cnrs (swivel ½ inwards) | set to 3cnrs (and face own 2cnrs)
25--::
  Reels3 across, 1c RSh to 2cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14937, '2022-07-03 12:59:42.193979+00', '2022-07-13 06:45:13.243641+00', 6679, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; cross LH | dance LSh round 4cnrs into facing lines3 across
9--::
 ½ Reels3 across, 1c RSh to 1cnrs ; all set | change place RH
17--::
  ½ Reels3 across, 1c RSh to 2cnrs[pos], 3c & 2c casting ; all set | all change places.1c face out as 3c & 2c face P
25--::
  1c dance RSh round 2cnrs[pos] to 2pl | set ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14106, '2021-07-04 08:53:46.087071+00', '2021-07-04 09:04:00.329792+00', 14118, 1, 202, 'ace', '1--::

  1c set | turn RH ; cast off (2c up) | 1c turn LH ¾ and face Wside

9--::

  1c lead out, cross and cast into lines3 across ; ½ Mirror Reels3 across, 1M Lsh to 3M, 1W RSh to 2M

17--::

  3C Set&Link across (to 2,1,3) ; all turn P RH (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14955, '2022-07-13 06:23:30.712864+00', '2022-07-13 06:35:17.45672+00', 936, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; ½ Fig8 down round 3c (2,1,3)
9--::
  1c cross LH | cast up (2c down) ; ½ Fig8 up round 2c. On [16] 1W dances LSh round 2W to own side between 2W & 3W and face out _while_ 1M dances between 2c finishing behind 1W (1,2,3)
17--::
  1c (1W leading) dance RSh round 3c to 2pl centre, RHJ facing up ; 1c lead to top | cast off and face 3c (2c up on [23-24])
25--::
  1c & 3c facing on sides set | turn BH ; 2c+1c Circle4 L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14864, '2022-06-14 14:27:39.37913+00', '2022-06-14 14:27:39.37913+00', 20784, 2, 1, 'ace', '1–8::
  1M followed by 2M+3M and 1W followed by 2W+3W dance in, cast off to 3pl, and
  lead back up to fin in prom hold
9–16::
  1c+2c+3c dance “Promenade Pass”:
  9–12::
    All dance 4 bars of a 3-cpl promenade [fin on M''s side in order 321]
  13–14::
   2c&1c veer left individually and dance up one place [fin 2c in 1pl, 1c in 2pl, in
   ctr w/RH joined] _while_ 3c continues promenade
  15–16::
    2c turn R to sides _while_ 1c S adv to pass and fin back to back facing opp sides
    _while_ 3c finishes promenade in 3pl
17–24::
  Double Triangles [on 23–24, 1c dance out to 2pl w/2 PdB]
25–32::
  Circle6', 2);
INSERT INTO 'dancecrib' VALUES (14860, '2022-06-12 17:33:05.98067+00', '2022-06-18 09:08:24.054559+00', 7630, 1, 1645, 'ace', '1--::

  1c+3c advance diagonally | turn &frac14; to L & dance to cnr & face out _while{4}_ 2c cast clw to centre line ; all set

  twice, 1c & 3c turning to face each other on [5-6], end in facing lines across

9--::

  Repeat [1-8] from new places (3x,2x,1x)

17--::

  3c, followed by 2c, cast off _while{4}_ 1c cross up (1,2x,3x) ; 1c+2c &frac12; RHA | 1c+3c &frac12; LHA (2,3,1)

25--::

  All circle6 to L & back (2,3,1)



', 2);
INSERT INTO 'dancecrib' VALUES (14861, '2022-06-12 23:57:22.278712+00', '2022-06-14 12:27:11.856898+00', 20893, 1, 202, 'ace', '1--::
  2C Poussette (1,2,3)
9--::
  Mirror Reels3 on sides {8}, 1c starting in, all joining hands where possible | From bar [6], 1c+2c lengthen their steps to continue the reel to exchanged places, 1c looping to 2pl (2,1,3)
17--::
  1c *Figure of Love* L : 1c ½ Fig8 L, meet P in centre, touch BH and pivot RSh back ½ ; dance RSh round 1cnr to 2pl (2,1,3)
25--::
  1c+3c Tourbillon (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (8101, '2013-11-01 14:03:32.28905+00', '2022-04-26 01:44:05.336008+00', 13365, 2, 160, 'ace', '1–4::

  1M 2L BtoB while 1L dances down own side and follows ptnr as he retires.

  2M similarly dances up own side and follows ptnr as she retires.

5–8::

1s 2s dance half poussette

9–16::

1L 2s & 1M 3s RH across; 1s change ends LH across

17–24::

1s fig. 8 on sides- 1s in and down 

25–32::

1s 3s bourrel

', 2);
INSERT INTO 'dancecrib' VALUES (9113, '2016-03-14 00:07:52.618927+00', '2023-01-07 21:50:51.713807+00', 16856, 1, NULL, 'ace', '{{explanation}}

3c+ 4c start on opp sides (1,2,3x,4x)



1--::

  1c+4c set | cast to middle (2c+3c to end) ; 1c+4c ½ RHA | both M join W behind in promhold, crossing to face out and R

9--::

  2M+both pairs+3M ½ diag. Reel4, pairs pass Rsh ; 2W+pairs+3W ½ diag. Reel4, at the end both pairs split, W leading M, 4W+1M facing up, 4M+1W facing down

17--::

  3c+(4W leading 1M) & 2c+(1W leading 4M) Rsh lead-change Reels3 across (to 3,1,4x,2x)

25--::

  3M+1M+4M+2M ½ diag R&L ; 3W+1W+4W+2W ½ diag R&L (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (12692, '2020-03-30 23:46:39.008458+00', '2020-04-18 23:56:12.692745+00', 17251, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; 2c+3c set and petronella to midline

9--::

  2c+3c ½ Reel4 on midline ; 3c+2c petronella to own sides and set (3,1,2)

17--::

  "Corner Change and Chase":  1c+1cnrs change places RH | the cnrs dance on to the other cnr''s place, with 1c following, returning to 2ppl on own side ; 1c+2cnrs repeat LH (2x,1,3x)

25--::

  All chase cclw half round ; 1c ½ Fig8 R (3,1,2)

', 3);
INSERT INTO 'dancecrib' VALUES (14956, '2022-07-13 20:21:23.681752+00', '2022-07-13 20:22:09.967305+00', 20532, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; turn P RH (2,1,3)

9--::

  1c Fig8 across, RSh to 2cnrs. 1c on midline LSh to P face opposite sides

17--::

  2c+1W & 1M+3c RHA ; all turn P RH. 1c pass P RSh to midline

25--::

  2c+1M & 1W+3c LHA ; all turn P LH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10403, '2018-01-25 20:26:08.45747+00', '2020-10-15 21:49:29.023221+00', 16663, 2, 963, 'ace', '1-8::

  1M dances down middle, casts up behind 3W, crosses over below 2c, casts up behind 2M back to place WHILE 1W casts behind 2W, crosses over below 2c, casts behind 3M and up middle back to place facing out  

9-16::

  1c,2c,3c Rsh R3 on the side  

17-24::

  1c set and cast; 2c,1c,3c, turn partner RH  

25-32::

  2c,1c,3c circle 6 hands round and back', 5);
INSERT INTO 'dancecrib' VALUES (12526, '2020-01-26 11:38:56.033042+00', '2020-01-26 16:17:46.904697+00', 7397, 1, NULL, 'ace', '1--::

  1c+2c turn PRH ; 1c+2c LHA (1,2,3)

9--::

  1c, with 2c+3c dancing up and following, dance down {3}, All Face P and set L{1} ; All cast R to own sideline and set (3,2,1)

17-20::

  3c cross RH and cast off to 2plx _while{4}_ 2c+1c ½ RHA | 2c cross RH to 3pl _as_ 1c dance up NHJ and cast to 1plx (1x,3x,2) 

21-24::

  1c cross RH | cast off and pass P Rsh to face 2cnr _while{4}_ 3c+2c ½ RHA | 3c cross RH to 3plx _as_ 2c dance up NHJ and cast to 1plx  

25--::

  Reels3{6} on the sides, 1c Rsh to 2cnr | All cross RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (15191, '2022-10-27 09:06:42.189138+00', '2022-10-27 10:52:55.636571+00', 11806, 1, 202, 'ace', '1--::

  All W RHA, face centre and cast R to opposite places facing out ; all W chase clw ½ to original places (1,2,3,4)

9--::

  All M set advancing to centre,turning R to face P | all set (M high cuts) ; all M still BtoB set moving one place clw to face a new P | all set (M high cuts)

17--::

  Intersectings Reels4 (quick ½ LHA in centre). Finish as on [17]

25--::

  All couples into allemande hold chase cclw to places. All M face in, all W face out

33--::

  ½ Schiehallion Reels

41--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (12691, '2020-03-29 18:11:09.479135+00', '2020-04-18 20:38:32.641361+00', 19542, 1, 1645, 'ace', '1-::
  6 steps of interlocking reels of 4, starting RSh to P | turn P &frac34; LH to W in centre facing clw, M facing in
9-::
  *Triquetra reel:* M, passing RSh in centre, dance in | then out to end in next place cclw
  _while{4}_ W, passing in front of P, dance out to next place clw |
  then, following that M, dance in to next inner place clw (2,3,1) ; repeat (3,1,2)
17-28::
  *LSh Celtic reel:* Pass P LSh | M &frac23; RHA _while{2}_ W chase &frac13; cclw to (1,2,3) M now inside ;
  repeat twice from new places to (3,1,2) M inside
29-32::
  Turn P 1&frac14; LH (or tulloch turn with L arm elbow grip) to sides (3,1,2)
', 5);
INSERT INTO 'dancecrib' VALUES (15168, '2022-10-11 14:41:44.358903+00', '2022-10-11 14:46:10.497427+00', 2830, 1, 202, 'ace', '1--::

  1c & 3c cross RH | cast off one place to midline LSh to P facing own sides (2c & 4c up) ; 2c+1M & 1W+4c+3M & 3W+5c RHA. On [8] 1c & 3c face 2cnrs

9--::

  Reels4 on 1diag. On [15-16] 1c & 3c pass P RSh to face 2cnrs, 1W+3M passing LSh _while_ cnrs loop to places

17--::

  2c+1M & 3W+5c Reels3 across _while{8} 1W+4c+3M Reel4 across. On [21-22] 1W+3M LHJ turn to face opposite sides on midline and join RH with P

25--::

  1c+3c BiL | turn P RH ¾ and face up NHJ ; 1c & 3c set | cast off, 1c to 3pl and 3c to 5pl (4c & 5c step up) (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (12527, '2020-01-26 14:24:08.891241+00', '2020-01-26 14:26:19.553675+00', 1392, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 down round 3c to face 1cnrs

9--::

  1c +1cnrs change place RH | set ; ½ Reel4 on 1diag. On [16] 1cnrs (in centre) turn LH ¾ to face 2cnrs (own P)

17--::

  2c & 3c change places RH | set ; ½ Reel4 on 2diag (to 1,3,2 on Mside, 3,2,1 on Wside)

25--::

  ½ Reels3 on sides, 3M & 2W LSh to 1c ; 1M+3M & 1W+2W turn RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14863, '2022-06-13 23:22:02.230961+00', '2022-06-13 23:22:33.12528+00', 20768, 1, 1645, 'ace', 'Set of 5 dancers: 2 & 4 on M side facing gaps in line of 1, 3 & 5 on W side.  

.....1...3...5  

Top  

.......2...4..  



1--4::

  1+3+5 S&Link3 _while{4}_ 2+4 S&Link2 to lines across 1+3+2 facing up, 4+5 facing down

5--8::

  1+3+2 S&Link3 _while{4}_ 4+5 S&Link2 ending 4,2 in 1pl & 3pl on W side, 5,3,1 on M side, 5 & 1 facing out

9--12::

  5+3+1 &frac12; Reel3 on M side, 3 starts LSh to 5

13--16::

  4+3+2 &frac12; Reel3 on W side, 3 starts RSh to 2 & ends twirling R to face down in centre

17--20::

  4+3+5 set as DTr | 4 sets _while_ 3+5 &frac12; turn RH & 5 twirls R to face up

21--24::

  5+1+2 set as DTr | 1 sets _while_ 5+2 &frac12; turn RH & 2 twirls R to face 4 in 1cnr pos

25--28::

  2 with 4+1 Corner Pass & Twirl on 1diag & face 2cnr

29--32::

  2 with 5+3 repeat on 2diag, 2 ends in 2pl on W side, 4 & 5 finish twirls on M side facing gaps (3,4,2,5,1)





', 2);
INSERT INTO 'dancecrib' VALUES (14862, '2022-06-13 21:42:10.789536+00', '2022-06-13 21:48:22.367444+00', 19279, 1, 1645, 'ace', '1--::
  1c+2c dance down 3pl _while{2}_ 4c+5c cast up 3pl (4,5,3,1,2) |
  4c & 2c set facing down/up _while{2}_ 5c dance down 2pl & face out _while{2}_ 1c cast up 2pl (4,1,3,5,2) ;
  repeat [1-4] from new places (5,4,3,2,1)
9--::
  4c & 2c set | petronella to centre line ; turn RH ending with backs to 1cnrs
17--::
  *Corners Chase & Turn:* 4c & 2c, followed by 1cnrs, pass RSh | 4c & 2c set in 3cnr pos _while_ 1cnrs turn RH ending with backs to 4c/2c ;
  1cnrs, followed by 4c/2c, pass RSh | 1cnrs set in 1cnr pos _while_ 4c & 2c turn &frac34; RH ending with backs to 2cnrs
25--::
  Repeat [17-24] with 2cnrs, but 4c & 2c end on own side (5,4,3,2,1)
33--::
  All set | turn RH | set
41--::
  2c, followed by 3c+4c+5c, dance down below 1c & cast up to the top | all set (2,3,4,5,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15195, '2022-10-28 10:23:41.946041+00', '2022-10-28 10:24:53.197671+00', 14967, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 down round 3c (2,1,3)

9--::

  1c lead down ; lead up to 2pl (2,1,3)

17--::

  All A&R ; all turn P RH into promhold (2,1,3)

25--::

  3C Promenade (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12047, '2019-08-26 20:33:21.424007+00', '2022-04-26 09:24:17.823504+00', 5225, 1, 202, 'ace', '1--::

  1c+2c The Bourrel (2,1,3)

9--::

  1c cross RH | 1c turn 1cnrs LH ½ ; 2M+3W in 2pl cross RH | 2M+1M & 1W+3W turn LH ½ (On Wside: 2W,1M,2M, On Mside 3W,1W,3M)

17--::

  Reels3 on sides, 1c RSh to 2cnrs

25--::

  1c cross LH | 1c turn 4cnrs[pos] RH ½ ; 2W+3M in 2pl cross LH | 1W+3M & 2W+1M turn RH ½ (3x,1,2x)

33--::

  Reels3 on sides, 1c LSh to 3cnrs[pos] (3x,1,2x)

41--::

  1c set | cross RH ; Circle6 L ½ (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3374, '2012-01-22 19:30:22.580362+00', '2020-04-02 23:41:52.336767+00', 9896, 1, NULL, 'ace', '1–::

  All set | turn RH ½ ; Chase clw ½ (4,3,2,1)

9–::

  Repeat LH / cclw (1,2,3,4)

17–::

  1c slip down | up ; cast to 4pl (2c+3c+4c up)

25–::

  All Circle8 and back (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (13857, '2021-03-29 19:18:38.524093+00', '2021-03-31 08:56:59.967972+00', 15093, 1, 202, 'ace', '1--::

  1c set | 1c (1W leading) cast off 2 places ; cross below 3c (2c up) | dance to 2plx (2,1x,3)

9--::

  Parallel Reels3 on sides {6}, 1c LSh to 2c | all set (2,1x,3)

17--::

  All turn P RH ; chase clw ½ (3x,1,2x)

25--::

  1c ½ Fig8 L round 2cnrs[pos] _while{4}_ 2c & 3c set to P | cross RH (to 3,1x,2) ; 1c ½ Fig8 L round 4cnrs[pos] _while{4}_ 2c & 3c set up/down | change places RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (1767, '2012-01-22 19:29:01.297201+00', '2020-08-02 23:23:07.660178+00', 549, 1, NULL, 'ace', '1–::

  1c & 3c cross RH | cast off (2c+4c up) ; ½ Fig8 up and face 1cnr

9–::

  Turn CPCP (1c & 3c turn 1cnr RH, P LH, 2cnr RH, P LH), finish facing 1cnr

17–::

  1c & 3c Reels4 with 1cnrs, at the end pass P Lsh.

25–::

  1W+2c (top), 1M+4c+3W (middle) and 3M+5c (bottom) RHA ; 1c & 3c turn LH and cast off (4c+5c up). (to: 2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (12528, '2020-01-26 14:46:55.114539+00', '2020-01-26 15:27:21.282811+00', 17177, 1, 202, 'ace', '1--::
  All set | La Baratte (1x,2x,3x)
9--::
  All chase cclw ½ (to 3,2,1) ; 1c set | cast up (2c down) (3,1,2)
17-28::
  3C R&L (3,1,2)
29-32::
  All turn P RH (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (2385, '2012-01-22 19:29:34.785482+00', '2020-12-20 23:43:57.119213+00', 9165, 1, NULL, 'ace', '1–::

  1c+3c dance Rsh ¾ round P to face P on the midline | ½Reel4 | dance Rsh ¾ round P to own sides (3,2,1)

9–::

  2c+1c S&Link ; 3c+1c S&Link (1W & 3M face out) (1,3,2)

17-19::

  ½Reels3{3} on the sides (1c Rsh to 3c), 1W finishes facing out (2,3,1)

20-24::

  1W, 1M following, casts up behind 3W and across in 2pl (3c down) {3} | 1c turns LH to face 1cnrs

25–::

  »Corners Pass and Turn«: (1c dance Rsh around 1cnr _while{4}_ 1cnrs turn BH and return to place as 1c pass Rsh to face 2cnr ; repeat with 2cnrs, 1c passing Rsh to 2,1,3)



{{explanation}}

After the second repetition, 4c dance up slightly as they begin, while 1c step down.', 3);
INSERT INTO 'dancecrib' VALUES (11964, '2019-07-14 19:57:25.64846+00', '2022-04-26 15:03:48.533236+00', 18521, 1, 202, 'ace', '1--::

  1c dance down | turn BH opening to face up ; dance to top | cast to 3pl _while{2}_ 3c dance to 1pl (3,2,1,4)

9--::

  3c+2c & 1c+4c The Bourrel finishing in Reel4 position on sides (2,3,4,1)

17--::

  Mirror Reels4 on sides, RSh on Mside, LSh on Wside (2,3,4,1)

25--::

  2c+3c & 4c+1c Poussette (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (15100, '2022-09-19 09:19:07.941713+00', '2022-09-19 09:21:32.66383+00', 21106, 1, 202, 'ace', '1--::

  All A&R ; All advance, all M retire _while{2}_ all W pulling RSh back face P

9--::

  All Circle L giving hands if possible. All face new P ; all turn P LH 1½ to change places and face each other

17--::

  All Circle R giving hands if possible. All face original P ; all dance BtoB

25--::

  All dance BtoB with person diagonally to the L ; all promenade cclw', 2);
INSERT INTO 'dancecrib' VALUES (3687, '2013-01-22 12:52:21.867455+00', '2021-03-31 09:14:26.947159+00', 7088, 2, 1, 'ace', '1–2::

  1M sets advancing to 2W, who sets back in place _while_ 3W sets advancing

  to 2M, who sets back in place

3–4::

  1M+2W turn R [1M fin in 3W''s place] _while_ 3W+2M turn R [3W fin in 1M''s place]

5–8::

  1W+2M+3W & 1M+2W+3M RH across

9–10::

  1W sets advancing to 2M, who sets back in place _while_ 3M sets advancing

  to 2W, who sets back in place

11–12::

  1W+2M turn L [1W fin in 3M''s place] _while_ 3M+2W turn R [3M fin in 1W''s place]

13–16::

  2W+3c & 2M+1c LH across [2c fin facing out]

17–::

  Reels3 on sides, 2c giving LS to person on L [2W goes out and up, 2M out and

  down]

25–30::

  1c set | turn R ½ ; lead up to the top _while_ 3c set | cross R | cast off to

  3pl

31–32::

  1c cast off [2c up]', 3);
INSERT INTO 'dancecrib' VALUES (13858, '2021-03-31 19:14:01.49886+00', '2021-04-07 11:01:23.88685+00', 20240, 1, 202, 'ace', '1--::
  1c & 3c set | all pivot R and chase clw ¼ in tandem (M leading) to centre ; RHA. 1c+2c & 3c+4c face each other
9--::
  1c+2c & 3c+4c The Rondel, 2c & 4c making arches
17--::
  2c+4c RHA ; 2c & 4c set | cast R, 2c to 3pl and 4c to 1pl (4,1,2,3)
25--::
  All M set advancing to centre | Circle4 L ½ and pivot R to face out from centre _while{4}_ all W chase cclw ½ and face P ; all set to P | turn BH and face cclw
33--::
  In allemande hold, all Promenade (2,3,4,1)', 5);
INSERT INTO 'dancecrib' VALUES (14959, '2022-07-15 17:40:14.100497+00', '2022-07-15 17:40:14.100497+00', 20948, 2, 1, 'ace', '1–::
  All M cross (passing ptr RS) and chase cw to own side [fin 54321]
9–::
  All W cross (passing ptr LS) and chase ccw to own side [fin 54321]
17–::
  1c slip up the middle and down [fin in 5pl making arch]
25–::
  2c (followed by 3c+4c+5c) dance down, under the arch, and cast up on own sides
33–::
  Circle10 round and back, starting to R', 3);
INSERT INTO 'dancecrib' VALUES (14957, '2022-07-14 02:06:48.653228+00', '2022-07-14 02:10:15.442134+00', 5924, 1, 202, 'ace', '1--::

  All chase clw ½ ; set | cross RH (3,2,1)

9--::

  Repeat [1-8] from new positions (1,2,3)

17--::

  Mirror Reels3, 1c in and down. 2c in 1pl & 3c in 3pl face diagonally in _as_ 1c in 2pl centre NHJ face down

25--::

  1c set to 3c, turn inwards and face up NHJ | set to 2c ; 1c dance to top [ cast off to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15196, '2022-10-28 13:31:24.111516+00', '2022-10-28 13:34:33.111892+00', 21128, 1, 1645, 'ace', '*3c & 4c start on opposite sides (1,2,3x,4x)*

1--::

  1c & 4c &frac12; Fig8 round 2c/3c ; 1c+2c & 3c+4c S&Link & face up/down on the sides (2,1x,4,3x)

9--::

  RSh Reels4 on the sides, 1W & 4W end facing out

17--::

  1W, 4M, 1M & 4W dance RSh round the ends (as if continuing the reel) ; 1W+4M & 1M+4W turn LH, end in tandem with M leading

25--::

  1M+4W & 4M+1W tandem LSh Reels3 across with 2c/3c & end dancing down/up the sides (2,4,1x,3x)

', 2);
INSERT INTO 'dancecrib' VALUES (14958, '2022-07-15 13:55:20.411492+00', '2022-07-15 13:55:20.411492+00', 20947, 2, 1, 'ace', '1–::
  1c+2W & 2M+3c RH across ; 1c+2M & 2W+3c LH across
9–14::
  1c lead down between 2c | cast behind 3c ; lead up to 1pl
15–16::
  2c+3c ch pl on sides RH
17–::
  M advance, pull RS back, dance back to own sides | all ½ chase cw
25–::
  All cross R | 1c set adv ; turn BH [in PdB], open towards the bottom and cast up to 2pl
33–36::
  1c set _while_ 2c & 3c set advancing [into line in ctr of set] ; all balance in “cross” formation
37–40::
  1c pull back RS and cast to own sides _while_ 2c & 3c turn LH ¾ to own sides ;
  1c and 2c cross RH on sides _while_ 3c set. [This doesn''t seem to quite work;
  our suggestion would be for everyone to set on 39–40. – Ed.]', 1);
INSERT INTO 'dancecrib' VALUES (14960, '2022-07-16 01:57:23.516909+00', '2022-07-16 02:33:01.288264+00', 20953, 1, 202, 'ace', '1--::
  Mirror Reels3 on sides, 1c in and down (1,2,3)
9--::
  1c+2c RHA ; 2c+3c LHA _while{4}_ 1c turn LH and face out (1,2,3)
17--::
  1c dance down behind own lines, meet then up between 3c, out behind 2c to 1pl centre. On [24] 2c step in
25--::
  1c+2c Poussette (2,1,3)

*Deviser''s note* : On the second time through, on bar 24, 2nd and 3rd couples step in and the dance finishes with a three couple poussette.', 5);
INSERT INTO 'dancecrib' VALUES (14632, '2022-03-03 00:28:25.348342+00', '2022-07-05 22:34:54.536991+00', 20676, 1, 1645, 'ace', '1--4::

  1c & 3c turn &frac34; LH | join RH & BiL up/down _while{2}_ 2c & 4c turn &frac34; LH

5--8::

  W chase &frac12; way cclw outside _while{4}_ M RHA & stay in centre

9--12::

  3W+1M & 3M+1W &frac12; turn LH _while{2}_ 2W+4M+2M+4W BiL across |  

  2W+4M & 2M+4W &frac12; turn LH _while{2}_ 1M+3W+1W+3M BiL up/down

13--16::

  M chase &frac12; way cclw outside _while{4}_ W RHA & stay in centre

17--20::

  M slip in as W slip out, all clap | M slip out as W slip in & clap

21--24::

  W circle4 to L ending beside P (3,4,1,2)

25--::

  All circle8 one place L | set ; turn P RH (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (14100, '2021-07-01 08:57:35.59958+00', '2021-07-02 16:38:20.175878+00', 20247, 1, 202, 'ace', '1--::

  1c lead down ; and up. On [8], 1c turn inwards and face down NHJ, 2c step in and face up NHJ (1,2,3)

9--::

  *Half Rondel* : 1-2 under arch | 3-4 cross and loop ; 5-6 set | 7-8 2c cross LH _while_ 1c turn LH to face 1cnrs

17--::

  Corners Pass and Turn (2,1,3)

25--::

  Circle6 L {3}. On [28] cross R foot over L and face cclw ; chase back cclw to places (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (12695, '2020-04-02 10:12:47.482379+00', '2020-04-02 10:23:25.202757+00', 9143, 1, 202, 'ace', '1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 1c+4c ½ LHA ; 1c & 4c cast outwards to ends (2c & 3c step in) (4,2,3,1)

9--::

  4M+2W & 2M+3W & 3M+1W cross RH | set ; chase clw ½ to own sides (3M,2M,4M,1M on Mside, 4W,1W,3W,2W on Wside)

17--::

  4W+2M & 1W+4M & 3W+1M cross LH | set ; chase cclw ½ to own sides (3,1,4,2)

25--::

  All cross RH | Circle8 L | all set (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8712, '2015-03-07 21:37:15.311858+00', '2022-04-26 01:54:06.962893+00', 14438, 1, NULL, 'ace', '1--::

  1c+2c S&Link ; 2c+1c Circle4 L (2,1,3)

9--::

  1c+3c “The Bourrel” (1M+3W set adv | turn BH 2/3 and twirl _while{4}_ 1W+3M chase ¾ cclw and face P ; 1c+3c set to P | turn P BH ¾), finish in position for

17--::

  3c+1c half poussette ; 2c+1c half poussette, 1c turn on to finish on opposite side facing down NHJ

25--::

  1c dance down between 3c (2c up), cross and cast up ; All turn P BH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (13859, '2021-04-01 08:35:37.359146+00', '2021-04-01 08:51:18.365112+00', 9016, 1, 202, 'ace', '1--::
  1M+2W set advancing (PdB) | turn RH ; 1W+2M repeat [1-4] (1,2,3)
9--::
  1c lead down {3}, turn RH ½ (2c up on [11-12]), lead up and face 1cnrs
17--::
  1c dance RSh round 1cnrs _while{4}_ 1cnrs A&R, 1c pass P RSh ; 1c repeat [17-20] with 2cnrs (2,1x,3)
25--::
  Reels3 on sides {6}, 1c LSh to 1cnrs | 1c cross RH (2,1,3)

*Deviser''s note* : At the end of the second time through 1st couple may cross down to the bottom while original 4th couple continue the reel to their new 3rd place.', 2);
INSERT INTO 'dancecrib' VALUES (9895, '2017-05-29 21:11:30.565747+00', '2023-01-08 10:22:06.103704+00', 17768, 2, 2697, 'ace', '1-8::

    1s cross RH | cast to 2nd place; 1 ¼ turn LH

9-16::

    1L+3s, 1M+2s dance RH across ½ way | 1s dance clockwise ½ way _while{4}_ 2s+3s dance LH across | 1L+2s, 1M+3s dance RH across ½ way, 1s end facing 1s corners

17-24::

    1s+2s+3s dance diagonal Weasel Reel (start 1L to 2M, 1M to 3L, 2L & 3M chase clockwise)

25-32::

    1s dance RSh round 1s corner; turn RH to own sides ', 5);
INSERT INTO 'dancecrib' VALUES (12572, '2020-02-11 09:20:44.828146+00', '2021-04-02 17:07:54.467827+00', 5471, 1, NULL, 'ace', '1--::

  Circle8 and back

9--::

  All M advance to centre and raise both arms into a "double arch" in the centre | and retire ; All W advance to centre, pivot R and dance out, and face out

17-32::

  Full Schiehallion Reel (1,2,3,4)

33--::

  1c+3c advance NHJ to centre | join RH with opposite and lead out between side couple, cross and dance to opposite position | turn P RH ½ (3,2,1,4)  

*Repeat with 2c+4c dancing the final 8 bars, again with 3c+1c, again with 4c+2c*

', 3);
INSERT INTO 'dancecrib' VALUES (12693, '2020-03-31 18:01:16.834205+00', '2020-04-01 08:35:02.998163+00', 14860, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; turn 1cnrs EH (2,1x,3)
9--::
  1c dance BtoB _while{4}_ all cnrs set and cast clw one place (to 3M,1W,3W on Mside, 2M,1M,2W on Wside) ; 1c set | cast clw to midline _while{4}_ all cnrs RHA
17--::
  1c »RSh Turn« _while{4}_ all cnrs set and cast clw one place ; 1c set | cast clw to 2pl _while{4}_ all cnrs Circle4 L (3x,1,2x)
25--::
  Diagonal R&L (2,1,3)

*Note:*  
»RSh Turn« (Right Shoulder Turn) is also known as Gypsy Turn, a term now considered offensive by some.', 5);
INSERT INTO 'dancecrib' VALUES (1804, '2012-01-22 19:29:03.189901+00', '2021-03-27 21:44:37.947243+00', 674, 1, NULL, 'ace', '1–::

  1c+2c Half Reel Progression (both turn BH ¾ onto midline, ½ Reel4, turn BH ¾) to (2,1,3)

9–::

  1c set advancing and passing, turn 1cnrs BH to finish between end couples ; repeat with 2cnrs to finish (2,1x,3)

17–::

  2c+1c+3c cross RH (1c face out and corners face in diagonally) | [19-20] corners advance {1} and retire {1} _while_{2} 1c casts R to finish between end couples ; in lines across all change places RH (up / down) | Repeat [19-20] from new places, 1c finish BtoB facing 4cnr (2cnr persons)

25–::

  1c ½Reel4 with these cnrs, pass Lsh round P to face 3cnr (1cnr persons) ; ½Reel4 with these cnrs, at end turn RH to 2pl own sides

', 3);
INSERT INTO 'dancecrib' VALUES (13861, '2021-04-02 07:56:22.117331+00', '2021-04-10 16:05:53.925177+00', 12737, 1, 202, 'ace', '1--::
  1c & 3c set to P | Petronella turn ; set | turn P RH ½ _while{4}_ 2c & 4c set to P | Petronella turn
9--::
  1c+3c ½ Reel4 (1M+3M pass LSh) into promhold _while{4}_ 2c & 4c set to P |Petronella turn into promhold (to 3,2,1,4) ; all Promenade cclw ½ (1,4,3,2)
17--::
  1c+3c (both leading P LH to centre) LHA ½. 1M+3W face 2c _as_ 3M+1W face 4c ; 1M+3W & 3M+1W lead out through sides, separate and cast (3,4,1,2)
25--::
  ½ Double L-Chain. On [28] all M face clw, all W face cclw ; 4 bars of Gr-Chain (2 bars per hand) (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (14865, '2022-06-15 07:33:47.208998+00', '2022-06-15 07:45:51.042386+00', 5956, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA ; set | ½ LHA (1,2,3)

9--::

  1c set | cast off (2c up) ; ½ Reels3 across, 1c LSh to 1cnrs (2x,1x,3x)

17--::

  All NHJ on sides dance PdB R then Circle6 L ½ (to 3,1,2) ; all turn P RH into allemande hold (3,1,2)

25--::

  3C Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14866, '2022-06-16 22:27:15.08+00', '2022-06-16 22:27:24.663331+00', 20682, 1, 1645, 'ace', '1-::

  2c & 3c &frac12; turn P LH | 2M+3M & 3W+2W &frac12; tandem Reels3 on opp sides, starting RSh to 1W/4M | 3c+2c &frac12; RHA (4,2,3,1)

9-::

  4c+2c & 3c+1c Poussette

17-::

  All A+R{1+1} | 4c+2c & 3c+1c &frac12; circle4 to L ; all cross RH | all set (2,4,1,3)

25-::

  Circle8 & back (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14962, '2022-07-16 22:32:11.276842+00', '2022-07-17 05:25:01.362216+00', 20957, 1, 202, 'ace', '1--::
  1c+2c The Tourbillon (2,1,3)
9--::
  all set advancing passing P LSh, pull LSh back and dance to places, facing cclw ; all chase cclw ½ (3x,1x,2x)
17--::
  2c+1c+3c lead down. On [20] all change sides, W passing aboce M and under joined arms. All face up ; 3c+1c+2c dance up, 3c to 1pl centre NHJ facing down, 1c crossing to 2plx facing in, 2c to 3pl facing up (3,1x,2)
25--::
  Circle6 L {2} | all M turn W on their R while moving clw {2} ; Circle6 L {2} | all set (3,1x,2)
33--::
  1c ½ Fig8 R round 3cnrs[pos] ; all turn P RH (3,1,2)

*Deviser''s note* : repeat with a new top couple (3/3L) or from new position (3/4L).', 5);
INSERT INTO 'dancecrib' VALUES (14961, '2022-07-16 02:22:07.253997+00', '2022-07-18 07:39:21.469252+00', 20951, 1, 202, 'ace', '1--::

  1c & 2c Petronella turn to midline | set to P ; ½ Reel4

9--::

  2c & 1c set to P | Petronella turn to sides ; 2c & 1c turn P RH into allemande hold facing up

17--::

  2c+1c Allemande (1,2)

25--::

  1c+2c The Tournée (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (12694, '2020-04-01 07:47:42.892393+00', '2022-08-15 08:11:08.28731+00', 14832, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; 1c+3c RHA (2,1,3)

9--::

  Reel3 in tandem, 1c (1W leading) LSh to 2c (2M leading) (2,1,3)

17--::

  2c+1c LHA ; ½ Reel3 in tandem, 1c (1W leading) RSh to 3c (3M leading) (3,1,2)

25--::

  3c+1c Circle4 L. 1c & 3c face up/down ; 1c making arch dance up to 1pl _as_ 3c dance down under it to 2pl | 3c making arch dance down to 3pl _as_ 2c dance up under it to 2pl (1,2,3)

33--::

  Repeat same pattern of [29-32], middle couple making arch (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (13855, '2021-03-27 15:21:52.572573+00', '2021-04-02 20:41:49.202391+00', 20257, 1, 202, 'ace', '1--::

  1W+3W turn BH ½, face each other | cast R and dance out through sides, 1W RSh round 4M, 3W RSh round 2M into a line between 1c & 3c positions as for a RHA _while{6}_ 1M & 3M stand still {4} | set advancing (small step to the R, long step to the L) into a line between 2c & 4c positions as for a RHA | 1c+3c ½ RHA. 1W (+3M in tandem) face 4W _while_ 3W (+1M in tandem) face 2W

9--::

  1W+3M in tandem with 2M+4W & 3W+1M in tandem with 2W+4M Reels3 (no change lead), 1W RSh to 4W, 3W RSh to 2M. All finish in 2 lines4 between 2c & 4c positions facing P in order 2,3,1,4

17--::

  2c+3c & 1c+4c *Modified 2C Knot* : all turn P RH ½ into promhold and face out | 2c dance to 1pl _while_ 4c dance to 3pl _while_ 3c dance to 2pl _while_ 1c dance to 4pl. all face in and release RH (2,3,4,1) ; all M bring their P to centre LH | all turn P LH ½, M to centre, W on sides

25--::

  All M RHA and pivot R to face P ; all set | turn P BH ¾ to places (2,3,4,1)



*Deviser''s note* : Dance twice in Strathspey time then twice in Jig time, with RH and skip-ch instead of BH and strathspey travelling.', 5);
INSERT INTO 'dancecrib' VALUES (11583, '2019-02-19 23:03:56.026949+00', '2022-04-26 15:09:22.259096+00', 18036, 1, 1645, 'ace', '1-::

  1c & 3c adv{1} & ret{1} | set ; 2c & 4c repeat

9-::

  1c+3c &frac12; turn opposite RH & twirl away ; 2c & 4c repeat

17-::

  1c+3c bourrel: W set adv | &frac12; turn BH & twirl away _while{4}_ M chase &frac12; way cclw ; set to P | turn BH

25-::

  1c+3c RSh reel4 up/down, on [31-32] W accelerate to end in original places

33-48::

  2c+4c repeat [17-32] across the set

49-::

  1c+3c &frac12; turn opposite RH & twirl away _while{4}_ 2c & 4c adv{1} & ret{1} (small steps) | set ;  

  2c+4c &frac12; turn opposite RH & twirl away _while{4}_ 1c & 3c adv{1} & ret{1} (small steps) | set

57-::

  4C bourrel: all W set adv | circle4 &frac12; way to L, pull back RSh to face original place _while{4}_ all M chase &frac12; way cclw ;

  all set to P | turn BH

65-::

  Intersecting reels4, on [31-32] W accelerate to end in original places

73-::

  Circle8 & back

', 2);
INSERT INTO 'dancecrib' VALUES (13852, '2021-03-26 19:39:36.245612+00', '2021-04-02 20:58:00.281455+00', 17006, 1, 202, 'ace', '1--::

  Circle8 and back

9--::

  All dance BtoB ; turn P RH 1½. All W face in, all M face out

17--::

  All W Circle4 L ; set | cast R to original places and face out _while{8}_ all M chase clw to original places (1,2,3,4)

25-40::

  Schiehallion Reels (1,2,3,4)

41--::

  All turn P RH ; 1c+2c & 3c+4c ½ R&L (2,1,4,3)



*Deviser''s note* : 2nd time through couples in 1st & 4th positions dance ½ rights & lefts as those in 2nd & 3rd positions dance ½ rights & lefts.', 4);
INSERT INTO 'dancecrib' VALUES (13865, '2021-04-03 09:00:41.507776+00', '2021-04-03 09:10:07.000419+00', 6606, 1, 202, 'ace', '1--::

  1c set | turn RH ; all set | cross RH (1x,2x,3x,4x)

9--::

  1c+2c RHA ; chase clw ½ (2,1,3x,4x)

17--::

  1c+3c LHA ; 1c+3c chase cclw ½ (2,3,1x,4x)

25--::

  1c+4c RHA ; 1c+4c chase clw ½ (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13804, '2021-03-11 00:31:27.832492+00', '2021-04-02 20:59:59.379943+00', 16636, 2, 963, 'ace', '1-8::  

  1s & 2s dance the Tourbillon, 1c turn RH on 7&8 to face out 2nd plc opp side

9-14::  

  1c dance cw all the way around back to opp side WHILE 2s&3s adv and dance RHA  2,1x,3

15-16::

  All 1/2 turn prtn RH into allemande hold, 2s & 3s facing down, 1s facing up  

17-24::  

  2s,1s,3s dance a circulating allemande, 1s turn RH on 23&24 to finish with 1w facing out 2nd place own side, 1m behind her  3x,1,2x

25-32::  

  1w giving Rsh to 2m, 1c dance 1/2 dolphin reel with 2c ; 1m giving Lsh to 3w,

1c dance 1/2 dolphin reel with 3c  3,1,2', 5);
INSERT INTO 'dancecrib' VALUES (14964, '2022-07-17 09:53:48.801542+00', '2022-07-18 15:20:01.38348+00', 209, 1, 202, 'ace', '*Lines of 3 dancers round the room facing cclw, M in the middle. Starts with two chords. On 1st chord, all M dance forward and face both W; on 2nd chord, all bow and curtsy*

1--::
  RHA ; LHA
9--::
  Set to and Turn Corners, M starting with W on his R (1W)
17--::
  Reel3, M LSh to 1W into lines3 across facing cclw
25--::
  All A&R ; all M dance forward through next Wline and pull RSh back to face them', 4);
INSERT INTO 'dancecrib' VALUES (10990, '2018-08-15 15:35:01.407376+00', '2021-04-03 11:09:46.73486+00', 15292, 1, 202, 'ace', '_Strathspey_

1--::

  All turn P RH ; S&Link, finishing next to cnr, M facing out

9--::

  All turn cnr LH ; S&Link with cnr (2M+4W,3M+1W,4M+2W,1M+3W)

17--::

  All W ½ LHA, face P | all set ; turn P BH 1¼ (2,3,4,1)

25--::

  Circle8 and back (2,3,4,1)



*Repeat once as Strathspey and twice as Reel.*  

Deviser''s note:  

*1. Bars 1-4 & 9-12: The strathspey turns are slow open turns.  

2. Bars 21-24: Elbow tum in reel time, two and a quarter turns.*', 4);
INSERT INTO 'dancecrib' VALUES (1877, '2012-01-22 19:29:07.662634+00', '2020-08-02 23:40:49.018094+00', 919, 1, NULL, 'ace', '1–::

  1c+5c cross and cast to next position (2c+4c step to end) ; 2c+1c ½ L-Chain _while_{4} 5c+4c ½ RH M-Chain

9–::

  1c+2c & 4c+5c ½ R&L ; repeat the chains of [5-8]  (1,2x,3,4x,5)

17–::

  1c+2c & 4c+5c ½ R&L ; 1c+5c cross and cast to end (2c+4c step in)  (1,2,3,4,5)

25–::

  1c+2c & 3c+4c ½ Poussette (unusual: start from sideline, finish on the new diagonals), 5c steps in on [28] ; 1c+4c & 3c+5c ½ Poussette (normal) as 2c dances out on [29]. (2,4,1,5,3)



{{explanation}}

The Half Poussettes on [25-28] are like bars 1-4 of a Full Poussette; those on [29-32] are like bars 5-8 of a Full Poussette', 3);
INSERT INTO 'dancecrib' VALUES (14867, '2022-06-16 22:31:08.285538+00', '2022-06-16 22:31:50.129326+00', 20679, 1, 1645, 'ace', '*3c & 4c start on opposite side (1,2,3x,4x)*

1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 1c+4c RHA (2,1x,4,3x)

9--::

  2c+1c L-Chain _while_ 4c+3c M-Chain, 1c & 4c end passing on sides, W in front of M (2,4,1x,3x)

17--::

  *Progressive Double Figures of 8 on Sides:* All dance parallel Fig8 on sides,

  4M & 1W start in, 4W & 1M start out, 1c & 4c omit last pass (2,1x,4,3x)

25--::

  1c+4c set | circle4 &frac12; way to L, clap & swing P (2,4,1x,3x)

', 2);
INSERT INTO 'dancecrib' VALUES (14963, '2022-07-17 07:46:52.204693+00', '2022-07-17 14:54:11.51302+00', 1398, 1, 202, 'ace', '*3c & 4c start on opposite sides*



1--::

  1c & 4c cast inwards _while{2}_ 2c & 3c Petronella turn to midline into two diamond formations | all set ; 1c+2c & 3c+4c RHA. On [8] 1c & 4c dance out to places _while_ 2M & 3M pulling RSh back, 2c & 3c finish BtoB to P and face out (1,2x,3,4x)

9--::

  1c+2c & 3c+4c DblFig8, middles joining hands on sides before casting. On [15-16] 2c & 3c meet P, cross down RH to centre and finish NHJ facing ends with W on P''s Right (1,2x,3,4x)

17--::

  2c+3c NHJ set advancing and pass opposite couple LSh (to 1,3,2x,4x) | 1c+3c & 2c+4c Circle4 L | turn P BH. Top two couples and bottom two couples face out

25--::

  1c+3c & 2c+4c Allemande (3,1,4x,2x)', 4);
INSERT INTO 'dancecrib' VALUES (14966, '2022-07-19 21:56:35.271813+00', '2022-07-19 21:56:35.271813+00', 18056, 2, 160, 'ace', '1-8::  1s cross RH, cast 1 place; 1s cross below 3s, cast up to face corners.
9-16:: 1s and 1st corners dance half reel of 4, 1s pass Rsh; 1s and 2nd corners dance half reel of 4, 1s pass Rsh to end in DT position.
17-24:: Petronella DTs: normal DTs for 1s, corners  set & petronella 1 place CW, twice. 1s finish facing out the ends, 1L up - 1M down.
25-30:: Reels3 across the dance, pass dancer on the right by the right to begin.
31-32:: 1s cross RH to own sides.', 0);
INSERT INTO 'dancecrib' VALUES (14965, '2022-07-17 18:35:17.602115+00', '2022-07-18 08:38:56.882083+00', 19169, 1, 202, 'ace', '1--::
  1c+2c *Rose progression* :  1W+2M change place RH | chase 1 place clw ; turn BH ½, face and cast away _while{8}_ 1M+2W set | turn BH ½, face and cast away | chase 1 place clw (2,1,3)
9--::
  8 bars of 3C R&L (3M,3W,1W on Mside, 1M,2M,2W on Wside)
17--::
  All set | 3c & 2c turn P BH ¾ to centre _while_ 1c turn P RH ½ to centre. 3c face down. 1c & 2c face up (to 3,1,2) ; ½ Parallel Reels3 on sides, 1c RSh to 3c. 1c in 2pl centre face down touching hands briefly (2,1,3)
25--::
  All M RHA _while{4}_ all W LHA ; 1c meet, dance down to 3pl centre (3c dance up to 2pl) | 1c turn P BH (2,3,1)
', 4);
INSERT INTO 'dancecrib' VALUES (13862, '2021-04-02 21:14:57.112648+00', '2021-04-02 21:18:13.726293+00', 20292, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; turn LH into promhold facing 3W
9--::
  Reel3 on 1diag, 1c RSh to 3W. 1c face 2W
17--::
  Reel3 on 2diag, 1c LSh to 2W. 1c in 2pl centre face down
25--::
  1c lead down between 3c, cross and cast up to 2pl ; all turn P RH (2,1,3)

*Deviser''s note* : in a three-couple set, on bars 25-28 the 1s should cross down to 3rd place, 3s stepping up, and set, after which bars 29-32 proceed as written with the dancers in order 2, 3, 1.', 2);
INSERT INTO 'dancecrib' VALUES (13866, '2021-04-03 09:32:55.909137+00', '2021-04-03 10:29:01.976949+00', 11323, 1, 202, 'ace', '1--::

  3c (+2c+1c following) lead down ; 1c (+2c+3c following) lead up back to places centre (1,2,3,4)

9--::

  3C Allemande. On [7-8] 3c & 1c turn P RH ¾ into midline

17--::

  ½ Reel4 on midline. On [20] 1W+3M pass RSh into Reel4 position across ; ½ Reel4 across. On [24] 1W+3M slip in BtoB on midline facing P

25--::

  All set | Petronella turn (to 1,2c on midline facing P,3) ; 2c turn P RH ¾ | 1c+2c change places LH on sides (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11926, '2019-06-29 17:26:48.308761+00', '2022-04-26 19:22:52.19613+00', 19442, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c The Knot (2,1,4,3)

9--::

  1c+4c The Bourrel (2,4,1,3)

17--::

  2c+4c & 1c+3c Circle4 and back. Middle couples face ends (2,4,1,3)

25--::

  Parallel Reels4 on sides (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11933, '2019-07-02 20:03:04.405085+00', '2021-04-02 21:32:30.937842+00', 13574, 1, 1645, 'ace', '*On 2nd chord 1c & 3c cross to opposite side (1x,2,3x,4)*



{{explanation}}

Longwise Set 4x32



1-::

  1c+2c & 3c+4c &frac12; R&L ; 1c+4c &frac12; R&L (2x,4,1x,3)

9-::

  Reels4 on the sides, on [16] 1c+4c change LH on sides ready for

17-::

  4c+1c Ladies Chain

25-::

  Circle8 & back (2x,4,1x,3)

::

  *Repeat three more times. On 4th time W make full RH turn in [21-22] & turn P on [23-24] then end in square set after the circle.*





{{explanation}}

Square Set



1-::

  1c+3c &frac12; R&L ; 2c+4c &frac12; R&L

9-::

  Interlocking Reels4, all dancing as middle person, loop RSh round corner to start, end turning P LH into

17-::

  Double Ladies Chain

25-::

  Circle8 & back

', 5);
INSERT INTO 'dancecrib' VALUES (2350, '2012-01-22 19:29:32.717543+00', '2022-07-20 16:06:21.718544+00', 2575, 1, NULL, 'ace', '1–::

  1c+2c+3c Reels3 on the sides (1c crosses to begin), finishing 2c in top place and 1c in 2pl BtoB facing opposite side (DTr position)

9–::

  All set twice ; 1c turn 1cnrs RH and pass P Rsh to DTr position, 1M facing up, 1W down.

17–::

  All set twice ; 1c turn 2cnrs RH and finish in centre on own sides facing down NHJ

25–::

  1c dance between 3c and cast up to 2pl ; 2c+1c+3c turn P RH', 2);
INSERT INTO 'dancecrib' VALUES (13867, '2021-04-03 11:39:02.09036+00', '2021-04-03 11:39:14.358598+00', 11326, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fg8 L round 4cnrs (2,1,3)

9--::

  ½ diagonal R&L (M down, W up) ; ½ Reels3 on sides, 1c RSh to 2cnrs

17--::

  1c turn P RH 1½ ; ½ Fig8 RHJ down round 2W & 3W to 2plx (Mside: 3M,1W,3W Wside: 2M,1M,2W)

25--::

  ½ diagonal R&L (M down, W up) (to 3,1,2) ; ½ Reels3 on sides, 1c RSh to 3cnrs[pos] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8194, '2014-02-13 18:47:25.648792+00', '2022-08-18 08:55:50.509518+00', 12071, 2, 776, 'ace', '1-8:: 1st couple spin RH.

9-:: 1st couple work down the opposite line (i.e. of the people of the opposite sex) turning side person LH, partner RH, next side person LH, ... [2 bars per turn] When 1st couple reach the bottom, they spin to the end of the phrase, then join the side lines.



---------------------------------



A new couple starts every 16 bars.



Source: <<http://www.scottishdance.net/ceilidh/dances.html#StripTheWillow2>>



[square backets mark additions by person entering the dance into SCD Database]

', 0);
INSERT INTO 'dancecrib' VALUES (15197, '2022-10-28 14:06:36.061716+00', '2022-10-28 14:11:31.51807+00', 21125, 1, 1645, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 1c+3c S&Link & 1W faces out (2,3,1x)

9--::

  1W, followed by 1M, tandem Fig8 on the side round 3M & 2M, 1W crossing to own side facing out on [15-16] (3c down on 13-14)

17--::

  RSh Reels3 on sides

25--::

  2c+1c+3c Set&Rotate (3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (8805, '2015-06-25 14:05:26.100316+00', '2020-01-26 17:46:51.291671+00', 13100, 2, 160, 'ace', '*Note: Beginning arrangement:- line of two facing line of three - 2 1 facing spaces between 3 4 5*

1-8::

   2&1 dance  Figs of 8 round 3 4 5.  To begin 2 cuts between 3+4 and gives Lsh to 3 *while* 1 cuts between 4+5 and gives Lsh to 4.

9-16::

  5 Hands round and back.

17-24::

  2+1 set and link for 2 twice *while* 3 4 5 set and link in line twice. (4 5 3)

25-32::

  Half Rights & Lefts:- 2+1 with 5+3 (right diagonal dancers) ;

  Half Rights & Lefts:- 3+5 with 4+1 (left diagonal dancers).', 2);
INSERT INTO 'dancecrib' VALUES (12534, '2020-02-01 02:00:56.466498+00', '2020-02-01 02:21:34.715485+00', 14182, 1, NULL, 'ace', '1--::

  1c+2c set | turn P LH ½ and face down ; 2c, 1c following, cross down through 3c and cast up (2,1,3)

9--::

  2c+1W & 1M+3c ½ Reels3 across, 1c Lsh to 1cnr ; ½ Reels3 on the sides, 1c Rsh to 2cnr, to (3x,1x,2x), 1c facing down

17--::

  1c  Fig8 down through 3pl ;  Fig8 op through 1pl (3x,1x,2x)

25--::

  All ½ Gr-Chain (3c cross to start) ; all keep the RHJ and turn once more *(alternative: Birl)*

', 3);
INSERT INTO 'dancecrib' VALUES (3937, '2013-08-21 08:30:39.797104+00', '2023-02-04 01:18:22.553377+00', 9109, 3, NULL, 'ace', '1-8::
    1s+2s set & RH across 1/2 way, 1s+3s 1/2 R&L
9-16::
    3s+1s set & LH across 1/2 way, 2s+1s 1/2 R&L
17-24::
    1s lead down the middle, back to 2nd place & 2s+1s+3s set
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14928, '2022-06-28 17:25:29.645056+00', '2022-09-19 09:41:30.305865+00', 12863, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; dance down between 3c | cast up to 2pl and face 1cnrs

9--::

  Turn CPCP. On [15-16] 1c turn P LH to face 1cnrs

17--::

  1c dance RSh round 1cnrs ; dance LSh round 3cnrs to 2pl (2,1,3)

25--::

  Circle6 and back (2,1,3)



*Deviser''s note* : On bar 24, 1st couple should arrive just in time to flow into a circle.', 2);
INSERT INTO 'dancecrib' VALUES (14868, '2022-06-16 22:59:45.670419+00', '2022-06-16 23:02:37.804981+00', 20100, 1, 1645, 'ace', '1-::

  1W & 4M cast inwards | turn RH{4} | cast back to place

9-::

  1M & 4W cast inwards | turn LH, ending between 2c/3c facing 2M/3W ;

  1M+2c & 4W+3c &frac12; RSh Reels3 across, 1M & 4W end in original places (1,2x,3x,4)

17-::

  1c+2c & 3c+4c pass RSh on sides | 1c+4c &frac12; turn LH on sides (2x,4,1,3x) ;

  &frac12; Reels4 on sides, 4c & 1c do not pass LSh but end curving into centre BtoB facing cnrs

25-::

  All set, 3c & 2c (cnrs) advancing to take BH with 4c/1c | all slip &frac12; way clw ;

  all set, 1c & 4c pulling RSh back to face in | 1c+4c &frac12; circle4 to L (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13115, '2020-08-17 19:51:19.797496+00', '2023-01-09 23:09:07.328213+00', 17261, 2, 2929, 'ace', '1-4:: 1+2C set and cast off

5-8:: 1/2 Reel4 with first corners, finish 1W down, 1M up

9-10:: All set in lines

11-12:: 1C turn LH to second corners

13-16:: 1/2 Reel4 with second corners, finish 2nd place own side

17-20:: Circle 1/2

21-24:: 1C turn 1-1/2 times WHILE corners dance B2B

25-28:: Clap, 1C+3C circle left

29-32:: Clap, 1C+2C circle right', 2);
INSERT INTO 'dancecrib' VALUES (8856, '2015-08-13 20:34:14.820329+00', '2023-02-04 01:23:09.911586+00', 14289, 3, NULL, 'ace', '1-8::
    All set to partners, turn RH, set to corners & turn corners LH
9-16::
    Men dance RSh round partner into RH across in centre finishing in
    places
17-24::
    Ladies dance LSh round partner into LH across in centre finishing in
    places
25-32::
    Men dance LSH round corners into LH across in centre finishing in
    places
33-40::
    Ladies dance RSH round corners into RH across in centre finishing in
    places facing out
41-56::
    All dance Schiehallion Reels (16 bars)
57-64::
    1s+3s dance R&L
65-72::
    2s+4s dance R&L
73-88::
    All dance Grand Chain then turn partner RH (or birl)', 0);
INSERT INTO 'dancecrib' VALUES (13575, '2021-01-23 03:16:18.956158+00', '2021-04-02 21:53:32.889597+00', 12354, 1, 202, 'ace', '1--::

  1c & 3c set | cast off (2c & 4c up) ; 1c & 3c turn P LH into promhold. 1c face 2W and 3c face 4W

9--::

  1c+2c & 3c+4c ½ Parallel Reels3 across, 1c RSh to 2W, 3c RSh to 4W ; 1c & 3c NHJ dance up | 1c cast off round 2c _while_ 3c cast off round 4c (2x,1,4x,3)

17--::

  1c & 3c ½ Fig8 up (to 2x,1x,4x,3x) ; all set twice. On [23-24] 1c pivot to face down _while_ 4c & 3c pivot to face up (2x,1x,4x,3x)

25--::

  1c+4c+3c ½ Parallel Reels3 on sides, 1c RSh to 4c (to 2x,3x,4x,1x) ; all turn P RH 1½ (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12529, '2020-01-26 16:30:44.792544+00', '2020-12-29 11:41:39.073486+00', 11821, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 2c+1M & 1W+3c RHA (2,1x,3)

9--::

  Diagonal R&L into DblTr position, 1c in 2plx centre facing opposite side

17--::

  3c+1c+2c set as in DTr | all set advancing and swivel R to form »inverted« DTr (3c & 2c are BtoB in centre) ; all set | 1c cross RH _while{2}_ 3c & 2c cast R to own side. All face clw (3,1,2)

25--::

  All chase clw ½ (to 2x,1x,3x) ; all set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11237, '2018-10-02 00:32:20.322334+00', '2022-04-26 09:38:46.25369+00', 11450, 1, 202, 'ace', '1--::

  1c+3c Bourrel, 1W+2W set advancing to start. On [7-8] 1c & 3c turn P LH (3,2,1,4)

9--::

  1c+3c LSh Reel4 across, 1W+3W pass RSh _as_ 1M+3M dance into P place to start (3,2,1,4)

17--::

  2c+4c repeat [1-8] (3,4,1,2)

25--::

  All set | Circle8 L ¾ (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (13864, '2021-04-03 01:29:29.277491+00', '2021-05-07 23:16:26.418693+00', 20294, 1, 202, 'ace', '1--::
  1c (+2c+3c who dance up to follow) dance down and up (1,2,3)
9--::
  Mirror Reels3 on sides {6}, 1c in and down, 2c out and up | all set (1,2,3)
17--::
  1c+2c ½ R&L ; 1c+3c ½ R&L (2x,3x,1)
25--::
  1c ½ Fig8 up round 3c ; all turn P RH ½, face P | cast R to sides (2,3,1)
33--::
  Circle6 and back (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (8079, '2013-10-09 12:45:30.814873+00', '2020-08-03 06:25:11.437355+00', 975, 1, NULL, 'ace', '1–::

  All set to P and »middles« face »ends« | all set up/down ; both »ends« (start inwards) turn »middles« EH (1,2,3,4)

9–::

  Both »ends« a Fig 8 round their »middle«, _while_ the »middles« cross RH on [11-12], and change places on the sides [15-16] (1,3x,2x,4)

17–::

  »middles«with »centres« change places LH on sides | 1c+4c ½ LHA (3x,4x,1x,2x)  ; repeat [17-18] | 3c+2c ½ LHA (4x,2,3,1x)

25–::

  repeat [17-18] | 4c+1c ½ LHA (2,1,4,3) ; 1c+4c+3c ½ Reels3 on side, 4W Lsh to 1W, 4M Rsh to 3M (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (9585, '2017-02-09 01:33:01.383563+00', '2022-04-26 19:27:34.043645+00', 17349, 1, NULL, 'ace', '*Starting positions (1,2,3x,4x)*   



1--::

  1c+2c & 3c+4c “The Bourrel” (2,1,4x,3x)

9--::

  2c+3c cross RH | set ; cross RH | set _while{8_} 1c+4c R&L, but with final turn LH ¾ into line across, W in the middle, for 

17--::

  1c+4c The Targe (2,4,1x,3x)

25--::

  All turn P RH ; turn P LH

', 3);
INSERT INTO 'dancecrib' VALUES (10208, '2017-10-27 21:36:13.7299+00', '2022-09-19 09:43:54.462013+00', 12852, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; turn LH to face 1cnrs

9--::

  1c Set to and turn corners (2,1x,3)

17--::

  2c+1c+3c set | 1c turn BH 1½ | All set (2,1,3)

25--::

  1c dance down between 3c, cast up to 2pl ; dance up between 2c, cast to 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (1591, '2012-01-20 13:06:12.808237+00', '2021-04-04 10:59:38.522839+00', 13644, 2, 1, 'ace', '1-8::

  1C+2C set & rotate (1C fin facing 2cnr)

9-16::

  1C set to 2cnr | 1C cast RSh round each other to 4cnr position _while_

  2cnrs dance into centre and swivel R to face own pl ; repeat, 2cnrs fin in

  exchanged places and 1C facing 3cnr

17-24::

  Repeat pattern w/3cnrs, 1C fin in ctr (1W facing up, 1M down) and 1cnrs in

  exchanged places

25-28::

  1C dance RSh round 4cnr''s pl to 2pl own sides _while_ cnrs dance ½RL

  (starting up/down)

29-32::

  1C turn RH', 5);
INSERT INTO 'dancecrib' VALUES (13863, '2021-04-02 23:02:11.451442+00', '2021-04-03 22:26:22.430022+00', 20293, 1, 202, 'ace', '1--::

  1c dance down between 4c ; cast up to 1pl (1,2,3,4)

9--::

  Mirror  Reels4  on  sides,  starting RSh on Mside, LSh on Wside. On 

[15-16]  3c+2c  change  places  on  sides,  RH  on  Mside, LH on Wside 

(1,2,3,4)  

17--::

  1c+2c ½ R&L ; 1c+3c ½ R&L (2x,3x,1,4)

25--::

  1c+4c  ½ R&L (to 2x,3x,4x,1x) ; all turn P RH ½, face P | cast R to 

  sides (2,3,4,1)', 5);
INSERT INTO 'dancecrib' VALUES (14774, '2022-04-26 23:15:16.625476+00', '2022-04-26 23:17:13.072673+00', 7171, 1, 1645, 'ace', '1--::

  1c+2c petronella to centre line | set R & turn P &frac14; LH ;

  1W+2M turn &frac34; RH _while{2}_ 1M & 2W dance cclw to own sides |

  turn P &frac34; LH to line across, M facing up, W down

9--::

  M/W dance up/down | turn in & dance NHJ down/up towards P ;

  all set R{1} & 2M+1W turn &frac34; LH into allemande hold facing W side

  _while{3}_ 1M & 2W dance cclw to exchange places

17--::

  2M+1W diag Reel3 with 1M & 2W starting RSh to 1M, 2M & 1W end facing on diagonal each in front of P

25--::

  2M & 1W petronella to original places (beside P) _while{2}_ 2W & 1M set |

  circle4 to L{3} & on [30] dance in to touch LH | pull RSh back & curve out 1 place clw (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (14967, '2022-07-21 09:25:58.145767+00', '2022-07-21 09:31:29.476265+00', 20958, 1, 202, 'ace', '1--::

  1c cast off, dance down behind own lines ; cast outwards and dance up to 1pl (1,2,3,4)

9--::

  1c Fig8 down round 2c

17--::

  1c+2c RHA ; LHA

25--::

  1c lead down to 4pl centre (2c+3c+4c up) ; 1c turn P RH to 4pl (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15198, '2022-10-28 14:45:38.54777+00', '2022-10-28 14:48:06.143384+00', 21134, 1, 1645, 'ace', '1--::

  1c cross RH | cast off (2c up) ; &frac12; Fig8 up round 2c (2,1,3)

9--::

  Mirror Reels3 on sides, 1c start in & down

17--::

  1c+3c double Fig8, 1c start crossing down as 3c cast up

25--::

  2c+1c Circle4 to L & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (15372, '2023-01-06 15:30:48.87868+00', '2023-01-10 11:25:35.135223+00', 15737, 2, 81, 'ace', '1-8::

  1s and 3s set advancing to B-in-L and set.  RH turn and cast 1 place (2s and 4s step up)

9-16::

  1s and 3s set advancing to B-in-L and set.  RH turn 1.25 to finish facing 1st corners.

17-24::

  1s and 3s dance Corner Pass and Turn with 1st corners, then 2nd corners.  Finish 2nd/4th place opp. sides

25-32::

  1M with 2s, 1L and 3M with 4s, 3L with 5s, RH across. 1s and 3s cross RH and cast, 4s and 5s step up', 0);
INSERT INTO 'dancecrib' VALUES (15199, '2022-10-28 18:42:09.235691+00', '2022-10-28 18:57:41.318898+00', 21119, 1, 1645, 'ace', '1--::

  1c & 3c petronella to midline | all set facing P ; 1c+2c & 3c+4c RHA

9--24::

  *Chaperoned Celtic Reel: (1c & 3c dance complete Celtic Reel joining NH with 2c & 4c who chase around outside them):*  

  9-10: 1c & 3c pass P RSh & face clw _while{2}_ 2c & 4c chase &frac14; clw solo  

  11-12: 1W+3M dance &frac34; LSh round each other _while{2}_ 1M & 3W chase &frac14; clw NHJ with 2M & 4W _while{2}_ 4M & 2W chase &frac14; clw solo  

  13-24: repeat pattern of [9-12] 3 times. On [23-24] 3W & 1M do not pass LSh but curve R following P to sides (Mside: 2W,1W,1M,2M; Wside 4W,3W,3M,4M)

25--26::

  All chase 2pl clw (1,2,4,3)

27--32::

  1c cross RH ; cast to 4pl (2c up) | cross RH _while{6}_ 3c turn RH{4} | lead up to 2pl (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15254, '2022-11-21 13:43:01.001288+00', '2022-11-21 13:44:01.196014+00', 8608, 1, 202, 'ace', '1--::

  All W A&R ; All M A&R. All face P

9--::

  All turn P RH ; All dance BtoB

17--::

  G-Chain (2 bars per hand)

25--::

  With 5th person, Promenade cclw', 2);
INSERT INTO 'dancecrib' VALUES (15253, '2022-11-20 15:00:39.106654+00', '2022-12-01 14:55:24.168141+00', 5172, 1, 1645, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 2c+1c RHA (2,1x,3)

9--::

  1c cross LH | cast off (3c up) ; 3c+1c LHA (2,3,1)

17--::

  Mirror Reels3 on sides, 3c start in & down, 3c+1c end passing again, 1c face in & up (2,1,3)

25--::

  1c Fig8 on sides, start up between 2c & join hands where possible (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (8018, '2013-08-26 13:49:58.316348+00', '2020-01-30 10:39:14.761755+00', 13583, 1, NULL, 'ace', '1--::

  1c dance to bottom _while{4}_ 4c cast to top ; 4c dance down one _while{2}_ 1c cast up one (2c+3c step to ends) | 1c+4c set, turning so both M face down and both W up (i.e. facing "2cnr") (2,4,1,3)

9--::

  Rsh Reels3 on each of the sides, 1c+4c dancing as one and changing lead  (2,4,1,3)

17--::

  4c+1c turn P RH ½ | ½ RHA ; 2c+1c & 4c+3c repeat (1,2,3,4)

25--::

  1c (1W leading)+2M RHA, 2M finishes in 1M''s place (2W up) ; 1c+3W LHA (3M up)

33--::

  1c+4M RHA (4W up) ; 1c set | turn RH ¾ to (2,3,4,1), and face out to continue.', 3);
INSERT INTO 'dancecrib' VALUES (12530, '2020-01-29 22:57:05.149102+00', '2020-01-29 23:31:03.517131+00', 19838, 1, NULL, 'ace', '*Start in big circle RR facing in, M on L of P*  

*Best for 5 or more cpls; with 4 the progression fails*   



1--::

  All W dance diag.L {1} and pivot R to face P {1} |  set to P ; turn P BH to own places

9--::

  All M repeat [1-8] with the W to their L , all end in own places

17--::

  Circle L ; and R, finish facing P

25--::

  (ZigZag setting): Set advancing, passing P, and face next P | repeat 3 times and form circle RR with new P





', 3);
INSERT INTO 'dancecrib' VALUES (12531, '2020-01-31 03:41:13.40681+00', '2020-01-31 03:48:20.613325+00', 6363, 1, 202, 'ace', '1--::

  1c+2c cross RH and stay in centre RHJ | ½ RHA (to 2,1,3) ; 1c+3c repeat (2,3,1)

9--::

  3c+1c set | ½ R&L | cross RH (2,1,3)

17--::

  2c+1c set | ½ R&L | turn P RH ½ into Allemande hold (1,2,3)

25--::

  2C Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13868, '2021-04-04 13:14:32.350502+00', '2021-04-04 13:17:43.473345+00', 339, 1, 202, 'ace', '1--::

  1c+2c RHA ; LHA (1,2,3)

9--::

  1c cross RH | cast off (2c up) ; turn P RH 1½ (2,1,3)

17--::

  All A&R ; dance BtoB (2,1,3)

25--::

  Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12986, '2020-07-25 09:29:17.577+00', '2020-08-14 21:03:46.254659+00', 625, 2, 2784, 'ace', '1-::

  1M+2W cross RH (2M up) {2}, 1c+2c set and A&R

9-::

  1c+2c Petronella in tandem

17-::

  1W+2M cross RH (2W down) {2}, 1c+2c set and turn BH to finish 1c facing down, 2c facing up NHJ

25-::

  1c+2c Rondel

33-::

  1c+3c Rondel

41-::

  1c+4c Rondel



*Original instructions for bars 9-16 say Petronella in promhold (advance without turning, so turn on setting)*

', 0);
INSERT INTO 'dancecrib' VALUES (8959, '2015-11-02 05:53:43.538956+00', '2021-07-02 12:08:09.346294+00', 519, 2, 2452, 'ace', '*Third and fourth couple start at the same time as the first and second couples.*



{{title}}Strathspey



1-2:: First lady casts down and second man casts up round the next person

3-4:: The give right hands and turn until in line with original places

5-8:: First man and second lady join in to dance 4 hands across. Finish in original places

9-12:: First man casts down and second lady casts up to turn with left hands

13-16:: First lady and second man join in to dance four hands across. Second lady and first man return to place and turn to their right back into the centre of the set, while first lady and second man retain left hand and pass to start:-

17-24:: reel of four across the dance, giving right shoulder to partner

25-32:: Half chain progression (*see note*) . First man and second lady start by giving left hands to change places



{{title}}Reel



1-32:: Middle couples now dance the above 32 bars in reel time



All four couples start again with Strathspey





*Note: HALF CHAIN PROGRESSION

This is a new progression enabling two couples to change places. It is based on a two bar sequence called a “half chain”.*



*Tow couples stand in normal places. First lady and second man give right hands and do a half turn, finishing in their partner’s place (note – not in each other’s), while second lady casts up into first lady’s place, and first man casts down into second man’s place.*



*If this is danced four times i.e. for eight bars, each dancer turning or casting as they reach the appropriate place, everyone is back home. To progress, first man and second lady change places on bars 1-2, giving left hands, while first lady and second man stand still. Then on bars 3-8 dance three half chains.*', 4);
INSERT INTO 'dancecrib' VALUES (13869, '2021-04-04 13:24:57.399063+00', '2021-04-05 11:14:11.699028+00', 2049, 1, 202, 'ace', '1--::

  1c (+2c who dance up to follow) lead down ; 2c (+1c following) lead up (2,1,3)

9--::

  1c cast off, dance down behind own lines ; cast up back to places (2,1,3)

17--::

  1c Fig8 R across (2,1,3)

25--::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (13007, '2020-08-03 06:34:31.296832+00', '2020-08-03 06:36:00.372064+00', 1013, 1, 202, 'ace', '1--::

  Reels3 across, 2c LSh to 1cnrs (1,2,3)

9--::

  Reels3 on sides, 2c LSh to 3cnrs (1,2,3)

17--::

  1c+2c ½ R&L ; 1c+3c ½ R&L (2x,3x,1)

25--::

  1c turn P RH _while{2}_ 2c & 3c cross RH | Circle6 L (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (9156, '2016-06-05 18:01:02.827646+00', '2020-01-31 18:04:33.598456+00', 1114, 2, 1, 'ace', '1–6::

  1c&3c dance capstan round standing 2c (1W&3W dance round 2W, keeping

  her on their L, to finish in each other''s places, _while_ 1M&3M dance

  similarly round 2M keeping him on their R).

7–8::

  2c+1c change places (W LH, M RH) [2c fin facing out]

9–::

  Reels3 on sides (3c dance out and down, 1c cross down to 3x, 2c dance up;

  at end 2c+3c dance loops, 1c dance to face 2nd corner pos)

17–::

  1c (giving LH to ptr) & 2nd corner pos balance in line |

  1c ½ turn LH _while_ corners dance 1pl cw ;

  1c (giving LH to ptr) & 2nd corner pers balance in line |

  1c ½ turn LH _while_ corners dance 1pl cw

25–28::

  1M&2c, 1W&3c RH across (to 2,1x,3)

29–32::

  All 1½ turn RH (to 2,1,3)', 0);
INSERT INTO 'dancecrib' VALUES (13871, '2021-04-04 21:28:15.171249+00', '2021-04-04 21:34:36.553022+00', 2306, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; turn P LH 1½ and face 1cnrs

9--::

  Reel4 on 1diag into BiL position with 1cnrs

17--::

  BiL | 1c turn P LH 1¾ into BiL with 2cnrs | BiL

25--::

  Reel4 on 2diag (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13008, '2020-08-03 06:53:54.408192+00', '2020-08-03 06:54:18.506326+00', 1027, 1, 202, 'ace', '1--::

  Circle4 and back

9--::

  Couples facing cclw lead between opposite couples, cross and cast to P''s place ; couples facing clw repeat. All face P

17--::

  ½ R&L ; all turn P RH and face new couple', 2);
INSERT INTO 'dancecrib' VALUES (12533, '2020-02-01 01:45:10.388446+00', '2020-02-01 01:45:10.388446+00', 10482, 1, NULL, 'ace', '

1--::

  1c cross RH |  cast  (2c up) ; 2c+1c LHA, the M face out (2,1x,3)

9--::

  2c+1c La--Chain (2,1x,3)

17--::

  1c set | cast (3c up) 3c+1c RHA, the W face out (2,3,1x)

25--::

  3c+1c M-Chain (2,3,1x)

33--::

  1c cross RH | cast up (3c down) ; 1c dance up between 2c and cast to (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (3632, '2012-07-21 11:46:15.425289+00', '2022-06-17 19:44:44.097684+00', 11294, 1, NULL, 'ace', '1–::

  1c set | cross RH ; 1c+2c S&Link (2,1x)

9–::

  ½ Circle4 L | M turn W behind them to finish in a line on 1diagonal, the W BtoB ; ½ Diag. Reel4, finish the W in own places, the M in exchanged places

17–::

  R&L, finish in promhold facing in

25–::

  Tournée, dancing in on [25]', 3);
INSERT INTO 'dancecrib' VALUES (12532, '2020-01-31 10:13:33.892122+00', '2020-01-31 18:04:33.600131+00', 1114, 1, NULL, 'ace', '1--::

  1c+3c “The Capstan”{6} round 2c (1c dance down _as_ 3c cast up | repeat figure ; repeat figure) | 1c turn 2c EH ½ on the side and 3c & 2c face out (3,1,2)

9--::

  Crossover Reels3 on the sides, 1c cross down to start, finish with loops and with 1c LHJ and RHJ with 2cnr 

17--::

  1c+2cnrs BiL | 1c turn P LH ½ _as_ all cnrs chase 1place clw ; BiL again on 2diag. | 1c turn P LH ½ _as_ all cnrs chase 1place clw (2x, 1 on midline,3x)

25--::

  2c+1M & 1W+3c RHA ; All turn P RH 1½ (2,1,3)





  

', 4);
INSERT INTO 'dancecrib' VALUES (14103, '2021-07-02 12:39:11.495443+00', '2021-07-02 12:39:24.755513+00', 5712, 1, 1645, 'ace', '1--::

  1c+2c Chain Progression (2,1)

9--::

  1c in promhold Reel3 across with 2c, 1c start RSh to 2W

17--::

  1c turn 2c (M LH, W RH) ; 1c &frac12; Fig8 up through 2c

25--::

  2c &frac12; Fig8 down through 1c ; 2c+1c turn P 1&frac12; RH (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (12347, '2019-11-12 23:20:30.551534+00', '2019-11-12 23:39:40.886847+00', 17746, 1, NULL, 'ace', '1--::

  1c set | cast off (2c up) ; 1c ½ Fig8 R (2,1x,3)

9--::

  1cnrs turn RH ½ and cast to exchanged places ; 2cnrs repeat and face out (3x,1x,2x)

17--::

  1M+3c & 1W+2c Lsh Reels3 across (3x,1x,2x)

25--::

  1c set | cast off (2c up) ; 3c+2c ½ R&L as 1c cross RH and stands (2,3,1)  

', 3);
INSERT INTO 'dancecrib' VALUES (13117, '2020-08-18 22:05:07.091055+00', '2022-04-26 09:44:51.389061+00', 10768, 1, 202, 'ace', '1--::

  1M & 3M dance RSh round 2W/4W and face her from midline  

_while{4}_ 1W & 3W set to 2M/4M pivoting R to face out | cast above 2W/4W to midline facing their original places  

_while{4}_ 2M & 4M set to 1W/3W | dance to 1Wpl/3Wpl (to 2M,2W,4M,4W on Wside, 1W,1M,3W,3M on midline) ; all turn opposite person RH | 2W & 4W set _while{2}_ others dance to original places (1,2,3,4)

9--::

  1c+2c & 3c+4c RHA ; »Modified LSh Snake Pass« [: unwind the RHA, 2W & 3M leading pass other snake LSh diagonally to exchanged places and chase cclw, 2W to 3Wpl, 3M to 2Mpl (4,3,2,1)

17--::

  All set | Ends cross RH _while{2}_ Middles RHA ½ (to 4x,2x,3x,1x) ;  all set | cross RH (4,2,3,1)

25--::

  4c+2c & 3c+1c »Modified 2C Bourrel« [: same as 2C Bourrel except Petronella turn on last 2 bars] (2,4,1,3) ', 5);
INSERT INTO 'dancecrib' VALUES (10463, '2018-02-27 03:40:02.982055+00', '2022-04-26 19:29:21.117552+00', 5679, 1, 202, 'ace', '1--::

  1W followed by 1M & 4M followed by 4W chase clw ½ to exchanged ends, 1W & 4M face out at end ; 4c+2c & 3c+1c RHA (4x,2,3,1x)

9--::

  Parallel ½ Reels4, 1M & 4W face out at end ; 1c & 4c repeat [1-4] with 1M & 4W leading (4,3,2,1)

17--::

  All set | 4c+3c & 2c+1c ½ RHA (to 3x,4x,1x,2x) ;  4c & 1c ½ Fig8 round nearest ends _while{4}_ 3c & 2c set | cross RH (3,4,1,2)

25--::

  4c+1c Bourrel (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (12696, '2020-04-05 00:03:43.20064+00', '2020-04-05 00:10:26.235807+00', 11422, 1, 202, 'ace', '1--::

  1c cross RH | set ; cast off (2c up) | set to 3c (2,1x,3,4)

9--::

  1c+3c ½ M-Chain across (to 2M,1W,1M,4M on Mside, 2W,3M,3W,4W on Wside) ; 1c in promhold + 2c ½ Reel3 across, 1c RSh to 2W _while{4}_ 3c in promhold + 4c ½ Reel3 across, 3c RSh to 4M (2W,3W,3M,4W on Mside, 2M,1M,1W,4M on Wside)

17--::

  Middle couples ½ Fig8 round ends _while{4}_ ends ½ R&L up/down (to 4M,1M,1W,2M on Mside, 4W,3W,3M,2W on Wside) ; Middle couples ½ La-Chain (4,1,3x,2)

25--::

  1M+3W in promhold + 4c ½ Reel3 across _while{4}_ 3M+1W in promhold + 2c ½ Reel3 across (to 4x,3,1x,2x) ; 3c & 1c ½ Fig8 round ends _while{4}_ ends ½ R&L up/down (2,3x,1,4)

33--::

  3c+1c ½ RHA (to 2,1x,3,4) | 1c+3c+4c set ; 1c cast off (3c+4c up) | 1c cross to 4pl _while{2}_ 2c+3c+4c set (2,3,4,1)

41--::

  Circle8 and back (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (13009, '2020-08-03 07:13:36.301669+00', '2020-08-03 07:18:16.160555+00', 1086, 1, 202, 'ace', '1--::

  1c cast to bottom and back _while_ 4c cast up to top and back, claping RH (or slaping) when passing (1,2,3,4)

9--::

  1c cross and clap RH, dance down to bottom ; repeat same pattern to 1pl (1,2,3,4)

17--::

  All chase cclw (1,2,3,4)

25--::

  1W (1M following) dance down the middle (2c+3c+4c up on [27-28]). On [28] 1M taps 1W''s shoulder ; 1c cross hands and spin (or tulloch turn) to 4pl (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (1744, '2012-01-22 19:28:59.579484+00', '2021-07-02 14:03:10.906934+00', 471, 1, NULL, 'ace', '1–::

  All cross RH and face R | chase clw into lines across, W above, M below ; All change places with P LH and face L | chase cclw to (1,2,3)

9–::

  In »Galant Hold« 1c, +2c following, lead down, 1c crossing below 3c, 2c not crossing ; 1c cast up to 2plx and turn RH ¾ _while{4}_ 2c casts up to 1pl

17–::

  1M, 1W following, cast Rsh round 2W and cross to 2pl ; All C turn RH (2,1,3)

25–::

  Circle6 and back.



{{explanation}}

Galant Hold: M (on the R) M puts L arm behind W who joins LH with him on her waist and RH in promhold; alternatively he may hold her waist LH, and she her skirt.', 3);
INSERT INTO 'dancecrib' VALUES (12980, '2020-07-24 09:59:45.822315+00', '2020-08-03 08:32:22.301192+00', 13122, 1, 202, 'ace', '1--::

  1c+2c Circle4 L ; turn P RH ½, face P and cast away to 1plx (1x,2x,3)

9--::

  2C Set&Rotate up/down (1,2,3)

17--::

  1c Fig8 {6} round 3c (2c up on [17-18]) | 1c+3c turn EH on sides (2,1,3)

25--::

  1c+3c The Espagnole (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (2063, '2012-01-22 19:29:17.804231+00', '2020-08-04 00:39:47.158348+00', 1578, 1, NULL, 'ace', '1–::

  1c+2c+3c cross over RH, set ; repeat

9–::

  1c 1½ RH turn ; cast off one place, turn LH to finish facing 1cnrs

17–::

  1c change places RH with 1cnrs, set to cnrs ; change place RH, turn LH to face 2cnrs

25–::

  1c change places RH with 2cnrs, set to cnrs ; change places RH, cross over LH.', 2);
INSERT INTO 'dancecrib' VALUES (13870, '2021-04-04 13:50:03.568998+00', '2021-04-04 13:57:17.571558+00', 7162, 1, 202, 'ace', '1--::

  1c turn P RH ½ moving to 2pl centre (2c up) | turn P LH ¾ ; ½ Reels3 across, 1c RSh to 1cnrs into facing lines3 across

9--::

  All A&R {1+1} | all advance {1}, 1c turn P RH to 2plx {1} _while_ 2c & 3c retire {1} (to 2x,1x,3x) ; all A&R {1+1} | 1c cross RH (2x,1,3x)

17--::

  1c dance LSh round 4cnrs[pos] into lines3 across _while{2}_ 2c & 3c A&R {1+1} | 1c turn RH ; ½ Reels3 across, 1c LSh. 1c face 1cnrs

25--::

  SetH&G. On [31-32] 1c Petronella turn to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2968, '2012-01-22 19:30:04.972081+00', '2022-09-19 09:49:54.025532+00', 12691, 1, NULL, 'ace', '1–::

  1c long cast for 2 places (2c+3c up) ; 2c repeat (3c+1c up) (3,1,2,4)

9–::

  1c+2c dance up between 3c, cast off, pass between 4c and cast up to (3,1,2,4), 1c facing out and 2c in and up

17–::

  1W+2W & 1M+2M turn EH 1½ ; 3M+2M & 3W+2W &1M+4M & 1W+4W turn EH 1½ (2,3,4,1)

25–::

  Mirror Reels4 on the sides, the W Lsh and the M Rsh.', 3);
INSERT INTO 'dancecrib' VALUES (14775, '2022-04-26 23:18:16.766601+00', '2022-04-26 23:18:39.974938+00', 9470, 1, 1645, 'ace', '1--::

  1c+2c+3c Inverted Inveran Reels, 3c crossing up on [1] & down on [5]

9--::

  3c cross up between 2c into wide EH turns with 2c & end facing up between 2c ; repeat with 1c & face up

17--::

  3c dance up & cast off to original pl ; 3c lead up followed by 2c & 1c who start down the sides

25--::

  3c+2c+1c Promenade, 3c end casting off to 3pl as 2c & 1c dance up (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12697, '2020-04-05 21:17:59.521886+00', '2020-04-05 21:29:31.41346+00', 8141, 1, 202, 'ace', '1--::

  1c cross RH | cast off  ; cross LH | cast off. Nobody step up

9--::

  1c cast up to 1pl _while{4}_ 2c+3c A&R ; 1c cross RH | cast off (2c up) to 2pl centre BtoB facing opposite sides (2,*1*,3)

17--::

  DTr (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (7922, '2013-08-21 08:31:51.320129+00', '2023-02-04 01:23:12.029781+00', 7104, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 1s+2s dance RH across 1/2 way as 3s cross RH, 2s+1s+3s
    set & 1/2 turn partner RH ready for Allemande
9-16::
    2s+1s+3s dance Allemande 1s turning LH to end facing 1st corner
    pstns
17-24::
    1L+3s (in 1st place) also 1M+2s (in 3rd place) dance reels of 3
    across (LSh to 1st corner to start)
25-32::
    1s dance RH across (L with top cpl & M with cpl in 3rd pl), 1L
    followed by 3s & 1M followed by 2s cross passing LSh to change ends
    & loop round anticlockwise to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13010, '2020-08-03 09:33:53.642688+00', '2020-08-03 09:53:11.079522+00', 20061, 1, 202, 'ace', '1--::
  1c set advancing slightly |»RSh Turn« round P ; cast off (2c up) |»LSh Turn« round P to face 1cnrs (2,1,3)
9--::
  1c+1cnrs set | »RSh Turn« round each other and face P ; ½ Reel4 on 1diag, 1c passing P LSh. On [16] 1c face P in centre, pull RSh back to face 2cnrs
17--::
  1c+2cnrs set | »LSh Turn« round each other and face P ; ½ Reel4 on 2diag, 1c passing P RSh into facing lines3 across. 1W(1M) between 3c(2c) faces down(up)
25--::
  All set (no hands) | 1c »RSh Turn« round P to 2plx ; all set (no hands) | cross RSh (3,1,2)

*Note:*  
»RSh/LSh Turn« (Right/Left Shoulder Turn) is also known as Gypsy Turn, a term now considered offensive by some. ', 2);
INSERT INTO 'dancecrib' VALUES (12698, '2020-04-05 22:21:58.889995+00', '2020-04-05 22:27:43.480794+00', 8814, 1, 202, 'ace', '1--::

  1c & 3c in promhold (W on left) Parallel Reels3 across, RSh to 2M/4M (1,2,3,4)

9--::

  Mirror Reels4 on sides (RSh on Mside, LSh on Wside) (1,2,3,4)

17--::

  4C Promenade (1,2,3,4)

25--::

  1c cast off to 4pl (2c+3c+4c up) ; all turn P RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (14104, '2021-07-02 15:59:52.367237+00', '2021-07-02 16:00:50.78778+00', 20362, 1, 1645, 'ace', '1--::

  1c set | cast below 4c (2c+3c up in [5-6]) | lead up 1pl to face 1cnrs (3M & 4W)

9--::

  1c+1cnrs Pass & Turn ; repeat with 2cnrs (4M & 3W) & pass RSh to own sides (2,3,1,4)

17--::

  2c+3c RHA ; LHA _while{8}_ 1c+4c set | &frac12; RHA ; set | cross RH

25--::

  Circle8 & back (2,3,4,1)

::

  *NB crib derived from the video*

', 2);
INSERT INTO 'dancecrib' VALUES (14096, '2021-06-29 15:11:32.591838+00', '2021-07-03 11:36:33.993132+00', 20248, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

  1c+2c & 3c+4c ½ DblFig8, 1c & 4c crossing (to 1x,2x,3,4) ; all set | all turn P RH ½ into promhold, 1c & 2c facing up, 3c & 4c facing down

9--::

  4C Interlocking Allemande (2,4x,1,3x)

17--::

  All set | 4M+1W NHJ cross under 4W+1M making arch, all to opposite sides (to 2,4,1x,3x) ; 4c & 1c turn nearest cnrs EH into facing lines4 across, 4c between 2c facing down, 1c between 3c facing up | all set

25--::

  4c+1c RHA. 4c & 1c face out ; 4c cast off to 2pl _while{2}_ 1c cast up to 3plx | all set (2,4,1x,3x)', 5);
INSERT INTO 'dancecrib' VALUES (14099, '2021-07-01 07:04:07.26147+00', '2021-07-02 20:51:42.991685+00', 9213, 1, 202, 'ace', '*3c & 4c start on opposite sides (1,2,3x,4x)*

1--::

  1c+2c & 3c+4c R&L. On [8] 1M & 4M face out (no polite turn) (1,2,3x,4x)

9--::  

  1c chase cclw to 3plx _while{4}_ 4c chase cclw to 2pl (2W & 3W step out on [9-10], 2M & 3M step out on [11-12]) (to 2,4,1x,3x) ; ½ Reels4 on sides. On [15-16] 4c & 1c pivot R to face the cnrs[pos] they just passed (3x,4,1x,2)

17--::

  Middles (4c & 1c) turn ends (3c & 2c) RH 1½ to form a St Andrew''s Cross (3c & 2c retain RH and give LHA in centre) ; *H.Schottische BiL* : (middle couples RHJ to cnrs and LHJ in centre) all set HS {1}, while setting to R drop LH and pass cnrs changing to LHJ (take LH under RH) {1} ; on return change hands back (take RH under LH) {2}, at end 3c & 2c form a St Andrew''s Cross again very briefly as on [20].

25--::

  3c+2c LHA ; 3W+2M LHJ on Mside & 3M+2W LHJ on Wside lead out and cross, 2c to 1pl, 3c to 4plx (4c & 1c step inwards) (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (13011, '2020-08-03 10:16:23.051185+00', '2021-05-02 18:06:19.656489+00', 20062, 1, 202, 'ace', '1--::
  R&L (1,2)
9--::
  1M+2W cross RH | set _while{4}_ 1W+2M set | cross RH (to 2x,1x) ; chase clw ½ (1,2)
17--::
  1M+2W set | cross LH _while{4}_ 1W+2M cross LH | set (to 2x,1x) ; chase cclw ½ (1,2)
25--::
  2C Set&Rotate (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (12546, '2020-02-02 02:47:42.45584+00', '2020-09-15 00:19:30.65729+00', 13904, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Inveran reels (6 bars), 1s curve in/down to 2nd
    place, 2s curve out/up to 1st place.  2 1 3
9-16::
    2s+3s dance R&L (no polite turn) _while_ 1s cross RH, cast right
    round 1st corner (pstn) to ends, dance through 2nd place own side &
    cast right into lines of 3 across facing 2nd corners
17-24::
    _1/2_ reels of 3 across (1M+2L & 1L+3M pass LSh); 1s turn LH (1.3/4
    in Strathspey: 3/4 in reel) _while_ 2s+3s set up/down on sides &
    change places RH (3) (1) (2)
25-32::
    3s+1s+2s Set+Link for 3 twice.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9129, '2016-03-30 18:32:03.174812+00', '2023-02-10 14:43:17.920803+00', 1681, 2, 2847, 'ace', '1-16:: 1st couple dance a Petronella Diamond.

17-18:: 1M and 2L change places giving right hands.

19-20:: 1L and 2M change places giving right hands.

21-22:: 1M and 3M change places giving left hands.

23-24:: 1L and 3L change places giving left hands.

25-26:: 1M and 4L change places giving right hands.

27-28:: 1L and 4M change places giving right hands.

29-32:: All turn right hands 1½ times to own side.



Repeat with a new top couple', 0);
INSERT INTO 'dancecrib' VALUES (1988, '2012-01-22 19:29:13.735883+00', '2021-07-03 12:34:16.77148+00', 387, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  All set to P | all M dance cclw in front of P and W on R, behind opposite W to face own cnr | turn cnr BH (M finishing 1 place clw)

9–::

  All W repeat [1-8] mirrored, dancing clw and turning »new« cnr

17-32::

  Repeat [1-16], finishing (3,4,1,2)

33–::

  All dance Double M-Chain

41–::

  1c+3c ½ R&L ; 2c+4c ½ R&L (1,2,3,4)

49–::

  All dance Double L-Chain, the M omitting final polite turn into

57-64::

  G-Chain, 1 step / hand, starting RH to cnr (M travel clw) (1,2,3,4)



{{title}}

Reel



1-56::

  Repeat [1-56], turning cnrs RH and with polite turn on [56]

57–::

  Circle8 and back (1,2,3,4)', 3);
INSERT INTO 'dancecrib' VALUES (2205, '2012-01-22 19:29:25.717347+00', '2020-08-04 05:49:30.122702+00', 2079, 1, NULL, 'ace', '1–::

  1c lead down, cross below 3c and cast to 2plx (2c up) ; All turn P BH 1½ (2x,1,3x)

9–::

  1c cast up, cross RH, cast off to 2plx ; All turn P BH 1½, finish (2,1,3) H joined for

17–::

  Circle6 L ; All C dance BtoB {2 bars} | All turn P RH into

25–::

  All promenade (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11107, '2018-09-14 09:05:03.886556+00', '2020-08-04 00:44:47.815072+00', 12817, 1, 202, 'ace', '1--::

  1M+2W & 3M+4W set | change places RH ; 1W+2M & 3W+4M set | change places LH (2x,1x,4x,3x)

9--::

  2c+1c & 4c+3c ½ R&L ; 1c (with 1W on 1M right) & 4c (with 4W on 4M left) RHJ chase clw ½ into two lines4 across

17--::

  4c+1c set | ½ Circle4 L to change places ; 1c+4c set diagonally | ½ Circle R to change back into Reel4 position

25--::

  RSh Reels4 across, ending 1c(4c) in 3plx(2plx),  2c (with 2W on 2M right) between 1c facing down, 3c (with 3W on 3M left) between 4c facing up

33--::

  2c & 3c LHJ chase clw ½ to 1plx/4plx (to 2x,4x,1x,3x) ; all turn LH 1½ (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12699, '2020-04-06 12:17:04.707536+00', '2020-04-06 12:55:48.931506+00', 8170, 1, 202, 'ace', '1--::

  All M cast off behind P, LHA and dance RSh round P to places (1,2,3,4)

9--::

  All W cast off behind P, RHA and dance LSh round P to places (1,2,3,4)

17--::

  1c+3c ½ La-Chain ; 2c+4c ½ La-Chain

25--::

  All turn cnrs RH 1½ ; all turn P LH 1½ (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (14098, '2021-06-30 13:41:12.263908+00', '2021-07-03 12:38:19.006716+00', 20246, 1, 202, 'ace', '1--::
  1c ½ Fig8 down round 2c ; 1c+2c change places EH (to 2,1x,3) | 1c+3c turn RH. 1c in 2plx face up and out (2,1x,3)
9--::
  Mirror Reels3 on sides, 1c out and up. On [15-16] 1c cross up to 2pl (2,1,3)
17--::
  2c+1c *Non Progressive Set&Rotate* : same as 2C Set&Rotate except [21-22] RHA ½ (2,1,3)
25--::
  Circle6 and back.', 2);
INSERT INTO 'dancecrib' VALUES (8757, '2015-04-29 19:05:41.084347+00', '2022-01-29 00:42:32.667801+00', 440, 2, 160, 'ace', '1-8::
  1C Turn RH , Cast 1 pl. (2C up) ; 1C cross LH , cast L (M up/L down) to lines of 3 across.
9-16::
  Reels3 across - 1L+2C, 1M+3C. 1C pass Lsh to give Rsh to 2W/3M respectively.
  1C end 2pl opp. sides.
17-24::
  1C pass half round: approach, pull Lsh back and cast (M up/L down) to lines of 3 across; 1C approach, pull Lsh back and cast to 2pl own sides and pass Lsh to face 1crnrs.
25-32::
  Turn CPCP.', 0);
INSERT INTO 'dancecrib' VALUES (14108, '2021-07-04 20:39:58.448401+00', '2021-07-04 20:41:43.731894+00', 16196, 1, 1645, 'ace', '1--::

  1c set | dance down curving into 2pl (2c up) ; repeat to 3pl (2,3,1)

9--::

  2c & 1c set | dance to next cnr cclw & curve into place ; repeat (1x,3,2x)

17--::

  1c+3c+2c S&Link twice, but on [17-18] 3c cross RH & swivel instead of setting (2,3,1)

25--::

  Circle6 to L, pivot ; chase back cclw (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15104, '2022-09-22 12:34:22.732642+00', '2022-09-22 12:47:55.616881+00', 21108, 1, 202, 'ace', '1--::

  1c cross RH _while_ 2c+3c set | *Mirror Modified 3C Set&Link* : same as 2C Set&Link where top two couples in tandem cast off _while_ bottom couple dance up to 1pl (to 3,1x,2) ; all repeat [1-4] from new positions (2,3x,1x)

9--::

  2c+3c turn P RH ½ | chase clw ½ (to 3x,2,1x) ; repeat (2,3x,1x)

17--::

  3c (+ 2c following) Fig8 down round 1c (3x,2,1x)

25--::

  3c cross RH _while_ 2c+1c set | Mirror Modified 3C Set&Link (to 1x,3,2) ; repeat [25-28] from new positions (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9794, '2017-04-14 22:56:55.547314+00', '2022-06-17 20:04:04.569581+00', 6787, 1, 202, 'ace', '1--:: 

 1c dance between 2c and cast up ; 1c turn BH

9--::

 2c dance up between 1c and cast off ; 2c turn BH

17--::

 1c cross | cast (2c up) ; 1c ½ Fig8 round 2c (2,1,3)

25--::

 2c+&c R&L', 2);
INSERT INTO 'dancecrib' VALUES (14759, '2022-04-15 21:09:45.846611+00', '2022-07-21 15:03:31.14298+00', 10070, 1, 1645, 'ace', '1--::

  1c cross RH | cast off (2c up) ; &frac12; Fig8 to L, 1W up, 1M down (2,1,3)

9--::

  1c+2cnrs turn RH, 1c return to sides & swivel to R ; 1c+1cnrs turn RH, 1c end facing out

17--::

  Rsh Reels3 on the sides

25--::

  Circle6 to L & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12700, '2020-04-06 13:54:17.826597+00', '2020-04-06 14:25:57.365046+00', 8169, 1, 202, 'ace', '1--::
  1c set | cast off (2c up) ; turn LH 1½ to 2plx (2,1x,3)
9--::
  Reels3 on sides, 1c LSh to 2cnrs. 2c & 3c NHJ in centre face up/down _as_ 1c in 2plx face out (2,1,3)
17--::
  1c chase cclw to 2pl _while{4}_ 2c & 3c A&R up/down back to sides ; all turn P RH (2,1,3)
25--::
  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15200, '2022-10-28 19:08:14.265991+00', '2022-10-29 08:15:00.60979+00', 21120, 1, 1645, 'ace', '1--::

  All dance intersecting L-Chains with &frac12; RHA in centre, end facing P

9--::

  All &frac12; G-Chain, 2 bars per hand (3,4,1,2)

17--::

  All turn P 1&frac14; RH into promhold facing cclw ; dance &frac34; cclw & face P

25--::

  All set to P | turn &frac34; RH ; M dance 1pl clw outside W to original pl | set to new P (M: 1234; W: 2341)

', 2);
INSERT INTO 'dancecrib' VALUES (9823, '2017-05-06 13:13:02.256117+00', '2021-07-04 12:10:44.374803+00', 17428, 1, 202, 'ace', '1--::

 All set | cross RH ; repeat

9--::

 1M+2W cross RH | 1W+2M & 1M+3M cross LH ; 1W+3W & 1M+4W cross RH | 1W+4M cross LH (2x,3x,4x,1x)

17--::

 All W *facing down* A&R _while{4}_ All M *facing up* A&R ; All turn P RH 1 ½ (2,3,4,1)

25--::

 Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (1995, '2012-01-22 19:29:14.062894+00', '2021-07-06 20:26:01.607505+00', 13259, 1, NULL, 'ace', '1–::

  1c cast behind own lines ; turn outward and dance back up to place

9–::

  1c+2c RHA ; LHA

17–::

  1c lead down {3}, up {3}, cast off (2c up)

25–::

  2c+1c  R&L', 3);
INSERT INTO 'dancecrib' VALUES (15203, '2022-10-29 17:08:58.687453+00', '2022-10-29 17:12:19.579576+00', 21127, 1, 1645, 'ace', '1--::

  1c petronella to midline _while_ 2c cast up | 1c+2c set ; A&R{1+1} | set

9--::

  1c petronella to opp sides _while_ 2c cast off | 1c cross RH | cast off (2c up) to (2,1,3)

17--::

  1c &frac12; diagonal R&L with 1cnrs ; repeat with 4cnrs (3x,1,2x)

25--::

  1c cross into &frac12; Reels3 on opp sides starting LSh to 3M/2W (2x,1x,3x) ; all cross RSh | set (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14109, '2021-07-05 07:25:08.438948+00', '2021-07-05 07:30:46.928203+00', 11331, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; 1c turn P RH 1½ to face 3W in tandem, 1M leading

9--::

  ½ Reel3 in tandem (with lead change) on Wside, 1M RSh to 3W ; ½ Reel3 in tandem (with lead change) on Mside, 1W RSh to 3M. 1c between 3c in 1pl face down

17--::

  1c dance down between 2c in 3pl | cast up to 2plx (to 3,1x,2) ; ½ Mirror Reels3 on sides, 1c in and up (2,1x,3)

25--::

  1c dance down round 3c to 2plx ; turn P RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13012, '2020-08-04 00:58:25.091769+00', '2020-08-04 01:03:25.451736+00', 2180, 1, 202, 'ace', '1--::

  All A&R ; all dance BtoB (1,2,3,4)

9--::

  2c Fig8 R, LSh to 1cnrs (1,2,3,4)

17--::

  1c+2c & 3c+4c RHA ; LHA (1,2,3,4)

25--::

  1c cross RH | dance behind P''s lines to 4plx | cross RH (2c+3c+4c up on [31-32])

', 2);
INSERT INTO 'dancecrib' VALUES (15329, '2022-12-19 01:19:50.281628+00', '2023-02-04 01:20:02.705716+00', 21179, 3, NULL, 'ace', '1-4::
    All set, 1s+2s & 3s+4s dance 1/2 RH across. (2) (1) (3) (4)
5-8::
    All set, 2s+4s cross RH _while_ 1s+3s turn partner 3/4 RH into line
    in centre of set, 1M+3M facing down 1L+3L facing up.
9-12::
    1s+3s dance 1/2 RSh reel of 4 up/down centre, finishing with quick
    1/2 RH turn to face opp sides.
13-16::
    2s+3s & 1s+4s dance 1/2 RSh reels of 4 across the dance, 1s+3s
    finish facing partners, 3L+1L facing down 3M+1M facing up.
17-20::
    3s+1s dance 1/2 RSh reel of 4 in centre, finish with quick RH 1/2
    turn to face own sides.
21-24::
    1s+2s & 3s+4s dance 1/2 RSh reels of 4 across, 1s+3s finish facing
    partners, 1M+3M facing down 1L+3L facing up.
25-26::
    1s+3s turn partner 3/4 RH to face up
27-32::
    1s+3s lead up to top and cast on own sides, 1s to 4th place, 3s to
    2nd place. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14105, '2021-07-04 08:45:58.760674+00', '2021-07-04 08:52:36.428295+00', 15323, 1, 1645, 'ace', '1--::

  1c+2c Espagnole, but in [5-8] 1c turn 1&frac12; LH to face 1cnrs

9--::

  1c+1cnrs diagonal RSh Reel4, 1c end facing 1cnrs again

17--::

  1c+1cnrs Set to Corners & Cast Away, 1c end facing 2cnrs

25--::

  1c+2cnrs diagonal RSh Reel4, 1c end facing 2cnrs again

33--::

  1c+2cnrs Set to Corners & Cast Away, 1c end passing RSh to face out on opp sides (2,1x,3)

41--::

  2c+3c set facing down/up | change pl RH ; set to P | cross LH _while{8}_  

  1c cast R round 1cnr to face P on centre line ; all clap, 1c pull RSh back & cast R round 4cnr (2,1,3)

::

  *NB Set to Corners & Cast Away is also known as the Best Set in the Hall figure*

', 2);
INSERT INTO 'dancecrib' VALUES (14107, '2021-07-04 19:46:44.103353+00', '2021-07-04 19:53:39.177617+00', 755, 1, 1645, 'ace', '1--4::
  All &frac12; turn P BH & face up | set
5--12::
  1c, others following, dance slightly up & cast to 4pl (4x,3x,2x,1x) ;
  cross in 4pl (no hands, W in front of P) & dance up own side, 1c & 3c curving to face down (1,2,3,4)
13--20::
  Mirror Reels4 on sides, 1c & 3c starting in & down, join hands when meeting
21--24::
  3c & 1c dance down below 4c & cast up, 3c to 1pl, 1c to 3pl (3,2,1,4)
25--32::
  3c+2c & 1c+4c Tourbillon (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (15204, '2022-10-30 12:35:24.213818+00', '2022-10-30 12:41:13.897166+00', 21153, 1, 1645, 'ace', '1--::
  1c & 3c &frac12; Fig8 round 2c/4c ; 1c & 3c dance down, 1c end BtoB facing 2cnr pos, 3c end BtoB between 4c _while_ 2c petronella on sides, 2M down, 2W up (to form shape of figure 7) | all set
9--::
  1c+2c RSh Reel4 on diagonal _while_ 3c+4c RSh Reel4 across. On [15-16] 1c & 3c do not pass LSh but curve to face in centre
17--::
  1c+3c &frac12; LHA ending 3c/1c between 2c/4c _while{2}_ 2c cast back to 2pl | 3c & 1c set to P ; 3c & 1c &frac12; turn RH & cast away to 2pl/4pl (2c & 4c up on [21-22])
25--::
  Circle8 to L & back (2,3,4,1)
', 2);
INSERT INTO 'dancecrib' VALUES (15453, '2023-02-21 15:59:55.891688+00', '2023-02-23 15:02:00.076237+00', 20455, 2, 1363, 'ace', '1-8:: 1s+2s dance the rose progression.1M+2W set for 2, half turn & twirl BH for 4, cross to own sides for 2. Meanwhile 2M+1W change places RH for 2, dance up/down sides for 2, half turn & twirl BH for 4. 2s+1s have progressed.
9-16:: 
 1s+3s dance the rose progression.
17-24::2s+3s dance a poppy, ending with the 2s back to place but 3s B2B facing own sides. On bar 24, 1s step in B2B facing own sides. 17-18: 2s+3s dance indiagonally for 1, pull RSh back and dance out to place for 1, 19-20: all curve into the next place clockwise, 21-22: all curve into the next place clockwise, 23-24: all dance RH across halfway, 2s ending as on bar 16, and 3s ending B2B in the centre facing own sides. 25-32: 3s+1s dance the bow progression:
25-26: 3s+1s dancing to their L, loop round to the R through their original positions,
27-28:: 3s+1s dance LH across halfway 
29-30:: 1s+3s loop round to the R into opposite places,
31-32:: 1s+3s cross RH back to own sides', 0);
INSERT INTO 'dancecrib' VALUES (1688, '2012-01-22 19:28:56.689705+00', '2021-07-04 10:07:48.172798+00', 274, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; cross LH | cast L on own side to between end Cs

9–::

  Turn 1cnr RH ½ | 1cnrs loop round each other to places as 1c loops R to midline facing P ; 1c turn LH ¾ and cast R on own side, to between end Cs

17–::

  Turn 2cnr LH ½ | 2cnrs loop round each other to places as 1c loops L to midline facing P ; 1c turn RH ¾ and cast L on own side, to between end Cs

25–::

  Opposing Reels3 on the sides, Lsh to 2cnr, 1c touch RH briefly on [28], and finish (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14776, '2022-04-26 23:52:51.356327+00', '2022-04-27 00:01:06.468331+00', 13911, 1, 202, 'ace', '1--::

  1c+2c *The Philabeg* : [1-2] 1c & 2c turn P BH 1¼ to centre facing diagonally, Ms down, Ws up | [3] 1c & 2c dance diagonally, 1c down to Mside, 2c up to Wside [4] 1c & 2c turn P BH ¾ ; [5] 1c & 2c dance diagonally to centre, 2c up, 1c down [6] 2c & 1c turn P BH ¾ | [7-8] 2c & 1c pass P RSh to own sides (2,1,3)

9--::

  All set | 2c & 3c cross RH and face on sides (no polite turn) _while{2}_ 1c turn P RH ¾ to midline facing P ; 2c & 3c set | change places LH (no polite turn _while{4}_ 1c dance RSh round 1cnrs[pos] into lines3 across facing 

4cnrs[pos]

17--::

  ½ Reels3 across, 1c LSh to 4cnrs[pos]. 1c finish in 2plx facing 2cnrs[pos] ; ½ Reels3 on sides, 1c LSh to 2cnrs[pos]. On [23-24] 1c turn P RH ½ to 2pl (2,1,3

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (8957, '2015-11-02 05:12:13.222766+00', '2022-11-21 13:44:01.194483+00', 8608, 2, 2452, 'ace', '1-8:: IN & OUT, WOMEN THEN MEN: women advance & retire, then men advance & retire;

9-16:: TURN & BACK-TO-BACK: turn partner with right hand & skip change of step, then dance back-to-back with partner;

17-24:: GRAND CHAIN: starting passing partner with right hand dance a Grand Chain, 2 steps to each hand;

25-32:: PROMENADE: promenade the 5th person anticlockwise, ending in one circle.



REPEAT with new partner', 0);
INSERT INTO 'dancecrib' VALUES (12701, '2020-04-06 15:07:38.681098+00', '2020-04-06 15:17:15.648921+00', 8168, 1, 202, 'ace', '1--::

  All set | cross RH ; set | 1c & 4c turn RH ½ and face up/down _while{2}_ 2c & 3c cross RH and face out (1,2,3,4)

9--::

  1c & 4c lead in | ½ RHA and face out  _while{4}_ 2c & 3c dance out to ends | stand still {2} ; 4c & 1c lead out, cross and cast inwards (2,4,1,3)

17--::

  All dance BtoB ; middles and ends (2M+4M,1M+3M,2W+4W,1W+3W) turn RH on sides (2,4,1,3)

25--::

  Reels4 on sides (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15201, '2022-10-28 19:38:11.309402+00', '2022-10-28 19:44:00.374414+00', 21130, 1, 1645, 'ace', '1--::

  1c+2c mirror S&Link, 1c casting, 2c dancing up ; 1c dance below 3c & cast up (2,1,3)

9--::

  1c turn 1&frac14; LH ; 2c+1W & 1M+3c &frac12; RHA | 1c cast round 4cnrs to 2pl (2x,1,3x)

17--::

  1c+1cnrs &frac12; diag R&L ; 1c+4cnrs &frac12; diag R&L (3,1,2)

25--::

  3c+1M & 1W+2c LHA ; RSh Snake Pass (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12702, '2020-04-06 15:39:43.159103+00', '2020-04-06 15:47:45.015732+00', 8167, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig up round 2c and face 1cnrs (2,*1*,3)

9--::

  Turn CPCP. 1c in 2plx face out (2,1x,3)

17--::

  1c dance LSh round 2cnrs[pos] | turn P RH ½ ; dance RSh round 4cnrs to 2pl _while{6}_ 2c+3c cross RH (polite turn) | step inwards ; change places LH on sides (polite turn) | all set to P (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14779, '2022-04-27 12:34:49.096413+00', '2022-04-27 12:40:40.552562+00', 17166, 1, 202, 'ace', '1--::

  1c+2c The Bourrel (2,1,3)

9--::

  1c set | cross RH ; dance RSh round 1cnrs | meet in centre pulling RSh back into BtoB position. 1W face up, 1M face down

17--::

  All A&R {1+1} (no hands) | 1c turn 4cnrs RH to 2pl (to 2,1,3) ; all A&R {1+1} | all turn P BH (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12703, '2020-04-06 18:05:09.788917+00', '2020-04-06 18:10:33.719727+00', 2102, 1, 202, 'ace', '1--::

  1c+2c the Tournée (2,1,3)

9-20::

  3C R&L (2,1,3)

21-24::

  1c turn P BH 1½ to 2pl centre facing clw (2,*1*,3)

25--::

  Reels3 {6} on sides, 1c LSh to 1cnrs | 1c cross RH to 2pl _while{2}_ 2c & 3c loop to places (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12057, '2019-08-28 14:17:26.267244+00', '2022-04-27 10:14:41.581146+00', 19563, 1, 1645, 'ace', '1-::

  1c set adv | &frac12; turn BH & twirl away ; cast off (2c up) | cross LH (2,1,3)

9-::

  All dance 3 couple Bourrel ending with new P (M: 3,2,1; W: 1,3,2)

17-::

  3M+1W+3W & 2M+1M+2W RHA, 2M & 3W pass RSh ; 3M+1M+2M & 3W+1M+2W LHA

25-::

  All dance *Outer Tandem Bourrel:*  

  _1-4_: 3M+2W set adv | &frac12; turn BH & twirl away _while{4}_ 3W+1W & 1M+2M chase &frac12; way cclw  

  _5-8_: 1M+2M NHJ & 2W also 3M & 3W+1W NHJ set facing on centre line | Circle3 &frac34; L & form one circle opposite original P (2,1,3)

33-::

  All Circle6 & back (2,1,3)

41-::

  All dance *Inner Hand-in-Hand Bourrel:*  

  _1-4_: 2M+1M NHJ & 1W+3W NHJ set adv to facing lines of 2 across | Circle4 &frac12; L & twirl away _while{4}_ 2W & 3M chase &frac12; way cclw  

  _5-8_: 2W & 1W+3W NHJ also 2M+1M NHJ & 3M set facing on centre line | Circle3 &frac34; L to sides (3,1,2)

', 5);
INSERT INTO 'dancecrib' VALUES (3219, '2012-01-22 19:30:16.195148+00', '2020-04-06 15:59:24.062044+00', 5934, 1, NULL, 'ace', '1–::

  1W+2W & 1M+2M turn RH ; 1c+2c dance BtoB with P

9–::

  1c+2c turn P RH ; 1W+2W & 1M+2M dance BtoB

17–::

  1M+2M dance across above/below P and cast in between them, to (1,2) ; 1M+2M set to each other and change places LH

25–::

  1W+2W repeat bars 17-24 round 2M+1M', 2);
INSERT INTO 'dancecrib' VALUES (14871, '2022-06-17 22:49:34.911072+00', '2022-06-17 23:02:56.982884+00', 20896, 1, 202, 'ace', '1--::

  Mirror Reels3 {6} on opposite sides, 1c crossing dowm RH to 2plx, all joining hands where possible | 1c cross down LH to 2pl (2c up) (2,1,3)

9--::

  1c Petronella turn _while{2}_ 2c+3c change places RH on sides | 1c change places RH _while{2}_ 2c & 3c set (side, across) ; 1c Petronella turn to 2pl _while{2}_ 3c & 2c cross RH | 1c cross RH _while{2}_ 3c & 2c set (across, side) (3x,1x,2x)

17--::

  3c+1M & 1W+2c RHA ; all chase clw ½ (2,1,3)

25--::

  1c+3c Set&Link ; all turn P BH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (14781, '2022-04-28 18:29:45.391979+00', '2022-04-28 18:29:55.950792+00', 6268, 1, 1645, 'ace', '1--::

  1c+2M RHA, 1W+1M end in tandem facing 3W, 2M ends in 1pl (2W up on [3-4]) ;

  1c, 1W leading, &frac12; tandem LSh Reel3 on 1diag & end facing 2W

9--::

  1c+2W RHA, 1W+1M end in tandem facing 3M ;

  &frac12; tandem LSh Reel3 on 2diag & 1c each end facing 1cnr [pos]

17--::

  1W+3W & 1M+2M &frac12; turn RH | 3W+2M &frac12; turn LH _while{2}_ 1c set ;

  1W+2M & 1M+3W &frac12; turn RH | 1c turn LH to face 2cnr [pos] _while{2}_ 1cnrs set

25--::

  1c repeat [17-24] with 2cnrs & end on own side (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14782, '2022-04-30 19:08:12.313599+00', '2022-04-30 19:14:04.6739+00', 20795, 1, 1645, 'ace', '{{explanation}}

Do As I Say (first time through)



1--4::

  1M+2M+3M dance across above P | wheel round to face in _while_ W set adv slightly

5--8::

  1W+2W+3W dance across below P''s place | W wheel round to face in _while_ M set (1x,2x,3x)

9--::

  2c+3c RHA (bottom) ; 1c+2c+3c &frac12; Reels3 on sides, 2c+3c start passing RSh (3x,2x,1x)

17--::

  3c+2c LHA (top) ; 3c+2c+1c &frac12; Reels3 on sides, 3c+2c start passing LSh (1x,2x,3x)

25--::

  2W+1c & 2M+3c &frac12; RSh Reels3 across (1,2,3) ; 1c+2c &frac12; RHA | cross RH (2,1,3)





{{explanation}}

Do As I Mean (second time through, 1c starting from 2nd place)



1--4::

  1M+2M+3M dance across above P | wheel round below P & take P in promhold in _while_ W set in place

5--8::

  1c+2c+3c dance across to M''s place | W dance across to own sides (1,2,3)

9--::

  1c+2c RHA (top) ; 1c+2c+3c &frac12; Reels3 on sides, 1c+2c start passing RSh (3,2,1)

17--::

  2c+1c LHA (bottom) ; 3c+2c+1c &frac12; Reels3 on sides, 2c+1c start passing LSh (1,2,3)

25--::

  2M+1c & 2W+3c &frac12; RSh Reels3 across (1x,2x,3x) ; 1c+2c &frac12; RHA _while_ 3c cross RH | all set (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12960, '2020-07-14 12:21:44.745422+00', '2022-05-02 23:29:35.72317+00', 20049, 1, 202, 'ace', '1--::

  2C Set&Rotate. 1M & 2W face out (2,1,3)

9--::

  2c+1c RHA. 1M face out ; 1c+3c LHA.1c face up (2,1,3)

17--::

  Parallel Reels3 on sides, 1c RSh to 2c. All face in (2,1,3)

25--::

  1c+3c 2C Knot (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (14778, '2022-04-27 00:54:33.863331+00', '2022-04-27 11:31:17.627426+00', 12947, 1, 202, 'ace', '1--::

  1c+2c The Bourrel. On [7-8] 2c & 1c turn P RH ¾ into allemande hold facing up (2,1,3)

9--::

  2C Allemande (1,2,3)

17--::

  1c+2c S&Link ; 1c+3c S&Link (2,3,1)

25--::

  Circle6 and back (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10230, '2017-11-05 10:05:22.085708+00', '2022-07-21 15:18:28.545518+00', 10073, 1, 202, 'ace', '1--::

  Mirror Reels3 on opposite  sides, 1c crossing down to start, 1c finish in promhold facing down

9--::

  1c+2c ½ Reel3 across, 1c Rsh to 2M ; 1c+3c ½ Reel3 across, 1c Lsh to 3W, 1c ending between 3c

17--::

  1c separate, cast off to 1plx ; ½ Fig8 round 2c (1,2x,3x)

25--::

  1c+2c Petronella turn | set ; repeat (2,1x,3x)

33--::

  1c+3c repeat [25-32] (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (15202, '2022-10-28 21:26:48.859537+00', '2022-10-28 21:39:21.486044+00', 21129, 1, 1645, 'ace', '1--::

  1c turn RH | cast off (2c up) ; 1c+1cnrs &frac12; diagonal R&L

9--::

  1c+4cnrs &frac12; diagonal R&L (3x,1,2x) ; 1c petronella to midline | set as H&G{2} to face 1cnrs

17--::

  *Half Diamond Reel of Four:*  

  17-18: 1c & 1cnrs pass RSh, 1c end in 1cnr pos, 1cnrs pass LSh & turn to face each other on 2diag  

  19-20: 1c & 1cnrs set, 1cnrs advancing on [20] to end BtoB facing 3cnr pos  

  21-22: 1cnrs & 1c pass RSh, 1cnrs end in places as at [5], 1c pass LSh & turn to face P in 2plx  

  23-24: 1c set as H&G{2} to face 2cnrs  

25--::

  Repeat [17-22] with 2cnrs, 1c end facing P up/down | 1c petronella to own sides (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14780, '2022-04-27 13:01:37.937194+00', '2022-04-28 03:47:08.501842+00', 16591, 1, 202, 'ace', '1--::

  1c+2c The Bourrel. On [7-8] 1c turn P RH 1¼ to face 1cnrs

9--::

  1c+1cnrs set | turn BH ¾ advancing slightly toward centre opening to face centre diagonally NHJ ; 1M+3W & 1W+2M S&Link. 1cnrs cast R to original places _while_ 1c pass P RSh to face 2cnrs

17--::

  1c+2cnrs repeat same pattern [9-16]. 2cnrs cast R to original places _while_ 1c pass P RSh. 1M face up, 1W face down

25--::

  Reels3 across {6}, 1c LSh to 3cnrs (to 2,1x,3) | 1c cross LSh (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14783, '2022-05-02 23:56:14.44526+00', '2022-09-13 15:09:45.712809+00', 11608, 2, 1, 'ace', '1–:: All S | W cross, pass ptr LS ; chase back to own side

9–12:: All S | 1c Petronella into middle [M fin facing up, W down]

  _while_ 2c+3c Petronella in tandem [M fin facing up, W down]

13–16:: All S| 1M Petronella to 1W''s pl _while_ 1W Petronella to 3M''s pl

  _while_ 2c+3c Petronella in tandem [2M to 3W''s pl, 3M to 2W''s pl,

  2W to 1M''s pl, 3W to 2M''s pl]

17–:: All S | M cross, pass ptr LS ; chase back to opp side

25–:: All A&R ; All turn BH 1½

33–:: Circle6', 0);
INSERT INTO 'dancecrib' VALUES (14874, '2022-06-19 12:07:16.102673+00', '2022-06-19 13:25:51.826613+00', 20877, 1, 202, 'ace', '1--::
  All clap and 1c cross RSh | cast off (2c up) ; cross RSh ½, face P and cast aways to 2pl facing 3cnrs (2,1,3)
9--::
  Reels3 on sides, 1c RSh to 3cnrs. 1c in 2pl face out (2,1,3)
17--::
  1c dance RSh round 3cnrs into lines3 across _while{4}_ 2c & 3c A&R diagonally ; 1c pass RSh | dance RSh round P to 2pl _while{4}_ 2c & 3c set twice diagonally (2,1,3)
25--::
   Circle6 L {3}, cross R foot over and pivot L ; chase cclw (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14785, '2022-05-03 23:16:22.335418+00', '2022-05-03 23:18:17.128294+00', 20781, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; 1c set advancing | turn 1cnrs RH ¾ into lines3 across, 1W between 2c & 1M between 3c all facing down

9--::

  All dance down, pull RSh back | dance up into facing lines3 across, 2c+1W on 1pl, 3c+1M on 3pl

17-28::

  3C R&L up/down

29-32::

  1c turn P 1¼ to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15454, '2023-02-21 16:06:38.657565+00', '2023-02-23 14:57:14.823411+00', 21242, 2, 1363, 'ace', '1- 8::
  1s+2s+3s dance set and rotate for 3 cpls, ending 321.
9-16::
  3s+2s+1s dance a modified split allemande: 3s+2s dance a 2-cpl allemande finishing 3s in 3rd place and 2s in 1st place; on bars 11-12 1s having stepped up and 3s having danced down to 3rd place; 213 on bars 15-16 1s set advancing to face 1st corners as 2s+3s retire to sidelines.
17-24::
  1s dance hello-goodbye setting finishing with a petronella turn to 2nd place on their own sides.
25-32::
  2s+1s+3s dance 6H round and back, ready to begin again', 4);
INSERT INTO 'dancecrib' VALUES (2367, '2012-01-22 19:29:33.722306+00', '2022-06-18 08:40:11.352991+00', 2640, 1, NULL, 'ace', '1–::

  1c+2c Circle L ; 1c facing 2c set NHJ, 2c turning in to face down | 2c cast up as 1c dance down (2,1,3)

9–::

  G-Chain, 2c cross to start

17–::

  2c+1c R&L

25–::

  All A&R ; all Turn BH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2543, '2012-01-22 19:29:46.962285+00', '2022-06-19 09:59:39.85681+00', 1624, 1, NULL, 'ace', '1–::

  1c cast | cross RH ; cast up | cross LH (1,2)

9–::

  2c cast up | cross RH ; cast down | cross LH (1,2)

17–::

  1M with 1W on R in promhold cast behind 2M (2M up), passes 1W across in front of him LH to leave her in 2M place (1W dances a full turn single in Sk-Change) ; crosses up for 1M+2W turn RH ½ (2,1x)

25–::

  1M+2W NHJ dance between their Ps, divide and round P to W side | turn RH and face P (2, 1x)

33–::

  1c ½ Fig8 up between 2c ; turn RH (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (14875, '2022-06-19 12:57:35.087333+00', '2022-06-19 13:12:16.123556+00', 20886, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; turn RH ½, face P and cast aways to 2pl (2,1x,3)

9--::

  *Corners Pass and Cast Away* : 1c+4cnrs pass RSh, cnrs turn RH ½, face each other and cast away to exchanged places as 1c meet P and turn RH to face 3cnrs ; repeat with 3cnrs. On [16] 1c pass P RSh to 2plx (3x,1x,2x)

17--::

  3C Set&Link twice (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14873, '2022-06-18 12:45:16.273402+00', '2022-06-19 13:31:36.510752+00', 20887, 1, 202, 'ace', '1--::
  1c set | cross RH ; cast off (2c up) | turn P LH ¾ to face 1cnrs
9--::
  4 bars of SetH&G ; ½ Reel4 on 2diag. 1c face 4cnrs[pos}
17--::
  4 bars of SetH&G ; ½ Reel4 on 1diag. 1c on midline LSh to P face own sides
25--::
  3c+1M & 1W+2c RHA ; all chase clw ½ (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14877, '2022-06-20 06:03:57.188877+00', '2022-06-20 23:52:22.237722+00', 20897, 1, 202, 'ace', '1--::
  1c set | lead down {3}, lead up {3} to 2pl midline, 1M passing 1W in front of him to face up in tandem (2c up on [3-4])
9--::
  1c+2W RHA ; ½ Reel3 in tandem (with lead change) on 2diag, 1W leading LSh to 3M
17--::
  1c+2M LHA ; ½ Reel3 in tandem (with lead change) on 1diag, 1M leading RSh to 3W. On [24] 3M & 2W step in. All finish in centre in promhold, 1c in 2pl centre pulling RSh back to face down (3x,1x,2x)
25--::
  Inverted 3C Allemande (face down to start). On [31-32] all turn P LH ½ to sides (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14876, '2022-06-19 15:46:31.108293+00', '2022-06-19 15:46:31.108293+00', 20898, 2, 1, 'ace', '1–4::
  2c+3c turn BH
5–8::
  2M+3M & 2L+3L ½ turn RH on sides ; 2c+3c set
9–12::
  All turn BH
13–14::
  1W casts off _while_ 2M dances in/down 1pl (3W & 4M step up)
15–16::
  Top and bottom two W and top and bottom two M turn RH (each)
  [fin 3124 on W''s side, 1342 on M''s side]
17–22::
  Middle people (3M+4M+1W+2W) Circle4 to L ¾ round, start dancing
  out ; 1W dances Rsh round 3L, 2W round 4L , 3M round 1M, 4M round 2M
 23–24::
  “Middle people” turn the person around whom they just danced RH
  [fin 3M between 1M & 3W, 2W between 2M and 4W, 1W and 4M in sidelines]
25–::
  Circle8 to L [fin 3142] ; all S', 2);
INSERT INTO 'dancecrib' VALUES (14784, '2022-05-03 00:06:49.162515+00', '2022-05-03 00:06:49.162515+00', 8161, 2, 1, 'ace', 'Couples RR facing anticlockwise, W on M''s right. Start on outside foot.
1–2:: 6 steps moving forward (fin back to back w/ptr, then facing ptr, BH joined)
3–4:: Step sideways anticlockwise and close; repeat
5–8:: R 1–4 moving clockwise (fin facing ptr in ballroom hold)
9–10:: Waltz once round progressing anticlockwise
11–12:: Step sideways anticlockwise and close; repeat
13–16:: Waltz twice round, progressing anticlockwise, and open to start again.', 3);
INSERT INTO 'dancecrib' VALUES (2952, '2012-01-22 19:30:04.291057+00', '2022-11-20 15:54:19.348811+00', 5032, 1, NULL, 'ace', '1–::

  1W sets twice to 2M ; 1M sets twice to 2W

9–::

  1c lead down the middle {3} and up {3} | cast off (2c up)', 3);
INSERT INTO 'dancecrib' VALUES (2727, '2012-01-22 19:29:54.855846+00', '2022-07-23 15:04:51.643876+00', 4064, 1, NULL, 'ace', '1–::

  1c+2c+3c circle6 and back (to sidelines)

9–::

  1c+2c+3c cross RSh ; cross back RSh

17–::

  1c turns BH moving down to face 1cnrs _while{4}_ 2c turns BH {2} and casts up to 1pl _while{4}_ 3c turn BH to 3pl ; 1c set to 1cnr | to 2cnr

25–::

  Reels3{6} on opposite sides, Rsh to 2cnr | 1c cross RH to 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14786, '2022-05-04 14:36:03.032889+00', '2022-05-04 14:40:46.266322+00', 20791, 1, 202, 'ace', '1--::
  1c & 2c turn P RH ½, face up and set NHJ ; 1c cast off _while_ 2c loop to 1pl (2,1,3)
9--::
  Mirror Reels3, all crossing from the top (2c on [9], 1c on [11], 3c on [13]) (2x,1x,3x)
17--::
  All Allemande turn RH ; al set | cross RH (2,1,3)
25--::
  1c+3c The Tourbillon (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (14970, '2022-07-25 07:03:42.125685+00', '2022-09-13 12:43:04.112464+00', 8258, 1, 202, 'ace', '*5 dancers in a square set, 5 in centre facing 1 (1,2,3,4,5)*
1--::
  1+5 set | change places RH. 1 pivots R to face 2 ; 2+1 repeat. 2 pivots R to face 3
9--::
  3+2 repeat. 3 pivots R to face 4 ; 4+3 repeat. 4 pivots R to face 5 (5,1,2,3,4)
17--::
  5+4+2 Reel3, 4 RSh to 5. 4 faces 3
25--::
  3+4+1 Reel3, 4 LSh to 3. 4 faces 5 (5,1,2,3,4)', 2);
INSERT INTO 'dancecrib' VALUES (5190, '2013-08-21 08:31:02.264255+00', '2021-01-09 01:19:35.401252+00', 8351, 3, NULL, 'ace', '1-8::
    1s & 3s set, 1s cast 1 place & cross up to partner''s place _while_
    3s cross up & cast, 1s+2s change places on sides (RH Ladies'' side &
    LH Men''s) _while_ 3s 1/2 turn RH
9-16::
    2s+1s+3s circle 6H round & back
17-24::
    2s+1s+3s set, cross RH, 2s+3s change places LH on sides & set
    _while_ 1s cast (Man down & Lady up) into middle facing 1st corner
    (pstns)
25-32::
    1s dance RSh round 1st corner & pull back RSh to face 4th crnr
    (pstn) _while_ crnrs 1/2 turn, pull back RSh & dance out to diag opp
    place. Repeat with 4th crnrs & 1s end in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (3061, '2012-01-22 19:30:08.837288+00', '2020-04-07 11:09:42.693098+00', 5412, 1, NULL, 'ace', '{{title}}

Strathspey



1–::

  1c cast off 2, meet below 3c ; 1c dance up and 2c cast up to face each other NHJ | set up/down (2,1,3)

9–::

  2c+1c circle4 and back, to sidelines (2,1,3)

17–::

  1c petronella to between end couples _while{2}_ end couples change places RH up/down | set in lines across ; 1c petronella to 2plx _while{2}_ 3c+2c cross RH | all set (3x 1x,2x)

25–::

  The serpentine ({the middle C always starts inwards} 1c+2c change places EH | 3c+2c (other hand) repeat ; 3c (other hand) +1c repeat, 2c+1c+3c cross RH.  Polite turns at the end positions)



{{title}}

Reel



33-64::

  1c+3c+4c repeat [1-32] in reel time (2,3,1,4)



*1c step down and 4c up on [1-2] of next turn. (2,3,4,1)*', 3);
INSERT INTO 'dancecrib' VALUES (14968, '2022-07-24 19:52:08.632944+00', '2022-07-24 19:53:36.60037+00', 13103, 1, 202, 'ace', '*5 dancers in circle pattern, 1 at top, 2,3,4,5 clw (1,2,3,4,5)*
1--::
  All advance, taking hands briefly | retire ; 1+4 dance BtoB
9--::
  4+2 A&R ; 2+5 dance BtoB
17--::
  5+3 A&R ; 3+1 dance BtoB
25--::
  1+4 change places RH | 1+2 repeat ; 1+5 repeat | 1+3 repeat (4,5,1,2,3)

*Deviser''s note* : On bars 25-32, dancers should release hands early enough to reach new places.', 2);
INSERT INTO 'dancecrib' VALUES (3403, '2012-01-22 19:30:23.918515+00', '2022-11-01 18:55:40.504611+00', 6637, 1, NULL, 'ace', '{{explanation}}

16-bar pattern: ½ RH turn | Promenade down 2 places ; cross LH | cast up one ; Set turning to | cast up 1 place ; turn RH ½  | Promenade down 1 place to face 2M position.



1-16::

  1c dance pattern _while_{16} 2c set turning and cast up 1 place ; and follow pattern for 12 bars _while_{16} 3c set turning and cast up ; repeat ; follow pattern for 6 bars | set to P

17–::

  2M+1c+3W diagonal Rsh. Reels3

25–::

  2W+1c+3M diagonal Lsh. Reels3 (but 1c ½Reel, dance up through 1pl, cast off to 2pl)', 2);
INSERT INTO 'dancecrib' VALUES (14971, '2022-07-27 18:18:22.179097+00', '2022-07-27 18:18:22.179097+00', 18060, 2, 160, 'ace', '1-8::  1s 2s 3s turn RH once round; 1s long cast to 2pl.
9-16::  2s 1s Set and Link; that again - 2L 1M face out.
17-24::  Parallel Reel3 on sides - 1s pass 3s by left shoulder to begin.
25-32::  1s 3s LHA; 2s 1s RHA.', 3);
INSERT INTO 'dancecrib' VALUES (10400, '2018-01-25 14:51:52.959224+00', '2022-06-21 07:46:39.758981+00', 18230, 1, 202, 'ace', '1--::
  Inveran Reels3, 1c crossing down (1,2,3)
9--::
  All set | cross RH ; repeat [9-12]
17--::
  1c lead down to bottom, cross and cast up to 2plx (2c up on [19-20]), turn P RH to face 1cnrs
25--::
  6 bars of SetH&G | 1c dance to 2pl and face out
33--::
  1c+3c turn EH 1 ½ on sides ; 2c+3c turn EH (2,3,1)
41--::
  2c+3c+1c A&R ; all dance BtoB (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (14870, '2022-06-17 16:34:48.670036+00', '2022-06-26 11:39:47.336025+00', 20895, 2, 602, 'ace', '1-4::

  1s+2s set and link

5-8::

  2s+1s+3s set and cross RH

9-16::

  All chase clockwise, after 4 bars 1s turn RH 1 1/2 times to face 1L''s first corner, 1M closely behind 1L. Corners keep dancing to where they began on bar 9.

17-24::

  Alternating tandem (dolphin) RSh reel of three on first corner diagonal, finishing facing 1L''s second corner

25-32::

  Alternating tandem (dolphin) LSh reel of three on second corner diagonal, finishing in second place on opposite sides

33-40::

  Set and link for 3 couples, twice, fiinishing on own sides in order 312.

41-48::

  Circle six hands round and back.', 0);
INSERT INTO 'dancecrib' VALUES (14841, '2022-05-31 20:49:25.167928+00', '2022-07-27 22:14:25.643227+00', 20871, 1, 1645, 'ace', '1-::

  1c dance down below 3c | cast up to 2pl _while{4}_ 2c set | dance up & face out (2,1,3) ;

  2c+1c turn EH on sides, 1c start up between 2c

9-::

  Mirror Reels3 on the sides, joining hands where possible, 1c start in & down (2,1,3)

17-::

  1c+3c turn EH on sides, 1c start down between 3c ;

  2c+1c+3c A&R

25-::

  Circle6 to L & back (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (14777, '2022-04-27 00:31:57.080594+00', '2022-08-17 18:28:05.661917+00', 11451, 1, 202, 'ace', '1--::

  1c+2c set | turn P BH opening into ; Circle4 L (1,2,3)

9--::

  1c+2c The Bourrel. Finish in centre NHJ, 2c facing down, 1c facing up. On [16] 3c step in and face up NHJ (2,1,3)

17--::

  Hand-in-hand Reel3, all dancing NHJ with partner. At the ends, couples release hands, turn in the same direction and rejoin hands to continue the reel as a couple (2,1,3)

25--::

  1c+3c Poussette (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14832, '2022-05-21 10:01:13.516587+00', '2022-08-30 21:43:11.158731+00', 20864, 1, 1645, 'ace', '1-::
  1c+2c set | 1W & 2M cast off/up & followed by P, chase &frac12; way clw | cross RSh (2,1,3)
9-::
  All adv{1}, ret{1} & link, 1M/1W ending above/below 1pl/3pl on centre line, 3c & 2c face P across ;
  1c cast clw to 2plx | turn &frac34; LH to centre line, 1M below 1W _while{4}_ 2c & 3c dance BtoB
17-::
  2c+1W & 1M+3c RHA ; Snake passing LSh (2,1,3)
25-::
  1c+3c set | 1M & 3W cast off/up & followed by P, chase &frac12; way cclw | cross LSh (2,3,1)
', 5);
INSERT INTO 'dancecrib' VALUES (15256, '2022-11-21 15:01:12.306455+00', '2022-11-21 15:05:50.831777+00', 21168, 1, 202, 'ace', '1--::

  1c turn RH ; turn LH (1,2,3)

9--::

  1c+2c RHA ; LHA. 1M faces out

17--::

  1c (1M leading) cast off | cross to 2plx (2c up) ; cast off | cross to 3pl (3c up) (2,3,1)

25--::

  1c dance to top, 1W up the middle, 1M behind M line ; 1c cast off and dance to 3pl, 1W behind W line, 1M down the middle  (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (14969, '2022-07-24 23:35:46.276896+00', '2022-07-24 23:35:55.90731+00', 20959, 1, 1645, 'ace', '1--::

  1c cross LH | cast off (2c up) ; &frac12; Fig8 LSh round 3cnrs (M up, W down) & pass LSh to face 1cnrs on diagonal

9--::

  1c+1cnrs Set to Corners and Cast Away{4}: 1c end in 3cnr positions, 1cnrs twirl to end BtoB facing P on 2nd diagonal ;

  2M+3W (original 1cnrs) Pass and Twirl with P: 2M & 3W pass P RSh & twirl to end BtoB on 1st diagonal facing own 1cnr pos _while{4}_

  2W+3M (2cnrs) &frac12; turn RH & twirl away to opposite corner

17--::

  2M+3W (original 1cnrs) repeat [9-16], corners end as at bar 9, 1c twirl to end BtoB facing 1cnrs again

25--::

  1c turn 1cnrs RH | pass RSh (corners dance 4 bars) ; 1c turn 2cnrs RH | pass RSh to own side (2,1,3)

33--::

  Circle6 to L & pivot ; chase back cclw (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (15375, '2023-01-10 23:03:53.655006+00', '2023-01-12 16:58:21.996054+00', 21279, 1, 1645, 'ace', '1--::
  2c followed by 1c lead down, cross below 4pl, cast up to the top & cross RH (2,1,3,4)
9--::
  3c followed by 4c lead up, cross above 1pl, cast off to the bottom & cross RH (2,1,4,3)
17--::
  1c+4c S&Link (2,4,1,3) ; 2c+4c & 1c+3c Circle4 to L & open out to form one circle
25--::
  Circle8 to L ; pivot & chase back (2,4,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (5929, '2013-08-21 08:31:16.939567+00', '2023-02-04 01:20:44.319294+00', 3393, 3, NULL, 'ace', '1-8::
    1s set, cross RH, set & cast 1 place (2s step up 7-8)
9-16::
    1M+2s also 1L+3s dance RH across & LH back. 1s end facing 2nd
    corners
17-20::
    1s set 1/2 HS (to right) & turn 2nd corners LH to end between
    corners & facing 1st corners
21-24::
    1s set 1/2 HS (to left) & turn corner RH to end in middle in 2nd
    place, BtoB facing opp sides side
25-32::
    1s circle 3H round to left with 2nd & 1st corners (2 bars), all
    turning into place (1s between corners); 1s turn 2H 1.1/2 times to
    2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (14972, '2022-07-30 11:23:39.27646+00', '2022-08-15 11:51:51.421746+00', 19602, 1, 1645, 'ace', '1--::

  1c set | cast off (2c up) ; 2c+1c Circle4 to L, retain NH facing down/up (2,1,3)

9--::

  *Hand-in-hand Reel of 3:* 2c, 1c & 3c, all NHJ dance Reel3 on centre line, 1c start RSh to 2c.

    At each end couples release hands, turn singly & rejoin hands, always nearer own side



17--::

  1c, 1M leading, cast up round 2M, cross, cast off round 2W & cross.

  1c end facing down in LH allemande hold, 3c step in to normal RH allemande hold facing up

25--::

  *Keppoch:* 3c & 1c A&R{1+1} diagonally R with modified PdB | pass LSh to end BtoB & release front hand ;

  1c/3c turn P LH/RH (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (7651, '2013-08-21 08:31:46.107706+00', '2023-02-04 01:22:54.299774+00', 6637, 3, NULL, 'ace', '1-4::
    1s 1/2 turn RH to face down in prom hold & dance down to 3rd place
    _while_ 2s & 3s set & cast up 1 place
5-8::
    1s cross LH to 3rd place own side & cast up to 2nd pl _while_ 2s 1/2
    turn RH to face down in prom hold & dance down to 3rd pl as 3s set &
    cast up 1 pl
9-12::
    1s set & cast to top _while_ 2s cross LH to 3rd place own side &
    cast up to 2nd pl as 3s 1/2 turn RH to face down in prom hold &
    dance down to 3rd pl
13-16::
    1s 1/2 turn RH to face 2M (in top place) _while_ 2s set & cast up to
    1st place as 3s cross LH to 3rd place & set
17-24::
    1s (in prom hold) dance diagonal RSh reel of 3 with 1st corners &
    end facing 3M
25-32::
    1s dance 1/2 diag LSh reel of 3 with 2nd corners & on bar 29 1s lead
    up & cast to 2nd place own sides as corners continue reel.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13016, '2020-08-07 04:06:23.297381+00', '2022-11-20 16:27:03.044182+00', 4768, 1, 202, 'ace', '1--::

  ½ Reels3 on sides, 1c in and down ; ½ Reel3 on opposite sides, 1c crossing up (1x,2,3,4)

9--::

  1c cross RH | cast off (2c up) ; 1c cross LH | dance RSh round 1cnrs into facing lines3 across

17--::

  All set H.Schottische ; all turn opposite person BH, 1c dancing to 2pl (2,1,3,4)

25--::

  1c lead down, separate between 3c & 4c to 4pl (3c+4c up) ; 3c, 4c & 1c turn P RH (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (14235, '2021-08-14 00:22:27.916174+00', '2023-02-04 01:23:08.12602+00', 7000, 3, NULL, 'ace', '1-8::
    2s+4s dance Petronella to opposite side (Petronella turn & set
    twice). 1 (2) 3 (4)
9-16::
    1s+2s also 3s+4s dance Ladies'' Chain
17-20::
    2s+4s dance 1/2 Fig 8 round couples above them. 1 2 3 4
21-24::
    2s+3s dance DoSiDo with partners
25-30::
    1s dance chain on own sides to 4th place giving LH on Ladies'' side &
    RH on Men''s side to begin, ending with polite turns
31-32::
    All set.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7923, '2013-08-21 08:31:51.329918+00', '2023-02-04 01:23:12.05748+00', 7105, 3, NULL, 'ace', '1-8::
    1s set, dance in & cast to 2nd place, set to each other _while_
    advancing to 1st corners
9-16::
    1s dance 1/2 reel of 4 with 1st corners, pass by RSh to dance 1/2
    reel with 2nd corners. 1s end in centre BtoB, 1M facing up, 1L
    facing down
17-24::
    3s+1s+2s dance Double Triangles facing up & down, 1s ending in 2nd
    place on own sides
25-32::
    1s dance Diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (7984, '2013-08-21 08:31:54.010154+00', '2023-02-04 01:23:14.920122+00', 10242, 3, NULL, 'ace', '1-8::
    1L followed by 1M cast 1 place, cross below 2s (2s step up), dance
    down behind 3M & up the middle to face 2L (1L leading)
9-16::
    1s+2L dance RH across then cross diagonally down to face 3M, dance
    LH across with 3M & 1s end in 2nd place opposite sides facing out
17-24::
    1s dance out & up into reflection (mirror) reels of 3 on sides & 1s
    end facing 1st corners
25-32::
    1s turn 1st corners RH & pass RSh in middle, 1s turn 2nd corners RH
    & pass RSh to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (12706, '2020-04-07 23:11:39.307186+00', '2020-04-07 23:17:39.321879+00', 19724, 1, 202, 'ace', '1--::

  1c+2c set | cross RSh ; repeat (1,2)

9--::

  1c+2c Circle4 L to sides ; RHA. On [15], 1c & 2c take P RH and M turn P under joined arms into allemande hold facing up

17--::

  2C Allemande (2,1)

25--::

  DblFig8, 1c crossing up (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (15258, '2022-11-21 19:17:31.611333+00', '2022-11-22 09:57:06.74777+00', 21170, 2, 10819, 'ace', '1-4:: 1C+2C set and dance first turn of Tourbillon (1C to ladies'' side, 2C to men''s side).

5-8:: 1C+2C RA stay facing clw _while_ 3C TB, lady twirl to face on side, followed by partner.

9-16:: Diagonal Reel of three, all couples in tandem; 1C LS to 3C, to finish in places as on bar 4.

17-24:: Set and link for three, twice.

25-28:: 1C+2C RA, finish facing partner on sideline.

29-30:: 1C+2C dance second turn of Tourbillon (1C into 2nd plc, 2C into 3rd place) _while_ 3C 1/2 TB to own side.

31-32:: All set.', 3);
INSERT INTO 'dancecrib' VALUES (14973, '2022-07-30 11:32:26.461013+00', '2022-07-30 11:32:39.595652+00', 19584, 1, 1645, 'ace', '1--::

  1c set | turn BH ; cast off (2c up) | turn BH & face up NHJ, 2c & 3c step in to face down/up NHJ (2,1,3)

9--::

  *Hand-in-hand Reel of 3:* 2c, 1c & 3c, all NHJ dance Reel3 on centre line, 1c start RSh to 2c.

  At each end couples release hands, turn singly & rejoin hands, always nearer own side

17--::

  2c+1c RHA ; 1c+3c LHA, 1c end facing down in LH allemande hold, 3c face up in normal RH allemande hold

25--::

  *Keppoch:* 3c & 1c 1 bar of Glasgow Highlanders then 1 bar travelling diag R | repeat L, passing other couple LSh & end BtoB ;

  1c/3c turn P LH/RH (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (1692, '2012-01-22 19:28:56.924012+00', '2022-07-30 16:44:21.824839+00', 292, 1, NULL, 'ace', '1–::

  1c set | cast (2c up) ; 1c, advancing, set to 1cnr | turn cnr BH

9–::

  1c+1cnrs Circle4 L, finish in lines across ; 1c, advancing, set to 2cnr | turn 2cnr BH

17–::

  1c+2cnrs Circle4 L to (2,1x,3) ; 1c set | turn BH to face up, W on L

25–::

  Mirror Reels3{6} with cnrs | 1c cross to (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15257, '2022-11-21 19:07:42.194587+00', '2022-11-22 09:59:53.43019+00', 21167, 2, 10819, 'ace', '1-4:: 1C+3C eight slip steps to opp side _while_ 2C+4C four slip steps to the left, four slip steps to the right, finish in center, 2C facing down, 4C facing up

5-8:: 1C+3C 1/2 chase back home _while_ 2C+4C LA

9-16:: "Choochoo reels" half way: 1C+3C always in tandem dance into the center (men in the lead), couples pass LS in the center, dance out to opp sides, all set (no hands, stay facing clw) _while_ 2C+4C in tandem dance out to sides (ladies in the lead), all set (no hands, stay facing clw), dance into the center and pass LS in the center, finish facing out.

17-18:: 1C+2C and 3C+4C all pass opp person RS.

19-20:: 1C+3C pass opp person LS in the center and pull back LS _while_ 2C+4C chase 1plc clw.

21-24:: 1C+3C LA _while_ 2C+4C 1/2 chase.

25-32:: Repeat "Choochoo reels" half way across the dance: 2C, 3L+1M, 1L+3M, 2C (ladies lead from the center), center cpls finish facing out.

33-40:: 1C+3C set (second step to finish side by side with partner), set to opp person, link with partner (no hands), dance out to next side place clw _while_ 2C+4C set, link with partner (no hands), 1/2 TR, then chase to next side place clw (to 4, 1, 2, 3)', 3);
INSERT INTO 'dancecrib' VALUES (2665, '2012-01-22 19:29:52.221146+00', '2022-07-31 19:28:16.581444+00', 3775, 1, NULL, 'ace', '1–::

  1c cross RH, cast off (2c up) ; 1c+3c ½RHA (2,3x,1)

9–::

  1c set twice ; 3c+1c ½R&L, to face 1cnr

17–::

  1c set to and turn corners

25–::

  Reels3{6} on the sides | 1c cross to 2pl own side', 2);
INSERT INTO 'dancecrib' VALUES (12707, '2020-04-07 23:30:59.123651+00', '2020-04-07 23:35:04.150739+00', 19723, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; ½ Fig8 up round 2c (2,1x,3)

9--::

  1c lead down {3}, lead up {3} | turn P RH ¾ into midline, pulling RSh back to face up/down

17--::

  6 bars of DTr up/down | 1c turn 4cnrs RH to 2pl. 4cnrs face out (2,1,3)

25--::

  Reels3 on sides, 1c LSh to 3cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12796, '2020-05-05 15:12:54.022297+00', '2022-07-31 20:36:47.935068+00', 19198, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; ½ Fig8 up round 2c (2,1x,3)

9--::

  1c set | ½ Fig8 down round 3c (to 2,1,3) ; set advancing to face 1cnrs

17--::

  Corners Pass and Turn on 1diag, pass RSh ; repeat on 2diag (2,1,3)

25--::

  Repeat [17-24] with 3cnrs then 4cnrs (2,1,3)

33--::

  1c set | cast off (3c up) (to 2,3,1) : 1c turn P RH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (15205, '2022-11-02 12:58:00.592772+00', '2022-11-02 12:59:54.977973+00', 20142, 1, 202, 'ace', '1--::

  1c Fig8 on sides, in and down (1,2)

9--::

  1c+2c RHA ; LHA (1,2)

17--::

  1c (2c following) lead down ; 2c (1c following) lead up. Remain in centre (2,1)

25--::

  2c+1c Promenade (2,1)



*Deviser''s note* : in a 2/4L, on [1-8] 1c dance a figure of 8 down round 2c.', 2);
INSERT INTO 'dancecrib' VALUES (14977, '2022-08-01 21:09:30.148857+00', '2022-08-01 21:14:07.515337+00', 9440, 1, 202, 'ace', '1--::
  1W+2M turn RH ; chase clw ½ to exchanged places _while{8}_ 1M+2W chase clw ½ to exchanged places ; turn RH (2x,1x)
9--::
  2c+1c chase clw ½ ; RHA (1,2)
17--::
  1c lead down {3}, lead up {3} | cast off (2c up) (2,1)
25--::
  1c Fig8 up round 2c (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (14974, '2022-07-30 22:59:26.566841+00', '2022-08-01 21:08:20.390157+00', 20964, 1, 1645, 'ace', '1-::
  1c & 4c set adv | turn BH ; cast inwards (2c & 3c out) | cross RH & face out (2,1x,4x,3)
9-::
  1c+4c alternating tandem RSh Reels3 on opp sides with 2c & 3c (2,1x,4x,3)
17-::
  1c+4c RHA ; cast & chase &frac12; way cclw (2,4,1,3)
25-::
  All allemande turn RH with P & stay in centre | set ; cast away to own side | set (2,4,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (14976, '2022-08-01 20:38:09.975006+00', '2022-08-01 20:44:07.261339+00', 16932, 1, 202, 'ace', '1--::

  1c set | turn RH ¾ ; 1c (1W leading) cast round 2W | cross to 2plx (2c up) (2,1x,3)

9--::

  ½ Parallel Reels3 on sides, 1c LSh to 3c (to 3,1x,2) ; 1c (1W leading) dance RSh round 3M and down the middle to finish 1W between 2c and 1M between 3c

17--::

  ½ Parallel Reels3 across, 1W LSh to 2W, 1M LSh to 3W ; 1c (1W leading) dance RSh round 2W to 2pl (3x,1,2x)

25--::

  3c & 2c cross RH _while_ 1c pivot R (2 PdB to face clw | all chase clw ¼ ; all cross RH | chase clw ¼ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14975, '2022-08-01 17:57:42.427225+00', '2022-08-02 07:58:14.566769+00', 9442, 1, 202, 'ace', '1--::
  1c set advancing into BtoB position | turn 2c EH ½ on sides (to 2,1x,3x) ; repeat [1-2] | turn 3c EH ½ on sides. 3c face out (2,3,1)
9--::
  Mirror Reels3 on sides, 3c out and down. 3c continue the reel to 3pl _while_ 1c cross fo face 1cnrs
17--::
  Corners Pass and Turn (2,1,3)
25--::
  Circle6 L ; on [5] dance into centre swiveling R to spiral out clw to sides (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14979, '2022-08-02 07:51:04.70723+00', '2022-08-02 07:56:27.844505+00', 9438, 1, 202, 'ace', '1-4::

  1c cross RH | cast off (2c up) (2,1x,3)

5-12::

  Mirror Reels3 on sides, 1c in and down, 3c out and up (2,1x,3)

13-16::

  1c ½ Fig8 down round 3c and face 1cnrs

17--::

  ½ Reel4 on 1diag, pass P RSh ; ½ Reel4 on 2diag (3x,1x,2x)

25--::

  ½ Reels3 on sides, 1c LSh to 1cnrs[pos] (to 2x,1x,3x) ; ½ Reels3 across, 1c RSh to 4cnrs[pos] (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12795, '2020-05-05 13:40:28.695523+00', '2022-07-31 20:41:30.541214+00', 19197, 1, 202, 'ace', '1--::

  1c & 3c set | cast off (2c & 4c up) ; ½ Fig8 up round 2c/4c (2,1x,4,3x,5)

9--::

  1c & 3c set | ½ Fig8 down round 4c/5c (to 2,1,4,3,5) ; set advancing to face 1cnrs

17--::

  Parallel Corners Pass and Turn on 1diag, pass RSh ; repeat on 2diag (2,1,4,3,5)

25--::

  Repeat [17-24] with 3cnrs then 4cnrs (2,1,4,3,5)

33--::

  1c & 3c set | cast off (4c & 5c up) (to 2,4,1,5,3) : 1c & 3c turn P RH (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (12708, '2020-04-08 00:08:36.837456+00', '2021-04-07 11:44:08.681184+00', 19935, 1, 202, 'ace', '1--::

  1c turn P RH ½ | lead down (2c up on [3-4]) and cast up round 3c to 2plx | all set advancing into promhold,  2c & 3c facing up, 1c facing down

9--::

  Circulating Allemande. On [23-24] 1c pull RSh back (PdB) BtoB facing 2cnrs[pos]

17--::

  *Modified Turn CPCP* : same as Turn CPCP except start with RH to 2cnrs[pos]. On [23-24] 1c turn P LH to face 1cnrs[pos]

25--::

  1c dance LSh round 1cnrs[pos] _while{4}_ cnrs set advancing diagonally | ½ RHA to sides ; all cross RH | all set (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3901, '2013-08-21 08:30:38.781305+00', '2021-02-04 01:18:18.841521+00', 14365, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s cross down & dance reflection reels of 3 on opposite sides
17-24::
    1s cross down & dance reflection reels of 3 on own sides
25-32::
    1s set & cast down to 4th place & 2s+3s+4s step up on bars 27-28, 1s
    cross up & face up between 2nd & 3rd places
33-40::
    1M dances RH across with 3L+4L as 1L dances LH across with 3M+4M, 1s
    cross & cast to 4th places own sides
41-48::
    1s cross up & dance reels of 3 on opposite sides with 3s+4s (dancing
    up round 3s to start)
49-56::
    1s cross up & dance reels of 3 on own sides with 3s+4s (dancing up
    round 3s to start)
57-64::
    4s+1s dance 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12897, '2020-06-24 12:50:46.03914+00', '2022-11-22 10:01:50.724386+00', 20032, 2, 10819, 'ace', '1-4:: All petronella turn, set to partner (star formation: ladies back to back in the center, men on the outside, all facing partner).

5-12:: Double Reels of 4 (with 1/2 LA in the middle), to finish in star formation as on bar 4.

13-16:: All set to partner, then petronella turn back to sidelines into partners‘ places, facing own partner again.



17-32:: „Mystic Knot“: On bars 1-4, couples in top and bottom places 1/2TB and open up facing in; dance one step in NHJ, and with opp. person dance one step out to side couples‘ places NHJ, finish facing new partner; on bars 5-8, now in side couples‘ places, 1/2 TB and pull RS back to finish back to back and dance 1 place into partners‘ opp. places, facing partner; repeat that movement back to places where the „Mystic Knot“ started from _while_ side couples start the movement with what is described for bars 5-8 and continue the ongoing movement from there.



33-34:: Starting with own partner: chain for two hands, one place on.

35-36:: TR 3/4

37-40:: Ladies 1/2 chase clw round set _while_ men LA (to 4 1 2 3), to face own partner, ready to start the next repeat. The first two repeats are in Strathspey time, the last two repeats in Reel time.', 5);
INSERT INTO 'dancecrib' VALUES (15376, '2023-01-12 18:40:50.652807+00', '2023-01-12 18:41:02.96921+00', 5997, 1, 1645, 'ace', '1--::

  1c set | cross RH ; cast off (2c up) | petronella to 1W between 3c, 1M between 2c, all facing up/down

9--::

  *Eddy:* All adv{2} up/down | ret{1} & set L ;

  2c & 3c dance RSh round opposite to same places _while{4}_ 1c dance RSh 1&frac14; round P to opp sides (2,1x,3)

17--::

  Repeat Eddy across the set, all dancing RSh round P & end 1W between 2c, 1M between 3c facing down/up

25--::

  1c set | petronella to opp side ; set | cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14980, '2022-08-03 13:15:37.653675+00', '2022-08-03 13:48:02.341318+00', 20965, 1, 202, 'ace', '1--::
  Circle8 and back (1,2,3,4)
9--::
  1c lead down ; lead up to 2pl (2c up on [11-12]) (2,1,3,4)
17--::
  1c set twice ; turn RH (2,1,3,4)
25--::
  2c+1c R&L (2,1,3,4)

*Deviser''s note* : 
On 2nd, 4th, 6th and 8th repetition, 1st couple start from second place and end in third place. Accordingly, on bars 25-32, 2nd couple in second place and 1st couple in third place dance rights and lefts.  
On 3rd, 5th and 7th repetition, on bars 1-8, previous 1st couple, starting from third place, dance eight hands round and back. Then new 3rd couple in fourth place step up while previous 1st couple step down behind them.', 2);
INSERT INTO 'dancecrib' VALUES (9872, '2017-05-21 14:32:04.624629+00', '2022-08-03 20:09:00.14152+00', 17754, 1, 1645, 'ace', '1-:: 

  1c lead down below 3c, cross & cast up to 2plx ; 1c cross RH | cast R to 1M/1W between 2c/3c

9-:: 

  1c turn &frac34; LH | turn 1cnr &frac34; RH to lines across facing 4cnr with 1W+2M in promhold (1W on L) ; 1c loop LSh round 4cnrs to same pl, 1W releasing promhold _while{4}_ 4cnrs pass 1c LSh into centre | turn LH to pl

17-::

  Repeat 9-16 inverted with 2cnrs: 1c turn &frac34; RH | turn 2cnr &frac34; LH to lines across facing 3cnr with 3M+1W in promhold (1W on R) ; 1c loop RSh round 3cnrs to same pl, 1W releasing promhold _while{4}_ 3cnrs pass 1c RSh into centre | turn RH to pl

25-::

  All &frac12; chase clw ; 1c turn RH 1&frac14; _while{4}_ cnrs continue chase to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12705, '2020-04-07 01:12:25.083387+00', '2023-01-28 09:22:40.875677+00', 2342, 1, 202, 'ace', '1--::
  1c long cast to 2pl (2c up) ; dance down between 3c, cross and cast up to face 1cnrs (2,1,3)
9--::
  ½ Reel4 on 1diag, turn P BH 1¼ to face 4cnrs ; ½ Reel4 on 2diag, turn P BH into midline BtoB facing 1M(1W) up(down). 2c & 3c face up/down (3x,1,2x)
17--::
  All A&R {1+1} touching hands | All advance {2} and face opposite direction, 1c pulling RSh back and cnrs turning inwards ; repeat [17-20], 1c passing RSh to face 4cnrs[pos] (3x,1,2x)
25--::
  1c+4cnrs[pos] turn RH | 1c RSh Turn 1½ to face 2cnrs[pos] _while{2}_ cnrs chase clw 1 place ; 1c+2cnrs[pos] turn RH | pass RSh to 2pl _while{2}_ cnrs chase clw 1 place (2,1,3)

*Note:  In the 2 bar turns (bars 11 & 12 and bars 15 & 16) the man does not place the lady. They merely drop hands and flow into back to back position*.', 4);
INSERT INTO 'dancecrib' VALUES (7883, '2013-08-21 08:31:50.527696+00', '2023-02-04 01:23:09.524243+00', 12907, 3, NULL, 'ace', '{{explanation}}
5s in centre facing 1s

1-8::
    1s+2s+3s+4s promenade round clockwise as 5s turn RH & turn LH
9-16::
    5s+1s dance RH across, 5L dances RSh round 1M & across to face 3M as
    5M dances RSh round 1L & across to face 3L
17-24::
    5s+3s dance LH across, 5L dances LSh round 3M & round to face 4M as
    5M dances LSh round 3L & round to face 4L
25-32::
    5s dance parallel reels of 3 across with 4s+2s (LSh to 4s to start)
    & end facing 1s
33-40::
    5s dance parallel reels of 3 up/down with 1s+3s (RSh to 1s to start)
    & end facing 4s
41-48::
    5s make an arch & dance out, crossing (5L dancing under 5M arm) into
    4th place as 4s dance under arch curving to right to face 3s. Repeat
    with 3s, 2s & 1s to end with 1s in centre

{{explanation}}
Note:  after bar 8 all the subsequent figures start with 5M facing a Lady, 5L facing a Man', 0);
INSERT INTO 'dancecrib' VALUES (15259, '2022-11-21 19:38:38.246067+00', '2022-12-07 16:44:48.925945+00', 21169, 2, 10819, 'ace', '1-8:: 1C+3C+5C set and link (5C by casting into partner''s place), set facing partner, 1/2 TB and twirl to face clw towards center.

9-16:: 5M+1C and 5L+3C RA and snake pass, 5C finish almost LS to LS in the center _while_ 2C+4C repeat bars 1-8.

17-24:: 5M+2C and 5L+4C RA and snake pass, 5C finish almost LS to LS in the center facing partner (slightly diagonal).

25-28:: Ladies cast one plc anticlw _while_ 5C B2B.

29-40:: "Mixer Chain" two bars per hand: XR with partner; 1L+3M+5M and 1M+3L+5L dance LA two positions on _while_ all others XL; repeat this 4 bar figure two more times to finish facing partner.

41-44:: All XR with partner (5C to finish facing across the set), all set on the sidelines (5C set to partner).

45-46:: 5L+4L and 5M+4M XR, 4C in the center to face partner across the dance.

47-48:: 4C petronella turn to face one another up and down the set.', 3);
INSERT INTO 'dancecrib' VALUES (14981, '2022-08-04 07:55:22.181806+00', '2022-08-04 17:12:44.093199+00', 20571, 1, 202, 'ace', '1--::
  1c+2c RHA ; LHA (1,2,3)
9--::
  1c dance down ; dance up to 2pl (2c up on [11-12]) (2,1,3)
17--::
  Set to Corners (to 2,1,3) ; 1c turn RH 1½ (2,1x,3)
25--::
  Reels3 on opposite sides, 1c RSh to 1cnrs. On [32] 1c pass P LSh to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12709, '2020-04-08 23:46:32.642365+00', '2020-04-08 23:54:35.230106+00', 19936, 1, 202, 'ace', '1--::

  All S&Link. All M face out ; all 4 bars of Schiehallion Reel (2,3,4,1)

9--::

  All »Modified intersecting La-Chain« [: same as La-Chain but all W dance ½ LHA and all M turn W RH] (2,3,4,1)

17--::

  1c & 3c turn P RH ¾ | 1M+3M turn LH 1½ _while{4}_ 1W & 3W chase clw ½ to exchanged places | 3c & 1c turn P RH ¾ (2,1,4,3)

25--::

  2c & 4c turn P LH ¾ | 2W+4W turn RH 1½ _while{4}_ 2M & 4M chase cclw ½ to exchanged places | 4c & 2c turn P LH ¾ (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (15101, '2022-09-19 13:32:26.889089+00', '2022-09-19 13:41:59.605199+00', 8065, 1, 202, 'ace', '1--::

  1c+2c set twice ; 1c & 2c set twice up/down (1,2,3)

9--::

  1c dance down | cast up round 3c ; meet and dance up to top | cast off to 2pl (2c up (2,1,3)

17--::

  1c+3c RHA ; 2c+1c LHA

25--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (14982, '2022-08-04 21:55:54.073011+00', '2022-08-04 21:57:36.703871+00', 4779, 1, 1645, 'ace', '1--::
  1c set | turn RH moving down (2c up) ; &frac12; RSh Reels3 on own sides, 1c cross to 2plx (3,1x,2)
9--::
  1c set | turn RH ; &frac12; RSh Reels3 on opp sides, 1c end in Dtr position (2,1,3)
17--::
  2c+1c+3c DTr, 1c start setting R, 2c+3c start setting L, 1c end on own sides (2,1,3)
25--::
  Circle6 once round | turn P BH (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (2964, '2012-01-22 19:30:04.778564+00', '2022-08-05 16:46:27.103037+00', 9177, 1, NULL, 'ace', '1–::

  1c+2c set | ½RHA ; chase on one place | turn 1¼ RH into line across between 1pos and 2pos, 1M & 2W outside, on own side, facing Ps who are BtoB in the centre.

9–::

  Reel4 across the dance, to same positions

17–::

  1c+2c H.Schottische Poussette, moving short (dn/up) | long (across) ; long (up/dn) | short (NO turn at the end) into P facing P on midline, M below W

25–::

  1c+2c the Knot (starting with a ¾ RH turn) (to 2,1)', 2);
INSERT INTO 'dancecrib' VALUES (14983, '2022-08-05 20:57:33.693203+00', '2022-09-23 18:50:55.909071+00', 20955, 2, 963, 'ace', '1-4::  

  1C cross RH and cast 1 plc  2C up 3&4  2,1x,3  

5-16::  

  R&Ls for 3C - variation - dancers in 2nd crn position set instead of changing LH on the diag  3x,1,2x  

17-24::  

  1C dance two 1/2 R3 across - Lsh to 1st crn then switching to other end Lsh to 3rd crn position.  Finish in 2nd plc own side  3x,1,2x  

25-32::  

  1C dance diag R&Ls twice - lady up, man down  2,1,3', 5);
INSERT INTO 'dancecrib' VALUES (10029, '2017-07-24 03:53:55.07275+00', '2022-08-06 16:22:09.099232+00', 17901, 1, 202, 'ace', '1--::
 1c lead down | cross and cast to 2plx (2c up) ; 1c turn LH 1 1/4 to midline, LSh to LSh, facing own sides
9--::
 1c Teapots R, pass Rsh ; Teapots L (2,1x,3)
17--::
 2c+1c La-Chain, 1M face out at end
25--::
 1M followed by P casts round 3W | crosses to own side ; 1M casts round 3M _while_ 1W dance up to 2pl, *pulling Rsh back* | all set', 2);
INSERT INTO 'dancecrib' VALUES (14984, '2022-08-05 23:24:54.006976+00', '2022-08-07 08:31:02.47657+00', 20968, 1, 202, 'ace', '_Strathspey_

1--::

  1c & 4c long cast inwards (2c & 3c step out on [3-4]) ; 1c & 4c ½ Fig8 round nearest ends (2,1x,4x,3)

9--::

  1c+4c Set&Rotate (2,4x,1x,3)

17--::

  1c turn BH 1½ ; 4c cross down to 3pl _while{4}_ 3c cast up to 2pl (2,3,1,4)

25--::

  3c+1c Poussette (2,3,1,4)



_Reel_

33--::

  1c *Figure of Love* R : 1c ½ Fig8 R, meet P in centre, touch BH and pivot LSh back ½ ; dance LSh round 2cnr[pos] to 3pl. 1c face out (2,3,1,4)

41--::

  3c+1c+4c Chain Progression. 1c face 1cnrs (2,4,1,3)

49--::

  ½ Reel4 on 1diag, pass P LSh ; ½ Reel4 on 2diag. Pass P LSh to face 3cnrs

57--::

  Repeat [49-56] with 3cnrs then 4cnrs (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14985, '2022-08-06 13:29:07.569094+00', '2022-08-07 08:24:44.164291+00', 20966, 1, NULL, 'ace', '1--::

  1c & 4c long cast inwards (2c & 3c step out on [3-4]) ; 1c & 4c ½ Fig8 round nearest ends (2,1x,4x,3)

9--::

  1c+4c Set&Rotate (2,4x,1x,3)

17--::

  1c turn BH 1½ ; 4c cross down to 3pl _while{4}_ 3c cast up to 2pl (2,3,1,4)

25--::

  1c *Figure of Love* R : 1c ½ Fig8 R, meet P in centre, touch BH and pivot LSh back ½ ; dance LSh round 2cnr[pos] to 3pl. 1c face out (2,3,1,4)

33--::

  3c+1c+4c Chain Progression. (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13810, '2021-03-12 05:42:59.129913+00', '2022-08-07 11:01:11.500215+00', 9018, 1, 202, 'ace', '1--::

  1c+2c The Knot. On [7-8] 1c turn LH and face 2W

9--::

  1c NHJ set to 2W (swivel ½ inwards), set to 3M (veer L together), set to 3W (swivel ½ inwards), set to 2M finishing in 2pl centre NHJ facing up

17--::

  Mirror Reels3 on sides giving hands when possible, 1c up between 2c, 3c out and up, 2c & 3c loop to places (2,1,3)

25--::

  Circle6 L {3}, cross R foot over and pivot L ; chase cclw (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2339, '2012-01-22 19:29:32.146408+00', '2022-11-01 19:26:18.556568+00', 6479, 1, NULL, 'ace', '1–::

  1c set adv | slip down BHJ (2c+3c up) ; 2c+3c set _while_{2} 1c set, opening downwards to face out | 1c turn 3c EH on side _while_{2} 2c dance in and cast to face out (2,1,3)

9–::

  Mirror Reels on the sides, 1c dance in and up

17–::

  1c set | turn RH ¾ ; 2c+1W & 1M+3c LHA (2,1x,3)

25–::

  1c set | turn RH ¾ ; 2c+1M & 1W+3c LHA (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (15377, '2023-01-14 09:37:10.322619+00', '2023-01-18 08:18:41.421597+00', 13547, 1, 202, 'ace', '1--::

  8 bars of Schiehallion Reels6 (3,1,2)

9--::

  3c+1c ½ M-Chain ; (3W+1M)+2C ½ M-Chain

17--::

  All W Petronella turn to next W place on R | all set ; repeat [17-20] (2,3,1)

25--::

  Circle6 and back  



*repeat 2 times more in Strathspey time, 3 times in Reel time.*', 2);
INSERT INTO 'dancecrib' VALUES (14305, '2021-09-09 08:29:03.016155+00', '2022-07-21 16:24:09.752185+00', 10079, 1, 1645, 'ace', '1-::

  1c+2c Petronella in Tandem (SkipCh) | set facing up/down ; change pl LH with P | chase &frac14; cclw (2,1,3)

9-::

  &frac12; Reels3 across, 1c start LSh to 1cnr ; 1c turn LH to face 1cnr[pos]

17-::

  1c+1cnrs Corners Pass & Twirl, 1c pass RSh to face 2cnrs ; repeat with 2cnrs, 1c end facing P just in from opp side (3x,1x,2x)

25-::

  1c set | turn &frac34; LH _while{4}_ corners &frac12; turn RH on sides | cast away ; 2c+1W & 1M+3c RHA (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (14986, '2022-08-06 13:31:14.429057+00', '2022-08-07 08:32:31.810894+00', 20967, 1, NULL, 'ace', '1--::

  1c & 4c long cast inwards (2c & 3c step out on [3-4]) ; 1c & 4c ½ Fig8 round nearest ends (2,1x,4x,3)

9--::

  1c+4c Set&Rotate (2,4x,1x,3)

17--::

  1c turn BH 1½ ; 4c cross down to 3pl _while{4}_ 3c cast up to 2pl (2,3,1,4)

25--::

  1c *Figure of Love* R : 1c ½ Fig8 R, meet P in centre, touch BH and pivot LSh back ½ ; dance LSh round 2cnr[pos] to 3pl. 1c face out (2,3,1,4)

33--::

  3c+1c+4c Chain Progression. (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12710, '2020-04-09 00:18:44.78738+00', '2020-04-09 00:24:04.547059+00', 19940, 1, 202, 'ace', '1--::

  1c lead down | lead up ; cast to 4pl BHJ (2c+3c+4c up on [5-6]) (2,3,4,1)

9-20::

  2c+3c+4c 3C R&L _as_ 1c retire on [9-10] (2,3,4,1)

21-24::

  2c & 3c & 4c turn P RH. 3c face out (2,3,4,1)

25--::

  2c+3c+4c Reels3 on sides, 3c RSh to 2M/4W (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (14622, '2022-02-22 17:56:21.505338+00', '2022-08-14 09:43:55.205538+00', 20670, 1, 202, 'ace', '1--::
  1c set | lead down and cross round 2c to 1plx ; turn P RH into promhold in 1pl centre facing 2M
9--::
  1c in promhold + 2c Reel3 across, 1c RSh to 2M. 2c finish in 1pl. 1c in 2pl centre face 3M
17--::
  Repeat with 3c. 1c finish in 2pl centre facing opposite sides, LSh to P
25--::
  2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA (2,1,3)
33--::
  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10456, '2018-02-24 13:31:52.160747+00', '2023-01-14 11:58:47.470726+00', 18246, 2, 1645, 'ace', '1--::
  1c dance down below 3c | cast up to 2pl (2c up) ; turn 1&frac14; RH
9--::
  2c+1M & 1W+3c LHA, 1c pass LSh ; 2c+1W & 1M+3c RHA, 1c end facing 1cnrs
17--::
  1c & 1cnrs dance diagonal RSh Reel4, 1c end passing RSh to opp sides (2,1x,3)
25--::
  All chase &frac12; way clw ; 2c & 3c continue chase _while{4}_ 1c turn RH (2,1,3)
', 3);
INSERT INTO 'dancecrib' VALUES (4054, '2013-08-21 08:30:42.763698+00', '2023-02-04 01:18:30.324333+00', 9839, 3, NULL, 'ace', '1-8::
    1M+2L cross RH, 1L+2M cross RH, 2s+1s turn RH
9-16::
    1M+2L cross LH, 1L+2M cross LH, 1s+2s turn LH
17-24::
    1s lead down the middle & back to 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7846, '2013-08-21 08:31:49.663117+00', '2023-02-04 01:23:05.978104+00', 6961, 3, NULL, 'ace', '{{explanation}}
Start:  Glasgow Highlanders positions - 1s & 3s on Men''s side, 2s & 4s on Ladies'' side, men with partner on right

1-8::
    1M+2M also 3M+4M 3/4 turn RH & dance RSh round partner to place,
    Ladies repeat turning LH & dance LSh round partner
9-16::
    1s+2s also 3s+4s dance Western DoSiDo :
::
    _9-10_   Men set _while_ Ladies dance in, Ladies pass each other LSh
    & turn to face partner
::
    _11-12_ Change places LH with partner
::
    _13-14_ Men change places with opposite Lady RH, Men pass LSh
    _while_ Lady dances to partner''s place
::
    _15-16_ Turn partner RH to end in promenade hold
17-20::
    1s & 4s change places -  1s pass 2s RSh, dance down Ladies side
    _while_ 4s pass 3s RSh, dance up Men''s side.  2s dance in, curve to
    Right & dance back to place, 3s dance similar
21-24::
    2s+4s also 1s+3s dance RH across, finish on sides facing partner
25-28::
    All set to partners & change places RH
29-32::
    RSh 1/2 reels of 4 on sides (3s & 4s on Men''s side, 1s & 2s on
    Ladies side), passing partner RSh to start.  All now 1 place
    clockwise round from start position', 0);
INSERT INTO 'dancecrib' VALUES (7847, '2013-08-21 08:31:49.762294+00', '2023-02-04 01:23:06.17243+00', 6962, 3, NULL, 'ace', '1‑8::
    1s set, cast 1 place, dance down between 3s, cast up & pass LSh to
    face 1st corners
9‑16::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh & dance RH
    across (1L with 2M+3M & 1M with 2L+3L) ending in middle 2nd pl opp
    sides
17‑24::
    1s set, 3/4 turn RH to face 2nd corners & dance 1/2 reel of 4 with
    2nd corners end passing RSh for…
25‑32::
    1s dance LH across (1L with 3s at top & 1M with 2s) end 2nd pl opp
    sides, 1s set advancing & 1/2 turn 2H _while_ 3s+2s dance 1/2 R&L
    (change places on sides to start)', 0);
INSERT INTO 'dancecrib' VALUES (13935, '2021-04-05 18:56:06.166286+00', '2022-09-23 20:01:51.646928+00', 20298, 1, 202, 'ace', '1--::

  1c+2c The Espagnole up/down, 1c crossing down RH. On [5-8] 1c+2c turn EH 1½ (2x,1x,3)

9--::

  1c+3c The Espagnole up/down, 3c crossing up LH. On [13-16] 1c+3c turn EH (2x,1,3x)

17--::

  Reels3 on sides, 1c RSh to 3cnrs[pos]. On [23-24] 1c cross up to 2plx (2x,1x,3x)

25--::

  2c & 3c Petronella turn to midline | set to P ; Petronella turn to sides | set _while{8}_ 1c chase cclw ½ LSh round 2cnrs[pos], between 2c/3c (setting) to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15102, '2022-09-19 14:00:40.826929+00', '2022-09-20 11:58:43.015083+00', 21109, 1, 202, 'ace', '1--::
  1c Mirror Fig8 on sides starting in (1,2,3)
9--::
  1c dance down | cast up round 3c ; meet and dance up to top | cast off to 2pl (2c up) (2,1,3)
17--::
  2c+1c LHA ; 1c+3c RHA (2,1,3)
25--::
  Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14978, '2022-08-01 21:15:21.780579+00', '2022-09-23 18:58:12.908336+00', 20954, 2, 963, 'ace', '1-8::  

  MEANWHILE FIGURE - 1C & 3C pass opp Rsh, face 90 degrees right and, women leading, dance out, 1C to 4th plc, 3C to 2nd plc and face cw. 1C & 3C dance one plc cw and set WHILE 2C & 4C set swivelling to face cw and, men leading, chase cw one plc, dance in to pass opp Rsh, face 90 degrees right and, women leading, dance out (all in orig plc but women on men''s left)  

9-16::  

  HALF CHAIN AND TURN -  All 4 men RHA 1/2 and turn opp woman LH, rpt (ladies chain dancing reversed roles)    

17-24::

  ALL FOUR COUPLES - adv for 2, turn away from prtn to meet crn, dance back to sidelines and face prtn.  Turn prtn RH and face in (women still on the left)  

25-32::  

  SET AND ROTATE FOR 4C IN A SQ SET - All taking hands with prtn, set.  Men cast into their prtn''s spot as women cast one plc cw to next position and face back from whence they came.  All change plc RH with prtn ending between the sq positions and face cw.  All chase cw to progressed places 4,12,3,

  ', 5);
INSERT INTO 'dancecrib' VALUES (15260, '2022-11-23 10:13:35.879067+00', '2022-11-23 10:13:44.157391+00', 21171, 1, 1645, 'ace', '*Start in big circle with partner, men inside facing out to women*

1--::

  Turn P RH ; dance BtoB with P starting RSh

9--::

  Turn P BH, end in promhold facing cclw ; promenade cclw & turn towards P to face clw

17--::

  Promenade clw ; turn P BH (cclw)

25--::

  Dance BtoB with P starting LSh ; turn P LH & face diagonally R to repeat with new partner

', 2);
INSERT INTO 'dancecrib' VALUES (15261, '2022-11-23 15:05:33.344126+00', '2022-11-23 15:06:22.3845+00', 19115, 1, 202, 'ace', '1--::

  1c dance down ; and back. 1M faces out

9--::

  Parallel Reels3 on sides, 1c LSh to 2c

17--::

  1c+2c ½ LHA (to 2x,1x,3,4) | 1c+3c ½ RHA (to 2x,3x,1,4) ; 1c+4c ½ LHA (to 2x,3x,4x,1x) | all cross RH

25--::

  Circle8 and back (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (15103, '2022-09-19 14:39:53.165098+00', '2022-10-14 22:17:00.568194+00', 8046, 1, 202, 'ace', '*Couple facing couple RR, 1c facing clw*

1--::

  All W Fig8 round 1M & 2M passing opposite M RSh

9--::

  All M Fig8 round 1W & 2W passing opposite W LSh

17--::

  2M+1W lead out between P cross and cast back to exchanged places ; 1M+2W lead to centre between P and cast back to exchanged places

25--::

  All RHA ; all turn opposite personn RH. On [31] all face original direction (1c clw), on [32] all dance toward new couple', 2);
INSERT INTO 'dancecrib' VALUES (14998, '2022-08-11 18:57:52.608544+00', '2022-08-11 18:58:34.797925+00', 20969, 1, 202, 'ace', '1--::

  1c+2c Set(diagonally)&Rotate (2,1,3)

9--::

  1c lead down | turn P RH ½ (2c up) ; lead up | turn P RH to face 1cnrs

17--::

  SetH&G (2,1,3)

25--::

  All A&R ; all turn P RH (or Birl) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12711, '2020-04-10 06:03:33.851677+00', '2020-04-10 06:05:34.4375+00', 19793, 1, 202, 'ace', '1--::
  1c+2c Circle4 and back
9--::
  1c set | cross down RH through 2c ; cast up to 1plx | cross RH. 1c face out  
  _while{8}_ 2c stand still {2} | set ; cross down RH through 3c | cast up to 2plx  
  _while{8}_ 3c stand still {4} ; set | cross RH. 3c face out (1,2x,3x)
17--::
  Mirror Reels3 on sides, taking hands when possible, 1c out and down, 2c in and up. Cnrs loop to places (1,2x,3x)
25--::
  1c+2c set | ½ RHA ; 1c+3c set | 1c & 3c cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14991, '2022-08-10 22:26:10.493854+00', '2022-08-10 23:28:32.259924+00', 20970, 2, 35920, 'ace', '1–8::

  1s & 2s Set, ½ turn R and RA

9–16::

  1s & 2s Set, ½ turn L and LA, finishing with M1 facing out, L1 behind him

17–24::

  with 1s dancing in tandem Reel of 3 (Lsh to 2nd M ) across the dance changing the lead at the turn of the reel - finish in original places

25–32::

  1s Set & cast 1 place, TR', 5);
INSERT INTO 'dancecrib' VALUES (14992, '2022-08-10 22:28:13.253508+00', '2022-08-11 10:20:11.175262+00', 20971, 2, 35920, 'ace', '_Strathspey_

1-8::

  1s Set, cast to 2nd place (2s step up on 3&4), 1s turn both hands twice, finish facing up in centre

9-16::

  1s dance up, cross, cast behind 2s, dancing down between 3s, 1s turn 3s 1½ times nearer hand (L on Ladies side & R on Men''s) finish in 3rd pl. (opp side) 23(1)

17-24::

  2s, 3s & 1s Grand Chain. 1s (in 3 rd place opp side) cross Right to start while 2s & 3s change RH on the sides

25-32::

  3s & 1s Diamond Poussette 23(1) (1s finish on opp sides)



_Reel_

33-40:: 

 Next ''1s'' set, cast to 2nd place (2s step up). 1s turn RH finish facing up in the centre (or birl)

41-48:: 

 1s lead up, cross, cast behind 2s, dance down between 3s, turn 3s 1½ times with nearer hand (L on Ladies'' side & R on Men''s) to finish in 3rd pl.(opp side) 23(1)

49-56:: 

 2s, 3s & 1s Grand Chain. 1 s (in 3 rd place opp side) cross RH to start while 2s & 3s change RH on the sides

57-64::

  All Circle to left & back (1s finish on opp sides) 23(1)



*Deviser''s note* : As dance progresses, original 1st couple lead in Strathspey, original 2s in Reel & original 3s in Strathspey time, each couple finish on opp sides after 32 bars as the medley continues each couple leads the dance in the other timing & finally return to their original sides of the set.', 5);
INSERT INTO 'dancecrib' VALUES (10251, '2017-11-12 01:21:15.697738+00', '2023-01-14 12:09:28.393385+00', 18053, 1, 1645, 'ace', '1--::

  1c & 3c set | cast (2c & 4c up) ;

  1c & 3c turn LH to face 1st cnrs _while_{4} 2c & 4c & 5c set pulling RSh back | dance to next cnr pos clw

9--::

  1c & 3c &frac12; RSh Reels4 on 1diag & end facing P ; 1c & 3c turn P &frac34; LH | &frac12; turn 2nd cnrs RH into centre

17--::

  Repeat [9-16] on 2diag from new places

25--::

  &frac12; RSh Reels4 on 1diag ; 4W+1W+3W & 2c+5c & 1M+3M+4M RHA

33--::

  5W+5M & 2M+2W chase clw to 1pl & 5pl _while{4}_ 1W+4W+3W & 3M+4M+1M chase clw to centre (5,4M+3M,1M+3W,1W+4W,2) ;

  5c & 2c turn RH (or birl) _while{4}_ 3c+4c+1c circle 6H &frac34; to L only (5,3,4,1,2)

', 5);
INSERT INTO 'dancecrib' VALUES (14878, '2022-06-20 07:43:48.16407+00', '2022-06-20 07:44:12.067241+00', 2608, 1, 202, 'ace', '1--::

  1c lead down to bottom, cross (2c up on [3-4]) and cast up to 2plx, turn P RH 1¼ to face 4cnrs

9--::

  Reels3 across, 1c RSh to 4cnrs. On [15-16] 1c turn P RH 1¼ to face 4cnrs

17--::

  Reels3 on sides, 1c RSh to 4cnrs. On [23-24] 1c turn P LH 1¼ to midline, LSh to P facing opposite sides

25--::

  2c+1W & 1M+3c RHA, pass P RSh ; 2c+1M & 1W+3c LHA (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11011, '2018-08-19 14:07:28.028098+00', '2022-08-11 13:27:14.982762+00', 104, 1, 202, 'ace', '1--::

  Circle6 and back finishing in centre facing up (1,2,3)

9--::

  3C Allemande (3,2,1)

17--::

  1c dance up | cast round 3c (2c down) ; all A&R (PdB) (3,1,2)

25--::

  3c+2c ¾ R&L _while{6}_ 1c cross RH and turn RH 1½ | all set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15105, '2022-09-26 19:00:51.815913+00', '2022-09-30 11:21:10.242273+00', 13184, 2, 2929, 'ace', '1-4 :: Facing after bow and curtsy, all Petronella and Set

5-8 :: W RH across and take NH with P

9-12 :: Set and Link, M join RH

13-16 :: M RH across and take NH with P

17-20 :: Set and Link, W take RH

21-24 :: Advance 2 positions, end W B2B

25-:: Petronella, Set, turn P RH 1-1/2', 2);
INSERT INTO 'dancecrib' VALUES (14987, '2022-08-10 16:47:48.794974+00', '2022-08-11 18:58:34.796849+00', 20969, 2, 35920, 'ace', '1-8::

  1s & 2s Set & Rotate (facing in diagonally)

9-16::

  1s lead down for 2 steps, ½ turn RH (2s step up), lead back up for 2 steps, turn RH to face 1st corners

17-24::

  ''Hello Goodbye'' setting to corners & partners

25-32::

  2s, 1s & 3s Advance & ''Retreat'' (retire). 1s Turn RH (or birl) (213)', 5);
INSERT INTO 'dancecrib' VALUES (12311, '2019-10-28 06:14:08.410648+00', '2022-08-11 23:12:50.576945+00', 1603, 1, 202, 'ace', '1--::

  1M+2W A&R ; dance BtoB

9--::

  1W+2M repeat [1-8]

17--::

  1c (2c following) dance down ; 2c (1c following) dance up

25--::

  Circle4 and back', 2);
INSERT INTO 'dancecrib' VALUES (12610, '2020-02-24 08:30:26.577543+00', '2022-08-12 07:39:42.793064+00', 19852, 1, 202, 'ace', '1--::

  All A&R ; all turn P RH (1,2,3,4)

9--::

  All A&R ; all turn P LH (1,2,3,4)

17--::

  1c cast off to 4pl (2c+3c+4c up) ; 1c turn P RH (2,3,4,1)

25--::

  Circle8 and back (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12158, '2019-09-04 01:42:58.998759+00', '2022-08-12 11:27:04.836828+00', 5642, 1, 202, 'ace', '1--::

  Circle4 and back

9--::

  All set | ½ RHA. All W retain RH ; ½ La-Chain, all M casting cclw to start

17--::

  R&L starting with P. Finish 1c in inner circle facing 2c in outer circle, all W on M''s left 

25--::

  All, joining hands into two concentric circles, set (PdB coupé) ; all turn (PdB) opposite person BH 1½. On [32] M release LH opening to face original direction with exchanged W on his right', 4);
INSERT INTO 'dancecrib' VALUES (11372, '2018-12-12 17:28:58.083221+00', '2022-11-23 15:06:22.383331+00', 19115, 2, 1645, 'ace', '1-8::

  1C dance down for 4 bars and back to places. Finish facing men''s side.

9-16::

  1C, 2C and 3C dance parallel reels of 3, 1C and 2C passing LSh to begin. 1C again finish facing men''s side.

17-24::

  1C and 2C dance LHA half way, 1C and 3C dance RHA half way. 1C and 4C dance LHA half way. All cross back RH to own sides.

25-32::

  All dance 8 hands round and back.', 2);
INSERT INTO 'dancecrib' VALUES (7848, '2013-08-21 08:31:49.770503+00', '2023-02-04 01:23:06.21507+00', 10791, 3, NULL, 'ace', '1-8::
    1s dance RSh reels of 3 on sides
9-16::
    1L followed by partner casts down behind 2L, crosses, casts down
    behind 3M crosses & casts up behind 3L to 2nd place own side 1M
    dances up between 3s to 2nd place own side
17-24::
    1s dance Figs of 8 Man round 2s & Lady round 3s
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (12111, '2019-08-30 14:24:44.731082+00', '2022-08-12 22:02:04.665722+00', 6326, 1, 202, 'ace', '1--::

  Circle4 and back

9--::

  All set | change places RH with opposite person ; RHA. All W retain RH

17--::

  ½ La-Chain, all M casting to original place. All retain LH ; LHA (all have moved one place clw, each M facing original W)

25--::

  All with new P set | pass P RSh ; dance (PdB) RSh round original P and face opposite direction | advance to meet next couple (M having changed their P face original direction)', 2);
INSERT INTO 'dancecrib' VALUES (9876, '2017-05-21 14:45:30.102055+00', '2023-01-14 15:31:34.754658+00', 17756, 1, 1645, 'ace', '*On 2nd chord, 3c & 4c cross to opposite sides (1,2,3x,4x)*

1--::

  1c+2c & 3c+4c Reverse S&Link ; 2W+1c & 4c+3W LHA _while{4}_ 2M & 3M chase &frac12; way cclw

9--::

  3M+2W+1c & 4c+3W+2M S&Link ; 1M+3M+2W & 3W+2M+4M RHA _while{4}_ 1W & 4W chase &frac12; way clw

17--::

  All chase 2pl clw (3x,1x,4,2) | 3c+1c & 4c+2c turn BH on sides ; all &frac12; RSh Reels4 on sides (2,4,1x,3x)

25--::

  2c+4c & 1c+3c Circle4 to L & back (2,4,1x,3x)

', 5);
INSERT INTO 'dancecrib' VALUES (12052, '2019-08-28 11:49:55.157481+00', '2022-08-11 13:42:42.942001+00', 647, 1, 202, 'ace', '1--::

  1c A&R ; cross RH | cast off (2c up) (2,1x,3)

9--::

  1c turn P RH ¾ | dance RSh round 2cnrs[pos] and chase clw ½ to exchanged places _while{8}_ 2c+3c cross RH | set ; change places LH on sides | set

17--::

  1c turn P RH | dance RSh round 4cnrs[pos] and chase clw ½ to exchanged places _while{8}_ 2c+3c repeat [9-16]

25--::

  1c turn P RH ¾ | Circle6 L (2,1,3)



*Note:  

In 9-24, the corners traditionally set one bar to the person they just passed, then one bar to the next person to pass.*', 4);
INSERT INTO 'dancecrib' VALUES (12714, '2020-04-11 10:38:13.143469+00', '2020-04-11 10:41:47.328715+00', 19951, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 2c+1c A&R (2,1)

9--::

  1c cross LH | cast up (2c down) ; 1c & 2c dance BtoB (1,2)

17--::

  1c+2c set | ½ RHA ; 2c+1c set | cross RH (2,1)

25--::

  Circle4 and back', 2);
INSERT INTO 'dancecrib' VALUES (14997, '2022-08-11 14:58:31.688437+00', '2022-08-11 18:52:07.320096+00', 20978, 2, 35920, 'ace', '1-8::

  1s & 2s Set & Rotate (facing in diagonally)

9-16::

  1s dance down between 3s, cast up, dance up between 2s, cast to 2nd place			

17-24::

  1s & 3s dance the Knot  (231)	

25-32::

  1s & 4s set & link, Circle to left (2341)', 5);
INSERT INTO 'dancecrib' VALUES (12712, '2020-04-10 17:52:47.953676+00', '2020-04-10 18:32:14.713871+00', 19944, 1, 202, 'ace', '1--::

  All W set | dance LSh round P | turn P LH ½ into centre BHJ (1x,2x,3x)

9--::

  All slip down {2} | slip up {2} ; 1c cast to 3plx _while{4}_ 2c & 3c dance up and cast to 2plx/1plx (3x,2x,1x)

17--::

  3C S&Link twice (1,2,3)

25--::

  1c cross RH | cast to 3plx (2c & 3c up) ; 1c Tulloch Turn (or spin) to 3pl (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11885, '2019-06-10 11:36:10.772615+00', '2022-08-12 07:44:24.460008+00', 2068, 1, 202, 'ace', '1--::

  1c turn RH ; cast off (2c up) (2,1,3)

9--::

  1c turn LH ; cast off (3c up) (2,3,1)

17--::

  Circle6 and back (2,3,1)

25--::

  1c lead up to top (3c down on [27-28]) ; set | cast to 2pl (2,1,3)

33--::

  1c turn 1cnrs RH ; turn P LH (2,1,3)

41--::

  1c turn 2cnrs RH ; turn P LH to face 1cnrs

49--::

  1c Fig8 R, LSh to 1cnrs. 1c face 2cnrs

57--::

  Reels3 across, RSh to 2cnrs (2,1,3)



*Note:  

The original circle was to the left only and the setting on bars 29 -30 has been introduced in accordance with modern practice.*', 2);
INSERT INTO 'dancecrib' VALUES (15000, '2022-08-12 07:03:59.81929+00', '2022-10-25 19:40:30.525702+00', 20985, 2, 35920, 'ace', '_Strathspey_

1-8::

  1s & 3s Advance & Retire, ½ Rights & Lefts

9-12::

  With corners all Schottische set

13-16::

  turn corners two hands twice

17-24::

  1s & 3s Ladies chain

25-32::

  Circle to left & back

33-64::

  2s and 4s Repeat bars 1-32



_Reel_



1-8::

  1s & 3s Advance & Retire, ½ Rights & Lefts

9-16::

  With corners all set twice (or pas de basque coupe) & TR (or birl)

17-24::

  1s & 3s Ladies chain

25-32::

  Circle to left & back

33-64::

  2s and 4s Repeat bars 1-32', 5);
INSERT INTO 'dancecrib' VALUES (12588, '2020-02-17 01:30:32.181386+00', '2022-08-12 11:35:16.804493+00', 5746, 1, 202, 'ace', '1--::

  All turn P RH ½ | retire to opposite sides ; all turn P RH into Reel3 position. 1c & 2c face on sides (1x,2x,3x)

9--::

  Parallel Reels3 {6} on sides, 1c RSh to 2c | 1c & 2c continue the reels. 1W face out (2x,1x,3x)

17--::

  2c+1c RHA ; 1c+3c LHA. 3c face out (2x,1x,3x)

25--::

  1c+3c ½ DblFig8, 1c crossing down (to 2x,1,3) ; 1c lead up and cast off to 2pl _while{4}_ 2c cast off and cross up to 1pl (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (11124, '2018-09-19 00:08:48.577107+00', '2020-12-07 13:07:07.567558+00', 16869, 1, 202, 'ace', '1--::

  1c set | 1W followed by 1M cast below 2W, cross (2c up), cast below 3M and dance up between 3c to face 1cnrs

9--::

  SetH&G, 1c to 2pl facing 3cnrs (2,1,3)

17--::

  Reels3 {6} on sidelines, 1c RSh to 3cnrs | 1c+3cnrs change places RSh (to 1,2,3 on M side, 2,3,1 on W side)

25--::

  3C Bourrel (3,1,2)

33--::

  All chase clw ½ ; all turn P RH ½, face P | cast R to exchanged places (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15106, '2022-09-26 19:04:36.00715+00', '2022-10-26 19:47:36.495777+00', 12785, 2, 2929, 'ace', 'Strathspey:
1-8 :: Circle8 around and back
9-12 :: 1C cast and weave to bottom (others step up on 11-12)
13-16 :: Back to Back

Reel:
17-24 :: 1C followed by other couples up middle and cast back to place
25-28 :: At top and bottom join hands on side, M make arch and all dance across, face on sideline and set R on side and L to Partner
29-32 :: All half turn and twirl', 2);
INSERT INTO 'dancecrib' VALUES (15003, '2022-08-12 16:29:52.856829+00', '2022-08-17 08:53:22.497508+00', 20983, 1, 202, 'ace', '1--::

  1c+3c+5c set advancing to midline, all giving RH to P | Bil ; 1c & 5c turn P RH and cast inwards (2c & 4c step out) _while{4}_ 3c turn P RH (2,1,3,5,4)

9--::

   2c+3c+4c set advancing to midline, all giving RH to P | Bil ; 2c & 4c turn P RH and cast inwards (1c & 5c step out) _while{4}_ 3c turn P RH (1,2,3,4,5)

17--::

  All set | 1c (+2c+3c+4c+5c following) cast off to bottom {4} (to 5,4,3,2,1) | all set (5,4,3,2,1)

25--::

  5c+4c+3c+2c ½ Reels4 on sides _while{4}_ 1c turn RH or Birl ; all set | turn P RH (2,3,4,5,1)', 2);
INSERT INTO 'dancecrib' VALUES (14996, '2022-08-11 06:35:58.607584+00', '2022-08-13 03:36:44.898088+00', 20992, 1, 202, 'ace', '*On 2nd chord, 2c+3c cross to opposite sides (1,2x,3x)*  
_Strathspey_
1--::
  1c set advancing | turn BH ; dance down (2c up) | turn BH ½ into promhold facing down. On [8] 2c & 3c step in. All face down (2x,1x,3x)
9--::
  3C Allemande. On [15-16] 1c set advancing to face 3cnrs[pos]

_Reel_
17--::
  *Modified Corners Pass and Turn* : same as Corners Pass and Turn except that cnrs turn RH ½, face each other and cast away to exchanged places. On [23-24] 1c dance to centre and face P BHJ _while_ 3W steps in _as_ 3M curves L to face P in centre BHJ
25--::
  1c+3c 5 bars of Poussette. On [6] 3c & 1c turn BH ¼ to midline | 3c & 1c Petronella turn to opposite sides (2,3x,1x)', 5);
INSERT INTO 'dancecrib' VALUES (15004, '2022-08-12 20:29:55.446384+00', '2022-08-13 09:04:57.443639+00', 20982, 1, 202, 'ace', '1--::

  1c+2c set | turn P BH opening into | Circle4 L (1,2,3,4)

9--::

  1c set | cast off (2c up) ; turn P RH 1½ (2,1x,3,4)

17--::

  1c dance down to bottom | cast up round 4c to 3plx (3c up) ; cross RSh | cast off to 4pl (2,3,4,1)

25--::

  Circle8 and back (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (15262, '2022-11-23 20:11:26.221851+00', '2022-11-23 23:48:03.551422+00', 12902, 1, NULL, 'ace', '1--::

  1c set | cast (2c up) ; dance between 3c and cast up (2,1,3)

9--::

  1c turn P RH | turn 1cnr LH ; turn P RH | turn 2cnr LH into facing lines across

17--::

  S&Link3 ; all set | all cross RH (2,1,3)

25--::

  Circle6 and back (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (15111, '2022-09-27 13:40:59.684171+00', '2022-10-25 19:38:34.918219+00', 21112, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; turn P RH and face out (2,1x,3)

9--::

  3C Chain Progression (3,1x,2)

17--::

  1c ½ Fig8 L round 4cnrs[pos] ; 3c+1M & 1W+2c LHA (3,1,2)

25--::

  Reels3 on sides, 1c RSh to 4cnrs[pos] (3,1,2)

33--::

  Circle6 L {3}, cross R foot over and pivot L ; chase cclw (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (15109, '2022-09-27 10:29:27.989438+00', '2022-12-22 18:22:17.303561+00', 790, 1, 1645, 'ace', '1-::

  1c Fig8 round 2c

9-::

  Mirror Reels3 on sides giving hands, 2c start out and up, all end NHJ facing up

17-::

  All advance up | retire to sides ; turn P RH

25-::

  1c cross RH | cast off to 3plx (2c+3c up) ; turn 1&frac12; in mutually agreed way (2,3,1)

::

  *NB if using the recommended recording (without a chord), the first time 1c cross over on [1-2], honour partner on [3-4] then &frac12; Fig8 round 2c. Thereafter all dance as above*

', 2);
INSERT INTO 'dancecrib' VALUES (14993, '2022-08-10 22:35:28.801747+00', '2022-08-11 14:44:26.996719+00', 20972, 2, 35920, 'ace', '1-4::

  1s cross down between 2s, cast to right, round & in to face 1st corners

5-8::

  1s with 1st corners, set & turn two hands (finishing facing 1st corners)

9-16::

  1s & 1st corners dance diagonal reel of 4 with a twizzle/twirl (ie pulling R shoulder back as you pass Lsh in the middle) 1s finish in centre facing each other (up & down) L between 2s, M between 3s

17-24::

  1s cross RH (up & down), cast to right round & in to face 2nd corners 1s with 2nd corners, set & turn two hands (finishing facing 2nd corners)

25-32::

  1s & 2nd corners dance diagonal reel of 4 with a twizzle/twirl (ie pulling R shoulder back as you pass Lsh in the middle) 1s finish on own sides (213)

33-40::

  1s & 3s set & link, 1s & 4s set & link



*or for a 3 couple set* 



33-40::

 1s & 3s set & link, 1s & 3s turn two hands pulling Rsh back twirl into side lines



*or for a 3 couple dance in a 4 couple set*



33-40::

   2s, 1s & 3s Set ,All turn R½ Pull Rsh back & dance/twirl out to sides All set, cross RH for Bill', 5);
INSERT INTO 'dancecrib' VALUES (12713, '2020-04-11 05:10:49.760122+00', '2020-04-11 05:16:46.647168+00', 19934, 1, 202, 'ace', '1--::
  1c+2c set | turn P RH | Petronella Turn to midline
9--::
  ½ Reel4 to opposite sides, 2W+1M passing LSh (to 2x,1x,3) ; 2c+1c chase clw ½ (1,2,3)
17--::
  2W (1W following) + 3c Reel3 across in tandem, RSh to 3M
25--::
  2M (1M following) + 3c Reel3 across in tandem, LSh to 3W (2,1,3)

*Deviser''s note*:  
On bar 17, 3rd woman may begin the tandem reel of three by casting up, thus allowing 2nd and 1st woman time to pass.', 2);
INSERT INTO 'dancecrib' VALUES (3685, '2013-01-18 14:54:17.939951+00', '2020-08-04 05:55:06.194141+00', 2300, 2, 1, 'ace', '1–::

  1c+2c S | ½ RH across ; 1c+3c S | ½ LH across

9–12::

  1c cross R | cast up [3c down]

13–16::

  All petronella to center | 2c+3c petronella to own sides _while_ 1c petronella

  to fin back to back in 2pl facing own sides

17–20::

  In DT formation, all dance Highland Schottische moving up then down

21–24::

  ½ Reels3 on own sides (LS to 2W/3M to begin) [1c fin back to back facing opposite

  sides]

25–28::

  R bars 17–20

29–32::

  ½ Reels3 on opp sides (LS to 3W/2M to begin) [1c fin in 2pl own sides]', 3);
INSERT INTO 'dancecrib' VALUES (15107, '2022-09-26 22:11:32.943239+00', '2022-09-27 07:04:15.305445+00', 17257, 1, 1645, 'ace', '1--::

  1c cross down into Reels3 on opp sides (1x,2,3)

9--::

  1c dance down & up ending in the middle facing up

17--::

  1c cast off (2c up) | dance La Baratte ending with LH turn to face 1cnrs

25--::

  1c turn 1cnr RH | pass RSh ; turn 2cnr RH | cross passing RSh

33--::

  2c+1c+3c Circle6 to L & back (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13013, '2020-08-04 19:04:01.567639+00', '2020-08-04 21:09:32.41247+00', 576, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; cross LH |dance LSh round 4cnrs into lines3 across
9--::
  1c turn 1cnrs RH ½ | 1cnrs turn P (4cnrs) LH ½ ; 4cnrs turn 1c RH ½ | 1c pass P RSh to exchanged places and face in
17--::
  Repeat same pattern [9-14] starting LH with 2cnrs[pos] | 1c dance LSh round P to face 2cnrs
25--::
  Reels3 {6} on sides, 1c RSh to 2cnrs | 1c cross LH to 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (9164, '2016-06-11 15:38:31.328154+00', '2023-01-14 15:47:29.805947+00', 17023, 1, NULL, 'ace', '*On 2nd chord, 2c cross to opposite sides (1,2x,3)*

1--::

  1c+2c half turn BH to sides (as Tourbillon bars 1-2) | all set ; all circle &frac13; | all turn BH to W back to back, M facing in

  (triangular set: 1c centre of 3pl, 2c in 1W pl, 3c in 1M pl)

9--::

  All dance as bars 2-3 of diamond poussette rotating triangular set 90&deg; to (1c in 2W pl, 2c in 1M pl, 3c in 3M pl) |

  repeat turning less to (1c in centre of 1pl, 2c in 3M pl, 3c in 3W pl) M facing clw, W facing cclw ;

  &frac12; interlocking Reel4 back to places at bar 9

17--::

  All set turning to be RSh to P | M chase &frac13; clw _while{2}_ W &frac23; LHA ; all turn P BH | all set turning to be RSh to P

25--::

  M chase &frac13; clw _while{2}_ W &frac23; LHA | all turn P BH to sidelines (as Tourbillon bars 5-6) ; 1c+3c SLink (2,3x,1)

', 5);
INSERT INTO 'dancecrib' VALUES (15015, '2022-08-13 14:15:31.973592+00', '2022-08-13 14:15:41.333912+00', 10745, 1, 1645, 'ace', '*Three dancers 1,2,3 in a triangular set*

1--::

  All set twice turning R about ; circle3 to L

9--::

  All set twice turning L about ; circle3 to R

17--::

  All RHA ; set advancing & BiL | set retiring

25--::

  Dancers 1 & 2 change pl passing RSh | 1 & 3 repeat ; all LHA (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (3710, '2013-02-09 22:40:10.768648+00', '2022-08-13 15:05:42.398336+00', 12085, 1, NULL, 'ace', '1–::

  Mirror Reels3 on the sides, 1c cross down to start, at end 2c face out and up (1,2,3)

9–::

  2c cast up, meet, cross down through 2pl, cast off behind 3c, meet and cross up (1,2,3)

17–::

  1c+3c petronella to midline | set to P ; turn RH 1 ¼ to (1,2,3)[

25–::

  Circle6 and back

33–::

  1c cross RH | cast off ; cross up to top | cast off to 3pl (2c+3c up)', 2);
INSERT INTO 'dancecrib' VALUES (15379, '2023-01-14 21:43:48.899521+00', '2023-01-14 21:44:02.771963+00', 3169, 1, 1645, 'ace', '1--::

  All set | 1c+2c &frac12; RHA _while{2}_ 3c cross RH ; all set | cross RH & 1c face out (2,1,3)

9--::

  1c cast off below 3c, dance up NHJ, cast off & end BtoB facing 2cnrs

17--::

  1c+2cnrs &frac12; diag _LSh_ Reel4, 1c pass LSh ; 1c+1cnrs &frac12; diag _RSh_ Reel4, 1c end on own sides (3x,1,2x) 

25--::

  1c+2cnrs &frac12; diag R&L (1M up, 1W down) ; 1c+1cnrs &frac12; diag R&L (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11662, '2019-03-11 22:33:54.985599+00', '2022-08-13 20:07:51.037974+00', 11687, 1, 202, 'ace', '1--::

  All set twice ; 1c cross below 2c and cast up to 1plx (1x,2,3)

9--::

  Reels3 on sides, 1c in and down, 2c out and up (1x,2,3)

17--::

  Reels3 on sides, 1c crossing to 2pl (1,2,3)

25--::

  1c lead down {3}, lead up {3} | cast to 2pl (2c up) (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (6927, '2013-08-21 08:31:33.043848+00', '2023-02-04 01:21:59.595552+00', 11722, 3, NULL, 'ace', '{{explanation}}
2 facing 2 at random throughout the room

1-8::
    Advance to meet other couple & retire with other partner sideways,
    turn other partner RH
9-16::
    Advance to meet own partner & retire to place, turn partner LH
17-24::
    All dance Ladies'' Chain
25-32::
    All promenade at will to face new couple', 0);
INSERT INTO 'dancecrib' VALUES (7894, '2013-08-21 08:31:50.655717+00', '2023-02-04 01:23:09.925411+00', 9221, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s circle 4H round to left, 1s+2s also 3s+4s set to
    each other on sides & 2M+3L dance out Men''s side & cast to ends
    _while_ 2L+3M dance out Ladies side & cast to ends _while_ 1s+4s
    dance down/up & out to sides.  2 1 (4)(3)
9-16::
    2s+1s also 4s+3s dance double Fig of 8  across (2s & 3s crossing
    down/up to start) & 1s+4s end with 1/2 turn RH on sides.  2 (4) 1
    (3)
17-24::
    All dance Grand Chain
25-32::
    4s & 1s dance out ends & cast in 1 place, 4s & 1s turn partners
    1.1/2 times 2H to end 2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (10616, '2018-04-16 06:40:49.05423+00', '2022-07-21 17:04:01.336025+00', 10088, 1, 202, 'ace', '*3c & 4c start on opposite sides*

1--::

  1c+2c & 3c+4c S&Link, 1M & 3W & 2W & 4M face out at end ; 2c+1c & 4c+3c turn RH on sidelines (2,1,4x,3x)

9--::

  Parallel Reels4. On [15-16], middles pass Rsh, all ending on M(W) side facing up(dn)

17--::

  All chase clw ½ ; 4c+1c RHA (3,4,1x,2x)

25--::

  Circle8 and back



*Deviser''s note:  

Repeat once from new positions to return to starting places.  

Each couple dances once from an end position and once from a middle position.*', 2);
INSERT INTO 'dancecrib' VALUES (2227, '2012-01-22 19:29:26.767163+00', '2022-09-23 16:29:56.124003+00', 11719, 1, NULL, 'ace', '{{explanation}}

M on outer circle face P on inner circle



1–::

  All W A&R to P (who stands) ; All M A&R likewise

9–::

  All W dance Rsh round P (who stands), turn P RH

17–::

  All M dance Rsh round P (who stands), turn P RH into promhold, facing clw

25–::

  Dance forward as couples ; W stand as M dance to pass one W and face second W as new P.', 2);
INSERT INTO 'dancecrib' VALUES (14994, '2022-08-10 22:36:40.028479+00', '2022-08-11 14:35:11.765086+00', 20973, 2, 35920, 'ace', '1-4::

  1s & 3s turn RH, while 2s set, pulling R shoulder back, cast behind 3 rdcorner to face each other (L up, M down) in centre of set

5-8::

  2s turn LH 1½ to face 1st corner position, while 1s & 3s cross RH & change LH on sides

9-16::

  2s ½ diagonal reel of 4, Rsh to 1st corner position, pass Lsh into ½ diagonal reel of 4 with 2nd corner position, 2s turn L to finish in centre of dance facing up on own side with 1s & 3s for promenade

17-24::

  1s, 2s & 3s Promenade, 1s cast into 2nd place as 2s dance up to 1st place

25-32::

  Circle 6 Hands round & back (213)', 5);
INSERT INTO 'dancecrib' VALUES (2308, '2012-01-22 19:29:30.895096+00', '2020-08-04 21:21:14.764999+00', 2421, 1, NULL, 'ace', '{{explanation}}

5c start in middle, 5M facing 2M and 5W facing 4M



1–::

  5W+4c & 5M+2c ½RHA | 2c+4c ½LHA ; 4c+5M & 2c+5W ½RHA | 5c turn ¾ LH (1,4,3,2, in middle 5M faces down, 5W up)

9–::

  1M+5W & 5M+3M turn RH | 5c turn LH ; 1W+5W & 5M+3W turn RH | 5c turn ¾ LH [»Men, Partner, Women, Partner« ]

17–::

  5M+2M+1M and 5W+4M+3M Lsh ½Reels3, (Lsh to 4pl/2pl) ; 5M+1W+2W and 5W+4W+3W Rsh ½Reels3 (Rsh to 1pl/3pl). (to 2,3,4,1, and 5 in middle) (this exchanges the C between 1pl & 4pl and between 3pl & 2pl)

25–::

  5c set, turn BH ½ to face 1c in 4pl ; 5c+1c ½R&L (to 2,3,4,5, 1 in middle)', 2);
INSERT INTO 'dancecrib' VALUES (9106, '2016-02-29 15:08:36.42883+00', '2023-01-14 16:08:14.64208+00', 16890, 1, NULL, 'ace', '1--::

  1c+3c set to P | turn BH ; opening out into Circle4 to L back to places (M leading)

9--::

  1c+2W & 3c+4W RHA ; 1c+4M & 3c+2M LHA, 1c & 3c end in tandem (M leading) facing 2W/4W

17--::

  1c+3c dance &frac12; tandem Reels3 across ending side by side facing own place ;

  turn corner EH 9/8 to diagonals with 1W, 4M, 3W, 2M at the points of a diamond in 1st, 2nd, 3rd, 4th place

  and 1M+2W also 3M+4W in tandem facing 1W/3W

25--::

  1M+2W also 3M+4W &frac12; diag Reels3 giving LSh to 1W/3W ; all turn P 7/8 (1c & 3c RH, 2c & 4c LH)

  and twirl into progressed places (2,3,4,1)

', 5);
INSERT INTO 'dancecrib' VALUES (11342, '2018-11-12 23:23:21.970582+00', '2022-08-13 21:25:54.130178+00', 17116, 1, 202, 'ace', '_Strathspey_

1--::

  Interlocking Reels4 on the circle, RSh to P (1,2,3,4)

9--::

  Double M-Chain (1,2,3,4)

17--::

  1c & 3c set to P | ¾ R&L starting RH to P

25--::

  2c & 4c repeat [17-24]

33--::

  1c+3c »Half-turn and cast away« [turn opp person RH ½, face each other | cast R to exchanged places] ; 2c+4c repeat, all W face out (1,2,3,4)

41-56::

   Schiehallion Reel (1,2,3,4)

57--::

  Circle8 L {2}, dance in {1}, loop R {1} to next place ; repeat (1,2,3,4)  



_Reel_



1-56::

  Repeat as for Strathspey (1,2,3,4)

57--::

  Circle8 L {3}, cross R foot over and pivot L ; chase cclw (1,2,3,4)', 2);
INSERT INTO 'dancecrib' VALUES (15006, '2022-08-13 08:08:45.681783+00', '2022-08-16 20:55:03.463526+00', 20976, 2, 35920, 'ace', '1-8::1s lead down for 3, M1 dance in front of partner, turning partner under R arm
(2s step up on 3&4)
1s lead up, cross to 2nd place own side facing out
1s turn ½ with 2s (nearer hand) into 1st place
9-16::1s cross RH, cast 1 place, cross R
& cast to R to face each other up & down the set (M bet 2s, L bet 3s)
17-24::1s turn RH, reels of 3 across, M1 with 2s (Rsh to L2), L1 with 3s (Rsh to 3M)
1s finish in 2nd place own sides in centre facing down
25-28::3s make arch (nearer hands facing up) 3s dance up while 1s lead RH down under arch,
1s cross & cast up & in to face up
while 3s (turning towards each other) dance down taking nearer hands to 3rd place
29-32::2s make arch, dance down while 1s lead RH up under arch, 1s cross, cast to 2nd place,
while 2s (turning towards each other) dance back up to 1st place with nearer hands', 5);
INSERT INTO 'dancecrib' VALUES (1936, '2012-01-22 19:29:10.738162+00', '2023-01-16 10:31:48.176807+00', 1163, 1, NULL, 'ace', '1–::

  1c BHJ slip down to below 3c and open upper hands | set to 3c (1M with L foot) ; 1c BHJ slip to top | cast to 2pl (2c up) (2,1,3)

9–::

  2c repeat [1-8] (1,2,3)

17–::

  1c dance down 1 place and turn inwards to face up (2c up) | 2c+1c circle4 L, 1c finish in middle | 1c dance up to 1pl (2c down)

25–::

  1c set, cast off to 2pl (2c up) ; 2c+1c+3c turn partners RH.', 3);
INSERT INTO 'dancecrib' VALUES (13015, '2020-08-05 14:07:22.370427+00', '2020-08-05 14:23:19.264935+00', 3025, 1, 202, 'ace', '1--::

  End couples (1W & 4M casting to lead) chase clw back to places _while{8}_ Middle couples Circle4 and back (1,2,3,4)

9--::

  1W & 4M cast to ends of own lines (W/M step up or down on [9-10]) ; new End couples turn RH

17--::

  2W & 3M repeat same pattern [9-12] (to 3,4,1,2) ; 3c & 1c set | turn RH (3,4,1,2)

25--::

  3c lead down to 4pl _while{4}_ 4c+1c+2c clap 3 times and step up up on [27-28] ; 3c turn (elbow grip) _while{4}_ A&R (4,1,2,3)', 2);
INSERT INTO 'dancecrib' VALUES (15108, '2022-09-26 22:22:31.627491+00', '2022-09-26 22:24:27.162149+00', 21103, 1, 1645, 'ace', '1--::
  1c+2c+3c+4c set | &frac12; turn RH ; 1c+2c & 3c+4c &frac12; RHA | 1c & 3c &frac12; turn RH to face 1cnrs
9--::
  1c & 3c Corners Pass & Turn with 1cnrs, pass RSh ; repeat with 2cnrs, end on midline M facing up, W down
17--::
  1c+3c Reel4 on midline _while{8}_ 2c+4c+5c RSh Reels3 on sides, 4M starting down & in, 4W up & in
25--::
  1c+3c set twice facing up/down ; turn 1&frac14; RH moving down to 3pl/5pl (2,4,1,5,3)
', 2);
INSERT INTO 'dancecrib' VALUES (15112, '2022-09-27 14:05:37.363339+00', '2022-09-27 14:06:34.875093+00', 4403, 1, 202, 'ace', '1--::

  Circle4 and back (1,2)

9--::

  RHA ; LHA (1,2)

17--::

  2c (+ 1c following) lead down ; 1c (+2c following) lead up (1,2)

25--::

  2C Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (15115, '2022-09-29 21:00:49.324126+00', '2022-09-29 21:00:49.324126+00', 16226, 2, 2784, 'ace', '1-::
 All W RHA; dance round P Rsh, 2+4W finish in own pl but 1+3W end BtoB in centre facing P
9-::
 1c+3c dance La Baratte, on 15 & 16 1+3W set in P’s pl _while {2}_ 1+3M pull Rsh back & dance out to opp W’s pl _while {2}_ 2+4W dance into the centre, pulling Lsh back to face P
16-::
 2c+4c dance La Baratte, on 23 & 24 2+4W set in P’s pl _while {2}_ 2+4M pull Rsh back & dance out to opp W’s pl
25-::
 W face clw, M face cclw change place RH with person they are facing, change place LH with P
29-::
 All set to P, 1/2 turn BH (4, 1, 2, 3)', 3);
INSERT INTO 'dancecrib' VALUES (15110, '2022-09-27 11:44:11.297204+00', '2022-09-28 00:38:04.810057+00', 21111, 1, 202, 'ace', '1--::
  1c turn RH ½ (2c up) | cross over to cast behind 3c ; cast off, meet and lead up LH to face 1cnrs
9--::
  Corners Pass and Turn, corners giving BH. On [16] all dance in into promhold 1c facing down and 2c & 3c facing up (2,1x,3)
17--::
  3C Circulating Allemande. On [23-24] 1c cast away RSh to 2plx and face out (3,1x,2)
25--::
  1c dance RSh round 1cnrs[pos] | set advancing towards P ; change places RH on midline | Petronella turn to 2pl (3,1,2)', 5);
INSERT INTO 'dancecrib' VALUES (1895, '2012-01-22 19:29:08.56793+00', '2022-09-23 16:48:51.071138+00', 11610, 1, NULL, 'ace', '1–::

  Parallel Lsh Reels3{6} on own side, on [7-8] 1c pass 2c Lsh to (2,1,3), but with 1W in the centre facing 3W

9-24::

  »H&G Chase«:  1W SetH&G right round, finish between 3c on [22] | 1W makes full pivot R to face down  _while_{16} 1M advances to 3W on [9-10] and then SetH&G right round, finish in the middle in 2pl facing down

25–::

  1W with 1M following cast up behind 3W, cross to M side, cast up above 2c to top | pass 2c Rsh to (2,1,3), 1M facing out.', 3);
INSERT INTO 'dancecrib' VALUES (9874, '2017-05-21 14:39:09.820387+00', '2023-01-14 12:29:29.422904+00', 17753, 1, 1645, 'ace', '1--::

  1W dances below 3W | casts up to 2pl (2W up) ; 1W crosses to 1M who sets turning to face out |

  1c in tandem (1M leading) cast to face 3W while{2} 2M dances up to face out

9--::

  1c &frac12; tandem diag Reel3, RSh to 1st cnrs ;

  1c continue &frac12; diag Reel3 changing lead, M end on sides (2,1,3), 1W ends below 3M & takes NH

17--20::

  3M+1W NHJ dance diagonally up to 3M before 2W, 1W in 2pl | 3M+2W & 1W+3W turn &frac34; RH

21--24::

  1W dances up crossing 3M LH under arch made by 2M+1M _while{2}_ 2W+3W set facing on sides |

  3M casts to 3pl _while{2}_ 1W loops to end above 2M & takes NH _while{2}_ 2W+3W cross RH on sides

25--28::

  Repeat [17-24] inverted: 1W+2M NHJ dance diagonally down to 1W in 2pl, 2M before 2W | 1W+3W & 2M+2W turn &frac34; LH

29--32::

  1W dances down crossing 2M RH under arch made by 1M+3M _while{2}_ 3W+2W set facing on sides |

  2M casts up to 1pl _while{2}_ 1W casts up to 2pl _while{2}_ 2W+3W cross LH on sides (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (13014, '2020-08-04 22:50:13.526899+00', '2020-08-05 13:35:13.037757+00', 2544, 1, 202, 'ace', '1--::

  1c set advancing | turn P BH ; lead down, cross and cast up round 2c to 1plx (1x,2)

9--::

  6 bars of R&L | A&R {1+1} (2,1x)

17--::

  2c & 1c set advancing | turn P BH ; 1c cast up | dance down to 2plx _while{4}_ 2c cross down to plx | cast up to 1plx (2x,1x)

25--::

  6 bars of R&L (to 1x,2x) | Circle4 L ½ (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (15007, '2022-08-13 08:13:15.467972+00', '2022-08-13 08:32:04.255021+00', 20977, 2, 35920, 'ace', '1-4::

  1s & 3s (& 5s) Set, Set turning on the spot (pulling Rsh back) while 2s (& 4s) Dos-sis-dos

5-8::

  1s & 3s (& 5s ) Dos-si-dos while 2s (& 4s) Set, Set turning on the spot (pulling Rsh back)

9-16::

  1s, 2s & 3s Reels of 3 own sides (2s Rsh to R) finishing facing 1st corners (while 4s & 5s ½ RA, ½ TR and ½ LA, ½ TL)

17-24::

  2s (& 4s) diagonal reel of 4 (1st corners), 2s,1s & 3s finishing in centre of set facing up

25-32::

  1s, 2s & 3s promenade, 1s cast to (2,3,1) in 3C set, or to (2, 1, 3, 4) in 4C set or (1s, 2s & 3s promenade to positions 3,4,5 while 4s & 5s promenade to positions 1,2 ) (4,5,1,2,3) (2,3,4,5,1) (5,1,2,3,4) (3,4,5,1,2) (1,2,3,4,5)', 5);
INSERT INTO 'dancecrib' VALUES (14995, '2022-08-10 23:25:15.219408+00', '2022-08-11 08:51:47.287382+00', 20991, 1, 202, 'ace', '1--::
  1c set | cross RH ; cast off (2c up) | advance and pull RSh back to face 1cnrs
9--::
  1c turn 1cnrs BH | pass P RSh ; turn 2cnrs BH | pass P RSh to 2pl. 1c face out (2,1,3)
17--::
  Parallel Reels3 on sides {6}, 1c out and down, 3c in and up | on [23-24], 1c & 3c continue the reel to exchange places (2,3,1)
25--::
  3c+1c Poussette (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (10358, '2017-12-26 15:51:45.323+00', '2022-08-12 09:06:46.959181+00', 2894, 1, 202, 'ace', '1--::

  1M+2M lead between P, cast round own P ; cross between P, (1M in front of 2M) to exchanged places

9--::

  1W+2W repeat [1-8] (2,1,3)

17--::

  1c turn 1cnrs RH ; turn 2cnrs LH, finish BtoB on midline facing own side

25--::

  DTr, finish BtoB on midline facing own side

33--::

  All Circle3 and back

41--::

  Reels3, 1c Lsh to 3cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10571, '2018-04-03 06:44:59.819086+00', '2022-08-14 08:24:19.311857+00', 13898, 1, 202, 'ace', '1--::

  1c (start inwards) Mirror ½ Fig8 on sidelines ; cross up between 3c, up behind 2c on opposite sides, meet into promhold between 2c facing 2M

9--::

  1c+2c ½ Reel3 across, 1c start Rsh to 2M, end between 3c facing 3W, 2c end in 1plx ; 1c+3c ½ Reel3 across, 1c start Lsh to 3W, end in 3plx as 3c end in 2plx (2x,3x,1x)

17--::

  3M+2c & 3W+1c RHA ; all turn P RH ½, face each other | cast R to exchanged places (2,3,1)

25--::

  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (9873, '2017-05-21 14:35:27.222823+00', '2023-01-14 16:42:33.107753+00', 17758, 1, 1645, 'ace', '1--::

  1W sets to 1M (who does _not_ set back) | 1W sets to 2W ;

  2W+1W in promhold &frac12; Fig8 on side LSh to 3W _while{4}_ 3W steps up | steps down (1,2,3)

9--::

  All dance Inveran reels

17--::

  1c+2c DblFig8 (1c crossing down)

25--::

  1c+2c &frac12; turn EH | 1c+3c &frac12; turn EH ; 1c dance up NHJ _while{2}_ 3c loop back to 3pl | 1c cast off(2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (15113, '2022-09-27 15:45:54.077842+00', '2022-09-27 15:47:32.772923+00', 10800, 1, 202, 'ace', '1--::
  1c+2c Chain and Turn (2,1,3)
9--::
  1c Petronella turn to between ends | all set ; 1c Petronella turn to 2plx | all set (2,1x,3)
17--::
  ½ Reel4 on 1diag. On [20] 1c meet P, pull RSh back to face 2cnrs ; ½ Reel4 on 2diag. On [24] 1c pull RSh back to 2plx and face out (3x,1x,2x)
25--::
  All chase clw ½ ; all turn P BH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15016, '2022-08-14 15:07:58.584565+00', '2022-08-14 15:08:07.863253+00', 16147, 1, 1645, 'ace', '1--::

  1c turn RH ; turn LH | cast off (2c up)

9--::

  1c Fig8 up round 2c

17--::

  2c+1c set | RHA | set

25--::

  2c+1c Circle4 & back (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (2899, '2012-01-22 19:30:02.134288+00', '2023-01-17 00:15:26.441441+00', 9011, 1, NULL, 'ace', '1–::

  1W+2M advance {1}, pull back Rsh and cast R round standing dancer ; turn RH 1¼ to exchanged places

9–::

  1M+2W repeat Lsh, L and LH (2x,1x)

17–::

  2c+1c set | pass P Rsh (no hand) and face P in middle ; spiral R to sideline | set (2,1)

25–::

  2c+1c Poussette (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (15017, '2022-08-14 19:06:02.307562+00', '2022-08-17 08:32:18.59484+00', 20792, 1, 202, 'ace', '1--::

  1c set | turn BH and face down ; dance to bottom (2c up) | cast up round 3c to 2pl (2,1,3)

9--::

  ½ Reel4 on 1diag, 1c passing LSh. 1c pass LSh for ; ½ Reel4 on 2diag (3x,1x,2x)

17--::

  3C Set&Link twice (2,1,3)

25--::

  1c+3c *The Rosette* : all set to P | turn P RH ½, face P ; cast R to exchanged places | chase clw ½ (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (15020, '2022-08-15 00:25:55.459591+00', '2022-08-15 08:07:12.686685+00', 18331, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; ½ Fig8 R round 3cnrs and face 1cnrs
9--::
  4 bars of Dance to Corners and Set. On [12] 2W+3M are BtoB on 1diag ; ½ Reel4 on 1diag. 2W+3M pass RSh into BtoB position on 2diag
17--::
  4 bars of Dance to Corners and Set from new positions. On [20] 1c is BtoB on 2diag ; ½ Reel4 on 2diag. 1c pass P RSh into BtoB position on 1diag
25--::
  ½ Reel4 on 1diag ; 1c turn P RH 1¼ to 2pl (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (13036, '2020-08-10 00:18:31.209212+00', '2023-02-04 01:18:36.619425+00', 19983, 3, NULL, 'ace', '{{title}}
Strathspey

1-4::
    1s+2s Set+Link, 2L+1M face out
5-12::
    2s+1s dance »Mixed Chain« (as Men''s Chain but 2M+1L turn 3/4 LH &
    1M+2L loop on sides)
13-16::
    2s+1s dance LH across
17-28::
    2s+1s Set+Link; 2s+1s repeat »Mixed Chain« from new positions
29-32::
    1s turn LH moving down to 2nd place (2s step up 31-32)

{{title}}
Reel

1-32::
    1s+3s repeat 1-32', 0);
INSERT INTO 'dancecrib' VALUES (10672, '2018-04-21 12:49:27.599262+00', '2020-08-05 13:32:43.288386+00', 2534, 1, 202, 'ace', '1--::

  1c+2c set | cross RH and face on sides ; 1c & 2s set | change places EH, 1c out and down (2x,1x,3)

9--::

  1c+3c  ½  DblFig8, 1c crossing down, 3c casting up (to 2x,1,3x) ; ½ Reel3  on sides, 1c crossing to 1plx, 2c out and down, 3c out and up. 2c & 3c end with loops (3x,1x,2x)

17--::

  All  A&R  {1+1}  |  cross RH ; all A&R {1+1} | 1c turn P LH to face 3cnrs[pos] _while{2}_ 3c & 2c cross LH (3x,1,2x)

25--::

  ½ Reel4 on 1diag, pass LSh to face 4cnrs[pos] ; ½ Reel4 on 2diag to  2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (15380, '2023-01-17 02:38:07.368429+00', '2023-02-16 14:50:19.994631+00', 18125, 1, 202, 'ace', '1--::
  *Butterfly* : 1c cross down RH to 2plx _while_ 2c cast up to 1pl | 2c+1c repeat pattern of [1-2] (to 1x,2x,3) ; 1c lead down, turn outwards to 2plx and face P _while{4}_ 2c cast up to 1plx | cross RH and face out (2,1x,3)
9--::
  Reels3 on sides, 1c RSh to 2cnrs. On [15-16] 1c pull LSh back and face opposite sides as for DTr position
17--::
  DTr (2,1,3)
25--::
  1c+3c ¾ R&L | 3c+1c set (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (9100, '2016-02-29 01:19:22.060552+00', '2023-01-14 12:33:30.922062+00', 16884, 1, NULL, 'ace', '*On 2nd chord, 2c & 4c cross to opposite sides (1,2x,3,4x)*

1--::

    1c & 4c cross RH | cast inwards (2c & 3c to ends) ; 1c+4c LHA (2x,1x,4,3)

9--::

    2c & 3c cross RH | cast inwards (1c & 4c to ends) ; 2c+3c &frac12; LHA | &frac12; turn cnr RH (3,1x,4,2x)

17--::

    Parallel RSh Reels4 on the sides (3,1x,4,2x)

25--::

    All set adv on sides passing LSh | 3c+2c turn BH on sides & face in ; 1c+3c & 2c+4c mirror S&Link, 3c & 2c casting to ends (3,1x,4,2x)

', 5);
INSERT INTO 'dancecrib' VALUES (14355, '2021-10-06 22:10:20.79788+00', '2022-08-13 17:25:35.34446+00', 9368, 1, 202, 'ace', '1--::

  1c & 4c turn P RH 1½ (to 1x,2,3,4x) ; cast inwards (2c & 3c step out on [5-6]) to centre finishing BtoB facing cnrs they just passed (2,1x,4x,3)

9--::

  Intersecting Reels4 (use ½ LHA in centre). Finish as on [8]

17--::

  All set | all changes places RH with nearest cnrs. 1c & 4c face clw ; 1c & 4c chase clw ½ _while{4}_ 2c+3c ½ LHA | set. All finish on sides (4,3x,2x,1)

25--::

  4c+3c & 2c+1c ½ R&L (to 3,4x,1x,2) ; 4c+1c ½ R&L (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (11795, '2019-04-20 09:59:53.261504+00', '2022-08-13 22:11:51.308621+00', 19275, 2, 1645, 'ace', '1- 8::

  All chase anticlockwise, pull right shoulder back and chase back to places

9-10::

  All turn corner both hands (skip-change of step) ¾ times to open into saltire formation. All facing anticlockwise

11-16::

  All in saltire formation dance ¼ anticlockwise, set and men petronella turn forward into sides of big square (ladies as corners)

17-24::

  1L+3L cross over giving right hands, 2L+4L repeat, 1M+3M repeat, 2M+4M repeat

25-32::

  All circle 8H round & back to finish on the new places (1 pl clockwise)

', 0);
INSERT INTO 'dancecrib' VALUES (15008, '2022-08-13 08:23:32.157511+00', '2022-08-14 08:18:21.9174+00', 20979, 2, 35920, 'ace', '1-8::

  1s ½ turn R, lead down between 2s & 3s, cast up into 2nd place & turn RH (2s step up on 3&4)

9-16::

  1s with L2 RH across, L1 followed by M1 & L2 dance up & round M2 by Lsh (1s to 2nd pl) & L1 pulling Rsh back 1s TR, while L2 returns to own side at top of set

17-24::

  1s with M3 RH across, L1 followed by M1 & M3 dance down & round L3 by Lsh (1s to 2nd place on opp sides) & L1 pulling Rsh back 1s TR, while M3 returns to 3rd place own side

25-32::

  1s dance ½ figure of eight, L up, M down (around partner''s 2nd corner by Rsh) to 2nd place own side, 2s & 1s cross RH, ½ RH across, stay in centre of set (123)

33-40::

  1s & 2s poussette (213)', 0);
INSERT INTO 'dancecrib' VALUES (15114, '2022-09-27 16:11:08.396831+00', '2022-09-27 16:11:48.576452+00', 20881, 1, 202, 'ace', '1--::

  1c+2c Rose Progession (2,1,3)

9--::

  All turn P BH. 1c remain in 2pl centre ; 1c dance down | cast to 2pl (2,1,3)

17--::

  Mirror Reels3 on sides {6}, 1c in and down, 3c out and up | 1c+3c continue the reel to exchanged places (2,3,1)

25--::

  All set | Circle6 L ¾ {3) dance in on L foot into centre and all swivel R {1} | spiral out to chase clw to sides (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (14879, '2022-06-21 14:27:35.119207+00', '2022-06-21 14:28:01.114746+00', 782, 1, 202, 'ace', '1--::

  1c lead down to 3pl, cross and cast to 2pl, _while{4}_ 2c set and cross RH into 3pl, _while{4}_ 3c cast to top and cross RH ; all C turn BH 1½ to own side (3,1,2)

9--::

  All set | Reels3 across, 1c LSh to 1cnrs (3,1,2)

17--::

  All repeat [1-8] from new positions (2,3,1)

25--::

  3c+1c Tourbillon (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (2859, '2012-01-22 19:30:00.422806+00', '2022-11-27 16:33:22.003869+00', 4674, 1, NULL, 'ace', '1–::

  1c set | Petronella turn (2c step a bit up) ; set giving RH | turn RH ¾ to line across with 2c

9–::

  Reel4 across, 1c finish facing 1cnr, 2c in 1pl

17–::

  1c set to 1cnr | change place RH ; set again | change back RH and face 2cnr

25–::

  Repeat LH with 2cnr, finish 1M between 2c and 1W between 3c

33–::

  In lines across set twice, 1c dancing to 2pl ; 2c+1c+3c A&R', 2);
INSERT INTO 'dancecrib' VALUES (3874, '2013-08-08 09:48:30.993301+00', '2021-04-05 17:20:26.189353+00', 6853, 1, NULL, 'ace', '1–::

  1c set adv | turn BH ; lead down (2c up) and cast behind 3pos to 4pl (3c+4c up) (2,3,4,1)

9–::

  2c+3c & 4c+1c ½ R&L ; All change sides, dancing ½ Fig8 to the L, passing Rsh on the diagonal, (3,2,1,4)

17–::

  repeat [9-16] from new positions (2,3,4,1)

25–::

  2c_3c & 4c+1c Circle4 L ; All turn P RH (2,3,4,1)





Note: on [13-14] also pass Rsh with dancer of the next set in the line', 2);
INSERT INTO 'dancecrib' VALUES (11842, '2019-05-11 15:58:40.555359+00', '2023-01-14 16:22:09.265457+00', 19309, 1, 1645, 'ace', '*On 2nd chord, 2c & 4c cross to opposite sides (1,2x,3,4x,5)*

1--::

  1c+2c & 3c+4c &frac12; RHA | 1c+4c &frac12; LHA (2,4x,1,3x,5) ;

  1,2,3 pl M side & 3,4,5 pl W side S&Link3 _while{4}_ 4,5 pl M side & 1,2 pl W side S&Link2 to end in crown triangles top & bottom and zigzag in middle

9--::

  All set | drop RH and turn LH into DDtr ; all set | drop LH and turn RH back into DDTr

17--::

  All set | 5c+2c &frac12; turn LH _while{2}_ 1c cast LSh back to crown triangles top & bottom and zigzag in middle ;

  top & bottom (approx) S&Link3 _while{4}_ middle 4 drop LH & (approx) S&Link2 to the sidelines (4,5x,1,2x,3)

25--::

  All circle 10H round and back

', 5);
INSERT INTO 'dancecrib' VALUES (14310, '2021-09-14 11:57:58.487781+00', '2022-08-14 21:32:25.908104+00', 16847, 1, 202, 'ace', '1--::

  1c turn RH | cast off (2c up) ; dance down between 3c | cast up fo face 1cnrs

9--::

  *Rotating Reel of Four* on 1diag : 1c dance RSh round 1cnrs[pos], meet in centre ; turn RH 1½ to face 2cnrs _while{8}_ 1cnrs ½ Reel4 when passing LSh in the middle make a full twirl R about, and continue to exchanged places ; chase clw ½ to original places

17--::

  *Rotating Reel of Four* on 2diag (2,1,3)

25--::

  Circle6 L {3}, cross R foot over and pivot L ; chase cclw (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (15018, '2022-08-14 19:47:50.792457+00', '2022-08-15 18:00:33.290582+00', 13859, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; all set | turn P RH ½ into promhold, 2c facing down, 1c & 3c (with 3W on P''s Left) facing up
9--::
  Reel3 on midline, 1c RSh to 2c. 2c in 1pl face out, 1c in 2pl centre face up, 3c in 3pl face out (2,1,3)
17--::
  Mirror Reels3 on sides, 1c in and up, 2c out and down. On [21-22] 1c cross down to 3plx (2,1x,3)
25--::
  All A&R ; 1c turn P RH 1½ (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3904, '2013-08-21 08:30:38.920658+00', '2023-02-04 01:18:19.070411+00', 1930, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides & 1s
    end BtoB in 2nd place facing opposite sides as 2s end in 1st place
9-16::
    1s dance Crown Triangles with 2s+3s & end facing 2nd corners
17-24::
    1s dance reels of 3 with corners passing 2nd corner by RSh & cross
    LH to 2nd place own sides
25-32::
    1s dance Figs of 8 (Lady up through 2s & Man down through 3s)', 0);
INSERT INTO 'dancecrib' VALUES (2768, '2012-01-22 19:29:56.622032+00', '2022-09-23 17:25:45.824401+00', 11403, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; ½ Reels3 on own side, 1c starting in and down , and 2c+3c looping in at the end (to 3,1,2)

9–::

  1c+1cnr positions »Allemande R« ; turn RH

17–::

  1c+2cnr positions »Allemande L« ; turn LH

25–::

  3c+1c+2c set | cross RH ; chase clw to (2,1,3)



{{explanation}}

Note »Allemande L«: dancers advance and take LH, W dancing under M''s arm | W dances out and M retires but here keep LHJ ready for the turn', 2);
INSERT INTO 'dancecrib' VALUES (9104, '2016-02-29 15:02:04.913191+00', '2023-01-14 12:40:47.551515+00', 16888, 1, NULL, 'ace', '1--::

  1c & 3c set | &frac34; turn LH ; 1c & 3c &frac12; LSh Reel4 _while{4}_ 2c & 4c set | &frac34; turn LH, all M end BtoB facing P

9--::

  All &frac12; intersecting LSh Reels4 with &frac12; RHA in the centre ; 1c & 3c turn LH _while{4}_ 2c & 4c &frac12; LSh Reel4

17--::

  All set to P | M dance out to next place clw and face in _while{2}_ W dance in to face the place they just left ; repeat from new places to (4,1,2,3) all M again BtoB facing P

25--::

  All dance &frac14; Rosace (ie Schiehallion starting from these positions) to (1,2,3,4) ; all &frac34; turn RH into promhold | promenade one place cclw (2,3,4,1)

', 5);
INSERT INTO 'dancecrib' VALUES (12807, '2020-05-11 16:09:53.924195+00', '2023-01-17 11:10:45.808148+00', 2345, 2, 116, 'ace', '01-04::

  1C & 4C set to partners and cross over RH to finish 1C facing down, 4C facing up.

05-08::

  2C & 3C turning to face up/down, all set and change places LH.

09-16::

  1C & 2C and 3C & 4C dance a ladies'' chain (3C & 4C dance a ladies'' chain with men leading).

17-20::

  1C & 4C set and dance half RH across.

21-24::

  1C & 3C, facing each other on the sides, set, then 1C turn in and dance up to 2nd place (centre) while 4C cast off to 3rd place (centre) while 3C set advancing.

25-32::

  1C & 4C & 3C allemande.', 4);
INSERT INTO 'dancecrib' VALUES (13363, '2020-11-02 01:22:20.32348+00', '2023-02-04 01:23:06.245719+00', 14607, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast 2 places (2s step up) & dance up to face 1st
    corners
9-16::
    1s dance ''Corner Pass+Turn'':
::
    1s dance a loop RSh round 1st corner _while_ 1st corners turn each
    other RH & return to places, 1s pass RSh in the middle & repeat with
    2nd corners. 1s end passing RSh to BtoB facing own side
17-24::
    All set as in Double Triangles, Bar 20: 1s pass each other RSh, pull
    back RSh to BtoB facing opp sides; all set as in Double Triangles &
    1s finish in centre, 1M pulling back RSh to end facing up (Lady on
    Man''s right)
25-32::
    1s dance up to top, cast, meet, dance down & cast up round 3s into
    2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (15002, '2022-08-12 09:16:54.38917+00', '2022-08-12 11:08:28.451961+00', 20994, 1, 202, 'ace', '1--::
  1c set | Mirror Fig8 on sides, starting in and down (1,2,3)
9--::
  1c+2c the Knot. 1c & 2c retain LH in centre (2,1,3)
17--::
  1c+2c LHA ; 1c+3c Circle4 L. On [24] release H except with P
25--::
  On [25] 1c & 3c join BH turning into diagonal line. Poussette (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (7308, '2013-08-21 08:31:38.779049+00', '2023-02-04 01:23:06.282669+00', 6964, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, 2s+1s+3s set & circle 6H round to left 1/2 way
9-12::
    1s cross RH, cast right into centre _while_ 2s+3s set (facing
    diagonally in) & dance RH across 1/2 way
13-16::
    1s cross up/down RH & cast right to 2nd place own side _while_ 2s+3s
    set & dance RH across 1/2 way
17-24::
    1s dance 1/2 reels of 3 across (1M with 3s at top & 1L with 2s) & 1s
    turn 2H 1.1/2 times
25-32::
    3s+1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (2567, '2012-01-22 19:29:47.943451+00', '2020-08-06 15:20:44.811292+00', 3485, 1, NULL, 'ace', '1–::

  2c+4c pass P Lsh into diag. Reels4 with 1cnrs

9–::

  2c+4c pass P Lsh into Rsh diag. Reels4 with 2cnrs (1,2,3,4,5)

17–::

  2c+4c (start in and L) Fig8 {7bars} on own side round standing couples, on [24] 1c+2c+3c+4c dance in for

25–::

  1c+2c & 3c+4c ½Poussette (on [28] 5c dance in) ; 1c+4c & 3c+5c (bottom four couples) ½Poussette (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (1780, '2012-01-22 19:29:01.988255+00', '2022-08-13 17:36:11.54744+00', 11389, 1, NULL, 'ace', '1–::

  1c dance down one, and stay in middle | 1c set as 3c set advancing, both turning inwards to face up ; 1c+3c dance up between 2c and cast off (2c up) (to 2,3,1)

9–::

  Repeat from same positions (2c and 1c dancing) (to 3,1,2)

17–::

  Cross diagonally RH between 1M+2M positions and 2W+3W positions | Repeat LH between 1W+2W & 2M+3M positions | Repeat RH between 1M+2M & 2W+3W positions | All set (2,1,3)

25–::

  All circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (13204, '2020-09-19 19:19:50.875205+00', '2022-08-13 22:15:41.84096+00', 19982, 1, 1645, 'ace', '{{explanation}}

Strathspey



1-::

  1c & 3c dance LSh round opposite to face P in lines across with back to corner ;

  dance LSh round P, face corner & pass them LSh. On [8] corners pull RSh back to face cclw & take promhold with 1c & 3c on outside

9-::

  1c & 3c, in promhold with corners, chase &frac12; way clw so 2c & 4c have exchanged places with promenade partner on their R ;

  releasing promhold, 1c & 3c set adv diagonally to P | turn BH (3,4,1,2)

17-32::

  2c+4c repeat [1-16], all end in original places, W facing out

33-::

  All &frac12; Schiehallion reel

41-::

  Circle8 & back (3,4,1,2)



{{explanation}}

Reel



Repeat 1-48 in reel time', 2);
INSERT INTO 'dancecrib' VALUES (10653, '2018-04-18 19:00:02.202172+00', '2022-08-14 08:30:41.536302+00', 13913, 1, 202, 'ace', '1–-::

  1W+2M turn RH ½ | 1c+2c RHA | 1M+2W turn RH ½  (2x,1x,3)

9--::

  2c+1c R&L, finish 2c(1c) facing dn(up) (2x,1x,3)

17--::

  2W+1W & 2M+1M & 3c set | Mirror Reels3 {6} on sidelines, 1c start out and up, 1c finish facing out

25--::

  2c cross down LH to 2pl and cast up to 1pl _while{4)_ 1c cast up to 1pl and cross down LH to 2pl (to 2,1,3) ; 1c+3c Circle 4 L', 2);
INSERT INTO 'dancecrib' VALUES (8172, '2014-02-08 00:07:05.833431+00', '2022-08-14 21:57:58.759253+00', 1942, 1, NULL, 'ace', '1–::

  1c cross down (no hands) _while_ 2c dance out and up to 1pl {3 bars}.  1c turn 2c EH to form a circle, all facing in (order 2,1x,3)

9-20::

  Balance in/out in circle | all M roll W on his L to his R ; repeat twice

21-24::

  1c cross up between 2c and cast to (2,1,3)

25–::

  Mirror Reels3 on the sides, 1c in and down (2,,3)', 2);
INSERT INTO 'dancecrib' VALUES (15263, '2022-11-25 16:18:36.057231+00', '2022-11-25 16:18:54.863574+00', 3946, 1, 1645, 'ace', '

1-::

  1c set | cast off (2c up) ; 1c &frac12; Fig8 LSh round 1cnr _while{4}_ 2c & 3c set | turn BH ending NHJ with P facing down/up

9-::

  All set | &frac12; Circle6 to L ; all M with W on their R turn BH | &frac12; Circle6 (2,1x,3)

17-::

  2c+1M & 1W+3c RHA ; 1c, then 2W+3M, then 2M+3W &frac12; turn LH in centre & chase clw in path of other RHA ending on sides (3x,1,2x)

25-::

  All set | 3c & 2c petronella to midline ; set | petronella to own sides

  _while{6}_ 1c cast clw ; cross between setting couples & cast R | cross RH (3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (14880, '2022-06-21 14:42:23.011151+00', '2022-06-21 14:44:16.138051+00', 14567, 1, 202, 'ace', '1--::
  2c & 4c set | turn RH and face out RHJ ; lead out through ends, cast inwards to face 1cnrs
9--::
  Reels4 on 1diag. 2c & 4c face 1cnrs
17--::
  Turn CPCP (1,2,3,4,5)
25--::
  1c+2c & 3c+4c Set&Link (to 2,1,4,3,5) ; 1c+4c & 3c+5c Set&Link (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (1813, '2012-01-22 19:29:03.769013+00', '2022-09-23 17:31:20.132187+00', 11303, 1, NULL, 'ace', '1–::

  1c cross down RH 2 places (2c up) and cast up ; ½Fig8 (W up M dn) to face 1cnr

9–::

  1c dance RSh round 1cnr, meet and curve R to face 4cnr _while{4}_ these cnrs ½ turn RH & cast away to change places ; repeat with 4cnrs, 1c finish facing 3cnr

17–::

  SetH&G, to finish (3x,1x,2x)

25–::

  All S&Link3 ; repeat. (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15010, '2022-08-13 08:25:02.958824+00', '2022-08-24 07:06:13.365319+00', 20995, 2, 35920, 'ace', '_Strathspey_
1-8::
  1s ½ turn R, lead down between 2s & 3s, cast up into 2nd place & turn RH (2s step up on 3&4)
9-16::
  1s with L2 RH across, L1 followed by M1 dance up & round M2 by Lsh (1s to 2nd pl) & L1 pulling Rsh back 1s TR
17-24::
  1s with M3 RH across, L1 followed by M1 dance down & round L3 by Lsh (1s to 2nd place on opp sides) & L1 pulling Rsh back 1s ½ TR
25-32::
  2s & 1s diamond poussette (213)

_Reel_ (from 2nd place)

1-24::
  as above,
25-32::
  2s,1s & 3s circle to left & back', 5);
INSERT INTO 'dancecrib' VALUES (10321, '2017-12-19 22:16:10.41774+00', '2022-08-15 11:14:52.025732+00', 18130, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; ½Fig8 up round 2c (2,1x,3)

9--::

  1c set | cast (3c up) ; ½Fig8 up round 3c to centre, 3c step in [15-16] for

17--::

  3c+1c Poussette, 1c finishing BtoB in centre facing own side

25--::

  2c+1c+3c DTr (2,1,3)

33--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (2214, '2012-01-22 19:29:26.172376+00', '2022-06-21 21:34:37.057813+00', 2125, 1, NULL, 'ace', '1–::

  1c set | turn RH ½ to 2plx (2c up) ; set | turn RH to finish 1W, with 1M behind her, facing 2M

9–::

  (1W+1M following)+1cnrs Rsh diagonal Reel3 (finish facing 3M)

17–::

  (1W+1M following)+2cnrs Rsh diagonal Reel3, on last 2 bars 1c turn LH (to face 1cnrs)

25–::

  1c turn 1cnr RH (cnrs dance 4 bars), pass P Rsh, turn 2cnr RH, pass Rsh to 2pl own side', 2);
INSERT INTO 'dancecrib' VALUES (14696, '2022-03-10 00:08:28.751197+00', '2022-08-15 13:49:09.552081+00', 19854, 1, 202, 'ace', '1--::

  Circle6 and back (1,2,3)

9--::

  ½ Reel4 on 1diag 2c passing LSh, pass RSh ; ½ Reel4 on 2diag (3x,2x,1x)

17--::

  All A&R ; all turn oppposite person RH (3x,2x,1x)

25--::

  All set and retain hands hold | on each line, left end dancers dance under arch made by middle and right end dancers, ends with skip change, middles pulling RSh back with pdb | all facing new Lines3 set', 2);
INSERT INTO 'dancecrib' VALUES (12839, '2020-05-18 01:00:55.952004+00', '2022-09-30 11:27:40.846593+00', 11072, 1, 202, 'ace', '1--::

  1W+3M cross RH | 1M+3W cross LH ; repeat. 1M face out (1,2,3)

9--::

  1M (1W following) cast off one place | dance to 2plx (2c up) ; 1W pulling LSh back (1M following) cast off one place | dance to 3pl (3c up) (2,3,1)

17--::

  Parallel Reels3 on sides, 1c LSh to 3c (2,3,1)

25--::

  3c+1c set diagonally | set to P ; 1c turn P RH (2,3,1)



*Deviser''s note*:  

For less experienced dancers, bars 17-24 may be danced with only 1st couple dancing a figure of

eight around 2nd and 3rd couples.', 2);
INSERT INTO 'dancecrib' VALUES (1611, '2012-01-22 19:28:50.863586+00', '2022-08-14 08:48:57.927386+00', 14389, 1, NULL, 'ace', '{{explanation}}

Couple face couple RR.



1–::

  1c+2c RHA ; LHA

9–::

  Circle4 R ; Circle4 L

17–::

  With dancer opposite dance BtoB ; dance BtoB with P

25–::

  1c to 2c A&R ; pass other couple, couple facing clw RR making an arch, and meet next couple



{{explanation}}

Note: the original gives no details on the circles of [9-16], but the unusual »first R then L« fits better with both the preceding and succeeding figures.', 3);
INSERT INTO 'dancecrib' VALUES (3283, '2012-01-22 19:30:18.914438+00', '2022-09-30 21:24:44.017898+00', 9892, 1, NULL, 'ace', '1–::

  1c set | cross down (no hands) to 2plx (2c up) facing out ; 1c turn 2c EH (2,1x,3)

9–::

  Mirror Reels3 on the sides, 1c starts out and up, and finish facing 1cnr

17–::

  1c ½Reel4 with 1cnrs, pass Lsh, ½Reel4 with 2cnrs (to 3x,1x,2x)

25–::

  All ½Circle6 L ; All clap and turn P RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (2855, '2012-01-22 19:30:00.262614+00', '2022-11-27 16:52:28.78454+00', 4663, 1, NULL, 'ace', '1–::

  1M+2W change places RH {4} ; 1W+2M repeat

9–::

  Repeat bars 1-8

17–::

  1c lead down the middle and up {6} | cast off (2c up) (2,1,3)

25–::

  Turn CPCP (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (15019, '2022-08-14 22:17:40.569832+00', '2022-08-14 22:24:16.692858+00', 1091, 1, 202, 'ace', '1--::
  1W+3M change places RH | chase clw round 2c to P''s places ; change places LH | chase cclw to original places _while{8}_ 1M & 3W set diagonally | cross to P''s places ; repeat [1-4] pulling RSh back to face in (1,2,3)
9--::
  Mirror Reels3 on sides, 1c in and down, 2c out and up. 2c face out (1,2,3)
17--::
  1c+2c turn on sides EH 1¼ ; 1c (+2c following) dance to bottom | cast up round 3c to original places (1,2,3)
25--::
  1c+2c *The Rosette* : all set to P | turn P RH ½, face P ; cast R to exchanged places | chase clw ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10427, '2018-02-13 15:58:40.668646+00', '2022-08-15 08:46:00.547911+00', 17470, 1, 202, 'ace', '*On 2nd chord, 3c+4c cross to opposite side (1,2,3x,4x)*

1--::

  4C Pick-up Chain, 2 bars per hand, 1c cross RH to start (3x,2x,4x,1x)

9--::

  Parallel Lsh Reels4 on sideline

17--::

  All set | all La Baratte (3,2,4,1)

25--::

  3c+2c & 4c+1c Circle4 R ; 3c+2c S&Link _while{4}_ 4c+1c set | cross RH (2,3,4x,1x)', 2);
INSERT INTO 'dancecrib' VALUES (11271, '2018-10-17 11:22:01.038392+00', '2022-08-15 14:39:13.892846+00', 18978, 1, 202, 'ace', '1--::

  1M followed by 1W cast and cross to 3plx (2c+3c up) ; 1c+4c RHA (2,3,1x,4)

9--::

  All set | turn P BH, opening into ; 2c+3c & 1c+4c Circle4 L, 3c & 1c face out the ends (2,3,1x,4)

17--::

  1c & 3c dance out ends, cast in to meet P in promhold, W on L ; dance round other cpl Rsh into Lines4 across, with 3c(1c) between 2c(4c), all on own side facing down

25--::

  Both lines dance down {3} and bring 3c & 1c  in to meet P (3,2,1,4) ;  1c/3c make arches and 2c/4c dance up under, and all dance up to (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (14178, '2021-08-03 08:24:50.649505+00', '2022-08-16 10:05:56.657082+00', 20415, 1, 202, 'ace', '1-4::

  1c turn RH | cast off (2c up) and face 1cnrs

5-16::

  *Modified Dance to Corners and Set* : same as Dance to Corners and Set except dancers give RH on meeting in centre. On [15-16] 1c cross RH to 2pl (3x,1,2x)

17--::

  Diagonal R&L (2,1,3)

25--::

  1c dance to top | cast off ; 1c+3c turn 1½ RH on Mside, LH on Wside (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15024, '2022-08-16 11:21:48.638052+00', '2022-08-17 08:20:11.969359+00', 20742, 1, 202, 'ace', '1--::

  1c set | dance down and face P (2c up) ; 1c turn BH | set advancing to face 1cnrs

9--::

  ½ Reel4 on 1diag, pass P RSh ; ½ Reel4 on 2diag (3x,1x,2x)

17--::

  All chase clw ½ ; 1c turn P BH and face out (2,1,3)

25--::

  3C Chain Progression (3,1,2)', 4);
INSERT INTO 'dancecrib' VALUES (15033, '2022-08-17 10:08:24.045352+00', '2022-08-17 10:18:53.209128+00', 20741, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; turn P LH 1½ (2,1,3)

9--::

  Reels3 across, 1c LSh to 1cnrs (2,1,3)

17--::

  1c lead down ; lead up (2,1,3)

25--::

  2c+1c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3793, '2013-07-13 15:56:07.814576+00', '2022-08-18 00:17:33.285241+00', 13576, 1, NULL, 'ace', '1–::

  1c cross down RH | cast behind 3c ; cross up RH | cast up to top

9–::

  All turn RH ; Turn LH

17–::

  1c+2c »The Helix« [set passing Lsh | cast R to own side ; turn ½ RH into ½ RHA] (2,1,3)

25–::

  All Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (15011, '2022-08-13 08:28:50.52553+00', '2022-08-13 15:33:11.99209+00', 20980, 2, 35920, 'ace', '1-4::

  1s & 2s Set, 1s cast to 2nd place, while 2s dance up & curve into 1st place

5-8::

  1s dance down bet 3s, cast up to 2nd place

9-12::

  1s turn RH (or birl) finishing in centre facing down on own side

13-16::

  1s dance down between 3s&4s, cast up to 3rd place (3s step up)

17-20::

  3s with 1s circle to left

21-24::

  1s with 4s circle to right

25-32::

  4s facing up retain nearer hands make arch, while 1s dance under & cast up 1 & turn RH (or birl) down to 4th place', 5);
INSERT INTO 'dancecrib' VALUES (9787, '2017-04-10 19:51:42.190805+00', '2022-08-14 08:58:47.947077+00', 14600, 1, 202, 'ace', '1--::

 1c ½ Fig8 round 2c ; 1c cross RH | cast (2c up) (2,1,3)

9--::

 1c+1cnrs turn RH, 1c finishing facing 1cnrs _while{4}_ 2cnrs set, change places RH ; ½ Reel4 in 1diag, 1c passing Rsh to face 2cnrs pos

17--::

 1c+2cnrs pos turn RH, finishing facing 2cnrs pos _while{4}_ 1cnrs set, change places RH ; ½ Reel4 in 2diag, 1c passing Rsh to 2pl (2,1,3)

25--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (9896, '2017-05-29 22:39:05.287432+00', '2022-08-15 08:49:50.500255+00', 17689, 1, 202, 'ace', '1--::

 1c cross RH | cast (2c up) ; cross LH | cast L into facing lines of 3 across

9--::

 1W+2c A&R ; set   _while{6}_ 1M+3c set | A&R | 1c Petronella to 2plx (2,1x,3)

17--::

 Mirror Reels3 on sidelines, 1c cross down to start (2,1,3)

25--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (10354, '2017-12-23 23:03:28.439705+00', '2022-08-15 11:16:06.679885+00', 18184, 1, 202, 'ace', '1--::

  Circle6 and back (1,2,3)

9--::

  1c+2c RHA ; 1c cast (2c up) | turn RH and retaining RH give LH 1M(1W) to 3c(2c)

17--::

  2c+1W & 1M+3c LHA ; Rsh »Snake Pass« (unwind the LHA, 1c leading, pass other snake Rsh through 2pl and chase clw) (3,1x,2)

25--::

  ½ Reels3 on sidelines, 1c Lsh to 1cnrs position ; 1c turn P RH 1 ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14239, '2021-08-14 08:14:40.101257+00', '2022-08-15 13:58:36.607462+00', 19961, 1, 202, 'ace', '1--::

  All RHA ; LHA

9--::

  Reel3, 1p RSh to 3p

17--::

  All Petronella turn | set ; repeat [17-20]

25--::

  Circle3 and back', 5);
INSERT INTO 'dancecrib' VALUES (14388, '2021-10-14 10:24:45.634705+00', '2022-08-15 14:54:21.504818+00', 20506, 1, 202, 'ace', '1--::

  1c & 4c cross RH | cast inwards _while{4}_ 2c & 3c set | dance out to ends (to 2,1x,4x,3) ; 1c+4c set | ½ RHA (2,4,1,3)

9--::

  All repeat same pattern [1-8] from new positions (4,3,2,1)

17--::

  4c+3c & 2c+1c set | ½ LHA ; all set | cross RH (3,4,1,2)

25--::

  3c+4c+1c Mirror Reels3 on sides, 1c LSh to 4c (to 1,4,3,2) ; ½ Reel4 on sides (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (15381, '2023-01-19 10:20:22.866509+00', '2023-01-19 23:13:01.271271+00', 16243, 1, NULL, 'ace', 'This crib follows our copy of the instructions.  There must be an error as there is no progression.  

   

*Start: Y shaped triangular set, couples facing cclw, M inside NHJ to W*



1-4::

  All S&Link, finish in normal triangular set, M facing in, W out

5-16::

  Schiehallion Reel6

17-20::

  All turn P RH ¾ (into Y set, W inside facing P)

21-28::

  1c+2c ½ Rsh Reel4 (to Y set) ; 2c+3c repeat  

29-32::

  3c+1c repeat, finish in Y set all facing cclw, now with the W in centre

33-64::

  Repeat from new positions

', 1);
INSERT INTO 'dancecrib' VALUES (12259, '2019-09-30 01:58:53.579052+00', '2021-05-12 17:46:33.226792+00', 4024, 2, 160, 'ace', '1-4::  1s2s set adv. to face up NHJ. 1s lead up & cast as 2s lead up and curl into top pl.

5-8:: 1s3s repeat. (2 3 1)

9-16:: 1s followed by 3s lead up to top, cast around 2s & meet, lead down & cast up around 3pl. 3s curl into 3pl. (2 1 3)

17-24::  2s1s circle L once round open into extended line. Half reel4 - pass ptnr R shoulder to begin. (1 2 3)

25-32::  1s2s dance Philabeg to progress.

25-26::  1s2s turn ptr BH once round

27-28::  1s dance diagonally down & out AS 2s dance diagonally up & out

29-30::  2s1s dance diagonally into the middle

31-32:: 2s1s turn BH 3/4 round & dance out to own sides.', 2);
INSERT INTO 'dancecrib' VALUES (15005, '2022-08-13 08:07:37.18538+00', '2022-08-17 07:23:28.078253+00', 20975, 2, 35920, 'ace', '1-8::
1s lead down for 3, M1 dance in front of partner, turning partner under R arm
(2s step up on 3&4)
1s lead up, cross to 2nd place own side facing out
1s turn ½ with 2s (nearer hand) into 1st place
9-16::
1s cross RH, cast 1 place, cross R
& cast to R to face each other up & down the set (M bet 2s, L bet 3s)
17-24::
1s turn RH, reels of 3 across, M1 with 2s (Rsh to L2), L1 with 3s (Rsh to 3M)
1s finish in 2nd place own sides in centre facing down
25-28::
3s make arch (nearer hands facing up) 3s dance up while 1s lead RH down under arch,
1s cross & cast up & in to face up
while 3s (turning towards each other) dance down taking nearer hands to 3rd place
29-32::
2s make arch, dance down while 1s lead RH up under arch, 1s cross, cast to 2nd place,
while 2s (turning towards each other) dance back up to 1st place with nearer hands', 5);
INSERT INTO 'dancecrib' VALUES (15028, '2022-08-17 08:30:07.687646+00', '2022-08-17 08:49:03.019435+00', 20984, 2, 35920, 'ace', '1-8::

  1s turn RH, cast to 2nd place, 1¼ turn LH (L1 between 2s facing down & M1 between 3s facing up)

9-16::

  1s Set, L1 casts out top & down behind L2 & L3 dances up the set to face down between 2s while M1 follows to finish facing up between 3s

17-24::

  1s Set, turn RH 1¼ face up, lead up to top & cast into 2nd place

25-32::

  2s,1s & 3s Circle to left & back', 5);
INSERT INTO 'dancecrib' VALUES (11093, '2018-09-09 21:44:46.0099+00', '2022-08-17 21:06:44.625153+00', 18569, 2, 202, 'ace', '1--::

  Mirror Reels3 on sidelines, 1c in (1,2,3)

9--::

  All cross RH | 1M cast off 2 places (2M+3M up) ; all turn opposite BH

17--::

  3C S&Link

25--::

  3C Bourrel (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15034, '2022-08-17 10:57:04.581439+00', '2022-09-23 18:47:44.991539+00', 20996, 1, 202, 'ace', '1--::

  3C Set&Link ; chase clw ½

9--::

  Repeat [1-8] from new positions (3x,2x,1x)

17--::

  All set | turn P RH ½, face P and cast away to exchanged places | set (3,2,1)

25--::

 3c+2c Rose Progression (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (14881, '2022-06-22 05:54:30.994756+00', '2022-06-22 05:58:24.479047+00', 18756, 1, 202, 'ace', '1--::

  1c cast off (2c up) | cross RH ; all chase clw ½ (3x,1,2x)

9--::

  Reels3 across, 1c RSh to 2cnrs[pos] (3x,1,2x)

17--::

  Reels3 on sides, 1c RSh to 2cnrs[pos] (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14882, '2022-06-22 22:11:36.2323+00', '2022-06-22 22:11:54.966225+00', 12186, 1, 202, 'ace', '1--::

  1c+2c Set&Rotate (2,1,3)

9--::

  2c+1c RHA ; 1c+3c LHA (2,1,3)

17--::

  Parallel Reels3 on sides, 1c RSh to 2c

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (7849, '2013-08-21 08:31:49.778553+00', '2023-02-04 01:23:06.302428+00', 7289, 3, NULL, 'ace', '1-8::
    1s set advancing & turn 2H, dance down middle & cast to 2nd place
    own sides
9-16::
    1s set advancing to 1st corners & turn 2H to end between 2s/3s, set
    advancing to 2nd corners & turn 2H to end 2nd place opposite sides
17-24::
    1s cross RH & cast to right, cross RH up/down & cast to right to end
    in 2nd pl own sides _while_ 2s+3s set & dance RH across 1/2 way
    twice
25-32::
    2s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (14233, '2021-08-14 00:22:26.265416+00', '2023-02-04 01:23:06.327631+00', 6965, 3, NULL, 'ace', '1-8::
    1s+2s dance 4H round to left (3 bars), pull back LSh, reform circle
    and circle 4H round to right
9-16::
    1s set & cross RH; 1s+2s set & chase 1 place round clockwise
17-24::
    1s+2s dance RH across; 1s (on Ladies'' side) & 2s (on Men''s side)
    turn partner 1.1/4 RH to end 1s facing up, 2s facing down, all take
    prom hold
25-32::
    1s+2s dance ''The Whirligig'':
::
    _25-30_   1s+2s promenade round 1.1/4 times (Men LSh-LSh)
::
    _31-32_   2s turn LH to own side (2nd place) & cast up to 1st place
    _while_ 1s turn LH moving down to 2nd place on own side
33-40::
    2s+1s dance Double Fig 8.  End 2 1', 0);
INSERT INTO 'dancecrib' VALUES (15012, '2022-08-13 08:30:28.024718+00', '2022-08-13 15:27:24.818323+00', 20981, 2, 35920, 'ace', '1-2::

  All Advance(1 step) & retire(1 step)

3-4::

  Repeat – All Advance(1 step) & retire(1 step)

5-6::

  All ½ turn RH dancing out to opposite sides

7-8::

  All dance towards partner & pull Rsh back dance out to curve into sidelines

9-12::

  1s with 2s, 3s with 4s Set & Link (finish 1s facing down 4s & 3s facing up)

13-16::

  1s, 4s & 3s dance ½ reel of 3 (1s & 4s pass Lsh to start) (2x3x4x1x)

17-24::

  All parallel reel of 4 on sides (Rsh to start)

25-30::

  2s with 3s Set, pull Lsh back, cast to chase round top-half of set (anticlockwise) back to place (2x3x4x1x) while 4s with 1s Set & pull Rsh back cast to chase round bottom-half of set (clockwise) back to place (2x3x4x1x)

31-32::

  All cross RH', 5);
INSERT INTO 'dancecrib' VALUES (8761, '2015-05-12 14:24:14.690184+00', '2023-01-20 11:34:38.142994+00', 2981, 2, 1, 'ace', '1–4::

  1c set | 1M casts to 3pl (2M+3M up)

5–8::

  2M+3M+1M set to 1W+2W+3W, adv slightly | all turn RH for

9–::

  Promenade (3cpl)

17–20::

  2c+3c dance RH across to 1pl+3pl _while_ 1c set to ptr and cast to 2pl

21–24::

  1c turn RH

25–::

  Circle6', 3);
INSERT INTO 'dancecrib' VALUES (15021, '2022-08-15 09:05:45.423762+00', '2022-08-15 09:07:06.533369+00', 20570, 1, 202, 'ace', '1--::

  Circle6 and back (1,2,3)

9--::

  All cross RSh | cross RSh back ; 1c turn BH and cast off to 2pl _while{4}_ 2c turn BH and dance up to 1pl _while{4}_ 3c turn P BH (2,1,3)

17--::

  1c set advancing to 1cnrs | turn 1cnrs BH and face 2cnrs ; set to and turn 2cnrs BH. 1c on midline face Mside, 1W on P''s Right

25--::

  1c NHJ dance out and cast back to midline facing Wside ;  dance out and cast back to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15023, '2022-08-15 11:42:13.526608+00', '2022-08-15 11:42:22.85151+00', 19372, 1, 1645, 'ace', '1--::

  1c+2c & 3c+4c S&Link ; 1c+4c S&Link (2,4,1,3)

9--::

  2c+4c & 1c+3c RHA{3}, LHA{3} | 2c & 1c cast off _while_ 4c & 3c dance up (4,2,3,1)

17--::

  4c+2c & 3c+1c set | cross over ; &frac12; R&L (2,4,1,3) & face up/down on sides

25--::

  Reels4 on sides (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2634, '2012-01-22 19:29:50.885199+00', '2022-11-27 21:06:47.78414+00', 3684, 1, NULL, 'ace', '1–::

  1c+2c set | RHA | 1c cast to 1cnr as 2c dance up to 1pl

9–::

  1c turn 1cnr RH | pass Rsh ; turn 3cnr LH | pass Lsh to face 2cnr

17–::

  1c turn 2cnr RH | pass Rsh ; turn 4cnr LH | pass through 2plx into

25–::

  2c+1c+3c Reels3 on the sides, Lsh to 2cnr, at end 1c cross back to finish (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10575, '2018-04-03 20:54:04.769858+00', '2020-09-01 10:54:48.606061+00', 4042, 2, 1, 'ace', '_Figure 1 (1c&3c dancing)_



1–:: 1c&3c set | ½ RH across ; M turn R about and turn ptr LH to opp pl

9–:: 1c&3c set | ½ LH across ; L turn R? about and turn ptr RH to own pl

17–:: 1M+3M BtoB ; 1L+3L pass LS | turn opp M RH

25–:: 1M+3M LS BtoB ; 1L+3L pass RS | turn ptr LH



_Figure 2 (all dancing)_



1–:: All set adv to their left, L join RH | “Big star” ¼ round ;

    M turn R about and turn ptr LH into opp pl

9–:: Rpt 1-8 going to R, M joining LH, turning R to orig pls

17–:: All M BtoB w/opp M ; all L pass LS | turn opp M RH

25–:: All M LS BtoB ; all L pass RS | turn ptr LH



_Figure 3 (2c&4c dancing)_



1–32:: 2c&4c repeat Figure 1



_Figure 4 (all dancing)_



1–:: L set adv to give RH across _while_ M set adv anticlockwise (passing ptr LS)

    | L ½ RH across _while_ M dance anticlockwise round set

    ;  All turn ptr LH into opp pl (¾ or 1¾)

9–:: Rpt 1–8, all M giving LH across, all L dancing clockwise round outside,

    all turning RH

17–:: All M BtoB _while_ all L dance ½ round anticlockwise ;

    all L pass LS and turn ptrs RH to orig pls

25–:: All M LS BtoB _while_ all L dance ½ round clockwise ;

    all L pass RS and turn ptrs LH to orig pls', 3);
INSERT INTO 'dancecrib' VALUES (12011, '2019-08-08 19:28:22.645821+00', '2023-01-19 12:40:04.699366+00', 16754, 1, 1645, 'ace', '1--4::

  1c & 3c petronella to centre facing up/down | 1c, 2c & 3c set to P, 2c pull LSh back to face clw

5--12::

  Weasel reel: Reel4 on midline (M up, W down), on reaching ends

  pass RSh, chase &frac12; way clw on opposite side & rejoin reel, finish in starting place

13--16::

  1c & 3c petronella to opp sides _while_ 2c cross RH (1x,2x,3x) | all set

17--24::

  All &frac12; turn RH & cast away (1,2,3) ; all dance BtoB with P

25--32::

  1c cross RH | cast off (2c up) ; turn 1&frac12; RH (2,1,3).

  *1c tulloch turn to 4pl on their 2nd repeat (3c up on 31-32).*

', 2);
INSERT INTO 'dancecrib' VALUES (15026, '2022-08-16 12:20:09.893991+00', '2022-08-16 12:22:06.009972+00', 20746, 1, 202, 'ace', '1--::

  1c cross RH | cast off two places ; meet and lead up to 2pl centre BtoB facing own side (2c up on [5-6])

9--::

  DTr. On [15-16] Petronella turn to between ends, 1c facing 4cnrs

17--::

  Reels3 across, 1c RSh to 4cnrs. On [24] 1c turn LH ½ to 2p centre, LSh to P, 1M facing down, 1W facing up

25--::

 All M and all W RHA ; 1c turn P LH to 2pl _while{4}_ 2c+3c turn RH on sides (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15029, '2022-08-17 08:36:45.957463+00', '2022-08-17 08:44:39.194963+00', 20986, 2, 35920, 'ace', '1-4::

  1s & 2s Set & turn partner with two hands

5-8::

  1s face up & cast to 2nd place, while 2s dance up (nearer hands) cast into 1st pl. 1s turn RH to face own sides

9-16::

  2s & 1s Rsh reel of 4, 1s twirl into circle

17-24::

  2s & 1s circle to left and back

25-32::

  2s & 1s Diamond Poussette', 5);
INSERT INTO 'dancecrib' VALUES (14277, '2021-09-07 19:17:39.783574+00', '2023-01-20 11:10:30.867771+00', 3142, 2, 3069, 'ace', '1-4:: 1C turn RH 1.1/4, finish between 2C facing opposite side

5-14:: Spurtle with 2&3C, 1C finish facing down in 3rd place

15-16:: 1C ast up to 2nd place, 3C step down

17-24:: 3C Grand chain, 2+1C give RH & 3C cross RH

25-26::  2+3C cross RH to own sides

27-32:: 1C lead down for 2, 1/2 turn, lead up to 2nd place

', 2);
INSERT INTO 'dancecrib' VALUES (3232, '2012-01-22 19:30:16.705153+00', '2022-08-19 08:40:13.687685+00', 5976, 1, NULL, 'ace', '1–::

  1c lead down the middle | turn RH ½ ; lead up | turn RH ½ to place

9–::

  1c+2c RHA ; ½ LHA | 2M+1M & 2W+1W turn LH ½ on the side (1x,2x)

17–::

  All set | turn P BH into ; Circle 4H L and face in diagonally (1x,2x)

25–::

  All petronella 1 place cclw | ½ RHA ; Petronella 1 place cclw | ½ LHA (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (15040, '2022-08-25 09:09:55.171477+00', '2023-01-20 19:26:55.596967+00', 2698, 2, 36038, 'ace', 'Round the Room Dance 2 facing 2



1-8::

    All set to opp dancer & change places RH to face new couple; all set to opp dancer & change places LH to face another new couple

9-16::

    All dance RH across & LH across

17-24::

    Ladies Adv+Ret; Men Adv+Ret

25-32::

    Ladies change places RH, Men change places LH; All turn partners 1.1/2 RH to face new couple



', 0);
INSERT INTO 'dancecrib' VALUES (14842, '2022-05-31 20:53:03.457001+00', '2023-01-20 22:54:32.077543+00', 20872, 1, 1645, 'ace', '1-::

  1c cross LH | cast off to midline, 1M above 1W (2c up) ;

  2c+1M & 1W+3c RHA, 1c pass RSh & end (with optional twirl) BtoB facing 1cnr

9-::

  1c set H&G ending on 1diag facing 3cnr

17-::

  1c+3cnrs turn RH, 1c pass RSh on 2diag to face opp side, corners dance 4 bars (2,1x,3) ;

  &frac12; RSh Reel3 on sides, 1c pass RSh & end on diag facing 4cnr pos (3cnr person)

25-::

  Repeat [17-24] with 4cnrs[pos] using LH turn and &frac12; LSh Reel3, 1c end passing LSh to 2pl own side (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (1905, '2012-01-22 19:29:09.095074+00', '2023-01-21 11:03:38.929011+00', 1019, 1, NULL, 'ace', '1–::

  1W (leading)+2W+3W cross, dance down behind the M men, round 3M and up to places.

9–::

  Men repeat (1,2,3)

17–::

  1c facing 2c set and change places RH ; repeat LH (1M & 2W full polite turn) into:

25–::

  1c+2c Allemande, at end 1c cross LH to (2,1x,3)

33–::

  1c Reels3{6} on opposite side (Rsh to 2cnr) | 1c cross RH to (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (1666, '2012-01-22 19:28:53.854244+00', '2022-09-30 21:26:52.887663+00', 9838, 1, NULL, 'ace', '1–::

  All set | cross RH ; set | cross RH (1,2,3)

9–::

  1c dance down and face P (2c up) | set passing Lsh ; Turn 1cnr BH to facing lines across | All set

17–::

  1c set passing Lsh | turn 2cnr BH to (2,1x,3) ; All set | 1c cross Rsh and face out and down

25–::

  Mirror Reels3{6} on the sides | 1c turn 3c EH ½ (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (9276, '2016-07-26 23:47:11.002569+00', '2022-11-27 19:54:50.972238+00', 4498, 2, 2292, 'ace', '1-4::   1st lady turns 2nd man with right hand, while 1st man turns 2nd woman: then giving left hand to partner, they set in line of 4 across the dance.

5-8::   1st couple turn each other round and then join hands in a line of 4 facing the bottom of the dance.

9-12::   They dance down the centre.

13-16::  2nd lady followed by 1st man dance up belhind ladies'' line, while 2nd man followed by 1st lady dance up behind men''s line to finish, 2nd couple at the top and 1st couple on the wrong side in 2nd place.

17-24::  1st & 2nd couples dance 4 hands round and back.

25-28::  1st couple dance 1/2 fingure of 8 round 2nd couple.

29-32::  1st couple turn with right hand 1 1/2 times to finish in 2nd place on own side.', 4);
INSERT INTO 'dancecrib' VALUES (2821, '2012-01-22 19:29:58.777054+00', '2020-12-13 12:15:44.661925+00', 4521, 1, NULL, 'ace', '1–::

  1c+2c ½ RHA, set to P (in middle) ; 1c+2c lead down LH , cross between 3c and cast up to places

9–::

  1c+2c The Knot, 1c finish in promhold, W on the R, facing the W side

17–::

  1c(promhold)+1cnrs (=2M+3W) Reel3 (Rsh to 3W)

25–::

  1c+2cnrs ½Reel3 (Lsh to 2W) ; 1c dance down, cross and cast to 2pl _while{4}_ 2cnrs complete the reel3 (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (11870, '2019-06-02 16:01:45.116461+00', '2022-08-15 11:48:29.731014+00', 19380, 1, 202, 'ace', '1--::

  1c turn RH | cast (2c up) ; cross RH | dance RSh round 1cnrs into facing lines3 across

9--::

  Circle6 L 1¼. 1c finish BtoB in centre, 1W(1M) facing up(down) into DTr up/down

17--::

  All set as in DTr | 1M+3W & 1W+2M change places RH ; all set as in DTr | all set advancing into inverted DTr but on [24] 2M+1M & 1W+2W turn BH ½ ending BtoB

25--::

  All set as in inverted DTr | 2M+1M & 1W+3W change places RH ; all set as in inverted DTr | 1c Petronella turn to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15030, '2022-08-17 08:45:13.51446+00', '2022-08-17 09:28:22.620984+00', 20987, 2, 35920, 'ace', '1-4::

  1s slip step down & back

5-8::

  2s slip step down & back

9-16::

  1s Set advancing, Half Turn both hands )(or Cross RH), cast 1 place, cross RH, cast to Right (finish in the centre M1 above 2s facing down L1 below 3s facing up)

17-24::

  M1 with 2s & L1 with 3s circle to left for 6 slip steps, all turn right about (2s & 3s in places) while 1s dance clockwise behind opposite sides (L1 up / M1 down) to M1 below 3s & L1 above 2s in centre

25-32::

  L1 with 2s & M1 with 3s circle to left for 6 slip steps, all turn right about (2s & 3s in places) while 1s cast to 2nd place own sides & set', 5);
INSERT INTO 'dancecrib' VALUES (14242, '2021-08-15 19:42:51.116832+00', '2022-12-04 13:55:39.793931+00', 20399, 2, 1645, 'ace', '1-8::

  1s+2s+3s 6H round & back

9-16::

  1s lead down the middle & back finishing in the centre facing up

17-24::

  1s cast off (2s step up), & turn LH 1 1/4 times to end 1L btwn 2s & 1M btwn 3s, facing 1st crnrs

25-32::

  All dance LSh reels across

:: *(Crib provided by William Legge)*', 0);
INSERT INTO 'dancecrib' VALUES (14258, '2021-08-21 15:04:14.304166+00', '2022-12-04 13:55:39.797793+00', 20399, 1, 202, 'ace', '1--::

  Circle6 and back (1,2,3)

9--::

  1c lead down ; lead up to 1pl centre (1,2,3)

17--::

  1c long cast (2c up) ; turn P LH 1¼ into lines3 across, 1c facing 1cnrs

25--::

  Reels3 across, 1c LSh to 1cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9165, '2016-06-11 15:57:25.304573+00', '2022-08-19 22:29:53.446861+00', 17024, 1, NULL, 'ace', '1--::    1c+2c & 3c+4c Bourrel. On [7-8] 1c & 4c &frac12; turn P BH & twirl away to end BtoB with P on the midline

9--12::  2c+1W & 3c+4M LHA ending with 1W/4M passing 4W/1M LSh _while{4}_ 1M+4W dance LSh round 1&frac12; times

13--16:: 2c+4W & 3c+1M RHA _while{4}_ 1W+4M dance RSh round 1&frac12; times, all end on the sides facing down/up (2,4,1,3)

17--::   Parallel RSh Reels4

25--::   2c+4c (top) & 1c+3c (bottom) Circle4 to L & back (last time all Circle8 & back) (2,4,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (14886, '2022-06-23 20:41:14.14245+00', '2022-06-23 20:41:26.888491+00', 20901, 1, 1645, 'ace', '1-::

  1c+2c & 3c+4c DblFig8, 1c & 3c start crossing down as 2c & 4c cast up

9-::

  1c+3c Rose progression around standing 2c (3,2,1,4)

17-::

  All set | turn P BH{4} | set

25-::

  3c+2c & 1c+4c Knot, 3c & 1c end facing out for the repeat (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15382, '2023-01-21 14:07:54.71448+00', '2023-01-21 14:11:23.530787+00', 5852, 1, 1645, 'ace', '1--::

  1c set | cast off (2c up) ; &frac12; Fig8 round 3c (2,1x,3)

9--::

  2c+1c R&L

17--::

  1c+3c L-Chain across the set (M dancing across), on final turn 1c end facing 1cnrs

25--::

  Turn CPCP (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (4142, '2013-08-21 08:30:44.128533+00', '2023-02-04 01:18:36.648085+00', 364, 3, NULL, 'ace', '1-8::
    1s lead down & back to top
9-16::
    1s+2s dance Allemande
17-24::
    2s+1s dance R&L
25-32::
    1s dance Fig of 8 round 2s', 0);
INSERT INTO 'dancecrib' VALUES (5688, '2013-08-21 08:31:11.645025+00', '2023-02-04 01:20:25.376826+00', 2941, 3, NULL, 'ace', '1-8::
    1s+2s set & 1M turns left about & changes place LH with 2M, 1M+3M
    set to 2L+3L & 1M turns out & change place LH with 3M.
9-16::
    Reels of 3 on sides, 1L+2L & 3M+1M pass LSh to start. Bars 15-16: 1s
    cross to 2nd place on opposite sides facing out as 2L dances to top
    & 3M to 3rd place own sides
17-24::
    1s dance reels of 3 on opposite sides giving LSh to 2nd corners, 1s
    turn LH to end in diagonal line between 2nd corners
25-32::
    2s+1s+3s Bal-in-Line, 1s turn LH to end between 1st corners &
    Bal-in-Line, 1s turn LH to 2nd places own sides', 0);
INSERT INTO 'dancecrib' VALUES (14234, '2021-08-14 00:22:26.289287+00', '2023-02-04 01:23:06.36412+00', 20147, 3, NULL, 'ace', '1-4::
    1s set advancing _while_ 2s step up, 1s dance RSh round each other
    to 1L between 2s, 1M between 3s
5-8::
    1s pass LSh to dance 1/2 diag reel of 4 with 2nd corners, 1s end in
    2nd place opp sides
9-16::
    1s dance 1/2 Fig 8 (1M up / 1L down) to 2nd place own side; all
    chase clockwise 1/2 round, 1s curve in to face 4th corners (pstn)
17-20::
    1s set to 4th corners (pstn), set to 1st corners (pstn)
21-24::
    1s Petronella turn to opp sides, 1s Ret+Adv (1 bar each) _while_ 2s
    & 3s Adv+Ret (1 bar each)
25-28::
    1s pass LSh to dance 1/2 diag reel of 4 with 3rd corners (pstn) to
    end 1M between 2s at top facing down, 1L between 3s at bottom facing
    up
29-32::
    1s set advancing & dance RSh round each other to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (15013, '2022-08-13 08:43:49.013946+00', '2022-08-13 09:04:57.4454+00', 20982, 2, 35920, 'ace', '1-8::

  1s and 2s Set, turn partner two hands, opening out into circle (4 hands round) to left for four

9-16::

  1s Set, cast into 2nd place, 1½ turn RH to face down in centre on opp sides (2s moving up on 11/12)

17-24::

  1s dance down between 3s & 4s, cast out & up round 4s, cross passing Rsh,(across the causeway)

cast down to 4th place (3s moving up on 19/20) (to flow into Loch Duich)

25-32::

  All circle (8 hands round) to left & back', 5);
INSERT INTO 'dancecrib' VALUES (3119, '2012-01-22 19:30:12.080246+00', '2020-12-16 10:34:30.857674+00', 5609, 1, NULL, 'ace', '1–::

  Parallel Rsh Reels3 on the sides

9–::

  All set | 1c cast (2c up) ; 1c ½ Fig8 round 2c

17–::

  1c facing down in promhold, W on the R, Rsh Fig8 round 3M and 2W, finish facing 1cnr _while_ 2M+3W change places RH, change back

25–::

  1c set to and turn cnrs BH

33–::

  1c facing up in promhold, W on the L, Lsh Fig8 round 2M and 3W, finish facing 2cnr _while_ 2W+3M change places RH, change back

41–::

  All set | 1c cast off to 3plx (3c up) ; 1c ½ Fig8 round 3c (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (10362, '2017-12-27 16:55:39.995691+00', '2022-08-14 10:29:39.864139+00', 14901, 1, 202, 'ace', '1--::

  1c dance BtoB ; 1c+2c Circle4 L

9--::

  Parallel Reels3, 1c Rsh to 2c to start, at end 1c+2c continue the reel to exchanged places, 1M facing out (2,1,3)

17--::

  1M followed by 1W cast R round 2M, dance down the middle, 1c pulling Rsh back at end ; 1W followed by 1M cast L round 2M to 2pl, 1M pulling Rsh back & 1c ending BtoB facing own sides

25--::

  DTr, at end 2c & 3c advance to join P for

33--::

  3C Promenade', 2);
INSERT INTO 'dancecrib' VALUES (15031, '2022-08-17 08:48:33.889235+00', '2022-08-17 08:50:36.801517+00', 20988, 2, 35920, 'ace', '1-8::

  1s dance across set under triangular arch made by 3s(nearer hands facing up), followed by L2 with M4, then by M2 with L4 (who first dance up to first place), divide & cast to original places

9-12::

  All couples Set & Link

13-16::

  All Ladies LH across 3 places to meet partners while Men cast out & dance clockwise 1 place, ½ turn partner RH, finish M facing out, L facing in

17-20::

  ½ Schottische Diamond (in ballroom hold) (Schottische set to M''s Left and pulling Rsh back to set again on 2nd side of diamond - open out to finish facing clockwise (M1 outside)

21-28::

  Ladies RA with L hand on partner''s Rsh & Mens'' R arm on partners'' waist, dance clockwise once round set

29-32::

  All turn two hands & set facing centre (all having moved 1 place anti clockwise 2341)', 5);
INSERT INTO 'dancecrib' VALUES (2281, '2012-01-22 19:29:29.565916+00', '2022-09-30 21:31:09.684871+00', 9810, 1, NULL, 'ace', '1–::

  1W, followed by 1M casts off round 2W and crosses to 2plx (2c up) ; 1c turn 2c RH on side (2,1x,3)

9–::

  1c turn 3c LH on side ; 1W followed by 1M casts off round 3M (3c up) to (2,3,1)

17–::

  1c set adv. | dance up between 3c (3c down) ; cast up behind 2c and dance down between 2c to finish BtoB for

25–::

  2c+1c+3c DTr', 2);
INSERT INTO 'dancecrib' VALUES (13018, '2020-08-07 18:57:19.435038+00', '2020-08-07 19:01:38.638478+00', 18573, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) (to 2,1,3) ; ½ Reels across, 1c RSh to 2cnrs (2x,1x,3x)

9--::

  ½ Reels3 on sides, 1c LSh to 1cnrs[pos] (to 3x,1x,2x) ; ½ Reels3 across, 1c RSh to 4cnrs[pos] (3,1,2)

17--::

  3c+1W & 1M+2c RHA ; 3c+1M & 1W+2c LHA (3,1,2)

25--::

  All turn P RH ½, face P | cast to exchanged places ; all chase clw ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3424, '2012-01-22 19:30:24.903522+00', '2022-08-19 08:55:25.695193+00', 7530, 1, NULL, 'ace', '1–::

  All Clap. 1c (give no hands) cross down, cast behind 3c, cross down between 4c, cast up to own place

9–::

  1c+2c & 3c+4c RHA ; 1c+3c cast off as 2c+4c dance up (2,1,4,3) | 1c+3c turn RH ¾ to midline

17–::

  1c+3c ½ Reel4 ; set to P | Petronella to own side  (2,3,4,1)

25–::

  All circle8 & back', 3);
INSERT INTO 'dancecrib' VALUES (14276, '2021-09-07 19:02:38.575356+00', '2022-08-20 18:07:08.217979+00', 3022, 2, 3069, 'ace', '1-4:: 2+3C Circle L, Finish 2C face down 3C face up nearer hands joined

5-8:: 2+3C set to each other, 2C cast while 3C dance up to change place

9-16:: Reels of 4 on sidelines

17-20:: 3+2C 1/2 R&L

21-24:: 2C 1/2 Fig 8 round 1C, 3C 1/2 Fig 8 round 4C

25-28:: 1+2C set & /2 circle left

29-32:: 1+3C  set & /2 circle left

33-36:: 1+4C set & /2 circle left

37-40:: All set & cross RH

', 2);
INSERT INTO 'dancecrib' VALUES (14883, '2022-06-23 08:04:42.174624+00', '2022-06-23 11:23:17.964221+00', 20874, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; ½ Fig8 to top round 2c, pass P LSh to face 1cnrs
9--::
  ½ Reel4 on 1diag, meet P in centre and swivel R to face 4cnrs ; ½ Reel4 on 2diag, pass P RSh into BiL formation on 1diag
17--::
  BiL on 1diag | turn P RH ¾ into BiL formation on 2diag ; BiL on 2diag | turn P RH ½ to 1plx (3x,1x,2x)
25--::
  All Chase clw ½ ; Allemande turn (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (15383, '2023-01-21 14:13:15.385236+00', '2023-01-21 14:14:18.7785+00', 21316, 1, 1645, 'ace', '1--::

  1c set | lead down & cross below 3c ; cast up (2c up) | cross RH (2,1,3)

9--::

  All chase once round clw

17--::

  2c+3c R&L starting up/down

25--::

  1c+3c S&Link ; Circle4 to L (2,3,1).

::

  *Crib derived from the video*

', 2);
INSERT INTO 'dancecrib' VALUES (12842, '2020-05-24 08:28:29.30176+00', '2022-08-20 19:38:03.65997+00', 19981, 1, 1645, 'ace', '1-::

  1M+2W & 3M+4W turn RH to centre line, M facing down ; &frac12; RSh Reel4

9-::

  4W+3M & 2W+1M turn 1&frac14; RH to sides ; all dance BtoB with new partner

17-::

  1W+2M & 3W+4M turn LH to centre line, W facing down ; &frac12; LSh Reel4

25-::

  4M+3W & 2M+1W turn 1&frac14; LH to sides (3,4,1,2) ; all dance BtoB

33-::

  1c+2c &frac12; Circle4 to L | 4c+2c &frac12; Circle4 to R ; 3c+2c &frac12; Circle4  to L | all cross RH (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15035, '2022-08-21 22:28:40.161811+00', '2022-08-21 22:43:52.517741+00', 20997, 1, 1645, 'ace', '{{explanation}}

Strathspey



1--::

  1c cast off (2c up) | 1W/1M dance through arches made by 2c/3c who dance down/up ;

  1c cast LSh round 1cnr & up/down to ends of centre line _while{3}_ 2c+3c &frac34; RHA,

  then 1M+3W+2W & 3M+2M+1W &frac13; LHA{1}.

  3W & 2M end on centre line in 1pl/3pl, 1M+2W & 3M+1W face across

9--::

  3C Bourrel from these places: 3W & 2M chase &frac12; round cclw _while{4}_

  1M+2W & 3M+1W set adv | turn &frac34; BH & twirl away to face P on centre line ;

  all set | turn P &frac34; BH to sides (2,1,3)



{{explanation}}

Reel



17--::

  1c birl to face 1cnr ; 1c+1cnrs &frac12; RSh diag Reel4, but after passing LSh 1cnrs loop L to take P in promhold (3W has P on R) as 1c pass RSh to face 2cnr pos

25--::

  1c+cnrs &frac12; RSh diag Reel4, all end on centre line, nearer opp sides, facing P ;

  all birl to own side (3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (12791, '2020-05-04 10:25:17.863406+00', '2022-08-22 23:05:26.988249+00', 19910, 1, 202, 'ace', '1--::

  1c set | cross RH ; 1c & 2c face on sides and set | 1c+2c change places LH on sides. M face out (2,1x,3)

9--::

  La-Chain. 1c face down (2,1x,3)

17--::

  »Modified 3C Gr-Chain« {6} [: same as 3C Gr-Chain, 2c crossing RH but with 2 steps per hand] (to 3x,1,2x) | all set

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12792, '2020-05-04 14:41:13.967869+00', '2023-01-22 19:52:23.075247+00', 18729, 1, 202, 'ace', '1--::

  1c set | cast off 2 places (2c up) ; cross RH | cast up to 2plx (2,1x,3)

9--::

  Diagonal R&L (3x,1x,2x)

17--::

  All turn P RH ; all chase clw ½, 3W & 2M pulling LSh back ready for (2,1,3)

25--::

  Reels3 on sides, 1c LSh to 3cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12153, '2019-09-03 07:37:44.32579+00', '2022-08-14 10:43:44.846103+00', 15198, 1, 202, 'ace', '1--::

  1M followed by P cast off two | dance across the set ; cast up two | cross over to 2pl (1,2,3)

9--::

  1c & 2c set on sides | turn EH ½ on sides, 1c out and down ; 1c+3c Circle 4 L (2,1,3)

17--::

  1c turn P RH and face down on sides ; 1c & 3c set on sides | turn EH ½ on sides, 1c in and down. 1c face out (2,3,1)

25--::

  1c cast up behind 3c, dance up between 2c and cast back to 3pl (2,3,1)

33--::

  Circle 6 and back (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (15027, '2022-08-17 08:27:19.066986+00', '2022-08-17 08:53:22.498758+00', 20983, 2, 35920, 'ace', '1-4::

  1s, 3s & 5s Set advancing, balance-in-line in centre of set

5-8::

  1s & 5s turn RH, 1s cast to 2nd place, 5s cast to 4th place while 3s turn RH & return to sides (2s & 4s stepping out to 1st & 5th places)

9-16::

  2s, 3s & 4s Set advancing, balance-in-line in centre of set 2s & 4s turn RH, cast to 2nd end place, while 3s turn RH & return to sides (1s & 5s moving out to 1st & 5th places)

17-24::

  All set, face up 1s cast to 5th place followed by 2s,3s,4s & 5s dancing up and casting to 54321 and set

25-28::

  5s,4s,3s & 2s ½ reel of 4 on sides while 1s turn RH (or birl) (23451)

29-32::

  All set & TR', 5);
INSERT INTO 'dancecrib' VALUES (10188, '2017-10-18 11:24:23.121604+00', '2022-08-19 09:20:00.543925+00', 17998, 1, 202, 'ace', '1--::

  1c set | cast (2c up) ; dance between 3c | cast up to 2pl (2,1,3)

9--::

  1c Petronella turn | set ; repeat [9-12] (2,1x,3)

17--::

  1M+2c & 1W+3c RHA (Teapots R) ; 1c dance Lsh round P _while{4}_ 2c+3c chase clw ½ (3x,1x,2x)

25--::

  1M+3c & 1W+2c RHA (Teapots R) ; 1c turn LH 1 ¼ to 2pl _while{4}_ 3c+2c chase clw ½ (2,1,3) ', 4);
INSERT INTO 'dancecrib' VALUES (13017, '2020-08-07 04:31:49.289196+00', '2021-04-02 21:57:19.532793+00', 12823, 1, 202, 'ace', '1-4::
  2c ½ Fig8 up round 1c _while{4}_ 3c set | cross RH (1,2x,3x,4)
5-12::
  Reels4 on sides (1,2x,3x,4)
13-16::
  1c & 4c cross RH | cast inwards (2c & 3c step out) (2x,1x,4x,3x)
17--::
  1c+4c RHA ; LHJ with nearest cnrs, all RHA ½ to sides (3,4,1,2)
25--::
  2c+3c 6 bars of R&L _while{6}_ 4c+1c Circle4 L ; set | 4c+1c lead down to 3pl/4pl _while{2}_ 3c dance to 2pl (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (1871, '2012-01-22 19:29:07.233079+00', '2020-08-07 20:02:07.000423+00', 905, 1, NULL, 'ace', '1–::

  1c+5c cross RH and cast one towards middle of set ; 1c+5c turn 1¼ RH to centre line (M face up, W down)

9–::

  1c+5c Reel4 _while_{8} 2M+3M+4M & 2W+3W+4W Reels3 on sides (3c starts inwards giving Rsh)

17–::

  1c+2c & 4c+5c RHA ; LHA (1c+5c finish in the middle)

25–::

  1M+5W 1½ RH turn ; 1W+5W & 1M+5M 1½ LH turn, each pair ending on own sides, (on [29] 2M+3M+4M & 2W+3W+4W step one place to the left) (finishing order M 2-3-4-5-1 and W 5-1-2-3-4, i.e. not facing own P)', 2);
INSERT INTO 'dancecrib' VALUES (15036, '2022-08-21 22:39:10.010087+00', '2022-10-24 14:54:11.939576+00', 21001, 1, 1645, 'ace', '1-::

  1c cross RH | set to P ; 1c+2c &frac12; turn RH/LH on M/W side to DTr pos | all set as in DTr

9-::

  1c+1cnrs &frac12; diag RSh Reel4, 1c pass RSh to 2pl own side ;

  1c+3M/2M mirror S&Link, 1c cast, 3M & 2M dance up & face out (M side: 3W,3M,1M; W side 2W,2M,1W)

17-::

  3c/2c (M/W side) &frac12; turn RH/LH _while{2}_ 1c cross LH | all set facing in without taking hands ;

  1c+3W/2W &frac12; turn LH/RH on M/W side to DTr pos | all set as in DTr

25-::

  1c+1cnrs[pos] turn RH{4}, 1c pass RSh to lines of 3 across (3M+1M+2M & 3W+1W+2W) ;

  all chase &frac34; clw (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (12686, '2020-03-26 22:36:56.143324+00', '2022-08-22 23:33:57.463774+00', 19905, 1, 202, 'ace', '1--::

  1c+2c the Knot (2,1,3)

9--::

  2c+1c the Bourrel. 1c face out (1,2,3)

17--::

  1c cast off (2c up) | 1c cross LH (to 2,1x,3) ; all chase cclw ½ (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14999, '2022-08-12 07:00:00.238847+00', '2022-08-24 03:24:06.905837+00', 20974, 2, 35920, 'ace', '1-4::
  1s & 2s Set & Link
5-8::
  2s & 1s RA finishing 2s facing out
9-16::
   Reel of 3 on the sides - 1s crossing up to dance on opposite sides, 2s down, 3s out & up 1s turn R finishing facing 2s on opp sides, as 2s extend reel into 2nd place  
17-32::
  The Spurtle  
  _17-20_ 1s & 2s dance ½ reel of 4 (L1 Rsh to M2 , M1 Rsh to L2) (2s crossing the set in 2 steps & dancing up with 2 small steps) 1s turn RH in the middle to repeat with 3s  
  _21-24_ 1s & 3s ½ reel of 4,1s turn RH while 3s dance up  
  _25-28_ 1s & 4s ½ reel of 4, 1s TR to 4th place on opposite sides, while 4s dance up  
  _29-32_ All set on the side, cross RH', 5);
INSERT INTO 'dancecrib' VALUES (15385, '2023-01-22 12:28:01.590275+00', '2023-01-22 12:28:58.310087+00', 21313, 1, 1645, 'ace', '1--::

  1c+2c &frac12; Circle4 to L | set, pulling back RSh ; chase &frac12; way clw to original pl |

  1c &frac12; turn RH moving down & pivot to face 1cnrs _while{2}_ 2c dance up to 1pl

9--::

  1c+1cnrs Set to Corners & Cast Away (Best Set in the Hall figure), end facing 2cnrs

17--::

  Repeat with 2cnrs, end on opp sides (3x,1x,2x)

25--::

  S&Link3 twice (2,1,3).

', 2);
INSERT INTO 'dancecrib' VALUES (4115, '2013-08-21 08:30:43.809123+00', '2023-02-04 01:18:35.136702+00', 11583, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 1s turn RH 1.1/2 times _while_ 2s+3s chase 1/2 way.
    (3)(1)(2)
9-16::
    3M+1M+2M Adv+Ret & set _while_ partners set & Adv+Ret, all turn RH
    for…
17-24::
    3s+1s+2s dance Allemande & end with 1s set advancing to 1st corners
25-32::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    Pass+Turn with 2nd corners 1s ending 2nd place own sides', 5);
INSERT INTO 'dancecrib' VALUES (15388, '2023-01-23 15:29:24.316359+00', '2023-01-23 15:38:24.974147+00', 12861, 1, 202, 'ace', '1--::

  All W cross and dance RSh round P ; once behind M line, 1W leading, all W chase clw to W side into reversed order

9--::

  All M cross and dance LSh round opposite person ; 1M leading, all M chase cclw to M side. On [16] 2W & 3W step in _while_ 2M curves in and up & 3M dance in and down into Rondel position (3,2,1)

17--::

  3c+2c Rondel. 2c face up and 3c face down (2,3,1)

25--::

  Mirror Reels3 on sides, 3c out and down (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (8230, '2014-04-02 19:25:54.000301+00', '2022-09-30 12:20:12.730032+00', 10476, 2, 160, 'ace', '1–8::

 1C cross, cast 1pl.; 2C+1C turn RH.

9-16::

 1C cross LH, cast 1pl.; 2C+3C+1C turn LH & face ccw.

17–24::

 Chase CCW once round.

25–32::

 1W followed by 1M, cast up 1pl. cross to opp. side (3C down); 1C turn LH 1-1/2 to own side.', 0);
INSERT INTO 'dancecrib' VALUES (11316, '2018-10-29 01:21:43.566506+00', '2022-08-14 10:50:26.250553+00', 15206, 1, 202, 'ace', '1--::

  1c+3c ½ R&L (no polite turn) and face cclw (W leading) ; chase cclw one place | set _while{8}_ 2c & 4c set | advance {2} ; pivot R ½ | set (into longwise set 1x,2x,4,3)

9--::

  1c+2c & 4c+3c RHA ; 1c & 3c (M leading) chase clw ½ _while{4}_ 2c+4c LHA and face out (longwise set 3x,2x,4,1)

17--::

  2c & 4c pass opp persons LSh and chase cclw one place (to 2,3,4,1) ; 2c+4c ½ R&L (4,3,2,1)

25--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (3399, '2012-01-22 19:30:23.752109+00', '2022-09-30 21:34:20.550947+00', 9785, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; cross LH | cast L to between end couples (M down, W up)

9–::

  1c turn LH _while_{4}   2c+3c turn P RH ; 1c dance through ends (M down, W up) and cast L to 2plx _while_{4} 2c+3c set and petronella to midline

17–::

  1c turn LH _while_{4}    2c+3c turn P RH ; 1c cast L through opposite side and between end couple to 2pl _while_{4} 2c+3c set and petronella turn (to 2x,1,3x)

25–::

  2c+3c set | La Baratte _while_{8}   1c petronella to midline | set advancing to join RH ; join in the last 4 bars of La Baratte (2,1,3)



{{explanation}}

La Baratte [6 bars]: [turn P RH ½ to full arms'' length | change back sideways, W passing in front with her back to M, changing hands overhead to LH | turn LH ½ to exchanged places]', 2);
INSERT INTO 'dancecrib' VALUES (15032, '2022-08-17 08:55:58.143523+00', '2022-08-17 09:20:16.402892+00', 20989, 2, 35920, 'ace', '*Paisley-side M S48/R48 Alternatively danced progressively round the room in Reel time

Set – Man with 2 ladies (L1 on his R,L2 on his left) facing a man with 2 ladies*  

_Strathspey_

1-8::

  All Set, Dos-si-dos and set

9-16::

  M in promenade hold with L1(on R) pass Lsh into reel of 4 across dance throughout 17-24 M retain hand holds (L hand with L1 and R hand with L2)

17-18::

  M drop R hand hold, retain L-hand hold with L1 make an arch & pass L1 to left,

while taking L2 with R-hand under arch to Right

19-20::

  M and L2 make arch and L2 dances back to place while L1 by L hand passes under the arch All face about

21-22::

  L1 making the arch dances across while L2 passes under all face about again

23-24::

  L2 makes the last arch while L1 passes under ie L1 with L hand over-under-over-under - while L2 with R hand under-over-under-over

25-32::

  M Reel of 3 with partners (Rsh to L1)

33-36::

  M cross passing Lsh to RA on opposite sides

36-40::

  M cross back to LA on own sides

41-44::

  ½ reel of 3 with partners (Rsh to L1)

45-48::

  Advance & retire (or progress to next set) Ladies have change places



_Reel_



Repeat [1-48]', 5);
INSERT INTO 'dancecrib' VALUES (13019, '2020-08-07 22:13:34.289766+00', '2020-08-07 22:18:19.850267+00', 467, 1, 202, 'ace', '1--::

  1c turn P RH | cast off (2c up) ; ½ Reel4 on 1 diag

9--::

  ½ Reel4 on 2diag (to 3x,1x,2x) ; all turn P RH into promhold facing down

17--::

  3C Promenade (3x,1x,2x)

25--::

  All A&R ; Circle6 L ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10704, '2018-04-28 19:52:12.17279+00', '2022-08-24 10:42:12.073628+00', 16687, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; 1c turn LH 1¼ into promhold facing 3W
9--::
  RSh Reel3 on 1diag, 1c end facing 2W
17--::
  RSh Reel3 on 2diag, 1c end in 2pl centre facing up
25--::
  1c dance up and cast off to 2pl ; turn RH (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14884, '2022-06-23 08:38:04.665616+00', '2022-06-23 08:40:05.352631+00', 20875, 1, 202, 'ace', '1--::

  1c cross RH _while{2}_ 2c & 3c set | 1c set and cross RH _while{4}_ 2c+3c Circle4 L | all set (1,2,3)

9--::

  1c+2c Tourbillon (2,1,3)

17--::

  1c dance RSh round 3cnrs | meet in centre and turn P L ¾ ; dance RSh round 2cnrs to 2plx (2,1x,3)

25--::

  ½ Reels3 on sides, 1c LSh to 1cnrs[pos] ; 1c turn P BH 1½', 2);
INSERT INTO 'dancecrib' VALUES (4122, '2013-08-21 08:30:43.917959+00', '2023-02-04 01:18:35.765935+00', 329, 3, NULL, 'ace', '1-8::
    1L+2L+3L cross & dance round partner RSh back to places & turn
    partners RH
9-16::
    1M+2M+3M repeat
17-24::
    1s+2s+3s Promenade
25-32::
    1s cross RH, cast 2 places, cross RH & change places LH with 4s on
    sides', 0);
INSERT INTO 'dancecrib' VALUES (7951, '2013-08-21 08:31:51.788374+00', '2023-02-04 01:23:13.463225+00', 7159, 3, NULL, 'ace', '1-8::
    All Ladies cast round partners, in to face partner & set twice
9-16::
    All Ladies cast back round partners & turn partner LH
17-24::
    1s+3s slip step down/up (Men passing BtoB), set & slip step back to
    places (Ladies BtoB)
25-32::
    2s+4s repeat
33-48::
    All Ladies cast round partners & in to face partner, all dance RSh
    reels of 4 (all passing LSh in centre)

{{explanation}}
Men repeat bars 1-16, turning partner RH in bars 13-16', 0);
INSERT INTO 'dancecrib' VALUES (15043, '2022-08-29 06:28:44.267976+00', '2022-08-29 06:37:41.848442+00', 20940, 1, 202, 'ace', '1-4::

  1c turn RH | cast off (2c up) (2,1,3)

5-16::

  3C R&L (2,1,3)

17--::

  All set | cross RH ; set | cross RH (2,1,3)

25--::

  3C Promenade (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15044, '2022-08-29 06:59:31.81405+00', '2022-08-29 07:14:58.655162+00', 20767, 1, 202, 'ace', '*Trios face trios RR*
1--::
  Circle6 and back
9--::
  Middle couple turn 1cnrs RH, pass P RSh ; turn 2cnrs RH, pass P RSh to original places
17--::
  3C Set&Rotate
25--::
  All set | ends on each trio change places like in bars 3-4 of 2c Set&Link ; set | cross LH and face a new trio', 2);
INSERT INTO 'dancecrib' VALUES (9820, '2017-05-04 19:23:06.371738+00', '2022-08-13 09:36:14.667301+00', 8526, 1, 202, 'ace', '1--::

 1W+3M cross RH | 1M+3W cross RH ; 2c cross RH -| 3c+2c+1c turn RH ½ for

9--::

 3C Allemande (1,2,3)

17--::

 1c set | cast (2c up) ; 3c set | cast (1c down) (2,3,1)

25--::

 Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (14459, '2021-11-21 22:39:20.881581+00', '2022-11-29 22:05:41.604874+00', 20562, 1, 1645, 'ace', '1-4::

  1W & 3W &frac12; Fig8 out nearest side _while{4}_ 1M+3M turn 1&frac12; RH to end BtoB facing P in line up/down ready for

5-8::

  1c+3c &frac12; LSh Reel4 up/down

9-12::

  1c & 3c &frac12; turn LH | set _while{4}_ 2c & 4c &frac12; turn RH | 2W & 4W cross between 3c & 1c as 2M & 4M loop back

13-16::

  1c & 3c &frac34; turn LH | 1W & 3W cross between 2c & 4c as 1M & 3M loop back _while{4}_ 2c & 4c &frac34; turn RH | set 

17-20::

  1c & 3c _full_ turn LH | 1M & 3M cross between 4c & 2c as 1W & 3W loop back _while{4}_ 2c & 4c &frac12; turn RH | set

21-24::

  1c & 3c &frac34; turn LH | set _while{4}_ 2c & 4c &frac34; turn RH | 2M & 4M cross between 3c & 1c as 2W & 4W loop back

25-32::

  1c & 3c &frac34; turn _RH_ to sides _while{2}_ 2c & 4c &frac12; turn RH (3,4,1,2) | all chase &frac34; clw (4,1,2,3)', 5);
INSERT INTO 'dancecrib' VALUES (2934, '2012-01-22 19:30:03.533349+00', '2022-09-30 12:32:15.514468+00', 10290, 1, NULL, 'ace', '1–::

  1c+2c set | ½ circle4 L ; set | cross RH (2,1,3)

9–::

  1c+3c repeat (2,3,1)

17–::

  1c turn BH | cast up to 2pl (3c down) ; turn BH | cast up to 1pl (2c down) (1,2,3)

25–::

  1c+2c Tournée.', 2);
INSERT INTO 'dancecrib' VALUES (10160, '2017-10-03 14:23:03.06228+00', '2020-08-07 09:40:59.152534+00', 6309, 2, 1824, 'ace', '1-8--::

 1s and 3s  lead down for four and back to place

9-16--::

  1s + 2s + 3s + 4s facing up slip-step to opposite sides, set twice (1s & 3s turn about on second setting to face couples below them). All 4 couples slip-step back to own sides of the dance and set twice [1s facing 2s & 3s facing 4s]

17-24--::

  1s + 2s and 3s + 4s dance ladies chains

25-32--::

  1s + 2s and 3s + 4s dance rights and lefts half-way [2 (1) 4 (3)]. 1s and 3s cross RH, 1s cast off to 4th place  while 3s lead up to 2nd place [2 3 4 1]', 2);
INSERT INTO 'dancecrib' VALUES (15041, '2022-08-25 21:17:35.760279+00', '2022-08-25 21:22:42.829052+00', 10169, 1, 202, 'ace', '1--::

  All set | 2c set _while{2}_ 1M+3W turn RH ¾ to opposite end same sides and face out _while{2}_ 1W casts off & 3M casts up to opposite end same sides (to 3,2,1) ; all chase clw ¾ into facing lines3 across

9--::

  All set | 2c set _while{2}_ 1M+3W turn LH ¾ to opposite end same lines _while{2}_ 1W casts above Wline & 3M casts below Mline to opposite end same lines ; all chase cclw ¾ (1,2,3)

17--::

  1c set | cross down RH to 2plx _while{4}_ 2c cross RH | cast up to 1plx (to 2x,1x,3) ; 2c+1c ½ DblFig8, 2c crossing down (2,1,3)

25--::

  3C Gr-Chain, 2c crossing RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (10118, '2017-09-11 23:01:00.966902+00', '2022-08-26 12:17:11.268114+00', 17926, 2, 1, 'ace', '1–::
  1c+2c “Rose Progression”: 1L+2M change places R | cast 1pl clw ;
  turn B ½, face and twirl away _while_ 1M+2L set | turn B ½, face and
  twirl away | cross to other side (2, 1)
9–12::
  1c turn B 1¼ to lines across (2c+1M, 3c+1L)
13–16::
  All S&link for 3 (2x 1x 3x)
17–::
  All S, Petronella to midline, set, Petronella to sides (2 1 3)
25–28::
  All S&link for 3 to lines across (3c+1M, 2c+1L)
29–32::
  1c turn B ¾ to face, and twirl away to sides (3 1 2)', 2);
INSERT INTO 'dancecrib' VALUES (13020, '2020-08-08 11:15:12.084399+00', '2020-08-08 11:24:59.952312+00', 6367, 1, 202, 'ace', '1--::
  »Modified R&L« [: 1-2 set no hands | 3-4 cross RH with polite turn ; 5-6 set | 7-8 cross LH with polite turn]
9--::
  Repeat [1-8] back to places
17--::
  All with hands crossed (LH below) slip down ; and up retaining hands ready for
25--::
  2C Allemande (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (15038, '2022-08-21 22:46:37.866982+00', '2022-09-01 16:41:02.353883+00', 20998, 1, 1645, 'ace', '1-4::

  1c+3c &frac12; Men''s Change (M-Chain without hands)

5-8::

  All dance back to back with facing person, starting RSh (3M+1W,2,1M+3W,4)

9-12::

  All set HS right | M dance to next M place cclw _while{2}_ W chase clw &frac12; way in centre (2M+3W,1M+4W,4M+1W,3M+2W)

13-16::

  All set HS left | W dance to next W place clw _while{2}_ M chase cclw &frac12; way in centre (4M+2W,3,2M+4W,1)

17-20::

  All dance back to back with facing person, starting LSh

21-24::

  2c+4c &frac12; Men''s Change (2,3,4,1)

25-32::

  All dance &frac12; Grand Change (Grand Chain without hands) 2 bars per person (4,1,2,3)

', 5);
INSERT INTO 'dancecrib' VALUES (14887, '2022-06-23 20:56:29.16421+00', '2022-06-23 20:57:09.78738+00', 20553, 1, 1645, 'ace', '1-::

  1c long cast to 2pl (2c up on [3-4]) ;

  1c repeat to 3pl _while_ 2c long cast to 2pl _while_ 3c dance up NHJ & face up _while_ 4c dance in & cast out to sides facing out (3,2,1,4)

9-::

  3c+2c & 1c+4c DblFig8, 2c & 1c start crossing to ends (no hands) as 3c & 4c cast inwards, 3c & 4c end facing out

17-::

  3c+2c & 1c+4c turn 1&frac12; EH on sides (2,3,4,1) ; 3c & 4c dance NHJ up/down out the ends & cast back to place

25-::

  All circle8 to L & back (2,3,4,1)



', 2);
INSERT INTO 'dancecrib' VALUES (15042, '2022-08-28 06:32:11.095609+00', '2022-08-28 23:11:02.379874+00', 3906, 1, 202, 'ace', '1--::

  *4C Snowball Gr-Chain* : Top and Bottom couples cross RH to start a Snowball Chain (4x,2x,3x,1x)

9--::

  1c lead up and cross to 1pl _while{4}_ 4c cast off to 4plx (to 1,2x,3x,4x) ; all set | 1c cast off _while{2}_ 2c cross up to 1pl _while{2}_ 3c & 4c cross RH. 2c & 3c retain RH (2,1,3,4)

17--::

  2c+1W & 1M+3c RHA, 1c pass P LSh ; LHA (2,1,3,4)

25--::

  1c turn RH (elbow grip) | cast off to 3plx (3c up) ; cross RH | 1c+4c change places LH on sides (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (15386, '2023-01-22 12:31:45.328541+00', '2023-01-22 12:32:54.791945+00', 21314, 1, 1645, 'ace', '1--::

  1c+2c Circle4 to L ; set on sides | petronella to midline, W facing down, M up

9--::

  *Interlocking Mignonettes:*  

  1: All set to R with &frac14; turn, RSh back, on hop  

  2: Repeat to L, again RSh back  

  3: Set R to face P on midline in exchanged places  

  4: 1W+2M set L curving round, LSh back, to change places _while_ 1M & 2W small set L  

  5--8: Repeat from new places, end 2c above 1c, M facing down to P on midline

17--::

  2c+1c Reel4 on midline

25--::

  All set to P | petronella to sides ; turn P BH (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15266, '2022-11-30 10:27:13.98842+00', '2022-11-30 15:16:35.458213+00', 5800, 1, 202, 'ace', '1--::
  1c (+2c who dance up to follow) cast off two places, meet and dance up to top | 1c cast off to face 1cnrs _while{2}_ 2c dance up to top
9--::
 1c dance path of Reel4 round 1cnrs. 1c pass P LSh to face 2cnrs
17--::
  1c dance path of Reel4 round 2cnrs. On [23-24] 1c pass P LSh as for DTr position
25--::
  1M+2W+3W & 1W+2M+3M Circle3 L ; all dance last 4 bars of DTr (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14893, '2022-06-24 22:19:41.36729+00', '2022-06-27 12:07:30.696774+00', 20899, 1, 202, 'ace', '1--::

  1c Fig8 down round 2c giving RH then LH when crossing (1,2)

9--::

  1W+2M turn LH1¼ into 1diag facing P ; ½ Poussette (2,1)

17--::

  2c+1c Set&Link ; Circle4 L (1,2)

25--::

  Rose Progression (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (13021, '2020-08-09 12:09:16.263535+00', '2020-08-09 18:17:38.573109+00', 20065, 1, 202, 'ace', '1--::

  1c Fig8 down round 2c (1,2,3)

9--::

  2c (1c following) cross between 3c, cast up, cross down between 3c again, and cast up (2,1,3)

17--::

  1c (3c following) cross up between 2c, cast off, cross up between 2c again, and cast down (2,3,1)

25--::

  1c Fig8 up round 3c (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (13022, '2020-08-09 21:29:11.949798+00', '2020-08-09 21:37:21.947616+00', 15635, 1, 202, 'ace', '1--::

  1c cast off (2c up) | dance down ; on [5-6] change sides to face up, 1W crossing above 1M and under joined arms | dance up to 2pl centre (2,1x,3)

9--::

  Mirror Reels3 on sides, 1c dance to top and cast off, 2c cast off and down between 3c, 3c cast up. On [15-16] 1c pass P RSh to face 4cnrs

17--::

  Set to and Turn 4cnrs RH. 1c face 1cnrs ; Set to and Turn 1cnrs RH. 1c face 2cnrs

25--::

  Repeat [17-24] with 2cnrs then 3cnrs

33--::

  Reels3 across, 1c LSh to 2cnrs. 1c pass P RSh to 2pl and face out (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9772, '2017-04-06 10:41:14.790121+00', '2020-08-23 10:15:37.710767+00', 17310, 1, 202, 'ace', '1--::

 1c set | 1W followed by 1M cast off one ; cross to 2plx (2c up) | turn RH ½ and stay in middle RHJ (2,1,3,4)

9--::

 2c+1c RHA ; 1M followed by 1W cast off one | cross to 3plx (3 up) (2,3,1x,4)

17--::

 1c turn LH ½ and stay in middle LHJ | 3c+1c LHA | All set (2,3,1,4)

25-28:: 

 1c&4c Petronella | 1c&4c turn RH

29-36::

 »½ Celtic reel«: 1c+4c pass Rsh | “outers” chase clw ¼ _while{2}_ “inners” turn (no hands) Lsh ¾ to face P ; repeat [29-32]

37-40::

 4c&1c turn RH | Petronella (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (11512, '2019-01-16 03:36:14.681327+00', '2020-08-07 09:49:28.571753+00', 6558, 1, 202, 'ace', '1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 2c+1c & 4c+3c facing on sides set | turn facing person ¾ into 2 lines4 across in BiL[pos]

9--::

  BiL, release LH in middle | turn RH ½ into 2 lines4 across in BiL[pos] ; BiL, release LH in middle | turn RH ¾ to sidelines (1x,2,3,4x)

17--::

  1c & 4c turn P RH 1½ _while{4}_ 2c & 3c turn P RH ; 1c cross RH | cast (2c up) (2,1x,3,4)

25--::

  1c set | cast off (3c up) ; 1c cross RH | cast off (4c up) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (15039, '2022-08-21 22:50:47.486056+00', '2022-08-21 22:56:29.228277+00', 20999, 1, 1645, 'ace', '

1-::

  All turn P LH and face corners ; all turn corner RH, 1M & 3M end BtoB in centre facing P

9-::

  1c+3c &frac12; RSh Reel4, 1M+3M pass LSh & face 4W/2W ;

  4W+1M+3M+2W &frac12; RSh Reel4, 1M+3M pass RSh to original pl (M: 1,2,3,4; W: 3,4,1,2)

17-::

  All S&Link on sides with new P ; S&Link with corner & end beside P, M facing out (2,3,4,1)

25-::

  *Corner Schiehallion:* W dance straight across & face out _while{2}_ M loop to R round corner & face in |

  repeat 3 times{6} from new places to end facing P (4,1,2,3)

', 5);
INSERT INTO 'dancecrib' VALUES (15037, '2022-08-21 22:43:12.817063+00', '2022-08-30 17:33:16.444375+00', 21000, 1, 1645, 'ace', '*2c & 4c start on opposite sides (1,2x,3,4x)*
1-::
  2c & 3c petronella to centre line | set ; turn &frac34; RH | set (1,2,3x,4x)
9-::
  2c & 3c &frac12; Fig8 through nearest end ; 2c+3c LHA (1,2x,3,4x)
17-::
  1c+2c & 3c+4c bit less than &frac12; RHA, retain RH & 1c+4c also join LH at a slight angle to the sidelines | all set ;
  1c+4c &frac12; turn LH on sides _while{2}_ 2c & 3 cross RH, M/W face out/in | all BiL on sides (2x,4,1x,3)
25-::
  All &frac12; Reels4 on sides ; 3c+1c & 4c+2c each circle4 to L (3,1x,4,2x)
', 5);
INSERT INTO 'dancecrib' VALUES (12976, '2020-07-24 00:23:09.696202+00', '2022-12-19 00:59:08.692505+00', 9663, 1, 202, 'ace', '1--::

  1W+2M turn LH ½ | chase cclw _while{2}_ 1M & 2W A&R{1+1} ; turn RH to original places (1,2)

9--::

  1M+2W turn RH ½ | chase clw _while{2}_ 1W & 2M A&R{1+1} ; turn LH to face P on 2diag

17--::

  Reel4 on 2diag. End as on [17]

25--::

  1M turn P RH to 2Wpl _while{2}_ 2W turn P RH to 1Mpl | all chase clw 1 place (to 2,1) ; Circle4 L', 5);
INSERT INTO 'dancecrib' VALUES (15045, '2022-09-01 16:43:10.43838+00', '2022-09-01 16:43:20.07573+00', 21002, 1, 1645, 'ace', '1--::

  1c+2c Chain progression, 1c end with just &frac12; RH to face up in tandem, 1W above 1M

9--::

  1c, 1W leading, tandem &frac12; Fig8 RSh round 2W (2,1x,3) ; 1c+3c LHA, 1W ends facing up on centre line

17--::

  1c, 1W leading, tandem &frac12; Fig8 LSh round 2M (2,1,3) ; 1c+3c RHA ending on sides

25--::

  2c+1c+3c Circle6 to L & back (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (15046, '2022-09-02 10:09:24.449107+00', '2022-09-02 10:11:16.917867+00', 20693, 1, 1645, 'ace', '1--::

  Mirror Reels3 on sides, 2c start out & up, 1c & 2c end in promhold facing up

9--::

  1c+2c Allemande (2,1,3)

17--::

  1c+3c Circle4 to L & back, ending in the middle

25--::

  1c+3c Poussette (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11652, '2019-03-08 01:17:05.864146+00', '2022-09-02 14:28:47.773544+00', 17253, 1, 202, 'ace', '*3c & 4c start on opposite sides (1,2,3x,4x)*

1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; all set | turn P BH ½ opening to face 2c & 4c down, 1c & 3c up, all NHJ with W on M''s right (2x,1,4x,3)

9--::

  »Zig Zag Progression« [All set advancing, passing LSh to exchanged places | 1c & 4c (ends) turn P BH ½ opening to face 1c down, 4c up _while{2}_ 2c & 3c (middles) set advancing, passing LSh to exchanged places, all NHJ with W on M''s right ; repeat [9-10] | 3c & 2c (ends) dance forward and loop to sides _while{2}_ 1c & 4c (middles) set advancing, passing LSh to exchanged places, NHJ] (3,4,1x,2x)

17--::

  4c & 1c dance out through end cpls | cast inwards (to 3,4,1x,2x) ; 4c+1c set | ½ RHA (3,1,4x,2x)

25--::

  Circle8{2} L | set in the circle ; Circle8{2} R to sides | all set (3,1,4x,2x)', 5);
INSERT INTO 'dancecrib' VALUES (14819, '2022-05-08 23:18:43.006163+00', '2022-06-25 08:43:47.662461+00', 20806, 1, 1645, 'ace', '1--::

  1c set | cast off ; 1c+2c &frac12; R&L (1x,2x,3)

9--::

  1c set | cast off ; 1c+3c &frac12; R&L (2x,3x,1)

17--::

  1M+3M change pl RH | 1W+3W change pl RH (2x,1x,3) ; 1c+2c set | 2c cross RH _while_ 1c pass R to end BtoB

25--::

  2c+1c+3c Double triangles (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (15050, '2022-09-04 09:12:11.977735+00', '2022-09-04 09:12:21.789353+00', 21096, 1, 1645, 'ace', '1--::

  1M+2W set | change pl RH ; 1W+2M & 1M+3M set | change pl RH

9--::

  1W+3W set | change pl RH ; 1c set | cast up (3c down) to (2x,1,3x)

17--28::

  *Figure of 8 Grand Chain:*

  2W+1M & 1W+3M change pl RH on sides _while{2}_ 2M+3W change pl RH on 2diag |

  1c change pl LH on 1diag _while{2}_ 2c & 3c change pl LH on sides ;

  repeat pattern twice more from new places (2x,1,3x)

29--32::

  1c turn P RH _while{4}_ 2c & 3c turn P 1&frac12; RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (15049, '2022-09-02 18:52:51.493061+00', '2022-09-02 19:40:51.528361+00', 20932, 1, 202, 'ace', '1--::
  1c set | cast off ; dance down | cast up to 2pl (2c up) (2,1,3)
9--::
  3C Set&Link ; 1c turn RH 1¼ to 2plx and face out _while{4}_ 2c & 2c chase clw ½ (2x,1x,3x)
17--::
  1c dance RSh round 1cnrs[pos] | pass P LSh up/down ; dance RSh round 2cnrs[pos] to 2plx _while{8}_ 2c & 3c advance diagonally, give hands, retire twice (2x,1x,3x)
25--::
  3C Set&Link ; 1c turn RH 1¼ to 2pl _while{4}_ 2c & 2c chase clw ½ (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (7953, '2013-08-21 08:31:51.804547+00', '2023-02-04 01:23:13.520987+00', 9016, 3, NULL, 'ace', '1-8::
    1M+2L set advancing & turn RH, 1L+2M repeat
9-16::
    1s lead down for 3, 1/2 turn RH & lead up to face 1st corners
17-24::
    1s dance round corner RSh _while_ corners Adv+Ret, 1s pass RSh &
    repeat with 2nd corners to end facing 1st corner
25-32::
    2s+1s+3s dance LSh reels of 3 on opposite sides, 1s cross RH to 2nd
    place on own side', 0);
INSERT INTO 'dancecrib' VALUES (14888, '2022-06-23 21:25:13.189741+00', '2022-06-23 21:25:24.462699+00', 20904, 1, 1645, 'ace', '1--::

  All set | &frac34; DblFig8, 1c & 3c cast down to start (2,1x,4,3x)

9--::

  1c+4c S&Link ending NHJ with P, 4c facing down, 1c up ; 1c+4c S&Link to sides (2,4x,1,3x)

17--::

  4c+1c RHA & 4c face up to 2c, 1c face down to 3c ;

  all set | &frac12; turn on sides, 2c & 1c starting between 4c/3c, 4c face down, 1c face out (4x,2,3x,1)

25--::

  1c cast up to 1pl _while{2}_ 4c cross down to 4pl | 1c cross down to 3plx _while{2}_ 3c cast up to 1plx ;

  1c cast up to 1plx _while{2}_ 3c cross down to 3pl | 1c cross down to 2pl _while{2}_ 2c cast up to 1pl (2,1,3,4)

33--::

  1c+3c+4c &frac12; Mirror Reels3 on sides, 3c start in & up (2,4,3,1) ;

  3c+1c turn EH on sides & 3c face up | 4c+3c &frac12; turn EH (2,3,4,1)

41--::

  All circle8 to L & back (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (9884, '2017-05-27 12:05:51.927498+00', '2022-08-13 11:18:31.444831+00', 9880, 1, 202, 'ace', '*3c & 4c start on opposite sides*

1--::

  1c & 4c cross RH | cast inwards (2c & 3 c step out) ; ½ Fig8 round ends (2,1,4x,3x)

9--::

  1c+4c L-Chain (2,1,4x,3x)

17--::

  2c+1W & 4W+3c RHA ; 2c+1M & 4M+3c LHA (2,1,4x,3x)

25--::

  1c+4c ½ R&L no polite turn (to 2,4,1x,3x) ; ½ Parallel Reels4 (3x,1x,4,2)

33--::

  All set | cross RH (to 3,1,4x,2x) ; Circle8 L ½ (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (15047, '2022-09-02 10:23:39.637452+00', '2022-09-02 10:25:09.931221+00', 20936, 1, 1645, 'ace', '1--::

  1c cross RH, cast off (2c up on 3-4), cross LH, cast off (3c up on 5-6) | turn BH & open out to face up

9--::

  1c dance up to top | cast off to 2pl (3c down) ; 1c set adv to end BtoB on 1diag | set to 1cnrs

17--::

  1c Pass & Turn with 1cnrs, pass RSh ; repeat with 2cnrs & end in centre facing down, 1W on R of 1M

25--::

  1c, giving LH, &frac12; Fig8 through 3c, 1c & 3c end in centre ; 1c+3c &frac12; Poussette (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15051, '2022-09-04 14:48:05.079976+00', '2022-09-04 14:48:40.148284+00', 20921, 1, 1645, 'ace', '*Circle of six dancers with one (dancer 4) in the middle, numbered from the top:*  

*..1..2..*  

*3..4..5*  

*..6..7..*  

1--::

  4+1+2 RHA ; 4+6+7 LHA

9--::

  3+4+5 Reel3 across, 4 starts RSh to 3 & ends facing 6

17--::

  4 changes pl with 6 RH, then round the circle cclw, one bar per hand, changing with 7 LH, 5 RH, 2 LH, 1 RH, 3 LH, 7 RH, 5 LH (3,1,7,6,2,5,4)

25--::

  3+1+2+4+5+7 Circle6 & back _while{8}_ 6 sets in centre (3,1,7,6,2,5,4)

', 2);
INSERT INTO 'dancecrib' VALUES (15118, '2022-10-01 13:40:34.034958+00', '2022-10-01 13:47:57.416944+00', 21116, 1, 1645, 'ace', '1--::

  1c+2c & 3c+4c Poussette

9--::

  All set | &frac12; turn RH ; 1c+2c & 3c+4c chase &frac12; way clw (2,1,4,3) | all turn P BH, 2c & 3c to sides, 1c & 4c end NHJ in centre facing down/up

17--::

  1c+4c Rondel (2,4,1,3)

25--::

  All set | cross with M making arches ; repeat with W making arches (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (15387, '2023-01-22 12:41:58.320961+00', '2023-01-22 12:46:15.059085+00', 21317, 1, 1645, 'ace', '1--::
  1c turn RH | cast off (2c up) ; turn 1&frac14; LH to midline, M facing down, W up
9--::
  Set as in Crown Triangles | 1c+4cnrs turn RH to own sides ; &frac12; Reels3 on sides, 1c LSh to 3cnrs, 1c end as at [8]
17--::
  Repeat [9-16] with 1c+1cnrs turning LH & &frac12; RSh Reels3 on opp sides (2,1x,3)
25--::
  1c &frac12; Fig8 up through 2c ; 2c+1c+3c A&R (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (3497, '2012-01-22 19:30:27.900296+00', '2020-08-07 10:17:29.214456+00', 13283, 1, NULL, 'ace', '1–::

  1c+2c R&L, 1M finish facing out

9–::

  1M+1W following cast off one and cross (2c up) to face 3W/3M (2,1x,3) ; dance Rsh round that person to (2,1x,3)

17–::

  Parallel Reels3 on the sides, Lsh to 2c (2,1x,3)

25–::

  2c+1c LHA ; 1c turn LH 1½  (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (15389, '2023-01-23 17:15:02.072817+00', '2023-01-23 18:22:42.960079+00', 21318, 1, 202, 'ace', '1--::

  1c set | cast off  ; ½ Fig8 up round 2c (2c up on [7-8] (2,1x,3)

9--::

  2c+1M & 1W+3c RHA into DTr up/down, 1M facing up, 1W facing down ; all dance 4 bars of DTr up/down

17--::

  2c+1W & 1M+3c LHA into DTr up/down, 1M facing down, 1W facing up ; all dance 4 bars of DTr up/down. On [23-24] 1c Petronella turn to 2pl (2,1,3)

25--::

  2c+1c R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14894, '2022-06-25 10:12:55.60088+00', '2022-06-25 10:13:08.680616+00', 20879, 1, 1645, 'ace', '1--::

  1c, starting in & down, Fig8 on own sides

9--::

  *Set and Stroll:* 1c+2c set | 1W & 2M cast clw _while{2}_ 1M & 2W dance across ;

  1W+2M dance RSh round each other _while{4}_ 1M & 2W dance &frac12; way clw around them (2,1,3)

17--::

  All set | 2c+3c link (as S&Link3) _while{2}_ 1c petronella to facing lines of 3 across ;

  repeat from new places, ending in circle (3x,1x,2x)

25--::

  All set | dance in, pull RSh back & dance out ; chase &frac12; way clw (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (11065, '2018-09-04 19:02:10.497625+00', '2022-10-01 15:09:23.005874+00', 18555, 1, 202, 'ace', '*3c & 4c start on opposite sides*



1--::

  1c & 4c Fig8 round nearest centre cpls (1,2,3x,4x)

9--::

  1c & 4c set, 1M & 4M pivoting L ½ _while{2}_ 2c & 3c turn BH ½ (skip-change) and release inside hands | 1c+4c chase cclw ½ to change places _while{4}_ 2c+3c Circle4 L and release hands to join BH with P | 4c & 1c set _while{2}_ 2c & 3c turn BH ½ (skip-change) to sidelines (4,2,3x,1x)

17--::

  4c & 1c cross RH | cast inwards (2c & 3c step out) ; 4c+1c S&Link (2,1,4x,3x)

25--::

  1c+4c The Spiral (2,4,1x,3x)', 4);
INSERT INTO 'dancecrib' VALUES (11840, '2019-05-09 21:39:10.13043+00', '2022-10-01 18:00:11.266813+00', 19306, 1, 202, 'ace', '1--::

  1c & 2c set | turn P BH into ; 1c+2c ½ Poussette (2,1,3)

9--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag (3x,1x,2x)

17--::

  »1C Knot« [: 1c turn P RH into allemande hold facing up | dance up LSh round 3W and face down along Mside ; on [21] releasing RH, 1M guides 1W in front of him so they face down just outside the Mside. On [22] 1M, dancing down and slightly in, guides 1W into centre | 1c turn LH ½ to 2plx] (3x,1x,2x)

25--::

  All set | all turn P BH and face clw ; all chase clw ½ (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (3886, '2013-08-21 08:30:38.458153+00', '2023-02-04 01:18:16.693045+00', 9812, 3, NULL, 'ace', '1-8::
    1s+2s+3s petronella turn & set, 3/4 turn RH & set (all on opposite
    sides)
9-16::
    1s+2s set & dance 1/2 RH across, 1s+3s set & dance 1/2 RH across
17-24::
    1s cast up 1 place & dance to top, cast to 2nd place opposite sides
    & set turning to face out
25-32::
    1s cast to right & cross up/down, cast to 2nd place own sides
    _while_ 2s+3s change places RH on sides & set up/down then change
    back RH, all set', 0);
INSERT INTO 'dancecrib' VALUES (15392, '2023-01-24 17:10:58.710369+00', '2023-01-24 17:11:08.316736+00', 16295, 1, 1645, 'ace', '1--::

  1c cast behind own lines & back to place

9--::

  1M+2c LSh Reel3 across

17--::

  1W+2c RSh Reel3 across

25--::

  1c cross RH | cast off (2c up) ; turn 1&frac12; RH & face out (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (8986, '2015-11-30 08:59:28.331288+00', '2023-02-04 01:18:37.833877+00', 12007, 3, NULL, 'ace', '1-8::
    All clap 2 bars (1-2-3-4) All Adv+Ret (raise hands & »hooch« in
    centre) All clap (2 bars)
9-16::
    1s pass each other LSh, dance round outside of set & back to place
    (1M anticlockwise, 1L clockwise)
17-24::
    2s repeat bars 9-16 passing partner RSh
25-32::
    All circle 8H round and back', 0);
INSERT INTO 'dancecrib' VALUES (11894, '2019-06-16 08:55:15.197129+00', '2022-08-13 12:14:41.912125+00', 10647, 2, 1645, 'ace', '1- 8::

  1s cross RH, cast one place and dance 1/2 fig of 8 around 2s to face 1st corners.

9-16::

  1s turn 1st corners RH, pass RS, turn 2nd corners RH and pass RS to own side.

17-24::

  1s dance figure of 8 on side passing RS to partner’s 1st corner to begin.

25-32::

  6 hands round and back.

:: *The figure of 8 on the sides may also be danced as a reel of three.*', 0);
INSERT INTO 'dancecrib' VALUES (11896, '2019-06-16 10:50:31.608056+00', '2022-08-13 12:14:41.913461+00', 10647, 1, 202, 'ace', '1--::

  1 cross RH | cast (2c up) ; ½ Fig8 up round 2c and face 1cnrs

9--::

  Turn 1cnrs RH | pass P Rsh ; turn 2cnrs RH | cross RSh to 2pl and face out (2,1,3)

17--::

  1c Fig8 on sides, RSh to 3cnrs (2,1,3)

25--::

  Circle6 and back (2,1,3)



*Notes:  

For more advanced dancers, a reel of three on the sides may be substituted in bars 16-24.*', 2);
INSERT INTO 'dancecrib' VALUES (15048, '2022-09-02 10:39:00.928135+00', '2022-09-02 10:41:25.051182+00', 20692, 1, 1645, 'ace', '1--4::

  1W & 1M &frac12; Fig8 round 2c/3c _while{4}_ 1M & 4W stand{2} | cross down/up to face out between 2pl & 3pl on opp side

5--8::

  1M & 4W, each followed by P, cast off/up round 3M/2W & cross to own side (4,2,3,1)

9--::

  4c+2c & 3c+1c Circle4 & back, end facing down/up NHJ with P

17--::

  4c & 2c, also 3c & 1c S&Link across ; chase &frac12; way clw (2,4,1,3)

25--::

  2c+3c A&R on diagonal ; 4c & 1c turn P RH (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (15391, '2023-01-24 11:32:39.65173+00', '2023-01-24 11:32:49.22901+00', 21319, 1, 1645, 'ace', '*Two chords: bow to partner then opposite couple*

1--::

  1c+3c set | &frac34; LHA to sidelines (2c & 4c step away from P) | all set facing opp line

9--::

  RSh Reels4 on sides, 2W & 4M end in 1pl, 4W & 2M in 3pl

17--::

  2W+4M & 4W+2M &frac12; turn LH | &frac12; L-Chain | all set (4,1,2,3)

25--::

  Circle8 to L & back (4,1,2,3)

', 2);
INSERT INTO 'dancecrib' VALUES (15084, '2022-09-05 00:22:23.689574+00', '2023-02-04 01:23:06.386762+00', 14787, 3, NULL, 'ace', '1-6::
    1M & 3M cast down _while_ 2L & 4L cast up, pass RSh in centre, dance
    RSh round own partner to swap places
7-8::
    1s+2s also 3s+4s chase clockwise 1 place 2 1 4 3
9-16::
    1s+4s dance Set & Rotate.  2 4 1 3
17-20::
    2s+4s also 1s+3s dance Set+Link
21-24::
    4s+2s also 3s+1s dance 4H round to left 4 2 3 1
25-28::
    4s+2s+3s dance 1/2 mirror reels of 3 on the sides (4s out/down, 2s
    in /up, 3s out/up). 3 2 4 1
29-32::
    2s turn RH, cast up to 1st place (3s move down on bars 31-32). End 2
    3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (15390, '2023-01-24 11:00:16.533177+00', '2023-01-25 06:31:06.186451+00', 2722, 1, 202, 'ace', '_Chorus_
1--::
  All set to P | turn P RH ¾, M facing clw, W facing cclw ; all W LHA _while{4}_ all M chase clw ½
9--::
  All set to new P | turn new P RH ¾, M facing cclw, W facing clw ; all M LHA _while{4}_ all W chase clw ½ (3,4,1,2)

_Figure 1_
1--::
  3c+1c RHA pivoting RSh on [4] to finish BtoB with P facing sides ; 3W+1M & 3M+1W dance out through sides and cast to places as on [1]  (3,4,1,2)
9--::
  2c+4c repeat [1-8] (3,4,1,2)

_Chorus_ (1,2,3,4)

_Figure 2_
1--::
  All Circle4 L ; set to P | turn P RH and face corners (3,4,1,2)
9--::
  All set to corners | turn corners LH ; Circle4 R (1,2,3,4)

*Repeat in reel time (1,2,3,4)*', 2);
INSERT INTO 'dancecrib' VALUES (13879, '2021-04-05 00:18:35.429016+00', '2023-02-04 01:18:38.275711+00', 411, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 round 2s
9-16::
    1s+2s dance Double Fig 8 (1s cross down, 2s cast up to start)
17-24::
    1s dance down the middle & back, remain in centre, 2s step in bar 24
    ready for …
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (5572, '2013-08-21 08:31:09.420142+00', '2023-02-04 01:20:17.352205+00', 2722, 3, NULL, 'ace', '{{title}}
Chorus

1-8::
    All set to partners, 3/4 turn RH to end with Men (on outside) facing
    clockwise & Ladies facing anticlockwise, Ladies dance LH across &
    end in partner''s place _while_ Men dance round set 1/2 way to face
    new partner
9-16::
    All set to new partners, 3/4 turn RH to end with Ladies (on outside)
    facing clockwise & Men facing anticlockwise, Men dance LH across
    _while_ Ladies dance round set 1/2 way (all now opposite original
    places)

{{title}}
Fig 1

1-8::
    1s+3s RH across & end facing corners (1s & 3s BtoB with ptnr),
    dancing couples dance out between side cpls & cast back to pl (as at
    bar 16)
9-16::
    2s+4s repeat

{{title}}
Chorus

{{title}}
Fig 2

1-8::
    All circle 8H round to left, set to partner & turn RH to end facing
    corners
9-16::
    All set to corners & turn LH & circle 8H round to right

{{explanation}}
Repeat in Reel time all ending in original places', 0);
INSERT INTO 'dancecrib' VALUES (7850, '2013-08-21 08:31:49.786935+00', '2023-02-04 01:23:06.415606+00', 12635, 3, NULL, 'ace', '1-8::
    1s+3s cross down RH into double triangle position & set, dance round
    1st corner into a line up/down middle facing partner
9-16::
    1s+3s dance RSh reel of 4 in centre _while_ 2s+4s+5s dance LSh reels
    of 3 on sides (4M in & up, 4L in & down to start)
17-24::
    1s & 3s 1/2 turn partner RH, dance RSh round 2nd corner & turn
    partner RH 1.1/2 times to 2nd/4th place own sides
25-32::
    2s (at top) stand _while_ 1s+4s also 3s+5s Set+Link;  All turn RH to
    end 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (10636, '2018-04-16 21:42:45.743088+00', '2023-02-04 01:23:06.438968+00', 12093, 3, NULL, 'ace', '1-8::
    1s & 3s dance 1/2 Figs of 8 down round 2s & 4s; 1s+2s also 3s+4s
    dance RH across, Men face out
9-12::
    1M followed by 1L casts to 4th place own sides _while_ 4M followed
    by 4L casts up to 1st place opp sides _while_ 2s+3s dance LH across.
    (4) 2 (3) 1
13-16::
    4s+2s also 3s+1s Set+Link
17-24::
    4s+1s+3s Set+Link for 3 twice
25-28::
    1s+4s Set+link
29-32::
    1s set & cross RH.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (3867, '2013-07-25 10:25:30.87586+00', '2022-06-25 15:13:04.507354+00', 14994, 1, NULL, 'ace', '1–::

  1c+2c ½ DblFig8 (1c cross down) ; ½ Mirror Reels3 on the sides (2c out & up) (3,2x,1x)

9–::

  2c+1c ½ DblFig8 (1c cross up) ; ½ Mirror Reels3 on the sides (2c out & down) (1,2,3)

17–::

  1c dance down (2c up) | turn 3c EH ; turn 2c with other hand | All set (2,1,3)

25–::

  1c+3c Tourbillon (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (14872, '2022-06-18 05:20:12.783539+00', '2022-06-26 11:39:47.337285+00', 20895, 1, 202, 'ace', '1--::

  1c+2c Set&Link : all set | cross RH (2x,1x,3x)

9--::

  All chase clw ½ (to 3,1,2) ; 1c turn P RH 1½ to finish 1W facing 1cnr[pos], 1M behind her _while{4}_ 3c & 2c chase clw ½

17--::

  Reel3 on 1diag in tandem (with lead change), 1W RSh to 2W. 1W face 2cnr[pos], 1M behind her

25--::

  Reel3 on 2diag in tandem (with lead change), 1W LSh to 3W (2x,1x,3x)

33--::

  3C Set&Link twice (3,1,2)

41--::

  Circle6 and back', 2);
INSERT INTO 'dancecrib' VALUES (9860, '2017-05-16 09:25:39.312044+00', '2022-08-14 21:29:46.266262+00', 10661, 1, 202, 'ace', '1--::
 1c dance down (2c up) ; set facing P | dance up towards 3c
9--::
 1c turn 3c EH and dance up ; turn 2c EH finishing in 2pl in promhold facing up, 3c step in on [16]
17--::
 1c+3c Allemande (2,3,1)
25--::
 1c+3c S&Rotate (2,1,3)
33--::
 Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (15394, '2023-01-26 20:26:47.51377+00', '2023-01-26 20:26:47.51377+00', 7542, 2, 10819, 'ace', '*Partners stand side by side facing across the other couple*

 _Foursome Reel – 32 bar Strathspey_
1-8::
  Reel of 4 across. W pass L shoulder to begin. M wait 2 bars and join in the reel. M finish by curving in back to back to face opposite W.
9-16::
  All set.
17-24::
  Reel of 4 across. M finish back to back to face partner.
25-32::
  All set.  
  
_32 bar Reel_
1-8::
  Reel of 4 across. M finish back to back to face opposite W.
9-16::
  All set.
17-24::
  Reel of 4 across. M finish back to back to face partner.
25-32::
  All set. 

_Half Reel of Tulloch – 64 bar Reel_

1-8::
  M pas de basque out to the side lines passing partner by right on bars 1-2. As W advance towards each other to set in centre.
9-12::
  W turn R once and half in Tulloch hold.
13-16::
  W turn L twice in Tulloch hold to face opposite M.
17-24::
  All set.
25-28::
  All turn R once and half in Tulloch hold.
29-32::
  All turn L twice in Tulloch hold. M finish facing in centre.
33-64::
  Repeat bars 1-32 above but with M in centre and on bars 61-64 partners turning L twice and a quarter in Tulloch hold to finish beside partners on opposite side of the set.', 3);
INSERT INTO 'dancecrib' VALUES (12836, '2020-05-16 22:22:44.580987+00', '2023-01-27 11:12:58.878431+00', 2610, 2, 2784, 'ace', '1-::

  1c+2c circle4 and back

9-::

  1c cross RH | cast (2 up); 1c dance BtoB turning to face 2c

17-::

  1W turns 2M RH _while_{2} 1M turns 2W LH into line of four across the set; dance down middle {3} 2c curve in and lead to 1pl _while_{3} 1M turns P under his R arm and 1c follow back to 2pl

25-::

  2c+1c R&L

', 4);
INSERT INTO 'dancecrib' VALUES (3343, '2012-01-22 19:30:21.362105+00', '2023-01-25 17:45:16.617068+00', 6393, 1, NULL, 'ace', '1–::

  All set to cnr | All »La Baratte« with cnr [turn RH ½ to full arms'' length | change back sideways, W passing in front of M as both face the centre, changing hands overhead to LH | turn LH ½ to exchanged places]

9–::

  With next person turn ½ RH and face | cast (inwards or outwards, swivel R) ¼ round set to meet P ; Turn P LH 1½ (to 3,4,1,2)

17-32::

  Repeat 1-16  (to 1,2,3,4)

33–::

  1c+3c LHA 1¼ , finish in promhold, forming line across, M in the middle ; 1c+3c cast R round standing cpl to places

41–::

  2c+4c repeat

49–::

  All cpls face in NHJ and Set | advance NHJ to middle ; retire NHJ with cnr | Set

57–::

  Circle8 L {2} | turn P BH ; continue Circle8 L (to 1,2,3,4)', 3);
INSERT INTO 'dancecrib' VALUES (15393, '2023-01-25 12:01:45.471964+00', '2023-01-28 21:13:28.769621+00', 18367, 1, 202, 'ace', '1--::
  ½ Mirror Reels3 on opp sides, 1c crossing down to start (to 3,2,1x) ; all set | 1c dance up and face 1cnrs
9--::
  1c dance RSh round P ¾ (PdB) to face 2cnrs[pos] _while{2}_ 2c & 3c chase 1 place clw | 1c change places RH with 2cnrs[pos] _while{2}_ 1cnrs[pos] set ; 3M & 2W BtoB in centre on 2diag dance RSh round P ¾ (PdB) to face 3cnrs[pos] _while{2}_ new cnrs chase 1 place clw | 3M & 2W turn 3cnrs RH into facing lines3 across
17--::
  *Modified 3C Set&Link across* : same as 3c Set&Link across except 1c change places RH on [17-18] ; top 2 Men on W side & bottom 2 Women on M side Set&Link (on M side 2M,1W,2W on W side 3M,1M,3W)
25--::
  Cnrs RHA ¾ to own sides _while{4}_ 1c set | 1M cast up between 3c, 1W cast down between 2c ; 1c turn RH to 2pl (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (15395, '2023-01-28 13:42:24.65795+00', '2023-01-28 16:44:41.329079+00', 2823, 1, 202, 'ace', '1--::
  1c and 3c cross RH |1c+2c & 3c+4c last 6 bars of R&L (1,2x,3,4x)
9--::
  Progressive Parallel Reels4 across, all W passing LSh. 1M & 4M face out (2x,1,4x,3)
17--::
  1c+4c L-Chain finishing into Reels4 position on sides (2x,1,4x,3)
25--::
  Parallel Reels4 on sides  (2x,1,4x,3)
33--::
  1c set | cross down to 4plx _while{4}_ 3c cross RH | cast up to 2plx (to 2x,3x,4x,1x) ; all turn P BH 1½ (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (15117, '2022-10-01 13:33:11.384396+00', '2022-10-01 15:18:37.000526+00', 21124, 1, 1645, 'ace', '1--::

  1c+2c RHA ; 1W+2W & 2M+3M S&Link _while{4}_ 1M & 3W dance &frac12; way clw (Mside: 3W,3M,2M; Wside: 2W,1W,1M)

9--::

  3M+1W (in 2pl) &frac12; turn RH & twirl away ; *repeat [5-8]:* 2W+3M & 1W+2M S&Link _while{4}_ 3W & 1M dance &frac12; way clw (Mside: 1M,2M,1W; Wside: 3M,2W,3W)

17--::

  2c cross RSh | set adv to 4cnr pos ; 2c+4cnrs &frac12; diag RSh Reel4 (1,2,3)

25--::

  1c+2c &frac34; R&L | all set (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (15397, '2023-01-29 19:31:16.26804+00', '2023-01-30 00:06:44.87411+00', 4888, 1, 202, 'ace', '1--::
  1c+2M Reel3 across, 1M LSh to 1W _while_ 2M dances up. 2M faces out
9--::
  1M+2W+2M chase 1 place clw, 1M giving RH to 2W | 1c+2c set diagonally ; 1c+2c advance diagonally. 1M+2M & 1W+2W joined BH, Women under Men''s hands | _while_ setting on spot. On [15] Men raise arms and lower behind Women''s backs. On [16] Women put hands behind Men''s backs
17--::
  Circle4 L 2¼ gradually increasing the size of the circle into normal Circle4 (2x,1)
25--::
  2c ½ Fig8 down round 1c ; 2c+1c turn P LH (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (5296, '2013-08-21 08:31:04.350046+00', '2023-02-04 01:20:00.440492+00', 2228, 3, NULL, 'ace', '1-8::
    1M+2M+3M dance across, pass partner LSh, dance RSh round Lady below
    & LSh round partner & across back to place (i.e. Fig 8 on opp side)
9-16::
    1L+2L+3L repeat above Fig. passing partner RSh, LSh round Man below
    & RSh round partner, back to place
17-24::
    1M+2L change places RH
::
    1L+2M also 1M+3M change places LH
::
    1L+3L also 1M+4L change places RH
::
    1L+4M change places LH
25-32::
    All advance to pass partner RSh, turn to face partner & retire to
    own sides; all turn partners RH to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14608, '2022-02-16 02:01:29.699588+00', '2022-10-01 18:04:25.784539+00', 20665, 1, 202, 'ace', '1--::

  1c set | cross down to 2plx (2c up) ; 1c+3c 2C S&Link. 1W & 3W face out (2,3,1x)

9--::

  3c+1c M-Chain (2,3,1x)

17--::

  2c & 1c set | cross RH (to 2x,3,1) ; 2c cast off (3c up) | 2c turn P LH ¾ to face 1cnrs

25--::

  All SetH&G. On [31-32] 2c turn P RH into Allemande hold. On [32] 1c step in

33--::

  2c+1c 2C Allemande (3,1,2)', 5);
INSERT INTO 'dancecrib' VALUES (2328, '2012-01-22 19:29:31.713053+00', '2023-01-27 11:48:44.830848+00', 2488, 1, NULL, 'ace', '1–::

  All C L-Chain with C opposite, at end make extra ¼ turn and M turn in into promhold (all C face towards their own M side)

9–::

  Dance Lsh round couple »initially behind« ; dance Rsh round couple »opposite«

17–::

  with C opposite RHA ; LHA, finish facing P

25–::

  All set | turn P BH 1½ {4}, M face out  | M (W following) dance cclw ½ round opposite couple to meet new couple, M swiveling L into the L-Chain



{{explanation}}

Dance twice in Strathspey time, then twice in Reel time, using Skip-change for the BH turns', 2);
INSERT INTO 'dancecrib' VALUES (15402, '2023-01-30 17:40:04.528556+00', '2023-01-31 09:48:46.855868+00', 18886, 1, 1645, 'ace', '1--::

  1c cross below 3c, cast up, cross up between 2c & cast off to face 1cnrs (2c up on 7-8)

9--::

  1c set to & turn cnrs BH, end facing 3cnrs

17--::

  1c+3cnrs &frac12; RSh diag Reel4, pass RSh ; repeat with 4cnrs & end on own side (3x,1,2x)

25--::

  &frac12; diag R&L twice, 1W up, 1M down (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (15398, '2023-01-29 23:01:48.056479+00', '2023-02-04 11:51:59.511026+00', 21336, 1, 1645, 'ace', '1--::
  1c set | dance &frac34; Fig8 on sides, starting LSh to 2c (1M may cast), 1W ends crossing up to face 1M who ends in 2pl
9-10::
  2M+1M+3M+1W set in D shape: M join NH on sides as 1W joins outer hands with 2M & 3M who turn in slightly
11-12::
  1W petronellas back to 2pl own side _while_ 1M sets adv to face her _while_ 2M & 3M set on sides
13-16::
  Repeat [9-12] on W side, 1M ends facing 2M with 1W following in tandem
17--::
  1c &frac12; alternating tandem Reel3 on 1diag, RSh to 2M, end 1W leading facing 3M ; repeat on 2diag, 1c end on opp side (3x,1x,2x)
25--::
  All chase &frac12; way clw ; all turn P RH (2,1,3)
', 5);
INSERT INTO 'dancecrib' VALUES (15403, '2023-01-31 14:51:08.801255+00', '2023-01-31 15:50:15.142404+00', 21337, 2, 1, 'ace', '1–:: 1c+2c set and link [1M fin facing out] ; 1M followed by 1L cast up round 2M | dance down to between 3C [1L fin between 2C]
9–:: 1M+3c & 1L+2c Reels3 across (RS to 3M/2M)
17–:: 1M followed by 1L cast up round 3M | dance across to 2plx ; 1c & 3c turn R [1c fin in Allemande hold facing down, 3c facing up]
25–:: 1c+3c dance circulating Allemande [both dancing as 2nd couple, 1c starting toward M''s side and down; 1c cross R on 31–32]', 5);
INSERT INTO 'dancecrib' VALUES (7851, '2013-08-21 08:31:49.79501+00', '2023-02-04 01:23:06.4591+00', 11193, 3, NULL, 'ace', '{{explanation}}
2 chords - 3s & 4s cross on 2nd chord

1-8::
    1s & 4s set, cast into centre & dance RH across 1.1/4 way to end
    with 1s on Ladies side & 4s on Men''s side
9-16::
    All Set+Link for 4 twice (as 3 couple Set+Link but 3 dancers cast &
    chase clockwise)
17-24::
    1s+4s dance RH across 1.1/4 way to end 3 1 4 2 with 4s & 2s on opp
    sides, all turn partner RH
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12754, '2020-04-11 10:53:30.729592+00', '2023-02-04 01:23:06.612928+00', 19946, 3, NULL, 'ace', '1-8::
    1s dance down NHJ (3 bars), dance up (3 bars) & cast (2s step up).
    1s meet in centre, give LH to partner & RH to 1st corner
9-16::
    1s & corners dance "The Spoke". 1s end facing 1st corner
17-24::
    1L+2s (at top) & 1M+3s (at bottom) dance reels of 3 across (LSh to
    1st corner). 1s end in 2nd place own side
25-32::
    1s & 3s dance DoSiDo with partners; 1s & 3s turn partner RH.  2 1 3
    4', 0);
INSERT INTO 'dancecrib' VALUES (7852, '2013-08-21 08:31:49.81067+00', '2023-02-04 01:23:06.641084+00', 6972, 3, NULL, 'ace', '1-8::
    All dance RSh reels of 4 on own sides
9-16::
    1s & 3s set advancing into centre (give RH to partner) &
    Bal-in-Line, 1s+2s & 3s+4s dance RH across once round
17-24::
    Centre couple (1L+3M) 3/4 turn LH in centre _while_ 1M & 3L dance
    round crnr to meet ptnr in line across & set, repeat & set in line
    up/down dance
25-32::
    3s+2s & 1s+4s dance RH across once round, turn facing corner RH
    (2L+3L, 3M+2M, 1L+4L & 1M+4M) onto own sides (Ladies turn 1.1/2
    _while_ Men turn once round).  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7853, '2013-08-21 08:31:49.818784+00', '2023-02-04 01:23:06.670897+00', 6978, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 RH across, 1s+3s dance 1/2 LH across, 1s lead up 1
    place & 1L casts up to top as 1M casts down
9-16::
    1s dance 1/2 RSh reels of across (1L with 2s & 1M with 3s), 1s dance
    1/2 reels of 3 on opposite sides ending in centre facing partner
17-24::
    1s turn RH & change places LH with 3s (in 1st place) on own sides,
    3s turn RH & change places LH with 2s on sides
25-32::
    2s turn RH & change places LH with 1s on sides, 1s lead up & cast to
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (12164, '2019-09-04 17:05:28.857657+00', '2023-02-04 01:23:06.695311+00', 19572, 3, NULL, 'ace', '1-8::
    1s & 4s turn 2H (4 bars) to face up NHJ; 1s cast to 4th place, 4s
    dance up to top & face out
9-16::
    _1/2_ Mirror reels of 4 on sides (4s out/down, 1s in/up), 2s & 3s do
    not pass LSh; All turn LH to original place (1s & 4s with partner,
    2L+3L, 2M+3M)
17-24::
    1s+2s also 3s+4s dance R&L
25-32::
    1s+2s dance 1/2 RH across, 1s+3s dance 1/2 LH across, 1s+4s dance
    1/2 RH across, all cross RH', 0);
INSERT INTO 'dancecrib' VALUES (14895, '2022-06-26 12:07:47.544988+00', '2022-06-26 12:10:25.897834+00', 20922, 2, NULL, 'ace', '1–8::	1s+2s+3s set & cross over passing RSh (no hands) & repeat.    

9–16::	1s+2s set & link then circle 4H to left. Finish on sides 2s facing down & 1s facing up. 

17–24::	RSh parallel reels of 3 on sides. 2L, 1M+3L finish by dancing long way into place.

25–32::	1s+3s set & link then circle 4H to left. 



', 5);
INSERT INTO 'dancecrib' VALUES (4197, '2013-08-21 08:30:45.112675+00', '2023-02-04 01:18:39.921571+00', 14238, 3, NULL, 'ace', '1-8::
    1M dances in & casts to 3rd place (2M+3M up), 1M+3L+4s circle 4H
    round to left
9-16::
    1L crosses (2L up) & casts 1 place, crosses & casts down to 3rd
    place (3L up)
17-24::
    2s+1s dance double Fig of 8 round 3s (1s cross up)
25-32::
    1s+4s Set+Link, 1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (7855, '2013-08-21 08:31:49.841564+00', '2023-02-04 01:23:06.748577+00', 14973, 3, NULL, 'ace', '1-8::
    1s set advancing & turn 2H, 1s dance down & 2s cross up as 1s cast
    up round 3s to face 2L (1L with 1M behind her)
9-16::
    1s dance a 1/2 diagonal LSh Alternating Tandem reel of 3 with 2L+3L,
    1M continues diagonal reel of 3 to end between 3s _while_ 1L casts
    up round 2M to end between 2s
17-24::
    2s+3s chase clockwise 1/2 way as 1s advance & 1.1/4 turn 2H to face
    2s, 1s also 2s Set+Link.  (3)(1)(2)
25-32::
    All chase clockwise 1/2 way, all turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (7856, '2013-08-21 08:31:49.855493+00', '2023-02-04 01:23:06.86793+00', 6981, 3, NULL, 'ace', '1-8::
    1s cast down below 3s turn out & cast back to top
9-16::
    1s lead down the middle for 3 steps, back to top & cast to 2nd place
    & face 1st corners
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH to end
    2nd place opposite sides
25-32::
    2s+1s+3s Adv+Ret, 1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (7857, '2013-08-21 08:31:49.865232+00', '2023-02-04 01:23:06.894473+00', 6991, 3, NULL, 'ace', '1-12::
    1s dance down to 4th place & all circle 8H round & back
13-16::
    1s dance up to top under arches made by 2s+3s+4s
17-24::
    1s dance Fig of 8 round 2s
25-32::
    1s set, cast to 4th place, all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (14548, '2022-01-10 02:21:12.733995+00', '2023-02-04 01:23:06.917796+00', 20607, 3, NULL, 'ace', '{{explanation}}
Round the Room.  2 circles, e.g. Ladies with backs to centre of room facing partner

1-8::
    All face to left (Ladies anticlockwise, Men clockwise) & dance (or
    walk) 4 bars round, pull back RSh & dance back to face partner
9-16::
    All DoSiDo with partner & turn partner RH
17-24::
    All Retire (2 bars), Advance (2 Bars) & clap; All Retire (2 bars) &
    Advance towards person diagonally to right
25-32::
    All dance RSh round ''new partner'' (4 bars); All turn ''new partner''
    RH (or birl) to end inner circle (Ladies) facing anticlockwise,
    outer circle (Men) facing clockwise', 0);
INSERT INTO 'dancecrib' VALUES (13643, '2021-02-04 01:22:15.307427+00', '2023-02-04 01:23:06.9477+00', 6982, 3, NULL, 'ace', '1-8::
    1s dance in & cast, meet below 2s & dance down, cast up round 3s,
    meet & dance up to top remaining in centre. 2s step in behind 1s
    (bar 8)
9-16::
    1s+2s dance Allemande
17-24::
    1s Petronella turn 3 times to end 1M between 2s at top facing down
    1L between 3s facing up, 1s turn 3/4 RH to 2nd place own side
25-32::
    1s+3s dance »Slip Knot«:  As the Knot, but on last 2 bars couples
    dance LH across 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (15399, '2023-01-29 23:04:24.267868+00', '2023-01-29 23:22:59.1055+00', 7812, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Reels3 across, 1c RSh to 4cnrs (2x,1,3x)

9--::

  2c+1M & 1W+3c LHA ; 1c set | turn P BH to face 3cnrs[pos]

17--::

  ½ Reel4 on 1diag, pass P RSh to face 4cnrs[pos] ; ½ Reel4 on 2diag (3,1,2)

25--::

  1c Petronella turn twice to 2plx _while{4}_ 3c+2c change places RH on sides | cross LH (to 2x,1x,3x) ; all set | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15404, '2023-01-31 19:32:06.147941+00', '2023-01-31 19:32:06.147941+00', 15974, 2, 2929, 'ace', '1-8 :: 3C + 4C make arches, 2C followed by 1C dance under arches and back
9-16 :: 3M, 3W, 1M, 1W down for 2, set and face own side, slip up, turn 1/2 to line up and down
17-24 :: Reel4, slip step back to back in middle
25-32 :: 1C dance one-couple poussette: down 2, half turn in 2 steps, down 2, quarter turn in 1 step, retire
33-40 :: All turn RH, circle to the left at top and bottom', 2);
INSERT INTO 'dancecrib' VALUES (9617, '2017-02-24 20:49:29.354328+00', '2023-02-03 09:35:50.989986+00', 17619, 1, NULL, 'ace', '*The dance comprises four parts of 32 bars; each first a 16-bar Cloverleaf formation, then one of several 8 bar figures, and finally 8 unchanging bars.  The women progress anticlockwise to a new partner each time, and finish with their original partner.*



1-16::

  _Cloverleaf_ 

::

         1--   All W RHA ¾ _while{4}_ all M chase ¼ cclw ; turn P LH into promhold facing cclw | promenade 1 place cclw (3,4,1,2)

::

         9--   Repeat to places (1,2,3,4)

17-::

  Variable 8-bar figure (3,4,1,2)

25-::

  All set to cnr | turn cnr RH ¾ into promhold ; promenade cclw till M is back in own place with cnr as new P.





::

  _Variable figure_

::

  Part 1   17--   All M dance in front of P, cclw behind next W and to opposite place ; All W dance in front of M, clw behind next M, and join P (3,4,1,2)

::

  Part 2   17--   1c+3c ½ R&L ; 2c+4c repeat (3,4,1,2)

::

  Part 3   17--   1c+3c Set | ½ RHA ; 2c+4c repeat (3,4,1,2)

::

  Part 4   17--   Same as for Part 1 ; the W finish BtoB in the middle.

', 5);
INSERT INTO 'dancecrib' VALUES (15405, '2023-02-02 20:34:15.170771+00', '2023-02-03 10:30:20.159636+00', 14429, 1, 1645, 'ace', '1--::
  1c & 4c cross RH | cast in (2c & 3c to ends) ; &frac12; Fig8 out nearest end (2,1,4,3)
9--::
  RSh Reels4 on sides
17--::
  2c+1c & 4c+3c Circle4 to L & back
25--::
  1c+4c &frac12; R&L ; set | cross RH (2,4,1,3)
::
  *Repeat in strathspey then clap & repeat twice in jig time.*
', 2);
INSERT INTO 'dancecrib' VALUES (13294, '2020-11-02 01:18:33.461049+00', '2023-02-04 01:18:33.640938+00', 17616, 3, NULL, 'ace', '1-8::
    1s set to 2s & 1s+2s turn 2H on sides; 1s+2s set to partners, turn
    partners 2H
9-16::
    1s+2s Set & Rotate (no hands given)
17-24::
    2s+1s circle 4H round & back
25-32::
    2s+1s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (12115, '2019-09-01 11:33:43.510683+00', '2023-02-04 01:23:07.283844+00', 19580, 3, NULL, 'ace', '{{explanation}}
Round the Room, 2 facing 2

1-8::
    All dance 4H round & back.
9-16::
    All dance RH across & LH back
17-24::
    All dance DoSiDo with partner, all dance DoSiDo with opposite person
25-32::
    All Adv+Ret, couples facing clockwise make an arch & advance to meet
    next couple as anticlockwise couples dance under', 0);
INSERT INTO 'dancecrib' VALUES (9424, '2016-10-06 07:19:05.858059+00', '2023-02-04 01:23:07.41341+00', 17260, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH & cast in (2s & 3s step up/down); 1s+4s dance RH
    across 1.1/2 round
9-16::
    2L+4L+1M+3M dance Diagonal reel of 4 (4L+1M passing RSh to start)
17-24::
    2M+4M+1L+3L dance Diagonal reel of 4 (4M+1L passing LSh to start)
25-32::
    1s+4s dance Diamond Poussette _while_ 2s+3s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7858, '2013-08-21 08:31:50.01361+00', '2023-02-04 01:23:07.449866+00', 10937, 3, NULL, 'ace', '1-8::
    1s 1/2 turn 2s on sides (1M RH - 1L LH) to face own sides BtoB,
    2s+1s+3s dance Double Triangles
9-16::
    1s on opposite sides dance Figs of 8 round 2s+3s (dance between 3s
    to start) & end 2nd place opposite sides
17-24::
    1s+3s Set+Link, 1s 1/2 turn RH, lead up to 2nd place _while_ 3s turn
    RH & cast to 3rd place
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13449, '2020-12-02 01:22:16.416968+00', '2023-02-04 01:23:07.473715+00', 17798, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s dance Fig 8 round 2s+3s on own side giving hands,1s dancing down
    between 2s to start. (2s+3s+4s step up 7-8). 1s end in centre, 2nd
    place
9-16::
    2s+3s+4s circle 6H round & back _while_ 1s turn RH & turn LH.  1s
    end NHJ facing down

{{title}}
Reel

17-24::
    1s followed by 2s+3s+4s dance down (4 bars), 2s+3s+4s divide & 1s
    followed by 2s+3s+4s dance up
25-32::
    2s+3s+4s make arches & 1s dance under to 4th place; 1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6230, '2013-08-21 08:31:20.872639+00', '2023-02-04 01:21:07.107384+00', 7812, 3, NULL, 'ace', '1-8::
    1s cross, cast (2s step up); 1s dance 1/2 reels of 3 across (1L with
    2s & 1M with 3s). (2) 1 (3)
9-16::
    1s dance LH across (1M+2s at top, 1L+3s); 1s on sides & turn 2H to
    face 3rd corners (1M facing 2L, 1L facing 3M)
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh to dance
    1/2 reel of 4 with 2nd corners & pass RSh to end in 2nd place own
    sides
25-32::
    1s dance 2 Petronella turns to opposite sides _while_ 2s+3s change
    places RH on sides & cross LH; 2s+1s+3s set & cross RH. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12752, '2020-04-11 10:53:25.836464+00', '2023-02-04 01:23:00.387854+00', 9660, 3, NULL, 'ace', '1-8::
    1s+3s Adv (2 steps) & set; 1M+3L dance out through 2s & cast back to
    places _while_ 1L+3M dance out through 4s & cast back to places
9-16::
    Grand Chain 1/2 round (start RH), turn partner RH to finish with
    Ladies joining LH in centre, RH with partner, all facing NH
    anticlockwise
17-24::
    All dance 4 skip change 1/2 round; Ladies dance in front of partner
    to next »arm« of cross _while_ Men dance into centre to beside
    partner. All set (in cross)
25-32::
    Men face partner & dance Hello-Goodbye setting 1/2 round set (all
    finish 1 place on, 4 1 2 3)
33-40::
    Ladies dance to centre, pass LSh (2 steps), turn next Man LH (Men
    start dancing into Lady''s place beside them); Ladies repeat to
    finish beside prtnr
41-48::
    All promenade clockwise once round ending 4 1 2 3
49-56::
    2s+4s Adv (2 steps) & set, 2M+4L dance out through 3s and cast back
    to places, _while_ 2L+4M dance out through 1s and cast back to
    places
57-64::
    Grand Chain 1/2 round (start LH), turn prtnr LH to finish with Men
    joining RH in centre LH with partner, all facing  NH, all facing
    clockwise
65-72::
    All dance 4 skip-change 1/2 round set; Men dance in front of prtnrs
    to next »arm« of cross _while_ ladies dance into centre to beside
    prtnrs. All set (in cross)
73-80::
    Ladies face partner & dance Hello-Goodbye setting 1/2 round set
    (Ladies end in original places)
81-88::
    Men dance to centre, pass RSh (2 steps), turn next Lady RH(Ladies
    start dancing into Man''s place beside them): Men repeat to finish
    beside prtnr
89-96::
    All promenade clockwise once round ending in original place', 0);
INSERT INTO 'dancecrib' VALUES (7859, '2013-08-21 08:31:50.021789+00', '2023-02-04 01:23:07.50165+00', 6990, 3, NULL, 'ace', '1-8::
    1s cross down below 2s, dance behind 3s, meet & lead up to top,
    cross & cast to 2nd places
9-16::
    3s followed by 1s+2s lead down & 2s lead back to places
17-24::
    2s+1s+3s set, 1s petronella turn (1M between 3s facing up, 1L
    between 2s facing down) All set in lines across, 1s petronella turn
    to opp sides
25-32::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corner (6
    bars) 1s cross RH to 2nd place own sides (bars 31-32)', 0);
INSERT INTO 'dancecrib' VALUES (13450, '2020-12-02 01:22:16.581028+00', '2023-02-04 01:23:07.655318+00', 16382, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig 8 down round 2s; 1s+2s set & dance into line of 4
    across (Men cast to form line ends, Ladies dance in & pull back RSh,
    to BtoB facing ''oppsite'' Man)
9-16::
    Reel of 4 across.  Bars 15-16: Ladies dance straight across to own
    side _while_ Men dance a little to right to be opposite partner.  2
    (1)
17-24::
    2s+1s circle 4H round & back
25-32::
    1s set & spring points; 1s turn R 1.1/2 (Tulloch hold)', 0);
INSERT INTO 'dancecrib' VALUES (7861, '2013-08-21 08:31:50.039857+00', '2023-02-04 01:23:07.719672+00', 7551, 3, NULL, 'ace', '1-8::
    1s cross RH cast 1 place & cross LH, 1s cast to 3rd place & dance up
    middle in prom hold
9-16::
    1s dance 1/2 RSh reel of 3 with 2L+3L, 1L crosses up between 2M & 3M
    & cast down round 3M & turns partner RH to face up in prom hold
17-24::
    1s dance a 1/2 LSh reel of 3 with 2M+3M, 1M dances down middle as 1L
    dances into 2nd pl Mens side & 1M casts up round 3L into 2nd pl
    Ladies side
25-32::
    1s dance up & cast into 2nd pl opposite sides, 1s cross down & cast
    up to 2nd places _while_ 2s+3s set & cross RH twice', 0);
INSERT INTO 'dancecrib' VALUES (9242, '2016-06-16 22:42:20.924186+00', '2017-07-23 15:58:57.72588+00', 14930, 3, NULL, 'ace', '1-8::
    1s turn 2H twice round, face up NHJ & cast down behind own lines
9-12::
    1s turn away from each other, dance up behind lines, meet in centre
    at top & face down NHJ
13-16::
    1s turn 2s (Men RH, Ladies LH). 1s face down NHJ
17-24::
    1s followed by 2s dance down.  2s followed by 1s dance up to places
    2 1 3
25-28::
    1s+3s circle 4H round to Left
29-32::
    1s turn 3s 1.1/2 times 2H to change places  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (14447, '2021-11-11 18:20:58.772233+00', '2022-10-01 18:05:30.903525+00', 20554, 2, 963, 'ace', '1-4::  

  1M, flwd by 1W, cast off, dance across to 2W''s plc WHILE 2W, flwd by 2M, casts up, crosses to 1M plc  2x,1x,3

5-8::  

  1M, flwd by 1W, cast off, dance across to 3M''s plc WHILE 3M, flwd by 3W, casts up, crosses to 2W plc 2x,3x,1

9-12::  

  1C dance 1/2 fig 8 up around 3C  2x,3x,1x  

13-16::  

  All three cpls dance back to back  

17-24::   

  1C flwd by 3C and 2C dance down for 4, men bring women under rt arm and pass behind them to face up middle on own sides: dance up to 2C middle top facing down, 3C in 2nd place and 1C middle bottom facing up  

25-32::  

  Circle 6 hands round and back to 2,3,1 

 

  ', 5);
INSERT INTO 'dancecrib' VALUES (15400, '2023-01-29 23:53:57.975602+00', '2023-01-30 00:04:46.092007+00', 15614, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; turn P LH facing 2W in tandem, 1W leading

9--::

  ½ Reel3 in tandem on 1diag, 1c RSh to 2W ; ½ Parallel Reels3 across, 1W LSh to 1cnr & 1M LSh to 4cnrs[pos]. 1c in tandem (1M leading) face 2W in 3W[pos]

17--::

  ½ Reel3 in tandem on 2diag, 1c RSh to 2W ; 1c in tandem (1M leading) dance up to top and cast to 2plx facing down (2x,1x,3x)

25--::

  3c (+1c+2c who dance down to follow) dance up to top, cross and cast off (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12809, '2020-05-12 12:11:19.624845+00', '2022-10-01 15:23:42.922696+00', 19975, 1, 202, 'ace', '1--::

  1c set | »Tom Bombadil Turn« [: 1c turn P RH ½, 1W pivoting L under joint arms. 1c RHJ face up] ; 1c cast off (2c up) | turn LH ¾ to face 1cnrs (2,*1*,3)

9--::

  SetH&G. On [15-16] 1c turn P RH ¾ to 2pl centre facing down RHJ (2,*1*,3)

17--::

  1c cross down between 3c | cast up to 2pl centre RHJ facing up ; cross up between 2c | cast off to 2pl centre BHJ. On [24] 3c step in ready for

25--::

  1c+3c Poussette (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (13937, '2021-04-05 21:42:08.399013+00', '2023-02-03 20:57:25.825775+00', 20302, 1, 202, 'ace', '1--::

  All Interlocking Reels4, RSh to P. All W face out (1,2,3,4)

9--::

  Schiehallion Reels (3,4,1,2)

17--::

  All M turn P RH ¾ | all M chase clw 1 place _while_ all W ½ LHA ; all W turn new P RH ½ | all W chase clw 1 place _while_ all M ½ LHA (4,1,2,3)

25--::

  All set to P | turn P RH into allemande hold facing cclw ; all dance 2 places cclw (2,3,4,1)



Repeat once in Strathspey time then twice in Reel time.', 2);
INSERT INTO 'dancecrib' VALUES (15206, '2022-11-03 01:18:16.118046+00', '2023-02-04 01:18:17.249894+00', 21113, 3, NULL, 'ace', '1-4::
    2s dance 1/2 Figs of 8 (2M round 1s & 2L round 3s)
5-8::
    2M+1s also 2L+3s dance RH across. 2s pass LSh to finish 2nd place
    own sides
9-16::
    1s+2s+3s chase clockwise once round
17-24::
    1s+2s Set+Link; 1s+3s Set+Link.  2 3 1
25-32::
    2s+3s+1s dance 6 bar LSh parallel reels of 3 on own sides (2s pass
    3s LSh to begin), 2s+3s+1s set.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (15207, '2022-11-03 01:18:16.477884+00', '2023-02-04 01:18:17.60882+00', 21114, 3, NULL, 'ace', '1-4::
    1s set, cast 1 place (2s step up bars 3-4)
5-8::
    1s cross RH & cast round 3s ending in 2nd place in middle BtoB
    facing opposite sides
9-12::
    2s+1s+3s set as in Double Triangles. 1s, retaining RH, turn 1st
    corners once round
13-16::
    1s, passing partner LSh, dance 1/2 diag reel of 4 with 3rd corners
    (1s pass 3rd corners RSh to begin). 1s finish in 2nd place in middle
    BtoB facing opposite sides
17-20::
    2s+1s+3s set as in Double Triangles. 1s, retaining LH, turn 2nd
    corners once round
21-24::
    1s, passing partner RSh, dance 1/2 diagonal reel of 4 with 4th
    corners (1s pass 4th corners LSh to begin). 1s finish in 2nd place
    on opposite sides facing out
25-32::
    1s cast LSh round 2nd corners (1M up, 1L down), pass partner RSh
    up/down middle of set, cast RSh round 4th corners to finish in 2nd
    place own sides  _while_ 3s+2s set (facing up/down) & change places
    RH on sides. 3s+2s set & cross RH. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15406, '2023-02-04 01:18:32.15532+00', '2023-02-04 01:18:32.158207+00', 20297, 3, NULL, 'ace', '1-8::
    1s & 4s set, 1L followed by 1M & 4M followed by 4L chase clockwise
    1/2 round, 1L casts up to 3rd place Men''s side as 1M dances up
    middle to 3rd place Ladies'' side _while_ 4M+4L dance similar to end
    in 2nd place opp sides (2s/3s step down/up 7-8). End 2 (4) (1) 3
9-16::
    4s+1s dance Mixed Chain (as Ladies'' Chain but 4M+1L cross RH & turn
    Lady/Man on sides).
17-24::
    All dance RSh reels of 4 on sides
25-32::
    2s+4s also 1s+3s dance RH across; 4s+1s dance LH across to end 2 (4)
    (1) 3

{{explanation}}
Repeat 3 more times from new positions to end in original places', 0);
INSERT INTO 'dancecrib' VALUES (4073, '2013-08-21 08:30:43.145261+00', '2023-02-04 01:18:32.192653+00', 245, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s cast down 1 place (2s dance up) & 1s set
9-16::
    1s+3s dance LH across, 1s cast down 1 place (3s dance up) & 1s set
17-24::
    1s dance up to top & cast, dance down between 3s & cast up & face
    1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting (6 bars) Bars 31-32 1s petronella
    turn to 2nd place own sides', 3);
INSERT INTO 'dancecrib' VALUES (4157, '2013-08-21 08:30:44.371871+00', '2023-02-04 01:18:37.316189+00', 382, 3, NULL, 'ace', '1-8::
    1s & 3s set, 1L+3M petronella turn & set _while_ partners petronella
    turn into centre (between ptnrs) & turn RH, 1s & 3s petronella to
    opp sides
9-16::
    2s set, dance 1/2 Figs of 8 (2M round 1s & 2L round 3s), 1s & 3s set
    & all 3 couples 1/2 turn LH into prom hold facing up
17-24::
    1s+2s+3s Promenade with 1s casting to 2nd place & 2s leading up to
    top
25-32::
    1s dance reels of 3 across (1L with 2s & 1M with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (4215, '2013-08-21 08:30:45.433028+00', '2023-02-04 01:18:40.936842+00', 472, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up 3-4) & turn LH (4 bars)
9-16::
    1s dance RH across, 1L with 2s at top & 1M with 3s. 1s pass RSh &
    dance LH across with other couple.  1s remain in centre facing 2M at
    top
17-24::
    1s NHJ set twice forming an arch _while_ 2M dances under arch & out
    to left _while_ 2L sets & crosses over. 1s turn inwards to face 3L &
    repeat (3M sets & crosses)
25-32::
    1s swivel Right to face 3L again & repeat (3M sets & crosses), 1s
    turn inward to face 2M again & repeat (2L sets & crosses)
33-40::
    1s in centre pass LSh to dance LSh reels of 3 across (1L with 2s &
    1M with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (3897, '2013-08-21 08:30:38.746424+00', '2023-02-04 01:19:37.1359+00', 14568, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig of 8 (1s crossing down to start)
9-16::
    1s dance reflection reels on own sides (dance between 2s to start)
17-24::
    1L followed by partner dance down the middle, 1M followed by partner
    dance up & out behind 2s to original places
25-32::
    1s+2s change places on sides (dance between 2s) & 1s+3s turn 1.1/2
    times (with other hand).  2 3 1

{{explanation}}
Danced twice through', 0);
INSERT INTO 'dancecrib' VALUES (14935, '2022-07-03 02:12:49.108769+00', '2022-10-09 10:29:11.7395+00', 20929, 1, 202, 'ace', '1--::

  1c set | dance down between 2c (2c up) ; cast off behind 3c | dance up in tandem, 1W leading facing 1cnr (2M)

9--::

  ½ Reel3 in tandem (with change lead) on 1diag ; on [12] 1M pull LSh back and turn P LH to face 2cnr (2W), 1W behind 1M

17--::

  ½ Reel3 in tandem (with change lead) on 2diag ; on [20] 1W pull LSh back and turn P LH, 1c to 2pl

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (4163, '2013-08-21 08:30:44.511008+00', '2023-02-04 01:18:37.710426+00', 394, 3, NULL, 'ace', '1-4::
    1s cross RH, cast, meet in centre facing down & turn away from each
    other to face opposite sides in 2nd place (2s step up 3-4)
5-8::
    3L dances in & turns about into Prom hold with 1M to dance out round
    4L & up middle as 3M dances in & turns left about into Prom hold
    with 1L to dance out round 2L & down middle
9-16::
    1s turn 2H 1.1/2 times in middle to face 2s as 3s turn 2H twice to
    face 4s, 2s & 3s set to corners & turn 2H into lines across
17-24::
    1s & 3s dance reels of 4 across & end turning partners 2H to end in
    order 1 2 3 4 in middle facing up (Ladies on right)
25-32::
    All dancing up divide to dance down own sides & 1s make an arch
    (hands raised - not joined) as 2s+3s+4s dance up to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (11441, '2019-01-01 01:56:16.651301+00', '2023-02-04 01:18:37.727864+00', 396, 3, NULL, 'ace', '1-8::
    1s set, cross RH, set & cast (2s step up)
9-16::
    2s+1s cross RH & circle 4H 1/2 round to left (1 skip change to cross
    + 6 slip steps for circle); cross LH & circle 4H 1/2 round to right
    (2 skip change + 4 slip steps)
17-24::
    1L+2s & 1M+3s dance reels of 3 across (1s RSh to 4th corner). 1s end
    facing 1st corners
25-32::
    Hello-Goodbye setting, 1s petronella turn to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (15131, '2022-10-05 00:18:40.120362+00', '2023-02-04 01:18:38.459236+00', 20794, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All set to partners twice; all turn partner 3/4 RH, Ladies join LH
    in centre, Men pull back RSh & join NH with partner facing
    anticlockwise. All dance LH across 1 place round (2 bars).  Finish
    Ladies BtoB in centre facing partner
9-16::
    All set, change places RH with partner (Men now BtoB in centre); all
    dance 1/2 interlocking double reel of 4 (LH across in centre)
17-24::
    All set, change places RH with partner (Ladies now BtoB in centre);
    all dance 1/2 interlocking double reel of 4 (LH across in centre).
    Finish with Ladies on partner''s right facing out
25-32::
    All dance 8 bars Schiehallion reel.  Couples have progressed 1 place
    clockwise round 4 1 2 3

{{explanation}}
Repeat in Reel time, Strathspey time & Reel time', 0);
INSERT INTO 'dancecrib' VALUES (8541, '2015-02-13 12:47:26.184994+00', '2023-02-04 01:18:38.625546+00', 15608, 3, NULL, 'ace', '1-4::
    1M dances 1/2 reel of 3 with 2s
5-12::
    1s (Man behind Lady) dance Alternating Tandem reel of 3 with 2s with
    1M ending in partners place
13-16::
    1L dances 1/2 reel of 3 with 2s to end (1)2
17-24::
    1s+3s dance Ladies'' Chain
25-32::
    1L followed by partner casts 1 place & crosses to own side, 2s+1s+3s
    turn LH', 0);
INSERT INTO 'dancecrib' VALUES (4177, '2013-08-21 08:30:44.899362+00', '2023-02-04 01:18:38.825344+00', 9972, 3, NULL, 'ace', '1-4::
    1L+2L change places LH _while_ 1M+2M change pl RH, 1L+3L change pl
    RH _while_ 1M+3M change pl LH
5-8::
    2s & 1s set advancing & 1/2 turn 2H to form circle with 3s (2s
    facing 3s & 1s facing each other)
9-16::
    2s+3s+1s dance interlocking reels of 4 & end on sides
17-24::
    2s & 1s cross RH, 1s cast up to 2nd place & turn (or spin) RH
25-32::
    2s+1s+3s circle 6H round to left for 6 steps, all pivot left & 2s+3s
    chase back to places _while_ 1s turn (or spin) LH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (8304, '2014-07-29 12:58:44.321714+00', '2023-02-04 01:18:38.846466+00', 15221, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-8::
    1s set adv. & turn 2H to face down & give nearer hand to 2s (2s face
    up), 1s+2s set & 1s turn 2s on sides with nearer hand to finish in
    lines across facing down, WHILST, 4s dance likewise with 3s
9-10::
    All set
11-16::
    1s & 4s change places RH, cast behind 2s & 3s, pass partner by the
    right to face corner (4M facing 2M, 4L facing 2L, 1L facing 3L, 1M
    facing 3M) on the diagonal
17-24::
    All dance (RSH) interlocking diagonal reels of 4 to end on the sides
    2 4 (1) (3)
25-32::
    4s & 1s, giving RSH to corners, reel of 4 on sides, middles passing
    RSH at end 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (4179, '2013-08-21 08:30:44.917293+00', '2023-02-04 01:18:39.077236+00', 420, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across, set & dance 1/2 RH across
9-16::
    1L followed by partner casts 1 place, crosses, casts down round 3M
    up to 2L
17-24::
    1s+2L dance RH across, LH across with 3M & dance up to 2M
25-32::
    1s dance LH across with 2M, RH across with 3L & both end 2nd place
    own sides
33-40::
    2s+1s turn on sides (Ladies RH, Men LH), 1s+3s turn (Ladies LH, Men
    RH)', 0);
INSERT INTO 'dancecrib' VALUES (4180, '2013-08-21 08:30:44.925398+00', '2023-02-04 01:18:39.103653+00', 9002, 3, NULL, 'ace', '1-8::
    1s+3s set & dance the Capstan:
::
    1M+3M change places by dancing LSh 1.1/2 times round standing 2M
    _while_ 1L & 3L dance RSh 1.1/2 times round 2L
9-16::
    1s cross (no hands) up to 2nd pl opp sides, 1L+3M (at top) turn RH
    _while_ 1M+2L turn RH, 1s pass RSh & 1L+2M also 1M+3L turn RH 3 (1)
    2
17-24::
    3s+1s+2s set, 1/2 turn partners RH & chase clockwise 1/2 way 2 (1) 3
25-32::
    1s dance RH across (Man with 2s & Lady with 3s), 1L dances 1/2 Fig
    of 8 round 2s _while_ 1M dances 1/2 Fig of 8 round 3s', 0);
INSERT INTO 'dancecrib' VALUES (4181, '2013-08-21 08:30:44.935291+00', '2023-02-04 01:18:39.126761+00', 11798, 3, NULL, 'ace', '1-8::
    1s set & turn RH, cast 1 place & cross LH
9-16::
    1s dance reels of 3 on opposite sides (dancing out round 3s to
    start)
17-24::
    1s set & Petronella turn, set & Petronella turn to own sides
25-32::
    1s set advancing & turn 2H, dance down below 3rd place & cast up to
    2nd place _while_ 2s+3s dance R&L (starting RH on sides)', 0);
INSERT INTO 'dancecrib' VALUES (4182, '2013-08-21 08:30:44.945131+00', '2023-02-04 01:18:39.148825+00', 424, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opposite sides

1-8::
    1s & 4s dance 1/2 Figs of 8 round 2s/3s & end between 2s/3s in lines
    across, 1s+2s Adv+Ret as 4s+3s Ret+Adv
9-16::
    All dance reels of 4 across 1s & 4s end in middle BtoB facing
    corners
17-24::
    1s & 4s dance ''Hello-Goodbye'' setting & on bars 23-24 end with1M &
    4M crossing RH to face out (1M on L side, 4M on M side) _while_
    others PdB turning around as 4L ends facing down between 2s & 1L
    facing up between 3s
25-32::
    1M & 4M followed by partners cast to right around corner (3M/2M)
    into centre, loop round to right & cast around next corner (3L/2L)
    then cross to other side to end 2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (4223, '2013-08-21 08:30:45.589728+00', '2023-02-04 01:18:41.67494+00', 483, 3, NULL, 'ace', '1-8::
    All turn RH & turn corners LH to end facing clockwise Lady on right
9-16::
    All Promenade to original places
17-24::
    The Bouquet - All set to partners, Men cast & chase cl''wise _while_
    Ladies cast & chase anticl''wise to meet new partners, repeat with
    new partner
25-32::
    Repeat twice more
33-40::
    All circle 8H round & back
41-48::
    All in Allemande hold promenade to original places
49-64::
    Repeat The Bouquet', 0);
INSERT INTO 'dancecrib' VALUES (14789, '2022-05-05 00:18:34.160601+00', '2023-02-04 01:18:39.171776+00', 17103, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s+4s (who dance up sides to start) dance down (3
    bars),cast up back to place (3 bars ) & all join hands on sides &
    set
9-16::
    1M followed by 2M dances between 1L & 2L, down behind 2L, across set
    and back up Men''s side to place _while_ 3M+4M dance similar round 3L
    & 4L, all Men set
17-24::
    Ladies advance towards partner & set to partner (no hands); pull
    back RSh & dance out to place, join hands & set
25-28::
    1s cast (2s cross up LH) _while_ 4s cast up (3s cross down RH),
    1s+4s (middle couples) dance 1/2 RH across _while_ 2s+3s (end
    couples) set
29-32::
    2s+4s also 1s+3s dance 1/2 LH across, all 4 couples join hands on
    sides & set.  4 2 1 3
33-40::
    Men advance towards partner & set to partner (no hands); Men dance
    RSh round partner & back to place
41-48::
    4s+2s also 1s+3s dance the Knot.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4183, '2013-08-21 08:30:44.953197+00', '2023-02-04 01:18:39.194546+00', 428, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, turn LH 1.1/2 times 2nd place opposite
    sides
9-16::
    1M casts up, crosses & casts to 2nd place own side as 1L cast down 1
    place, crosses & casts up to 2nd place _while_ 2s+3s dance RH across
    once round 1s turn LH 1.1/2 times to face 1st corners positions
    _while_ 2s+3s chase clockwise to opposite corners
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners & 1/2 reel of 4
    with 2nd corners
25-32::
    2s+1s+3s dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4185, '2013-08-21 08:30:44.971009+00', '2023-02-04 01:18:39.257467+00', 10155, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reel of 3 on own sides (1s in & down to start)
9-16::
    1s turn RH 1.1/2 to end facing 1st corners, 1s dance Pass+Turn with
    1st corner & turn RH to face 3rd corner
17-24::
    1s dance diagonal RSh reel of 4 & end turning RH to 2nd place on own
    side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4186, '2013-08-21 08:30:44.980889+00', '2023-02-04 01:18:39.444262+00', 9113, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s set to 2s & 1/2 turn (1s dancing between
    2s).  2 1 3 4
9-16::
    All dance reflection reels of 4 on sides (1s in & down, 3s in &
    down)
17-24::
    1s+3s petronella turn into centre (merging 1L+3L+1M+3M) _while_
    2s+4s change places RH on sides & all set, 1s+3s petronella turn to
    opposite side _while_ 4s & 3s cross LH & all set
25-32::
    Repeat bars 17-24 back to own sides
33-40::
    1s cross RH, cast to bottom & turn 2h 1.1/2 times.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (10328, '2017-12-22 15:43:55.876821+00', '2023-02-04 01:18:39.457565+00', 14476, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance double Figs 8 (1s & 4s cast, 2s cross up, 3s
    cross down)
9-16::
    2s+3s dance the "Tourbilink":
::
    _9-10_    2s+3s 1/2 turn partners 2H, 2M and 3L lead partners NHJ 1
    place clockwise to end 2s on Ladies'' side and 3s on Men''s side
::
    _11-14_  2s+3s Set+Link on the sides
::
    _15-16_  2s+3s chase clockwise round one place. 1(3)(2)4
17-24::
    1s+3s & 2s+4s dance the "Tourbilink"  3(1)(4)2
25-32::
    All dance RSh  reel of 4 on sides
33-40::
    1s+4s dance 1/2 RH across, 1L+4L & 1M+4M set facing up/down on sides
    &1/2 turn RH, 1s+4s set to partner  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (15214, '2022-11-03 01:18:38.713602+00', '2023-02-04 01:18:39.467903+00', 21117, 3, NULL, 'ace', '1-2::
    1s turn RH _while_ 2s set.
3-8::
    1s lead down the middle for 4 bars & back to 2nd place to finish in
    the middle facing up _while_ 2s cast up into 1st place, turn RH to
    finish in middle facing up. 3s step in on bar 8.  2 1 3
9-16::
    2s+1s+3s dance Allemande. 1s finish facing 1st corners (pstn).
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners then with 2nd
    corners (pstn) to finish in 2nd place opposite sides
25-28::
    1s 1/2 turn RH to face down, 1s lead down & on bar 28 1M guides 1L
    in front of him.
29-32::
    1L followed by 1M dance round 3M''s place & into 2nd place on own
    sides _while_ 2s & 3s set & cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (4187, '2013-08-21 08:30:44.99072+00', '2023-02-04 01:18:39.482313+00', 431, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    1s+2s dance R&L
9-16::
    1s dance between 2s & cast back to place, 1s turn RH
17-24::
    2s repeat bars 9-16 round 1s
25-32::
    1s+2s Adv+Ret (with 3 claps on bar 28). 1s+2s advance to meet next
    couple (1s making an arch)', 0);
INSERT INTO 'dancecrib' VALUES (4188, '2013-08-21 08:30:45.000624+00', '2023-02-04 01:18:39.499671+00', 11373, 3, NULL, 'ace', '1-8::
    1L+2M turn RH to give LH to partner & Bal-in-Line, 1L followed by
    partner casts 1 place (Men''s side) & crosses to end 2nd place own
    sides _while_ 2M followed by partner casts up (Ladies'' side) &
    crosses to 1st place own side
9-16::
    2s+1s+3s dance reels of 3 on sides (1s RSh to 3s to start)
17-24::
    1s repeat bars 1- 8 with 3s
25-32::
    1L dances behind 3L, in front of 2L & casts to 2nd pl _while_ 1M
    dances in front of 3M, behind 2M & dances down to 2nd place,
    2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (4189, '2013-08-21 08:30:45.010568+00', '2023-02-04 01:18:39.512636+00', 11587, 3, NULL, 'ace', '1-8::
    1s set & cross RH, 1s set to 2s on sides & change places LH
9-16::
    2s+1s dance Ladies'' Chain
17-24::
    1M followed by 1L casts behind 3L & 1M crosses to own side then
    casts up to 2nd place as 1L dances up middle to 2nd pl. (4 bars),
    2s+1s turn LH on sides
25-32::
    1s dance reels of 3 on sides giving RSh to 3s', 0);
INSERT INTO 'dancecrib' VALUES (4190, '2013-08-21 08:30:45.020331+00', '2023-02-04 01:18:39.526602+00', 434, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across 1/2 way, set & cross RH
9-16::
    2M+1L+3M Advance, Bal-in-Line & retire _while_ 2L+1M+3L Advance &
    Bal-in-Line
17-24::
    2L+1M+3L dance reel of 3 up/down middle (1M RSh to 3L to start) &
    end on sides
25-32::
    2M+1L+3M dance reel of 3 up/down middle (1L RSh to 2M to start) &
    end on sides', 0);
INSERT INTO 'dancecrib' VALUES (15119, '2022-10-01 15:30:25.561076+00', '2022-10-01 15:38:59.779571+00', 21131, 1, 1645, 'ace', '1--::
  2c set | cast round 3cnr to lines across facing 2cnr ; &frac12; LSh Reels3 across
9--::
  2c dance LSh round P to end BtoB on centre line M facing up, W down ; 1c+2M & 2W+3c Circle3 to L ending on the sides (1x,2,3x)
17--::
  1c+2c+3c S&Link, 3c & 1c end facing P ; 2c petronella to own side | set _while{4}_ 3c & 1c set | cross RH (3,2,1)
25--::
  2c+1c Knot (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (4191, '2013-08-21 08:30:45.030435+00', '2023-02-04 01:18:39.540503+00', 7349, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & 2s+1s+3s turn partners RH
9-16::
    2s+1s+3s circle 6H round & back
17-24::
    1s cross RH, cast 1 place & 3s+1s+4s turn partners LH
25-32::
    1L dances reel of 3 with couple above (3s) & 1M with couple below
    (4s) 1s end between 5s Man facing Lady
33-40::
    1s+5s dance reel of 4 across 1s ending in 5th place', 0);
INSERT INTO 'dancecrib' VALUES (2820, '2012-01-22 19:29:58.737892+00', '2022-10-01 19:07:57.694334+00', 9638, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up) ; 1c followed by 3c dance up and cast round 2c to (2,3,1,4,5)

9–::

  1c+4c+5c mirror Reels3, 1c cross down to enter, 4c start out and up (2,3,1x,4,5)

17–::

  2c+3c+1c mirror Reels3, 1c cross up to enter, 3c start out and down

25–::

  1c set | cast off to 4pl (4c up) ; 1c followed by 5c dance up and cast round 4c to (2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (4192, '2013-08-21 08:30:45.040344+00', '2023-02-04 01:18:39.553042+00', 13859, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 2s+1s+3s set & turn RH 1/2 way to end in
    middle in prom hold (2s facing down & 1s+3s facing up with3L on
    ptnrs left)
9-16::
    2s+1s+3s dance a Promenade reel of 3 (2s+1s pass RSh to start) all
    ending on own sides  2 1 3
17-24::
    2s+1s+3s dance Inveran reels of 3 on sides (1s dance up between 2s
    to start, cast & cross down to 3rd place)  2(1)3
25-32::
    2s+1s+3s Adv+Ret, 1s turn RH 1.1/2 times  2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (4194, '2013-08-21 08:30:45.069104+00', '2023-02-04 01:18:39.785627+00', 441, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All dance RSh reels of 4 on sides
9-16::
    All set twice & turn partner 2H
17-24::
    1M & 2M cross to face 2L &1L (1M in front of 2M) also 3M & 4M cross
    to face 4L & 3L (3M in front of 4M), all set & Men dance round
    Ladies RSh back to places (again 1M & 3M in front of 2M & 4M)
25-32::
    All set twice, turn 2H into 2 diagonal lines of 4 (1M & 2L also 3M &
    4L in own places & partners BtoB between them
33-40::
    All dance RSh diagonal reels of 4
41-48::
    All set twice & turn 2H to end in original places
49-56::
    1s & 3s set advancing to partner & turn 2H (Ladies on partners left)
    to face 2L/4L, set & circle 3H round to left 1/2 way to face 2M/4M
57-64::
    1s+3s set twice to 2M+4M & circle 4H round for 2 steps, turn partner
    2H to original places

{{title}}
Reel

1-8::
    1s+2s also 3s+4s dance 1/2 R&L with setting between each hand to
    person just passed
9-16::
    All repeat bars 1- 8
17-24::
    All Men set for 8 bars (Highland Steps) as partners set twice &
    advance turning with 4 PdB steps to right to give their backs to the
    Men
25-32::
    All Men dance RSh round partner to face them, all set twice with
    Ladies again turning their backs on the Men
33-40::
    All repeat bars 25-32
41-48::
    All Men dance forward 3 PdB steps, pat partners on shoulder & dance
    back 1 step, Ladies turn to face partner, turn RH to end facing in
    middle', 0);
INSERT INTO 'dancecrib' VALUES (4195, '2013-08-21 08:30:45.077229+00', '2023-02-04 01:18:39.815831+00', 442, 3, NULL, 'ace', '1-8::
    1s+2s turn 2H on sides (2 bars) opening out to circle 4H round to
    left (4 bars), 1s & 2s turn partners 2H (2 bars) & end in centre
    with 3s dancing in ready for ...
9-16::
    1s+2s+3s Promenade ending with 1s casting to 2nd place
17-24::
    1s+3s dance RH across once round, 2s+1s dance LH across once round
25-32::
    2s+1s+3s dance reels of 3 on own sides 1s giving RSh to 3s', 0);
INSERT INTO 'dancecrib' VALUES (4196, '2013-08-21 08:30:45.088969+00', '2023-02-04 01:18:39.842695+00', 9022, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 1s turn 2H opening out to face up with nearer hands
    joined
9-16::
    1s dance reels of 3 on own sides (1s in & up to start) & end facing
    1st corners
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    Pass+Turn with 2nd corners ending with 1s facing up (Lady on Mans
    left)
25-32::
    1s lead up, cross, cast 1 place, dance down between 3s & cast up to
    2nd place on own side', 0);
INSERT INTO 'dancecrib' VALUES (4198, '2013-08-21 08:30:45.120783+00', '2023-02-04 01:18:39.947208+00', 10546, 3, NULL, 'ace', '1-8::
    All dance Schiehallion Reel 1/4 way (1 place), 1s+3s dance RH across
    _while_ 2s & 4s turn partners RH
9-16::
    All dance Schiehallion Reel 1/4 way (1 place, 2s+4s dance RH across
    _while_ 1s & 3s turn partners RH
17-24::
    All chase clockwise to original pstns, set & cast 1 place clockwise
25-32::
    All circle 8H round & back

{{explanation}}
Repeat in Jig Time from new pstns', 0);
INSERT INTO 'dancecrib' VALUES (4199, '2013-08-21 08:30:45.13066+00', '2023-02-04 01:18:39.981761+00', 8023, 3, NULL, 'ace', '1-4::
    1s cross down to 3rd pl _while_ 2s set as 3s cast to top & all cross
    RH;
5-8::
    Repeat from new positions: 3s cross down to 3rd pl _while_ 2s set as
    1s cast to top & all cross RH.  (1)2(3)
9-16::
    1s+2s+3s dance reels of 3 on sides (2s in & up to start) & 1s cross
    to own sides.  1 2 (3)
17-24::
    2s dance 1/2 Fig of 8 round 1s, 3s dance 1/2 Fig of 8 round 2s.  1
    (2) 3
25-32::
    1s+2s+3s set, 1s+2s dance RH across 1/2 way _while_ 3s cross RH;
    all set & 1s+3s dance LH across 1/2 way.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4200, '2013-08-21 08:30:45.140751+00', '2023-02-04 01:18:40.011266+00', 445, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, dance RH across with 3s & end 1M+3L also
    1L+3M in prom hold facing out to pass corner person RSh
9-24::
    All dance 4x1/2 Reels of 3 on sides (to right to start, then left,
    right & left) with 1s+3s changing partners in centre at end of each
    1/2 Reel to progress Men clockwise & Ladies anticlockwise.  End in
    centre 1s facing down & 3s facing up
25-32::
    1s dance between 3s turning 3s with nearer hand 1.1/2 times,
    crossing over to own sides & turn 4th person 1.1/2 times (Men RH &
    Ladies LH)', 0);
INSERT INTO 'dancecrib' VALUES (9468, '2016-11-09 08:48:09.187179+00', '2023-02-04 01:18:40.040917+00', 15022, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up), meet in centre & turn 3s (1M+3L LH &
    1L+3M RH) finishing in centre facing up  2 (1) 3
9-16::
    2s+1s+3s dance reflection (mirror) reels of 3 on sides (1s up, 2s
    out/down, 3s out/up).
17-24::
    1s dance 1/2 Fig 8 round 2s & dance 1/2 reels of 3 across (1L+2s &
    1M+3s,1s passing 1st corner LSh). Finish all on opp sides (2) (1)
    (3)
25-32::
    2s+1s+3s Adv+Ret.  2s+1s+3s 1/2 turn partner RH, pull back RSh &
    dance out to own sides.  2  1  3', 0);
INSERT INTO 'dancecrib' VALUES (4202, '2013-08-21 08:30:45.165575+00', '2023-02-04 01:18:40.087849+00', 447, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s
9-16::
    1M+2L set & change places RH, 1L+2M set & change places RH
17-24::
    1s+3s dance RH across & LH back
25-32::
    1M+3M set & change places RH, 1L+3L set & change places RH
33-40::
    1s+4s dance 1/2 R&L, all set & cross over.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14640, '2022-03-07 02:18:32.653282+00', '2023-02-04 01:18:40.110915+00', 16873, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance mirror reels of 3 on the sides (1s in/down to start)
9-16::
    1s turn RH and face down NHJ, 1s+2s set; 2s dance up to 1st place as
    1s dance down and cast up round 3s to 2nd place.  2 1 3 4
17-24::
    1s turn 1.1/4 RH to face 2nd corners; 1s turn 2nd corners LH & turn
    1st corners RH into lines of 3 across (1L between 2s, 1M between 3s)
25-32::
    Lines of 3 Adv+Ret; 1s turn 1.1/4 RH to 2nd place own side.  2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (14484, '2021-12-18 01:43:03.157703+00', '2023-02-04 01:18:40.140913+00', 15531, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All circle 8H round & back
9-16::
    1s+3s change places, 1s dancing under arch made by 3s & change
    sides, Ladies dance under Man''s right arm; repeat, 1s making arch
17-24::
    Ladies Petronella turn 1 place right & all set; Men Petronella turn
    1 place right & all set
25-32::
    All repeat 17-24 (all couples now opposite original place)
33-40::
    2s+4s dance RH across finishing 2L facing 1M (3M''s place) with
    partner following & 4L facing 3M (1M''s place) with partner following
41-48::
    2s & 4s dance Alternating Tandem RSh reels of 3 across with 1s / 3s.
    End as at end bar 32, all facing corners
49-56::
    All set, all change places with corners with La Barrat & finish
    facing next person
57-64::
    All change places RH with facing person & LH with next person into
    partner''s original place & all turn partner RH 1.1/2

{{explanation}}
Reel	As Strathspey except:

::
    _9-16_    2s+4s change places, 4s make 1st arch, 2s make 2nd arch
::
    _33-40_  1s+3s dance RH across, LH back & end facing partners (3s
    between 2M/4L & 1s between 2L/4M) & dance RSh reels of 4 across. 1s
    & 3s pass partner RSh at end of reel', 0);
INSERT INTO 'dancecrib' VALUES (15120, '2022-10-01 21:07:30.509714+00', '2022-10-01 21:12:57.779974+00', 21113, 1, 202, 'ace', '1--::

  2c ½ Fig8 L round 2cnrs ; 1c+2M & 2W+3c RHA. 2c pass P LSh to 2pl (1,2,3)

9--::

  All chase clw (1,2,3)

17--::

  1c+2c Set&Link ; 1c+3c Set&Link (2,3,1)

25--::

  Parallel Reels3 on sides {6}, 2c LSh to 3c | all set (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (4145, '2013-08-21 08:30:44.152791+00', '2023-02-04 01:18:36.827763+00', 13720, 3, NULL, 'ace', '1-8::
    1s+2s set, circle 4H round to left, turn 2H into prom hold facing up
9-16::
    1s+2s dance Allemande 1s end turning LH to face 1st corners
17-20::
    1s dance RSh round 1st corner position & end facing 2nd corners as
    corners 1/2 turn & twirl to dance out to opposite corners
21-24::
    1s repeat with 2nd corners
25-32::
    1s dance RH across (M with 3s at top, L with 2s), 1s followed by
    3s/2s dance clockwise 1/2 way to own sides', 0);
INSERT INTO 'dancecrib' VALUES (10825, '2018-06-11 00:35:53.847214+00', '2023-02-04 01:18:40.355934+00', 18373, 3, NULL, 'ace', '{{explanation}}
2 chords - on 2nd chord 3s & 4s cross to opp sides

1-8::
    1s+2s also 3s+3s Set & Rotate (top 2 & bottom 2 couples set facing
    in diagonally) 2 1 (4) (3)
9-16::
    Tandem reels on sides: 1M followed by 4L RSh to 2M (up), 4M followed
    by 1L RSh to 3M (down)
17-24::
    "Double Knot":
::
    2s+1s dance Knot down Men''s side to bottom ending on opp sides
    _while_ 4s+3s dance Knot up Ladies'' side to top ending on own sides
    4 3 (2) (1)
25-28::
    3s+2s (middle couples) dance 1/2 RH across & set  4 2 (3) (1)
29-32::
    4s+1s turn partner RH (4 bars) moving down/up to 2nd/3rd place
    _while_ 2s+3s cast to 1st/4th place & turn RH (2 bars)  2 4 (1) (3)

{{explanation}}
Repeat once more in Strathspey time and twice in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (4204, '2013-08-21 08:30:45.186224+00', '2023-02-04 01:18:40.418498+00', 451, 3, NULL, 'ace', '1-4::
    1L followed by partner dances across & behind 4s (4s turn slightly
    to left)  & 1s+4s dance 1/2 LH across
5-6::
    1L followed by partner dances across to in front of 3s _while_ 4s
    continue turning LH to place
7-10::
    1s+3s dance RH across
11-14::
    1L followed by partner dances across & behind 2s (2s turn slightly
    to left)  & 1s+2s dance 1/2 LH across
15-16::
    1s dance to place in prom hold _while_ 2s continue turning LH to
    place & take prom hold
17-24::
    All Promenade round anticlockwise
25-32::
    All Men dance RSh round next Lady to right (not partner) into centre
    & dance LH across back to places
33-40::
    All Ladies dance LSh round next Man to left (not partner) into
    centre & dance RH across back to places
41-48::
    All circle 8H round & back

{{explanation}}
Repeat 3 more times with couple to right starting, i.e. dancing couple order is 1 4 3 2', 0);
INSERT INTO 'dancecrib' VALUES (4205, '2013-08-21 08:30:45.194566+00', '2023-02-04 01:18:40.453778+00', 453, 3, NULL, 'ace', '1-8::
    1s set advancing & turn RH, lead down crossing below 2s & cast up to
    1st place opposite sides
9-12::
    1s set & cast to 2nd place as 2s set advancing & turn LH
13-16::
    1s set & dance up to 1st place opposite sides as 2s lead up crossing
    & cast to 2nd place opposite sides
17-20::
    1s cast & cross up to 1st place as 2s cross up & cast to 2nd place
21-24::
    1L+2L 1/2 turn RH as 1M+2M 1/2 turn LH & 1s dance up & turn inwards
    to face down as 2s cast to 2nd place & face up
25-32::
    1s dance down making an arch under which 2s dance up & Men cross
    partners in front of them, 2s & 1s turn twice to own sides', 0);
INSERT INTO 'dancecrib' VALUES (4206, '2013-08-21 08:30:45.205312+00', '2023-02-04 01:18:40.485489+00', 13849, 3, NULL, 'ace', '1-8::
    All set touch hands & turning away from partner dance to corner
    positions, turn corners 2H & dance back to original places
9-16::
    All dance Grand Chain (start RH to partner) 1/2 way & face clockwise
    in prom hold with partner, all promenade 3/4 round (1s in 2nd pl
    etc)
17-24::
    Side couples (1s+3s) circle 4H round to left & set, 1s+3s turn away
    fom partner & curve back to places (as bar 16)
25-32::
    2s+4s repeat bars 17-24
33-40::
    All circle 8H round to left 1/2 way (2 bars) & dance in, turn right
    about (all touching LH) dance out to reform & circle 8H round back
    to place', 0);
INSERT INTO 'dancecrib' VALUES (4208, '2013-08-21 08:30:45.339168+00', '2023-02-04 01:18:40.524121+00', 457, 3, NULL, 'ace', '1-8::
    All 4 couples turn partner RH & chase 1/2 way
9-16::
    4s+3s also 2s+1s dance RH across, 2L followed by 1L+1M+2M cross &
    turning left chase anticlockwise round top of set _while_ 3M
    followed by 4M+4L+3L cross & chase anticlockwise round bottom of set
    All end in original place but opposite sides
17-24::
    2s & 4s cross up RH, cast down 1 pl into prom hold & dance 1/2 reel
    of 3 across with cpl above (2s dance to Men''s side & 4s to Ladies''
    side to start)
25-32::
    2s & 4s release hands & dance up to own sides & dance full reels of
    3 across with 1s & 3s in prom hold
33-40::
    1s & 3s turn RH & cast up (order 1 2 3 4), 1s lead down to 4th place
    under arches made by others', 0);
INSERT INTO 'dancecrib' VALUES (8542, '2015-02-13 12:47:26.739484+00', '2023-02-04 01:18:40.640104+00', 15609, 3, NULL, 'ace', '1-4::
    1M+2L set advancing, 3/4 turn 2H & twirl to end BtoB (2L facing up &
    1M down) _while_ partners chase anticlockwise to face partner
5-8::
    Set to partners & turn RH, 2s to own sides in 1st place & 1s turn RH
    to 1M facing up as 1L faces down
9-16::
    1s dance reels of 3 across giving RSh to 2nd corners (1M with 2s, 1L
    with 3s) & end facing 1st corners
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    Pass+Turn with 2nd corners & 1s turn LH to end Lady facing up & Man
    down
25-32::
    1s dance reels of 3 across (LSh to 1st corner) & end 2nd place own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (14110, '2021-07-07 00:18:35.6963+00', '2023-02-04 01:18:40.680001+00', 463, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s turn 1.1/4 LH to face 1st corners
9-16::
    1s turn 1st corner RH, partner LH; turn 2nd corner RH & turn partner
    LH to face 1st corners
17-24::
    1s dance 6 bar reels of 3 on opp sides passing 1st corner LSh to
    start, 1s cross up RH to 1st place _while_ 2s cast to 2nd place
25-32::
    1s set & 1/2 turn RH to finish in centre facing down; 4s set
    advancing, turn LH once round to finish in centre facing up (Ladies
    on right of partners)
33-36::
    2s & 3s set twice, 2M & 3L advancing towards partner on bars 35-36
37-40::
    2s turn 2H 3/4 round to end on Ladies'' side _while_ 3s turn 2H 1.3/4
    round to end on Men''s side (now in square set, Ladies on right of
    partners)
41-48::
    All face partners & dance 1/2 Grand Chain to meet partner again.
    Bars 47-48 all turn partners RH once round
49-56::
    All face partner & continue Grand Chain back to place. Bars 55-56
    all turn partners RH once round & face in
57-64::
    1s+4s dance Ladies'' Chain up/down set & finish facing corners
65-72::
    1s & 4s set twice to corners & turn corners 2H
73-80::
    2s+3s dance Ladies'' Chain across set & finish facing corners
81-88::
    2s+3s repeat 65-72
89-96::
    All dance 8H round & back.  Honour corner then partner.', 0);
INSERT INTO 'dancecrib' VALUES (2263, '2012-01-22 19:29:28.500038+00', '2022-10-02 12:00:27.707575+00', 9537, 1, NULL, 'ace', '1–::

  1c ½ RH turn | 1c+2c ½RHA ; 1c+3c ½LHA, 1c+4c ½RHA (2x,3x,4x,1)

9–::

  1c cast up to top ; cross RH and cast off to face 1cnr position

17–::

  Corners Pass and Turn, finish facing out in 2plx (2x,1x,3x,4x)

25–::

  1c+3c half turn easy hand (1c move out) | 1c+4c turn ½ easy hand (1c move in) ; all set | all cross RH', 2);
INSERT INTO 'dancecrib' VALUES (12460, '2020-01-02 06:58:48.255361+00', '2023-02-04 01:18:40.766264+00', 12831, 3, NULL, 'ace', '1-2::
    1M+2M 1/2 turn LH _while_ 1L+2L 1/2 turn RH _while_ 3s set, 3M
    pulling back LSh, 3L RSh, to face out
3-4::
    2s (facing out)+1s (facing in)+3s (facing out) Balance in Line
5-8::
    1s+3s change places (Men RH, Ladies LH), 2s+3s+1s Balance in Line
9-16::
    2s+3s+1s dance mirror reels of 3 on sides (2s out/down, 3s in/up, 1s
    out/up)
17-24::
    1s dance up to 2nd place _while_ 3s step down to 3rd place (2 bars),
    1s cross up LH between 2s & cast to 2nd place opp sides, turn LH to
    face 1st corners
25-32::
    1s set to 1st corner, set to partner, set to 2nd corner, pull back
    RSh & dance round each other RSh to 2nd place own side facing out.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4213, '2013-08-21 08:30:45.413418+00', '2023-02-04 01:18:40.800922+00', 10507, 3, NULL, 'ace', '1-8::
    1s & 3s petronella turn into middle & set, 1s+3s dance 1/2 RSh reel
    of 4 up/down middle
9-16::
    1s & 3s change places with partners RH, 3M+1L change places LH &
    1L+3M+2s dance LH across _while_ 1M+3L chase clockwise 1/2 way
17-24::
    1s & 3s petronella turn to own sides & set, 1s cast 1 place & turn
    LH into…
25-32::
    1s dance reels of 3 across (1L with 2s & 1M with 3s) ending in 2nd
    places (NB 2nd time - 1s dance between 3s to 4th pl)', 0);
INSERT INTO 'dancecrib' VALUES (4214, '2013-08-21 08:30:45.42329+00', '2023-02-04 01:18:40.868209+00', 471, 3, NULL, 'ace', '1-8::
    1s+2s+3s cross RH & all chase clockwise to Ladies across top 1st pl
    & Men across in 3rd pl, all change places with prtnr LH & chase
    anticl''wise back to places
9-16::
    1s followed by 2s (in »Galant hold«) dance down below 3rd pl,1s
    cross, 2s remain on own side & 1s cast up to 2nd place opp sides &
    3/4 turn RH remaining in middle facing up _while_ 2s cast up to 1st
    place own sides
17-24::
    1M followed by 1L dance up and cast behind 2L (in 1st place) and
    into 2nd place own sides.  All turn RH.  2 1 3
25-32::
    All circle 6H round & back

{{explanation}}
Galant Hold: Lady on Man''s Left.  Man gives partner right hand & puts his left hand behind her. She takes his left hand in hers on her waist. If the lady wishes (and if she trusts him) she may allow him to rest his hand on her waist while she holds her skirts in the approved manner.', 0);
INSERT INTO 'dancecrib' VALUES (15407, '2023-02-04 01:18:40.901548+00', '2023-02-04 01:18:40.903173+00', 20305, 3, NULL, 'ace', '1-8::
    1s & 3s cross, cast (2s & 4s step up); 1s & 3s dance 1/2 Fig 8 round
    couple above
9-16::
    3s followed by 1s dance down, cast up behind own line, 3s to 2nd
    place, 1s to 4th place, 1s & 3s turn partner LH to face 1st corners.
    2 3 4 1 5
17-20::
    1s & 3s dance Corner Pass+Turn with 1st corners, pull back RSh to
    face 4th corners
21-24::
    1s & 3s dance Corner Pass+Turn with 4th corners finishing 3s in 2nd
    place, 1s in 4th place own side. 2 3 4 1 5
25-32::
    2s+3s+4s (top 3 couples) circle 6H round & back _while_ 1s+5s
    (bottom couples) dance 1/2 R&L, set & cross RH.  2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (4216, '2013-08-21 08:30:45.443096+00', '2023-02-04 01:18:40.963713+00', 474, 3, NULL, 'ace', '1-4::
    1s cross RH, cast 1 place, dance into centre & up to form a line
    across with 2s (all facing up)
5-12::
    1s+2s dance up 1 step & Men pass Ladies (1M+2L, 2M+1L) in front to
    put 2s in the middle in prom hold facing 1L (in 1M place), 1s+2s
    dance 1/2 reel of 3 across giving LSh to 1L, 2s cast down round 1s
    to original places
13-16::
    2s cross RH, cast up to top, dance into centre & form line across
    with 1s (facing down)
17-24::
    1s+2s dance down 1 step & Men pass Ladies in front to put 1s in the
    middle in prom hold facing 2L (in 2M place), 1s+2s dance 1/2 reel of
    3 across giving RSh to 2L, 1s cast up round 2s to original places
25-32::
    1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (12906, '2020-07-01 00:18:34.486914+00', '2023-02-04 01:18:41.011633+00', 19635, 3, NULL, 'ace', '1-4::
    1s+2s set advancing & face up NHJ, 1s cast to 2nd place as 2s dance
    up & face out. 3s face up
5-8::
    All dance 1/2 reflection reels of 3 on own sides (1s in/down to
    start), 3s & 2s loop into place 3 1 2
9-16::
    1s turn 3/4 RH to face 1st corners, turn 1st corners LH, partner 3/4
    RH, turn 2nd corner LH to end facing 3rd corner
17-20::
    1s+3rd corners dance Corner Pass+Turn (corners turn 2H), 1s pass RSh
    to face 4th corners
21-24::
    1s+4th corners repeat 17-20 to end on own sides 3 1 2
25-32::
    3s+1s+2s dance »Accompanied Alternate Rights+Lefts«:
::
    ''25-26 3s+1L also 1M+2s dance 1/2 RH across in 1st/3rd places, 1L
    leading 3L & 1M leading 2M, end outside 2L/3M. (3M+2L have moved
    clockwise)
::
    ''27-28 1L+3L with 2L also 1M+2M with 3M dance 1/2 LH across on opp
    sides to end  2L+ 3L+1L on Men''s side & 1M+ 2M+3M on Ladies'' side
::
    ''29-32 Repeat bars 25-28 but with 3L leading 1L & 2M leading 1M to
    end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4218, '2013-08-21 08:30:45.458942+00', '2023-02-04 01:18:41.03283+00', 10929, 3, NULL, 'ace', '1-8::
    1s cross RH, cast behind 2s, in front of 3s & behind 4s to 4th place
    opposite sides
9-16::
    All dance Grand Chain 1/2 way & set
17-24::
    1s cross down & dance reels of 3 with 4s+3s on opposite sides (top 3
    cpls)
25-32::
    All dance Grand Chain 1/2 way.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8377, '2014-07-31 07:48:42.269761+00', '2023-02-04 01:18:41.193701+00', 14442, 3, NULL, 'ace', '1-8::
    1s cast off one place (4 steps), 1s & 2nd corners turn RH to finish
    1s back to back, 1M facing up and 1L facing down, retain hands with
    corners
9-12::
    1M+2s and 1L+3s, give hands as in Crown Triangles, all set then,1s
    PdB out _while_ 2s+3s PdB in all turning R about (2s&3s are back to
    back)
13-16::
    1M+2s and 1L+3s give hands, set and 1s set again as 2s+3s advance
    setting, to finish 2s in 1st place and 3s in own place
17-24::
    1s turn 1.1/4 RH to face out on opposite sides & cast to R ,1s dance
    1/2 Fig of 8 across to finish in 2nd place own sides
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (8833, '2015-08-13 20:33:20.969518+00', '2023-02-04 01:18:41.235348+00', 14283, 3, NULL, 'ace', '{{explanation}}
3 couples in Triangular Set

1-4::
    1s Adv, face each other, set advancing passing LSh to 1M facing 3s,
    1L facing 2s
5-8::
    1M+3s also 1L+2s dance RH across.  1s face each other (1M facing up,
    1L facing down)
9-16::
    1s set, cross RH, cast clockwise round outside and end 1M facing 3s,
    1L facing 2s
17-20::
    2s & 3s take promenade hold & all dance 1/2 RSh reel of 4.  1s face
    each other, 1M facing down, 1L facing up
21-24::
    1s turn 1.1/4 LH.  1M faces 2s (3rd place), 1L faces 3s (2nd place)
25-28::
    Repeat bars 17-20.
29-32::
    2s & 3s promenade 2 places clockwise _while_ 1s turn 1/2 RH to join
    promenade.  Finish 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (14889, '2022-06-23 22:00:08.441916+00', '2022-06-23 22:36:33.678801+00', 20547, 1, 202, 'ace', '1--::
  1c cross RSh, all clapping on [1] | cast off 2 (2c up on [3-4] ; 1W (1M following) dances up the middle. On [8] 1c pull RSh back and face down
9--::
  1c in tandem (1M leading) dance down, pull back RSh and dance up to face 1cnrs
17--::
  Corners Pass and Turn no hands. 1c in 2pl face out (2,1,3)
25--::
  Reels3 on sides {6}, 1c RSh to 3cnrs | 3c continue the Reel to 2pl _while{2}_ 1c cast to 3pl (2,3,1)

*Deviser''s note* : On the next iteration, all couples clap on bars I and 2.  
The following time, all clap on bars 1,2 and 3.  
Continue this pattern to the end of the dance.  
Intended to get people laughing together as they attempt to keep track of the clapping bit', 4);
INSERT INTO 'dancecrib' VALUES (4219, '2013-08-21 08:30:45.47061+00', '2023-02-04 01:18:41.266991+00', 13602, 3, NULL, 'ace', '1-8::
    1s+3s dance Ladies'' Chain & end 1M+3L facing 2s, 1L+3M facing 4s
9-16::
    1s & 3s dance reels of 4 across
17-24::
    1s & 3s pass 2s/4s RSh & chase clockwise to 1st/3rd positions, 1s+3s
    dance RH across to end 1s in 2nd place & 3s in 4th place as 2s+4s
    dance into centre & dance RH across (4 bars) then chase 1 place to
    3rd/1st places (4 bars)
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4220, '2013-08-21 08:30:45.480418+00', '2023-02-04 01:18:41.28494+00', 12520, 3, NULL, 'ace', '1-8::
    1s+2s set & dance RH across 1/2 way, 1s+3s set & dance LH across 1/2
    way. (2) (3) 1
9-16::
    3s+1s+2s dance modified Snowball starting with 3s+1s changing place
    LH on sides then 2s+1s change places RH on sides as 3s cross RH etc.
    to end 3 (1) 2
17-24::
    1s set & dance 1/2 Fig of 8 round 2s & all Advance
25-32::
    3s+1s+2s dance Allemande. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10438, '2018-02-24 07:52:07.466946+00', '2023-02-04 01:18:41.302099+00', 479, 3, NULL, 'ace', '1-8::
    All set; 1s dance 1/2 Fig 8 down round 2s _while_ 5s dance 1/2 Fig 8
    up round 4s; 1s & 5s 3/4 turn partners RH
9-16::
    1s+2M also 5s+4L dance RH across, 1L & 5M pass RSh; 1s+3L also 5s+3M
    dance LH across.
17-20::
    1s+4M also 5s+2L dance RH across
21-24::
    1L followed by 1M dances down between 4s, separate & cast to 4th
    place own side _while_ 5M followed by 5L dances up between 2s & cast
    to 2nd place own side (2s & 4s step down/up 21-22) End 2 5 3 1 4
25-28::
    5s+3s also 1s+4s dance 1/2 R&L.  End 2 (3) (5) (4) (1)
29-32::
    1s & 3s turn partners 1.1/2 RH to own sides _while_ 5+4s dance 1/2
    R&L.  End 2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (4221, '2013-08-21 08:30:45.490543+00', '2023-02-04 01:18:41.327168+00', 9047, 3, NULL, 'ace', '1-8::
    All set, Ladies dance clockwise in front of partners & behind next
    Man to meet opposite Man, all set
9-12::
    1s & 3s 1/2 turn own partners RH, lead out (1s to 2nd pl, 2s to 4th
    pl) _while_ 2s & 4s retire to corners & advance towards partner
13-16::
    2M+4L 1/2 turn RH & lead out to 2nd place _while_ 2L+4M 1/2 turn RH
    & lead out to 4th place _while_ 1s & 3s retire to corners & set
17-20::
    4L+2M also 2L+4M dance (Ladies leading) 1/2 Alternating Tandem reel
    of 3 across with 1s/3s (RSh to 1M/3M)
21-24::
    2s+4s dance 3/4 LH across in centre & Ladies followed by partners
    dance out (2s to 1st pl, 4s to 3rd pl) _while_ 1s & 3s remain in
    corners
25-28::
    2s & 4s dance (Ladies leading) dance 1/2 Alternating Tandem reel of
    3 across (LSh to 1M/3M) & 1s end in 4th pl, 3s in 2nd pl
29-32::
    2s+4s dance 3/4 RH across & Men followed by partners dance out (2s
    to 1st place & 4s to 3rd place)
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4224, '2013-08-21 08:30:45.599797+00', '2023-02-04 01:18:41.696467+00', 10069, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 2nd pl into centre BtoB Lady facing up Man dn,
    1L+2s & 1M+3s circle 3H round to left & 1L ends b''tw''n 2s facing 1M
    b''tw''n 3s
9-16::
    2s+1s+3s set & dance Triple Petronella onto sides, set & Triple
    Petronella into lines across
17-24::
    2s+3s+1s set, circle 6H round to left & 1s end facing 3rd corner
    positions
25-32::
    1s dance 1/2 diagonal reel of 4 with 3rd corners, turn RH to face
    2nd corner positions, dance 1/2 reel of 4 with 2nd corners & pass
    RSh to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (12859, '2020-06-03 16:25:09.166404+00', '2023-02-04 01:18:41.723437+00', 484, 3, NULL, 'ace', '1-8::
    1s+5s cross RH, cast in 1 place (2s & 4s step up/down bars 3-4), all
    set & cross RH
9-12::
    All set & cross LH, 2s+3s+4s finish on the side _while_ 1s+5s turn
    partners 1/2 LH in the centre
13-16::
    1s+5s continue turning partner 1.1/4 LH to face own sides
17-20::
    1M+2s & 1L+3s+5M & 5L+4s dance RH across. 1s+5s finish in centre
    facing partners (L facing up, M facing down)
21-22::
    1s+5s turn partners 1/2 LH finishing 1L between 2s facing down, 5M
    between 4s facing up, 1M/5L in centre between 3s facing up/down LSh
    to LSh
23-24::
    Top & bottom lines set as centre 4 Bal-in-Line
25-32::
    1s & 5s turn to right & dance reels across (1L+2s & 5M+4s reels of 3
    at ends & 1M+5L+3s reels of 4 in middle). 1M+5L pass by right &
    1s/5s finish in centre facing partners in 2nd/4th places.
33-34::
    1s+5s turn partners LH to own sides facing out
35-36::
    1M+3M also 5M+4M change places LH (no polite turn) _while_ 1L+3L
    also 5L+4L change places RH (no polite turn). Finish 1s/4s face
    in/out
37-38::
    1M+4M change places RH _while_ 1L+4L change places LH (no polite
    turn). Finish 1s face out
39-40::
    1M+5M change places LH _while_ 1L+5L change places RH (no polite
    turn). End 2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (4227, '2013-08-21 08:30:45.626336+00', '2023-02-04 01:18:41.843776+00', 9289, 3, NULL, 'ace', '1-8::
    1s slip step down & back
9-16::
    1s cast to face 1st corner, set to 1st corner, set to 2nd corner &
    set to partner up/down in the centre
17-24::
    1s turn RH 1.1/4 times to 2nd place opposite side & dance 1/2 reels
    of 3 on sides giving RSh to 1st corner
25-32::
    1s chase anticlockwise round end couples (M up & L down) to 2nd
    place own side _while_ 2s+3s turn RH, 3s+1s+2s dance 1/2 reels of 3
    on sides', 0);
INSERT INTO 'dancecrib' VALUES (4228, '2013-08-21 08:30:45.634442+00', '2023-02-04 01:18:41.86984+00', 12607, 3, NULL, 'ace', '1-8::
    1s cross, cast 1 place, advance, 1/2 turn & twirl to 2nd place own
    sides _while_ 2s+3s dance 1/2 R&L (RH on sides to start)
9-16::
    1s dance reels of 3 on own sides giving RSh to 3rd corner (pstn) to
    start, 1s meet in middle & 1/2 turn RH
17-24::
    1s twirl & dance reels of 3 across (1M with 3s at top & 1L with 2s)
    giving RSh to 2nd corner (pstn) & pass partner LSh to…
25-32::
    1s dance RH across (1L with 3s at top & 1M with 2s), 3s+1s+2s circle
    6H round 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (13880, '2021-04-05 00:18:38.329011+00', '2023-02-04 01:18:41.947106+00', 9017, 3, NULL, 'ace', '1-8::
    1L+2L+3L dance RSh round partner & back to place, all set
9-16::
    1L+2M+3M repeat 1-8
17-24::
    1s cross RH, cast to 3rd place opp sides (2s+3s step up); 1s cross
    RH, cast up to 2nd place own side (3s step down)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4230, '2013-08-21 08:30:45.761944+00', '2023-02-04 01:18:41.968537+00', 10967, 3, NULL, 'ace', '1-8::
    1s dance down between 2s & cast down behind 3s, dance up between 3s
    & cast up behind 2s
9-16::
    1s cross down & cast round 1st corner to end between couples, 1s
    turn RH 1.1/4 times to own sides
17-24::
    1s dance RH across 1/2 way (1L with 2s, 1M with 3s) 7&cast to 2nd
    place own sides, 2s+1s+3s circle left 1/2 way & 1/2 turn partners RH
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (8545, '2015-02-13 12:47:27.413938+00', '2023-02-04 01:18:42.248266+00', 15597, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance 3 Couple Knot _while_ 4s+5s dance 2 Couple Knot.  3 2
    1 5 4
9-12::
    1L crosses up to dance 1/2 reel of 3 with 2M+3M _while_ 1M crosses
    down to dance 1/2 reel of 3 with 5L+4L
13-16::
    1L crosses down to dance 1/2 reel of 3 with 3L+2L _while_ 1M crosses
    up to dance 1/2 reel of 3 with 5M+4M (as Inveran Reels).  2 3 1 4 5
17-24::
    1s dance the Stafford Knot: 1s cross down RH below 4s to cast up &
    cross RH to own side, 1s cast down to cross up LH to 3rd place opp
    sides
25-28::
    2s+3s dance R&L (1 bar per hand) _while_ 1s+4s+5s dance Grand Chain
    for 4 bars
29-32::
    2s+3s turn 2H once round _while_ 4s+5s+1s turn 2H 1.1/2 times to end
    2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (4231, '2013-08-21 08:30:45.792965+00', '2023-02-04 01:18:42.273361+00', 495, 3, NULL, 'ace', '1-8::
    1s & 4s cast in 1 place _while_ 2s & 3s cross up/down & face out,
    2s+1s also 4s+3s set on sides with nearer hands joined & turn round
    once
9-16::
    Repeat above Fig from new pstns ie 2s & 3s cast _while_ 1s & 2s
    cross up/down, set on sides & turn (all now on opposite sides)
17-24::
    1s & 4s cast in 1 place _while_ 2s & 3s cross up/down to ends on own
    sides & face in, 1s+4s 1/2 turn partner RH, 1/2 RH across & 1/2 turn
    partner to end with 4s in 2nd place facing down & 1s in 3rd place
    facing up with nearer hands joined
25-32::
    4s+1s circle 4H round & back to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4232, '2013-08-21 08:30:45.803338+00', '2023-02-04 01:18:42.527158+00', 497, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s turn RH 1.1/2 times, cast down 1 place & dance 1/2 Fig of 8 to
    face 1st corners
9-16::
    1s dance reel of 4 with 1st corners & end facing 2nd corners

{{title}}
Reel

17-24::
    1s dance reel of 4 with 2nd corners
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4233, '2013-08-21 08:30:45.813342+00', '2023-02-04 01:18:42.821428+00', 9367, 3, NULL, 'ace', '1-8::
    1s & 3s dance double Fig of 8 round 2s (1s cast to start)
9-16::
    1s lead down for 3 steps, lead back up & cast to 2nd place
17-24::
    2s+1s+3s dance reflection reels of 3 on sides (1s dance between 3s
    to start) & 1s give RH to end BtoB for Double Triangles
25-32::
    1s dance Double Triangles & end facing 1st corners
33-40::
    1s dance ''Hello-Goodbye'' setting ending in centre facing partner &
    petronella turn to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (13039, '2020-08-10 00:18:36.126352+00', '2023-02-04 01:18:42.848466+00', 498, 3, NULL, 'ace', '{{explanation}}
Circle, Man has Lady on his right

1-8::
    All circle round & back
9-16::
    Men advance (2 steps) & make arch, Ladies stand for 2 bars dance
    under arch (2 bars); Ladies dance round partner LSh & back to place,
    Men turn to face partner bar 16
17-24::
    All dance DoSiDo with partner & turn partner RH & all face
    anticlockwise, hands crossed ready for …
25-32::
    All promenade anticlockwise in allemande hold. Bar 32: Men turn
    Ladies under arm to face partner ready for …
33-40::
    All dance Grand Chain (2 steps per hand) passing 4 people, person 5
    becomes new partner', 0);
INSERT INTO 'dancecrib' VALUES (14511, '2022-01-10 02:18:28.716906+00', '2023-02-04 01:18:43.119013+00', 17951, 3, NULL, 'ace', '1-2::
    1s dance down passing RSh to BtoB in centre 2nd place 1L facing up,
    1M facing down (2s step up 1-2)
3-8::
    2s+1s+3s dance Crown Triangles.  Bar 8: 1M turns right about to
    behind 1L facing 3M
9-16::
    1s dance 1/2 Alternating Tandem reel (1L RSh to 3M); 1s repeat (1M
    LSh to 2M)
17-24::
    1s repeat (1L RSh to 3M at top); 1s repeat (1M LSh to 2M at bottom).
    1s end in centre facing own side, 1M above 1L
25-32::
    1M+3s (at top) & 1L+2s (at bottom) dance RH across & LH across to
    end 3 1 2

{{explanation}}
Note:	Bars 9-24: 1s are dancing Alternating Tandem Figs 8 - first on Men''s side, then on Ladies'' side', 0);
INSERT INTO 'dancecrib' VALUES (4237, '2013-08-21 08:30:45.936764+00', '2023-02-04 01:18:43.176871+00', 13577, 3, NULL, 'ace', '1-8::
    1s set & dance down between 3s & cast up to end LH with partner
    facing 1st crnrs
9-16::
    1s set & turn inwards to face 3rd crnrs, 1s set to 3rd crnrs & turn
    crnrs LH to end RH with partner facing 2nd crnrs
17-24::
    1s set & turn inwards to face 4th crnrs,1s set to 4th crnrs & turn
    crnrs RH to end 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4238, '2013-08-21 08:30:45.945107+00', '2023-02-04 01:18:43.208698+00', 510, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & cross RH; 2L+1s also 2M+3s dance RH across. End in
    line of 3 across (1L & 3M in middle of lines)
9-16::
    All dance 6H round & back ending in lines across again
17-20::
    1s+2s+3s change with partners RH (2s cross diagonally up/down),
    change RH with opposite person, 1M dancing below 3rd place, 1L above
    1st place
21-24::
    2L+3s (at top) & 2M+1s (at bottom) dance RH across to end on own
    sides 3 2 1
25-32::
    3s cross & cast to 3rd place _while_ 2s+1s set & cross RH moving up
    1 place; all set & cross RH to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8987, '2015-11-30 08:59:29.673532+00', '2023-02-04 01:18:43.240135+00', 12747, 3, NULL, 'ace', '1-8::
    1s+3s cast behind lines (4 bars) & cast back to places
9-16::
    1s+3s set, cross down diagonally to 1s between 2nd & 3rd place, 3s
    below 4th place.  1L+3L, followed by partners, cast up behind Men &
    cross back to original places
17-24::
    RSh reels of 4 on sides.  1L finish facing out
25-32::
    1L followed by 1M casts below 4s, crosses into 4M place pulling back
    RSh to face 1M in 4L place (2s+3s+4s step up 27-28)  All turn prtnr
    RH (1s turn 1.1/2 times)', 0);
INSERT INTO 'dancecrib' VALUES (4239, '2013-08-21 08:30:45.95336+00', '2023-02-04 01:18:43.266017+00', 7351, 3, NULL, 'ace', '1-8::
    1s +3s dance down the middle for 2 steps, turn 2H, dance up to
    places & cast down 1 place.  2 1 4 3
9-16::
    2s+1s also 4s+3s dance Diamond Poussette
17-24::
    1s & 3s set, 1/2 turn partners RH & dance out to chase clockwise 1/2
    way (to change places)
25-32::
    All circle 8H round & back.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4240, '2013-08-21 08:30:45.96156+00', '2023-02-04 01:18:43.294409+00', 8554, 3, NULL, 'ace', '1-8::
    1s+2s+3s turn partner RH 1/2 way, turn R & dance out to partners
    place & dance 6H 1/2 way round to own sides
9-16::
    3s+2s+1s repeat above Fig back to places
17-24::
    1s+2s 3/4 turn partners 2H into middle & dance a 1/2 reel of 4,
    2s+1s turn 2H to end in prom hold facing up as 3s dance in
25-32::
    2s+1s+3s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (12380, '2019-12-05 01:28:50.343063+00', '2023-02-04 01:18:43.321557+00', 19415, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, 1s face down to dance 1/2 parallel reels of 3
    on sides (1M+3L pass RSh, 1L+3M pass RSh) 3M & 1M face out. 3 (1)
    (2)
9-16::
    3s+1s dance Ladies'' Chain
17-24::
    _17-18_    All set
::
    _19-20_   3s+2s dance "The Capstan":3s NHJ dance down 2 places
    _while_ 2s cast up to 1st place
::
    _21-22_   2s NHJ dance down 2 places _while_ 3s cast up to 1st place
::
    _23-24_   3s NHJ dance down 2 places curving into 3rd place _while_
    2s cast up to first place.  (2) (1) 3
25-32::
    2s+1s dance 1/2 double Fig 8 (2s cross down, 1s dance up) & 1s+2s
    turn on sides (Men RH, Ladies LH).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13391, '2020-12-02 01:18:41.202062+00', '2023-02-04 01:18:43.344991+00', 19148, 3, NULL, 'ace', '1-8::
    1L casts followed by 1M, dances across to 2nd place opp side (2s
    step up 3-4); 1M casts followed by 1L, dances across to 3rd place
    own side (3s step up 7-8)
9-16::
    1s dance up to top, cast, meet, dance down & cast up round 3s to
    face 1st corners (3s step down 15-16)
17-24::
    1s turn 1st corner LH, dance LSh round 2nd corner into lines across
    (1M between 2s facing down, 1L between 3s facing up); all turn
    opposite dancer RH (1s 3/4 RH turn to 2nd place own side)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12071, '2019-08-30 09:53:49.014328+00', '2023-02-04 01:18:43.373579+00', 19424, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Set & Rotate for 3 couples to finish 3 2 1. 1s
    finishes facing clockwise
9-16::
    1M followed by partner dances up 1 place & 1s turn RH  to face 1st
    corner positions
17-24::
    1s dance ''Hello-Goodbye'' setting to finish 1L between 2s (in 3rd
    place) & 1M between 3s (in 2nd place)
25-32::
    All 3 couples dance Set+Link for 3 once to finish 3 1 2 all on opp
    side; RH across, 1L+2s, 1M+3s
33-40::
    3s+1s+2s chase 1/2 round set clockwise & all turn partner RH (or
    Birl). End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13040, '2020-08-10 00:18:36.518456+00', '2023-02-04 01:18:43.400822+00', 15661, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s turn 1.1/4 RH ending in centre facing
    opp sides _while_ 2s+3s chase clockwise 1/2 round
9-16::
    1s dance the Snake Pass:
::
    1s dance LH across (1M+3s & 1L+2s), 1M followed by 3s also 1L
    followed by 2s pass RSh diagonally across through 2nd place to
    change ends & loop round to right to end in 2nd place.  (2) 1 (3)
17-24::
    2s+1s+3s chase clockwise 1/2 round; 3L+1M (top couple Ladies'' side)
    with 1L+2M (bottom couple Men''s side) dance 1/2 diag reel of 4
    (1L+3L pass RSh, 1M+2M pass RSh to start)
25-32::
    3M+1M (top couple Men''s side) with 1L+2L (bottom couple Ladies''
    side) dance 1/2 diag R&L; 1/2 LSh reels of 3 across (1M+2L also
    1L+3M pass LSh to start).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15055, '2022-09-05 00:18:36.35329+00', '2023-02-04 01:18:43.435123+00', 20917, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast 2 places & dance up to BtoB in centre, 2nd
    place facing opp sides (2s step up 5-6)
9-16::
    2s+1s+3s dance Inverted Double Triangles: All set, 1s set advancing
    & turn R about to face in _while_ 2s & 3s dance in & turn R about to
    face out; repeat ending with 1s in centre facing 1st corners
17-24::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh, 1s dance 1/2
    diag reel of 4 with 2nd corners & end in 2nd place opp side
25-32::
    1s cross RH & cast right _while_ 2s+3s set & change places RH on
    side; 1s cross RH up/down & cast right _while_ 2s+3s set & cross RH.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4243, '2013-08-21 08:30:45.988951+00', '2023-02-04 01:18:43.487098+00', 519, 3, NULL, 'ace', '{{explanation}}
3s+4s dance similarly to 1s+2s

{{title}}
Strathspey

1-4::
    1L cast down 1 place as 2M cast up 1 place & they turn RH until in
    line with original place
5-8::
    1s+2s dance RH across ending in original places
9-16::
    1M cast down 1 place as 2L cast up 1 place & 1/2 turn LH, 1s+2s
    dance LH across & end 2L+1M in place as 1L+2M pass LH to face
    partners
17-24::
    All dance RSh reels of 4 across ending in original places
25-32::
    All dance a »Half« Chain:
::
    1L+2M turn LH into partner''s place _while_ 2L+3M cast up/down
::
    Repeat this figure three more times with persons in 1L & 2M
    positions turning LH

{{title}}
reel

1-32::
    Middle coupls repeat above figures in reel time', 0);
INSERT INTO 'dancecrib' VALUES (4245, '2013-08-21 08:30:46.018253+00', '2023-02-04 01:18:43.630211+00', 521, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place (2s step up), set & cast to 3rd place (3s step
    up)
9-16::
    1s set, lead up to places (2s+3s step down), cross RH & cast to 2nd
    place opposite sides (2s step up)
17-24::
    2s+1s dance R&L 1s end facing 1st corners
25-32::
    1s set & turn 1st corners, set & turn 2nd corners
33-40::
    1s dance down between 3s, cast up to 2nd place & turn partner 2H to
    end in centre (on opposite sides)
41-48::
    1s dance up between 2s, cast to 2nd place & turn partner 2H 1.1/2
    times', 0);
INSERT INTO 'dancecrib' VALUES (4247, '2013-08-21 08:30:46.038868+00', '2023-02-04 01:18:43.70292+00', 9340, 3, NULL, 'ace', '1-8::
    1s dancing in cast to 2nd place, 2s+1s dance RH across
9-16::
    1s dancing in cast to 3rd place, 3s+1s dance LH across
17-24::
    1s lead up to top (LH), cast to 2nd place, 2s+1s+3s turn RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4248, '2013-08-21 08:30:46.047231+00', '2023-02-04 01:18:43.737507+00', 11777, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cross down _while_ 2s cast up, 1s+3s turn 1.1/2 times
    on the sides (Men''s side LH & Ladies'' side RH)
9-16::
    3s+1s set, 1s dance up to 2nd place _while_ 3s cast back to places,
    2s+1s turn 1.1/2 times on sides (Men''s side RH & Ladies'' side LH)
17-24::
    1s cross down to dance reflection (mirror) reels of 3 on own sides
25-32::
    1s cross RH, cast 1 place & turn RH 1.1/2 times to 2nd place own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (4249, '2013-08-21 08:30:46.059193+00', '2023-02-04 01:18:43.766797+00', 11600, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place _while_ 2s set & cross up, 1s turn RH to
    face 2nd corner (pstn)
9-16::
    1s dance 1/2 RSh reels of 3 across (Man with 2s & Lady with 3s), 1s
    turn LH 1.1/2 times _while_ 2L+3M also 2M+3L turn LH all into prom
    hold
17-24::
    All dance reel of 3 across (1s give RSh to 2M+3L to start) ending
    with 1s in centre facing down, 2s in 1st places, 3s in orig places
25-32::
    1s dance down below 3s, cross & cast up to 2nd place as 3s set &
    cross RH & 1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4250, '2013-08-21 08:30:46.069428+00', '2023-02-04 01:18:43.806861+00', 12869, 3, NULL, 'ace', '1-8::
    1s dance RSh round each other moving down (2s step up) & end BtoB in
    double triangle position (1L facing up to 2s & 1M down to 3s), all
    set, 1s turn 4th corner RH
9-16::
    1s turn 1st corner LH & all chase clockwise 1/2 way (1M between 3s
    at top, 1L between 2s at bottom)
17-24::
    1s change places RH up/down & cast to right into 2nd place own side
    & All turn partners RH (3) 1 (2)
25-32::
    1s dance Diag R&L.  2 1 3
33-40::
    2s+1s+3s circle 6H round for 3 bars, pivot left & chase back to
    places', 0);
INSERT INTO 'dancecrib' VALUES (4251, '2013-08-21 08:30:46.083325+00', '2023-02-04 01:18:43.85766+00', 13593, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 2 places (3s face down), 1s with 3s+2s dance 1/2
    reflection reel of 3 (1s dancing in/up, 3s down/out, 2s in/down to
    start)  (1) 3 2
9-16::
    1s cross down to dance full reels of 3 on own sides.  1 3 2
17-24::
    3s+2s (bottom 2 couples)  Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (3s in 2nd pl).  1 2 3
25-32::
    1s+2s dance 1/2 R&L, 2s+1s turn partner 1.1/2 times RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12718, '2020-04-11 10:50:23.458654+00', '2023-02-04 01:18:44.072694+00', 9652, 3, NULL, 'ace', '1-8::
    All circle 8H round and back
9-10::
    1s+4s change places, 1s dancing under arch made by 4s.  4 2 3 1
11-12::
    1s+3s turn on sides (Ladies LH, Men RH) _while_ 4s+2s turn on sides
    (Ladies RH, Men LH).  2 4 1 3
13-14::
    1s+4s cross, 1L+4L NHJ dance across under arch made by 1M+4M. (4) 2
    3 (1)
15-16::
    1L+3M turn LH, as 1M+3L turn RH, as 4L+2M turn RH, as 4M+2L turn LH.
    Finish (4) 2 3 (1)
17-18::
    2s+3s cross, Ladies dancing under arch made by Men
19-20::
    2L+4L turn RH, as 2M+4M turn LH, as 3L+1L LH, as 3M+1M RH. Finish
    (2) (4) (1) (3)
21-22::
    2s+3s change places up/down dance, 2s dancing under arch made by 3s
23-24::
    2L+1L turn RH, as 2M+1M turn LH, as 3L+4L turn LH, as 3M+4M turn RH.
    Finish (4) (3) (2) (1)
25-28::
    4s followed by 3s & 2s dance towards each other and cast, 4s to 3rd
    place, 3s to 2nd place, 2s to 1st place. (2) (3) (4) (1)
29-32::
    All couples set and cross.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13129, '2020-09-15 00:18:37.078536+00', '2023-02-04 01:18:44.097764+00', 19994, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s+2s Set+Link; 1s+3s Set+Link.  2 3 1
17-24::
    1s cross RH, cast up 1 place (3s step down); 1s turn 1/2 RH, pull
    back RSh & dance slightly toward own side to end joining RH with
    partner & LH with 3rd corner
25-32::
    1s dance the »Spoke« with 3rd corner, 2nd corner, 1st corner & 4th
    corner (moving clockwise round) ending in 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (4253, '2013-08-21 08:30:46.101803+00', '2023-02-04 01:18:44.155519+00', 11632, 3, NULL, 'ace', '1-8::
    1s set, dance down below 3s, cast up own sides & in to face 1st
    corners
9-12::
    1s turn crnrs 2H _while_ 2nd crnrs change pl LH to form lines of 3
    across (1L between 2M+3M & 1M with 2L+3L) & set (bottom line turns
    to face dn)
13-16::
    All dance down in lines of 3 & turn to face up
17-24::
    2M+1L+3M dance up in ''Triumph'' hold followed by 2L+1M+3L, all set
    (top line turns to face dn) & 1s cross LH to face 2nd crnr (pstn) as
    crnrs set
25-32::
    1s dance 1/2 diagonal reel of 4 with corners & pass LSh to 2nd place
    own side & all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (4254, '2013-08-21 08:30:46.112054+00', '2023-02-04 01:18:44.178131+00', 13683, 3, NULL, 'ace', '1-8::
    1s turn 2H & cast to 3rd place, cross RH & cast up to 2nd place
9-16::
    1s dance reflection reels of 3 on opposite sides (1s in & up to
    start)
17-24::
    1s cross up RH ending 1s facing down to 2s in middle & set, 1s+2s
    dance 4H round to left ending BtoB facing original places
25-32::
    1s & 2s dance The Bow:
::
    1s & 2s loop right round through original places & dance LH across
    1/2 way, 2s & 1s loop round to right into opp places & cross RH to
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (14891, '2022-06-23 23:08:47.519257+00', '2022-06-23 23:10:26.450587+00', 20878, 1, 1645, 'ace', '1--::

  1c cross RH | cast off (2c up) ; cross LH | cast L to facing lines of 3 across, 1W/1M between 2c/3c

9--::

  All A&R up/down ; S&Link3 to sides (2x,1,3x)

17--::

  All A&R ; S&Link3, 1M/1W end facing down/up between 3c/2c who face P

25--::

  1c petronella to 2pl _while{2}_ 3c & 2c set facing P | 1c set _while{2}_ 3c & 2c petronella to centre line ;

  3c & 2c pass P RSh, 3W followed by 2W dance up as 2M followed by 3M dance down & 3W/2M cast off/up to 3pl/2pl (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (15121, '2022-10-01 21:35:05.961697+00', '2022-10-12 19:53:48.396132+00', 21114, 1, 202, 'ace', '1--::

  1c set | cast off (2c up) ; cross RH | cast off round 3c to 2plx centre facing opposite sides

9--::

  All set as in DTr | 1c turn 1cnrs RH, pass P LSh ; ½ Reel4 on 1diag, RSh to 3cnrs. 1c finish as on [9]

17--::

  All set as in DTr | 1c turn 2cnrs LH, pass P RSh ; ½ Reel4 on 2diag, LSh to 4cnrs. 1c in 2plx face out (3x,1x,2x)

25--::

  1c dance LSh round 2cnrs[pos] | pass P RSh ; dance RSh round 4cnrs[pos] to 2pl _while{8}_ 3c & 2c set facing each other | change places RH ; set to P | cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (4255, '2013-08-21 08:30:46.227225+00', '2023-02-04 01:18:44.444345+00', 10115, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    1M & 4M cast in 1 place, set _while_ 1L & 4L cast in 1 place, 1M+4M
    1/2 turn RH _while_ partners set, 1s+4s dance RH across 1/2 way
9-16::
    1s+4s dance Ladies'' Chain & end turning Ladies LH into middle (1M+4L
    facing down, 1L+4M facing up)
17-24::
    Couples pass RSh & dance 1/2 Figs of 8 (1L+4M round 2s & 4L+1M round
    3s) & end 1s on Ladies'' side, 4s Men''s side, Set+Link with partners
25-32::
    1L & 4L followed by partners dance Tandem RSh reels of 3 across (1s
    with 3s, 4s with 2s) & end 2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (4257, '2013-08-21 08:30:46.251248+00', '2023-02-04 01:18:44.523079+00', 529, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 R&L, all turn RH
9-16::
    1s+4s dance LH across, 2s+1s also 4s+3s dance 1/2 R&L  1 2 3 4
17-20::
    1s+2s cross with Ladies dancing under Mens arch & 1s+2s change
    places on sides with 2s dancing under 1s arm  (2)(1)3 4
21-24::
    1s+3s cross with 1L+3M dancing under arch made by 1M+3L, 1s+3s
    change places on sides with 3s dancing under 1s arm  (2)(3)1 4
25-32::
    1s+4s cross with Ladies dancing under Mens arch, 1s+4s change places
    on sides with 4s dancing under 1s arm, all set & cross RH  2 3 4 1
33-40::
    3s+4s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4258, '2013-08-21 08:30:46.25969+00', '2023-02-04 01:18:44.553957+00', 530, 3, NULL, 'ace', '1-8::
    1s prom round outside of set (pass 2M LSh) end in 2nd pl facing
    Men''s side as 2s+3s set, cross RH & dance RH across to end in pl on
    opp sides
9-16::
    1s (prom hold) dance 1/2 reel of 3 with 2L+3L (on Men''s side) giving
    LSh to 3L & 1/2 reel with 2M+3M giving LSh to 2M & end in centre
    facing dn
17-24::
    1s (prom hold) dance 1/2 reel of 3 across with 2s (3rd pl) giving
    RSh to 2L & 1/2 reel with 3s RSh to 3M ending at top with 3s+2s
    behind ready for
25-32::
    1s+3s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4259, '2013-08-21 08:30:46.269736+00', '2023-02-04 01:18:44.591199+00', 11198, 3, NULL, 'ace', '1-8::
    1s+2s set & dance RH across 1/2 way, set again then 2s turn LH to
    sides _while_ 1s turn LH to face 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting finishing with Petronella turn to
    end facing 3rd corner
17-24::
    1s dance 1/2 Diag reel with 3rd cnrs, pass RSh to dance 1/2 Diag
    reel with 4th corners ending 2nd place own sides
25-32::
    1s dance Diag R&L (Man down, Lady up).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13980, '2021-05-03 00:18:37.081685+00', '2023-02-04 01:18:44.614265+00', 8376, 3, NULL, 'ace', '1-4::
    All 4 couples set,1s & 4s cast in 1 place _while_ 2s & 3s dance NHJ
    with partner to 1st/4th place
5-8::
    1s+4s dance LH across finishing in prom hold with partner. 1s facing
    2L, 4s facing 3M
9-16::
    1s+2s & 4s+3s dance RSh reels of 3 across. 1s & 4s finish in centre,
    BtoB with partner, facing own side
17-24::
    1s & 4s 1/2 turn corners NH, corners join free hands in centre in St
    Andrews Cross & all set, corners drop hands in centre & all turn to
    end in original places
25-32::
    1s cross RH, cast behind 2s, dance down between 3s, dance down
    behind 4s & cross LH to 4th place own side (2s+3s+4s step up 31-32)', 0);
INSERT INTO 'dancecrib' VALUES (4260, '2013-08-21 08:30:46.278039+00', '2023-02-04 01:18:44.645437+00', 535, 3, NULL, 'ace', '1-8::
    1s & 3s 1/2 turn RH moving down 1 place, face partner & set; cross
    LH to own sides, cast Left to face 1st corners (1M+3L pass LSh)
9-16::
    All dance reels across (RSh reels of 3 at ends & RSh reel of 4 in
    centre) end with 1s & 3s holding partners LH in centre of dance & RH
    to 1st crnr
17-24::
    1s & 3s Bal-in-Line with corners, turn corners RH into centre &
    Bal-in-Line, turn corners to sides & face 2nd corners
25-32::
    1s & 3s dance Pass+Turn with 2nd corners, turn RH 1.1/2 times & cast
    1 place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (4262, '2013-08-21 08:30:46.300545+00', '2023-02-04 01:18:44.830722+00', 537, 3, NULL, 'ace', '1-8::
    1M+2L set, 3/4 turn RH, 2L casts down behind 1L as 1M cast up around
    2M, change places giving LH & end facing partner on opposite side
9-16::
    1s & 2s set to partners on sides, change places LH, 1M+2M (at top)
    also 1L+2L turn RH
17-24::
    Repeat bars 1- 8 with 2M+1L starting
25-32::
    1L+2L also 1M+2M set, change places LH, 2s & 1s turn partners RH
    1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (4263, '2013-08-21 08:30:46.30897+00', '2023-02-04 01:18:44.863433+00', 540, 3, NULL, 'ace', '1-8::
    1L followed by 1M casts & dances across to 2M place (1M to 2L
    place), 1M followed by 1L casts & dances across to 3M place (1L to
    3L place)
9-16::
    1s+2s+3s chase anticlockwise all the way round back to place & 1s
    lead up to face 1st corners
17-24::
    1s set & turn corners (2H) ending 2nd place on opposite sides
25-32::
    All set & 1s 1/2 turn RH _while_ 2s+3s set again, 2s+1s+3s turn RH', 4);
INSERT INTO 'dancecrib' VALUES (4264, '2013-08-21 08:30:46.317224+00', '2023-02-04 01:18:44.887154+00', 541, 3, NULL, 'ace', '1-8::
    1s turn RH & LH
9-16::
    1s lead down to just below 3rd place, 1M leaves partner in 3L''s
    place & leads 3L up to 1L''s place
17-24::
    1M+3L turn RH & LH _while_ 3M+1L do likewise
25-32::
    1M leads 3L down to just below 3L''s place & leads partner up to top
    place & both cast to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (4265, '2013-08-21 08:30:46.325511+00', '2023-02-04 01:18:44.918607+00', 542, 3, NULL, 'ace', '1-8::
    1s+2s Allemande Right (adv for 2, give RH to ptnr & Lady turns under
    M''s arm, Lady dances back to place as Man retires), 1s+2s dance RH
    across
9-16::
    1s+2s dance Allemande Left (repeat giving LH) & dance LH across
17-24::
    1M followed by partner casts 1 place, crosses up & casts round 2L to
    end on own sides in 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7895, '2013-08-21 08:31:50.669945+00', '2023-02-04 01:23:09.950697+00', 11479, 3, NULL, 'ace', '1-8::
    1L+2L 1/2 turn LH _while_ 1M+2M 1/2 turn RH, 1L+3L 1/2 turn RH
    _while_ 1M+3M 1/2 turn LH, 1s dance to top & cast to 2nd place
9-16::
    1s set advancing & Bal-in-Line with 1st corners (LH to partner),
    turn 1st corner RH into lines of 3 across & all set
17-24::
    1s set advancing & Bal-in-Line with 2nd corners, turn 2nd corner RH
    into lines of 3 on sides & all set
25-32::
    1s dance reels of 3 on sides (RSh to 2nd corner) & cross RH to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (2538, '2012-01-22 19:29:46.769349+00', '2022-11-30 23:37:46.641894+00', 9869, 1, NULL, 'ace', '{{explanation}}

Musical introduction of 8 bars, on [5-8]: Bow/curtsey to P, to Cnr



1-16::

  1M+3M petronella turn into centre to face P| set ; 1c+3c reel4 up & down ; turn P RH to places.

17-32::

  2c+4c repeat across

33–::

  2M facing 3W & 1W facing 4M set R advancing and join RH , set L | lead into centre ; exchange partners & lead out past own P, casting round P into diagonal lines 1c+4c facing 2c+3c.

41–::

  In diagonal lines A&R ; all turn P LH to places.

49-64::

  Repeat [33-48] with 1M+2W & 4W+3M starting and end in lines 1c+2c facing 4c+3c on other diagonal.

65-80::

  Women ½ RHA _while{2}_ Men chase cclw ¼ round | join LH with new W and set ; repeat 3 times & meet partner, turn LH to own pl.

81-88::

  All Circle8 & back.', 2);
INSERT INTO 'dancecrib' VALUES (15122, '2022-10-02 07:50:24.934819+00', '2022-10-02 19:13:51.87957+00', 21132, 1, 202, 'ace', '1--::
  1c & 3c lead down ; and back remaining in centre. On [8] 2c & 4c step in (1,2,3,4)
9--::
  1c+2c & 3c+4c Allemande (2,1,4,3)
17--::
  All set | 1c & 3c turn P ¾ ; ½ Reel4
25--::
  3c & 1c turn P RH ¾ and face up | 3c lead up and cast off round 2c to 2pl _while{4}_ 1c lead up and cast off round 4c to 4pl | all set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (4209, '2013-08-21 08:30:45.349277+00', '2023-02-04 01:18:40.550128+00', 12519, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s turn RH 1.1/2 times into prom hold
    facing 2L
9-16::
    1s set to 2L & set to 3L, 1M dances LH across with 2L+3L _while_ 1L
    dances RH across with 2M+3M & 1s end facing 3M
17-24::
    1s set to 3M & set to 2M, Men dance LH across _while_ Ladies dance
    RH across & 1s end facing 1st corners
25-32::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass LSh & dance
    1/2 reel with 2nd corners 1s pass LSh to own sides 2nd places
33-40::
    1s dance Diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (4266, '2013-08-21 08:30:46.335686+00', '2023-02-04 01:18:44.953275+00', 543, 3, NULL, 'ace', '1-4::
    1M+3L change places RH, dance through each other''s place & turn 2s
    (on sides) LH to form diag line with 3L & 1M in centre RH joined
5-8::
    Bal-in-Line & turn 2s back to side lines
9-16::
    1L+3M repeat except that they cross LH & turn RH on sides (3) 2 (1)
17-24::
    2s pass LSh to dance 1/2 diag reel of 4 with 1M & 3L; 2s turn 1.1/4
    LH to 2nd corner diagonal, 2M facing 3M, 2L facing 1L
25-32::
    2s dance 1/2 diagonal reel of 4 with 3M & 1L; 2s turn LH 1.1/2 times
    into Allemande hold facing up, 1s dancing in Bar 32 ready for …
33-40::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4267, '2013-08-21 08:30:46.345777+00', '2023-02-04 01:18:44.984358+00', 8039, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 on own sides (1s in & down to start)
9-16::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of 8 round 2s to end
    facing 1st corners
17-24::
    1s turn corners RH & passing RSh to face 2nd corners, 1s turn
    corners RH & pass partner RSh to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4268, '2013-08-21 08:30:46.356211+00', '2023-02-04 01:18:45.021825+00', 544, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s also 3s+4s dance 1/2 R&L, 1s & 4s lead out of ends & cast to
    2nd/3rd pl opp side _while_ 2s & 3s set & cross RH
9-16::
    1s+4s face diagonally in & set twice (HS)
17-24::
    1s+4s circle 4H round to left 1/2 way, dance in 1 step & twirl to
    face corner, set & turn corners (dancing out sides) & end facing
    up/down at bottom/top
25-32::
    4s+1s dance Half Rondel: 4s dance under arch made by 1s who dance
    up, 1s & 4s cross (Ladies in front of Men), set & cross LH.  2 1 4 3

{{title}}
Reel

1-8::
    2s+1s also 4s+3s dance 1/2 R&L, 2s & 3s lead out of ends & cast to
    2nd/3rd pl opp side _while_ 1s+4s set & cross RH
9-16::
    2s+3s face diagonally in & set (PdB) & points twice
17-24::
    2s+3s circle 4H round to left 1/2 way, set turning to face corner,
    set & turn corners (dancing out) ending facing up/down at bottom/top
25-32::
    3s+2s dance Half Rondel:
::
    3s dance down under the arch made by 2s who dance up, Ladies cross
    in front of Men & all cast to meet the other Lady or Man on the
    opposite side & join nearer hands, set on opposite sides of the
    dance & cross LH back to own sides.  1 2 3 4', 0);
INSERT INTO 'dancecrib' VALUES (14790, '2022-05-05 00:18:39.167009+00', '2023-02-04 01:18:45.201015+00', 546, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s cast to 3rd place  3 2 1, join hands on sides &
    set; 3s followed by 2s+1s cast back to place & all set.  1 2 3
9-16::
    All set, cross RH with partner; set & cross back RH
17-24::
    1s lead down & back
25-32::
    1s+2s dance »New Poussette«:
::
    _25-26_  1s+2s take prom hold with partner (Lady on Man''s right) 1s
    facing down/out to Men''s side, 2s up/out to Lady''s side)
::
    _27-28_  Couples dance out diagonally to sides & face diagonally in
    (1s down/in, 2s up/in)
::
    _29-30_  Couples dance diagonally into centre to line across facing
    partner (1M & 2L BtoB in centre)
::
    _31-32_  Couples turn partner RH to own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15314, '2022-12-19 01:18:40.322146+00', '2023-02-04 01:18:45.406623+00', 21161, 3, NULL, 'ace', '{{explanation}}
Music: »The Black Joke« - 6 bars + 6 bars + 10 bars + 10 bars phrases

1-4::
    1s+2s dance 1/2 Double Fig 8 (1s cross down, 2s dance up). 1s finish
    facing out
5-6::
    1s+2s change places (1M+2M LH,1L+2L RH)
7-10::
    1s+3s dance 1/2 Double Fig 8 (1s dance down, 3s cross up). 1s finish
    facing out
11-12::
    1s+3s change places (1M+3L LH, 1L+3M RH)
13-16::
    1s cross RH & cast up
17-22::
    2s+1s+3s Set+Link; all cross RH with dancer opposite
23-26::
    2s+1s+3s Set+Link to finish on the sidelines
27-30::
    1M dances 1/2 Fig 8 down round 3s as 1L dances /2 Fig 8 up round 2s
31-32::
    2s+1s +3s set', 0);
INSERT INTO 'dancecrib' VALUES (4270, '2013-08-21 08:30:46.374609+00', '2023-02-04 01:18:45.432652+00', 8328, 3, NULL, 'ace', '1-8::
    1s set, turn RH, cast 1 place & 3/4 turn LH to face 3rd corner
9-16::
    1s dance LSh reels of 3 across the set (M with 2s & L with 3s) & 1s
    turn LH to face 1st corner
17-24::
    1s dance LSh reels of 3 across the set (L with 2s & M with 3s) & 1s
    pass RSh to end facing 1st corner
25-32::
    1s set to 1st corner ending 2nd pl opp side, 1s 3/4 turn RH to face
    2nd crnr, set to 2nd crnr ending b''tw''n 2s/3s facing prtnr & 3/4
    turn to 2nd pl own side', 0);
INSERT INTO 'dancecrib' VALUES (4271, '2013-08-21 08:30:46.384804+00', '2023-02-04 01:18:45.468822+00', 547, 3, NULL, 'ace', '{{explanation}}
All couples start on opp sides

1-8::
    4s lead up to top & down to bottom with 3s dancing in behind 4s as
    they reach the bottom
9-16::
    3s+4s dance Allemande (down & round to left) to change places
17-24::
    4s dance RSh reels of 3 across (4L with 2s & 4M with 3s)
25-32::
    2s+4s+3s circle 6H round to right & back

{{explanation}}
4s repeat from 3rd place & step up to 1st place', 0);
INSERT INTO 'dancecrib' VALUES (4272, '2013-08-21 08:30:46.393192+00', '2023-02-04 01:18:45.499926+00', 549, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH & cast down 1 place, dance 1/2 Fig of 8 round the
    couples above them & cross to face 1st corners
9-16::
    1s & 3s turn 1st corners RH & partner LH, turn 2nd corner RH &
    partner LH to face 1st corners again
17-24::
    1s & 3s dance diagonal reels of 4 with 1st corners
25-32::
    All dance RH across once round (1L with 2s, 1M+3L with 4s & 3M with
    5s), 1s & 3s turn ptnrs LH & cast one place', 0);
INSERT INTO 'dancecrib' VALUES (11691, '2019-03-18 21:01:47.341986+00', '2023-02-04 01:18:45.530305+00', 550, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 RH across & all set; 1M+2L change places RH & all
    set
9-16::
    1s+2s dance 1/2 RH across & all set; 1L+2M change places RH & all
    set
17-24::
    1s dance Fig 8 round 2s & cross to own sides
25-32::
    2s dance Fig 8 round 1s & cross to own sides', 0);
INSERT INTO 'dancecrib' VALUES (4273, '2013-08-21 08:30:46.401542+00', '2023-02-04 01:18:45.55987+00', 551, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    All set, 1s+2s also 3s+4s turn 2H into circle 4H round to left to
    original places
9-12::
    1M+2L+3L+4M 1/2 diag reel of 4 (1M+2L & 3L+4M pass RSh to start) but
    Ladies do not complete reel to end in own pl & Men in each others pl
13-16::
    1L+2M+3M+4L 1/2 diag reel of 4 (1L & 2M also 3M & 4L pass RSh to
    start) but Men end in own places
17-24::
    4s+2s also 3s+1s change places RH on side, all cross LH, repeat but
    couples remain in centre (4s face 2s & 3s face 1s)
25-32::
    4s+2s also 3s+1s dance the Rondel with 2s & 3s making the arches.  2
    4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (13609, '2021-02-04 01:18:40.22788+00', '2023-02-04 01:18:45.585295+00', 13158, 3, NULL, 'ace', '1-8::
    1s & 5s dance parallel Figs of 8 on own sides (1s/5s pass 2s/4s RSh
    to start), 1L & 5M end facing out
9-16::
    1L followed by 1M also 5M followed by 5L cast down/up 1 place &
    across the set to opposite sides (2s & 4s step up/down), 1s & 5s
    turn 1.1/2 LH to own sides 2 1 3 5 4
17-24::
    All dance RH across (1L with 2s, 5M with 4s, 1M+5L with 3s); 1s & 5s
    pass partners RSh to dance LH across (1M with 2s, 5L with 4s, 1L+5M
    with 3s). 1s & 5s end on own side
25-32::
    All cross RH, 1s+3s change places LH on the sides; All cross RH,
    1s+5s change places LH on the sides. 2 3 5 1 4', 0);
INSERT INTO 'dancecrib' VALUES (15123, '2022-10-02 20:51:28.641638+00', '2022-10-09 10:00:52.720388+00', 21141, 1, 202, 'ace', '1--::
  1c+2c ½ R&L ; 2c+1c set | 2c cross LH _while{2}_ 1c turn LH ¾ to face 1cnrs
9--::
  Corner Chain with Setting. 1c face 2cnrs
17--::
  4 bars of Corners Pass and Turn. On [20] 1c on midline RSh to P face own sides NHJ ; 1c turn RH ½ to face P on midline | Petronella turn to 2pl (2,1,3)
25--::
  All set, cast R and chase clw (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (4274, '2013-08-21 08:30:46.411689+00', '2023-02-04 01:18:45.624884+00', 556, 3, NULL, 'ace', '1-8::
    1s, 3s & 5s set advancing to give RH to partner & LH to next dancer,
    Bal-in-Line, 3s & 5s turn RH & lead up 2 places _while_ 1s cast to
    5pl
9-16::
    Repeat from new places.  5 2 1 4 3
17-24::
    2s & 4s lead down for 3 & back to places, cast down 1 place.  5 1 2
    3 4
25-32::
    5s+1s also 3s+4s dance R&L _while_ 2s cross RH, set, cross back RH &
    set', 1);
INSERT INTO 'dancecrib' VALUES (4275, '2013-08-21 08:30:46.419982+00', '2023-02-04 01:18:45.652476+00', 557, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, set & cast below 3rd place
9-16::
    1s cross up & cast to top, cross RH & cast to 2nd place
17-24::
    1s dance reels of 3 across (Lady with 2s & Man with 3s)
25-32::
    1s dance reels of 3 across (Man with 2s & Lady with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (4276, '2013-08-21 08:30:46.535095+00', '2023-02-04 01:18:45.849793+00', 11109, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, set & turn 2H to face 2L
9-16::
    1s+2L set, 1L dances under partners arm to face 3M, 1s (prom hold)
    dance 1/2 RSh reel with 3M+2L & end facing 3L
17-24::
    1s+3L set, 1L dances under partners arm to face 2M, 1s (prom hold)
    dance 1/2 RSh reel with 2M+3L to end 3s, 1s & 2s in centre facing
    down
25-32::
    3s+1s+2s dance ''Upside Down Allemande'' for 6 bars & 1/2 turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4278, '2013-08-21 08:30:46.555611+00', '2023-02-04 01:18:45.922955+00', 8555, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back, cast to 2nd place on own sides
9-16::
    1s dance 1/2 Figs of 8 (Lady round 2s & Man down round 3s), turn to
    face 1st crnr & turn crnr LH (4 bar turn) 1s end in 2nd pl opp sides
17-24::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corner to
    start (end facing 2nd corners)
25-32::
    1s turn 2nd corners RH (4 bar turn) & dance 1/2 Figs of 8 (Man up
    round 2s & Lady down round 3s)
33-40::
    1s dance reels of 3 across giving LSh to 1st corners', 0);
INSERT INTO 'dancecrib' VALUES (12629, '2020-03-02 01:51:32.624933+00', '2023-02-04 01:18:45.959294+00', 7617, 3, NULL, 'ace', '1-8::
    1s cast (2s step up) & dance 1/2 Fig 8 up round 2s; 1s turn LH to
    face 1st corner
9-12::
    1s 1/2 turn 1st corner RH, corners join LH in centre & all
    Bal-in-Line
13-16::
    Middle couple turn 3/4 LH to 2nd corner diagonal & 1/2 turn 2nd
    corners
17-20::
    2nd corners join LH in centre & all Bal-in-Line, middle couple turn
    3/4 LH to 1st corner diagonal (1s)
21-24::
    Middle couple 1/2 turn 1s RH, 1s join LH in centre & all Bal-in-Line
25-32::
    1s turn 1.1/2 LH to 2nd place own side _while_ 2s+3s chase clockwise
    3/4 round to own side (6 bars) & all set.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4279, '2013-08-21 08:30:46.565923+00', '2023-02-04 01:18:45.990241+00', 559, 3, NULL, 'ace', '1-8::
    1s+2s+3s take hands on side & set twice, retain hands & 1M followed
    by 2M+3M cross & dance down behind Ladies _while_ 1L followed by
    2L+3L cross & down Men''s side (all pass RSh)
9-16::
    3s+2s+1s repeat above Fig with 1s leading crossing at bottom
17-24::
    1s dance Snowball Grand Chain for 3 cpls to end 3 (2) 1:
::
    1s cross RH & change places LH on side with 2s
::
    1s change places RH with 3s _while_ 2s cross RH
::
    1s cross LH _while_ 2s+3s change places LH.  3 (2) 1
25-32::
    3L+2L+1L set advancing to hold nearer hands & retire, 3M+2M+1M
    repeat
33-40::
    3s+2s+1s dance Snowball Grand Chain for 3 cpls to end 1 2 3:
::
    3s cross RH & change places LH on side with 2s
::
    3s change places RH with 3s _while_ 2s cross RH
::
    3s cross LH _while_ 2s+1s change places LH.  1 2 3
41-48::
    1s dance in & cast to 2nd place, all turn RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4280, '2013-08-21 08:30:46.576056+00', '2023-02-04 01:18:46.024645+00', 9562, 3, NULL, 'ace', '1-8::
    1s+2s+3s 1/2 turn partners RH & twirl right to dance out to opposite
    sides, 1s+2s+3s chase 1/2 way round to own sides
9-16::
    3s+2s (top 2 couples) dance 1/2 R&L as 1s cross RH & set, 3s+1s
    dance 1/2 R&L as 2s cross RH & set
17-24::
    1s dance RH across (Man with 3s & Lady with 2s), 1s Pass RSh & dance
    LH across with other couple
25-32::
    2s+1s+3s dance reflection reels of 3 on sides (1s dance in & up to
    start)', 0);
INSERT INTO 'dancecrib' VALUES (4281, '2013-08-21 08:30:46.584377+00', '2023-02-04 01:18:46.050017+00', 9931, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross LH, 1L casts up to face down
    between 2s as 1M casts down to face up between 3s
9-16::
    2s+1s+3s set, 1s 3/4 turn RH to opposite sides, 2s+1s+3s set & 1s
    3/4 turn LH ready for…
17-24::
    1L+2s also 1M+3s dance RH across, 1s pass RSh to dance LH across
    with other couple. 1s end in centre RSh to RSh facing opp sides
25-32::
    Fig 8 for 3 couples:
::
    _25-28_   1s pass RSh, 2M+2L follow 1M through 3L & 3M place _while_
    3L+3M follow 1L through 1M & 1L place.  1s end in centre LSh to Lsh
::
    _29-32_   All repeat Fig of 8 passing LSh', 0);
INSERT INTO 'dancecrib' VALUES (4282, '2013-08-21 08:30:46.594573+00', '2023-02-04 01:18:46.072404+00', 12521, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place (2s+3s step to ends), 1s & 4s 1/2
    turn partner 2H & set facing up/down
9-16::
    2s & 3s face in diag as 1s+4s dance 1/2 RH hands across & turn
    corner person LH, 1s+4s dance 1/2 RH across & 1/2 (wide) turn corner
    to original pls
17-24::
    1s+2s & 3s+4s Set+Link (1M & 4L end facing out), 1s & 4s 1/2 turn LH
    & all set.  2 4 1 3
25-28::
    All dance the Twirl: Advance towards partner (without joining hands)
    join RH with partner & Men raise hands above Ladies heads, Ladies
    dance under Mans arm (release hands end of bar 26), Ladies curve up
    & out to own sides to end facing down as Men retire (without joining
    hands)
29-32::
    2s+4s & 1s+3s dance RH across blending into:
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4284, '2013-08-21 08:30:46.611466+00', '2023-02-04 01:18:46.260549+00', 566, 3, NULL, 'ace', '1-8::
    All dance (holding 2H) to Ladies corner, 1/4 turn right & dance to
    next pl anticl''wise, all Ladies dance LH across as Men chase cl''wise
    1/2 way
9-16::
    With ''new'' partners repeat bars 1- 8
17-24::
    All dance 1/2 Grand Chain & set (in original places)
25-32::
    1L+3L dance in & set, 1/2 turn RH _while_ 2L+4L dance in & all
    Ladies (in circle) set
33-36::
    1L+3L cast to partners original places & set _while_ 2L+4L 1/2 turn
    RH as 1M+3M dance in & 2L+4L+1M+3M all (in circle) set
37-40::
    2L+4L cast to partners original places & set _while_ 1M+3M 1/2 turn
    RH as 2M+4M dance in & 1M+3M+2M+4M all set
41-48::
    1M+3M cast to partners place & set _while_ 2M+4M 1/2 turn RH & set
    to each other, 2M+4M cast to partners place (all now in partners
    orig pl)
49-56::
    1s+3s dance in & 3/4 turn opposite person RH to end in line of 4
    across (Ladies BtoB& 1M/3M between 4s/2s), 1M & 3M turn right about
    & cast right to original places followed by other partner
57-64::
    2s+4s repeat bars 49-56
65-128::
    repeat with new partners', 0);
INSERT INTO 'dancecrib' VALUES (8544, '2015-02-13 12:47:27.3966+00', '2023-02-04 01:18:41.92152+00', 15596, 3, NULL, 'ace', '1-8::
    1s+4s cross RH & cast in, 4s+1s dance 1/2 R&L
9-16::
    4s+1s+3s dance 1/2 reels of 3 on sides, 1s dance up to top.  1 2 3 4
17-24::
    1s+2s also 3s+4s dance double Fig of 8  (2s & 3s cross up/down)
25-32::
    All set twice, 1s cast to bottom as 2s+3s+4s turn RH & dance up 1
    place', 0);
INSERT INTO 'dancecrib' VALUES (9175, '2016-06-16 22:41:31.408504+00', '2023-02-04 01:18:46.280946+00', 8529, 3, NULL, 'ace', '1-4::
    1s cross RSh. 1s+2s change places on sides (1M+2L RH, 1L+2M LH)
5-8::
    2s+1s dance 1/2 double Fig 8 (1s cross up, 2s dance down)
9-12::
    1s followed by 2s dance down behind 3s & 4s to meet partners (2s
    above 1s) in centre NHJ
13-16::
    2s followed by 1s dance up.  2s cast into 1st place opp sides facing
    down, 1s between 2s facing up.
17-20::
    1s+2s Bal-in-Line (1 bar), set turning about (towards centre) to
    face opp direction (1 bar) & Bal-in-Line again (2 bars)
21-24::
    1s in promenade hold dance 1/2 reel of 3 across with 2s (RSh to 2L)
    Finish as Bars 19-20 but 2s on own sides
25-28::
    Repeat bars 17-20
29-32::
    1M+2M turn 3/4 LH as 1L+2L turn 3/4 RH', 0);
INSERT INTO 'dancecrib' VALUES (4285, '2013-08-21 08:30:46.619766+00', '2023-02-04 01:18:46.29544+00', 570, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance double Fig of 8 with couples below them 1s &
    3s dancing down to start
9-16::
    1s & 3s cross to dance reels of 4 on opposite sides passing down
    between 2s/4s to start to end in original places but 1s & 3s on
    opposite sides
17-24::
    1s & 3s 1/2 turn RH to 2nd/4th pl own side as 2s & 4s cast up, 2s+1s
    also 4s+3s dance 1/2 RH across & all turn partner 2H 1.1/2 times
25-32::
    1s+2s also 3s+4s dance 1/2 Diamond Poussette, 1s+4s dance 1/2
    Diamond Poussette.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4286, '2013-08-21 08:30:46.700435+00', '2023-02-04 01:18:46.520073+00', 13806, 3, NULL, 'ace', '1-8::
    1s+2s set & turn partners 2H, circle 4H round to left
9-16::
    1s+2s dance the Knot & 1s end facing 1st corners
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    Pass+Turn with 2nd corners & pass RSh to 2nd place own sides
25-32::
    1s dance Figs of 8 on own sides (RSh to 3rd corner) 1L ending
    between 2s & 1M between 3s, 1s 3/4 turn LH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4287, '2013-08-21 08:30:46.710741+00', '2023-02-04 01:18:46.731823+00', 571, 3, NULL, 'ace', '1-8::
    1M dances down centre & casts up behind 3L, crosses over & casts up
    behind 2M back to place
9-16::
    1L casts behind 2L, crosses over, casts down behind 3M & dances up
    to place
17-24::
    1s dance in & cast 1 place, lead down between 3s & cast to 2nd
    places
25-32::
    1L dances 1/2 Fig of 8 round 2s as 1M dances 1/2 Fig of 8 round 3s,
    1s full turn RH, dance out & round 2nd corners, pass RH in centre
33-40::
    1s dance reels of 3 on opposite sides starting by giving LSh to 1st
    corner, 1s cross to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13392, '2020-12-02 01:18:43.971385+00', '2023-02-04 01:18:46.78321+00', 19149, 3, NULL, 'ace', '1-8::
    1s cast to 4th place (2s+3s+4s step up 3-4); 4s+1s circle 4H round
    to left
9-16::
    1s cast back up to 1st place (2s+3s+4s step down 11-12); 1s+2s
    circle 4H round to right
17-24::
    1s dance mirror Fig 8 on sides (1s in/down to start)
25-32::
    1s set advancing, 1/2 turn RH to face down; lead down & 1/2 turn RH
    to 4th place own side (2s+3s+4s step up 29-30)', 0);
INSERT INTO 'dancecrib' VALUES (4289, '2013-08-21 08:30:46.729163+00', '2023-02-04 01:18:46.842799+00', 13761, 3, NULL, 'ace', '1-8::
    1s+2s dance 4H round to left & chase clockwise 1/2 way to diagonally
    opposite places
9-16::
    1s+2s set & cross RH, 1s+2s set & 2s cast to original places as 1s
    turn LH into prom hold to face 2L
17-24::
    1s dance reel of 3 with 2s passing 2L RSh to start with 2s ending in
    1st place
25-32::
    1s dance Fig of 8 round 2s crossing up to start', 0);
INSERT INTO 'dancecrib' VALUES (4290, '2013-08-21 08:30:46.737498+00', '2023-02-04 01:18:46.906453+00', 576, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, cross LH & 1L casts up as 1M casts down
    both to face 1st corners
9-16::
    Chain Across:
::
    _9-12_     1s change places RH with 1st corners, corners change
    places LH with partners
::
    _13-16_   1s change places RH with middle person (1M+3M & 1L+2L), 1s
    pass RSh to lines across facing 2nd corner (pstn)
17-24::
    1s repeat 9-16 starting 1M+2M & 1L+3L changing places LH. Bars
    23-24: 1s dance LSh round each other to face 2nd corners
25-32::
    1s dance reels of 3 on opposite sides (start passing 2nd corner RSh)
    & 1s end crossing LH to 2nd place own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4291, '2013-08-21 08:30:46.747694+00', '2023-02-04 01:18:47.014074+00', 578, 3, NULL, 'ace', '1-8::
    1s turn 2H & cast 1 place, turn 2H & cast 1 place (Lady up, Man
    down) to end 1L between 2s & 1M between 3s
9-16::
    2s+1s+3s set twice 1s turning into 2nd place opposite sides,
    2s+1s+3s set twice & 1s end facing 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners 1s end facing
    Men''s side (Lady on Man''s right)
25-32::
    1s lead out Men''s side, cross & cast round 2M/3M to meet facing
    Ladies'' side, lead out Ladies'' side, cross & cast round 2L/3L to 2nd
    pl own sides', 0);
INSERT INTO 'dancecrib' VALUES (4292, '2013-08-21 08:30:46.756045+00', '2023-02-04 01:18:47.042918+00', 583, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp. sides

1-8::
    1s & 4s dance Figs of 8 on sides (1s in & down & 4s in & up to
    start) _while_ 2s & 3s dance Figs of 8 across (casting to start), 2L
    & 3L end crossing down/up to other side to form line of 4 across
    with Men who cross down/up to BtoB facing other partner
9-16::
    2s+3s dance reel of 4 across & Men end turning LH to pick up partner
    (3s facing up & 2s down)
17-24::
    3s & 2s lead out ends crossing & cast in 1 place, all set & turn 2H
    to end 1s facing 3s & 2s facing 4s.  1 3 (2)(4)
25-32::
    1s+3s also 2s+4s dance Rondel to end 3 1 (4)(2)', 0);
INSERT INTO 'dancecrib' VALUES (4295, '2013-08-21 08:30:46.848614+00', '2023-02-04 01:18:47.276126+00', 585, 3, NULL, 'ace', '1-4::
    1s cross down & loop round to face out on opposite sides as for
    double triangles
5-8::
    Set as in double triangles & 1s dance out & turn right about to face
    in _while_ 2s & 3s dance in & turn right about to face out
9-16::
    Set (Inverted Triangle formation) & 1s dance in _while_ 2s & 3s
    dance out all turning R about, 1s dance RSh round 1st corner to face
    4th corner
17-24::
    1s dance LSh reels of 3 across
25-32::
    1s dance RSh reels of 3 on own sides (RSh to 3rd corner) & end in
    middle RSh to RSh
33-40::
    1s set & turn about, set & dance RSh round 4th corner to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (15267, '2022-11-30 21:54:00.162115+00', '2022-12-02 15:24:46.750079+00', 13389, 1, 202, 'ace', '1--::

  Circle8 and back

9-12::

  All W RHA. Finish BtoB facing P

13-24::

  Intersecting Reels4 (½ LHA in 2 bars in centre). Finish as on [13]

25--::

  All set to P twice ; turn P RH 1¼ to original places facing P

33--::

  Interlocking Reels4. Finish as on [33]

41--::

  All turn P RH ½. Retain RH and give LH to next person, all M facing out, all W facing in | BiL ; all turn next person LH ½. Retain LH and give RH to next one, all M facing in, all W facing out |BiL . On [48], all W face in

49--::

  2c+4c ½ L-Chain ; 3c+1c ½ L-Chain

57--::

  All A&R ; all Tulloch Turn (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (14885, '2022-06-23 18:29:03.287967+00', '2022-10-03 18:38:10.202828+00', 20900, 1, 202, 'ace', '1--::

  All cross RH | clap 3 ; repeat [1-4] (1,2,3)

9--::

  1c+2c Chain Progression (2,1,3)

17--::

  Reels3 on sides, 1c RSh to 3cnrs. 1c face 1cnrs

25--::

  SetH&G (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13390, '2020-12-02 01:18:41.004543+00', '2023-02-04 01:18:43.144719+00', 17802, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 on sides (1L casts, 1M dances in & 1s pass 2s RSh to
    start). 1L ends facing out
9-16::
    1L followed by 1M casts round 2L, crosses down between 3s, casts up
    round 3M to 2nd place own side (2s step up 11-12)
17-24::
    1s+3s Set+Link; 2s+3s+1s dance DoSiDo with partner
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4296, '2013-08-21 08:30:46.858698+00', '2023-02-04 01:18:47.312792+00', 11389, 3, NULL, 'ace', '1-8::
    1s dance down 1place, set to 3s who set advancing, 1s+3s dance up to
    top & cast 1s to 3rd place & 3s to 2nd place
9-16::
    2s dance down 1 place, set to 1s who set advancing, 2s+1s dance up
    to top & cast 2s to 3rd place & 1s to 2nd place.  3  1 2
17-24::
    3M+1L also 1M+2L change places RH, 3L+2L also 3M+2M change places
    LH, 1L+2M also 3L+1M change places RH & all set.  2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4298, '2013-08-21 08:30:46.892807+00', '2023-02-04 01:18:47.46769+00', 14909, 3, NULL, 'ace', '1-4::
    1s cross down RH to 2nd place opp sides facing out (2s step up) &
    change place with 3s (RH Ladies'' side, LH Men''s side)
5-8::
    1s dance up NHJ & turn 2s (RH Ladies'' side, LH Men''s side) to end
    2nd place opp side (3s step down 7-8)
9-16::
    1s dance RSh reels of 3 across (1L with 2s, 1M with 3s)
17-24::
    1s dance RH across (1L with 3s, 1M with 2s), 1s dance 1/2 Figs of 8
    to end 2nd place own sides (1L round 2s, 1M round 3s)  2 1 3
25-32::
    1s+3s dance Espagnole:
::
    _25-26_    1s+3s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _27-28_    1s+3s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _29-32_    3s turn RH as 1s turn LH to 3rd places.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4299, '2013-08-21 08:30:46.900855+00', '2023-02-04 01:18:47.487897+00', 590, 3, NULL, 'ace', '1-8::
    1s+2s petronella turn & set, 3/4 turn partners RH to opposite sides
    & dance RH across 1/2 way. 1s end facing 2nd corners
9-16::
    1s dance 1/2 RSh reels across (1M+2s & 1L+3s) & 1/2 reels of 3 on
    opp sides (LSh to 1st crnr). 1s ending BtoB in centre 1M face down &
    1L up
17-24::
    1s dance Crown Triangles to end facing out on opposite sides
25-32::
    1s dance 1/2 reels of 4 with 1st corner pstns, pass partner RSh for
    1/2 reel with 2nd corner pstns & cross RH to 2nd place own sides.  2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (8834, '2015-08-13 20:33:22.150499+00', '2023-02-04 01:18:47.56153+00', 14288, 3, NULL, 'ace', '1-8::
    All circle 8H 1/2 round to Left.  All dance 1/2 Grand Chain (RH to
    partner to start) back to places
9-16::
    All dance »Circular Knot«
::
    _9-10_     Turn partner 1.1/4 RH into promenade hold facing
    anticlockwise (Men in centre)
::
    _11-12_   All promeande 1 place
::
    _13-16_   All turn partner 1.1/4 LH.  Finish with Men facing out,
    Ladies facing in
17-20::
    Ladies dance RH across _while_ Men chase anticlockwise 1/2 round set
21-24::
    All pass opp person LSh. Men dance LH across _while_ Ladies chase
    clockwise 1/2 round set
25-26::
    All pass partners RSh. Ladies dance 1/2 RH across _while_ Men chase
    1 place anticlockwise round set
27-28::
    1M+2L, 2M+3L, 3M+4L & 4M+1L turn LH
29-30::
    Ladies dance 1/2 RH across _while_ Men chase 1 place anticlockwise
31-32::
    1M+3L, 2M+4L, 3M+1L & 4M+2L turn 3/4 LH to end in square set with
    new partners', 0);
INSERT INTO 'dancecrib' VALUES (4302, '2013-08-21 08:30:46.926886+00', '2023-02-04 01:18:47.625054+00', 594, 3, NULL, 'ace', '1-8::
    2s followed by 1s lead down the middle, 1s cross & cast up to top &
    curve in to end BtoB facing 2s who have danced back to place
9-16::
    ''The Spurtle'':
::
    _9-12_    1s dance 1/2 RSh reel of 4 with 2s & turn RH to face 3s (M
    facing L)
::
    _13-16_  Repeat with 3s but end facing 4s
::
    _17-20_  Repeat with 4s
::
    _21-24_  1s continue turn to end in 4th place opposite sides & all
    set  (2) (3) (4) (1)
25-32::
    All Petronella to centre & set, Petronella to own sides & set. 2 3 4
    1', 0);
INSERT INTO 'dancecrib' VALUES (4303, '2013-08-21 08:30:46.936681+00', '2023-02-04 01:18:47.659249+00', 13356, 3, NULL, 'ace', '1-8::
    1s set & cast (2s step up), 1s set & 3/4 turn LH _while_ 2s & 3s
    turn LH once round & face out on own sides
9-16::
    1s dance LSh reels on own sides (1M up, 1L down) & end in Double
    Triangle positions facing own sides
17-24::
    1s dance Double Triangles (6 bars) & end dancing round partner
    (PdeB) clockwise to1M facing up & 1L down _while_ 2s+3s continue
    setting
25-32::
    1M with 2s also 1L with 3s circle 3H round to Left(4 bars); opening
    into 6H round to Left tending 2 1 3 on own sides', 0);
INSERT INTO 'dancecrib' VALUES (14724, '2022-04-01 00:18:46.884303+00', '2023-02-04 01:18:47.708396+00', 20674, 3, NULL, 'ace', '{{explanation}}
1s & 3s start on opposite sides (1) 2 (3) 4

1-8::
    1s+2s & 3s+4s dance RH across & LH across back, 2M & 3M end facing
    in, 2L & 3L face out on sides
9-16::
    2s+3s dance reel of 4 across, 2M+3M start passing LSh as 2L & 3L
    loop to right. 2L+3L end dancing round each other 3/4 LSh & take
    partner in prom hold, 2s facing up, 3s down
17-20::
    2s+1s dance 1/2 reel of 3 across (2s RSh to 1M in 1L''s place)
    _while_ 3s+4s dance similar (3s RSh to 4M)
21-24::
    2s+1L+4M dance 1/2 reel of 3 on Ladies'' side (2s LSh to 4M) _while_
    3s+1M+4s dance similar (3s LSh to1M).
25-32::
    2s+3s dance 1/2 Men''s Chain (Ladies cast down/up to start); 4s+2s
    also 3s+1s set advancing & circle 4H 1/2 round to left.  (2) 4 (1) 3', 0);
INSERT INTO 'dancecrib' VALUES (13731, '2021-03-02 01:18:50.754088+00', '2023-02-04 01:18:47.95344+00', 13374, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All 4 couples set, 1s & 3s cast down 1 place _while_ 2s+4s cross up
    1 place to face  partner on opp sides; All set. 2s & 4s cast down
    one place _while_ 1s+3s cross up. (1) (2) (3) (4)
9-16::
    All dance mirror reels of 4 on opposite sides (RSh reels for Men,
    LSh reels for Ladies)
17-24::
    All circle 8H round to left 2 places (2 bars), 1s+2s also 3s+4s
    circle 4H round to left once round (4 bars), all circle 8H round to
    left 2 places. 4 3 2 1
25-28::
    4s+3s also 2s+1s chase 1 place clockwise, all face partner up/down
    on the sides & set
29-32::
    All turn partner RH to end in diagonal square set (arranged
    clockwise 4s, 2s, 1s, 3s) Ladies facing out, Men facing in
33-36::
    Ladies chase clockwise 1 place, dance in & dance LSh 1/2 round in
    middle to end facing diagonally opp Man (4M+1L, 2M+3L, 1M+4L, 3M+2L)
37-40::
    All Ladies set to and turn Man LH
41-43::
    Men chase anticlockwise, dance in & dance RSh 1/2 round in middle to
    face original partner
44-48::
    All set to and turn partner RH to end in longwise set all facing in
    (Ladies side: 1L 1M 3L 3M, Men''s side: 2M 2L 4M 4L)
49-52::
    All set to couple opposite, 1s+2s & 3s+4s dance LH across 3/4 round
    (2) 1 (4) 3
53-56::
    2s & 4s turn partner LH 1.1/2 times to own sides _while_ 1s & 3s
    turn partner LH.  2 1 4 3
57-64::
    All circle 8H round and back

{{title}}
Reel

65-128::
    All repeat bars 1-64 in reel time', 0);
INSERT INTO 'dancecrib' VALUES (9425, '2016-10-06 07:19:06.348526+00', '2023-02-04 01:23:09.964767+00', 13557, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 1M faces out.  1M followed by 1L casts up, dances
    down middle to face 3M, 1L faces 2M
9-16::
    1M+3s & 1L+2s dance reels of 3 across (1M+3M and 1L+2M pass RSh to
    start)
17-24::
    1M+3M & 1L+2M turn RH, 1M+3L & 1L+2L turn LH to finish 1M facing
    down between 3s & 1L facing down between 2s.
25-32::
    1M followed by 1L casts up men''s side & dances across to 2nd place
    opp sides & 1s turn 1.1/2 RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13732, '2021-03-02 01:18:50.782669+00', '2023-02-04 01:18:47.981572+00', 587, 3, NULL, 'ace', '1-4::
    1s cross down RH  to double triangles position (2s step up 1-2)
    1s+2s+3s set as Double Triangles
5-8::
    1s turn 2nd corner 3/4 LH. 1M ends above 2s facing down, 1L ends
    below 2s facing up
9-12::
    1M+2s set as Double Triangles, 2s turn inwards to face down & 2s+1L
    set as Double Triangles (1s set throughout 4 bars)
13-16::
    1M followed by 1L casts down behind Ladies'' side. 1M ends below 3s
    facing up, 1L dances in between 2L & 3L to face down above 3s
17-20::
    1s+3s repeat 9-12
21-24::
    1M followed by 1L casts up behind 3M, 1M dances in, pulls back RSh
    to end in 2nd place own side, 1L dances across to 2nd place own side
    passing 1M RSh
25-32::
    2s+1s+3s turn partner RH then turn partner LH (dance out to sides
    each time). 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4306, '2013-08-21 08:30:46.962875+00', '2023-02-04 01:18:48.175803+00', 11171, 3, NULL, 'ace', '{{explanation}}
1s & 3s start on opp sides

1-8::
    2s+3s dance RH across, 1s+2s also 3s+4s dance LH across
9-16::
    All petronella turn into middle, set, 3/4 turn RH to change sides &
    set.  1 (2)3(4)
17-24::
    1s+2s also 3s+4s dance 1/2 R&L, end couples 1/2 turn 2H & centre
    couples 1/2 turn 2H on sides to end in a square set
25-32::
    All dance 1/2 double Men''s Chain, couples in 1st & 3rd places set &
    turn 2H 1.1/2 times to face Mans corner with Lady behind Man _while_
    couples in 2nd & 4th places continue with another 1/2 Men''s Chain
33-40::
    Couples in 1st & 3rd places dance Tandem LSh reels of 3 across & end
    curving round to face side couple (1s face 4s & Lady faces Man)
41-48::
    All circle 4H round to left, set, side cpls make arch & cpls from
    1st & 3rd pl dance under arches, divide & cast back to form longwise
    set.  (2) 4 (1) 3', 0);
INSERT INTO 'dancecrib' VALUES (4307, '2013-08-21 08:30:46.97104+00', '2023-02-04 01:18:48.21051+00', 600, 3, NULL, 'ace', '1-8::
    1M sets to 2L & casts 1 place, 1L sets to 2M & casts 1 place
9-16::
    2s+1s+3s dance Allemande Right (Adv for 2, give RH to ptnr & Lady
    turns under M''s arm, Lady dances back to place as Man retires),
    repeat using LH
17-24::
    1s set, petronella turn, set & turn RH to face 1st corners
25-32::
    1s dance 1/2 diagonal reel with 1st corners, pass RSh & dance 1/2
    diagonal reel with 2nd corners ending BtoB in centre with Man facing
    up
33-36::
    1s circle 3H round to left (1L with 2s, 1M with 3s) opening out with
    1M leading 3s down Ladies'' side as 1L leads 2s up Men''s side.
37-40::
    3s+1s+2s circle 6H 1/2 round to left to end 2 1 3 (own sides) & all
    3 couples set', 0);
INSERT INTO 'dancecrib' VALUES (8547, '2015-02-13 12:47:28.553182+00', '2023-02-04 01:18:48.278344+00', 15610, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-8::
    1s+4s dance interlocking Figs of 8 on sides (1s in/down, 4s in/up to
    start)
9-16::
    2s & 3s dance Figs of 8 across crossing between 1s/4s to start
17-24::
    1s+2s also 3s+4s dance 1/2 R&L, 1s+4s dance 1/2 R&L.  (2)(4)1 3
25-32::
    All circle 8H round & back
::
    Note:  1st & 3rd time through 3rd & 4th couples start on opp sides;
    2nd & 4th time through 1st & 2nd couples start on opp sides', 0);
INSERT INTO 'dancecrib' VALUES (4309, '2013-08-21 08:30:47.011594+00', '2023-02-04 01:18:48.312248+00', 12148, 3, NULL, 'ace', '1-8::
    1s set & cross RH as 2s set, 1s+2s change places LH on sides as 3s
    set & 1s+3s change places RH _while_ 4s set as 2s cross RH.  (2) 3
    (1) 4
9-16::
    2s+3s also 1s+4s change places LH on sides & 2s+4s change pls RH as
    1s & 3s cross RH, 3s+4s also 2s+1s change pls LH & all set.  4 (3) 1
    (2)
17-24::
    All dance 1/2 reels of 4 on sides, 1s+3s+4s (bottom 3 couples) dance
    1/2 reels of 3 on sides.  (2) 4 (3) 1
25-32::
    4s & 1s dance 1/2 Figs of 8 round couple above, 2s & 1s cross RH as
    4s+3s dance RH across 1/2 way  & all set. 2 3 4 1
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4310, '2013-08-21 08:30:47.019701+00', '2023-02-04 01:18:48.344216+00', 604, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, turn 2H to end 1s facing down & 2s+3s facing up in
    centre, 1s+2s set advancing passing LSh to change places _while_ 3s
    set, 2s turn 2H _while_ 1s+3s set advancing to change places
9-16::
    2s+3s set advancing to change places _while_ 1s turn 2H, 3s turn 2H
    _while_ 2s+1s set advancing to change places & repeat to 1 2 3
17-24::
    1s+2s dance the Rondel ending with 1s crossing to opposite sides
25-32::
    1L+3M turn LH _while_ 1M+3L turn RH, 2M+1L 1/2 turn RH _while_ 2L+1M
    1/2 turn LH, 1s cross down to 2nd place as 2s dance out & up to 1st
    place', 0);
INSERT INTO 'dancecrib' VALUES (4314, '2013-08-21 08:30:47.140818+00', '2023-02-04 01:18:48.660099+00', 611, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance 6H round & back
9-16::
    1s followed by 2s+3s (who dance up) lead down to order 3 2 1; 2s+1s
    set adv, 1s turn 2H to end in centre BtoB (Lady facing up & Man
    down) _while_ 2s turn RH & lead up to top _while_ 3s cast to 3rd
    place
17-24::
    1L dances reel of 3 across with 2s giving LSh to 2M _while_ 1M
    dances 3H round & back with 3s
25-32::
    1L dances 3H round & back with 2s _while_ 1M dances reel of 3 across
    with 3s giving LSh to 3L
33-40::
    1s dance down between 3s & cast up round them, lead up between 2s &
    cast round them to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (13041, '2020-08-10 00:18:40.597702+00', '2023-02-04 01:18:48.695472+00', 15414, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole, Bar 5: 1s turn partner 1.1/2 LH to 2nd place
    opp sides facing out _while_ 2s turn RH as normal
9-16::
    Reels of 3 on sides, 1s pass 2nd corner LSh to start
17-24::
    1s cast LSh round 2nd corner, cross RH up/down centre; 1L dances up
    & casts round 2L _while_ 1M dances down & casts up round 3M to 2nd
    place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4315, '2013-08-21 08:30:47.150607+00', '2023-02-04 01:18:48.722274+00', 9755, 3, NULL, 'ace', '1-8::
    1L casts below 3s & dances up to 2nd pl as 1M dances down & casts up
    to 2nd pl, 2s+1s+3s cross RH & dance 6H round to L 1/2 way
9-16::
    2s & 3s petronella turn into centre, dance a 1/2 reel of 4 up/down
    middle & petronella turn to own sides having changed places
17-24::
    2s+1s Set+Link, 2s+3s Set+Link
25-32::
    All dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (12461, '2020-01-02 06:58:53.029173+00', '2023-02-04 01:18:48.74679+00', 16682, 3, NULL, 'ace', '1-8::
    All Set+Link; Ladies dance 3/4 RH across to end 1 place round
    anticlockwise _while_ Men set, pull back LSh & cast 1 place to right
    to end with partner
9-16::
    1s+3s (pstn) dance 1/2 R&L; 2s+4s (pstn) dance 1/2 R&L
17-24::
    All dance Grand Chain 1/2 round (4 bars) & turn partners RH
25-32::
    All circle 8H round to left (4 bars), pull back LSh & chase
    anticlockwise back to place as at end of Grand Chain (bar 20). 2 3 4
    1', 0);
INSERT INTO 'dancecrib' VALUES (4317, '2013-08-21 08:30:47.237055+00', '2023-02-04 01:18:48.836814+00', 7352, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 on own sides (1s in & down to start)
9-16::
    1s cross RH, cast 1 place, set & cross RH
17-24::
    1s+3s+4s dance reels of 3 on sides (1s out & down to start)
25-32::
    1s set, cast to face 4s (on sides), 1s+4s set & change places on
    sides (Men RH & Ladies LH)', 0);
INSERT INTO 'dancecrib' VALUES (15268, '2022-12-01 11:12:50.473965+00', '2022-12-01 14:51:27.267054+00', 20766, 1, 1645, 'ace', '1-::

  1c set | cross RH ; cast off (2c up) | turn LH to lines of 3 across facing 1cnr

9-::

  Reels3 across, 1c start LSh to 1cnr & end BtoB facing 1cnr again

17-::

  Turn CPCP, 1c end crossing _RH_ to 2pl

25-::

  Circle6 to L & back (2,1,3) 

', 2);
INSERT INTO 'dancecrib' VALUES (4252, '2013-08-21 08:30:46.093366+00', '2023-02-04 01:18:44.131274+00', 9735, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    1s & 4s cross RH & cast in 1 place, 1s+4s dance LH across
9-16::
    1s & 4s change places RH with corners & 2s+3s dance LH across, all
    set
17-24::
    All dance reels of 4 on sides
25-32::
    All set, 1s+2s also 3s+4s dance RH across 1/2 way,  1s+4s dance LH
    across 1/2 way _while_ 2s & 3s cross RH, all set.  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (4318, '2013-08-21 08:30:47.247039+00', '2023-02-04 01:18:48.876799+00', 9842, 3, NULL, 'ace', '1-8::
    1s set advancing, 1/2 turn 2H, dance down NHJ below 3s & cast up to
    2nd place _while_ 2s set & cross LH up to 1st place (2)(1) 3
9-16::
    1s set advancing, 1/2 turn 2H, dance up above 2s & cast to face 1st
    corner positions _while_ 3s set & cross LH
17-24::
    1s dance 1/2 diagonal reel with 1st corners (pstns), pass RSh to
    face 2nd corner positions & dance 1/2 reel with 2nd corners (pstns).
    1s pass RSh to end  in 2nd place own sides. 3 1 2
25-32::
    3s+1s+2s chase clockwise 1/2 way & turn partners RH 1.1/2 times to
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (10060, '2017-09-03 23:44:18.07525+00', '2023-02-04 01:18:48.899542+00', 17901, 3, NULL, 'ace', '1-8::
    1s lead down, cross below 3s & cast up to 2nd place opp sides (2s
    step up 3-4).  1s turn 1.1/4 LH to end in middle facing own side
9-16::
    1M+2s also 1L+3s dance RH across, 1s pass RSh to dance LH across
    with other couple.  1s end in 2nd place opp sides
17-24::
    2s+1s dance Ladies'' Chain .  1s end in 2nd place opp sides, 1M
    facing out
25-32::
    1M followed by 1L, casts behind 3L, across set, 1M dances up behind
    3M to 2nd place own side _while_ 1L dances up middle , pulls back
    RSh to dance into place.  2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (4319, '2013-08-21 08:30:47.255278+00', '2023-02-04 01:18:48.927484+00', 627, 3, NULL, 'ace', '1-4::
    1M dances 1/2 LSh reel of 3 across with 2s
5-8::
    1M picks up partner in prom hold & dance a further 1/2 reel with 2s
9-12::
    1L dances 1/2 reel with 2s _while_ 1M casts 1 place with a loop (4
    bars)
13-16::
    1M dances 1/2 LSh reel with 3s _while_ 1L casts with a loop
17-20::
    1M picks up partner in prom hold & dance 1/2 reel with 3s
21-24::
    1L continues with 1/2 reel with 3s _while_ 1M dances LSh round 2L
25-28::
    1M dances RSh round 3L _while_ 1L dances RSh round 2M
29-32::
    1s set & turn RH
33-40::
    1s cast (Man up, Lady down), cross over, cast to 2nd place & cross
    to own side _while_ 2s & 3s petronella to own sides', 0);
INSERT INTO 'dancecrib' VALUES (9176, '2016-06-16 22:41:31.953262+00', '2023-02-04 01:18:49.045333+00', 16838, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+3s dance Men''s Chain finish with Ladies facing out
17-28::
    All dance Schiehallion reels (12 bars) to finish 1 place clockwise
    from starting place 4 1 2 3
29-32::
    All birl (or turn) partners RH  End 4 1 2 3

{{explanation}}
Note: Dance twice as Strathspey, twice as Reel', 0);
INSERT INTO 'dancecrib' VALUES (4320, '2013-08-21 08:30:47.263358+00', '2023-02-04 01:18:49.05629+00', 629, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H left, set, 1s cast _while_ 2s dance up & face out
9-16::
    2s+1s+3s reels of 3 on side (1s dance in & down to start), 1s end
    facing 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting, end in centre BtoB with 1M facing
    up & 1L facing down
25-32::
    1s RH across (Man with 2s & Lady with 3s) 1s end in 2nd place
    opposite sides & 2s+1s+3s spin RH (1s back to own sides)', 0);
INSERT INTO 'dancecrib' VALUES (4321, '2013-08-21 08:30:47.273387+00', '2023-02-04 01:18:49.069806+00', 10456, 3, NULL, 'ace', '1-8::
    1s & 4s petronella turn & set (2s & 3s step up/ down 3-4); 1s & 4s
    turn partner LH 1.1/4 times, 1s finish between 2s, 4s between 3s all
    facing opp sides
9-24::
    1s+2s also 3s+4s dance Modified »Celtic Reel«:
::
    _9-12_   1s+2s (3s+4s) pass RSh as for reel of 4, 1s (3s) dance
    clockwise 1/4 way _while_ 2s (4s) turn 3/4 LH round each other to
    face other prtnr (up/down)
::
    _13-16_  1s+2s (3s+4s)  pass RSh as for reel of 4, 2s (4s) dance
    clockwise 1/4 way _while_ 1s turn 3/4 LH round each other to face
    other partner (across)
::
    _17-24_  1s+2s (3s+4s) repeat bars 9-16 to end 1s between facing
    down, 4s between 3s facing up.
25-32::
    1s & 4s set twice to each other & dance 1/2 R&L to end on own sides
    in 2nd/3rd places facing out.  2 4 1 3
33-36::
    1M followed by 4M dances down behind 3M & dances up between 3s
    _while_ 4L followed by 1L dances up behind 2L & dances down between
    2s
37-40::
    1s+4s dance LH across 3/4 round to end on own sides in order 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4323, '2013-08-21 08:30:47.310316+00', '2023-02-04 01:18:49.269457+00', 633, 3, NULL, 'ace', '1-16::
    All dance petronella round back to places
17-32::
    1L sets adv to 1M & turns 2H, 1L repeats with 2M, 3M & 4M, as 2L, 3L
    & 4L dance up 1 pl & repeat turning Men. Final turn 4L+1M, 3L+2M,
    2L+3M, 1L+4M. Ladies now are on Men''s side
33-40::
    1L followed by 2L, 3L & 4L weave ''out & in'' on Men''s side till 1L+2L
    are between 1M+2M & 3L+4L between 3M+4M, all dance across to place
41-48::
    All set twice to partners & turn RH into Allemande hold in centre
49-64::
    Each couple in turn sets advancing/turning to form a square set (4
    bars each couple), 1s to 1st place facing down, 2s to 4th place, 3s
    to 2nd place & 4s to 3rd place
65-72::
    Ladies continue setting _while_ Men set dancing in & turning to face
    partner & 1M & 4M set twice facing partner as 2M & 3M set once &
    dance clockwise to face 1M/4M forming a line in centre for reel of
    4.  2 1 4 3
73-80::
    Ladies set _while_ Men dance reel of 4 & end facing partners
81-88::
    All set twice & turn 2H into longwise pstns
89-96::
    1s+2s also 3s+4s dance All Round Poussette (Popular variation -
    progressive Poussette & repeat dance from new positions)', 0);
INSERT INTO 'dancecrib' VALUES (4324, '2013-08-21 08:30:47.318516+00', '2023-02-04 01:18:49.287561+00', 635, 3, NULL, 'ace', '1-4::
    1L followed by partner casts to 3rd pl & crosses to opp side _while_
    3M followed by prtnr casts to top & crosses to opp side _while_ 2s
    set & cross RH
5-8::
    3s+2s+1s turn RH
9-12::
    1M followed by partner casts to top & crosses to original pl _while_
    3L followed by prtnr casts to 3rd pl & crosses to own side _while_
    2s set & cross LH
13-16::
    1s+2s+3s turn LH
17-24::
    1s+2s cross (Ladies between Men), Ladies divide & dance back to
    place as Men cross (between partners), 1s turn RH _while_ 2s turn LH
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4325, '2013-08-21 08:30:47.32845+00', '2023-02-04 01:18:49.321654+00', 10934, 3, NULL, 'ace', '1-4::
    1s set & cast 1 place _while_ 2s set & cross up LH and 3s set &
    cross RH
5-8::
    1s lead down middle & cast up round 3rd pl into centre (LSh to LSh)
    _while_ 2s+3s change places RH on sides & cross RH with partner
9-16::
    1s dance RH across (1L with 3s at top & 1M with 2s) & end 2nd pl own
    sides, 1s dance 1/2 Diag R&L _while_ 3L+2M chase cl''wise 1/2 way.
    (2) (1) (3)
17-24::
    1s dance LH across (1M with 3s & 1L with 2s), 1s dance 1/2 Diag R&L
    _while_ 3M+2L chase anticlockwise 1/2 way  3 1 2
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (8240, '2014-04-08 11:28:01.540316+00', '2023-02-04 01:18:49.356682+00', 8978, 3, NULL, 'ace', '1-8::
    1M followed by 2M+3M dance down behind Ladies, 1M dances in front of
    2L  _while_ 2M+3M continue to dance down, 1M dances out between
    2L+3L to follow 2M+3M as all dance up to places on own side   2M 3M
    1M
9-16::
    1L+2L+3L repeat bars 1-8 to finish on own side  2L 3L 1L;  1s face
    out on bar 16
17-24::
    1s cast below 4s, dance full Fig 8 round 4s (6 bars); 1s changes
    places with 4s (M with LH, L with RH)
25-32::
    All circle 8H round & back', 4);
INSERT INTO 'dancecrib' VALUES (4326, '2013-08-21 08:30:47.354357+00', '2023-02-04 01:18:49.504075+00', 640, 3, NULL, 'ace', '1-8::
    1M+2L set to each other & turn RH, 1L+2M repeat
9-16::
    1s+2s circle 4H round to left, 1s set & cast to face 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s dance reels of 3 on sides with corners (LSh to 1st corner) &
    cross RH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (4327, '2013-08-21 08:30:47.364528+00', '2023-02-04 01:18:49.53593+00', 642, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    Chorus:
::
    _1-2_   1s+3s lead to centre _while_ 2s & 4s, facing partners, dance
    backwards away from partner to corners
::
    _3-4_   1M+3L lead to 2nd place & 3M+1L to 4th place _while_ 2M+4L
    dance to 3rd place & 4M+2L to 1st place
::
    _5-8_   Repeat 1-4 with 2s+4s leading to centre, 1s+3s dancing away
    from partners.  All dance to original places
9-16::
    Ladies dance 4H round to left 1/2 way to opposite positions.  Men
    dance 4H round to right to meet partners
17-24::
    All face partners & set HS.  All dance 1/2 Grand Chain back to
    original places
25-32::
    Chorus
33-40::
    Men lead partners into centre, all face corners, set (strathspey
    setting).  All give RH to corner partner & dance out to original
    places

{{title}}
Reel

1-8::
    Chorus
9-16::
    1s & 3s lead into centre, divide to face 2s/4s, all set & dance RH
    across back to places
17-24::
    2s & 4s repeat above Fig dancing LH across
25-32::
    Chorus
33-40::
    All dance 8H round & back all finishing in centre, arms raised', 0);
INSERT INTO 'dancecrib' VALUES (4329, '2013-08-21 08:30:47.384404+00', '2023-02-04 01:18:49.590541+00', 645, 3, NULL, 'ace', '{{title}}
Fig 1

1-8::
    All cross RH, all cross back RH
9-16::
    All circle 8H round to left
17-24::
    All turn partners 2H into Sq.Set (1s at top, 4s at bottom 2s on
    Ladies'' side & 3s on Men''s side Ladies on partner''s right) & all
    dance 1/2 Grand Chain
25-32::
    1s+4s dance 1/2 R&L, 2s+4s dance 1/2 R&L

{{title}}
Fig 2

1-8::
    All dance double reels of 4 (Ladies give LH in centre to start as
    Men set)
9-16::
    All set & turn corners 2H, set & turn partners 2H
17-32::
    All dance full Schiehallion Reel

{{title}}
Fig 3

1-4::
    1s change places with 4s dancing under 4s arch & 1/2 turn corners
    with free hand
5-8::
    1L+4M change places with 1M+4L dancing under 1M+4L arch & 1/2 turn
    corners with free hand
9-16::
    Repeat bars 1-8
17-24::
    All turn partners 2H approx twice to original places & all Adv+Ret
25-32::
    All circle 8H round to left', 0);
INSERT INTO 'dancecrib' VALUES (4330, '2013-08-21 08:30:47.394268+00', '2023-02-04 01:18:49.615993+00', 8102, 3, NULL, 'ace', '1-8::
    1s & 3s dance down for 2 steps, turn 2H, dance up to top, turn 2H to
    face 2s/4s who step in
9-16::
    1s+2s also 3s+4s dance the Rondel.  2 1 4 3
17-24::
    All set, 2s+1s also 4s+3s 1/2 R&L, all cross RH.  1 2 3 4
25-32::
    1M+2L change places RH, 1s change pl LH with dancers diag to left,
    1s change pl RH with dancers diag to right & 1L+4M change places LH
33-40::
    All Adv+Ret & turn 2H 1.1/2 times.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4332, '2013-08-21 08:30:47.414141+00', '2023-02-04 01:18:49.73412+00', 684, 3, NULL, 'ace', '{{title}}
Figure 1

1-8::
    All Men pull back RSh & dance Fig of 8 round corner & partner (RSh
    to corner to start) _while_ Ladies Adv+Ret twice (1 step in/out
    PdeB)
9-16::
    All turn corners RH & partner LH

{{title}}
Figure 2

17-24::
    1s & 3s cast round anticlockwise, 1L dances behind 4M+4L & in front
    of 4L+4M & round 4M to face him _while_ 1M dances behind & round 4M
    & behind 4M+4L & round to face her _while_ 3s dance similarly round
    2s
25-32::
    All set twice & turn opposite person RH
33-40::
    All dance RSh reels of 4 across
41-48::
    1s+4s also 3s+2s dance RH across & LH back ending in each others
    place
49-80::
    2s & 4s repeat above Figs bars 17-48 all ending in opposite places

{{title}}
Figure 3

81-88::
    All Men set advancing to join hands in circle, Men continue setting
    _while_ Ladies set advancing to join hands in front of Men as Men
    bring their arms over behind Ladies & Ladies bring arms over behind
    Men into Basket Fig
89-96::
    All circle left 1/2 way, set _while_ Ladies bringing arms over Men &
    Men bring arms over Ladies, all retire setting to original places
97-104::
    All dance 1/2 Grand Chain
105-112::
    All Promenade anticlockwise 1/2 way, set twice with Lady turning
    under Man''s right arm into centre on second setting for bow/curtsey', 0);
INSERT INTO 'dancecrib' VALUES (4333, '2013-08-21 08:30:47.424177+00', '2023-02-04 01:18:49.76756+00', 652, 3, NULL, 'ace', '1-8::
    1s full turn RH, lead down below 3s (2s step up 3-4), 1s cast up to
    2nd place & turn LH 1.1/4 times to face 1st corners
9-16::
    1s dance reels of 3 across with 2s & 3s (start LSh to 1st corner),
    1s turn RH on bar 12 to continue partner''s reel & end facing 1st
    corners
17-20::
    1s change places RH with 1st corners _while_ 2nd corners set, 1st
    corners 3/4 turn LH in centre _while_ 1s+2nd corners chase cl''wise
    to next corner
21-24::
    1s change places RH with 1st corner persons _while_ 2nd corners set,
    1s turn LH 1.1/4 times to face 1st crnr pstns _while_ crnrs chase
    cl''wise to next crnr
25-32::
    1s dance 1/2 diag reel of 4 with 1st corner (pstn) & 1/2 reel with
    2nd corner (pstn) & passing RSh cross to own side', 0);
INSERT INTO 'dancecrib' VALUES (4334, '2013-08-21 08:30:47.434134+00', '2023-02-04 01:18:49.799499+00', 654, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reels of 3 on own sides
17-24::
    1s lead down, cross & dance out on opp sides between 2s & 3s, cast
    down round 3s, lead up to top, cross & cast to 2nd place on own
    sides
25-32::
    2s+1s+3s dance 6H round & back
33-40::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (2201, '2012-01-22 19:29:25.541662+00', '2021-10-11 22:40:57.197611+00', 10459, 1, NULL, 'ace', '1–::

  1c turn RH | cast off (2c up) ; cross LH | cast L to 1M/1W between 2c/3c

9–::

  In facing lines of three A[1]&R[1] | change places RH ; A[1]&R[1] | 2c+3c change back, 1c turn RH to face 1cnr

17–::

  Cnrs Pass and Turn (BH), 1c pass RSh to (2,1,3)

25–::

  All circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (4336, '2013-08-21 08:30:47.462769+00', '2023-02-04 01:18:50.039279+00', 656, 3, NULL, 'ace', '1-8::
    1s cross RH, set, cast to 3rd place & 2s+3s+1s set
9-16::
    1s cast up to 2nd place, 2s+1s+3s set on sides, 1s lead up to top,
    cross to original places & 1s+2s set
17-24::
    1M+2L turn RH, 1L+2M turn LH
25-32::
    1s+2s dance RH across for 3 steps, LH back & 1s cast to 2nd place as
    2s lead up', 0);
INSERT INTO 'dancecrib' VALUES (4337, '2013-08-21 08:30:47.471126+00', '2023-02-04 01:18:50.074617+00', 658, 3, NULL, 'ace', '1-8::
    (8 bar introduction) All stand for 4 bars then bow & curtsey to
    Partner & to Corner
9-16::
    1s+3s lead into centre & lead opposite person through side couples,
    cross, cast to meet partner & turn RH to end with Lady on Man''s left
17-24::
    2s+4s repeat & end with Men facing out
25-32::
    All dance full interlocking Reels of 4 across giving LH in centre,
    ending with Ladies dancing clockwise round outside of set to meet
    next Man as Men dance anticlockwise (from LH across) to meet next
    Lady
33-38::
    Men turn new partner RH into Allemande hold, dance round
    anticlockwise 1/2 way & turn Ladies to face them (as ordinary
    allemande)
39-40::
    All cast round to right passing original partner & turn in to face
    them
41-48::
    All dance Grand Chain
49-56::
    All set to partners & turn 2H opening into 4H round (1s+4s & 2s+3s)
    opening into
57-64::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4338, '2013-08-21 08:30:47.480979+00', '2023-02-04 01:18:50.102328+00', 660, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place (2s step up); 1s turn LH into 1st place
    own side (2s step down)
9-16::
    1s+2s set & dance RH across 1/2 way, 1s+3s set & dance LH across 1/2
    way.  (2)(3) 1
17-24::
    3s+1s turn LH 1.1/2 times on sides, 2s+1s+3s turn partners RH 1.1/2
    times & 1s end facing 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting ending with Petronella turn to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (4340, '2013-08-21 08:30:47.500659+00', '2023-02-04 01:18:50.388502+00', 665, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance 1/2 R&L giving hands on sides to start,
    2L+1L+4M+3M dance 1/2 reel of 4 on diagonal
9-16::
    Repeat with all dancing 1/2 R&L as before & 1M+2M+3L+4L dancing 1/2
    reel of 4 on diagonal.  End 4 3 2 1 on opposite sides
17-24::
    2s+3s (centre couples) circle 4H once round to left, flowing into
    1/2 RH across. 4s+2s (top couples) dance 1/2 LH across
25-32::
    All turn partners twice right arm (elbow grip); 1s+2s set to
    partners & change places LH _while_ 3s+4s set to each other & change
    places LH on sides to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4341, '2013-08-21 08:30:47.508728+00', '2023-02-04 01:18:50.399349+00', 670, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s cast to 4th place _while_ 4s lead up to top, 4s+2s also 3s+1s
    dance 1/2 R&L
9-16::
    4s+1s dance 1/2 RH across, 2s+1s also 4s+3s dance 1/2 LH across;
    1L+2L & 3M+4M change pl RH, 1M+2M & 3L+4L change pl RH.  (2) 1 4 (3)

{{title}}
Reel

17-24::
    2s cast to 4th place _while_ 3s lead up to top (both couples on
    opposite sides), 3s+1s also 4s+2s dance 1/2 R&L
25-32::
    3s+2s dance 1/2 RH across, 1s+2s also 3s+4s dance 1/2 LH across,
    1s+4s+3s dance 1/2 reel of 3 on own sides (1s dance in to start)', 0);
INSERT INTO 'dancecrib' VALUES (4342, '2013-08-21 08:30:47.591961+00', '2023-02-04 01:18:50.540991+00', 671, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance 1/2 reels of 3 Lady with 2s & Man with
    3s
9-16::
    1s dance 1/2 reels of 3 on sides, 1/2 reels across Man with top
    couple (3s) & Lady with bottom couple ending 2nd place own sides
17-24::
    3s+1s+2s set & 3s+1s dance 1/2 RH across as 2s cross RH, 1s+3s+2s
    set & 3s+2s dance 1/2 LH across as 1s cross LH to original places
25-32::
    1L casts 1 place & crosses to 2nd M place as 2M casts up & cross to
    1L place, 1s+2s set & petronella turn to right to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4343, '2013-08-21 08:30:47.640713+00', '2023-02-04 01:18:50.56437+00', 674, 3, NULL, 'ace', '1-8::
    1s+2s 3/4 turn 2H to form line up/down centre & dance 1/2 reel of 4,
    3/4 turn partners 2H to own sides (having changed places)
9-16::
    1s set adv to ptnr & turn 1st corner 2H ending 1L between 2s & 1M
    between 3s, 1s set adv to partner &  turn 2nd crnr 2H ending 2nd
    place opp sides
17-24::
    2s+1s+3s cross RH & 1s cast to right round 3rd corner (pstns)
    _while_ corners turn right about & Adv+Ret (on diagonal), 2s+1s+3s
    cross RH (up/down set), 1s cast to right round 4th corner (pstns) &
    in to face them as 2s+3s turn right about & Adv+Ret
25-32::
    1s dance 1/2 RSh reel of 4 with 4th corner (pstns), pass LSh & dance
    1/2 reel with 3rd corner (pstns) & turn RH back to place', 0);
INSERT INTO 'dancecrib' VALUES (4344, '2013-08-21 08:30:47.654724+00', '2023-02-04 01:18:50.588061+00', 13586, 3, NULL, 'ace', '1-8::
    1s dance down below 3s & cast up behind 3s, dance up between 2s &
    cast to 2nd place
9-16::
    2s+1s+3s 1/2 turn partner 2H & twirl to opposite place, all circle
    6H round to left 3/4 way into lines across (Men facing down at top)
17-20::
    1s change places RH & cast right to 2nd place own side _while_ (bar
    19) 3M+2L change places diagonally RH
21-24::
    1s cross RH & cast right into middle _while_ (bar 23) 2M+3L change
    places RH all end in lines across (Ladies facing down, Men up)
25-32::
    All 1/2 turn partner 2H & twirl to opposite place, all circle 6H
    round to left to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4350, '2013-08-21 08:30:47.707715+00', '2023-02-04 01:18:50.772146+00', 11913, 3, NULL, 'ace', '1-8::
    All 1/2 turn & twirl to opposite sides, 1s & 3s dance 1/2 Fig of 8
    round couple below
9-16::
    1s+2s also 3s+4s dance Ladies'' Chain ending with Ladies passing LSh
    to face partner
17-24::
    All dance diag reels of 4 across with Ladies ending besides partner
    on sides
25-32::
    All set & 1s+2s also 3s+4s petronella-in-tandem, all set (facing
    across) & cross RH
33-40::
    1s cast as 2s cross up RH, 3s cast up as 1s cross down RH, 1s cast
    down as 4s cross up RH & 1s cross RH
41-48::
    2s+3s also 4s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (15215, '2022-11-03 01:18:47.571222+00', '2023-02-04 01:18:50.810147+00', 21118, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole:
::
    _1- 2_   1s+2s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _3- 4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5- 8_   2s turn RH as 1s turn LH
9-16::
    All set & turn 2H & chase clockwise 1/2 way round (3) (1) (2)
17-24::
    1s dance Fig of 8 on own sides, passing 4th corners (pstn) RSh to
    begin  (3) 1 (2)
25-28::
    1s dance 1/2 diagonal R&L with 1st corners (pstn). On bar 28 1s
    dance in to finish BtoB facing 4th corners (pstn)
29-32::
    1s dance 1/2 diagonal reel of 4 with 4th corners (1s & corners pass
    LSh to begin)', 0);
INSERT INTO 'dancecrib' VALUES (4352, '2013-08-21 08:30:47.725612+00', '2023-02-04 01:18:50.881819+00', 687, 3, NULL, 'ace', '1-8::
    All Adv+Ret, 1M+2M+3M dance DoSiDo diagonally with 2L+3L+4L _while_
    1L & 4M cross & cast to each others place
9-16::
    1L dances reel of 3 with 3M+4L giving RSh to 4L _while_ 4M similarly
    reel with 1M+2L, 4M+1L 3/4 turn LH to face 2M & 3L as others set
    diagonally
17-24::
    2M+1L+4M+3L dance reel of 4
25-32::
    1L casts up round 1M into prom hold as 4M casts down round 4L into
    prom hold, 1s+4s dance across & cast 1 pl to end BtoB 1s facing up &
    4s dn
33-40::
    1s & 4s lead to ends, cross to own sides & cast in 1 place, 1M+4M
    also 1L+4L turn 1.1/2 times to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4353, '2013-08-21 08:30:47.733616+00', '2023-02-04 01:18:50.913233+00', 689, 3, NULL, 'ace', '1-4::
    1s+2s+3s set ending with Men facing up & Ladies down, set passing
    partners BtoB & dance out to opposite sides
5-8::
    Repeat back to places with Men facing down & Ladies up
9-16::
    1s+2s+3s circle 6H round & back
17-24::
    1s set, cast behind 2s, dance down between 3s & cast up to 2nd
    places
25-32::
    1s (prom hold) dance up _while_ 2s cast into centre & 1s+2s dance
    Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4348, '2013-08-21 08:30:47.6913+00', '2023-02-04 01:20:48.352753+00', 3528, 3, NULL, 'ace', '1-8::
    1M bows to 2L & dances reel of 3 with 3s giving LSh to 3L (1M ending
    in 2nd place)
9-16::
    1L bows to 2M & dances reel of 3 with 3s giving RSh to 3M (1L ending
    in 2nd place)
17-24::
    1s dance reels of 3 across, 1L with 2s & 1M with 3s (1s end in 2nd
    places)
25-32::
    1s dance Fig of 8 round 2s (casting up to start)', 0);
INSERT INTO 'dancecrib' VALUES (7884, '2013-08-21 08:31:50.539734+00', '2023-02-04 01:23:09.547604+00', 7027, 3, NULL, 'ace', '1-8::
    1L+3M 1/2 Turn & Twirl to change pl _while_ partners cross & cast
    behind 2s to change pl, 1M+3L 1/2 Turn & Twirl _while_ ptnrs cross &
    cast back to pl
9-16::
    1s & 3s cast, meet in 2nd place & set _while_ 2s petronella turn
    into middle & set, 2s circle 3H round (Lady with 1s & Man with 3s)
    ending 1s & 3s BtoB facing 2L/2M
17-24::
    1s & 3s dance up/down making an arch for 2s, 1s & 3s turn inwards to
    face down/up & set _while_ 2s turn LH, 2s dance RH across (Lady with
    2s & Man with 3s) & end in original places
25-32::
    1s+2s facing on sides 1/2 turn 2H, set facing partners & dance RH
    across', 0);
INSERT INTO 'dancecrib' VALUES (8546, '2015-02-13 12:47:28.217745+00', '2023-02-04 01:18:46.330507+00', 15639, 3, NULL, 'ace', '1-8::
    1L followed by 1M casts 1 place, dances across to 2nd place opp.
    sides (2s step up 3-4).  1L+2M also 1M+2L turn RH
9-16::
    1L followed by 1M casts down 1 place, dances across to 3rd place own
    sides (3s step up 11-12).  1M+3M also 1L+3L turn LH
17-24::
    1s set, dance up middle, finish back to back facing own sides 2nd
    place (3s step down 19-20) 2s+1s+3s dance 4 bars Double Triangles
25-32::
    1L casts up round 2M, thru 2s as 1M casts down round 3L, thru 3s to
    2nd place own sides.  2s+1s+3s turn RH (1L remains facing out to
    repeat)', 0);
INSERT INTO 'dancecrib' VALUES (8052, '2013-10-01 08:46:33.400331+00', '2023-02-04 01:18:51.069599+00', 15056, 3, NULL, 'ace', '{{title}}
Strathspey

1-4::
    All dance 1/2 Grand Chain
5-8::
    All turn RH into Allemande hold & Promenade 1/2 way anticlockwise to
    orig.places & on bar 8 Men lead partner in front of them & all stay
    in circle facing anticlockwise
9-12::
    All chase anticlockwise & on bar 12 all pivot Right (Ladies 1/2
    turn, Men full turn)
13-16::
    Ladies chase clockwise back to original places on outside as Men
    chase anticlockwise 1.1/4 times on inside to end Men BtoB in the
    middle facing Ladies on outside
17-24::
    All dance DoSiDo with facing person, Ladies dance (Glasgow
    Highlanders step) as Men dance RSh round next lady on right & into
    centre to face following Lady on  right
25-32::
    Repeat with Men dancing round partner & remain in front of partner
33-40::
    All set to partner & 3/4 turn partner 2H, All pivot Right & dance
    round partner (no hands) to end in original. places, Ladies facing
    out
41-56::
    All dance Schiehallion Reels
57-64::
    All circle left & right

{{title}}
Reel

::
    Repeat in reel time, Ladies dancing PdB & Spring points instead of
    Glasgow Highlanders Step & on Bars 33-40 all dance Tulloch turn with
    partners', 0);
INSERT INTO 'dancecrib' VALUES (4354, '2013-08-21 08:30:47.743775+00', '2023-02-04 01:18:51.095931+00', 691, 3, NULL, 'ace', '1-8::
    All circle round once to left, advance into centre & turning inwards
    dance out to places & turn away from each other
9-16::
    1L crosses in front of 1M to dance reels of 3 (Man with 3s - LSh to
    3L & Lady with 2s - RSh to 2M)
17-24::
    1L crosses in front of 1M to dance reels of 3 (Man with 2s - RSh to
    2M & Lady with 3s - LSh to 3L)
25-32::
    1s & 3L+2M change places 1s dancing under arch made by 2M+3L & cross
    to new position, repeat with Ladies in 2nd place dancing under arch
    made by 2M+3M & cross
33-40::
    Dancers in 3rd place dance under arch made by 3s & cross (all now in
    original places), all set to partners & turn RH
41-48::
    All dance Grand Chain ending with Ladies BtoB in centre facing
    partners
49-56::
    All set & 1/2 turn RH, Ladies dance clockwise 1 place into centre
    BtoB _while_ partners follow & face them
57-64::
    All repeat bars 49-56 to end facing partners 2 3 1
65-72::
    All set & 1/2 turn RH, all chase clockwise to partners original
    place & 1/2 turn RH to end with Ladies facing out for…
73-84::
    All dance "Schiehallion"-like reels through all 3 positions giving
    RH across in centre (12 bars)
85-88::
    All turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (4355, '2013-08-21 08:30:47.755805+00', '2023-02-04 01:18:51.266285+00', 12404, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, lead down between 3s & cast up & turn LH
    to face 1st corners
9-20::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s meet again in
    middle & pass RSh (1L/1M face up/down)
21-24::
    1s dance LH across (Lady with 3s at top & Man with 2s) ending 2nd
    place opposite sides
25-32::
    All chase anticlockwise 1/2 way & circle 6H all the way round to
    left', 0);
INSERT INTO 'dancecrib' VALUES (12536, '2020-02-02 02:47:00.865368+00', '2023-02-04 01:18:51.29884+00', 19359, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left; 1s+2s turn partner 2H & face up, 1s
    cast to end facing 1st corners as 2s dance up to 1st place  2 1 3
9-16::
    1s turn 1st corner 1.1/2 RH; 1s+1st corners dance 1/2 diag reel of 4
17-20::
    1s followed by 1st corners chase clockwise 1/2 round, corners end
    back in place, 1s pass RSh to face 2nd corners
::
    _while_ 2nd corners Adv+Ret
21-32::
    1s+2nd coners repeat 9-20 with 1st corners Adv+Ret (bars 29-32). 1s
    pass RSh to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4359, '2013-08-21 08:30:47.786544+00', '2023-02-04 01:18:51.403129+00', 699, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1M dances RH across with 2s _while_ 1L
    dances RH across with 3s
9-16::
    1s dance out round 4th crnrs & dance RH across on sides (1M with
    2L+3L & 1L with 2M+3M) end retaining hold of 1st crnrs
17-24::
    1s (holding LH) Bal-in-Line with 1st corners; 1s turn LH 1.1/4 times
    to Bal-in-Line with 2nd corners
25-32::
    1M dances LSh reel of 3 with 2s _while_ 1L dances LSh reel of 3 with
    3s; 1s cross RH back to place', 0);
INSERT INTO 'dancecrib' VALUES (4361, '2013-08-21 08:30:47.802699+00', '2023-02-04 01:18:51.445958+00', 702, 3, NULL, 'ace', '1-8::
    1M dances Fig of 8 round 1L+2L dancing between them & down behind
    2L, round & up behind partner back to place _while_ 2M dances Fig of
    8 round 1L+2L out between them & up behind 1L, round & behind
    partner back to place
9-16::
    1L & 2L repeat
17-24::
    1s+2s set diagonally, 1M+2L change pls RH _while_ 1L+2M set, 1L+2M
    change pls RH _while_ 1M+2L set, 2s cross RH _while_ 1s turn RH down
    to 3rd pl
25-32::
    3s+1s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4362, '2013-08-21 08:30:47.81088+00', '2023-02-04 01:18:51.474134+00', 7353, 3, NULL, 'ace', '1-8::
    1s turn RH, 1L followed by partner dances down behind 2L & crosses
    to opposite sides
9-16::
    2s+1s+3s circle 6H round & back
17-24::
    1s & 3s dance ''Mirror'' Allemandes (1s up & 3s down) to change places
    (3s on opp sides):
::
    _17-18_   1s & 3s 1/2 turn RH into allemande hold, 1s facing up & 3s
    down, 1s & 3s curve to their left 1s down M side & 3s up the L side
::
    _19-24_   3s & 1s dance bars 3-8 of an allemande ending with 3s in
    2nd place on partner''s side & 1s in 3rd place
25-32::
    All petronella turn into centre, 3s set _while_ 1s & 2s change
    places RH (in centre), all petronella turn to own sides & set', 0);
INSERT INTO 'dancecrib' VALUES (15124, '2022-10-03 12:59:42.146742+00', '2022-10-03 14:27:59.266978+00', 21028, 1, 202, 'ace', '1--::
  Reels4 on sides (1,2,3,4)
9--::
  1c & 2c set up/down | 1c cross to 2plx _while_ 2c dance up to 1pl (to 2,1x,3,4); 1c & 3c repeat [9-12] (2,3,1,4)
17--::
  1c & 4c repeat [9-12] (to 2,3,4,1x) ; 2c & 3c & 4c turn P RH _while{4}_ 1c turn P RH 1½ (2,3,4,1)
25--::
  Circle8 and back (2,3,4,1)

*Deviser''s note* : Bars 21-24. Dancers may use birl instead of tum. Birl, in this dance, is danced with partner. Each couple, using right elbow grip, dance a pivot turn to finish on own sides.
', 4);
INSERT INTO 'dancecrib' VALUES (13518, '2021-01-09 01:18:45.489669+00', '2023-02-04 01:18:51.499849+00', 17689, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place (2s step up 3-4), 1s cross LH & cast to
    left to end in lines across (1L between 2s facing down & 1M between
    3s facing up)
9-16::
    1L+2s Adv+Ret & set _while_ 1M+3s set & Adv+Ret, 1s dance Petronella
    turn to 2nd place opposite sides
17-24::
    1s cross down to dance reflection reels of 3 on own sides (1L & 3L
    pass LSh, 1M & 3M pass RSh)
25-32::
    All circle 6H round & back 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4363, '2013-08-21 08:30:47.820695+00', '2023-02-04 01:18:51.525556+00', 710, 3, NULL, 'ace', '1-8::
    1s & 4s set & cast inward, 1s & 4s turn RH 1.1/2 times into prom
    hold facing other couple
9-16::
    1s & 4s set twice & turn right to face nearest corner, set to corner
    & set to next corner (to right)
17-24::
    1s & 4s dance RSh reels of 3 across with 2s/3s & end passing other
    couple LSh to face up/down NHJ
25-32::
    Set to 2s/3s & turn corners with free hands & all set on sides.  2 4
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (13042, '2020-08-10 00:18:43.151918+00', '2023-02-04 01:18:51.548968+00', 16789, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH; set & cross LH to finish facing partner 2H
    joined ready for …
9-16::
    1s+2s dance »Borders Poussette«:
::
    _9-13_   Normal poussette (all PdeB, Men start Right foot)
::
    _14_      1s+2s 1/4 turn into line up/down centre (2L 2M 1L 1M)
::
    _15-16_  1s+2s pull back RSh & cast to own sides, 1s face out
17-24::
    RSh reels of 3 on sides, 1M up (RSh to 2M) 1L down (RSh to 3L),
    corners dance loops at end, 1s face 2nd corners
25-32::
    1s+2nd corners dance LH Corner Pass+Turn (1s pass corners LSh,
    corner turn LH); 1s pass LSh to face 1st corners, 1s+1st corners
    dance LH Corner Pass+Turn, 1s pass LSh to 2nd place own side.  End 2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (9351, '2016-10-06 07:18:08.664913+00', '2023-02-04 01:18:51.611479+00', 17229, 3, NULL, 'ace', '1-8::
    1s dance down, cast up round 3s, turn LH, finish in centre 1M facing
    3s, 1L facing 2s (2s step up 3-4)
9-16::
    1M+3s & 1L+2s dance 1/2 RH across (2 bars), all drop hands & 1s lead
    chase clockwise to finish in lines of 3 across, Ladies at top facing
    down, Men in 3rd place facing up
17-24::
    All advance, set turning Right about.  2L followed by 1L+3L also 3M
    followed by 1M+2M dance down/up own sides to 3 1 2 (2L pull back RSh
    to face up)
25-32::
    _1/2_ RSh reels on sides (1L+2L, 1M+3M pass RSh to start), 1s turn
    LH to 2nd place own side, 2s+1s+3s set.', 0);
INSERT INTO 'dancecrib' VALUES (4365, '2013-08-21 08:30:47.838493+00', '2023-02-04 01:18:51.640356+00', 713, 3, NULL, 'ace', '{{explanation}}
Round the Room in 3 Couple Circles

1-8::
    All circle 6H round & back
9-16::
    All Adv+Ret (into centre of circle) & dance DoSiDo with partner
17-24::
    All dance RH across, Lady with hand is underneath dances out under
    arch into prom hold with new ptnr followed by next Lady etc
25-32::
    All Promenade with new partners anywhere round the room & hopefully
    meet with another 2 couples to start again', 0);
INSERT INTO 'dancecrib' VALUES (8053, '2013-10-01 08:46:33.513669+00', '2023-02-04 01:18:51.680565+00', 11303, 3, NULL, 'ace', '1-8::
    1s cross down RH 2 places (2s up) & cast up 1 place, 1s dance 1/2
    Fig of 8 (L up M down) to face 1st corner
9-16::
    1s dance RSh round 1st corner & pass RSh to face 4th corner _while_
    the cnrs turn RH & pass RSh to change places,1s repeat with 4th cnrs
    & end facing 3rd corners
17-24::
    1s dance ''Hello-Goodbye'' setting to end  (3)(1)(2)
25-32::
    All Set+Link for 3 twice', 0);
INSERT INTO 'dancecrib' VALUES (4366, '2013-08-21 08:30:47.846541+00', '2023-02-04 01:18:51.705791+00', 715, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All dance RH across & LH back
9-16::
    All dance R&L
17-24::
    Dance 1/2 Ladies'' Chain, set to new partners & turn 2H
25-32::
    All dance DoSiDo with opposite person (previous partner), set & pass
    RSh to face next couple
::
    Men continue round the room with changing partners _while_ Ladies
    move back & forth', 0);
INSERT INTO 'dancecrib' VALUES (14725, '2022-04-01 00:18:50.424172+00', '2023-02-04 01:18:51.767414+00', 18308, 3, NULL, 'ace', '1-4::
    1s+2s also 3s+4s dance 3 bars of Poussette & all turn partner 3/4
    2H, 1s+4s end in diagonal line ready for 1/2 Poussete _while_ 2s &
    3s end facing partner in centre
5-8::
    1s+4s dance 1/2 Poussette to face down NHJ _while_ bar 5 2s Retire
    then stand bars 6-8.  2 4 1 3
9-12::
    4s+1s+3s dance 1/2 mirror reels of 3 on sides (1s in/down to start)
13-16::
    2s+3s+1s dance 1/2 mirror reels of 3 on sides (1s dance in/up to
    start). 1 3 2 4
17-24::
    All set & 1/2 turn partner 2H; all set to partner, 1s+3s also 2s+4s
    circle 4H 1/2 round to left.  3 1 4 2
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4368, '2013-08-21 08:30:47.864393+00', '2023-02-04 01:18:51.803086+00', 721, 3, NULL, 'ace', '1-8::
    1L & 3L cross down & cast RSh round 2M/4M into centre to face them,
    set turning to left & dance back to places
9-16::
    1M & 3M cross down & cast LSh round 2L/4L into centre to face them,
    set turning to right & dance back to places
17-24::
    All circle 8H round & back
25-32::
    1s+2s change places on sides (Ladies RH & Men LH), 1s dancing down
    dance RSh round each other (no hands) to 3rd place opposite sides as
    3s cast up, 1s cast to 4th place as 4s dance up & 1s cross RH.  2 3
    4 1', 0);
INSERT INTO 'dancecrib' VALUES (4369, '2013-08-21 08:30:47.87259+00', '2023-02-04 01:18:51.844369+00', 722, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cross down _while_ 2s cast up, 1M+2L & 1L+3M turn LH &
    1s pass LSh to face 1st corners
9-16::
    1s dance a form of Pass+Turn with 1st corners (1s dance to corner,
    face in & set _while_ 1st corners dance in & turn RH 1.1/2 times,
    corners continue to opposite sides & set _while_ 1s dance in & turn
    1.1/2 RH to face 2nd corners
17-24::
    1s repeat with 2nd corners & end facing 3rd corner (1st corner
    person)
25-32::
    1s+3rd corners dance 1/2 diagonal reel of 4, pass RSh & dance 1/2
    diagonal reel with 4th corners & end crossing LSh to opposite sides
33-40::
    1s dance RH across on sides (1M+2L+3L & 1L+2M+3M), 1M dances up & 1L
    down to dance LH across (Man with 2s & Lady+3s), 1s end in 2nd pl', 0);
INSERT INTO 'dancecrib' VALUES (13733, '2021-03-02 01:18:54.260946+00', '2023-02-04 01:18:51.870963+00', 12153, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up 3-4), 1s NHJ dance down & cast up round 3s
    to 2nd place own side
9-12::
    1s set advancing & turn right about to face out _while_ 2s & 3s
    chase clockwise 1/2 way round & stay facing clockwise
13-16::
    1s join hands with corners (corners give RH to 1s), all dance 1/2
    way round set (1s using Pas de Basque, corners use skip change)
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & cross LH to own
    side
25-32::
    All circle 6H round & back. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4313, '2013-08-21 08:30:47.13103+00', '2023-02-04 01:18:48.624139+00', 610, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s lead down the middle & up to top
17-24::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4370, '2013-08-21 08:30:47.880684+00', '2023-02-04 01:18:51.891535+00', 203, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up), turn LH and cast 1 place
9-16::
    1s dance down 2 steps, 1/2 turn 2H to face up, dance up NHJ to end
    BtoB between 2s, 1M facing 2L, 1L facing 2M
17-24::
    1s+2s dance reel of 4 across.  1s cross down to 2nd place opp sides
    facing out
25-32::
    2s+1s+3s dance mirror reels of 3 on sides (1s out/down, 3s in/up to
    start)
33-36::
    1s 1/2 turn 3s (1L+3M LH, 1M+3L RH), 1s cross up to 2nd place
    _while_ 3s dance to 3rd place
37-40::
    1s turn 2s (1L+2L LH, 1M+2M RH).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4373, '2013-08-21 08:30:47.906877+00', '2023-02-04 01:18:51.962476+00', 9454, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance LH across (Lady with 2s & Man with
    3s)
9-16::
    1s dance 1/2 reels of 3 on sides (giving RSh to 2nd corners to
    start) & 1/2 LSh reel of 3 across (Man with 3s at top & Lady with
    2s)
17-24::
    1s turn LH to face 4th corner (pstn) & dance RSh round them _while_
    4th corners change places with a 1/2 turn & ''twirl''
25-32::
    1s turn RH to face 1st corner (pstn) & dance RSh round them to end
    in 2nd places _while_ 1st corners change places with a 1/2 turn &
    ''twirl''', 0);
INSERT INTO 'dancecrib' VALUES (4374, '2013-08-21 08:30:47.915206+00', '2023-02-04 01:18:51.991848+00', 9455, 3, NULL, 'ace', '1-8::
    1M+3L & 1L+3M 1/2 turn RH & set, 2s+4s making arches Adv+Ret as 1L
    followed by 1M also 3L followed by 3M dance under arch & chase
    anticlockwise to opposite places
9-16::
    1M+3L & 1L+3M 1/2 turn LH & set, 2s+4s making arches Adv+Ret as 1M
    followed by 1L also 3M followed by 3L dance under arch & chase
    clockwise to own places
17-24::
    2M+4L & 2L+4M 1/2 turn LH _while_ 1s+3s chase clockwise 1 place
    round the set to join hands across the set (1M+4L+2M+3L &
    1L+4M+2L+3M) & Bal-in-Line, ends turn in & Bal-in-Line again
25-32::
    All dance reels of 4 across
33-40::
    4L followed by 4M & 2L followed by 2M dance clockwise around outside
    to own places _while_ 1M followed by 1L & 3M followed by 3L dance RH
    across to place & all turn RH
41-48::
    All circle 8H round & back

{{explanation}}
Repeat with 2s & 4s as dancing couples', 0);
INSERT INTO 'dancecrib' VALUES (4375, '2013-08-21 08:30:47.923307+00', '2023-02-04 01:18:52.034036+00', 8624, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, set & cross back RH with 1s+2s end ready
    for…
9-16::
    1s+2s dance Allemande
17-24::
    1s dance RH across (1L with 2s & 1M+3s) & end Men facing up, Ladies
    dn, 2s+1s+3s dance 1/2 LSh reels of 3 on sides (2M & 3L cast to
    start)
25-32::
    1s dance LH across (1M+3s at top, 1L+2s) & end Men facing dn, Ladies
    up, 2s+1s+3s dance 1/2 RSh reels of 3 on sides (2M & 3L cast to
    start)', 0);
INSERT INTO 'dancecrib' VALUES (14641, '2022-03-07 02:18:42.350996+00', '2023-02-04 01:18:52.070608+00', 20405, 3, NULL, 'ace', '1-8::
    1s cross RH, cast and turn 1.3.4 LH to finish in middle facing opp
    sides (2s step up 3-4)
9-16::
    1M+2s also 1L+3s dance RH across, 1s pass RSh and dance LH across
    with other couples to finish facing 1st corners
17-40::
    Dance to Corners & Set: (24 bars)
::
    ''Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars). Repeat 10 more times to end
    with all back in place & 1s in the middle 2nd place Rsh to RSh with
    partner (1M facing up, 1L down)
41-48::
    1s dance figure of 8 on own sides, 1M+2M & 1L+3L pass LSh to start.
    1s end in 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14898, '2022-06-27 00:18:52.038175+00', '2023-02-04 01:18:52.107381+00', 20881, 3, NULL, 'ace', '1-8::
    1s+2s dance Rose Progression:
::
    _1-2_   1M+2L set as 1L+2M change places RH
::
    _3-4_   1M+2L 1/2 turn 2H as 2M & 1L dance into partner''s place
::
    _5-6_   2L+1M cast into each other''s place as 1L+2M 1/2 turn 2H
::
    _7-8_   2L & 1M dance into 1st/2nd places own sides as 2M & 1L cast
    to right
9-16::
    2s+1s+3s turn partners 2H, 1s remaining in centre NHJ facing up; 1s
    dance up & cast to 2nd place own side
17-22::
    2s+1s+3s dance mirror reels of 3 on the sides, (2s out/down, 1s
    in/down & 3s out/up), 2s end in 1st place
23-24::
    1s+3s continue path of reel, 1s dancing down, _while_ 3s cast up to
    end 2 3 1
25-32::
    All set, circle 6H round to left, all dance into centre, pull back
    RSh & spiral out to own sides. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (14364, '2021-10-11 22:38:58.028648+00', '2023-02-04 01:18:52.129282+00', 15530, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s
9-16::
    2s+1s dance Slip Knot - as the Knot but on last 2 bars 1s+2s dance
    LH across 1/2 way to end 2 1 3
17-24::
    2s+1s+3s dance Set+Link for 3 couples twice
25-28::
    1s pass LSh & dance 1/2 diag reel of 4 giving RSh to 3rd corner
    (pstn)
29-32::
    1s pass LSh & dance 1/2 diag reel of 4 giving RSh to 4th corner
    (pstn).  1s end in 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (4376, '2013-08-21 08:30:47.933132+00', '2023-02-04 01:18:52.157515+00', 726, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, set & cross RH
9-16::
    All dance 1/2 reflection reels of 3 on sides (1s out & down), 1s+3s
    circle 4H round to left _while_ 2s set & cross RH
17-24::
    All dance 1/2 reflection reels of 3 on sides (1s in & down), 1s+3s
    circle 4H round to left _while_ 2s set & cross RH
25-32::
    1s petronella turn into lines across & all set, 1s turn RH & cast
    RSh round 4th corners (pstn) _while_ 2s+3s change places RH on
    sides.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4378, '2013-08-21 08:30:47.954607+00', '2023-02-04 01:18:52.211383+00', 10070, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Figs of 8 (Man round 3s & Lady
    round 2s)
9-16::
    1s turn 2nd corner RH & return to place facing in, 1s turn 1st
    corner RH & return to place facing out
17-24::
    2s+1s+3s dance reels of 3 on own sides giving RSh to 3rd corner
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10625, '2018-04-16 21:41:31.67247+00', '2023-02-04 01:18:52.245016+00', 18226, 3, NULL, 'ace', '1-8::
    All set, 1s+2s also 3s+4s dance 1/2 RH across, all set, 1s+4s dance
    1/2 RH across.  Couples in 1st/3rd place face down, 2nd/4th place
    face up
9-16::
    All petronella turn into lines across & set; all dance 1/2 reels of
    4 across
17-24::
    All petronella turn to sidelines & set; all dance 1/2 reels of 4 on
    sides.  All face in (3L & 2M  pull back RSh)
25-32::
    End couples (3s & 2s) cross RH.  All circle 8H 3/4 round to Left.
    Finish in lines across 2 4 1 3

{{explanation}}
Devised for demonstration - dance 2x Strathspey, 2x Reel.  After 2nd time through all opposite original place, 4th time through back in start place', 0);
INSERT INTO 'dancecrib' VALUES (4379, '2013-08-21 08:30:47.962757+00', '2023-02-04 01:18:52.267187+00', 729, 3, NULL, 'ace', '1-8::
    1s cross over below 2s, cast down behind 3s, cross up above 3s &
    cast up behind 2s back to place
9-12::
    1s+2s+3s set, 1M+2M & 2L+3L Petronella-in-tandem _while_ 1L casts
    down & 3M casts up (into circle formation)
13-16::
    1L+3M change places RH _while_ 2s & 3s set, 1M+2M & 2L+3L
    Petronella-in-tandem to opp sides _while_ 1L casts up & 3M casts
    down
17-24::
    3L+2L & 2M+1M set _while_ 3M+1L change places RH, 1s+2s+3s circle 6H
    round to left 1/2 way back to places, 1s+2s+3s turn RH into prom
    hold
25-32::
    1s+2s+3s Promenade round & end with 1s casting to 2nd place _while_
    2s lead up to top', 0);
INSERT INTO 'dancecrib' VALUES (4381, '2013-08-21 08:30:47.97864+00', '2023-02-04 01:18:52.309329+00', 11390, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & 1s 1/2 turn RH as 2s+3s dance 1/2 RH Across, 1s+3s+2s
    chase clockwise 1/2 way
9-16::
    2M+1L turn RH, 2L+1M turn LH
17-24::
    1L+5M turn LH, 1M+5L turn RH
25-32::
    1s+4s+5s set & 1s 1/2 turn LH as 4s+5s dance 1/2 LH Across, 1s+5s+4s
    chase anticlockwise 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (4382, '2013-08-21 08:30:47.988405+00', '2023-02-04 01:18:52.334026+00', 732, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All set, cross RH, 1s+2s set & dance LH across 1/2 way as 3s+4s set
    & cross back LH
9-16::
    1s cross RH, cast to 3rd place (3s step up 11-12), 1s turn twice LH
    to face 1st corners
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners & turn RH to face 2nd corners again
25-32::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corners to
    start, 1s cross down LH to 4th place as 4s cast up to 3rd place
33-64::
    2s repeat 1-32

{{explanation}}
Reel	3s then 4s repeat bars 1-32 above', 0);
INSERT INTO 'dancecrib' VALUES (13043, '2020-08-10 00:18:44.586594+00', '2023-02-04 01:18:52.402276+00', 735, 3, NULL, 'ace', '1-8::
    1s cross down, dance out between 2s & 3s, dance down behind opp line
    (2s step up 3-4); 1s turn away from each other, dance up & cross RH
    through 2nd place to own side facing out.  2 1 3
9-16::
    Reels of 3 on sides (1s RSh to dancer on Right).  1s end BtoB in
    centre facing own sides
17-24::
    2s+1s+3s dance Double Triangles, 1s end in 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4384, '2013-08-21 08:30:48.039769+00', '2023-02-04 01:18:52.526921+00', 738, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, set & cast 1 place (Lady up & Man down)
9-16::
    1s dance reels of 3 on ''diagonals'' (1M with 2L+3L, LSh to 2L to
    start; 1L with 3M+2M, LSh to 3M to start; 2M+3L dance straight
    across set to enter reels)
17-24::
    1s pass RSh to dance reel of 3 on own sides (1M RSh to 2M, 1L RSh to
    3L to start) 1s dance extra loop to end facing 1st corners
25-32::
    1s set to & turn 1st corner, set to & turn 2nd corner, finish in
    middle nearer hands joined facing men''s side (1L on 1M LH side)
33-40::
    1s dance out between 2M+3M, cast round nearer corner, meet in
    centre, dance out on Ladies'' side, cast round nearer crnr & dance to
    2nd pl', 1);
INSERT INTO 'dancecrib' VALUES (4385, '2013-08-21 08:30:48.053713+00', '2023-02-04 01:18:52.678467+00', 739, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, 2s+1s circle 4H round to the left
9-16::
    1s dance up to top, cast 1 place, dance down between 3s & cast up to
    face 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s dance reels of 3 on the sides with corners (LSh to 1st corners to
    start) & 1s cross RH to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (4386, '2013-08-21 08:30:48.063547+00', '2023-02-04 01:18:52.71644+00', 741, 3, NULL, 'ace', '{{explanation}}
Longwise set

1-8::
    1s+2s dance RH across & 1s cast 1 place as 2s lead up
9-16::
    1s+3s dance RH across & 1s cast 1 place as 3s lead up
17-24::
    1s lead up to top, cast to 2nd place, lead down & cast round 3s to
    2nd place own sides
25-32::
    1s pass RSh, dance out on opposite sides, cast round 1st corner,
    turn RH, dance out ends & cast round 4th corner to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4387, '2013-08-21 08:30:48.073575+00', '2023-02-04 01:18:52.8756+00', 742, 3, NULL, 'ace', '{{title}}
Part A

1-8::
    All set to partner, set to corner, set to partner & turn partner 2H
    to finish in 2 diag lines with Men BtoB facing partner (1s+4s &
    2s+3s)
9-16::
    1s+4s also 2s+3s dance diagonal reels of 4.  Men end BtoB in centre
    of diagonal lines again
17-24::
    Chorus: All set to partners HS & turn 2H twice to original places

{{title}}
Part B

25-32::
    1s lead out between 4s _while_ 3s lead out between 2s, divide & cast
    to 1s facing 3s & all set HS
33-40::
    1s+3s (centre couples) turn person opposite 2H twice, Men lead
    partners out through side couples back to places
41-56::
    2s & 4s repeat bars 25-40
57-64::
    Chorus

{{title}}
Part C

65-80::
    1s dance to 4s & circle 4H round to left, pick up 3s & circle 6H
    round, pick up 2s & circle 8H round to end back in places
81-88::
    1s+4s also 2s+3s dance RH across & LH back
89-96::
    1s+4s also 2s+3s dance Ladies'' Chain
97-104::
    Chorus

{{title}}
Part D

105-112::
    All Ladies Adv+Ret (2 steps each) _while_  Men stand (2 bars) then
    dance into middle to face partner; all set & turn partners back to
    places
113-120::
    All dance Grand Chain
121-128::
    Chorus', 0);
INSERT INTO 'dancecrib' VALUES (4390, '2013-08-21 08:30:48.100311+00', '2023-02-04 01:18:53.019553+00', 750, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s turn LH to face 1st corners
9-16::
    1s set then turn corners 2H & face 2nd corners, 1s set then turn
    corners 2H & end between corners
17-24::
    1s dance reels of 3 on opposite sides (LSh to 1st corner to start)
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4391, '2013-08-21 08:30:48.19626+00', '2023-02-04 01:18:53.191054+00', 751, 3, NULL, 'ace', '{{explanation}}
Start in Glasgow Highlanders pstn

{{title}}
Strathspey

1-8::
    All circle 8H round & back
9-16::
    1s+2s & 3s+4s dance RH across & LH back
17-24::
    All set HS & turn partners twice round to places
25-32::
    All dance reels of 4 on sides
33-40::
    All advance into set & retire, turn partners RH

{{title}}
Reel	Clap

1-8::
    All circle 8H round & back
9-16::
    1s+2s & 3s+4s dance R&L
17-24::
    All coupe PdB with partners
25-32::
    All dance reels of 4 across dance
33-40::
    All dance Grand Chain', 0);
INSERT INTO 'dancecrib' VALUES (4392, '2013-08-21 08:30:48.215132+00', '2023-02-04 01:18:53.317498+00', 753, 3, NULL, 'ace', '1-8::
    1s cross RH, cast for 2 steps (2s cast on bar 3 & follow 1s), 2s+1s
    turn outwards, cast up, 2s+1s turn on sides (LH Ladies'' side & RH on
    Men''s) to end in line across 1s in centre all facing down
9-16::
    1s+2s dance down the middle & back, 1s move ahead & cast to 2nd
    place opp sides as 2s dance to 1st place
17-24::
    2s+1s dance a Ladies'' Chain
25-32::
    1s dance 1/2 Fig of 8 round 2s then 2s+1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4393, '2013-08-21 08:30:48.223416+00', '2023-02-04 01:18:53.339895+00', 12631, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH to face 1st corners
9-16::
    1s dance 1/2 diagonal reel of with 1st corners & pass RSh to face
    2nd crnrs, 1s dance 1/2 reel with 2nd crnrs & end with 1s giving RH
    cross to 2nd pl.
17-24::
    3s+1s+2s chase clockwise 1/2 way, 1s dance RH across (1L with 2s &
    1M with 3s) 1s passing LSh on Bar 24 to cross to 2nd place.
25-32::
    1s dance reels of 3 on sides (LSh to 2nd corners) & end passing RSh
    to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (9352, '2016-10-06 07:18:08.960576+00', '2023-02-04 01:18:53.549578+00', 14813, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up) & petronella turn (1L between 2s
    facing down, 1M between 3s facing up).  1s set as 2L+3M change
    places RH
9-12::
    1s petronella turn to 2nd place opp sides. 1s set as 2M+3L change
    places RH.  All now on opp sides (3) (1) (2)
13-24::
    3s+1s+2s dance R&L for 3 couples (omit polite turn bar 24)
25-32::
    3s+1s+2s turn RH to Ladies facing up, Men facing down & all chase
    clockwise 1/2 way.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15264, '2022-11-26 09:07:22.672863+00', '2022-12-01 14:53:22.793346+00', 20736, 1, 1645, 'ace', '1--::

  1c & 3c petronella to midline | set ; petronella to opp sides | set (1x,2,3x,4)

9--::

  2c & 4c repeat (1x,2x,3x,4x)

17--::

  1c+2c &frac12; R&L ; 1c+3c set | &frac12; Circle4 to L

25--::

  1c+4c &frac12; R&L ; all turn P BH (2,3,4,1)

::

  *Crib derived from the video*

', 2);
INSERT INTO 'dancecrib' VALUES (4396, '2013-08-21 08:30:48.25268+00', '2023-02-04 01:18:53.691879+00', 761, 3, NULL, 'ace', '{{explanation}}
Circle, Man has Lady on his right

1-8::
    All circle round & back
9-16::
    All advance 2 steps & retire twice
17-24::
    All turn partners RH once round to face next dancer, turn new
    partner LH 1.1/4 times & face anticlockwise in prom hold (Lady on
    Mans right)
25-32::
    All Promenade & end in circle to repeat', 0);
INSERT INTO 'dancecrib' VALUES (14365, '2021-10-11 22:38:59.70916+00', '2023-02-04 01:18:53.790381+00', 20487, 3, NULL, 'ace', '1-8::
    1s dance down middle (2s step up 3-4); 1s turn 2H (2 bars) & dance
    up to 2nd place remaining in centre. 2s & 3s step in bar 8
9-16::
    2s+1s+3s dance Allemande
17-24::
    3s+1s+2s dance Set+Link for 3 couples twice. (2) (1) (3)
25-32::
    1L+2s (at top) & 1M+3s dance 1/2 RSh reels of 3 across; 2s+1s+3s
    turn partners 2H', 0);
INSERT INTO 'dancecrib' VALUES (4398, '2013-08-21 08:30:48.269265+00', '2023-02-04 01:18:53.820248+00', 13353, 3, NULL, 'ace', '1-4::
    1s+3s set to partner & 1/2 turn RH
5-8::
    1L+3L followed by prtnrs chase 1/4 round set clockwise & dance in
    passing 2s/4s RSh into middle curving in to face 2s/4s
9-16::
    All dance parallel reels of 4 across but 1s & 3s dance only 3/4 reel
    & chase out to original places on bars 15-16
17-24::
    1s+3s dance R&L & end Man behind partner facing Ladies corner
    (4M/2M)
25-32::
    All dance Alternating Tandem reels of 3 across ending in original
    places
33-64::
    2s+4s repeat bars 1-32 (with reels up/down set)
65-72::
    All Set+Link, all Ladies dance (anticlockwise) in front of partner &
    behind next Man to opposite (Mans) place
73-80::
    All Set+Link with ''new'' partner, all Men dance (anticlockwise) in
    front of ''new'' partner & behind next Lady to opposite (Ladies) place
81-88::
    All Ladies dance RH across, Men dance LH across but end in BtoB in
    middle facing partner
89-96::
    All dance 3/4 double reels of 4 to end Ladies BtoB in middle facing
    partner (in original place) & all turn partners RH ending with a
    bow/curtsy', 0);
INSERT INTO 'dancecrib' VALUES (4400, '2013-08-21 08:30:48.297186+00', '2023-02-04 01:18:53.874957+00', 765, 3, NULL, 'ace', '1-8::
    1L followed by partner dances Fig of 8 round 2M & 3M (dancing
    between them to start) _while_ 4M & partner dance similarly round 2L
    & 3L
9-16::
    1s+2s also 3s+4s dance reels of 4 across set (1M & 2L pass LSh
    _while_ 1L & 2M cast), 1L+2M also 3L+4M turn LH & all end in middle
    (1s & 3s facing down, 2s & 4s up)
17-24::
    1s+2s also 3s+4s dance the Rondel
25-32::
    1s+4s dance 1/2 R&L starting RH on sides, set to partner & cross RH.
    2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14726, '2022-04-01 00:18:52.407242+00', '2023-02-04 01:18:54.105661+00', 20648, 3, NULL, 'ace', '1-4::
    1s+2s set right, 1/4 turn setting with left foot to face down/up on
    sides. 1s 3/4 turn 2s (Men LH, Ladies RH) into line of 4 across in
    1st place (1s BtoB)
5-8::
    1s+2s dance 1/2 reel of 4 across
9-16::
    1s+2s set, 1s pass 2s RSh & cast (1L up/ 1M down), 1s turn RH to
    finish in 2nd place own sides
17-20::
    1s+3s set right, 1/4 turn setting with left foot to face down/up on
    sides. 1s 3/4 turn 3s (Men LH, Ladies RH) into line of 4 across in
    3rd place (1s BtoB)
21-24::
    1s+3s dance 1/2 reel of 4 across
25-28::
    1s+3s set. 1L passes 3L RSh _while_ 1M passes 3M LSh & 1s cast up to
    finish in 2nd place on opposite sides. (2) (1) (3)
29-32::
    2s+1s+3s set & cross RH to own sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4403, '2013-08-21 08:30:48.430899+00', '2023-02-04 01:18:54.182305+00', 768, 3, NULL, 'ace', '1-8::
    1L dances anticlockwise around set back to place _while_ others
    dance RH (touch fingers only) across & 1s cross passing LSH
9-16::
    1s dancing out turn 2s 1.1/2 times on sides with nearer hand, 1s
    turn 3s 1.1/2 times with other hand
17-24::
    1s turn 4s 1.1/2 times with other hand & dance 1/2 Fig of 8 round 4s
25-32::
    2s+3s dance RH across & LH back _while_ 4s+1s dance LH across & RH
    back', 0);
INSERT INTO 'dancecrib' VALUES (4404, '2013-08-21 08:30:48.43903+00', '2023-02-04 01:18:54.200024+00', 769, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place (2s step up); 1s dance LSh round 1st
    corners to 2nd place opp side facing 2nd corners
9-16::
    1s dance 1/2 RSh reel of 3 on sides & dance 1/2 LSh reel of 3 across
    (1M with 3s at top, 1L with the 2s, LSh to 3rd corner position)
17-24::
    1s turn 3/4 LH, turn 3rd corner (pstn) RH & pass RSh to turn 4th
    corner (pstn) RH ending in 2nd pl own side in prom hold with 4th
    corner (pstn)
25-32::
    1s+corners promenade diagonally across (passing RSh) to diag opp
    corner & 1/2 turn to end 1s in 2nd pl opp side, 1s dance 1/2 Diag
    R&L (M up, L down).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8988, '2015-11-30 08:59:31.878247+00', '2023-02-04 01:18:54.253797+00', 12005, 3, NULL, 'ace', '{{explanation}}
Circle, Man has Lady on his right

1-8::
    All clap 2 bars (1-2-3-4) All Adv+Ret, All clap 2 bars (1-2-3-4)
9-16::
    Repeat bars 1-8 but stamp foot instead of clap
17-24::
    All turn partner RH (4 bars) turn partner LH (4 bars) All face
    anticlockwise NHJ
25-32::
    All promenade round & form circle again', 0);
INSERT INTO 'dancecrib' VALUES (4406, '2013-08-21 08:30:48.465744+00', '2023-02-04 01:18:54.396085+00', 773, 3, NULL, 'ace', '1-8::
    1s set, cast to 2nd place, set & cast to 3rd place
9-16::
    1s cross up & dance reel of 3 on opposite sides with 2s+3s & end in
    3rd place opposite sides
17-24::
    1s cross up & dance reel of 3 on own sides & end in 2nd place
    turning partner RH
25-32::
    1s dance reel of 3 across (Lady with 2s & Man with 3s giving RSh to
    4th corner to start), 1s end crossing RH to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (4397, '2013-08-21 08:30:48.26087+00', '2023-02-21 19:31:10.420992+00', 762, 3, NULL, 'ace', '1-8::

    All set & 1s+3s petronella turn into middle, centre couple (1M+3L)

    dance round each other to change places _while_ partners set & 1s+3s

    petronella turn to sides

9-16::

    All set & 1s+3s petronella turn into middle, centre couple (1L+3M)

    dance round each other to change places _while_ partners set & 3s+1s

    3/4 turn LH into prom hold facing up _while_ 2s dance in

17-24::

    3s+2s+1s Promenade & 3s end casting to bottom.  2 1 3

25-32::

    1M+3M turn LH _while_ 1L+3L turn RH, 1M+2M turn RH _while_ 1L+2L

    turn LH', 0);
INSERT INTO 'dancecrib' VALUES (15270, '2022-12-01 16:25:27.538349+00', '2022-12-01 16:28:39.390204+00', 6543, 1, 1645, 'ace', '1--::

  Reels3 on opp sides, all crossing down from the top (1x,2x,3x)

9--::

  1c & 3c turn 1&frac12; RH & form circle with 2c ; all set | M set while passing W on their L across to their R (W petronella in front of M) & reform circle

17--::

  Repeat [13-16] with W passing M in front ; repeat with M passing W in front, ending on sides (2,3x,1)

25--::

  3c+1c set | &frac12; RHA ; 1c set | cross RH (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (15127, '2022-10-04 11:05:41.711954+00', '2022-10-09 09:26:30.704066+00', 21140, 1, 202, 'ace', '1--::
  1c cross RH | cast off (2c up) ; 2c+1W & 1M+3c LHA (2,1x,3)
9--::
  *RSh Snake Pass* : unwind the LHA, 1c leading, pass other snake RSh through 2pl and chase clw (to 3,1x,2) ; all chase clw ½ (2x,1,3x)
17--::
  All set | dance BtoB | 2c & 3c set _while{2}_ 1c turn P RH ¾
25--::
  ½ Reels3 across, 1c RSh to 4cnrs[pos] :  1c continue the reels to 2plx | cross RH (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (8549, '2015-02-13 12:47:29.911642+00', '2023-02-04 01:18:54.542487+00', 15599, 3, NULL, 'ace', '1-8::
    All dance double reels of 4 giving LH in centre (Men start & Ladies
    follow)
9-16::
    All turn partners RH & dance Grand Chain but turning each 2nd person
    RH 1.1/2 times (Men clockwise, Ladies anticlockwise) back to places
17-24::
    All petronella-in-tandem on 1 place anticlockwise & set, all
    petronella on 1 place anticlockwise & set
25-32::
    Set advancing to pass partner LSh & set passing next 3 persons LSh
    to end in original places
33-40::
    All turn partners 2H 1.1/2 times, Ladies dance LH across _while_ Men
    dance clockwise 1/2 way
41-48::
    All turn 2H 1.1/2 times, Men dance LH across _while_ Ladies dance
    clockwise 1/2 way
49-64::
    Repeat bars 33-48', 0);
INSERT INTO 'dancecrib' VALUES (4407, '2013-08-21 08:30:48.49322+00', '2023-02-04 01:18:54.566212+00', 774, 3, NULL, 'ace', '1-10::
    1s & 2s set twice, 1s cast 1 place, cross up & cast to 2nd place
    opposite sides _while_ 2s cross up, cast & cross up to top place own
    sides
11-20::
    2s+1s+3s dance reels of 3 on sides (1s down between 3s to start) &
    1s turn RH to 2nd place opposite sides facing out
21-30::
    1s cast RSh round 1st corners into centre, turn LH 1.1/2 times,
    dance out other end, cast to 2nd place own side & into centre BtoB
    (Lady facing up Man down) _while_ 2s+3s dance R&L ending with 2s &
    3s dancing in to face down/up
31-40::
    2s+1L also 1M+3s circle 3H round to left, 1s dance down/up own side
    & 3H round to left with other cpl to end in 2nd pl on opp side &
    cross RH', 0);
INSERT INTO 'dancecrib' VALUES (4408, '2013-08-21 08:30:48.501487+00', '2023-02-04 01:18:54.592553+00', 776, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 on own sides (giving RSh to 2s)
9-16::
    1L followed by partner cast behind Ladies'' side, 1L dances below 3L
    round & up _while_ 1M dances round 2L to dance up the middle (1M
    leading) to top & cast down behind Men, 1M dances round 3M & 1L
    round 2M
17-24::
    1s dance reels of 3 across (Lady with 2s & Man with 3s) & 1s end
    facing up
25-32::
    1s dance RH across with 2L+3L & LH across with 2M+3M, 1s end 3rd
    place own sides.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13044, '2020-08-10 00:18:45.823697+00', '2023-02-04 01:18:54.756785+00', 17581, 3, NULL, 'ace', '1-8::
    1s dance DoSiDo; 1s dance down NHJ & cast up round 3s to 2nd place
    own side (2s step up 7-8)
9-12::
    1s set advancing passing LSh to face 1st corners & turn corners 3/4
    RH to end 1L between 2s facing down, 1M between 3s facing up
13-16::
    1s repeat 9-12 with 2nd corners to end in 2nd place opp sides
17-20::
    1s repeat 9-12 with 3rd corners to end 1M between 2s facing down, 1L
    between 3s facing up
21-24::
    1s repeat 9-12 with 4th corners to end in 2nd place own side
25-32::
    2s+1s+3s dance DoSiDo; all turn partners RH.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4409, '2013-08-21 08:30:48.509522+00', '2023-02-04 01:18:54.779588+00', 10545, 3, NULL, 'ace', '1-8::
    1s set adv & pass LSh, 1M+2L turn RH as 1L+2M turn LH, 1M+3M turn LH
    as 1L+3L turn RH & 1M+4L turn RH as 1L+4M LH to end 2 3 4 (1)
9-16::
    1s set adv & pass LSh, 1M+4M turn RH as 1L+4L turn LH, 1M+3L turn LH
    as 1L+3M turn RH, 1M+2M turn RH as 1L+2L turn LH & all end orig pl
17-24::
    1s+2s dance the Knot, 1s remain in middle & 3s step in for Poussette
25-32::
    1s+3s dance 1/2 Diamond Poussette, 1s+4s dance 1/2 Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (4411, '2013-08-21 08:30:48.527739+00', '2023-02-04 01:18:54.843258+00', 9456, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s & 1/2 reel of 3 on sides dancing in &
    down to start
9-16::
    1s dance 1/2 Fig of 8 up round 2s & 1/2 reel of 3 on sides dancing
    in & up to start
17-24::
    1s cross RH, cast 1 place, dance RH across (Man with 2s & Lady with
    3s) & cross passing LSh to…
25-32::
    1s circle 3H round to left (Man with 3s & Lady with 2s), 2s+1s+3s
    turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4413, '2013-08-21 08:30:48.547244+00', '2023-02-04 01:18:55.032029+00', 779, 3, NULL, 'ace', '1-8::
    1s+3s dance Petronella to opposite side
9-16::
    1s+2s+3s Adv+Ret, 1s+3s cross RH to own sides, 1s+2s+3s set
17-24::
    1s lead down to bottom & up to 1L between 2s & 1M between 3s facing
    1st corners
25-32::
    1s dance reels of 3 across giving RSh to 1st corner & cross LH to
    2nd place', 0);
INSERT INTO 'dancecrib' VALUES (4414, '2013-08-21 08:30:48.555396+00', '2023-02-04 01:18:55.05579+00', 10650, 3, NULL, 'ace', '{{explanation}}
Start 5s facing 1s

1-8::
    1s+5s dance 1/2 R&L, 1L+2s also 1M+4s dance RH across to end 1s
    facing each other in middle - Man facing down, Lady up
9-16::
    1s set & 1/2 turn RH, 1M+3s also 1L+5s dance LH across ending 1s
    passing LSh to 1M facing 4M & 1L facing 2M
17-24::
    1M+4M+2L also 1L+2M+4L: LSh reels of 3 across ending in lines of 3
    across BtoB facing top & bottom couples
25-32::
    All set & advance 2 steps (5s+3s under arches), all set turning
    about & dance back under arches
33-40::
    1s turn RH & LH in centre _while_ other cpls turn RH & chase
    clockwise 3/4 way round (M leading) to end 2 3 4 5 with 1s in centre
    facing 2s in top pl', 0);
INSERT INTO 'dancecrib' VALUES (4415, '2013-08-21 08:30:48.564604+00', '2023-02-04 01:18:55.082572+00', 780, 3, NULL, 'ace', '1-8::
    1s slip step down below 3s, dance up between 3s & cast up behind 2s
    on own side to place
9-16::
    1s+2s dance Espagnole:
::
    _9-10_    1s+2s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _11-12_  1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _13-16_  2s turn RH as 1s turn LH to face 4th corners
17-24::
    1s dance 1/2 diag RSh reel of 4 with 4th corners, passing RSh dance
    1/2 RSh reel of 4 with 1st crnrs, turn LH to end Man above Lady in
    centre
25-32::
    1s dance RH across (1M with 3s at top & 1L with 2s) ending on
    opposite sides, 3s+1s+2s chase clockwise 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (15125, '2022-10-03 23:01:03.482136+00', '2022-10-03 23:01:23.427755+00', 20012, 1, 202, 'ace', '1--::

  1c+2c set | ½ LHA ; 2c+1c set | ½ RHA (1,2)

9--::

  1c+2c Circle4 and back (1,2)

17--::

  1M+2M & 1W+2W Set&Link twice. On [23-24] 2M & 1W pass RSh to face P on 1diag

25--::

  1c+2c *Hello-Goodbye Poussette* : 1c+2c set R, set L each couple turning 3/8 to the R, to finish in line across | repeat to finish on 2diag ; repeat to finish on midline (2M,2W,1M,1W) | all Petronella turn (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2091, '2012-01-22 19:29:19.274009+00', '2022-10-04 13:31:28.079745+00', 9084, 1, NULL, 'ace', '{{explanation}}

Four dancers, numbered 1,2,3,4 clw, stand in a square facing a fifth dancer in the middle, who faces the gap between numbers 1 and 4



1–::

  1+2+5 RHA ; 3+4+5 LHA

9–::

  5+1+3 Rsh diagonal Reel3

17–::

  5+2+4 Lsh diagonal Reel3

25–::

  dancers 5 & 1 change places passing RSH | 1 & 4 repeat ; 4 & 3 repeat | 3 & 2 repeat, 2 finish in centre and face up. the tracks from one corner to the next should be a smooth curve.', 3);
INSERT INTO 'dancecrib' VALUES (15265, '2022-11-29 07:21:02.046206+00', '2022-11-30 12:22:06.357482+00', 14585, 2, 645, 'ace', '1–4::

  1s+3s dance Set&Link in tandem. To finish. 1s+3s face each other in the centre between 2s/3s.

5–8::

  1s+3s dance Set&Link in tandem and pull RSh at the end. 3L followed by 3M finish between 4M/2L, facing 4M, while 1L followed by 1M finish between 2M/4L, facing 2M.

9–16::

  4M+3s+1s+2M dance a diagonal reel of 4 in tandem passing LSh to start. At the end, 1M+3L & 1L+3M 1/2 turn RH. 3M followed by 3L finish between 2L/4M, facing 2L, while 1M followed by 1L finish between 4L/2M, facing 4L.

17–24::

  2L+3s+1s+4L dance a diagonal reel of 4 in tandem passing RSh to start. At the end, 1M+3L & 1L+3M 1/2 turn LH. 3L followed by 3M finish between 4M/2L, facing 4M, while 1L followed by 1M finish between 2M/4L, facing 2M.



25–28::

  3s dance out & in, 3L round 4L Lsh and 3M round 4M Lsh, while 1s dance out & in, 1L round 2L Lsh and 1M round 2M Lsh.

29–32::

  1L+2L 3M+4M 1M+2M 3L+4L set & 1/2 turn RH.

33–36::

  2s+4s LH across.

37–40::

  2s dance out, 2L passing 1L Rsh and 2M passing 1M Rsh, while 4s dance out, 4L passing 3L Rsh and 4M passing 3M Rsh. 2s+4s chase round set CW to next place.

41–48::

  All 8H round and back. 4123', 0);
INSERT INTO 'dancecrib' VALUES (15247, '2022-11-17 18:39:12.230573+00', '2022-12-01 14:59:18.633036+00', 2814, 1, 1645, 'ace', '1--::

  All set, W adv to P | &frac12; turn RH into allemande hold facing down on M side ;

  4c, others following, dance up centre (4,3,2,1).

  3c & 1c retain allemande hold but on [8] 4c & 2c cross LH to opp side

9--::

  3c with 4c & 1c with 2c Reels3 across, 3c/1c RSh to 4M/2M as 4c/2c cast.

  On [15-16] 3c & 1c change to promhold then separate to own sides as 4c & 2c cast off (3,4x,1,2x)

17--::

  3c+4c & 1c+2c &frac34; DblFig8, 3c & 1c casting to start,

  all pass briefly into allemande hold when crossing up (4x,3,2x,1) |

  4c & 2c &frac12; turn LH _while{2}_ 3c & 1c &frac12; turn RH into allemande hold facing up

25--::

  3c & 1c dance up to top, cross LH & cast off (4,1x,2,3x) | cross RH (4,1,2,3)

', 2);
INSERT INTO 'dancecrib' VALUES (15116, '2022-10-01 09:43:59.706682+00', '2023-01-22 20:52:38.107667+00', 21115, 1, 1645, 'ace', '1--::
  1c & 3c set | turn RH & face out ;
  1c+2c+3c+4c &frac12; mirror Reels4 on the sides, 1c & 3c start out & down & end BtoB on centre line, M facing up, W down (4,3,2,1,5)
9--::
  Double crown triangles, 3c & 1c end in same places
17--::
  3c & 1c &frac12; diag RSh Reels4 with 2cnrs, pass &frac34; LSh to face 1cnrs ; repeat with 1cnrs & face 4cnrs
25--::
  Repeat with 4cnrs, 3c & 1c end on sides (5,3,2,1,4) ;
  3c+2c+1c+4c &frac12; mirror Reels4 on sides, 3c & 1c start in & down. On [31-32] 4c cast up round 5c (who step down) to end in 1pl (4,5,1,2,3)
', 2);
INSERT INTO 'dancecrib' VALUES (3892, '2013-08-21 08:30:38.670436+00', '2023-02-04 01:18:17.548344+00', 13823, 3, NULL, 'ace', '1-8::
    1s dance 1/2 fig 8 round 2s, 1M dances down to face 2L as 1L dances
    down to face 2M & all set
9-16::
    1s+2s dance reel of 4 across
17-24::
    1s+2s set & 1s cast up round 2s to 1st place opposite sides, 1s 1/2
    turn RH & 2s step in ready for…
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (13393, '2020-12-02 01:18:51.408376+00', '2023-02-04 01:18:55.116152+00', 782, 3, NULL, 'ace', '1-4::
    1s lead down middle & cross over to cast up to 2nd place _while_ 2s
    set & cross RH to 3rd place _while_ 3s cast up to 1st place & cross
    RH. (3) (1) (2)
5-8::
    3s+1s+2s turn partner 1.1/2 2H to own sides
9-16::
    3s+1s+2s set, 1s dance reels of 3 across (6 bars, LSh to 1st corner
    (pstn) to start)
17-20::
    3s lead down middle & cross over to cast up to 2nd place _while_ 1s
    set & cross RH to 3rd place _while_ 2s cast up to 1st place & cross
    RH. (2) (3) (1)
21-24::
    2s+3s+1s turn partner 1.1/2 2H to own sides
25-32::
    3s+1s dance the Tourbillon:
::
    _25-28_   3s & 1s 1/2 turn ptnrs 2H, 3M & 1L lead ptnrs by nearer
    hand 1 place cl''wise to end 3s on Ladies side & 1s on Men''s side, 3s
    set to 1s
::
    _29-32_   3s & 1s 1/2 turn ptnrs 2H & lead ptnrs on 1 place
    clockwise & 1s+3s cross RH to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8989, '2015-11-30 08:59:31.974463+00', '2023-02-04 01:18:55.360626+00', 16777, 3, NULL, 'ace', '1-4::
    1s dance in and down, rotate (1M cl''wise, 1L anticl''wise) to face
    down in line between 2s _while_ 2s set & rotate  (2M cl''wise, 2L
    anticl''wise) to face up; 1s+2s Bal-in-Line
5-8::
    2s dance up to 1st place and stand _while_ 1s+3s repeat 1-4, 1s
    turning inwards to face up on bar 8
9-16::
    1s in prom. hold dance 1/2 reel of 3 on Ladies'' side (LSh to 2L), 1s
    dance 1/2 reel of 3 across (RSh to 2M)
17-24::
    1s dance 1/2 reel of 3 on Men''s side (LSh to 3M), 1s dance 1/2
    diagonal reel of 3 (RSh to 2M), 1s end facing in centre between 2s
    (1M facing up, 1L facing down) joining 2H, 3s+2s+4s step up
25-28::
    1s dance down middle 4 PdB steps (as in Poussette - move, 1/2 turn,
    move, 1/2 turn) to 4th place _while_ 3s+2s+4s set; 3s cast 1 place,
    2s dance to top, 4s set rotating (4L cl''wise, 1M anticl''wise)
29-32::
    2s+3s+4s turn RH once round _while_ 1s turn RH 1.1/4 to own sides
    2 3 4 1
::
    Original publication www.minicrib.org.uk/bardill-prince.html', 0);
INSERT INTO 'dancecrib' VALUES (9469, '2016-11-09 08:48:12.810689+00', '2023-02-04 01:18:55.387499+00', 13143, 3, NULL, 'ace', '1-8::
    All 3 couples »Set+Link« twice & face partners
9-16::
    All set, turn partner 3/4 RH.  Ladies join LH in middle, RH with
    partner.  All Bal-in-Line (Highland Schottische)
17-24::
    All dance strathspey »Targe«:
::
    _17-18_   Ladies dance LH across 2 places _while_ Men dance 1 place
    round clockwise
::
    _19-20_   All turn partners RH
::
    _21-24_   Repeat 17-20 End with ladies in centre facing partners
25-28::
    All set Advancing, pass partner, pull back RSh to face & all 3/4
    turn partner 2H to finish on sides
29-32::
    All pass partners RSh, take prom hold with »new« partner facing
    anticlockwise & all dance 1 place round to new place', 0);
INSERT INTO 'dancecrib' VALUES (4416, '2013-08-21 08:30:48.570818+00', '2023-02-04 01:18:55.408825+00', 10288, 3, NULL, 'ace', '1-8::
    All Adv+Ret, all advance to opposite sides Ladies dancing under Mens
    arms
9-16::
    All Adv+Ret, all advance to own sides Ladies dancing under Mens arms
17-24::
    1s slip step to bottom & back
25-32::
    1s followed by 2s+3s+4s+5s cast to bottom & 1s make an arch,
    2s+3s+4s+5s dance under arch & up to new places & make arches
33-40::
    1L dances up under arches as 1M casts to top, 1M dances down under
    arches as 1L casts to bottom
41-48::
    All swing partners', 0);
INSERT INTO 'dancecrib' VALUES (2370, '2012-01-22 19:29:33.901189+00', '2022-10-04 14:46:15.542125+00', 9007, 1, NULL, 'ace', '1–::

  1c+2c set | ½ RHA ; 1c+3c set | ½ LHA (2x,3x,1)

9–::

  2c+1c L-Chain up/down the dance, 1W finishes facing out

17–::

  1W, 1M following, cast to top and cross (2c+3c down) to (1x,2x,3x) ; All set | all turn P RH ½ into centre for

25–::

  1c+2c+3c promenade, at end 1c cast off and 2c dance up (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (4357, '2013-08-21 08:30:47.772219+00', '2023-02-04 01:18:51.358439+00', 696, 3, NULL, 'ace', '1-8::
    1s+2s+3s advance for 2 steps & retire & turn partners RH to end in
    centre for promenade
9-16::
    1s+2s+3s dance Promenade with 1s casting to face 1st corners
17-24::
    1s set to 1st corner, set to partner, set to 2nd corner & set to
    partner to end in 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4417, '2013-08-21 08:30:48.580766+00', '2023-02-04 01:18:55.444699+00', 794, 3, NULL, 'ace', '1-8::
    1s cast below 3s & lead up between to top, cross & cast to meet
    partner facing 2L
9-16::
    1s set to 2L, 3M, 3L then 2M & turn to face 1st corners
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH ending
    in 2nd place opposite sides
25-32::
    2s+1s+3s Adv+Ret & 1s turn with 2H 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (4418, '2013-08-21 08:30:48.588831+00', '2023-02-04 01:18:55.478063+00', 795, 3, NULL, 'ace', '1-8::
    1s+3s set & turn 2H to face up, 3s dance to top & cast back to
    places _while_ 1s cast to 3rd place & lead up LH to face 1st corner
9-16::
    1s 1/2 diagonal reel of 4 _while_ 2s+3s 1/2 R&L (inside the reel),
    1s+1corners 1/2 reel of 4 & 1s pass LSh to face 2nd corner
17-24::
    1s 1/2 diagonal reel of 4 _while_ 2s+3s 1/2 R&L up/down (inside the
    reel), 1s+2nd corners 1/2 reel of 4 & 1s end side by side (LSh)
    facing opp side
25-32::
    2s+1s+3s chase clockwise (1s merge) & turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (4419, '2013-08-21 08:30:48.601374+00', '2023-02-04 01:18:55.628108+00', 796, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on sides (1s in & down to
    start), 1s+2s continue reel to change places & 1s turn to face up on
    outside
9-16::
    All dance 3H across on sides (Ladies LH & Men RH), on bar 10 1s
    cross to join opposite wheel (Lady in front of Man), on bar 13 1s
    cross back to own side to continue wheels & rotate until 1s are at
    the top
17-24::
    1s followed by 3s+2s dance down the middle & back with 3s & 2s
    dividing to dance up behind 1s in order 1 3 2
25-32::
    All dance Allemande to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4420, '2013-08-21 08:30:48.611203+00', '2023-02-04 01:18:55.659393+00', 797, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s dance across & down opposite sides, 1s dance
    1/2 reels of 3 on sides (1M/2M pass RSh & 1L/2L pass LSh to start) &
    end 1s dancing to 2nd place in middle facing out opposite sides & 2s
    to top
9-16::
    Men dance LH across _while_ Ladies dance RH across, 2s change places
    & sides reverse direction ending with 3s changing places & 1s in
    centre facing up
17-24::
    1s lead up, cross & cast to 2nd place own sides, 1s & 3s turn
    partners RH ready for…
25-32::
    1s+3s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4421, '2013-08-21 08:30:48.619289+00', '2023-02-04 01:18:55.689774+00', 10595, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    1s & 4s set, cast in 1 place, dance RH across & end facing corners
9-16::
    All dance 1/2 Schiehallion Reel (2 places)
17-24::
    4s+1s dance LH across, 3s+4s also 1s+2s dance RH across 1/2 way &
    all 1/2 turn RH into…4 3 (2)(1)
25-32::
    4s Allemande to 3rd place (& cross LH) & 1s Allemande to 2nd place
    (& cross LH) _while_ 3s Poussette to 1st pl & 2s Poussette to 4th
    pl.  3 1 (4)(2)', 0);
INSERT INTO 'dancecrib' VALUES (13981, '2021-05-03 00:18:46.29135+00', '2023-02-04 01:18:55.720027+00', 18553, 3, NULL, 'ace', '1-8::
    1s set cross RH, cast off to 2nd place opp sides & turn RH to finish
    in the centre RH joined, facing 1st corners. (2s step up 5-6)
9-12::
    1st set to 1st corners, change places passing RSh; 2M+3L turn 1/4 RH
    to finish in centre with RH joined facing 3M/2L
13-16::
    2L+3L & 2M+3M set to each other & change places passing RSh, 2L+3M
    turn 1/4 RH to finish in centre RH joined facing 1L/1M
17-20::
    1L+2L & 1M+3M set to each other and change places passing RSh
21-24::
    1s turn 1.1/2 RH to face 1st corners (pstn)
25-28::
    1s+2L+3M dance 1/2 diag RSh reel of 4, 1s pass RSh to face 2nd
    corners (pstn)
29-32::
    1s+3L+2M dance 1/2 diag RSh reel of 4, 1s pass RSh to face 3rd
    corners (pstn)
33-36::
    1s+2L+3M dance 1/2 diag RSh reel of 4, 1s join RH on meeting
37-40::
    1s turn 1.1/2 RH to 2nd place own side _while_ 2s & 3s set & cross
    RH to own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4422, '2013-08-21 08:30:48.629125+00', '2023-02-04 01:18:55.758208+00', 803, 3, NULL, 'ace', '1-8::
    1s lead down, cross below 3s & cast back to opposite places, 2s
    following on bar 3 & 3s cross over on bar 5, 1s+2s+3s cross back to
    orig places
9-16::
    1s cast 1 place, cross passing LSh cast round 1st corner to meet in
    centre & turn about into Double triangle position up/down dance
17-24::
    1L with 2s & 1M with 3s set, 1s dance up/down dance & cast round 4th
    corner into Double Triangle position facing own sides & set with
    crnrs
25-32::
    1s dance reels of 3 on own sides passing 4th corner RSh', 0);
INSERT INTO 'dancecrib' VALUES (4423, '2013-08-21 08:30:48.652577+00', '2023-02-04 01:18:55.927804+00', 805, 3, NULL, 'ace', '{{title}}
Part A

1-8::
    1L crosses to 3M, 1L+3M set HS & 1L returns to place
9-16::
    1M repeats with 3L
17-24::
    1s dance Figs of 8 on own sides dancing between 2s to start
25-32::
    2s dance DoSiDo & all set HS

{{title}}
Part B

33-48::
    All dance full Petronella
49-56::
    3s followed by 2s+1s dance down 1 step & cast up on own sides to
    form lines of 6 across facing down with 3s in middle
57-64::
    All cross hands & advance 4 steps, all dance backwards 4 steps, end
    by dropping hands & turning left to place RH on shoulder of person
    in front
65-72::
    1L turns right about & dances in & out under the arms to the other
    end of the line
73-80::
    1M turns left about & dances in & out under the arm to other end of
    the line
81-88::
    1s followed by 2s+3s cast down room & lead up the centre with 1s
    crossing to own sides
89-96::
    1s followed by 2s cast on own sides & lead up under arch made by 3s
    to places', 0);
INSERT INTO 'dancecrib' VALUES (4424, '2013-08-21 08:30:48.660759+00', '2023-02-04 01:18:55.953556+00', 807, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s turn 1.1/2 times on sides (1s & 4s dance inwards),
    1s+4s LH across 1/2 way to face corners & change pls RH with crnrs.
    (4) 2 3 (1)
9-16::
    All dance Grand Chain 1/2 way (starting on sides), all dance 1/2 RSh
    reels of 4 on sides.  4 (2)(3) 1
17-24::
    4s+2s dance 1/2 R&L, 2s+4s dance LH across.  2 (4)(3) 1
25-32::
    4L+3M change places RH, 4M+3L change places RH; 3s+4s dance RH
    across.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4425, '2013-08-21 08:30:48.670454+00', '2023-02-04 01:18:55.985994+00', 8501, 3, NULL, 'ace', '1-8::
    1s & 2s dance double Fig of 8 (1s cross down to start)
9-16::
    1s dance Inveran Reels with 2s+3s
17-24::
    1s cross RH & cast 1 place, 1s dance DoSiDo _while_ 2s+3s dance 1/2
    R&L changing places on sides to start.  3 1 2
25-32::
    3s+1s+2s Set+Link for 3 twice to end on own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4426, '2013-08-21 08:30:48.679618+00', '2023-02-04 01:18:56.019052+00', 810, 3, NULL, 'ace', '1-8::
    All set, turn 2H to face up, dance up & cast to 3 2 1
9-16::
    3s+1s dance double Fig of 8 round 2s (3s cast, 1s cross up)
17-24::
    1s dance in & cast up to 2nd place, 1s circle 3H round to left (1L
    with 3s at top & 1M with 2s).
25-28::
    3s & 2s join NH & make arches & Adv+Ret (up/down set) _while_ 1s
    dance under arches (1L up through 3s, 1M down through 2s) & cast to
    right into 2nd place own side
29-32::
    1s circle 3H round to right (1M with 3s at top & 1L with 2s).  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4427, '2013-08-21 08:30:48.687651+00', '2023-02-21 13:35:31.970736+00', 815, 3, NULL, 'ace', '{{explanation}}

3s & 4s on opp sides



1-8::

    All dance 1/2 reels of 4 on sides, 4s+3s also 2s+1s dance RH across

9-16::

    All dance 1/2 reel of 4 on sides, 2s+3s dance LH across

17-24::

    All Ladies cross passing partner LSh & dance down/up to new places,

    all Men cross passing ptnr RSh & dance down/up to new pl.  3 4

    (1)(2)

25-32::

    4L+1L change places RH & set to each other _while_ 4M+1M set &

    change places RH, 1s+4s circle 4H round to left.  3 1 (4)(2)', 0);
INSERT INTO 'dancecrib' VALUES (15126, '2022-10-04 00:49:01.973204+00', '2022-10-09 07:02:07.298042+00', 21142, 1, 202, 'ace', '*3c & 4c start on opposite sides (1,2,3x,4x)*

1--::

  1W & 4W dance RSh round P, twirl in front of them to face own sides _while{4}_ 1M & 4M stand still | set ; 1c & 4c (both W leading) chase clw ½ to exchanged places. 4W & 1W face out (4,2,3x,1x)

9--::

  Reels4 on sides. 2M & 3M face out (4,2,3x,1x)

17--::

  2c+3c L-Chain (4,2,3x,1x)

25-28::

  All set | turn P RH ¾ to midline

29-36::

  4c+2c & 3c+1c *½ Celtic Reel* : 4c+2c & 3c+1c pass P RSh | "outers" chase clw ¼ _while{2}_ "inners" dance LSh round each other ¾ to face P ; repeat [29-32]

37-40::

  All turn P RH ¾ | set (2,4,1x,3x)', 5);
INSERT INTO 'dancecrib' VALUES (4346, '2013-08-21 08:30:47.671197+00', '2023-02-04 01:18:50.667354+00', 683, 3, NULL, 'ace', '{{explanation}}
4s+5s+6s start on opp sides

1-8::
    1s & 6s turn RH, cast in 1 place & turn LH 1.1/2 times to end BtoB
    facing 2s/5s _while_ 3s+4s dance RH across & LH back to places
9-16::
    1s+2s also 6s+5s dance reels of 4 across to end 1s/6s facing partner
    up/down (Ladies BtoB) _while_ 3s+4s dance reel of 4 across (Men LSh
    & Ladies cast to start)
17-24::
    1s & 6s set, 3/4 turn into prom hold & Promenade round each other
    (RSh) to end on sides between 3s+4s (1s facing 3M & 6s facing 4M)
25-32::
    1s dance reel of 3 on sides with 3M+4L _while_ 6s dance reels with
    4M+3L (1s & 6s end in centre ready for RH across).  2 3 6(1)(4)(5)', 0);
INSERT INTO 'dancecrib' VALUES (4367, '2013-08-21 08:30:47.854553+00', '2023-02-04 01:18:51.733978+00', 719, 3, NULL, 'ace', '1-8::
    1s set, cross RH, 1s+2s Set+Link.
9-16::
    2s+1s set & Petronella-in-Tandem, set & Petronella-in-Tandem.  1 (2)
17-24::
    1L+2M also 1M+2L promenade 3/4 round clockwise (end facing partners
    up/down) & dance RH across
25-32::
    1s & 2s set to partners, 1s 1/2 turn 2H _while_ 2s full turn 2H,
    1s+2s circle left 3/4 round to end 2 1', 0);
INSERT INTO 'dancecrib' VALUES (4428, '2013-08-21 08:30:48.69639+00', '2023-02-04 01:18:56.108438+00', 816, 3, NULL, 'ace', '1-12::
    1s+2s+4s+5s dance RSh reel of 4 on sides (3s stand)
13-16::
    1s+2s & 4s+5s turn RH on sides _while_ 3s turn LH in centre to end
    facing »1st corner couples« (Lady facing 1M+2M & Man facing 4L+5L)
17-24::
    3s dance RH across with 1st corners, pass RSh & dance LH across with
    »2nd corners« (Lady with 4M+5M & Man with 1L+2L)
25-32::
    3s dance out centre of own sides & cast clockwise round 3rd corner
    couple, dance in & pass partner RSh & dance out other end casting
    round 4th corner couple to 3rd place own sides (corner couples
    Adv+Ret to allow 3s to dance behind them)
33-40::
    All circle 10H round & back
41-48::
    2s+3s+4s+5s set & cast up 1 place _while_ 1s set advancing & lead
    down to bottom, all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (8550, '2015-02-13 12:47:30.208+00', '2023-02-04 01:18:56.142442+00', 12681, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig 8 round 2s; 1s turn 2s 1.1/2 times (1M+2L with LH,
    1L+2M with RH), 1s finish in centre in 2nd place, 2s on sides facing
    in
9-16::
    2M+1L+3M dance RH across & LH back as 2L+1M+3L dance LH across & RH
    back. 1s curve away from each other, ready for …
17-20::
    1L+3M turn LH 1.1/2 (4 bars) ; 1M+3L turn RH 1.1/2 (4 bars) to
    finish on sides 2 3 (1)
21-24::
    1s cross up to dance 1/2 Fig 8 round 3s.   2 3 1
25-32::
    2s+1s petronella turn into centre, face ptnr & set; 2s+1s turn ptnr
    2H 1.1/4 to finish on own sides', 0);
INSERT INTO 'dancecrib' VALUES (4429, '2013-08-21 08:30:48.718594+00', '2023-02-04 01:18:56.153862+00', 8143, 3, NULL, 'ace', '{{explanation}}
Round the Room in 3s facing anticlockwise

1-4::
    Nearer hands joined, touch the left heel then the left toe to the
    floor, bouncing on the right foot with each touch, All skip to the
    left for one step. Repeat with opposite feet.
5-8::
    Skip forward for two steps, then backwards for two steps.
9-12::
    All set & Ladies turn under Mans arms
13-16::
    Skip forward for two steps, then backwards for two steps', 0);
INSERT INTO 'dancecrib' VALUES (4432, '2013-08-21 08:30:48.742631+00', '2023-02-04 01:18:56.286192+00', 11260, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    All circle 4H round & back
9-16::
    Couple facing anticlockwise dance between other couple & cast back
    to places & turn RH
17-24::
    Couple facing clockwise repeat 9-16
25-32::
    Progress with alternating arches:  All dance in direction they are
    facing, clockwise couple make arch, dance under arch, make arch,
    dance under arch to meet a new couple', 0);
INSERT INTO 'dancecrib' VALUES (4433, '2013-08-21 08:30:48.754324+00', '2023-02-04 01:18:56.308676+00', 822, 3, NULL, 'ace', '1-8::
    1s followed by 2s dance down the middle, cast up round 3s on own
    sides, dance in & up to top, 1s casting to 2nd place
9-16::
    2s+1s+3s dance Grand Chain (2M & 1L end facing out)
17-24::
    2L+1M turn RH 1.1/2 & dance 1/2 way round clockwise _while_
::
    2M+1L dance 1/2 way round anticlockwise & turn LH 1.1/4 times to end
    facing partners
25-32::
    2s+1s dance diagonal reel of 4 ending on own sides with 1s in 2nd
    place. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4434, '2013-08-21 08:30:48.762712+00', '2023-02-04 01:18:56.329334+00', 13771, 3, NULL, 'ace', '1-8::
    1s dance down (2 bars) & turn 2H (2 bars), 1s dance up & cast to 2nd
    place
9-16::
    2s+1s+3s Set+Link for 3, 1s dance 1/2 Diag R&L starting Diagonally
    left
17-24::
    All Set+Link for 3, 1s dance 1/2 Diag R&L starting Diagonally left.
    (3)(1)(2)
25-32::
    All set & 1/2 turn RH, face partner and pull back RSh, dance out to
    places & set.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4435, '2013-08-21 08:30:48.772581+00', '2023-02-04 01:18:56.353945+00', 10767, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 1s turn RH 1.1/2 times to face 2L
9-16::
    1s set to 2L, turn & set to 3M, set to 3L, turn & set to 2M
17-24::
    1s dance RH across (1M with 2s & 1L with 3s) & LH across with other
    couple
25-32::
    2s+1s+3s dance reels of 3 on own sides', 0);
INSERT INTO 'dancecrib' VALUES (3898, '2013-08-21 08:30:38.752187+00', '2023-02-04 01:18:18.22048+00', 13896, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place, 1s dance down between 3s & cast up to
    2nd place own sides
9-16::
    2s+1s dance 1/2 double Fig 8 (1s cross up), 1s+3s dance 1/2 double
    Fig  8 (1s cross down)
17-20::
    1L+2s also 1M+3s dance RH across 1/2 way & 1s chase clockwise to 2nd
    place own sides
21-32::
    2s+1s+3s dance R&L for 3 couples', 0);
INSERT INTO 'dancecrib' VALUES (4436, '2013-08-21 08:30:48.780591+00', '2023-02-04 01:18:56.376105+00', 11014, 3, NULL, 'ace', '1-8::
    1s & 2s set, 1s cast & dance 1/2 Fig of 8 around 2s
9-16::
    2s+1s+3s dance reflection reels of 3 on side (1s In & down to
    start), 1s pass RSh into double triangle formation
17-24::
    1s dance Double Triangles
25-32::
    1s dance Fig of 8 on own sides', 0);
INSERT INTO 'dancecrib' VALUES (14414, '2021-11-06 01:10:10.756039+00', '2023-02-04 01:18:56.405757+00', 824, 3, NULL, 'ace', '1-8::
    1s+2s+3s Set & Petronella turn to face partner up & down; All 3/4
    turn partner 2H  to opp sides & all Set
9-16::
    All Adv+Ret (1 step each) twice; All turn partner 2H once round
17-24::
    Cross-over Mirror Reels:
::
    1s cross down, 2s out/up, 3s in/up to start. As each couple reaches
    1st place they cross down  to finish reel on own side. End 1s in
    centre NHJ facing down, 2s NHJ facing up, 3s in 3rd place own side
25-32::
    1s+2s dance Rondel', 0);
INSERT INTO 'dancecrib' VALUES (4437, '2013-08-21 08:30:48.789573+00', '2023-02-04 01:18:56.430586+00', 9077, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All set, 1s & 3s cast to 2nd/4th places _while_ 2s & 4s dance in &
    turn to face out to 1s/3s, all dance 1/2 reels of 4 across ending
    with 2s & 4s in centre facing opposite sides _while_ 1s & 3s loop
    round to face anticlockwise
9-16::
    2s & 4s set, dance out to opposite sides _while_ 1s & 3s dance to
    each others places, 1s+3s dance LH across _while_ 2s & 4s chase
    anticlockwise to opposite side (all Ladies on left of Men)
17-20::
    3s & 1s dance anticlockwise 1/2 round to original side _while_ 2s+4s
    dance LH across
21-24::
    All face partner & set, all turn partner RH once round. 2s & 4s take
    prom hold (Lady on Man''s left)
25-32::
    2s+4s in prom hold dance reels of 3 up/down set with corners (2s
    give RSh to 1L, 4s to 3L to start) All on wrong side of partner

{{title}}
Jig

{{explanation}}
Repeat 1-32 with 2s & 4s casting to start, 2s & 3s dance into centre etc.  1s & 3s dance promenade reels across set with partner on right (1s+4M & 3s+2M pass RSh) & all end in original places', 0);
INSERT INTO 'dancecrib' VALUES (4440, '2013-08-21 08:30:48.815876+00', '2023-02-04 01:18:56.509179+00', 8660, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    All dance 4H round to left, turn opposite dancer 2H, turn partners
    2H & end facing partners
9-12::
    All set HS to partners & 3/4 turn dancer on left of partner LH both
    ending in their partners place
13-16::
    All set HS to partner & 3/4 turn dancer on partners right RH both
    ending in their original places
17-24::
    Dance interlocking reels of 4 passing partner RSh ending couple
    facing couple
25-32::
    All dance the Rondel to progress', 0);
INSERT INTO 'dancecrib' VALUES (4441, '2013-08-21 08:30:48.82394+00', '2023-02-04 01:18:56.527719+00', 829, 3, NULL, 'ace', '1-8::
    1s followed by 2s lead down middle, 2s lead up to top _while_ 1s
    cast up behind 3s to 2nd place own sides
9-16::
    2s+1s+3s dance 1/2 reels of 3 on sides (1s in & up to start);
    3s+1s+2s dance 4 bars of Grand Chain (1 bar per hand)
17-24::
    1s+2s dance 1/2 R&L & turn partners 2H, 1s turning 1.1/2 to end
    facing 1st corners
25-32::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH to end
    in middle in 2nd place facing down ready to start again.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4443, '2013-08-21 08:30:48.962615+00', '2023-02-04 01:18:56.573498+00', 833, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s dance 1/2 Fig of 8 round 2s
9-16::
    2s+1s+3s dance a Chain - 1st person RH, 2nd person LH 1.1/2 times,
    3rd person RH & all set.  (3) 1 (2)
17-20::
    All advance for 1 step & turning right about dance out, all chase
    clockwise 1/4 way into lines of across
21-24::
    All advance down/up 1 step & turning right about dance up/down, all
    chase clockwise 1/4 way into sidelines
25-32::
    1s dance RH across & LH back (1M with 2s, 1L with 3s) to end 2nd
    place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4444, '2013-08-21 08:30:48.970617+00', '2023-02-04 01:18:56.600682+00', 8199, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s+3s turn RH
9-16::
    1s set advancing to 2nd corners & turn RH, 1s lead down below 3s
    cross & cast up to 2nd place own sides
17-24::
    1s set advancing to 1st corners & turn LH, 1s lead up to top cross &
    cast to 2nd place own sides
25-32::
    2s+1s dance R&L', 3);
INSERT INTO 'dancecrib' VALUES (4445, '2013-08-21 08:30:48.9787+00', '2023-02-04 01:18:56.636798+00', 10642, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s turn LH to face 1st corners
9-16::
    Dance Pass+Turn with corners & end turning LH to face opposite sides
17-24::
    1s dance RH across (1L with 2s, 1M with 3s), 1s dance LH across (1L
    with 3s, 1M with 2s), & end facing 1st corners,
25-32::
    1s dance Hello-Goodbye setting & petronella turn to 2nd place own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (4447, '2013-08-21 08:30:49.005711+00', '2023-02-04 01:18:56.81701+00', 9458, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    All dance Men''s Chain
9-16::
    Ladies pass opposite Man LSh, cast & turn other Lady RH 1.1/2 times
    back to place
17-24::
    Men pass opposite Lady RSh, cast & turn other Man LH 1.1/2 times
    back to place
25-32::
    All set, dance RH across & cross RH to meet next couple', 0);
INSERT INTO 'dancecrib' VALUES (4448, '2013-08-21 08:30:49.015504+00', '2023-02-04 01:18:56.846131+00', 841, 3, NULL, 'ace', '1-8::
    1s set twice, 1s facing 2s set twice to each other on sides
9-16::
    1s+2s+3s dance RSh reels of 3 on sides
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4449, '2013-08-21 08:30:49.023451+00', '2023-02-04 01:18:56.871609+00', 7355, 3, NULL, 'ace', '1-8::
    1s followed by 2s lead down, cross below 4s & dance to place on
    opposite sides
9-16::
    4s followed by 3s lead up LH, cross above 1s & dance down to place
    on opposite sides
17-24::
    All dance RSh reels of 4 on sides
25-32::
    1s lead down to 4th place, all set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (15271, '2022-12-02 09:59:17.362004+00', '2022-12-02 15:36:48.503266+00', 13396, 1, 202, 'ace', '1--::
  1c set | cross RH ; cast off (2c up) | 1c turn P LH ½ finishing in centre LSh to P
9--::
  All W & All M RHA ; 1c dance RSh round 4cnrs[pos] to 2pl centre, LSh to P facing opposite sides _while{4}_ 2W+3W & 2M+3M change places RH and face diagonally | 3c&2c set
17--::
  3c+1W & 1M+2c RHA ; 1c dance RSh round 1cnrs[pos] into facing lines3 across _while{4}_ 3c&2c turn P RH ½ and face diagonally | 3c&2c set
25--::
  All advance to centre, joining H briefly | retire ; 1c turn P RH 1¼ to 2pl _while{4}_ 3c+2c chase clw ½ (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (4450, '2013-08-21 08:30:49.031655+00', '2023-02-04 01:18:56.90257+00', 14944, 3, NULL, 'ace', '1-4::
    All set & Ladies Petronella turn into centre to face next Man,
5-8::
    All set & turn RH 1/2 way & Men move on to face own partner (all Men
    in centre)
9-12::
    All turn partners RH 1/2 way & Ladies dance LH across 1/2 way
    _while_ Men dance clockwise 1/2 way round to meet partners
13-16::
    All turn partners RH 1/2 way & Men dance LH across 1/2 way _while_
    Ladies dance clockwise 1/2 way round to meet partners
17-24::
    All dance intersecting reels of 4 (pass partner RSh to start & all
    giving LH in centre)
25-32::
    All Promenade anticlockwise round to end in new positions 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4451, '2013-08-21 08:30:49.039983+00', '2023-02-04 01:18:56.945523+00', 842, 3, NULL, 'ace', '1-8::
    1s+2s advance for 2 steps & retire, cross RH & dance 4H round to
    left 1/2 way
9-16::
    1s+3s dance 4H round to right 1/2 way & cross LH, 3s & 1s set & 1s
    lead up to 2nd place as 3s cast
17-24::
    1s set & cast (Lady up above 2s & Man down below 3s) _while_ 2s+3s
    dance RH across, 1s dance LH across with 2s/3s
25-32::
    1s dance reels of 3 across set giving LSh to 1st corner (pstn), 1/2
    turn partner RH to continue reels with other couple & 1s pass RSh to
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (12382, '2019-12-05 01:29:02.503072+00', '2023-02-04 01:18:56.974852+00', 14983, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    1s+3s dance RH across; 2s+1s dance LH across. 1s finish facing 1st
    corner
17-24::
    1s set to and turn 1st corner 2H; opening out (1st corners leading)
    into circle 4H round to Left. 1s finish facing 2nd corners (1st
    corners back in place)
25-32::
    1s repeat 17-24 setting to and turning 2nd corner 2H; opening out
    (2nd corners leading) into circle 4H round to left. End  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4452, '2013-08-21 08:30:49.049762+00', '2023-02-04 01:18:57.013344+00', 13681, 3, NULL, 'ace', '1-6::
    1s+2s also 3s+4s dance RH across 1s & 3s face down, 2s & 4s face up;
    all set
7-8::
    1s cross down to 2nd place opp sides facing out (2s dance up to 1st
    place) _while_ 4s cross up to 3rd place opp sides facing out (3s
    dance down to 4th place)  2 (1) (4) 3
9-12::
    2s+1s turn on sides (2L+1M LH, 2M+1L RH) _while_ 4s+3s turn on sides
    (4M+3L RH, 4L+3M LH)
13-16::
    All dance 1/2 RSh reels of 4 on sides.  3 (4) (1) 2
17-24::
    4s+1s dance 1/2 R&L; 3s & 2s turn partner RH
25-32::
    All circle 8H round & back.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (8551, '2015-02-13 12:47:30.560097+00', '2023-02-04 01:18:57.040047+00', 12682, 3, NULL, 'ace', '1-4::
    1s+2s set, 1s cross down (no hands) to 2nd place opp sides as 2s
    cast up to 1st place.  1M faces down, 1L faces up
5-8::
    1st corners followed by 1s (2M+1L also 3L+1M) dance across passing
    ptnrs (2L/3M) by right and cast, 2M down/3L up (still followed by
    1s) to change places with 1s finishing in 2nd place own sides,
    finish …

{{explanation}}
TOP	2L · 1L · 2M

::
    3L · 1M · 3M
9-16::
    1s set, cross passing LSh.  Repeat bars 5-8 with 2nd cnrs followed
    by 1s (2L+1M also 3M+1L) dancing across, pass opp person by Left,
    cast, 3M up/2L down (still followed by 1s) to change places & 1s
    finish in 2nd place own sides   (3) 1 (2)
17-20::
    1s petronella turn into centre, 1s set as 1st cnrs cross RH to place
21-24::
    1s petronella turn to 2nd place opp sides, 1s set as 2nd cnrs cross
    RH to place & face out
25-32::
    Reels of 3 on sides, 1s pass 2nd cnrs RSh to start (6 bars); 1s
    cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4453, '2013-08-21 08:30:49.057773+00', '2023-02-04 01:18:57.105746+00', 11188, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, 2s followed by 1s dance down between
    3s & cast up (2s to top place & 1s to 2nd place)
9-16::
    1s dance Diag R&L.  (1M down / 1L up)  (3)1(2)
17-24::
    1s dance 1/2 Figs of 8 (1L up round 3s, 1M down round 2s), all 3
    couples set & 1/2 turn partner RH, remaining in centre facing up
    ready for …
25-32::
    3s+1s+2s dance Allemande ending with 1s casting to 3rd place, 3s
    dancing up to 2nd place.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4455, '2013-08-21 08:30:49.073872+00', '2023-02-04 01:18:57.142457+00', 9768, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 2s+1s+3s set & turn partners 2H remaining in the
    middle facing up
9-16::
    2s+1s+3s dance Allemande 1s end facing 1st corners
17-24::
    1s set to 1st corner & turn 2H to face 2nd corner, set to 2nd corner
    & turn 2H to end side by side (LSh to LSh) facing own sides
25-32::
    3s+1s (dancing out)+2s chase clockwise 1/2 way, 2s+1s+3s turn 2H
    1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (4456, '2013-08-21 08:30:49.082044+00', '2023-02-04 01:18:57.162414+00', 9095, 3, NULL, 'ace', '1-8::
    1M followed by partner casts, crosses set below 2s, casts behind 3L
    & dances up middle to above 3s & pulls back RSh to face partner (2s
    step up 3-4, 3s+4s on 7-8)
9-16::
    1s+3s dance 4H round to left, 1s pull back RSh, 1M facing up, 1L
    facing down; 1M+2s also 1L+4s dance RH across
17-20::
    1s+3s dance LH across
21-24::
    3s retain hands & turn to finish 3M in own place & 3L in 2L''s place
::
    _while_ 1L+4L turn RH to end in 3rd & 4th places own sides
::
    _while_ 1M+2M turn RH to end in original places (2 3 4 1 Ladies''
    side & 1 2 3 4 Men''s). All dance in & take promenade hold
25-32::
    All with "new" partners Promenade round for 4 bars (until 1M,
    dancing up, is level with 4M), all drop hands & 1M cast to on own
    side to pick up partner _while_ other Men dance on to meet partners
    & continue Promenade to places.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (10948, '2018-08-08 01:15:24.882637+00', '2019-11-15 00:15:44.290866+00', 18491, 1, 202, 'ace', '1--::

  1c turn RH ; 1c+2c RHA (1,2,3)

9--::

  1c set | cast (2c up) ; 1c turn LH (2,1,3)

17--::

  1c+3c LHA ; 1c set | cast (3c up) (2,3,1)

25--::

  1c Mirror Fig8 on sidelines, starting in and up



*Deviser''s note:  

Alternative for more advanced dancers on [25-32]: Mirror Reels3 on sidelines, 1c starting in and up.*', 2);
INSERT INTO 'dancecrib' VALUES (13882, '2021-04-05 00:18:50.921349+00', '2023-02-04 01:18:57.183665+00', 13206, 3, NULL, 'ace', '1-8::
    1L+2M also 3L+4M cross RH, cast behind partner & dance back to
    place; 1s+2s also 3s+4s dance RH across
9-16::
    1M+2L also 3M+4L cross LH, cast behind partner & dance back to
    place; 1s+2s also 3s+4s dance LH across
17-24::
    All dance Interlocking Double Figs 8:
::
    1s+3s dance double Fig 8 round 2nd place (1s cross down, 3s cast up)
    _while_
::
    2s+4s dance double Fig 8 round 3rd place (2s cross down, 4s cast
    up).  (Dancers crossing down pass those casting up RSh on sides)
25-32::
    All dance 1/2 reels of 4 on sides (4 3 2 1); top 3 Ladies & bottom 3
    Men dance 1/2 reels of 3 on sides. End: Men''s side: 4 1 2 3, Ladies''
    side 2 3 4 1
::
    Repeat 3 more times, each time with new partner.  (Bars 17-24 may be
    easier if danced as Strathspey)', 0);
INSERT INTO 'dancecrib' VALUES (4457, '2013-08-21 08:30:49.091979+00', '2023-02-04 01:18:57.213054+00', 8331, 3, NULL, 'ace', '1-8::
    1s+2s dance Tourbillon :
::
    1s & 2s turn partners 2H 1/2 way, 1M & 2L lead partners on 1 place
    clockwise to end 1s on Ladies'' side & 2s on Men''s side, 1s set to 2s
::
    1s & 2s 1/2 turn partners 2H, 1L & 2M lead partners on 1 place to
    end 2s in 1st pl & 1s in 2nd pl & 2s+1s cross RH to own sides
9-16::
    1s turn 1st corner, partner, 2nd corner & partner to 2 1 3
17-24::
    2s+1s+3s Bubble Up: (ie 2s cast 2 pl _while_ 1s+3s 1/2 turn RH
    moving up 1 pl, repeat from new places 3 times to end (1)(3)2
25-32::
    1s+3s Set+Link _while_ 2s set & cross RH, 3s+1s+2s set & circle 6H
    round to left 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (10523, '2018-03-20 06:26:14.355169+00', '2023-02-04 01:18:57.23923+00', 18245, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up), dance down between 3s & cast up into
    2nd place opp sides
9-16::
    2s+1s+3s Set+Link; 1s turn 1.1/2 RH (or birl) to end RSh to RSh
    facing opp sides (1M above 1L)
17-24::
    1s dance the "Snake Pass": 1s dance LH across (1M with 3s & 1L with
    2s); 1M followed by 3s also 1L followed by 2s pass RSh diagonally
    across through 2nd place to change ends & loop round to right to end
    in 2nd place.  2 1 3
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (7885, '2013-08-21 08:31:50.555062+00', '2023-02-04 01:23:09.585606+00', 7028, 3, NULL, 'ace', '1-8::
    All dance RSh reels of 4 on sides
9-16::
    1s+2s also 3s+4s dance RH across & LH back
17-20::
    All advance 2 steps & retire 2 steps
21-24::
    1M+2L also 1L+2M turn RH (1s pass RSh to turn 2s on sides), 1s turn
    LH in centre
25-32::
    1s repeat bars 21-24 with 3s, then with 4s. 1s end in 4th place own
    side, 2s+3s+4s step up bars 31-32
33-40::
    All turn partners 2H (4 bars), 2s+3s also 4s+1s circle 4H round to
    left into…
41-48::
    All circle 8H round to left to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4458, '2013-08-21 08:30:49.10214+00', '2023-02-04 01:18:57.349854+00', 848, 3, NULL, 'ace', '{{title}}
Part 1

1-8::
    All dance 8H round & back
9-16::
    All dance Grand Chain 1/2 way
17-24::
    Ladies dance into centre & dance RH across with partners on their
    left (St Andrews cross) once round
25-32::
    All dance Grand Chain 1/2 way
33-40::
    Men dance into centre with partners on their right & dance LH across
    once round

{{title}}
Part 2

1-8::
    All circle 7H round & back with 1L in centre who sets
9-16::
    1L sets to partner & turns RH (Elbow grip), sets to opposite Man &
    turns LH
17-24::
    1L sets to M originally on her right & turns LH, sets to opp M &
    turns RH
25-40::
    1L dances reel of 3 with partner & opposite Man (RSh to partner)
    then dances reel with other Men (LSh to M on right), Men raise both
    arms in reel
::
    Repeat with 2L in centre then 3L, 4L, 1M, 2M, 3M & 4M

{{title}}
Part 3

1-40::
    Repeat Part 1', 0);
INSERT INTO 'dancecrib' VALUES (4460, '2013-08-21 08:30:49.12008+00', '2023-02-04 01:18:57.447486+00', 852, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 double Fig of 8 (1s cross down to start), 1s & 2s
    set & cross RH
9-16::
    1s+2s dance Poussette 1s ending back-to-back facing opposite sides
17-24::
    1s dance Double Triangles & end facing 1st corner pstns _while_
    2s+3s set & petronella turn to 1 place anticlockwise, set &
    petronella turn 1 pl
25-32::
    1s dance 1/2 diagonal reel of 4 with 1st corners & 1/2 reel with 2nd
    corners
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9470, '2016-11-09 08:48:13.430421+00', '2023-02-04 01:18:57.486756+00', 14435, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across.  1s+3s set, dance 1/2 LH across  (2)
    (3) 1
9-16::
    Reels of 3 on sides (1M+3L & 1L+3M pass LSh).  1L finishes in 3rd
    place facing out
17-24::
    1L followed by 1M casts up behind 3M & across to 2nd place opp side.
    1s turn LH. (3s step down).    (2) (1) (3)
25-32::
    2s+1s+3s dance down NHJ.  Bar 28 Ladies dance under partner''s arm to
    change sides & all dance back up to place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4462, '2013-08-21 08:30:49.13609+00', '2023-02-04 01:18:57.50335+00', 855, 3, NULL, 'ace', '1-8::
    1s cross down to dance Fig 8 round 2s
9-16::
    2s cross up to dance Fig of 8 round 1s
17-24::
    1s lead down the middle & back to 2nd place (2s step up 19-20)
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (13982, '2021-05-03 00:18:47.96831+00', '2023-02-04 01:18:57.611475+00', 20337, 3, NULL, 'ace', '1-2::
    All Ladies dance LH across 1/2 round _while_ Men cast & dance 1
    place round anticlockwise
3-4::
    All turn RH (3L+4M, 4L+1M, 1L+2M & 2L+3M)
5-6::
    All Men dance LH across 1/2 round _while_ Ladies cast & dance 1
    place round anticlockwise
7-8::
    All turn partner LH
9-16::
    Repeat 1-8 to return to original places
17-24::
    1s+2s also 3s+4s dance 1/2 R&L; 1s+4s also 3s+2s dance 1/2 R&L
25-32::
    1s+2s also 3s+4s dance 1/2 R&L; all turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (4463, '2013-08-21 08:30:49.144404+00', '2023-02-04 01:18:57.631014+00', 857, 3, NULL, 'ace', '1-4::
    Ladies dance LH across passing 1 Man, dance out behind next Man into
    his partners place
5-8::
    Repeat bars 1-4 to meet ''new'' partner
9-16::
    All set, turn ''new'' partner 2H, circle 6H round to left 1 place &
    all set
17-20::
    Men dance RH across passing 1 Lady, dance out behind next Lady into
    her partners place
21-24::
    Repeat bars 17-20 to meet another ''new'' partner
25-32::
    All dance 2 hands of Grand Chain (2 bars per hand), turn own partner
    2H & set.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4464, '2013-08-21 08:30:49.152551+00', '2023-02-04 01:18:57.651917+00', 860, 3, NULL, 'ace', '1-8::
    1M followed by 2M dance up & across to end in centre facing down
    _while_ 2L followed by 1L dance down & across to face partners
::
    1s+2s set; change places RH with partners & chase clockwise to own
    sides having changed places
9-16::
    2s+1s+3s dance 6H round to left for 4 steps; set; dance on 1 more
    step & cast to chase anticlockwise to sides
17-24::
    1M dances LH across with his crnrs 1/2 way; 1M+1L also 3L+2M & 2L+3M
    all turn RH (4 bars); 1M dances LH across with crnrs to places
25-32::
    1L dances RH across with her crnrs 1/2 way; 1M+1L also 3L+2M & 2L+3M
    all turn RH (4 bars); 1L dances RH across with crnrs to places', 0);
INSERT INTO 'dancecrib' VALUES (14791, '2022-05-05 00:18:49.49256+00', '2023-02-04 01:18:57.702888+00', 11437, 3, NULL, 'ace', '1-8::
    4s cast up round 3s, dance in between 2s/3s, dance out between 1s/2s
    to finish above 1s in centre & set. Bar 6 1s step in & raise arms to
    make »broken arch«
9-16::
    4s dance down middle & back
17-24::
    4s cast round 1s (who then step back), dance down middle (3 bars) &
    back up (3 bars)
25-32::
    4s cast round 2s, dance down (2 bars), & back up (2 bars), cast
    round 2s to 3rd place _while_ 3s cast to 4th place.  End 4s in
    middle facing down, 3s in middle facing up
33-40::
    4s+3s Adv+Ret (with »high fives«); 4s+3s dance RH across finishing
    on sides, 4s facing up.  1 2 4 3
41-48::
    4s+2s change places LH, 4s+1s change places RH; all 4 couples
    Adv+Ret (with »high fives«).  End 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (3720, '2013-04-05 07:19:54.864781+00', '2022-10-04 18:51:24.616942+00', 8683, 1, NULL, 'ace', '1–::

  1W dances R loop towards P and back | 1W (1M follows) cast R and cross to 2plx (2c up) | All set (2,1x)

9–::

  1M dances L loop towards P and back | 1M (1W follows) cast L and cross to 1pl (2c down) | All set (1,2)

17–::

  1c two Petronella Turns ; turn RH 1½ (1,2)

25–::

  Poussette (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11117, '2018-09-16 08:12:57.040232+00', '2019-11-01 02:01:37.151106+00', 11546, 1, 202, 'ace', '1--::

  1c Fig8 on sidelines, start inwards (1,2,3)

9--::

  1c followed by 2c+3c lead down, 2c & 3c divide ; 1c turn inwards and lead up, followed by *3c & 2c* into

17--::

  3C Allemande (2,3,1)

25--::

  Circle6 and back', 4);
INSERT INTO 'dancecrib' VALUES (12282, '2019-10-14 12:48:27.722347+00', '2019-11-01 09:39:53.980825+00', 18785, 1, NULL, 'ace', '1--::

  1c cross RH | cast off (2c up) ; ½ Fig8 R and face 1cnr

9--::

  "French Scroll":  1c turn 1cnr RH | 1c followed by 1cnr person turn 4cnr LH ; 1c, with the snake following, cross at the end and chase cclw along the other side, finishing 1c in 2cnr pos and the others behind. (M side:2W,2M,1W / W side:1M,3W,3M)

17--::

  2c+3c ¾ LHA _while{4}_ 1c cross to own side and cast L (to 2,1,3) ; All turn P LH  

25--::

  Reels3{6} on the sides, 1c Lsh to 4cnr | 1c, coming in the ends dance Lsh (gypsy, no hands) round P to (2,1,3)   

', 3);
INSERT INTO 'dancecrib' VALUES (12328, '2019-11-02 00:54:09.086949+00', '2019-11-02 01:33:45.670315+00', 7096, 1, NULL, 'ace', '1--::

  1W+2M set adv | turn RH ; dance through own place and chase clw to P''s place

_while{8}_ 1M+2W wait{4} ; set adv | turn LH to 1diag in middle facing own P

9--::

  Diag Reel4, start Rsh to P, for 6 bars | 1M/2W dance to 2M/1W place _while{2}_ 1M+2W turn LH ¾ to face P on 2diag

17--::

  Rsh Reel4 on 2diag, for 6 bars | 1M+2W finish reel _while{2}_ 1W+2M cast one place clw to (2,1)

25--::

  All chase clw ½ (spiral in) | RHA 1¼ | spiral out clw ¼ to (2,1) 

', 3);
INSERT INTO 'dancecrib' VALUES (12216, '2019-09-15 01:47:03.846766+00', '2019-11-05 01:09:11.390389+00', 1345, 1, 202, 'ace', '1--::

  1c+2c lead down (2c leading) the middle and up (1c leading) ready for (1,2)

9--::

  6 bars of Poussette. On[14] all dance a ¼ turn into midline | 1c & 2c turn P RH

17--::

  Reel4 on midline. 2c+1c face own sides NHJ

25--::

  2c+1c balance | turn P RH ½ ; balance | turn P RH ¾ to sides (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (13046, '2020-08-10 00:18:48.053456+00', '2023-02-04 01:18:57.755642+00', 16788, 3, NULL, 'ace', '1-8::
    1s lead down (3 steps), lead up (3 steps), cross & cast (2s step
    up). 1s face down
9-16::
    2s+1s+3s dance Grand Chain (2s cross at top, 1s+3s change places RH
    on sides to start)
17-24::
    1s cross down, cast up round 3s, dance up & cast to 2nd place own
    side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8552, '2015-02-13 12:47:30.668429+00', '2023-02-04 01:18:57.914872+00', 15612, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    2s+3s dance RH across, 2s+3s dance LH across part way to end 2M
    facing up & 3M down (Ladies on sides) _while_ 1L & 4L petronella
    turn into middle & set
9-16::
    1L+2M+3M+4L dance reel of 4 up/down middle & on Bar 13-16 1M & 4M
    petronella turn to 2nd/3rd place & set to opposite dancer
17-24::
    1M+3L+3M+4M+2L+2M circle anticlockwise & back with 1M & 4M breaking
    away to face partners
25-28::
    1L followed by partner cast down Ladies'' side to 3rd place & crosses
    to opposite side _while_ 4L followed by partner cast up Men''s side
    to 2nd place & crosses to own side _while_ 2s & 3s turn 2H moving
    out to end places.  2 4(1)(3)
29-32::
    All turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (12316, '2019-10-28 16:56:28.901572+00', '2019-11-02 20:43:58.880863+00', 7679, 1, NULL, 'ace', '1--::

  1M+2W & 2M+3W Turn BH ½ and face other pair | set to other pair ; Circle4 L 1¼,  finish with 2c in own place and 1M & 3W in exchanged places

9--::

  1W+2M & 2W+3M Turn BH ½ and face other pair | set to other pair ; pairs together LHA 1¼,  finish (3x,2,1x)

17-20::

  [Two Half Diamond Reels of Four]  

  2c+1cnrs pass Rsh, 2c finish in 1cnr pos as 1cnr persons (=3W+1M) petronella to just in front of 2cnr pos (long steps) forming a diamond shape | all face in diagonally and set, but 1M+3W set {1} and set advancing{1} to finish BtoB on 1diag. facing their original place 

21-24::

  1M+3W passing 2c Rsh dance to original places _while{2}_ 2c petronella turn to face P across the set | 2c set {1} and set advancing{1} to finish BtoB on 2diag facing 2cnrs. 

25-28::

  2c+2cnrs pass Rsh, 2c finish in 2cnr pos as 2cnr persons (=3M+1W) petronella to just in front of 3cnr pos (long steps) forming a diamond shape | all face in diagonally and set, but 3M+1W set {1} and set advancing{1} to finish BtoB on 2diag. facing their original place 

29-32::

  1W+3M passing 2c Rsh dance to original places _while{2}_ 2c dance in turning P LH to face up | 2c dance up to 1pl as 1c casts off (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12335, '2019-11-05 00:31:12.655006+00', '2021-01-04 12:27:43.088331+00', 16940, 1, 202, 'ace', '1--::

  All S&Link and face P ; all set | Petronella Turn. All M BtoB in centre face P

9--::

  All set | change places RH ; all M chase clw ½ _while{4}_ all W LHA. All W BtoB in centre face new person

17--::

  All set | all dance La Baratte. M in centre face clw, W face cclw

25--::

  All W chase cclw ½ _while{4}_ all M RHA ; all turn P LH into promhold and chase clw one place (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12329, '2019-11-03 22:50:31.449491+00', '2019-11-03 22:50:31.449491+00', 13611, 1, NULL, 'ace', '1--::

  1c cross RH | cast (2c up) ; cross LH | cast L round 4cnr to face 1cnr

9--::

  Reels3 across, Rsh to 1cnr

17--::

  In lines across A&R ; 1c cross RH up/down and cast R to (2,1x,3)

25--::

  All A&R ; set | 1c cross RH (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12330, '2019-11-03 23:43:17.678449+00', '2019-11-03 23:44:42.032244+00', 6780, 1, NULL, 'ace', '1--::

  All set | 1c+3c+5c cross RH _while{2}_ 2c+4c set advancing and pivot R to 1diagonal, BtoB with P and facing 3cnr (1x,*2*,3x,*4*,5x) ; ½ diag Reels4 and pass P Rsh to face 4cnr 

9--::

  ½ diag Reels4, 2c+4c finish in own places ; ½ Reels of 3,4,3 across, 2c+4c giving Rsh to 2cnr

17--::

  2c+4c ½ diag R&L with 1cnr (pos) ; with 2cnr (pos) (1,2x,3,4x,5)

25--::

  1c+2c & 3c+4c set and ½ RHA (1W+3W face out) (2,1x,4,3x,5) ; 1W+3W followed by P cast off and cross to own side (4c+5c up) (2,4,1,5,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12332, '2019-11-04 20:24:15.623095+00', '2021-06-09 08:37:35.663512+00', 2077, 1, 202, 'ace', '*3c & 4c start on opposite sides*



1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; ½ Fig8 through ends (2,1,4x,3x)

9--::

  1c+4c RHA. 1W+4W join LH ; 1M & 4M dance clw round and behind their P into LHA. All have changed places with their P facing nearest cnr (2,*1x*,*4*,3x)

17--::

  Intersecting RSh Reels4, using ½ LHA {1} in the centre. On [23-24] 1c & 4c pivot R to face the cnr they just passed (2,*4x*,*1*,3x)

25--::

  All set twice ; turn facing person RH into lines4 across in 1pl (4c between 2c) and 4pl (1c between 3c)

33--::

  RSh Reels4 across

41--::

  1c & 4c lead down/up, cross and cast inwards (to 2,4,1x,3x) ; all turn P RH', 2);
INSERT INTO 'dancecrib' VALUES (8553, '2015-02-13 12:47:30.677642+00', '2023-02-04 01:18:57.928046+00', 15613, 3, NULL, 'ace', '1-8::
    1s & 4s dance 1/2 Figs of 8 round 2s/3s, 1s+2s also 3s+4s dance 1/2
    RH across & 1s+4s dance 1/2 LH across _while_ 2s & 3s 1/2 turn RH.
    2(4)(1)3
9-16::
    2s+4s also 1s+3s dance 1/2 RH across then 2s+3s dance 1/2 LH across
    _while_ 4s & 1s cross RH to form St Andrews Cross, all set & 1/2
    turn corners RH
17-24::
    1s+4s dance ''Hello-Goodbye'' setting & end facing opposite corners
25-32::
    1s & 4s lead out ends & cast back to middle, 1s+4s circle 4H 1/2 way
    round.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (9353, '2016-10-06 07:18:09.888515+00', '2023-02-04 01:18:57.945292+00', 17180, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, cross down between 3s, cast up to 2nd place
    (opp sides) in the centre of the dance, NHJ, facing up
9-16::
    Reflection reels of 3 on sides (1s in/up on opposite sides, 2s
    out/down, 3s in/up), 1s cross on bar 13 to dance 2nd 1/2 of reel on
    own sides, & end facing 1st corners
17-24::
    1s dance Corner Pass+Turn with 1st and 2nd corners, 1s ending in 2nd
    place on opposite sides
25-32::
    RSh reels of 3 across (1L with 2s and 1M with 3s), 1s cross on bar
    20 to dance 2nd 1/2 of reel with other couple, ending in 2nd place
    on opposite sides
33-40::
    1L+3M and 1M+3L Set+Link, 1s turn RH 1.1/2 times
41-48::
    2s+3s+1s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (12331, '2019-11-04 12:48:40.224642+00', '2019-11-04 13:41:02.950422+00', 19759, 2, 2254, 'ace', '    1-4::  1s & 2s facing on sides set and change places, ladies LH, men RH

    5-8::  1s & 3s facing on sides set and change places, ladies RH, men LH     (2 3 1)

    9-16::  Reels of three on sides, 1s in and up, 3s out and up, 2s in and down to begin

    17-24::  1s turn RH, cast to 2nd place (3s step down on bars 19 & 20) 

                          and turn LH 1&1/4 to finish facing 1st corners

    25-32::  1s dance set to corner & partner (hello, goodbye), 

                          setting to each other on last 2 bars

    33-40::  1s change places RH, cast to 2nd place own sides 

                          then 2s, 1s & 3s advance and retire                                           (2 1 3)

', 3);
INSERT INTO 'dancecrib' VALUES (12333, '2019-11-05 00:12:14.84864+00', '2019-11-05 00:17:44.942328+00', 17816, 1, 202, 'ace', '1--::

  1c turn RH 1½ ; cast (2c up) | turn LH to face 1cnrs

9--::

  ½ Reel4 on 1diag ; 1c turn LH 1¼ to face 2cnrs

17--::

  ½ Reel4 on 2diag ; 1c turn LH 1½. 1M faces down, 1W faces up

25--::

  3c+1W & 1M+2c RHA ; LSh »Snake Pass« [unwind the RHA, 1c leading, pass other snake LSh through 2plx and chase cclw] (2x,1,3x)

33--::

  1c ½ Fig8 R round 1cnr[pos], cross RH to 2pl _while{6}_ 2c & 3c set, turn RH 1½ | all Set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12063, '2019-08-29 15:02:01.132313+00', '2019-11-05 01:07:45.025344+00', 66, 1, 202, 'ace', '1--::

  1c followed by 2c+3c (dancing up to start) dance down ; 3c followed by 2c+1c dance up and cast off to places. 1c face out (1,2,3)

9--::

  Mirror Fig8 on sides, 1c out and down taking hands when possible _while{8}_ 2c+3c A&R twice. 1c face out (1,2,3)

17--::

  1c cast off and mirror chase ¼ round the set | 1W+2W+3W RHA _while{4}_ 1M+2M+3M LHA | 1c dance to 3pl (2c+3c up) (2,3,1)

25--::

  Circle 6 and back (2,3,1)', 4);
INSERT INTO 'dancecrib' VALUES (12337, '2019-11-06 00:47:17.761817+00', '2019-11-06 00:56:46.233811+00', 19086, 1, NULL, 'ace', '1--::

  1c long cast (2c up) ; 2c+1M & 1W+3C LHA (2,1,3)

9--::

  1c dance down between 3c and cast up to 2pl ; 2c+1W & 1M+3c RHA 2,1,3)

17--::

  Circle6 L and back, finish in middle for

25--::

  2c+1c+3c Promenade (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (12334, '2019-11-05 00:25:42.713202+00', '2019-11-05 14:03:25.37762+00', 10093, 1, NULL, 'ace', '1--::

  Circle8 L

9--::

  All W ½ RHA | dance Lsh round opposite M {4} | ½ RHA to places, and face P (1,2,3,4)

17--::

  Interlocking Reels4 

25--::

  All M ½ LHA | dance Rsh round opposite W {4} | ½ LHA to places (1,2,3,4)

33--:: 

  [The Double Changes]  1c facing 3c, ½ turn opposite RH and twirl to exchanged places,  taking promhold (M on L) facing out ; 1c+3c promenade clw to places _while{4}_ 2c+4c A&R

41--::

  2c+4c repeat [33-40], 1c+3c dancing the A&R (1,2,3,4)

49--:: 

  [The Women do the Washing]  All W dance in and ¼ clw into small circle | set facing in ; cast L and spiral clw inside the set to own places

57--::

  [The Triple Changes] 1M+3M & 2W+3W & 1W+4W change places by ½ turn & twirl (all along 1diag direction) (2M+4M stand) ; Repeat the three parallel changes along the 2diag direction (1W+3W stand)  (2,3,4,1)  



*Can be danced as Strathspey 2 x 64 or as a Medley S64+R64*





', 3);
INSERT INTO 'dancecrib' VALUES (12339, '2019-11-07 01:16:19.772241+00', '2019-11-07 09:51:28.86281+00', 18149, 1, 202, 'ace', '1--::

  1c lead down ; and up. 1c face out (1,2)

9--::

  1c+2c DblFig8, 1c casting, into line4 across. 1c BtoB face own sides between 2c in 2pl

17--::

  »½ Celtic Reel« [: 1c+2c pass RSh | "outers" chase clw ¼ _while{2}_ "inners" dance LSh ¾ to face same person on midline ; repeat [17-20] into line4 across, 1c BtoB facing opposite sides between 2c in 2plx]

25--::

  ½ Reel4 (to 1,2) ; 1c+2c turn 1½ on sides, 1c in and down (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (12353, '2019-11-13 22:59:47.63482+00', '2021-07-20 08:48:42.239325+00', 5041, 1, NULL, 'ace', '*Trio W M W face Trio Round the Room*

1--::

  All A&R ; M turn M LH to face 1cnr (opposite W on the R)

9--::

  Each 1M turn 1cnr RH | M turn M LH to face 2cnr ; turn 2cnr RH | M turn M LH, ready for

17--::

  Each M with both opposite W RHA ; LHA, M end between opposite W facing out

25--::

  All W ½ R&L _while{4}_ the M dance clw round 1cnr. pos ;  M+own W ½ Reel3 across & face new trio

', 0);
INSERT INTO 'dancecrib' VALUES (9036, '2015-11-30 09:00:11.742673+00', '2021-07-30 08:15:48.980224+00', 11898, 3, NULL, 'ace', '{{explanation}}

Music in 20 bar phrases



1-6::

    1s+2s+3s dance reels of 3 across (2L LSh to 1M, 2M LSh to 3L to

    start)

7-10::

    1s+2s set, cast to 2nd & 3rd places _while_ 3s NHJ dance up to 1st

    place

11-20::

    3s+1s+2s set advancing & dance allemande (end 2 1 3 4)

21-26::

    1s+3s+4s dance mirror (reflection) reels of 3 on sides (1s in/down,

    3s out/up. 4s in up)

27-30::

    1s dance down to 4th place _while_ 3s+4s set, cast up to 2nd & 3rd

    place  (end 2 3 4 1)

31-40::

    3s+4s+1s set advancing, face down & dance promenade (down Ladies''

    side, up Men''s side)', 0);
INSERT INTO 'dancecrib' VALUES (12338, '2019-11-06 23:13:21.970461+00', '2019-11-07 10:31:09.007577+00', 19243, 1, NULL, 'ace', '1--::

  1W, 1M following, cast off to 2plx (2c up) ; 1c+3c LHA, and finish 1M+3W (on W side) & 1W+3M (on M side) taking promhold (2,*1x,3*,4)

 9--::

  2c+promholdpairs+4c  ½ Reels3 on the sides, Rsh to 1st couples'' 1cnrs ; 1c & 3c RHA meet into RHA emerging in promholde with P, 1c/3c on M/W side 

17--::

  4c+(1c or 3c)+2c ½ Reels3 on the sides, Rsh to 1st couples'' 1cnrs ; 1c+3c meet  into RHA, to sidelines, 1M facing out (2,1x,3,4)

25--::

  1M, 1W following, cast off to 4pl (3c+4c up) ; 4c+1c RHA (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (3087, '2012-01-22 19:30:10.686595+00', '2021-10-10 22:58:15.524307+00', 12680, 1, NULL, 'ace', '1–::

  1c+2c+3c Mirror Reels3 on sides, 1c crossing down (1x,2,3,4,5)

9–::

  1c dance down the middle and up, and face out (1x,2,3,4,5)

17–::44

  1c change places Easy Hand with 2c (1c passes outside) | with 3c (passing inside) ; with 4c (passing outside) | with 5c (passing inside) and face out (2,3,4,5,1x)

25–::

  1c Fig8 on sideline around 5c+4c, crossing to own side at the end _while_{8} 2c Fig8 round 3c+4c, starting inwards (2,3,4,5,1)', 3);
INSERT INTO 'dancecrib' VALUES (12336, '2019-11-05 14:08:37.183832+00', '2020-01-05 22:39:25.769091+00', 17824, 1, NULL, 'ace', '1--::

  1M & 2W & 3M & 4W dance Rsh round person to their R, to places ; 1M+2W & 3M+4W change places EH | change places LH with P 

9--::

  All set and Petronella in tandem to sidelines (1,2,3,4) ; All set |  1c+2c & 3c+4c change places on the sides EH, 1c & 4c passing between the other cpl. (2,1,4,3)

17--::

  1c+4c Espagnole (2,4,1,3)

25--::

  Reels4 on the sidelines (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3539, '2012-01-22 19:30:29.959721+00', '2019-11-19 09:47:38.693732+00', 7147, 1, NULL, 'ace', '1–::

  1c+3c set advancing to midline with P on R | BiL ; 1c turn ¾ RH and cast off to 3pl _while_{4} 3c turn ¾ RH and lead to 1pl (3,2,1)

9–::

  repeat [1-8] from new positions (1,2,3)

17–::

  1c lead down the middle (2c up on [19-20]) ; and up to (2,1,3)

25–::

  2c+1c R&L', 3);
INSERT INTO 'dancecrib' VALUES (12340, '2019-11-09 23:04:37.904999+00', '2019-11-10 00:08:24.938945+00', 9497, 1, NULL, 'ace', '*Set shape: six dancers.  Two "Centres" stand BtoB, each with a "1cnr" diagonally R and a "2cnr" diagonally L, forming two triangles.    

In this crib "cnr" refers to the person, not the position.*

1--::

  Each Centre+1cnr+2cnr Circle3 L ; Each Centre+1cnr+2cnr chase clw round their triangle, to places.

9--::

  Centres+1cnrs ½ Reel4, at end Centres meet and pivot R to face the P''s 2cnr ; repeat, at end Centres meet and pivot R to original set shape, all dancers are now diagonally opposite original positions

17--::

  All dance DTr, return to same places

25--::

  Each Centre+1cnr+2cnr RHA ; Centres+1cnrs change places Rsh, and 1cnrs pass Rsh in centre  | in "new triangle" 1cnrs (from centre) + 2cnrs chance places Rsh and 2cnrs pass Rsh in centre to become new Centres in the other triangle.



*Repeat, dancing 3 or 6 times through*', 3);
INSERT INTO 'dancecrib' VALUES (12341, '2019-11-10 00:14:55.917592+00', '2019-11-10 00:39:19.663067+00', 14320, 1, NULL, 'ace', '*2c is the dancing couple*  

1--::

  All S&Link tiwce (3x,2x,1x)

9--::

  2c+1cnrs set adv | turn RH ¾ ; 2c+1cnrs RHA, finish 2M between 3c in 1plx, 2W between 1c in 3plx,  

17--::

  2c+4cnrs set adv | turn RH ¾ ; 2c+4cnrs RHA, finish (3x,2,1x) 

25--::

  2c ½ Fig8 L ; All chase clw ½ round (1,2,3)

33--::

  Horseshoe Chain: 4 hands of Grand Chain, making full turns at top and bottom (stay on own side) (2,3,1)



', 3);
INSERT INTO 'dancecrib' VALUES (12344, '2019-11-10 10:55:54.339247+00', '2019-11-10 19:32:03.083643+00', 18178, 1, 202, 'ace', '*On 2nd chord, 2c & 4c cross to opposite side (1,2x,3,4x)*
1--::
  1c & 4c set and cross RH _while{4}_ 2c+3c RHA (to 1x,2x,3,4) ; 1c & 4c set and cross LH _while{4}_ 2c+3c LHA. 2c & 3c face on sides (1,2x,3,4x)
9--24::
  4C Gr-Chain, 2 bars per hand, 1c & 4c crossing RH (1,2x,3,4x)
25--::
  All A&R ; ½ Reels4 on sides (4x,3,2x,1)
33--::
  4c dance down to 2plx _while{4}_ 2c cast up to 1plx (to 2x,3,4x,1) ; all set | cross RH (2,3x,4,1x)
41--::
  Circle8 L (to 1,4x,3,2x) ; all chase clw ½ (2,3x,4,1x)', 4);
INSERT INTO 'dancecrib' VALUES (6933, '2013-08-21 08:31:33.313104+00', '2021-01-09 01:21:16.258377+00', 12531, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 2s to face 1st
    corners
9-16::
    1s dance 1/2 reel of 4 with 1st corners, pass RSh to dance 1/2 reel
    of 4 with 2nd corners
17-24::
    1s dance 1/2 reel of 3 on opp sides giving LSh to 1st corner (pstn),
    1s+4s dance double 1/2 Fig of 8 round 3s (1s cross down to start)
25-32::
    1s cross RH, cast up to top & 1s+2s dance 1/2 R&L
33-40::
    1s+3s dance 1/2 R&L, 1s+4s dance 1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (12342, '2019-11-10 10:14:45.052233+00', '2019-11-10 10:25:43.284151+00', 18179, 1, 202, 'ace', '1--::

  1M+2M+3M RSh Reels3 on sides _while{8}_ 3W+4W+5W LSh Reel3 on sides (1,2,3,4,5)

9--::

  1W+2W+3W RSh Reels3 on sides _while{8}_ 3M+4M+5M LSh Reel3 on sides (1,2,3,4,5)

17--::

  1c & 3c cross RH | cast off (2c &4c up) (to 2,1x,4,3x,5) ; 1c+4c & 3c+5c ½ R&L (2,4x,1,5x,3)

25--::

  All set | cross RH (to 2x,4,1x,5,3x) ; all set | 2c & 1c & 3c cross RH _while{2}_ 4c & 5c turn P RH (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (2449, '2012-01-22 19:29:39.464062+00', '2019-11-15 09:03:51.19539+00', 3031, 1, NULL, 'ace', '1–::

  1c+2c set | circle4 L | 1c NHJ facing 2c set 

9–::

  1c+2c Rondel (2,1,3)

17–::

  Mirror reels3 on the sides (1c starts down and out), touch hands when possible, flowing into

25–::

  2c+1c+3c in circle set | circle 6 L {3}, dance in and swivel R | spiral clw to places (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (12367, '2019-11-18 23:49:50.289002+00', '2019-11-18 23:53:24.524763+00', 15241, 1, 1645, 'ace', '1-::

  All petronella to centre | set ;

  1c+2c & 4c+5c turn P &frac14; LH & chase &frac12; way cclw in 2C set

  _while{4}_ 3c turn LH to face 1cnr pairs: 2M+1M & 5W+4W (2,1,3x,5,4)

9-::

  2M+1M+3W & 3M+5W+4W &frac12; RHA | 2M+1M+5W+4W LHA | repeat [9-10], 3c pass RSh to face 2cnr pairs (2W+1W & 5M+4M)

17-::

  3c repeat [9-16] with 2cnr pairs

25-::

  1c+3c & 5c+4c &frac12; R&L (2,3x,1x,4x,5x) ; 2c turn RH _while{4}_ 3c+1c+4c+5c turn P 1&frac12; RH (2,3,1,4,5)

33-::

  1c+4c+5c 3 couple poussette (2,3,4,5,1)

', 2);
INSERT INTO 'dancecrib' VALUES (11967, '2019-07-18 14:34:50.683238+00', '2022-04-26 01:34:38.341622+00', 18437, 1, 202, 'ace', '1--::

  All turn P RH ½ and stay in middle, W(M) facing up(down) | all chase clw ½ to own sides | all cross RH (3x,2x,1x)

9--::

  3C S&Link ; all set | ends change places RH _while{2}_ 2c turn RH ¾ to 2plx (3x,2x,1x)

17--::

  All set | all La Baratte (3,2,1)

25--::

  2c+1c The Bourrel (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (12205, '2019-09-13 01:59:39.392139+00', '2019-11-20 09:07:00.73543+00', 19641, 1, 202, 'ace', '1--::

  1c cast off 2 places | cross RH (2c up) ; cast up to 2pl | turn P RH to face 1cnrs 

9--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag, pass RSh to face 3cnrs

17--::

  Repeat [9-16] to 2pl (2,1,3)

25--::

  2c+1W & 1M+3c RHA ; 1c turn P RH and face out (2,1,3)



*Deviser''s note:*  

After 2nd time through stay facing out and dance to foot as 4th couple step up and new couple begin.', 2);
INSERT INTO 'dancecrib' VALUES (11296, '2018-10-23 00:06:59.517078+00', '2019-11-21 09:00:29.216742+00', 19018, 1, 202, 'ace', '1--::
  All Petronella Turn in Tandem and set one place cclw ; repeat (3,4,1,2)
9--::
  3c+1c ½ M-Chain ; 4c+2c ½ M-Chain
17--::
  All repeat [1-8]
25--::
  Intersecting Reels4 (M ½ LHA in the middle _as_ W cast into P place to start)
33-56::
  All repeat [1-24]
57--::
  Circle8 and back
65-128::
  Repeat [1-64] except La-Chain instead of M-Chain and Intersecting Reels4 (W ½ LHA in the middle _as_ M cast)', 2);
INSERT INTO 'dancecrib' VALUES (4466, '2013-08-21 08:30:49.235791+00', '2023-02-04 01:18:57.962077+00', 867, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1M+2L 1/2 turn RH & cast left round partner
    back to places
9-16::
    1s+2s dance LH across, 1L+2M & cast left round partner then pass LSh
    to face 2L/1M places
17-24::
    1M+2M+1L+2L dance reel of 4 but 2M+1L dance 1/2 the reel & then
    cross back to places
25-32::
    1s+2s dance Tourbillon:
::
    1s & 2s 1/2 turn ptnrs 2H, 1M & 2L lead ptnrs by nearer hand 1 place
    cl''wise to end 1s on Ladies'' side & 2s Men''s side, 1s set to 2s
::
    1s & 2s 1/2 turn partners 2H & lead partners on 1 place clockwise &
    2s+1s cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (11779, '2019-04-10 10:58:20.646903+00', '2019-11-11 12:48:48.071567+00', 14985, 1, NULL, 'ace', '1--::

  1c turn RH ½ into promhold, dance down 2 ; cross below 3c (2c up) | cast up to (2,1,3)

9--::

  2c+1W & 1M+3c Reels3 across (1c Lsh to 1cnr) (2,1,3)

17--::

  1c petronella turn | set in lines across ; 1c petronella turn | All set (2,1x,3)

25--::

  1c turn RH 1¾ ; 2c+1M & 1W+3c LHA (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12345, '2019-11-11 11:46:03.728067+00', '2019-11-12 13:28:09.141714+00', 18392, 1, NULL, 'ace', '*Set: Five couples form a circle and face in, numbered clw.*   



1-10::

  Four times ½ R&L: 1c+4c (start on bar 1) | 5c+3c (on bar 3) | 1c+2c (on bar 5) | 5c+4c (on bar 7) (5,1,4,2,3)

11-20::

  All face partner, and dance half Rsh Interlocking Reels of 5 round the set (pass 4 hands, 5th hand full turn RH {6} | continue Interlocking Reels5 back to places, the W face out (5,1,4,2,3),

21-30::

   Schiehallion Reel (5 changes), M pass the middle first, at end all W (in a Mpl) faces her Temporary corner (in a Wpl) 

31-40::

  With that corner set HS {4} Turn BH and face away | with Temporary P (next dancer) set HS {4}, finish W facing in, M facing out

41-50::

  Schiehallion Reel (5 changes), W pass the middle first

51-60::

  Repeat [11-20] (5,1,4,2,3),

61-70::

  Four times ½ R&L: 4c+5c (start on bar 1) | 1c+2c (on bar 3) | 5c+3c (on bar 5) | 1c+4c (on bar 7) (1,2,3,4,5)

', 4);
INSERT INTO 'dancecrib' VALUES (12348, '2019-11-12 23:52:40.883271+00', '2019-12-26 16:51:58.691187+00', 15423, 1, NULL, 'ace', '1--::

  1c+2c face in diagonally and set | 1W+2M cast one place clw _while{2}_ 1M+2W turn RH ¾ ; 1c+2c face in diagonally and set | 2W+1M cast one place clw _while{2}_ 2M+1W turn RH ¾ (1,2,3)

9--::

  1c cross RH | cast off (2c up) ; cross down between 3c and cast up (2,1,3)

17--::

  Mirror Reels3 on the sides, 1c start in and up (2,1,3)

25--::

  3C Allemande (3,1,2)

', 2);
INSERT INTO 'dancecrib' VALUES (12346, '2019-11-12 20:55:07.250668+00', '2019-11-12 20:58:08.474933+00', 17255, 1, 1645, 'ace', '1-::

  1c lead down & back up, crossing to face 1cnrs (2c up on [3-4])

9-::

  1c+1cnrs &frac12; diag RSh Reel4, 1c pass RSh ; repeat with 2cnrs, 1c pass LSh to face 3cnr[pos]

17-::

  1c set H&G{6} with 3cnr[pos] & 4cnr[pos] to face up/down | set adv & pull RSh back for

25-::

  3c+1W & 1M+2c RHA ; 1c turn BH _while_ 3c+2c chase &frac12; way clw (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12351, '2019-11-13 01:41:14.798582+00', '2020-04-18 21:38:43.820689+00', 13094, 1, NULL, 'ace', '*Line of 3 dancers all facing down; d1 has d2 on L, d3 on R) (3,1,2)*  

1--::

  All set NHJ | d1 Lsh fig8{6}, d1 finish in triangle position behind own place   

9--::

  Circle3 and back, finish in the line (3,1,2)

17--::

  d1+d2 set to and turn BH ; d1+d3 repeat (3,1,2)

25--::

  Reel3{6}, d1 Lsh to d2 (3,1,2) | d1+d2 change places LH {1}, d2+d3 change places RH {1} and all face down (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (12349, '2019-11-13 00:13:01.911499+00', '2020-09-11 21:35:12.105032+00', 18772, 1, NULL, 'ace', '

1--::

  1c set | cast off (2c up) ; set | turn P LH into 1M with 1W just behind facing 2W

9--::

  1M+1W following Rsh Reel3 across with 2c, in last loop change lead into 1W with 1M just behind facing 3M

17--::

  1W+1M following Rsh Reel3 on side with 2M+3M, at end 1c dance into 2pl own side (1,2,3M)

25--::

  1c turn P LH ; All set | 1M casts off (3M up) (2c, 3M+1W, 1M)

', 3);
INSERT INTO 'dancecrib' VALUES (7862, '2013-08-21 08:31:50.049148+00', '2023-02-04 01:23:07.755976+00', 13116, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across 1/2 way & set, 2s+1s dance DoSiDo & 1s face
    down (1L on prtnrs right)
9-16::
    1s dancing side by side dance 1/2 diagonal Alternating reel of 3
    with 2L+3L (LSh to 3L), 1s (1L on prtnrs left) circle 4H round to
    left with top couple _while_ bottom couple turn RH
17-24::
    1s+bottom couple circle 4H round to left _while_ top couple turn RH,
    1s dancing side by side dance 1/2 diagonal Alternating reel of 3
    with 2M+3M (RSh to 3M).  (3)(1)2
25-32::
    All dance Snowball Grand Chain for 3 cpls to end 2 1 3:
::
    1s+3s change places LH on sides, 1s cross RH to own sides _while_
    2s+3s change places RH on sides
::
    1s+2s change places RH _while_ 3s cross over RH, 2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (12350, '2019-11-13 00:59:41.399925+00', '2019-11-13 01:33:03.100328+00', 1661, 1, NULL, 'ace', '*Set of 5 dancers: 1c (own side) + 2c (opp. side) + Centre Man (CM) in the middle*  

1--::

  1c+2c chase clw _while{4}_ CM sets turning, LHJ with with 2W & RHJ with 1W, both W giving RH ; 1c+2c pivot R to chase cclw _while{4}_ CM sets turning, LHJ with with 1M & RHJ with 2M, both M giving LH [to places]

9--::

  1W+CM+2W Rsh Reel3 _while{8}_ 1M+2M set with Highland step

17--::

  1M+CM+2M Lsh Reel3 _while{8}_ 1W+2W set with Highland step

25--::

  1c+CM set as in DTr | 1M+CM change places LH ; 1M+2c set as in DTr | 1M+2M change places LH (2M is now in centre, both W in own place)  



*repeat twice only*', 3);
INSERT INTO 'dancecrib' VALUES (12352, '2019-11-13 16:02:44.348299+00', '2019-11-13 16:15:32.295034+00', 12594, 1, NULL, 'ace', '1--::

  1c cross down RH (2c up) | cast behind 3c ; dance up between 3c | turn P LH to face 1cnr

9--::

  Turn CPCP (2,1,3)

17--::

  All set | cross RH ; All set | All turn P LH ½ into promhold facing up

25--::

  3C Promenade (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (8866, '2015-08-26 19:48:09.764052+00', '2019-11-13 22:54:05.945273+00', 16523, 1, 1041, 'ace', '1--::  1c set | 1W followed by 1M cast off 1pl (2c up on 5-6) and cross | 1c+3c turn LH ½ on sidelines (1M+3M face out) (2,3,1x)



9--::  3c+1c L-Chain (1M face out)



17--::  1M followed by 1W cast up (3c down on 19-20) and cross ; 2c+1c RHA (1M+2W face out) (2,1,3)



25--::  Reels3 on the sides, 1c Lsh to 3c (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (2468, '2012-01-22 19:29:40.621034+00', '2019-11-15 00:08:54.405937+00', 7560, 1, NULL, 'ace', '1–::

  All in promhold Reel3 across (1c & 3c Rsh to begin).

9–::

  With 1W leading, 1c+3c RHA ; 1c+2c LHA

17–::

  2c+3c L-Chain _while_{8} 1c set | dance down the middle & cast up round the outside to orig. place.

25–::

  1c+3c ½R&L ; 1c+2c ½R&L. (to 3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (12356, '2019-11-16 07:39:58.051451+00', '2020-02-07 00:26:54.472288+00', 10694, 1, NULL, 'ace', '1--::

  1c+3c advance | set, turning on 2nd step to face side couples ; with new P dance out NHJ between side couple and cast back to place (1,2,3,4) 

9--::

  2c+4c repeat (1,2,3,4)

17--::

  All change place with P RH | set to next person (new cnr) ; change place LH | set to next person, your new P, and face in 

25--::

  New couples in 1pl+3pl ½ R&L ; new couples in 2pl+4pl repeat (All have moved 1 place, the M clw, the W cclw, and so have swapped P with couple opposite)



*repeat 3 times, swapping partners each time* 







', 3);
INSERT INTO 'dancecrib' VALUES (12354, '2019-11-15 10:31:40.696623+00', '2019-11-15 15:01:14.6104+00', 12143, 1, NULL, 'ace', '1--::

  1c+4c turn RH ¾ moving down and pivot R to finish BtoB, M facing down (2c+5c dance up) | 2c+1c+3c & 5c+4c+6c 6 bars of Crown Triangles, finish 1c & 4c facing 2cnr

9--::

  1c+4c diagonal Reels4, Rsh to 2cnr, at end pass P Rsh to face 1cnr 

17--::

  1c+4c diagonal Reels4, Rsh to 1cnr, at end omit Lsh pass to finish (2,1x,3,5,4x,6,7)

25--::

  1c+4c set to P | cast off one (3c+6c up) ; cross RH and cast off (5c+7c up) (2,3,5,1,6,7,4)  

', 3);
INSERT INTO 'dancecrib' VALUES (9709, '2017-04-05 13:48:55.086814+00', '2020-08-29 12:57:17.187486+00', 999, 1, 202, 'ace', '*3c+4c start on opposite side (1,2,3x,4x)*

1--::

 1c+2c & 3c+4c Set&Rotate (2,1,4x,3x)

9--::

 1c dance up and cast _while{4}_ 4c dance down and cast ; 1M+4W & 1W+4M in promhold dance LSh round each other to finish 1M+4W in 2pl centre facing 2M & 1W+4M in 3pl centre facing 3M

17--::

 1M+4W with 2c Reel3 across, Lsh to 2M _while{8}_ 1W+4M with 3c Reel3 across, Lsh to 3M (2,4,1x,3x)

25--::

 Circle(8) and back (2,4,1x,3x)', 2);
INSERT INTO 'dancecrib' VALUES (12355, '2019-11-15 15:38:23.212052+00', '2019-11-15 18:17:54.748343+00', 4709, 1, NULL, 'ace', '1--::

  1c+2c RHA ; 1c cast off as 2c dance up | 1c cross RH and hold hands for (2,1x,3)

9--::

  1c+3c RHA ; 1c cast below 3c (don''t step up) and cross LH

17--::

  1c cast up | lead up between 1pl ; cast to 2pl | turn P L Arm to face 1cnr _while{8}_ 2c+3c R&L, with polite turn

25--::

  CPCP, using elbow grip, finish (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3502, '2012-01-22 19:30:28.097715+00', '2019-11-15 23:09:30.571392+00', 7019, 1, NULL, 'ace', '1–::

  1c turn ¾ RH moving down (2c up) | 6 bars of Crown Triangles ending with 1M between 2c and 1W between 3c all facing down.

9–::

  1M+2c & 1W+3c down the middle & up, top line swiveling R again to face down

17–::

  1c change places RH | cast R into 2pl ; turn RH _while_{8} 2c+3c set up/down | change places RH ; set to P | cross RH. (3x,1,2x)

25–::

  diagonal R&L (1M crossing down & 1W crossing up).', 2);
INSERT INTO 'dancecrib' VALUES (4399, '2013-08-21 08:30:48.279068+00', '2023-02-04 01:18:53.854332+00', 763, 3, NULL, 'ace', '1-8::
    2s+3s set to each other on sides, set to partners; 1s+2s also 3s+4s
    set to each other on sides & set to partners
9-24::
    1s lead down & cross to face 4s, 1M+4L turn LH as 1L+4M turn LH &
    turn partner RH (as Strip the Willow) back to top
25-32::
    1s set, cast 1 place  (2s step up) & dance 1/2 Fig of 8 up round 2s
33-40::
    1s cross RH, cast to 3rd place (3s step up) & dance 1/2 Figs of 8 up
    round 3s.  2 3 1 4
41-48::
    1s+4s dance Poussette.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (2833, '2012-01-22 19:29:59.297896+00', '2019-11-16 01:00:32.389339+00', 1232, 1, NULL, 'ace', '1–::

  1W+2M set diagonally | 1W cast down, 2M cast up (1M down, 2W up) ; 1W+2M turn BH to (2,1)

9–::

  1M+2W repeat [1-8] (to 1,2)

17–::

  1c (cross down) Fig8 round 2c (1,2)

25–::

  »Divided knot«: 1c+2c set | Turn BH ½ and face down NHJ ; 2c cast up _while_{2} 1c dance down and cast up (to 2x,1x) | All Cross RH', 3);
INSERT INTO 'dancecrib' VALUES (4401, '2013-08-21 08:30:48.411806+00', '2023-02-04 01:18:54.063306+00', 8330, 3, NULL, 'ace', '1-8::
    1s facing 2s set & change places RH, 2s+1s+3s set & cross RH
9-16::
    2s+1s set & turn partner 2H, 2s+1s circle left _while_ 3s set & turn
    2H
17-24::
    2s+1s+3s circle 6H round to left 1/2 way, all Adv+Ret
25-32::
    3s+1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (8378, '2014-07-31 07:48:45.434953+00', '2023-02-04 01:18:57.983916+00', 14537, 3, NULL, 'ace', '1-4::
    All set to partners (Glasgow Highlander setting - right foot), pull
    RSh back to face corner. Repeat setting to corner (left foot), pull
    LSh back towards partner. Men face out, ladies face in
5-8::
    Men pass partners by Left, dance anticlockwise 1/2 way round set
9-12::
    All repeat 1-4 with new partners and corners. Men face in, ladies
    face out
13-16::
    Ladies pass partners by Right, dance clockwise 1/2 way round set,
    finish facing original partner
17-24::
    All turn partner RH once round, Men cross diagonally one place to
    right, cast round next lady into next man''s place
25-32::
    All turn new partner RH once round. Ladies face out, cast to right
    round new partner, cross diagonally to right to face out beside
    original partner
33-40::
    All dance 1/2 Schiehallion Reels (2 places)

{{explanation}}
Repeat, having passed a couple.', 0);
INSERT INTO 'dancecrib' VALUES (15128, '2022-10-04 18:53:33.88744+00', '2022-10-04 18:58:03.034586+00', 21024, 1, 202, 'ace', '1--::

  Mirror Reels3 on sides, 1c in and down, 2c out and up. On [5] 1c cross up to 2plx (1x,2,3)

9--::

  Mirror Reels3 on sides, all couples crossing down from top place (1,2x,3x)

17--::

  1c set | cast off (2c up) (to 2x,1,3x) ; *Modified Set&Link* : 1W+2M & 1M+3W set | 1c Petronella turn into facing lines3 across _while{2}_ 2M & 3W dance in and down, pull RSh back and dance back to places.

25--::

  3C Set&Link (to 2,1,3) ; all turn P RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12358, '2019-11-16 20:15:08.496156+00', '2019-11-16 20:54:27.301506+00', 11685, 1, NULL, 'ace', '1--::

  1C turn BH and face up | cast off (2c up) ; turn BH 1½ to (2,1x,3)

9--::

  All set | 2c+3c dance BtoB _while{4}_ 1c dance Rsh round P to sideline and face out (2,1x,3) | 2c+3c A&R diagonally {1+1} _while{2}_ 1c cast clw to between end couples, in facing lines across

17--::

  All set | 2c+3c dance BtoB with opposite _while{4}_ 1c dance Rsh round P to face out the end | 2c+3c A&R diagonally {1+1} _while{2}_ 1c cast clw to (2,1,3)

25--::

  Circle6 and back (2,1,3)



', 3);
INSERT INTO 'dancecrib' VALUES (12368, '2019-11-19 02:02:31.923824+00', '2019-11-19 10:16:41.48228+00', 19775, 2, NULL, 'ace', 'Overview of the dance, supplied by an event organizer.  This version differs considerably from a version available to the editors.   

   

1-16::

    Grand Chain, start RH to partner, 2b per hand

17-24::

    1s turn as couple to face out (2b), then 2s, 4s, 3s fall in behind 2b each

25-32::

    Chasse + set ; chasse back + set

33-40::

    1M cast followed by 2M 4M 3M, likewise 1W, 2W, 4W, 3W ; meet partner, nce up, and out to lines facing partners across

41-48::

    All set 4b ; meet partner and turn 2H to place.  



Repeat for 2s, 3s, 4s.    



Finish with a Grand Chain {16}', 0);
INSERT INTO 'dancecrib' VALUES (13024, '2020-08-10 00:18:17.167773+00', '2023-02-04 01:18:18.706853+00', 17612, 3, NULL, 'ace', '1-8::
    1s set, dance down, cast up round 3s to face 1st corners (2s step up
    3-4)
9-16::
    1s set to 1st corner, 1s & corners petronella turn to Right, 1s join
    NHJ with corner facing centre, Set+Link, corners casting back to
    place _while_ 1s end in 2nd place opp side facing 2nd corners
17-24::
    1s dance LSh reel of 3 with corners (1M up, LSh to 2L, 1L down, LSh
    to 3M), Bars 23-24: 1M/1L cross diagonally up/down from 3rd/1st
    place opp side to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12361, '2019-11-16 23:11:20.849335+00', '2021-01-08 11:52:58.447374+00', 12850, 2, 160, 'ace', '1-8::

  1s set, cast down 1place; cross down RH (btwn 3s)  cast up to 2nd place (2 1x 3)

9-14::

  2s 1s 3s mirrored Reels3 on sides - 1s in & up to begin.

15-16::

  1s turn LH 3/4.

17-24::

  RHA -1W with 2s and 1M with 3s  - 1s pass Rsh to change ends. LHA - 1M with 2s and 1W with 3s.

25-32::

  2s 1s  R&L.', 3);
INSERT INTO 'dancecrib' VALUES (4467, '2013-08-21 08:30:49.24445+00', '2023-02-04 01:18:58.01913+00', 873, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, turn partner LH 1.1/2 times to opposite sides
    (M facing up L down)
9-16::
    2s+1s+3s dance reel of 3 on sides giving LSh to 2nd corner & ending
    with 1s turning RH to face 1st corners
17-28::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s meet again in
    middle
29-32::
    1s turn RH 1.1/2 times to 2nd place own sides _while_ 2s & 3s change
    places RH on the sides & cross over LH', 0);
INSERT INTO 'dancecrib' VALUES (12228, '2019-09-17 00:16:58.066547+00', '2019-11-20 09:03:40.293767+00', 19655, 1, 202, 'ace', '1--::

  1c & 4c set | cast inwards (2c & 3c step out) ; 1c+4c RHA. 1c(4c) RHJ face up(down) (2,1,4,3)

9--::

  1c+4c lead out through ends, cross and cast inwards ; ½ Fig8 through ends into promhold facing up. 3c step in on [16] (2,1,4,3)

17--::

  1c+4c+3c Allemande (2,3,4,1)

25--::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (9345, '2016-10-05 13:27:46.884812+00', '2019-11-16 23:45:15.917094+00', 16962, 2, 160, 'ace', '1-2::

  1C 2C set - the ladies advancing toward partner, 

3-4::

  Ladies cast left about back to place ;

5-8::

  Repeat, men advancing and casting.

9-16::

  1C fig.8 round 2C (cross down to begin).

17-24::

  1C 2C progress with  *la spirale* (modified) ––

17-18::

  1C 2C turn BH 3/4 ,

19-20::

  1M 2W cast R (round each other) to progressed places

**AS** 1W 2M dance CW on the outside to Progressed places ,

21-24::

  2C 1C turn BH once round and stay in middle , cast R about back to places.

25-32::

  Poussette





', 0);
INSERT INTO 'dancecrib' VALUES (4468, '2013-08-21 08:30:49.254363+00', '2023-02-04 01:18:58.040219+00', 8629, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance double Fig of 8 (1s crossing down & 4s
    crossing up to begin)
9-16::
    1s dance down & 4s up as 2s & 3s cast to ends, 1s+4s turn opposite
    dancer 2H once round opening out & dancing 4H once round  2 1 4 3
17-24::
    1s+4s dance Poussette.  2 4 1 3
25-32::
    2s & 3s cross RH, cast in 1 place, cross with Ladies dancing under
    Men''s arch, all 1/2 turn corners nearer hand to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4469, '2013-08-21 08:30:49.262486+00', '2023-02-04 01:18:58.054666+00', 875, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set, dance RH across 1/2 way, 2s+1s also 4s+3s set
    & 2s & 4s cross LH _while_ 1s+3s turn LH to face 1st corners
9-16::
    1s & 3s dance ''Hello-Goodbye'' setting & end in centre Men facing
    down & Ladies up
17-24::
    1s+3s dance reel of 4 up/down centre _while_ 2s+4s+5s dance reels of
    3 on sides (2L+4L also 4M+5M pass RSh to start)
25-32::
    1s & 3s 3/4 turn RH, cast down 1 place & turn RH.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (12364, '2019-11-17 22:57:56.939944+00', '2019-11-17 23:03:48.296673+00', 8852, 1, 1645, 'ace', '*5c start in centre LSh to P, 5W facing up, 5M down.*

1-::

  5W+1c & 5M+3c RHA | 5W+2c & 5M+4c LHA to original places

9-::

  5c with 1c & 3c (in promhold) &frac12; RSh Reel4, 5c pss LSh ; repeat with 2c & 4c, end 5W facing down, 5M up

17-::

  5M Fig8 round 3c & 2c (1pl & 4pl) _while{8}_ 5W Fig8 round 1c & 4 (3pl & 2pl) starting RSh & end facing across to P

  _while{8}_ 1c+3c adv&ret on [17-20] ; 2c+4c adv&ret on [21-24]

25-::

  5c set | turn &frac34; BH to face 3c (by then in 4pl) _while{4}_ 3c+4c+1c+2c set | petronella in tandem (4,1,2,3,5) ;

  5c+3c set | &frac12; LHA (4,1,2,5,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12359, '2019-11-16 21:06:01.338578+00', '2019-11-16 23:45:15.918951+00', 16962, 1, NULL, 'ace', '1--::

  1c+2c set (W advancing) | 1W+2W cast L back to places ; 1c+2c set (M advancing) |  1M+2M cast L back to places (1,2)

9--::

  1c cross down into Fig8 round 2c (1,2)

17--::

  Modified La Spirale: 1c+2c turn P BH ¾ to midline | 1M+2W cast Rsh round each other, first tightly, all spiral out clw ; 2c+1c turn P BH and stay close | cast R to sideline (2,1)

25--::

  2c+1c Poussette (2,1)





', 3);
INSERT INTO 'dancecrib' VALUES (4470, '2013-08-21 08:30:49.270534+00', '2023-02-04 01:18:58.073816+00', 8348, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    1s+2s also 3s+4s circle 4H to left & Set+Link on sides
9-16::
    All dance RSh reel of 4 on sides
17-24::
    1M+4L & 4M+1L dance Ladies'' Chain (end facing in prom hold)
25-32::
    1M+4L & 4M+1L Promenade across (Men passing LSh), 4s dance up
    between 2s & cast to 2nd places _while_ 1s dance down & cast to 3rd
    places', 0);
INSERT INTO 'dancecrib' VALUES (12180, '2019-09-06 04:12:05.486659+00', '2023-02-28 15:27:51.99637+00', 19604, 1, 202, 'ace', '1--::

  1c+2c ½ R&L ; 2c+1c set | 2c cross LH _as_ 1c turn LH to face 1cnrs (2,1,3)

9--::

  1c+1cnrs set and turn RH. 1c face P in centre ; 1c followed by 1cnrs pass LSh, curve in L round 3cnrs[pos] to leave 1cnrs in exchanged places, dance in, touch P briefly LH and face 2cnrs

17--::

  Repeat [9-12] ; 1c followed by 2cnrs pass LSh, curve in round cnrs[pos] to leave 2cnrs in exchanged places, curve round to the L into facing lines3 across, 1W between 3c in 1plx facing 1M between 2c in 3plx

25--::

  All set | 1c Petronella Turn to 2plx _as_ 2c & 3c set and face in (3x,1x,2x) ; Circle6 L ½ (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (2289, '2012-01-22 19:29:30.001004+00', '2019-11-17 01:24:54.142377+00', 9350, 1, NULL, 'ace', '1–::

  1c+2W & 2M+3c RHA, finish 1W + 3M facing out ; 1c (1W leading) +3c (3M leading) chase clw half round 2c to (3x,2,1x)

9–::

  3c+2M & 2W+1c LHA, finish 1M + 3W facing out ; 3c (3W leading) +1c (1M leading) chase cclw half round 2c to (1,2,3)

17–::

  1M+2M & 1W+2W 1½ LH turn to exchange places ; 1M+3M & 1W+3W Turn RH

25–::

  2c+1c+3c circle6 and back



*On second time through, 1c may turn 3c RH 1½ on bars 21-24*', 3);
INSERT INTO 'dancecrib' VALUES (12362, '2019-11-17 21:22:21.041704+00', '2019-11-17 22:08:23.664402+00', 12179, 1, NULL, 'ace', '*Strathspey*  

1--::

  1c lead down (2c+3c up) ; 1c cross below 4c and cast up to (2,3,1x,4)

9--::

  3c+1c+4c Circle3 L {6} | 1c dance in and pivot R to face "1st cnrs".

17--::

  1c set to 1cnr | turn 1cnr RH  and 1c face P on midline ; 1c set and turn P RH to face 2cnr

25--::

  1c+2cnrs set and turn RH to (2,3,1x,4) | 1c set and cross RH (2,3,1,4)



*Reel*  

33--::

  2c+3c+1c Reels3 on the sides, 3c start out and down (2,3,1,4)

41--::

  3c+1M & 1W+4c Reels3 across, Rsh to 2cnr, 1c finish BtoB in 3pl facing own side

49--::

  3c+1c+4c DTr, to (2,3,1,4)

57--::

  1c turn P RH 1½, keep RHJ ; cross RH and cast off (4c up) (2,3,4,1) 



  

', 3);
INSERT INTO 'dancecrib' VALUES (12365, '2019-11-17 23:11:59.03066+00', '2020-03-25 15:38:02.801703+00', 9929, 1, 1645, 'ace', '1-::

  1W+3W cast off | cross _while{4}_ 1M+3M cross | cast off (2c+4c up) ; 1c & 3c turn 1&frac14; RH

9-::

  2c+1W, 1M+4c+3W & 3M+5c LHA ; 1c+3c &frac12; Reel4 on centre line

17-::

  2c+3M, 3W+4c+1M & 1W+5c LHA ; 1c & 3c turn &frac34; RH | 1c lead up _while{2}_ 3c cast off (2,1,4,3,5)

25-::

  All set | 2c cross RH _while{2}_ 1c+4c & 3c+5c &frac12; RHA ; all set | cross RH to (2,4,1,5,3). 2W & 1W stay facing out

', 2);
INSERT INTO 'dancecrib' VALUES (2791, '2012-01-22 19:29:57.546232+00', '2019-11-17 18:00:15.738872+00', 4407, 1, NULL, 'ace', '1–::

  1c set | cast off one (2c up) ; 1W+2c & 1M+3c RHA (2,1,3)

9–::

  Mirror Reels3 on own sides (1c dance up NHJ to begin) (2c+3c end with loops) (2,1,3)

17–::

  1W+2c and 1M+3c Reels3 across (Lsh to 1cnr), finish for

25–::

  DTr up/dn, 1W starting with 2c and 1M with 3c , to (2,1,3)

33–::

  Circle6 and back', 3);
INSERT INTO 'dancecrib' VALUES (12363, '2019-11-17 22:49:08.881652+00', '2019-11-17 22:52:27.67132+00', 9942, 1, 1645, 'ace', '1-::

  1c cast off | cross up LH ; cast off to 2pl (2c up) | turn &frac34; RH into promhold facing 3W

9-::

  1c (in promhold) &frac12; RSh diag Reel3 with 1cnrs ; repeat with 2cnrs & face 3W again in 3cnr [pos]

17-::

  Repeat [9-16] with 3cnrs & 4cnrs, 1c end facing W side

25-::

  2c+3c R&L _while{8}_ 1c lead out W side into Fig8 across, 1M/1W round 1pl/3pl, 1c end with &frac34; RH turn to (2,1,3).

  After 1st time 1c face out ready to repeat.

', 2);
INSERT INTO 'dancecrib' VALUES (11621, '2019-02-26 06:51:58.091379+00', '2019-11-18 22:28:25.91158+00', 17156, 1, 202, 'ace', '1--::

  1c+2c Mirror S&Link (1c cast, 2c dance up) ; ½ Mirror Reels3 on sides, 1c in and down, 3c out and up, with loops on the ends (3,1,2)

9--::

  3C Bourrel (2M, 3M, 1M on M side, and 1W, 2W, 3W on W side)

17--::

  1W+2W & 3M+1M S&Link ; all turn P BH twice (2,1,3)

25--::

  Circle6 and back', 5);
INSERT INTO 'dancecrib' VALUES (12366, '2019-11-18 23:31:53.667397+00', '2019-11-18 23:31:53.667397+00', 15240, 1, NULL, 'ace', '*5c start facing P across, 5M/5W with their backs to 4c/2c.*

1-::

  5W+1c & 5M+3c RHA, 5M+5W end LHJ facing 2c/4c ; 5c+2c+4c set twice, 5c turning in to take RH for [7-8]

9-::

  5M & 5W dance out through arches made by 2c & 4c who dance in _while{2}_ 1c & 3c &frac12; turn RH & face clw |   

  2c+4c RHA _while{4}_ 1c+5c+3c chase &frac12; way clw |   

  5M & 5W dance in through arches made by 4c & 2c who retire to place _while{2}_ 1c & 3c &frac12; turn RH to end in tandem, M leading

17-::

  5c &fras12; Reel4 with 3c +1c (each in tandem), 5c pass RSh to 5M/5W facing 4c/2c ;   

  repeat [17-20] with 2c+4c, 5c pass RSh to 5M/5W facing 3c/1c

25-::

  Repeat [9-16] with 1c & 3c making arches

33-::

  5c+1c+3c set twice, 5c turning in to take LH for [35-36] ; 5M+2c & 5W+4c RHA

41-::

  5c & 1c &frac12; turn LH | 5c+1c &frac12; LHA _while{4}_ 2c+3c+4c turn LH to face cclw ;   

  1c turn 1&frac14; LH in centre _while{4}_ outer couples chase &frac14; clw | turn P RH (4,5,2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (1749, '2012-01-22 19:29:00.391996+00', '2019-11-25 00:25:26.974487+00', 12426, 1, NULL, 'ace', '1–::

  1c set | 1W (1M follows) casts off 2, crosses, W dances up behind M line, and M dances up the middle, 1c face 1cnr (2c up)

9–::

  1c set to 1cnr | 1c cast Rsh round each other to 3cnr position _while{2}_ 1cnrs dance into centre, and swivel R to face own cnr ; repeat, 1cnrs finishing in exchanged places, and 1c facing 2cnr

17–::

  Repeat with 2cnrs (3x,1x,2x)

25–::

  All chase clw ½ round ; all turn RH. (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (12369, '2019-11-21 15:04:46.274125+00', '2019-11-21 17:32:18.550824+00', 15971, 2, 2929, 'ace', '1-:: Crossover mirror Reel3, finishing 1C+3C in middle facing up and down
9-10:: 1M+3M advance, set L WHILE 1L+3L+2C set R and advance
11-12:: 1M+3L, 3M+1L turn RH 3/4 into allemande hold WHILE 2C cross LH
13-16:: All chase halfway anticlockwise 
17-24:: Repeat 9-16 from new orientation
25-28:: 3C+2C dance half LHA, all set to partner
29-32:: Highland Schottische Balance: Give RH to partner, dance Highland Schottische Setting Step, turning halfway and giving LH under RH while turning, repeat with LH', 2);
INSERT INTO 'dancecrib' VALUES (2004, '2012-01-22 19:29:14.534271+00', '2019-11-21 20:46:46.365552+00', 9083, 1, NULL, 'ace', '1–::

  1M (1W following) cast off (2c+3c+4c up on [3-4] and both cross below 4c, 1M casts up round 3W into the middle and 1W casts up round 4W  into the middle

9–::

  2M+1M+3W & 3M+1W+4W parallel 1st diagonal Rsh Reels3, at end 1M+1W face L and 3W makes a loop, into

17–::

  2W+1M+3M & 3W+1W+4M parallel 2nd diagonal Rsh Reels3, 1c finish facing down

25–::

  1W (1M following) casts up behind 4W+3W, crosses, casts off to bottom, crosses, finishing (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (12237, '2019-09-23 00:56:10.154389+00', '2021-04-25 22:19:26.393251+00', 16628, 2, 160, 'ace', '0::  start - 1 2 3x 4x

1-4::  1s2s also 3s4s circle left once round.

5-8::  1s 4s  turn ptnr (RH) halfway and cast to ptr''s pl.  *While* 2s3s set , the 2s dance in and up to end b-to-b facing 1s & the 3s dance in and down to end b-to-b facing 4s. Now in lines of 4 across the set.

9-16::  Reels of 4 across the dance. On bar 16 2s3s take LH in passing. End - 2s facing up, 3s facing down.

17-20::  2s cross up and cast off on opp. sides *AS* 3s cross down and cast up on own sides.

21-24::  2s 3s dance half RL.  (1x 3x 2 4)

25-32::  1s3s also 2s4s face in diagonally - Set, Petronella Turn; repeat.  (3 1 4x 2x)', 0);
INSERT INTO 'dancecrib' VALUES (11063, '2018-09-04 01:05:41.910849+00', '2019-11-22 10:46:24.097373+00', 18513, 1, 202, 'ace', '1--::
  1c cross RH | cast ; cross LH | 1c set (2,1,3)
9--::
  Diagonal R&L (3x,1,2x)
17--::
  All A&R ; repeat (3x,1,2x)
25--::
  All cross RH (no curving round) | 1c cast R into lines3 across _while{2}_ 2c & 3c set facing up/down ; all change places LH (no curving round) | 1c cast L to 2pl _while{2}_ 2c & 3c set (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (7863, '2013-08-21 08:31:50.05713+00', '2023-02-04 01:23:07.784078+00', 7656, 3, NULL, 'ace', '1‑8::
    1s+2s dance Poussette.  2 1
9‑16::
    2s+1s dance R&L
17‑24::
    2s+1s dance  RH across, 1s+3s dance LH across (end in middle)
25‑32::
    1s+3s slip step down & back to end in middle ready to start again

{{explanation}}
At the beginning of the 3rd time through 1s+4s also dance Poussette to put 1s in 4th place', 0);
INSERT INTO 'dancecrib' VALUES (12370, '2019-11-24 12:31:58.699315+00', '2019-11-24 12:31:58.699315+00', 18791, 2, 1645, 'ace', '1-8::
  1s+2s set, cross RH, set & cross back RH
9-16::
  1M followed by partner casts 1 place & cross to opposite side, 2s+1s set to partners & set down/up
17-24::
  2s+1s dance Ladies'' Chain
25-32::
  1s set, 1M followed by partner casts up & cross to own side, 1M
casts to 2nd place while 1L dances down middle to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (12371, '2019-11-24 21:01:59.889318+00', '2022-04-25 20:11:17.409621+00', 5464, 2, 160, 'ace', '1-8::

  1s 2s RHA (keep hand joined); all dance forward and cast over left shoulder, continue dancing anti-clockwise to end progressed and on opposite sides (2x 1x)

9-12::

  2W 1M set advancing, turn BH half round (end B-to-B in the center - 1M facing up, 2W down) *while* 1W 2M dance anti clockwise half round and end in center facing partner (line of 4);

13-16::

  1s 2s set to partner, change places RH to take PH facing CCW, men shoulder to shoulder.

17-20::

  1s 2s dance once round and into diagonal line facing partner BHJ-

21-24::

  Half Poussette.', 3);
INSERT INTO 'dancecrib' VALUES (10405, '2018-01-29 00:02:24.973652+00', '2020-07-18 09:06:27.505955+00', 18219, 2, 2697, 'ace', 'Start positions:



5 - 6 - 7



4 ...... 8



3 - 2 - 1



1st, 3rd, 5th & 7th – Corner persons (Corners)



2nd, 4th, 6th & 8th – Edge persons (Edges)



1-8::

    Edges dance circle 4H round to left ½ way | clap and ret to opp place _while{8}_ Corners chase clw 1 place, clap and dance in; Corners dance circle 4H round to right ½ way; clap and ret. Ending to 36587214

9-16::

    Edges dance petronella to original places _while{8}_ corners set | cast to next corner place clw; _repeat{4}_.  End as 72143658

17-24::

    Edges dance fig of 8 round nearer corners begin LSh to 3rd corner

25-32::

    Edges RHA, clap & LHA ending to 3rd corner

33-40::

    Edges dance ''Hello-Goodbye'' setting ending with a clap & petronella turn to opp places, ending 76183254

41-48::

    All Rubik''s Set & Rotate: all set | Edges rotate singly & dance on 1 edge place clockwise _while{2}_ Corners dance in to end BtoB facing Edge persons; Edges change places RH with Corners | Edges dance on corner place _while{2}_ Corners dance to next edge place clw ending as 47618325', 3);
INSERT INTO 'dancecrib' VALUES (11988, '2019-07-29 14:54:43.54271+00', '2022-04-28 21:27:10.096002+00', 19362, 1, 202, 'ace', '1--::

  1c long cast to 2pl (2c up) ; dance RSh round 1cnrs and face 1cnrs

9--::

  Corners Pass and Turn (2,1,3)

17--::

  1c set | Petronella Turn info facing lines3 ; 3C S&Link (2x,1,3x)

25--::

  Diagonal R&L (3,1,2)

33--::

  All dance toward P, touch NH, dance up back to places ; all turn P BH (3,1,2)', 4);
INSERT INTO 'dancecrib' VALUES (8273, '2014-05-26 20:57:12.95059+00', '2019-11-25 07:03:33.966195+00', 15455, 2, 1, 'ace', '1–::

  1c&3c (in Prom hold) dance round each other passing RS ; continue dancing round to opp pl

9–::

  2c&4c repeat 1–8

17–::

  Grand chain (1 bar per hand) [finish W facing out, M facing in]

25–::

  Schiehallion reel halfway round [finish in original places]

33–::

  All turn partner RH ¾ | W dance LH across halfway _while_ M chase clockwise one pl ; All women turn nearest man RH halfway | M dance LH across halfway _while_ W chase clockwise one pl  [finish in order 2341 to begin again]', 3);
INSERT INTO 'dancecrib' VALUES (11960, '2019-07-08 12:37:20.37828+00', '2019-11-26 01:26:19.942014+00', 19471, 1, 202, 'ace', '1--::

  1c lead down {3}, lead up {3} | cast (2c up) (2,1,3)

9--::

  1c+3c DblFig8, 1c crossing down (2,1,3)

17--::

  1c+2c DblFig8, 1c crossing up (2,1,3)

25--::

  Mirror Reels3 on sides, 1c in and down, 3c out and up. (2,1,3)

33--::

  1c+3c The Espagnole (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (10709, '2018-04-29 20:02:50.728484+00', '2019-11-26 07:25:27.306231+00', 18310, 2, 10819, 'ace', '1-8:: 1s & 2s dance the "Rose Progression":  1L & 2M change places R, cast 1 place clockwise, TB 1/2, face & twirl away _while_ 1M & 2L set, TB 1/2, face & twirl away, cross over to other side (2, 1).
9-16:: Starting from the sidelines, all cpls dance a Gypsy Pousette with partner in Highland Schottische Step with a pivit at the end to face partner on the midline, men facing down, ladies up. 
17-24:: All TR 3/4 with partner, drop hands, pass partner RS to opposite sides, melt into a 1/2 chase clkw to own sides (3, 1, 2).
25-32:: 1s & 2s (bottom cpls) set, TR 1/2 way, 1/2 double figure of eight (1s starting down & in, 2s out & up). ', 5);
INSERT INTO 'dancecrib' VALUES (9840, '2017-05-11 23:38:13.868691+00', '2019-11-26 22:27:07.628394+00', 14332, 1, 202, 'ace', '1--::

 1c turn BH | dance down between 3c ; cast to 2pl | turn LH to face 2cnrs

9--::

 1c+2cnrs Pass&Turn, 1c pass Lsh ; 1c+1cnrs Pass&Turn, 1c pass Lsh to face 4cnrs

17--::

 1c+4cnrs turn BH (to 2,1,3) _while_ 1cnrs set diag | all dance BtoB with P | all set to R, set Adv to L meeting P for

25--::

 3C Allemande (3,1,2)', 5);
INSERT INTO 'dancecrib' VALUES (2860, '2012-01-22 19:30:00.462837+00', '2019-11-27 20:24:38.86626+00', 4679, 1, NULL, 'ace', '1–::

  1M+2W set advancing, turn RH to places ; 1W+2M repeat

9–::

  1c lead down the middle {3} and up, cast off one (2c up) (2,1,3)

17–::

  1c dance down between 3c and cast up to face 1cnrs ; set to 1cnrs, set to 2cnrs

25–::

  Reels3{6} on the sides (Rsh to 2cnr) | 1c cross (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (3212, '2012-01-22 19:30:15.909095+00', '2019-11-27 20:42:54.229378+00', 5906, 1, NULL, 'ace', '1–::

  1c set | cross RH ; cast off | cross up to 1pl

9–::

  2c set | cross RH ; cast up | cross down to 2pl

17–::

  1c followed by 2c lead down ; 2c lead up to 1pl, 1c to 2pl

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (15217, '2022-11-03 01:18:53.948458+00', '2023-02-04 01:18:58.274053+00', 21158, 3, NULL, 'ace', '1-8::
    1s dance down 1 place (2s step up), face & set  in the middle; 1s
    pull back RSh, cast out to own side, round 3rd corner (1M up, 1L
    down) & dance up/down to finish LSh to LSh in the middle
9-12::
    1M+3M+2M also 1L+2L+3L dance RH across, then 1s pass RSh to face 1st
    corner
13-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners passing RSh to
    start, 1s turn RH to face 2nd corner
17-20::
    1s dance 1/2 diagonal reel of 4 with 2nd corners passing LSh to
    start,1s finish RSh to RSh in the middle
21-24::
    1M+2M+3M also1L+3L+2L dance LH across, 1s finish in the middle
    facing each other
25-28::
    1s turn 2H 1.1/2 times and pull back RSh to face out _while_ 3s+2s
    chase anticlockwise 1/2 round
29-32::
    1M+2M+3M also 1L+2M+3M circle 3H round to the left 1/2 way and set', 0);
INSERT INTO 'dancecrib' VALUES (4472, '2013-08-21 08:30:49.334039+00', '2023-02-04 01:18:58.469794+00', 877, 3, NULL, 'ace', '1-8::
    1L casts down Ladies'' side _while_ 1M dances down the middle, 1s
    meet below 4s & lead up to original places
9-16::
    On bar 9 all Men turn by the left to face out with folded arms as in
    hornpipe & on bar 16 turning left face in again _while_ 1L dances
    across in front of her partner, behind 2M, in front of 3M & crosses
    to 3L place (2L+3L step up on bars 15-16)
17-24::
    1M similarly repeats bars 9-16 round the women (who remain facing
    in) to end in 3M place (2M+3M step up on bars 23-24)
25-32::
    1s+4s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (12373, '2019-11-28 13:09:59.22544+00', '2019-11-28 13:12:12.567695+00', 15569, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c R&L (1,2,3,4)

9--::

  Parallel Reels4 on sides (1,2,3,4)

17--::

  1c cast to 4pl (2c+3c+4c up on [19-20]) ; all turn P RH (2,3,4,1)

25--::

  Circle8 and back (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (11134, '2018-09-21 13:08:51.452541+00', '2019-12-01 07:49:43.475963+00', 18656, 1, 202, 'ace', '1--::
  1c long cast (2c up) ; turn LH to face 1cnrs
9--::
  4 bars of SetH&G ; ½ Reel4 on 2diag, 1c face 2cnrs (no pass)
17--::
  4 bars of SetH&G, 1c face 3cnrs ; ½ Reel4 on 1diag, 1c to 2pl facing clw (2x,1,3x)
25--::
  All chase clw ½ ; 2c & 3c turn P RH _as_ 1c turn P RH 1½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12375, '2019-11-30 01:00:51.245329+00', '2019-11-30 01:04:11.741588+00', 8310, 1, 202, 'ace', '1--::
  1c set advancing into BtoB | turn 2c EH ½ (to 2,1x) ; 1c repeat [1-4] (1,2)
9--::
  1c & 2c set | Petronella turn to midline ; repeat [9-12] (1x,2x)
17--::
  1c & 2c set | La Baratte (1,2)
25--::
  1c cast off | ½ Fig8 up round 2c (2c up on [29-30]) | cross RH (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (11346, '2018-11-22 08:57:34.445628+00', '2020-08-29 11:55:30.621139+00', 308, 1, 202, 'ace', '1--::

  1c lead down and cast up round 2c ; turn BH (1,2)

9--::

  2c repeat [1-8] with 1c (1,2)

17--::

  1M+2W turn BH ; 1W+2M turn BH (1,2)

25--::

  1c+2c set | ½ R&L  | turn P RH ½ (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (8554, '2015-02-13 12:47:30.743781+00', '2023-02-04 01:18:58.496322+00', 15614, 3, NULL, 'ace', '1-8::
    1s set & cast (2s step up); turn LH to face 2L in tandem (1L in
    front of 1M)
9-12::
    1s dance a 1/2 diagonal Tandem reel of 3 with corners
13-16::
    1s dance 1/2 reels of 3 across, 1L with 2M+3M (at top) LSh to 2M,
    1M with 2L+3L LSh to 2L. 1s end facing Mens 1st crnr (pstn) (1M in
    front of 1L)
17-24::
    1s dance a 1/2 diagonal Tandem reel of 3 with corners; 1s dance up
    to top (1M ahead of 1L) & cast to 2nd places opposite sides facing
    down
25-32::
    3s followed by 1s+2s (who dance down) lead up to top, cross & dance
    down own sides to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12374, '2019-11-30 00:46:54.898713+00', '2021-03-20 19:44:02.829286+00', 8309, 1, 202, 'ace', '1--::

  1c+2c S&Rotate (2,1)

9--::

  RHA ; LHA (2,1)

17--::

  1W followed by 1M casts up |dances across to 1plx (2c down) ; 1c set | cross RH (1,2)

25--::

  »modified Rondel« [: 1-2 under arch | 3-4 cross and loop ; 5-6 set | 7-8 cross LH] (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (9625, '2017-02-27 15:00:12.001984+00', '2019-11-29 00:58:16.795549+00', 17622, 1, NULL, 'ace', '1--::

    1c lead down the middle and up {6} | cast off (2c up) and face 1cnr

9--::

    »modified Corners Pass and Turn« [same as Corners Pass and Turn except that cnrs turn RH ½, face each other and cast away to exchanged places] ; repeat with 2cnrs (3x,1x,2x)

17--::

    Diagonal R&L (2,1x,3)

25--::

    ½ Fig8 L (W up, M down) ; 1c+3c S&Link (2,3,1)', 3);
INSERT INTO 'dancecrib' VALUES (4473, '2013-08-21 08:30:49.342379+00', '2023-02-04 01:18:58.515648+00', 13686, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH & cast 1 place, 1s & 3s dance down between couples
    below & cast up to end BtoB with partners facing out
9-16::
    1s & 3s dance Double Triangles with 2s+4s+5s & BtoB with partners
    facing opposite sides
17-24::
    1s & 3s turn 1st corners RH & pass partner RSh to face 2nd corners,
    1s & 3s turn 2nd corners RH to end on opposite sides between corners
    & all set
25-32::
    2s+1s+4s+3s+5s Adv+Ret, 1s & 3s cross RH & cast 1 place', 0);
INSERT INTO 'dancecrib' VALUES (13047, '2020-08-10 00:18:48.817729+00', '2023-02-04 01:18:58.775477+00', 18390, 3, NULL, 'ace', '1-8::
    1s+2s set, pull back RSh & chase 1 place clockwise (1s on Ladies''
    side, 2s on Men''s side); 1s turn 2s 1.1/2 RH
9-16::
    1s+2s dance R&L finishing facing partner on 1st corner diagonal 2H
    joined ready for …
17-24::
    1s+2s dance "Hello-Goodbye Poussette":
::
    _17-18_   All set (start right foot) moving on 2nd step into line
    across (1M+2L BtoB)
::
    _19-20_    Repeat, moving on 2nd step into line on second corner
    diagonal (1L+2M BtoB)
::
    _21-22_    Repeat, moving on 2nd step into line up/down (2L+1M BtoB)
::
    _23-24_    2s+1s 1/2 turn 2H, to face partner, Ladies facing down,
    Men facing up
25-32::
    2s+1s dance 6 bars of reel of 4, 2M followed by 1M also 1L followed
    by 2L dance up/down own sides to end 2 1', 0);
INSERT INTO 'dancecrib' VALUES (10439, '2018-02-24 07:52:12.270125+00', '2023-02-04 01:18:58.799352+00', 15654, 3, NULL, 'ace', '1-8::
    1M followed by 2M+3M dance across top, down behind Ladies, up middle
    _while_ 1L+2L+3L stand 4 bars then set advancing (2 bars), pull back
    RSh (rotate 2 bars) to join NH with partner in middle
9-16::
    1s+2s+3s promenade ending with 1s casting to finish in centre LSh to
    LSh facing opp sides _while_ 2s dance up to 1st place
17-24::
    "Snake Pass" figure:
::
    1L+2s (at top) & 1M+3s dance RH across. 1L followed by 2s also 1M
    followed by 3s pass LSh diagonally across through 2nd place to
    change ends & loop round to left to end 3 1 2
25-32::
    1s turn LH (4 bars) to sidelines, 1M faces down, 1L faces up.
    3s+1s+2s dance 1/2 LSh reel of 3 on sides (1M+2M & 1L+3L pass LSh to
    start) 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13734, '2021-03-02 01:19:00.28575+00', '2023-02-04 01:18:58.814708+00', 12159, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place (2s step up 3-4); 1s turn 1.1/2 LH to 2nd
    place, 1M facing out/up, 1L facing out/down.  2 (1) 3
9-16::
    1s dance 1/2 reel of 3 giving LSh to 2nd corners; 1s pass LSh in the
    centre to dance 1/2 reel of 3 on own side giving LSh to 4th corners.
    End in lines of 3 across (1L between 2s facing down, 1M between 3s
    facing up) (2s&3s dance 8 bar reels on own side)
17-24::
    All Adv+Ret; 1s turn 1.1/4 RH to 2nd place own side
25-32::
    All Adv+Ret; 1s turn RH.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12061, '2019-08-29 07:49:46.797817+00', '2019-12-03 19:07:36.391488+00', 560, 1, 202, 'ace', '1--::

  1c+2c & 3c+4c ½ R&L ; 1c+2c & 3c+4c RHA (2x,1x,4x,3x)

9--::

  1c+4c ½ R&L ; LHA finishing in centre facing nearest cnrs (2x,4,1,3x)

17--::

  »Corners Petronella round a Double Hello Goodbye Setting« [: All 4 cnrs Petronella Turn to next cnr place cclw _while{2}_  4c+1c 2 bars of SetH&G | NHJ in circle, all set. On [19] 4c+1c release LH to dance PdB L of SetH&G back to centre facing again same cnr ; repeat bars 17-20] (3,1x,4x,2)

25--::

  1c & 4c turn facing cnrs RH ; 1c+4c ½ LHA to sides | all set (3,4,1,2)

33--::

  3c+4c+1c BHJ slip down under 2c arch ; 2c+3c+4c+1c slip up to sides (2,3,4,1)', 4);
INSERT INTO 'dancecrib' VALUES (12376, '2019-12-01 14:56:46.836149+00', '2019-12-01 15:03:47.182403+00', 19204, 1, 202, 'ace', '1--::
  1c lead down (2c up on [3-4]) ; change sides {2} _while_ leading up, W passing under joined arms, to 2plx (2,1x,3)
9--::
  ½ Mirror Reels3 on sides, 1c out and up (to 3,1x,2) ; 3c & 2c turn RH ½ into centre, NHJ facing each other | all set (*3x*,1x,*2x*)
17--::
  1c Petronella turn to middle ends | set ; repeat [17-20] to 2pl _while{8}_ 3M & 2W Petronella turn to 2pl | set ; Petronella turn | set NHJ with P on their left _while{8}_ 3W & 2M cast R and chase clw ½ {6} | set NHJ with P on their right (*2x*,1,*3x*)
25--::
  All repeat [17-24] from new positions and finish as on [17] (*3x*,1x,*2x*)
33--::
  1c dance on sides to top and cross no hands to 2pl _while{4}_ 2c cross to 2pl and cast up to 1pl  _while{4}_ 3c cross to 2pl in front of 2c and cast down to 3pl (to 2,1,3) ; all turn P RH (2,1,3)
', 2);
INSERT INTO 'dancecrib' VALUES (12377, '2019-12-02 22:51:13.354241+00', '2019-12-08 22:55:50.898077+00', 19786, 2, 1645, 'ace', '*Round the room: 1c face cclw, 2c face clw*

1-::

  1c+2c RHA ; LHA

9-::

  1M+2W &frac12; fig8 round outside dancers ; 1W+2M repeat round insiders (2,1)

17-::

  R&L, start & end facing partner (2,1)

25-::

  Advance & retire to partner ; turn or birl partner (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (4529, '2013-08-21 08:30:50.135737+00', '2023-02-04 01:19:02.563115+00', 974, 3, NULL, 'ace', '1-8::
    1s lead down for 3 steps, lead up to top, cross & cast to 2nd place
    opposite sides (2s step up 7-8)
9-16::
    1s+ 2s dance Ladies'' Chain
17-24::
    1s set, cast up & turn 2H
25-32::
    1s lead down, cross & cast up own sides & dance 1/2 Diamond
    Poussette with 2s', 0);
INSERT INTO 'dancecrib' VALUES (8398, '2014-09-03 14:38:49.69972+00', '2019-12-04 11:12:18.010237+00', 1696, 2, 2088, 'ace', '1-4:: All set cross RH

5-8:: 1c & 2c; 3c & 4c Four Hands Round to left (finish 1,2,3,4 on partners side of set).

9-12:: 2c & 3c set cross LH

13-16:: 2c & 3c Four Hands Round to right (finish own side)

17-20:: 1c & 4c cross RH and cast one place (1c down, 4c up - 2c & 3c move up/down)

21-24:: 2c 1c 4c & 3c 2 Hand Turn clockwise (finsh 2c & 1c facing down partner on left, 4c & 3c facing up partner on right)

25-32:: Two Double Figures of Eight (1c & 4c cast Up/down while 2c & 3c lead up/down and cross)

33-40:: Grain Chain 1 step per hand (begin 2c & 3c facing across the dance, 1c facing down, 4c facing up finish 2,1,4,3)

', 2);
INSERT INTO 'dancecrib' VALUES (12860, '2020-06-03 16:25:21.834628+00', '2023-02-04 01:18:58.847606+00', 19826, 3, NULL, 'ace', '1-8::
    1s cast (2s step up), dance down below 3s & cast up to face 1st
    corners
9-16::
    _9-10_    1s+1st corners set
::
    _11-16_  1s cast round each other to partner''s 1st corner position &
    face out, 1L curves to right & dances up between 3s, 1M  curves to
    right & dances down between 2s, 1s turn RH to face 2nd corners
    _while_ 1st corners dance in, turn RH, dance out to place & set
17-24::
    _17-18_   1s+2nd corners set
::
    _19-24_   1s cast round each other to partner''s 2nd corner position
    & face out, curve to right, dance through 2nd place own side & cross
    RH to end  on opp sides, 1L facing up, 1M down _while_ 2nd corners
    dance in, turn RH, dance out to place & set.  2 (1) 3
25-32::
    2s+1s+3s dance reels of 3 on sides (1s RSh to 1st corners to start).
    Bars 31-32: 1s cross diagonally to 2nd place own side (1L from 3M''s
    place, 1M from 1L''s place).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15056, '2022-09-05 00:18:49.458258+00', '2023-02-04 01:18:58.877123+00', 20908, 3, NULL, 'ace', '1-8::
    1s set, dance down NHJ (2s step up 3-4); 1s cast up round 3s to 2nd
    place own side & set advancing to face 1st corner
9-16::
    1s turn 1st corner RH & face 2nd corner; 1s dance 1/2 LSh reel of 3
    on sides (LSh to 2nd corner to start). 1s end facing 3rd corner
17-24::
    1s turn 3rd corner RH & face 4th corner; 1s dance 1/2 LSh reel of 3
    on sides (LSh to 4th corner to start). End 1L between 2s facing
    down, 1M between 3s facing up
25-32::
    In lines of 3 across all set, 1s Petronella turn to 2nd place opp
    side; all set & 1s cross RH to 2nd place own side.', 0);
INSERT INTO 'dancecrib' VALUES (15408, '2023-02-04 01:18:59.001203+00', '2023-02-04 01:18:59.002653+00', 20298, 3, NULL, 'ace', '1-8::
    1s cross down RH & cast up to 1st place opp sides _while_ 2s dance
    up & cross down RH to 2nd place opp sides; 1s+2s turn 1.1/2 on sides
    (Men LH, Ladies RH)
9-16::
    1s+3s repeat 1-8 with 1s+3s turning 1.1/2 on sides (1L+3M RH, 1M+3L
    LH) to end (2) 1 (3)
17-24::
    _6_ bars RSh reels of 3 on sides (1s RSh to 3rd corner pstn), Bars
    23-24: 1s cross to 2nd place opp sides.  (2) (1) (3)
25-32::
    2s+3s Petronella turn & set twice _while_ 1s chase anticlockwise
    round 1 place, cross between 2s/3s (as they are setting), chase to
    2nd place own side & all set', 0);
INSERT INTO 'dancecrib' VALUES (4478, '2013-08-21 08:30:49.464837+00', '2023-02-04 01:18:59.193887+00', 888, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 on own sides
9-16::
    1s cross down to dance reflection reels of 3 on opposite sides & end
    in 2nd place BtoB facing opposite sides
17-24::
    1s dance Double Triangles to end facing down (Lady on Mans right)
25-32::
    1s dance down, Lady dances under Mans arm & dance up to 2nd place
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (4480, '2013-08-21 08:30:49.481414+00', '2023-02-04 01:18:59.268285+00', 889, 3, NULL, 'ace', '1-8::
    1s+2s dance the Tourbillon:
::
    1s & 2s turn partners 2H 1/2 way, 1M & 2L lead partners on 1 place
    clockwise to end 1s on Ladies'' side & 2s on Men''s side, 1s set to 2s
::
    1s & 2s 1/2 turn partners 2H, 1L & 2M lead partners on 1 place to
    end 2s in 1st pl & 1s in 2nd pl & 2s+1s cross RH to own sides. 1s
    face out
9-16::
    2s+1s+3s dance reels of 3 on sides (1s give RSh to person on right)
    & end with 1M facing up between 3s, 1L between 2s facing down
17-24::
    1s set, turn RH, 1L dances up between 2s _while_ 1M dances down
    between 3s & cast to 2nd place on own side
25-32::
    2s+1s+3s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4482, '2013-08-21 08:30:49.499507+00', '2023-02-04 01:18:59.323482+00', 890, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set, circle 4H round to left, 1s & 4s cast in 1
    place
9-16::
    2s+1L also 4M+3s dance RH across _while_ 1M+4L turn LH, 2s+1M also
    4L+3s dance LH across _while_ 1L+4M turn LH 1s & 4s ending in line
    up/down middle (Men facing up)
17-24::
    1s+4s set to partner, dance 1/2 reel of 4 up/down & 3/4 turn partner
    RH.  2 4 1 3
25-32::
    2s+4s also 1s+3s dance double Fig of 8  (1s & 4s casting to start)', 0);
INSERT INTO 'dancecrib' VALUES (4483, '2013-08-21 08:30:49.507693+00', '2023-02-04 01:18:59.355697+00', 893, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & cross RH; all set & cross back RH, 2s face out
9-12::
    1s 1/2 turn RH moving down to 2nd place & face up NHJ _while_ 2s
    dance up & turn to face 1s NHJ, 1s+2s set
13-16::
    1s+2s dance 1/2 RH across, 1s cast down to 2nd place _while_ 2s lead
    up & cross to 1st place own side
17-20::
    1s cross RH, 1M casts down round 3L to face up in centre & 1L casts
    up round 2M to face down in centre _while_ 2s+3s set facing
    diagonally in & advance 1 step to form a circle, retire 1 step to
    sides  (2M+3M & 2L+3L retain hands on sides)
21-24::
    1s change places LH up/ down set, 1M casts down round 2M as 1L casts
    up round 3L to 2nd place own sides _while_ 2s+3s set on sides &
    advance 1 step, retire with partner 1 step (up & down in centre) to
    end 2s at top facing down, 3s at bottom facing up. 2 1 3
25-32::
    2s+1s+3s set & circle 6H round to left, dance in, pull back RSh
    spiral out clockwise to places', 0);
INSERT INTO 'dancecrib' VALUES (10440, '2018-02-24 07:52:12.432373+00', '2023-02-04 01:18:59.386642+00', 15770, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s cast & 2s lead up to top, 1s pass LSh to
    face 1st corners
9-24::
    1s dance Corner Chain with 1st & 2nd corners :
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s who finish in centre, 1L facing up,
    1M facing down
25-32::
    1L+2s & 1M+3s dance reels of 3 across, (1s LSh to 1st corners to
    start) Finish 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4484, '2013-08-21 08:30:49.514037+00', '2023-02-04 01:18:59.407615+00', 8863, 3, NULL, 'ace', '1-8::
    All 1/2 turn RH, join hands with corners & set (Men facing out &
    Ladies in), 1/2 turn RH, join hands with corners & set (Men facing
    in & Ladies out)
9-16::
    Ladies dance RSh round partners into centre & dance LH across 1/2
    way, dance RSh round opp Man to next Man & turn RH into prom hold
17-24::
    All Promenade clockwise
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6797, '2013-08-21 08:31:31.064765+00', '2022-10-04 19:05:06.835424+00', 8475, 3, NULL, 'ace', '1-8::

    1s+2s dance R&L

9-16::

    1s lead down crossing below 2s & cast to top, 1s cross RH & cast to

    2nd place

17-24::

    2s+1s set & cross RH, 2s+1s set & 1/2 turn RH for…

25-32::

    2s+1s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (15409, '2023-02-04 01:18:59.471803+00', '2023-02-04 01:18:59.472952+00', 19811, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s
9-16::
    2s+1s+3s dance mirror reels of 3 on sides (1s in/down, 2s out/down,
    3s out/up)
17-24::
    2s+1s+3s dance Set+Link for 3 couples twice. (3) 1 (2)
25-32::
    Diag R&L for 3 couples (Man down, Lady up). 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4486, '2013-08-21 08:30:49.530253+00', '2023-02-04 01:18:59.504906+00', 896, 3, NULL, 'ace', '1-8::
    1s dance reflection reels on own sides (1s out & down to start) with
    1s casting to 2nd place at end
9-16::
    1s pass RSh to end BtoB in middle, Man facing down & Lady up for
    Crown triangles
17-24::
    1s pass LSh around person on their L to end in 2nd place own side &
    dance RH across (Man with 3s & Lady with 2s)
25-32::
    2s+1s+3s circle 6H round to left & turning round to left dance 6H
    back', 0);
INSERT INTO 'dancecrib' VALUES (12811, '2020-05-14 23:13:07.719247+00', '2023-02-04 01:18:19.315404+00', 19938, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance 1/2 reels of 3 across (1M+3L &
    1L+2M pass LSh to start)
9-16::
    2s+1s+3s dance Set & Rotate for 3:
::
    Set & rotate singly & chase 1 place clockwise, all change places RH
    with opposite person & chase clockwise to opp sides.  (3) (1) (2)
17-24::
    3s set & cast to 3rd place _while_ 2s dance in, NHJ dance up & cast
    into 1st place; 2s+1s+3s 1/2 turn partner RH, pull back RSh & dance
    out to own sides
25-32::
    2s+1s+3s circle 6H round & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9909, '2017-06-05 11:30:48.612941+00', '2023-02-04 01:18:59.650346+00', 15676, 3, NULL, 'ace', '1-8::
    1s+2s set advancing & turn 2H to face down.  2s+1s dance down below
    3s, cast up to end 2s in 1st place, 1s in 2nd place own sides
9-16::
    1s dance up between 2s, cast to 2nd place, turn RH to end in 2nd
    place facing out
17-24::
    2s+1s+3s dance RSh reels of 3 on sides (1L down, RSh to 3L, 1M up,
    RSh to 2M).  Bars 23-24 1s cross (1L from 1st place, 1M from 3rd
    place) to 2nd place opp sides
25-32::
    2s+1s+3s dance LSh reels of 3 on sides (1L down, LSh to 3M, 1M up,
    LSh to 2L).  Bars 31-32 1s cross (1L from 1st place, 1M from 3rd
    place) to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4489, '2013-08-21 08:30:49.564128+00', '2023-02-04 01:18:59.669464+00', 898, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 reels of 3 across (1L with
    2s, 1M with 3s) & end facing 4th corner pstn
9-16::
    1s set to corners & turn RH, 1s dance LH across with 3rd corner
    pstns & end facing 3rd corner pstn _while_ 2M+3L chase clockwise 1/2
    way
17-24::
    1s set to corners & turn RH, 1s dance LH across with 4th corner
    pstns & end facing 4th corner pstn _while_ 1M+2L chase clockwise 1/2
    way.  3 1 2
25-32::
    All set & turn 2H then all set', 0);
INSERT INTO 'dancecrib' VALUES (4491, '2013-08-21 08:30:49.580294+00', '2023-02-04 01:18:59.690155+00', 900, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s lead down the middle for 3, lead back to top & cast to 2nd place
    own sides (2s step up 15-16)
17-24::
    1s turn 1st corners RH & return to 2nd place own side, turn 2nd
    corners LH & return to 2nd place own side
25-32::
    1s dance RH across (Lady with 2s & Man with 3s), & dance LH across
    with other couple 1s end in 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (13395, '2020-12-02 01:18:55.638626+00', '2023-02-04 01:18:59.92262+00', 9227, 3, NULL, 'ace', '{{explanation}}
2 Chords - 2nd chord: 1M stands as 1L crosses to 2M''s place, 2M to partner''s place, 2L steps up, 3s & 4s move likewise (As »Glasgow Highlanders«)

1-8::
    All set to partner & turn 2H; 1s+2s also 3s+4s circle 4H round to
    left
9-16::
    All set on sides, all circle 8H round to left back to place
17-20::
    1s+2s also 3s+4s dance RH across
21-24::
    All Set+Link with partner, Men face out & join RH with partner, LH
    with neighbour couple on sides
25-28::
    All Bal-in-Line (HS):
::
    All dance 1st bar of Highland schottische with right foot
::
    Drop left hands & all move to right joining LH with partner (under
    their RH) then drop RH & join RH with neighbour couple
::
    All repeat HS with left foot & drop hands in centre, all move to
    left to face partner up/down on sides
29-32::
    All dance 1/2 reels of 4 on sides, finish facing partner on sides.
    3s & 4s now at top, 1s & 2s at bottom', 0);
INSERT INTO 'dancecrib' VALUES (4496, '2013-08-21 08:30:49.704484+00', '2023-02-04 01:19:00.336294+00', 908, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 4s & 5s & 6s cross to opp sides

1-8::
    1s+2s+3s also 6s+5s+4s dance RSh reels of 3 on sides:
::
    To start:1M dances across to pass 2L RSh, 1L crosses down, passing
    2M RSh
::
    At end: 1M crosses up from 2nd place opp side, pull back RSh to face
    in, 1L dances across from 1st place opp side to original place
    facing out
::
    6s dance similarly with 5s+4s.  3L+4L finish facing out
9-12::
    1s+2s also 3s+4s also 5s+6s dance RH across
13-16::
    1s & 6s cast in 1 place & 1/2 turn partner LH into prom hold,
    _while_ 2s & 5s dance to ends & set, _while_ 3s+4s dance LH across
17-24::
    1s set to 3L & 6s set to 4L, 1s set to 6s, 1s set to 3M & 6s set to
    4M, 1s set to 6s & face partner _while_ 3s & 4s set to partners &
    face up/down
25-32::
    1s+3s+4s+6s dance 6 changes of Grand Chain (1 bar per hand), 1s & 6s
    full turn RH _while_ 3s & 4s cross RH.  2 3 6(1)(4)(5)', 0);
INSERT INTO 'dancecrib' VALUES (4497, '2013-08-21 08:30:49.712586+00', '2023-02-04 01:19:00.374068+00', 909, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on opposite sides (1M crosses to give RSh to 2L
    & 1L crosses down giving LSh to 3M)
9-16::
    1s dance reels of 3 on own sides (1L crosses to give RSh to 2L & 1M
    crosses down giving LSh to 3M)
17-24::
    1s set to 2L, set facing down, set to 2M & back to places
25-32::
    1s+2s set & dance RH across 1/2 way, set & dance LH back to places
33-40::
    1s cross RH, cast 1 place & turn LH 1.1/2 times to own sides
41-48::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4498, '2013-08-21 08:30:49.720665+00', '2023-02-04 01:19:00.408246+00', 910, 3, NULL, 'ace', '1-8::
    1s set, 1M followed by partner casts & crosses to 2nd place opposite
    side, 2s+1s set.  2 (1) 3
9-16::
    1s set, 1L followed by partner casts & crosses to 3rd place own
    side, 3s+1s set. 2 3 1
17-24::
    1s dance up to top & cast, dance down between 3s & cast up to face
    1st corners
25-32::
    1s set to 1st corners & turn 2H, set to 2nd corners & turn 2H
33-40::
    1s dance reels of 3 on opposite sides (1s giving LSh to 1st corner
    to start) & cross back to own side 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (4499, '2013-08-21 08:30:49.728707+00', '2023-02-04 01:19:00.438959+00', 13449, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, 2s followed by 1s dance down between
    3s & cast  (2s to top place & 1s to 2nd place)
9-16::
    1s dance diag R&L.  (1M down / 1L up)  (3)1(2)
17-24::
    1s dance 1/2 Figs of 8 (1L up round 3s, 1M round 2s), all set & 1/2
    turn partner RH
25-32::
    All dance 3 couple Allemande ending with 1s casting to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (4500, '2013-08-21 08:30:49.736832+00', '2023-02-04 01:19:00.464879+00', 8024, 3, NULL, 'ace', '1-8::
    1s & 2s petronella turn into middle (Ladies face down & Men up), set
    & dance 1/2 reel of 4 up & down the middle
9-16::
    2s & 1s set & petronella turn onto own sides, 2s+1s+3s Adv+Ret
17-24::
    1L dances RH across with 2s & 1M with 3s, 1s turn LH 1.1/2 times to
    face 1st corner person as 2s & 3s chase cl''wise 1/2 way round
25-32::
    1s dance 1/2 diagonal reel of with 1st corners, passing RSh dance
    1/2 reel with 2nd corners 1s end in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (8555, '2015-02-13 12:47:31.292856+00', '2023-02-04 01:19:00.582115+00', 15615, 3, NULL, 'ace', '1-4::
    1M+2L also 3M+4L cross RH as partners set & 1s+2s dance on 1 place
    clockwise as 3s+4s dance similarly
5-8::
    1L+2M also 3L+4M cross RH as partners set & 1s+2s dance on 1 place
    clockwise as 3s+4s dance similarly  1 2 3 4
9-16::
    1s dance reels of 3 on sides then 2s dance to top as 3s+4s change
    places LH & 1s face 1st corners  2 1 4 3
17-24::
    1s dance »Hello-Goodbye« setting & end with a petronella turn 2nd
    place own sides
25-32::
    1s+4s+3s dance the Knot  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9633, '2017-03-04 12:45:35.7806+00', '2022-10-04 19:05:06.838511+00', 8475, 1, 202, 'ace', '1--::

 1c+2c R&L

9--::

 1c lead down between 2c, cross and cast up ; cross RH and cast (2,1)

17--::

 2c+1c set | cross RH ; set | turn P RH ½ into promhold facing up

25--::

 2c+1c Promenade', 3);
INSERT INTO 'dancecrib' VALUES (12381, '2019-12-05 01:29:01.585877+00', '2023-02-04 01:18:56.049521+00', 19417, 3, NULL, 'ace', '1-8::
    1s+2s set & petronella in tandem; petronella in tandem again to opp
    sides & cross RH with partner. 2 1 3
9-16::
    All dance Set+Link for 3 couples; 1s dance 1/2 Diag R&L (1M down, 1L
    up to start)
17-24::
    All repeat 9-16 to end (3) (1) (2)
25-32::
    All Advance (1), Retire (1) & repeat; All 1/2 turn partner 2H, pull
    back RSh & dance (curve) out to own side.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4504, '2013-08-21 08:30:49.864098+00', '2023-02-04 01:19:00.604231+00', 917, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance RH across opening out to circle 8H round 1/2 way
    ending 4 3 2 1 on opposite sides
9-12::
    4L+3L also 2L+1L dance between partners, divide & dance back to end
    Ladies facing each other for reel of 4 on side (Mens)
13-16::
    Ladies dance 1/2 reel of 4
17-24::
    Men repeat bars 9-16 passing between Ladies who are not their
    partners
25-32::
    1s cross RH & cast to 4th place _while_ 2s+3s+4s set & cross up RH,
    all turn 2H once round', 0);
INSERT INTO 'dancecrib' VALUES (12907, '2020-07-01 00:18:50.144291+00', '2023-02-04 01:19:00.627556+00', 13212, 3, NULL, 'ace', '1-8::
    1s+2s+4s+5s set, 1s+2s also 4s+5s dance 3/4 double Fig 8, 1s cross
    down, 2s dance up, 5s cross up, 4s dance down.  (2) 1 3 5 (4)
9-16::
    2s+1s dance RH back to back Knot _while_ 5s+4s dance LH Back to Back
    Knot:
::
    2s+1s 1/2 turn RH to BtoB in centre, 2s facing up, 1s facing down.
    Take allemande hold & then dance as per Knot (1s dance up Ladies''
    side, 2s down Men''s side)
::
    5s+4s dance similar, 1/2 turn LH to BtoB, 5s facing up, 4s facing
    down. Take allemande hold & dance as per Knot (5s dance down Ladies''
    side, 4s up Men''s side)
17-24::
    1s & 5s set, 1/2 turn RH & chase to opp end of set _while_ 2s+3s+4s
    dance Grand Chain (2s cross to start).  5 (2) 3 (4) 1
25-28::
    5s+2s+3s+4s dance 1/2 mirror reels of 4 on sides (5s & 3s in/down,
    2s & 4s out/up). 2s cross to own side from top, 5s curve to 4th
    place (4) 3 2 5 1
29-32::
    4s+3s+2s dance 1/2 mirror reels of 3 on own sides (4s start by
    crossing down to own side). End 2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (4505, '2013-08-21 08:30:49.872247+00', '2023-02-04 01:19:00.644657+00', 924, 3, NULL, 'ace', '1-8::
    1s+2s+3s+4s cross RH, 1s+2s also 3s+4s 1/2 circle 4H left,
    1s+4s+3s+5s cross LH, 1s+4s also 3s+5s 1/2 circle 4H right.  2 4 1 5
    3
9-16::
    All dance 1/2 Grand Chain (2s at top cross) for 6 bars (to 3 5 1 4 2
    on opp sides), 3s+1s (1st & 3rd pl) 3/4 turn 2H into middle _while_
    other couples full turn 2H to sides
17-24::
    3s+1s dance 1/2 reel of 4 in centre, 1/2 circle 4H to left & turn RH
    to own sides.  3 5 1 4 2
25-32::
    All 1/2 circle 10H to left for 6 bars, 3s & 1s turn RH _while_ 5s,
    4s & 2s 1/2 turn 2H all to own sides.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (4507, '2013-08-21 08:30:49.893651+00', '2023-02-04 01:19:00.850328+00', 8924, 3, NULL, 'ace', '1-8::
    1s set, turn RH 1.1/2 times & cast 2 places opposite side
9-16::
    3s+1s set & dance 1/2 RH across, 2s+1s set & dance 1/2 RH across
17-24::
    1s cross down to 3rd place & dance reels of 3 on own sides (1s out &
    up, 3s in & down to start) & 1s turn LH to face 3rd corners
25-32::
    1s turn 3rd corners RH, partner LH, 4th corner RH & partner LH to
    face 3rd corner
33-40::
    1s dance 1/2 diagonal reel with 3rd corners & 1/2 diagonal reel with
    4th corners
41-48::
    3s+1s+2s circle 6H round & back to end 3 1 2
::
    2nd time through, ends 3 4 1 2, 1s step to bottom & 3s become new 1s', 0);
INSERT INTO 'dancecrib' VALUES (4508, '2013-08-21 08:30:49.90179+00', '2023-02-04 01:19:00.876203+00', 929, 3, NULL, 'ace', '1-8::
    1s set & cross down RH, 1s cast RSh round 1st corners & 1/2 turn RH
    in centre
9-16::
    1s dance the Snake Pass: 1s dance LH across (1M with 2s & 1L with
    3s), 1M followed by 2s also 1L by 3s cross diagonally passing RSh to
    change ends & loop round to right to end 3 1 2
17-24::
    3s+1s+2s circle 6H to Left, casting to left chase back to own sides
25-32::
    3s+1s+2s 1/2 turn LH & set (retaining hands), all cast to chase
    clockwise 1/2 way to end on own sides 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14202, '2021-08-14 00:18:55.191137+00', '2023-02-04 01:19:00.902923+00', 12162, 3, NULL, 'ace', '1-4::
    1s+2s set. 2s cast up to 1st place _while_ 1s lead down & cross to
    2nd place opp sides facing 3s
5-8::
    2s set to partners & turn 2H _while_ 1s set to 3s & turn 2H. 1s
    finish facing up
9-16::
    2s+1s dance Ladies'' Chain. At the end 1s pass RSh to face 1st
    corners
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass LSh to dance
    1/2 reel with 2nd corners. 1s finish in 2nd place opposite sides (3)
    (1) (2)
25-26::
    3L+2M set (1st corner positions) _while_ 1L+3M also 1M+2L change
    places RH diagonally
27-28::
    1s set (2nd corner positions) _while_ 3L+2L also 3M+2M change places
    RH diagonally
29-30::
    2L+3M set (1st corner positions) _while_ 1L+3M also 3L+1M change
    places RH (2) (1) (3)
31-32::
    2s+1s+3s cross RH to own sides 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4509, '2013-08-21 08:30:49.909883+00', '2023-02-04 01:19:00.931534+00', 932, 3, NULL, 'ace', '1-8::
    1s+2s set & dance RH across 1/2 way, 1s+3s set & dance LH across 1/2
    way
9-16::
    1s set & cast up to 2nd place, 1s dance up between 2s & cast to 2nd
    places
17-24::
    1s cross down to dance 1/2 double Fig of 8 with 3s, 1s cross up to
    dance a double Fig of 8 with 2s
25-32::
    1s dance LSh reels of 3 across (1L with 2s, 1M with 3s)  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11734, '2019-03-26 02:05:01.857065+00', '2023-02-04 01:19:00.97811+00', 17949, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All petronella turn into centre & set; all petronella turn to opp
    sides & set
9-16::
    1s+2s & 3s+4s circle 4H round to left; all join hands on sides & set
    & cross RH with partner to own sides.  All clap twice on last 2
    beats bar 16

{{title}}
Reel

17-24::
    All set (no hands), 1s cross RH & cast to bottom, cross RH to 4th
    place own sides (2s+3s+4s step up bars 5-6)
25-32::
    All clap 8 times (4 bars); All turn partners (birl).  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4511, '2013-08-21 08:30:49.927688+00', '2023-02-04 01:19:01.111307+00', 936, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, 1s dance 1/2 Fig of 8 round 3s back to
    2nd place on own sides
9-16::
    1s cross LH, cast up on opposite sides & dance 1/2 Fig of 8 round 2s
    end with Lady facing down between 2s with partner behind her
17-24::
    1L followed by ptnr dance down & out between 2L+3L, cast behind 3L,
    cross & cast up round 3M, lead up between 2s & cast to 2nd pl own
    sides
25-32::
    1s+3s facing on sides set & turn 2H, 2s+1s dance 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (4510, '2013-08-21 08:30:49.919616+00', '2023-02-21 13:09:24.431278+00', 934, 3, NULL, 'ace', '1-8::

    1s lead down to bottom & back to end on Men''s side (Lady on partners

    right), 2M crosses to partners place on bar 8 as 2L steps up

9-16::

    1s+2s dance reel of 4 across Ladies passing LSh to begin & end

    facing partners on sides

17-24::

    1s+2s dance round each other with HS steps to end on own sides with

    1s in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (9635, '2017-03-04 13:58:47.866438+00', '2022-10-04 19:09:34.924139+00', 8470, 1, 202, 'ace', '1--::

  1M+2W set | change places RH ; 1W+2M set | change places RH. 1c & 2c face on sides (2x,1x)

9--::

 All set to opposite | all change places RH ; 1c+2c set | cross RH (1,2)

17--::

 1c set | cast ; 1c & 2c dance BtoB

25--::

 1c Fig8 up round 2c (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (4442, '2013-08-21 08:30:48.954401+00', '2023-02-04 01:18:56.550501+00', 13230, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 2s+1s+3s turn RH (4 bars)
9-16::
    1s dance 1/2 reel of 4 with 1st corners & 1/2 reel of 4 with 2nd
    corners (1s end in 2nd place opposite sides)
17-24::
    All Set+Link for 3 twice
25-32::
    2s+1s+3s circle 6H to left, pivot & circle right back to places', 0);
INSERT INTO 'dancecrib' VALUES (4512, '2013-08-21 08:30:49.937647+00', '2023-02-04 01:19:01.246078+00', 940, 3, NULL, 'ace', '1-8::
    1s cross down to 3rd place & cast up to 2nd place _while_ 3s cast up
    to 1st place & cross RH _while_ 2s set & cross down to 3rd place, 1s
    dance 1/2 Fig of 8 round 2s (in 3rd pl)
9-16::
    1s turn LH to join RH to 1st corners & Bal-in-Line _while_ 2nd
    corners set, 1s turn 1st corners RH, 1s 3/4 turn RH & join 2nd
    corners LH
17-24::
    1s Bal-in-Line with 2nd corners _while_ 1st corners set, 1s turn 2nd
    corners LH & turn LH to face 1st corners
25-32::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh & dance
    reel with 2nd corners 1s ending 2nd place opposite sides
33-40::
    2s+1s+3s chase clockwise - 2s+3s right round but 1s chase 1/2 way &
    turn RH to end in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4513, '2013-08-21 08:30:49.968641+00', '2023-02-04 01:19:01.30571+00', 941, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 2 places, cross LH & cast up 1 to face 1st corners
9-16::
    1s set to 1st corners, set on sides, set to 2nd corners & end with
    1M between 2s facing down & 1L between 3s facing up
17-24::
    1s pass LH to face 1st corner, turn 1st corner RH, partner LH, 2nd
    corner RH to end in 2nd place on opposite sides
25-32::
    1s dance LSh Reels of 3 across set (1M with 2s & 1L with 3s) & 1s
    cross RH to own sides
33-40::
    2s+1s+3s dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14512, '2022-01-10 02:18:39.721399+00', '2023-02-04 01:19:01.356035+00', 17952, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Tourbillon for 3 couples:
::
    _1- 4_  1s & 2s 1/2 turn ptnrs 2H, 1M & 2L lead ptnrs by nearer hand
    1 place clockwise to end 1s on Ladies side & 2s Men''s side, 1s+2s+3s
    set
::
    _5- 6_  1s & 2s 1/2 turn ptnrs 2H & lead ptnrs on 1 place clockwise
    _while_ 3s 1/2 turn 2H
::
    _7- 8_  1s cross to 2nd place own side facing clockwise _while_
    2s+3s turn partner 3/4 RH into line up/down centre, Men facing down,
    Ladies facing up
9-16::
    2s+1s+3s dance Weasel Reels:
::
    2s+3s dance part reel of 4 up/down middle but when reaching either
    end they dance clockwise to top/bottom to re-enter reel _while_ 1s
    dance clockwise to replace dancer leaving the reel. All end where
    they started
17-20::
    2s+3s Petronella turn to own side _while_ 1s Adv (1) & Ret (1), all
    3 couples set
21-24::
    1s pass person on right by RSh to dance 1/2 reel of 3 on sides. (2s
    & 3s loop into place at end)
25-32::
    1M+3s (at top) & 1L+2s (at bottom) dance LH across, 1s pass LSh to
    dance RH across with other couple.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (15315, '2022-12-19 01:18:55.1539+00', '2023-02-04 01:19:01.380384+00', 21176, 3, NULL, 'ace', '1-8::
    1s+2s dance Double Fig 8, 1s cross down to begin.
9-10::
    1s NHJ dance down between 3s _while_ 2s dance up to 1st place.
11-12::
    1L+3L turn 3/4 LH _while_ 1M+3M 3/4 turn RH
13-16::
    1s NHJ dance to top place, 1L+2L turn 3/4 RH _while_ 1M+2M turn 3/4
    LH. 2 1 3
17-22::
    1L+2s & 1M+3s dance LSh reels of 3 across.
23-24::
    1s+3s Petronella turn, Ladies face down, Men face up.
25-29::
    1s+3s dance All Round Square Poussette:
::
    _25_ 1s set towards Men''s side _while_ 3s set towards Ladies'' side,
    pull back RSh to 1/4 turn on hop.
::
    _26_ 1s set towards bottom of set _while_ 3s set towards top, pull
    back RSh to 1/4 turn on hop.
::
    _27_ 3s set towards Men''s side _while_ 1s set towards Ladies'' side,
    pull back RSh to 1/4 turn on hop.
::
    _28_ 3s set towards bottom of set _while_ 1s set towards top, pull
    back RSh to 1/4 turn on hop.
::
    _29_ Both cpls set towards centre to finish in line, Ladies facing
    down, Men facing up.
30-32::
    1s+3s turn 2H 1.1/4 to own sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15218, '2022-11-03 01:18:56.568491+00', '2023-02-04 01:19:01.55372+00', 21119, 3, NULL, 'ace', '1-8::
    1s+3s Petronella turn into the middle _while_ 2s+4s step up, all
    set; 1s+2s also 3s+4s dance RH across
9-24::
    All 4 couples dance a Chaperoned Celtic Reel:
::
    _9-10_   1s+3s pass partners RSh _while_ 2s+4s dance clockwise 1/4
    round set
::
    _11-12_  1L+3M dance 3/4 round each other LSh _while_ 2M+1M also
    3L+4L take nearer hands & with 4M+2L dance clockwise 1/4 round the
    set.
::
    _13-14_  3s+1s pass partners RSh _while_ 2s+4s dance clockwise 1/4
    way round
::
    _15-16_  1M+3L dance 3/4 round each other LSh _while_ 2L+3M also
    1L+4M take nearer hands & with 4M+2L dance clockwise 1/4 round the
    set
::
    _17-18_  3s+1s pass partner RSh _while_ 2s+4s dance 1/4 round set
::
    _19-20_  3M+1L dance 3/4 round each other LSh _while_ 2M+3L also
    1M+4L take nearer hands & with 4M+2L dance clockwise 1/4 round set
::
    _21-22_  1s+3s pass partners RSh _while_ 4s+2s dance clockwise 1/4
    round set
::
    _23-24_  2L dances up to 1M''s place, 1L dances out to 2M''s place, 1M
    dances to 3M''s place, 2M dances to 4M''s place. _While_ 4L dances
    into 1L''s place, 3L to 2L''s place, 3M dances out to 3L''s place, 4M
    dances to 4L''s place.
25-26::
    All chase 2 places clockwise to finish on sides 1 2 4 3
27-32::
    1s cross RH, cast to 4th place, cross RH to own sides _while_ 3s
    turn RH & lead up to 2nd place. (2s step up on bars 29-20) End 2 3 4
    1', 0);
INSERT INTO 'dancecrib' VALUES (4515, '2013-08-21 08:30:49.986999+00', '2023-02-04 01:19:01.579631+00', 946, 3, NULL, 'ace', '1-8::
    1s+3s dance 1/2 RH across, cast (Men to right & Ladies to left),
    meet behind 2s/4s, dance between 2s/4s crossing to original pl &
    turn ptnr LH
9-16::
    1s+3s Adv+Ret & turn corners with other hand
17-24::
    _17-18_  Men set _while_ Ladies dance in, Ladies pass each other LSh
    & curve to left, then turn right about to face partner
::
    _19-20_  All change places with partner LH
::
    _21-22_  Men change places with opposite Lady RH, Men pass LSh
    dancing back towards places _while_ Lady dances to partner''s place
::
    _23-24_  All turn partner RH to original places
25-32::
    All dance interlocking reels of 4
33-64::
    2s+4s repeat bars 1-32
65-72::
    All Men dance LH across, giving RH to partner & all Set+Link with
    partners
73-80::
    All Ladies dance LH across, giving LH to partner & all Set+Link with
    partners to end in original places
81-88::
    All turn partner RH, corner LH, partner RH & corner LH
89-96::
    All circle 8H round to left for 4 steps, turn partner 2H & continue
    to circle 8H round to places', 0);
INSERT INTO 'dancecrib' VALUES (4516, '2013-08-21 08:30:49.995103+00', '2023-02-04 01:19:01.608137+00', 950, 3, NULL, 'ace', '1-8::
    1s set advancing passing RSh, 1M+2L & 1L+2M 1/2 turn nearer hand &
    repeat back to places
9-16::
    1s lead down below 3s & cast up, meet, lead up to top & cast to
    place _while_ 2s cast up & lead down & cast up round 3s to place,
    1s+2s set
17-24::
    1s dance reels of 3 on own sides (1s in & down to start)
25-32::
    1s dance part reels of 3 on sides all crossing at the top to end 3 1
    2 on opposite sides & all set
33-40::
    1s cast down 1 place, cross RH, cast up to 2nd place _while_ 2s+3s
    cross RH, set on sides & change places RH, 2s+1s+3s set', 4);
INSERT INTO 'dancecrib' VALUES (9471, '2016-11-09 08:48:14.234337+00', '2023-02-04 01:19:01.629666+00', 15913, 3, NULL, 'ace', '1-8::
    1s+2s dance »Espagnole«. 1s end facing 1st corners
9-16::
    2s+1s+3s dance 4 bars of »Dance to Corners & Set:«
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 1 more time to end
    in lines across (2L facing 1L, 3M facing 1M)
::
    _1/2_ reels of 3 across (1L+2L & 1M+3M pass LSh)
17-24::
    _3_ couples dance 4 bars of »Dance to Corners & Set:«.  End 2M
    facing up, 3L facing down in middle opp sides. 1/2 RSh reels of 3 on
    sides.
25-32::
    _3_ couples 1/2 turn opp person RH, pull back RSh, dance out to own
    sides.  1M+2M (top 2 men) & 2L+3L (bottom 2 ladies) turn 1.1/2 LH.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4518, '2013-08-21 08:30:50.00951+00', '2023-02-04 01:19:01.676965+00', 11261, 3, NULL, 'ace', '1-8::
    3s dance LSh round 1st corners & 3s turn LH to face 2nd corner pstns
    _while_ 1s & 5s 1/2 turn 2H & cast clockwise (1M & 5L lead) to
    4th/2nd places _while_ 2s & 4s step up/down.  2 5 3 1 4
9-16::
    3s turn 2nd corners RH, partner LH, 1st corner RH & pass LSh to end
    3M facing up & 3L down _while_ 2s & 4s 1/2 turn 2H & cast clockwise
    (2M & 4L lead) to other end.  4 5 3 1 2
17-24::
    3M+4s+5s also 3L+1s+2s circle 5H round & back, ending with top 5
    persons facing down & 3M between 5s & bottom 5 facing up with 3L
    b''tw''n 1s
25-32::
    All set twice, 3s turn RH & dance to bottom.  4 5 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (4519, '2013-08-21 08:30:50.029377+00', '2023-02-04 01:19:01.699839+00', 13268, 3, NULL, 'ace', '1-8::
    All Ladies dance across passing partner RSh & dance up to top of set
    (1L leading), cross & dance down Ladies'' side
9-16::
    All Men dance across passing partner RSh & dance down to the bottom
    of set (4M leading), cross & dance up Men''s side.  4 3 2 1
17-24::
    All circle 8H round & back with 4s & 1s ending in middle (4s facing
    down, 1s facing up)
25-32::
    1s+4s dance 1/2 R&L (up/down), 1s cast to ends & cross RH _while_ 4s
    turn RH 1.1/2 times moving down to 3rd place
33-40::
    3s+2s dance 1/2 R&L & turn partners RH 1.1/2 times.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (10219, '2017-11-04 01:45:07.413721+00', '2023-02-04 01:19:02.113545+00', 14749, 3, NULL, 'ace', '{{title}}
Fig.1

1-8::
    1s+3s dance Ladies'' Chain, with extra 1/4 turn bar 8 so Ladies end
    BtoB in centre facing partners
9-16::
    1s+3s set, 1/2 turn RH, retain hands, Men join LH in centre &
    Bal-in-Line. Men 1/2 turn LH to face opp Lady
::
    _while_ 2s+4s set to partners, change places RH, set & change places
    LH
17-24::
    1s+3s dance RSh reel of 4 across.  Bar 24 Men pull back RSh to face
    partners
25-32::
    1s+3s turn RH into prom hold facing anticlockwise & promenade round
    to original places
::
    _while_ 2s+4s set to partners, Advance, set, Retire

{{explanation}}
Fig. 2

1-32::
    All 4 couples together dance Fig 1 with
::
    _1-2_ & 5-6           Ladies dance 1/2 RH across in centre
::
    _15-16_ & 19-20   Men 1/2 LH across in centre
::
    _17-18_ & 21&22  Ladies 1/2 LH across in centre

{{explanation}}
Fig. 3

1-32::
    2s+4s repeat Fig 1

{{title}}
Fig 4

1-8::
    Ladies dance RH across, finish facing partners.  All turn partners
    1.1/2 round LH
9-16::
    Men dance RH across, all turn partners 1.1/2 LH, Men pull back LSh
    to face clockwise NHJ with partners _while_ Ladies join RH in centre
17-24::
    All dance round in wheel, Ladies end BtoB in centre facing partners
25-32::
    All 1/2 turn partners RH into prom hold & promenade anticlockwise
    round, ending with Ladies BtoB in centre for bow/curtsey', 0);
INSERT INTO 'dancecrib' VALUES (4524, '2013-08-21 08:30:50.088258+00', '2023-02-04 01:19:02.17609+00', 964, 3, NULL, 'ace', '1-8::
    All dance interlocking reels of 4 (all pass partner RSh, next person
    LSh & following person RSh)
9-16::
    1s change places with 3s passing RSh, 3s+1s change places with
    partners LH & repeat back to places
17-24::
    1s & 3s (in prom hold) dance RSh reels of 3 at top & bottom dancing
    to right to start (1s with 2L+4M & 3s with 2M+4L) ending in lines of
    4 across set with 1s & 3s in centre
25-28::
    All set, 1s & 3s dance into centre of set, divide, dance out with
    other partner to sides as 2s & 4s dance into places vacated by 1s &
    3s & into centre of set (to form new lines across with 2s & 4s in
    centre of lines
29-32::
    All turn opposite dancer 2H, 2s & 4s dance out to original places as
    1s & 3s cast to places
33-64::
    Repeat from bar 1 with 2s & 4s as leading dancers
65-72::
    All Ladies dance RH across once round, all Men dance LH across once
    round ending in centre facing partner
73-80::
    All set HS & turn 2H 1.1/2 times to places', 0);
INSERT INTO 'dancecrib' VALUES (11443, '2019-01-01 01:56:25.676128+00', '2023-02-04 01:19:02.202236+00', 18943, 3, NULL, 'ace', '1-8::
    1s set, cross down RH to 2nd place (2s step up), set & cross RH to
    2nd place own side, facing out
9-16::
    1s cast Right, meet in centre, turn LH & 1M dances down, casts Left
    round 3L into 2nd place opp side _while_ 1L dances up, casts Left
    round 2M into 2nd place opp side
17-24::
    1s dance reels of 3 on opp sides (1M+2L & 1L+3M pass RSh).  1s curve
    in to end facing 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting finishing with Petronella turn to
    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4525, '2013-08-21 08:30:50.096537+00', '2023-02-04 01:19:02.23259+00', 9167, 3, NULL, 'ace', '1-8::
    2s dance 1/2 Figs of 8 (2L round 1s & 2M round 3s) & 1/2 Figs of 8
    on opposite sides
9-16::
    1s+2s dance R&L
17-24::
    All dance 1/2 LSh reels of 3 on sides, 2s+1s set facing up/down &
    change places on sides (LH Ladies'' side & RH Men''s side)
25-32::
    2s dance 1/2 Fig of 8 round 1s (cast up to start) & all turn LH', 0);
INSERT INTO 'dancecrib' VALUES (8772, '2015-06-15 11:40:31.002494+00', '2023-02-04 01:19:02.264328+00', 16125, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up), 1s turn 3/4 RH then 1L+2M & 1M+3L
    turn LH into 2nd place opp sides
9-12::
    _1/2_ reels of 3 on opp sides (1L down, passes 3M RSh & 1M up,
    passes 2L RSh)
13-16::
    _1/2_ reel of 3 across (1M+3M at top & 1L+2L in 3rd place pass LSh).
    1s finish BtoB facing 4th corners
17-20::
    1s dance round 4th corners into 2nd place own sides _while_ 2s+3s
    dance RH across (2 bars), twirl, dance out to opp corners
21-24::
    2s+1s+3s turn RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4528, '2013-08-21 08:30:50.127808+00', '2023-02-04 01:19:02.538369+00', 972, 3, NULL, 'ace', '1-8::
    1s turn RH, 1M+2L turn LH to end in centre as 2M dances up to 1L for
    Allemande
9-16::
    2M+1L also 1M+2L dance Allemande
17-24::
    1s followed by 2s lead down (1M dances down to join1L _while_ 2M
    dances up to join 2L) & 2s lead back to top
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4530, '2013-08-21 08:30:50.14381+00', '2023-02-04 01:19:02.591771+00', 976, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s Set+Link, 1s+3s dance RH across
9-16::
    2s+1s Set+Link, 1s+2s circle 4H round to left

{{title}}
Reel

17-24::
    1s cross down to double triangle position with 2s+3s & all set, 1s
    cast round 1st corners to end between 2s/3s & all set
25-32::
    2s+1s+3s Adv+Ret (up/down) & turn opposite person RH (1s turn RH
    1.1/4) to finish 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4532, '2013-08-21 08:30:50.15978+00', '2023-02-04 01:19:02.652349+00', 980, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across, 1s cast to 2nd place as 2s lead up to
    top
9-16::
    1s+3s set, dance LH across, 1s cast to 3rd place as 3s dance up to
    2nd place
17-24::
    1s set, lead up to top & cast to 2nd place own sides (3s step down
    19-20)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4533, '2013-08-21 08:30:50.167765+00', '2023-02-04 01:19:02.673772+00', 981, 3, NULL, 'ace', '1-8::
    1s & 4 set, cast in 1 place & dance RH across with nearer end couple
9-16::
    1s & 4s dance LH across, set & cast back to original places
17-24::
    1s lead down to bottom & make an arch, 4s followed by 3s+2s dance
    down & curve in to dance up under 1s arch to the top
25-32::
    4s+3s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4534, '2013-08-21 08:30:50.177423+00', '2023-02-04 01:19:02.783362+00', 984, 3, NULL, 'ace', '{{explanation}}
Progressive 2 couple dance,  2 facing 2 round room, Lady on Man''s right

1-8::
    All turn RH, face partner & set advancing to Bal-in-Line with Ladies
    in middle giving RH to each other & LH to partners
9-16::
    Ladies 1/2 turn RH into Ladies'' Chain ending back in original places
17-24::
    All dance R&L starting by giving RH to other partner
25-32::
    All Adv+Ret & dance on passing other partner RSh to face oncoming
    couple', 0);
INSERT INTO 'dancecrib' VALUES (4536, '2013-08-21 08:30:50.19368+00', '2023-02-04 01:19:02.835153+00', 985, 3, NULL, 'ace', '{{explanation}}
2 chords, on 2nd chord 1s+2s also 3+4s move to Glasgow Highlanders pstn

1-8::
    All Adv+Ret, cross RH & turn ptnrs LH to form 2 lines of 4 across,
    1s to the left facing 3s, 2s to the right facing 4s (Ladies on Men''s
    right)
9-16::
    All Adv+Ret, cross RH & turn ptnrs LH to longways set - 4s in top
    places (Mans side) facing 3s, 2s (Mans side) facing 1s (Ladies on
    Men''s right)
17-24::
    4s+3s & 2s+1s dance RH across & LH back
25-32::
    3s+2s dance diagonal reel of 4
33-40::
    4s+1s dance Ladies'' Chain
41-48::
    3s+4s & 1s+2s dance 1/2 R&L & 3s+2s dance 1/2 diagonal reel of 4 All
    end 1 place anticlockwise round set) (Original version)
::
    _41-48_   3s+4s & 1s+2s dance 1/2 R&L, 3s+2s dance change places
    diag RH & change with ptnrs LH on sides (Popular version)', 0);
INSERT INTO 'dancecrib' VALUES (4537, '2013-08-21 08:30:50.201888+00', '2023-02-04 01:19:02.928559+00', 986, 3, NULL, 'ace', '1-8::
    1s dance down the middle below 3s & set to each other, turn 2H &
    cast up to top place
9-16::
    1s+2s dance the Bourrel:
::
    1M+2L set advancing & 3/4 turn 2H pivoting right to end BtoB to 2L
    facing up & 1M down _while_ 1L+2M chase anticlockwise & face partner
::
    1s+2s set to partners & turn RH, 1s into prom hold facing down & 2s
    to top place own sides
17-24::
    1s dance 1/2 RSh reel of 3 with 2nd corners & 1/2 reel of 3 with 1st
    corners ending in 2nd place own sides facing out.  (3) 1 (2)
25-28::
    1s cast round 3rd corners, cross & cast to 2nd places _while_
    corners (in circle) set & circle left & right 1 step & loop round to
    right to place (opp side)
29-32::
    3s+1s+2s turn 2H & circle round to left 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (13396, '2020-12-02 01:18:58.046487+00', '2023-02-04 01:19:02.95395+00', 19150, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance over/under arches:
::
    1s under arch by 2s who dance up, 1s make arch & 3s dance up under,
    2s under arch by 3s; 1s under arch by 2s, 3s under arch by 1s, 3s
    under arch by 3s.  End 1 2 3
9-12::
    1s (1L followed by 1M) dance 1/2 tandem reel with 2M & 3M (1L LSh to
    3M )
13-16::
    1M followed by 1L dance 1/2 tandem reel with 2L+3L (1M LSh to 2L).
    1 3 2
17-24::
    1s+3s dance 1/2 R&L; 1s+2s dance 1/2 R&L
25-32::
    3s+2s dance 1/2 R&L; 2s+3s+1s Adv+Ret (1 step each), Adv (1 step),
    pull back RSh & dance out to place
33-40::
    2s+3s+1s dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4538, '2013-08-21 08:30:50.208127+00', '2023-02-04 01:19:02.973905+00', 7553, 3, NULL, 'ace', '{{explanation}}
Round the Room dance, couples facing anticlockwise (Ladies on partners right)

1-4::
    Starting with outside foot run forward for three steps & hop,
    backwards for three steps & hop.
5-8::
    Skip sideways away from partner (Men towards the centre, Ladies
    outwards) for two steps & clap, Return to partner in waltz hold.
9-12::
    Skip sideways to the Man''s left for two steps & back
13-16::
    Polka anticlockwise round the room.', 0);
INSERT INTO 'dancecrib' VALUES (4539, '2013-08-21 08:30:50.218006+00', '2023-02-04 01:19:02.998374+00', 12870, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, 1s dance RH across (Man with 2s & Lady
    with 3s)
9-16::
    1s 3/4 turn LH to end between 1st corners & Bal-in-Line, 1s 1/4 turn
    LH to end between 2nd corners & Bal-in-Line
17-24::
    1s dance reels of 3 on sides giving RSh to 2nd corners & cross to
    2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13735, '2021-03-02 01:19:03.759595+00', '2023-02-04 01:19:03.165386+00', 13376, 3, NULL, 'ace', '{{title}}
Start

::
    3s·····4s  (Men in centre facing partner)
::
    2s·····1s  (Ladies BtoB in centre facing partner)
::
    ····Top
1-4::
    1L+2L also 3L+4L NHJ, dance out between prtnrs, cast round them,
    dance in, 1L with 2L, 3L with 4L pass LSh in the middle
5-8::
    1L+4L also 3L+2L NHJ, dance out between prtnrs, cast round them,
    dance in, 1L with 4L, 3L with 2L pass LSh in the middle
9-12::
    3L+4L also 1L+2L NHJ, dance out between prtnrs, cast round them,
    dance in, 3L with 4L, 1L with 2L pass LSh in the middle
13-16::
    3L+2L also 1L+4L NHJ, dance out between prtnrs, cast round them,
    dance in, 3L with 2L, 1L with 4L pass LSh in the middle
17-24::
    All set HS in original place. All turn partner 1.1/2  RH into
    Allemande hold facing anticlockwise
25-32::
    All promenade round the set.  Ladies end in partners'' original place
    (at the corners), Men end ''on sides'' between 2 ladies
33-36::
    All Men dance into the centre, pull back RSh to face out &
    Petronella turn to one place clockwise round ''on sides'' between 2
    ladies
37-48::
    All Men repeat bars 33-36 three more times
49-56::
    All Ladies dance LH across; all turn partner RH to end in original
    places
57-64::
    All dance double RSh reels of 4, LH across in centre
65-72::
    All set HS in original place. All turn partner 1.1/2 RH into
    Promenade hold facing anticlockwise
73-80::
    All Promenade round back to original place (Alternative:  Promenade
    round & dance off, 1s leading)', 0);
INSERT INTO 'dancecrib' VALUES (12908, '2020-07-01 00:18:51.811168+00', '2023-02-04 01:19:03.188388+00', 19986, 3, NULL, 'ace', '1-8::
    Ladies cast behind partner (2 bars), dance in for RH across 2 places
    round (4 bars), dance LSh round corner (Man) to Ladies'' place
    (Ladies have moved 1 place anticlockwise)
9-16::
    Men cast behind new partner, into centre & LH across 2 places round,
    dance RSh round (new) corner (Lady) to Man''s place.  (Men have moved
    1 place clockwise)
17-24::
    All facing new partners turn 1.1/2 RH, meet next person & turn 1.1/2
    LH to all finish in original places, Men facing in, Ladies facing
    out
25-32::
    All dance 8 bars Schiehallion reels (to move 1 place clockwise).
    End  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4193, '2013-08-21 08:30:45.048553+00', '2021-07-03 11:56:02.30939+00', 439, 3, NULL, 'ace', '1-8::

    1L+3M change places RH & cast up/down round 2s to pick up partner,

    1s+3s dance RH across ending in partners place

9-16::

    1s+2s+3s reel of 3 on sides (1s out & dn to start), 1s & 3s end

    casting round 2s to meet nearer hands joined as 2s dance up/down

    into centre

17-20::

    1s+3s cross Ladies dancing under arch made by Men & cast up/down to

    meet partner in centre _while_ 2s set & petronella turn to own sides

21-24::

    1s+2s+3s circle 6H round to left to end in original places

25-32::

    1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (4479, '2013-08-21 08:30:49.473119+00', '2023-02-04 01:19:03.234058+00', 991, 3, NULL, 'ace', '1-8::
    1s turn RH moving down below 2s & end facing out on their own sides,
    M casts up & L down to form lines of 3 across (facing) & all set
9-16::
    1s turn RH & end on own sides in 2nd pl _while_ 2s+3s petronella 1
    pl & all set on sides; Repeat with 1s ending 1M between 2s in 3rd pl
    & 1L between 3s at top & all set
17-24::
    All DoSiDo with opp person, 1s turn 2H twice & end facing 1st crnr
    (pstn) _while_ 2s+3s dance 1/2 R&L (start on sides)
25-32::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (8305, '2014-07-29 12:58:48.777171+00', '2023-02-04 01:19:03.253614+00', 15042, 3, NULL, 'ace', '1-4::
    1s+3s set & 3/4 turn RH to form line up/down centre
5-8::
    1s+3s dance 1/2 reel of 4, 1M+3L turn 1/4 LH to end between 2s
    across the set
9-12::
    2L+1M+3L+2M dance 1/2 reel of 4
13-16::
    2L+1M also 3L+2M set, change places LH, 2s pass LSh
17-20::
    2M dances RH across with 1s as 2L dances RH across with 3s (»2nd
    corner positions«)
21-24::
    1s turn 2H ending in 3rd place as 3s turn 2H in 1st place _while_ 2s
    pass LSh & dance out opposite sides, 2s dance clockwise 1/2 way
    round  to 2nd place own side. All take promenade hold & face up.
25-32::
    3s+2s+1s Promenade ending with 3s casting off to 2nd place as 2s
    dance up to 1st place.     2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13048, '2020-08-10 00:18:52.325861+00', '2023-02-04 01:19:03.273431+00', 11610, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on own sides, LSh to 2s to start. Bars 7-8: 1s
    pass 2s LSh but 1L ends in centre facing 3L.  2 1 3
9-24::
    1s dance »Hello and Goodbye Chase« with corners:
::
    1L dances Hello-Goodbye setting (14 bars) ending between 3s, Bars
    23-24: 1L pulls back RSh to face down (PdeB) _while_
::
    1M sets advancing to 3L (bars 9-10), dance Hello-Goodbye setting (14
    bars) to end in centre in 2nd place facing down
25-32::
    1L followed by 1M casts up behind 3L, crosses to 2nd place Men''s
    side & 1s cast up round 2s to top, 1s pass 2s RSh  to 2nd place own
    side, 1M  facing out. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4540, '2013-08-21 08:30:50.233724+00', '2023-02-04 01:19:03.290333+00', 7629, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    2s+1s+3s+4s dance RSh reel of 4 on sides
17-24::
    1s & 3s dance round 2s/4s RSh & turn LH 1.1/2 times on own sides to
    end 2 3 1 4
25-32::
    2s+3s dance RH across & LH back _while_ 1s+4s dance RH across &
    dance 1/2 Diamond Poussette.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4488, '2013-08-21 08:30:49.556056+00', '2023-02-04 01:19:03.447434+00', 992, 3, NULL, 'ace', '1-8::
    All Ladies cast behind partners round to their corner Man & turn RH,
    all Ladies dance 1/2 LH across to face Man opposite their corner
9-16::
    All dance double reels of 4 & end with Man dancing on 1 place to
    meet partner
17-24::
    All set (4 bars), advance passing partner RSh & retire at right
    angles to face partner (Men facing clockwise & Ladies Anticlockwise)
25-32::
    All dance DoSiDo round partner, set & turn RH (Men facing out to
    start next 32 bars)
33-64::
    Repeat with Men dancing Ladies moves

{{explanation}}
Repeat bars 1-64', 0);
INSERT INTO 'dancecrib' VALUES (4542, '2013-08-21 08:30:50.26627+00', '2023-02-04 01:19:03.472363+00', 12105, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & turn RH
9-16::
    1s dance reels of 3 across (Lady with 2s & Man with 3s) ending 2nd
    place opposite sides
17-24::
    1s set & 3/4 turn LH _while_ 2s+3s cross RH & set, 1s set & 3/4 turn
    LH _while_ 2s+3s change places on sides RH & set
25-32::
    1s dance diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (4543, '2013-08-21 08:30:50.280649+00', '2023-02-04 01:19:03.641539+00', 8104, 3, NULL, 'ace', '{{explanation}}
Circle Round the Room, Man has partner on his Right

1-8::
    All circle round to Left & back to Right
9-16::
    All Men dance Fig of 8 round partner & Lady on left (in front of
    partner to start)
17-24::
    All Ladies dance Fig of 8 round partner & Man on right (in front of
    partner to start)
25-32::
    All join hands, Adv+Ret; all Advance & Ladies swivel and join 2H
    with partner, Men Retire followed by partner.  Men face in, Ladies
    face out
33-40::
    Men join hands to form arches & all dance DoSiDo with partners; all
    Men turn (birl) Lady on Right to end in large circle with new
    partner on right', 0);
INSERT INTO 'dancecrib' VALUES (12909, '2020-07-01 00:18:52.274833+00', '2023-02-04 01:19:03.67108+00', 9071, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, set & cross RH to own side
9-16::
    1s+3s dance 1/2 R&L, set & turn RH remaining in centre facing
    partner ready for…
17-24::
    3s+1s dance Poussette
25-32::
    1M dance down round 3M, 1L up round 2L, cast to 2nd place & turn RH
    to face out
33-40::
    1M casts up round 2M, 1L down round 3L finishing in centre.  1s turn
    1.3/4 to 2nd place own side
41-48::
    All set, all cross RH.  1s cast to 4th place (3s+4s step up). All
    cross RH.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4545, '2013-08-21 08:30:50.296934+00', '2023-02-04 01:19:03.726332+00', 999, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    1s & 4s dance out ends, cast back to 2nd/3rd places, 1M+4L & 1L+4M
    in prom hold dance round (Men LSh to LSh) 3/4 to face up/down
17-24::
    1M+4L dance LSh reel of 3 across with 2s & 1L+4M with 3s to end 2 4
    (1)(3)
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4546, '2013-08-21 08:30:50.307138+00', '2023-02-04 01:19:03.90819+00', 2050, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Tournee :
::
    1s+2s also 3s+4s dance into prom hold (Men with prtnr on right,
    1s/3s face Men''s side & 2s/4s Ladies'' side), couples 1/2 wheel
    anticl''wise & Men turn Ladies into middle, both couples turn 1.1/2
    times (2s/4s RH, 1s/3s LH) & dance out to places.  2 1 4 3
9-16::
    All Adv+Ret 1 step, repeat & all dance DoSiDo
17-24::
    Top 3 Men''s side cross RH with bottom 3 Ladies'' side. Top 3 Ladies''
    side cross LH with bottom 3 Men''s side, repeat bars 17-20 to 3412
    opp sides
25-32::
    3s+4s also 1s+2s set & 1/2 circle 4H left, 1s making arch dance up
    to top & cast to 2nd place _while_ 3s+2s dance down under arch to
    bottom & 2s cast to 3rd place.  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (4547, '2013-08-21 08:30:50.316973+00', '2023-02-04 01:19:03.937531+00', 7284, 3, NULL, 'ace', '1-8::
    1s cross down (no hands) to 2nd place (2s step up) , dance out & 1/2
    turn 3s with nearer hand; 1s 1/2 turn RH & lead up to top ending in
    prom hold (2s+3s step down 7-8)
9-16::
    1s in prom hold dance reel of 3 with 2s (RSh to 2L to start) 1s end
    in middle at top facing down (Lady on Man''s Left), 2s on sides & 3s
    step in & face up
17-24::
    1s+2s+3s set, all Petronella turn one place (1s+3s
    Petronella-in-Tandem); all set advancing (1 bar), join hands in
    circle & set (1 bar), pull back RSh & cast clockwise back to places
25-32::
    1s+2s dance the Knot.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4548, '2013-08-21 08:30:50.325225+00', '2023-02-04 01:19:03.966095+00', 8568, 3, NULL, 'ace', '1-8::
    1L+2M set twice, Adv+Ret _while_ 1M+2L turn RH & chase clockwise 1/2
    way (to change places)
9-16::
    2L+1M set twice, Adv+Ret _while_ 1L+2M turn RH & chase clockwise 1/2
    way
17-24::
    2s+1s dance modified Chain Progression :
::
    2s+1s 3/4 turn RH, end persons chase clockwise 1/2 way round _while_
    centre couple 1/2 turn LH, 1s+2s turn RH to…
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (4549, '2013-08-21 08:30:50.352087+00', '2023-02-04 01:19:04.059012+00', 9752, 3, NULL, 'ace', '1-8::
    1s+2s set & dance RH across 1/2 way, set & cross RH to own sides
9-16::
    All Ladies dance down & 1/2 way round to other side (behind Men),
    all Ladies dance through Men to own sides & set
17-24::
    All circle 6H round & back
25-32::
    All Men dance down & 1/2 way round to other side (behind Ladies),
    all Men dance through Ladies to own sides & set
33-40::
    2s+1s dance R&L  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4096, '2013-08-21 08:30:43.494477+00', '2021-01-09 01:18:31.228929+00', 294, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, cross RH & cast to 3rd place
9-12::
    1M+3L in prom hold dance 1/2 reel of 3 across with 4s (RSh to 4M)
    _while_ 1L+3M in prom hold dance 1/2 reel of 3 across with 2s (RSh
    to 2L)
13-16::
    1M+3L 1/2 reel of 3 on Men''s side with 2L+4L (LSh to 2L) _while_
    1L+3M dance 1/2 reel of 3 on Ladies'' side with 2M+4M (LSh to 4M) &
    end (4) 1 (3)(2)
17-24::
    4s+1s also 3s+2s dance R&L
25-32::
    All dance progressive ''Drop Out'' Chain to end 2 3 4 1:
::
    _24/26_ top & bottom couples cross RH _while_ middle couples change
    places RH on sides
::
    _27/28_ top 2 couples & bottom 2 couples change places LH on sides
::
    _29/30_ top couple crosses RH _while_ middle couples change places
    RH on sides & bottom couple (1s) stand
::
    _31-32_ top 2 couples change places LH _while_ bottom 2 couples (4s
    & 1s) stand', 0);
INSERT INTO 'dancecrib' VALUES (4551, '2013-08-21 08:30:50.459418+00', '2023-02-04 01:19:04.119063+00', 8513, 3, NULL, 'ace', '1-8::
    2s dance up between 1s & cast to 2nd place in centre facing down
    with nearer hands joined _while_ 4s dance down between 5s & cast up
    to 4th place in the centre facing up with nearer hands joined,
    2s+3s+4s 6H round (3s end on sides with 2s & 4s facing up/down)
9-16::
    2s+4s advance, turning to face ends dance up/down between end
    couples & turn them with nearer hand back to original places
17-24::
    2s Fig of 8 round 1s _while_ 4s Fig of 8 round 5s to end with 2s &
    4s facing 1s & 3s
25-32::
    1s+2s also 3s+4s set & 1/2 turn 2H ending with 1s & 3s facing 4s &
    5s, 1s+4s also 3s+5s set & 1/2 turn 2H to end 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (4552, '2013-08-21 08:30:50.469428+00', '2023-02-04 01:19:04.186209+00', 13581, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate & end 1s facing up, 2s down:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd place facing up)
9-16::
    1s dance reels of 3 on own sides (RSh to 2s)
17-24::
    1s set & turn 3/4 RH to face own sides, 1s dance LH across (1L with
    2s, 1M with 3s) to end 2nd place opposite sides
25-32::
    1s set & turn 3/4 RH to face opposite sides, 1s dance LH across (1M
    with 2s, 1L with 3s) ending 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8990, '2015-11-30 08:59:33.546758+00', '2023-02-04 01:19:04.21794+00', 16098, 3, NULL, 'ace', '1-8::
    All set, Men cast anticlockwise1 place (pull back LSh), turn new
    partner LH
9-16::
    All set to new partners, Ladies cast clockwise 1 place (pull back
    RSh), turn new partner RH & retain hands
17-24::
    All dance 2 bars Grand Chain moving 1 place to meet original
    partner. All set to partners, all DoSiDo with partners
25-28::
    All join NH with partner & set facing in.  All petronella-in-tandem
    to I place anticlockwise,
29-32::
    All repeat bars 25-28 with  Men moving 1 place anticlockwise as
    Ladies curve back to same place to face new partner.

{{explanation}}
Repeat 3 times with new partners, finish with original partner.  Men start each turn in original place, Ladies progress 1 place clockwise.', 0);
INSERT INTO 'dancecrib' VALUES (4553, '2013-08-21 08:30:50.477535+00', '2023-02-04 01:19:04.243561+00', 9229, 3, NULL, 'ace', '1-8::
    1s set & cross RH to 2nd place opp side, 1M casts up round 2L as 1L
    casts down round 3M to meet in middle LSh to LSh (L facing up, M
    down)
9-12::
    1s dance RH across on sides (1L with 2L+3L, 1M with 2M+3M)
13-16::
    1s pass RSh to dance LH across on other sides & end in lines across
    (M b''tw''n 2s, L b''tw''n 3s)
17-24::
    All set & 2s+3s set again with 1s petronella turn to 2nd place own
    sides, all turn RH
25-32::
    All circle 6H round & back.', 0);
INSERT INTO 'dancecrib' VALUES (14111, '2021-07-07 00:18:51.086411+00', '2023-02-04 01:19:04.263741+00', 1004, 3, NULL, 'ace', '1-4::
    1s+2s also 3s+4s dance RH across
5-8::
    2s+3s dance LH across finishing in centre, facing corners (2s facing
    up, 3s down) _while_
::
    1L followed by 1M casts behind Ladies'' side to end in 4th place opp
    sides _while_ 4M followed by 4L casts up Men''s side to end (4) 2 3
    (1)
9-20::
    All dance double diag reels of 4 (LH across in middle).  End in same
    positions as at end bar 8
21-24::
    2s+3s in centre turn corners 1.1/2 RH & retain RH to bring 4s & 1s
    into centre who join LH
25-32::
    All Bal-in-Line, 4s & 1s drop LH & turn 2s/3s 1/2 RH to bring 2s &
    3s into centre who join LH; all repeat 25-28
33-36::
    1s+4s dance LH across to finish on opp sides, 4s in 2nd place, 1s in
    3rd place _while_
::
    3M followed by 3L casts up behind Men''s line to top place opp side
    _while_ 2L followed by 2M casts behind Ladies'' side to end (3) (4)
    (1) (2)
37-40::
    3s+4s also 1s+2s dance RH across
41-48::
    All set, all turn partners 1.1/2 RH; all set.  End 3 4 1 2
::
    Repeat 1-48 from new positions', 0);
INSERT INTO 'dancecrib' VALUES (4554, '2013-08-21 08:30:50.487483+00', '2023-02-04 01:19:04.292348+00', 1007, 3, NULL, 'ace', '1-8::
    1s & 4s turn RH & cast in 1 place, turn LH to end in middle facing
    out to own side; 1M+4M also 1L+4L join near hands &  join other hand
    with corner
9-16::
    All set, change place with partner to face opposite sides (as in
    Double Triangles), all set & PdeB 1/4 turn to face partner up/down
    set (1L between 2s facing down, 4M between 3s facing up)
17-24::
    1s+4s RSh reel of 4
25-32::
    1s & 4s set twice to partners, 3/4 turn RH to 2nd/3rd place opposite
    sides
33-40::
    2s+1s also 4s+3s dance RH across, 1s & 4s set to partners & dance
    1/2 LH across to own sides.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4557, '2013-08-21 08:30:50.517584+00', '2023-02-04 01:19:04.383121+00', 9058, 3, NULL, 'ace', '1-8::
    1s set & cast to 2nd place, 1s set & cast to 3rd place
9-16::
    1s cross RH & cast up to 2nd place, 1s 1/2 Fig of 8 round 2s
17-24::
    2s+1s set & chase clockwise 2 places, repeat (back to places at bar
    16)
25-32::
    1s+3s circle left & turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (4558, '2013-08-21 08:30:50.616487+00', '2023-02-04 01:19:04.559389+00', 1013, 3, NULL, 'ace', '1-8::
    2s LSh reels of 3 across (Lady with 1s & Man with 3s)
9-16::
    2s reel of 3 on sides giving LSh to person on their Left
17-24::
    1s+2s 1/2 R&L, 1s+3s 1/2 R&L
25-32::
    1s turn RH _while_ 2s & 3s cross RH & all circle 6H round to Left.
    End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (12537, '2020-02-02 02:47:11.240959+00', '2023-02-04 01:19:04.572088+00', 1015, 3, NULL, 'ace', '1-8::
    1L followed by 1M casts 2 places & crosses to 3M''s place (2s+3s step
    up 3-4); 3s+1s dance RH across. 1L faces out
9-16::
    1L followed by 1M casts up 1 place & crosses to 2L''s place (3s step
    down 11-12); 2s+1s dance LH across.  2 1 3
17-24::
    1L sets to 2L  & turns RH on sides _while_ 1M sets to 3M & turns RH;
    1s turn 1.1/4 LH to face 1st corners
25-32::
    1s+1st corners dance Corner Chain, 1s face 2nd corners
33-40::
    1s+2nd corners dance Corner Chain, 1L ends facing out.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4490, '2013-08-21 08:30:49.572129+00', '2023-02-04 01:18:59.680056+00', 899, 3, NULL, 'ace', '1-8::
    1s cast & dance down own sides for 4 bars & turning out dance back
    to the top
9-16::
    1s turn RH, cast 1 place, dance 1/2 Fig of 8 round 2s & cross to top
    for…
17-24::
    1s+2s dance Allemande
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4559, '2013-08-21 08:30:50.624799+00', '2023-02-04 01:19:04.584816+00', 1017, 3, NULL, 'ace', '1-8::
    1s+2s+3s 1/2 reflection reels of 3 on own sides (1s in & down to
    start) & all turn partners RH
9-16::
    3s+2s+1s 1/2 reflection reels of 3 on own sides (1s in & up to
    start) & all turn partners RH
17-24::
    1s lead down the middle for 3 steps, back to top & cast to 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4560, '2013-08-21 08:30:50.644302+00', '2023-02-04 01:19:04.823852+00', 1018, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back again to places
9-16::
    2s lead down the middle & back again
17-24::
    1s+2s RH across for 3 steps, LH back to places & 1s cast to face 1st
    corners as 2s dance up to 1st place
25-32::
    1s turn 1st corner RH, turn partner LH, turn 2nd corner RH & partner
    LH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4562, '2013-08-21 08:30:50.664001+00', '2023-02-04 01:19:04.948658+00', 1019, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L dance across top & down behind Men, cross below
    3s & dance back up to place
9-16::
    1M+2M+3M repeat by crossing, dancing behind the Ladies & up on own
    side to places
17-24::
    1s set to 2s on sides & change places RH, set & change back LH to
    places
25-32::
    1s+2s Allemande 1s crossing LH to end in 2nd place on opposite sides
    facing in
33-40::
    2s+1s+3s dance reel of 3 on opposite sides (1s giving RSh to 2nd
    corners to start) & cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4563, '2013-08-21 08:30:50.672015+00', '2023-02-04 01:19:04.976766+00', 1020, 3, NULL, 'ace', '1-8::
    1M sets to 2L & turns LH _while_ 1L sets to 2M & turns RH, 1M sets
    to 3L & turns RH _while_ 1L sets to 3M & turns LH
9-16::
    1s lead up to top, cross, set & cast to 2nd place on own sides
17-24::
    1s+3s circle 4H round & back
25-32::
    2s+1s R&L', 0);
INSERT INTO 'dancecrib' VALUES (4564, '2013-08-21 08:30:50.681633+00', '2023-02-04 01:19:05.114793+00', 1022, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance 1/2 Fig of 8 round 2s
9-16::
    2s+1s dance R&L 1s end in diagonal line with 1st corners
17-24::
    1s Bal-in-Line with 1st corners, turn RH to 2nd corners, Bal-in-Line
    with 2nd corners & turn RH
25-32::
    1s dance out between 2L+3L, 1L casts up & 1M down, into centre & out
    Men''s side, cast & dance into 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4565, '2013-08-21 08:30:50.691351+00', '2023-02-04 01:19:05.182854+00', 1024, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret, circle 4H round to left 1/2 way
9-16::
    2s+1s repeat back to places
17-24::
    1M+2L turn RH, 1L+2M turn RH
25-32::
    1s+2s Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (14792, '2022-05-05 00:18:55.75721+00', '2023-02-04 01:19:05.202651+00', 1025, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up); 1s turn 3/4 RH to end 1L facing down,
    1M facing up, 2s+3s step in, all join hands in circle & set
9-16::
    All Petronella turn 1 place to right, reform circle & set; repeat
17-24::
    1s dance anticlockwise round to 2nd place own side _while_ 3s+2s
    dance RH across. All finish on sides (3) 1 (2); 1s turn 1.1/2 LH
25-32::
    1s dance Fig 8 on opp sides (LSh to 2nd corner to start) & cross to
    2nd place own side _while_ bars 25-28 2s+3s dance 1/2 R&L, bars
    29-32 2s+3s stand. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8557, '2015-02-13 12:47:32.102228+00', '2023-02-04 01:19:05.22392+00', 15177, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up), cross LH to face out in 2nd place
    opp. sides
9-16::
    2s+1s+3s dance reels of 3 on sides, 1s pass 2nd corner LSh to start.
    1s finish facing 1st corners
17-24::
    1s dance 1/2 diag. reel of 4 with 1st corners, pass RSh, dance 1/2
    diag. reel of 4 with 2nd corners finishing in 2nd place opp. sides
    (3) (1) (2)
25-32::
    3s+1s+2s turn partners RH and dance clockwise 1/2 way round set to
    own sides  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13130, '2020-09-15 00:18:54.878259+00', '2023-02-04 01:19:05.290565+00', 19995, 3, NULL, 'ace', '1-8::
    1s & 3s dance Double Fig 8 (1s cast, 3s cross up). 1s pass RSh to
    face 1st corners (2s step up 7-8)
9-24::
    "Best Set in the Hall" figure:
::
    _9-12_    1s set to 1st corners & dance RSh round each other into
    3rd corner (pstn) _while_ 1st corners dance in & turn right about to
    face their original position
::
    _13-16_  1s+1st crnr person set & 1st crnr persons dance RSh round
    each other into diag opp crnrs _while_ 1s dance in & pivot to right
    to face 2nd crnrs
::
    _17-24_  1s repeat bars 9-16 with 2nd corners & end passing RSh to
    2nd place opposite sides.  (3)(1)(2)
25-32::
    3s+1s+2s Set+Link for 3 couples twice
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (11179, '2018-09-30 22:19:27.887583+00', '2023-02-04 01:19:05.318702+00', 18587, 3, NULL, 'ace', '1-8::
    All circle 6H round & back
9-16::
    1s cross down to dance mirror reels of 3 on opp sides (6 bars), 1s
    1/2 turn RH remaining in centre facing down
17-24::
    1s followed by 2s lead down; 2s separate & follow as 1s lead up to
    top place, 2s to 3rd place, 3s dancing in to 2nd place (bars 23-24).
    All remain in centre facing up in prom hold
25-32::
    1s+3s+2s dance 4 bars of allemande, release RH, Ladies dance forward
    & turn partner LH to places.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (8692, '2015-03-03 08:47:23.155048+00', '2023-02-04 01:19:05.357182+00', 15274, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up), 1s dance 1/2 Fig 8 round 1st corner
    passing corner by LSh.  Finish facing 1st corners
9-16::
    1s set to & turn corners.  Finish 1M between 2s facing up, 1L
    between 3s facing down.
17-24::
    1s dance 1/2 Fig 8 round 3rd corner passing corner by LSh.  2s+1s+3s
    dance RSh reels of 3 on own sides (1L up, 1M down)
25-32::
    2s+1s+3s Adv+Ret; 2s+1s turn 2H flowing into 2s+1s circle 4H round
    to Left', 0);
INSERT INTO 'dancecrib' VALUES (8558, '2015-02-13 12:47:32.118183+00', '2023-02-04 01:19:05.401495+00', 15617, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    All circle 4H round & back
9-16::
    All dance RH across & LH back
17-24::
    All dance DoSiDo with opposite person, all dance DoSiDo with partner
25-32::
    All Adv+Ret, cross RH to face next couple', 0);
INSERT INTO 'dancecrib' VALUES (14642, '2022-03-07 02:18:53.665312+00', '2023-02-04 01:19:05.421763+00', 20517, 3, NULL, 'ace', '1-8::
    1M+2L change places RH. 1L+2M change places RH. 1s+2s chase
    clockwise to original places.
9-16::
    1s set, cast 1 place, dance down between 3s, cast up to 2nd place to
    face 1st corners. 2s step up bars 11-12
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass LSh & dance
    1/2 diagonal of 4 with 2nd corners. 1s finish 2nd place opp sides.
25-32::
    3s+1s+2s Adv+Ret & circle 6H 1/2 way round to left to finish on own
    sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7864, '2013-08-21 08:31:50.065197+00', '2023-02-04 01:23:07.814904+00', 6995, 3, NULL, 'ace', '{{explanation}}
Note: Music in 10 bar phrases

1-10::
    1s set & cross RH, set & cross down LH & cast up round 2s to
    original place - 1 2
11-20::
    1s+2s dance R&L 1.1/4 times (ie 5 moves) - (1) (2)
21-30::
    1s+2s set & dance 1/2 RH across, set & dance 1/2 LH across, 1L+2M
    continue turning 1/2 LH in centre as 1M & 2L cast, 1M down & 2L up
    to form line across all facing partners (2s on Man''s side, 1s on
    Ladies'' side) ready for …
31-40::
    1s+2s dance full reel of 4 across.  Bars 39-40 Pass partners RSh &
    dance back to own side (2s to top, 1s into 2nd place). 2 1', 4);
INSERT INTO 'dancecrib' VALUES (4501, '2013-08-21 08:30:49.744819+00', '2023-02-04 01:19:00.498917+00', 7356, 3, NULL, 'ace', '1-16::
    2s+3s set, 1/2 turn RH to face corners, all dance double diagonal
    reels of 4 giving LH in centre & ending with 2s+3s on opposite sides
17-24::
    1s+2s also 3s+4s dance 1/2 R&L, 1s+4s dance 1/2 R&L
25-32::
    All turn partners RH 1.1/2 times & chase 1/2 way round clockwise to
    end 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (13397, '2020-12-02 01:19:00.086591+00', '2023-02-04 01:19:05.450077+00', 19892, 3, NULL, 'ace', '1-8::
    1s cast behind lines, turn outwards & cast back up to 2nd place (2s
    step up 3-4)
9-16::
    2s set & cross passing RSh & stand for 4 bars _while_ 1s stand for 2
    bars, set, cross RSh, stand for 2 bars _while_ 3s stand for 4 bars,
    set, cross RSh (2) (1) (3)
17-24::
    All chase clockwise 1/2 way, 2L & 3M pull back LSh for 1/2 reels of
    3 on the sides (1M up, 1L down, LSh to 3rd corner to start) 1s end
    facing 1st corners)
25-32::
    1s dance ''Hello-Goodbye'' to end with Petronella turn to 2nd place
    facing out.

{{explanation}}
Note: at start of 3rd time through, 1s cast to 4th place, 4s step up', 0);
INSERT INTO 'dancecrib' VALUES (4566, '2013-08-21 08:30:50.809813+00', '2023-02-04 01:19:05.47056+00', 1029, 3, NULL, 'ace', '1-8::
    1M+2L change places RH, 1L+2M change places RH, 2s+1s dance RH
    across 1/2 way & set
9-16::
    Repeat bars 1-8 giving LH
17-24::
    1s dance 1/2 Fig of 8 round 2s, 2s dance 1/2 Fig of 8 round 1s
25-32::
    1s+2s set twice & dance 1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (13049, '2020-08-10 00:18:54.450123+00', '2023-02-04 01:19:05.68812+00', 1030, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance mirror reels of 3 on sides (1s in/down to start).  1s
    end in centre BtoB facing own side ready for …
9-16::
    1s dance Double Triangles ending pulling back RSh face partner in
    centre _while_ corners set, petronella anticlockwise 1 place &
    repeat.  (3) (1) (2)
17-24::
    1s dance 6 bar Fig 8 on opp sides, RSh to person on Right (1M up, 1L
    down). Bars 23-24: 3s+1s+2s set advancing & face up
25-32::
    All lead up, cross & cast to end 2 1 3; all turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (4567, '2013-08-21 08:30:50.818649+00', '2023-02-04 01:19:05.719699+00', 1032, 3, NULL, 'ace', '1-8::
    1s cross RH, lead down below 3s, cross RH & lead up to 2nd place to
    end back-to-back facing own sides
9-16::
    1s set (as Double Triangles), rotate BtoB to face 1st crnrs & dance
    1/2 diag reel of 4 end BtoB in middle (1L facing up 1M dn)
17-24::
    1s set (1L with 2s & 1M with 3s), rotate BtoB to face 2nd crnrs &
    dance 1/2 reel of 4 end turning LH to face 1st crnr (pstn)
25-28::
    1s change pl with 1st corner positions & 1s set _while_ 1st corners
    change places LH in centre
29-32::
    1s change places RH with corners & 1s turn LH to face 2nd corner
    positions
33-40::
    1s repeat bars 25‑32 with 2nd corner positions & end turning LH to
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4569, '2013-08-21 08:30:50.836578+00', '2023-02-04 01:19:05.856114+00', 13600, 3, NULL, 'ace', '{{explanation}}
 3s & 4s on opposite sides

1-8::
    1s & 4s cross RH & cast, 1s & 4s dance LH accross 1.1/4 times & end
    1s on M side, 4s on L side
9-16::
    1s & 4s dance Set & Rotate for first 6 bars then change places LH
    with person on sides:
::
    ''Set, Rotate singly & dance on 1 place clockwise, change places RH
    on sides then change places LH with person facing on sides (ie 2s &
    3s)
17-24::
    2s & 3s dance RH across in middle then LH across with 1s & 4s (all
    stay in the middle)
25-32::
    4s+2s & 1s+3s change places with an Allepousse (4s & 1s dance
    Allemande _while_ 2s & 3s dance Poussette) to end 2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (4570, '2013-08-21 08:30:50.844705+00', '2023-02-04 01:19:05.881551+00', 10597, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place to dance LSh round 1st corner to 2nd place opp
    side
9-16::
    2s+1s+3s set & cross RH, 1s cast to right into middle BtoB (1M
    facing up 1L facing down)
17-24::
    1M+2s also 1L+3s dance RH across almost once round opening out into
    2s+1s+3s (all on opp sides) & chase clockwise 1/2 way to own sides
    then all dance into middle to join partner facing up for…
25-32::
    3s+1s+2s dance Allemande to end 2s+1s+3s', 0);
INSERT INTO 'dancecrib' VALUES (13983, '2021-05-03 00:18:54.667429+00', '2023-02-04 01:19:05.910185+00', 1038, 3, NULL, 'ace', '1-4::
    1L+2L+3L set & dance across to opp side _while_ 1M followed by 2M+3M
    dance across top & down Ladies'' side
5-8::
    Men set & dance across to own side _while_ 1L followed by 2L+3L
    dance across top & down Ladies''s side.  3 2 1
9-16::
    1s turn 1.1/2 RH, cast up (2s step down) & 1s turn 3/4 LH
17-24::
    1L+3s (at top) & 1M+2s (at bottom) dance RH across; 1s pass RSh to
    dance LH across with other couple
25-28::
    All dance »Snake Pass«:
::
    1L followed by 3s & 1M followed by 2s pass RSh diagonally across
    through 2nd place to change ends, loop round to left, 1s end in 2nd
    place. 2 1 3
29-32::
    2s+1s+3s turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (4571, '2013-08-21 08:30:50.852836+00', '2023-02-04 01:19:05.92693+00', 1039, 3, NULL, 'ace', '1-8::
    1M+2s dance 1/2 reel of 3 across, 1M picks up partner in promenade
    to end reel & 1s dance into centre (2nd place opp side) facing down
9-16::
    1s dance out opp side, down behind 3s & into centre BtoB facing 3s,
    (Man facing Lady) set to 3s & turn (1M with RH & 1L with LH)
17-24::
    1s dance up between 3s, up behind 2s into centre BtoB facing 2s, set
    to 2s & turn (1M with LH & 1L with RH) to end at top on opp side
25-32::
    1s+3s dance double Fig of 8 (1s crossing down to start) with 1s
    crossing down to 2nd place at end
33-40::
    2s+1s+3s dance Grand Chain', 4);
INSERT INTO 'dancecrib' VALUES (4572, '2013-08-21 08:30:50.861069+00', '2023-02-04 01:19:05.945357+00', 13860, 3, NULL, 'ace', '1-8::
    2s & 4s set to & change places with partner as 1s+3s set & change
    places RH with opposite person to end in middle 1s facing up & 3s
    down, 1s+3s set & dance LH across 1/2 way ending BtB with partner
    facing 2s/4s
9-16::
    All dance first 6 bars reels of 4 across ending 1s & 3s on sides
    with 2s+4s in middle, 2s+4s dance LH across 1/2 way to end 2L+4M
    BtoB facing 1s & 4L+2M BtoB facing 3s
17-24::
    All dance first 6 bars reels of 4 across ending 2s & 4s on sides
    with 1s & 3s in middle, 1s+3s dance LH across 1/2 way to end in
    middle (1M facing 4L with partner behind him & 3M facing 2L with
    partner behind him
25-32::
    1M (followed by partner) dance tandem reel of 3 across (RSh to 4L)
    also 3M dances similarly (RSh to 2L) & end in square set opposite
    original place all facing partner. [1s & 3s may dance an alternating
    reel]
33-40::
    All set to partners & change places RH, (Ladies facing out) & all
    dance 4 bars of Schiehallion reels', 0);
INSERT INTO 'dancecrib' VALUES (4573, '2013-08-21 08:30:50.871156+00', '2023-02-04 01:19:05.965054+00', 1044, 3, NULL, 'ace', '1-8::
    1s in prom hold (Lady on left) dance reel of 3 with 2s (RSh to 2M to
    start) _while_ 3s dance similarly with 4s end with 1s/3s facing dn
    2s/4s up
9-16::
    1s dance under arch made by 2s & set to partner; 2s dance under arch
    made by 1s & set _while_ 3s+4s dance similarly
17-24::
    2s+3s dance LH across; 1s+2s also 3s+4s dance RH across
25-32::
    2s+3s dance LH across; 1L+2L 1/2 turn RH & Bal-in-Line with 3L
    _while_ 1M+2M 1/2 turn LH & Bal-in-Line with 3M
33-40::
    1L+3L 1/2 turn RH & Bal-in-Line with 4L _while_ 1M+3M 1/2 turn LH &
    Bal-in-Line with 4M; 1L+4L 1/2 RH _while_ 1M+4M 1/2 turn LH & all
    set to partners.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4575, '2013-08-21 08:30:50.890655+00', '2023-02-04 01:19:06.20373+00', 1045, 3, NULL, 'ace', '1-8::
    1s & 4s set advancing, turn 2H, cast in 1 place & all set
9-16::
    2s Fig of 8 round 1s _while_ 3s Fig of 8 round 4s
17-24::
    2s+1L also 3s+4M RH across _while_ 1M+4L turn RH, 2s+1M also 3s+4L
    LH across _while_ 1L+4M turn LH
25-32::
    2s lead down to meet 3s leading up, circle 4H round to left to
    original places & all set
33-40::
    1s turn RH, cast 1 place, lead down between 3s to 4th place _while_
    4s turn RH, lead up to top & cast to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (4576, '2013-08-21 08:30:50.898667+00', '2023-02-04 01:19:06.234014+00', 1046, 3, NULL, 'ace', '1-8::
    All dance reels of 4 on sides
9-16::
    1s & 4s turn RH moving into centre of set _while_ 2s+3s turn LH on
    sides & ending in corners, 1s+4s dance RH across.  2 1 4 3
17-24::
    1s+4s+3s dance reflection reels on sides (4s in & down to start)
25-32::
    4s dance Diag R&L (M down) ending 2 (3) 4 (1)

{{explanation}}
Note - repeat with new 2s & 4s on opposite sides, 2nd repeat ends with all on opposite sides & 4th repeat all on own sides', 0);
INSERT INTO 'dancecrib' VALUES (15316, '2022-12-19 01:18:59.583942+00', '2023-02-04 01:19:06.2767+00', 21207, 3, NULL, 'ace', '1-4::
    1s+2s Petronella turn  into middle, to face partners, & Set
5-8::
    1s+2s Turn partner 3/4  RH,retain RH & 1s+2s dance 1/2 RH across
9-16::
    1s, from sidelines, turn 1st corner RH, pass partner by RSh, turn
    2nd corner RH and pass RSh to own side, facing out
17-24::
    1s cast up, cross LH at top and cast off on opposite sides, cross RH
    and cast to 3rd place own side. (3s step up on bars 23-24)
25-32::
    3s+1s dance Strathspey (Diamond) Poussette', 0);
INSERT INTO 'dancecrib' VALUES (4577, '2013-08-21 08:30:50.908621+00', '2023-02-04 01:19:06.299564+00', 7637, 3, NULL, 'ace', '{{explanation}}
9 Dancers in triangular formation, 1 Man with 2 Ladies per side of triangle

1-8::
    All set, Men petronella turn to face partners (Ladies continue to
    set) & circle 3H round to left
9-16::
    Men dance RH across & LH back in centre _while_ Ladies cross RH,
    turn next Lady LH once round, cross RH back to place
17-24::
    All set, Ladies make arch & Men dance under & face in, Men set HS
    _while_ Ladies chase 2/3 clockwise to new partner
25-32::
    Men dance RSh reels of 3 with new partners, RSh to Lady on right to
    start', 0);
INSERT INTO 'dancecrib' VALUES (4578, '2013-08-21 08:30:50.918541+00', '2023-02-04 01:19:06.322395+00', 1050, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L. 1s+3s dance 1/2 R&L
9-16::
    All cross RH, 2M+3M also 3L+1M change places LH on sides, all cross
    RH & 2L+1M also 2M+1L 1/2 turn LH into prom hold as 3s Adv to centre
17-20::
    3s turn RH twice round as other couples dance round clockwise with
    1M leaving 2L in 1st place Ladies'' side & dancing on to 3rd place
    Ladies'' side _while_ 2M leaves 1L in 3rd place Men''s side & dances
    on to 1st place own side
21-24::
    3s dance out on opposite sides & cast to right into centre (3M
    between 1s, 3L between 2s)
25-32::
    3s dance 1/2 LSh reels of 3 (3M with 1s, 3L with 2s) & end 2nd place
    opp sides facing out. 2s+3s 1/2 double Fig of 8 (2s cross down to
    start).  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4580, '2013-08-21 08:30:50.936643+00', '2023-02-04 01:19:06.380604+00', 1058, 3, NULL, 'ace', '1-8::
    1s & 4s Fig of 8 round next couple to end in middle facing other
    couple & holding nearer hands
9-16::
    1s+4s advance towards each other, Ladies also Men dance out own
    sides & cast to orig places as 2s+3s adv to centre & turn to face
    crnrs, all set
17-32::
    All interlocking diagonal RSh reels of 4 & turn corners RH to end in
    original places ready for reels of 4 on sides
33-40::
    All RSh reels of 4 on sides ending with 1M & 3M also 2L & 4L facing
    in & 2M & 4M also 1L & 3L facing out to Bal-in-Line on the sides
41-48::
    All Bal-in-Line, 2s & 3s turn 1s & 4s into centre to form St Andrews
    Cross, all set, turn corners into lines across (1s & 4s on outside)
49-56::
    All Bal-in-Lines across, 2s followed by 1s dance under arches made
    by 3s & 4s who dance up, all dance out to side lines to end 3 4 1 2
57-64::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14366, '2021-10-11 22:39:10.731797+00', '2023-02-04 01:19:06.426658+00', 18049, 3, NULL, 'ace', '1-8::
    1s NHJ dance down, out behind 4s, up & out behind 3s & up to
    original places _while_ 2s & 3s dance up on sides & follow 1s. On
    bar 8, 1s+2s also 3s+4s change places on sides (Men RH, Ladies LH).
    1s+3s finish facing out
9-12::
    2s+1s also 4s+3s dance 1/2 double Fig of 8 (2) (1) (4) (3)
13-16::
    1s+4s+3s (bottom 3 couples) dance 1/2 reels of 3 on opposite sides
    (1s dance out & down to start). 3s+1s finish facing out (2) (3) (4)
    (1)
17-20::
    2s+3s also 4s+1s dance 1/2 double Fig of 8. 3s+1s finish facing out
    2 3 4 1
21-24::
    2s+3s+4s+1s dance 1/2 reels of 4 on own sides (Men pass RSh, Ladies
    pass LSh to begin) 1 4 3 2
25-28::
    All circle 8H 1/2 round to opposite sides (2) (3) (4) (1)
29-32::
    All turn partners 1/2 RH to face, pull back RSh & dance to opposite
    sides. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4583, '2013-08-21 08:30:50.959042+00', '2023-02-04 01:19:06.474028+00', 1060, 3, NULL, 'ace', '1-8::
    1s turn RH & cast down 2 places, cross LH & cast up to 2nd place
    opposite sides
9-16::
    1s turn RH & turn 1st corners LH, turn 2nd corners RH & turn partner
    LH to face 1st corners
17-24::
    1s 1/2 diagonal reel of 4 with 1st corners, pass RSh & dance 1/2
    diagonal reel with 2nd corners.  (3)(1)(2)
25-32::
    1s (centre couple) change places RH with person diagonally to Right,
::
    New centre couple change LH with person diagonally to Left,
::
    New centre couple change RH with person diagonally to Right
::
    All cross LH', 0);
INSERT INTO 'dancecrib' VALUES (15269, '2022-12-01 13:38:19.582255+00', '2022-12-03 10:24:08.867503+00', 21186, 1, 202, 'ace', '1--::
  1c set | cast off (2c up) ; set | turn P RH to 2pl and face out (2,1,3)
9--::
  ½ Reels3 on sides, 1c RSh to 3cnrs. On [12], 1c meet in centre, pivot R BtoB to P, 1M facing up, 1W facing down as for DTr position ; 4 bars of DTr up/down
17--::
  ½ Reels3 across, 1c RSh to 4cnrs[pos]. On [20] 1c meet in centre, pivot R BtoB to P facing own sides into DTr ; 4 bars of DTr (3x,1x,2x)
25--::
  All chase clw ½ ;  all turn P RH (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (8693, '2015-03-03 08:47:23.305062+00', '2023-02-04 01:19:06.503997+00', 12249, 3, NULL, 'ace', '1-8::
    1s cast down behind own lines (4 bars), turn outwards & dance back
    up to the top. Bar 8 1s turn LH 1/2 way to finish BtoB between 2s
    (1L facing 2M, 1M facing 2L)
9-16::
    1s+2s dance reel of 4 across.  At end 1s turn LH to finish in centre
    facing down on opp sides (2s finish in 2nd place)
17-24::
    1s dance down NHJ (3 bars), 1M dances below 1L & 1L dances under her
    raised left arm; 1s dance up staying in centre, 2s step in ready for
    …
25-32::
    1s+2s Poussette', 0);
INSERT INTO 'dancecrib' VALUES (4584, '2013-08-21 08:30:50.969169+00', '2023-02-04 01:19:06.535674+00', 9341, 3, NULL, 'ace', '1-8::
    1M+2L dance diagonal Fig of 8 (start passing LH & dance LSh round
    own partner, pass RH to dance RSh round others partner)
9-16::
    1s+2s set, 1L casts 1 place & 2M casts up 1 place _while_ 1M+2L
    cross into partners place, 1s set to 2s (across), 1M casts 1 place &
    2L casts up 1 place _while_ 2M+1L 3/4 turn RH
17-24::
    1s+2s diagonal reel of 4 (each passing partner RSh to start), 2M+1L
    end passing LSh to face partner (diagonally)
25-32::
    2s+1s 1/2 turn 2H & dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (4585, '2013-08-21 08:30:50.97749+00', '2023-02-04 01:19:06.550392+00', 8925, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 2nd place, dance RSh round 3s to end facing
    1st corners
9-16::
    1s turn 1st corners RH, partner LH, 2nd corner RH & pass LH to 2nd
    place own sides
17-24::
    2s+1s also 3s+4s Set+Link, all set & cross RH
25-32::
    All chase clockwise 1/2 way, set & petronella turn into line in
    centre facing partner
33-40::
    3s+4s also 2s+1s dance HS Poussette :
::
    3s/2s set HS step with both hands joined dancing out to Men''s side
    _while_ 4s/1s set & dance out to Ladies'' side ending with a 1/4 turn
    to right
::
    3s/2s dance HS down Men''s side & 4s/1s up Ladies'' side ending with a
    1/4 turn to right
::
    4s/1s+3s/2s dance HS into centre to reform line of 4 in middle with
    couples having changed places
::
    4s/1s+3s/2s 3/4 turn partners with both hands to own sides to end 4
    3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4586, '2013-08-21 08:30:50.98579+00', '2023-02-04 01:19:06.562858+00', 1066, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place, meet in centre nearer hands joined
    facing 2L, set to 2L turning to left to face 2M, set turning to face
    Men''s side
9-16::
    1L dances RH across with 2s _while_ 1M dances LH across with 3s. 1s
    turn about to face each other, set & turn 2H to face 3M
17-24::
    1s set to 3M turning to face 3L, set turning to face Ladies'' side.
    1M+2s dance LH across _while_ 1L+3s & dance RH  across. Bar 24 1s
    turn about to face each other up/down set
25-32::
    1s set & petronella turn on to own sides, 2s+1s+3s all turn partners
    2H', 0);
INSERT INTO 'dancecrib' VALUES (4588, '2013-08-21 08:30:51.110188+00', '2023-02-04 01:19:06.731209+00', 11375, 3, NULL, 'ace', '1-8::
    1s turn RH & LH
9-16::
    1s+2s dance double Fig of 8 (1s cross down _while_ 2s dance up)
17-24::
    1s & 2s 3/4 turn RH into line up/down & retaining hands set to
    partner, dance out to opposite sides, pull back RSh  & set
25-32::
    »Spiral Progression«:  1M+2L turn RH to give LH to prtnr &
    Bal-in-Line, on 2nd setting step 1L & 2M turn left about (face
    clockwise) & 1s+2s in diag line rotate 1/4 way clockwise. 1L & 2M
    drop hands & dance to next pstn on sidelines _while_ 1M+2L continue
    turning RH to end 2 1', 0);
INSERT INTO 'dancecrib' VALUES (14485, '2021-12-18 01:43:19.647718+00', '2023-02-04 01:19:06.794506+00', 7639, 3, NULL, 'ace', '1-8::
    1s+3s NHJ with partner slip step across (Men pass BtoB), set, back
    to place (Ladies pass BtoB), set
9-16::
    Interlocking reels of 3: All dance RSh reel of 3 with partner &
    corner
17-24::
    1M+3M change places RH, change places LH with partner. 2M+4M repeat,
    remain in centre, 3M+1L also 1M+3L step in all joining 2H ready for
    …
25-32::
    All dance 4 couple Poussette:   4s+(3M+1L) & 2s+(1M+3L) dance
    Poussette with Men dancing backwards to start.  Bars 31-32: 1s & 3s
    join NH with partners & retire to place _while_ 2s & 4s set to
    partners.  End 2 3 4 1 - all having moved 1 place anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (4589, '2013-08-21 08:30:51.124489+00', '2023-02-04 01:19:06.836524+00', 14533, 3, NULL, 'ace', '1-8::
    Inveran Reels - 1s cross down to dance 1/2 reel of 3 on opp side; 1s
    cross up to dance 1/2 reel on own sides (2s out/up, 3s in/up),  2s
    face out
9-16::
    1s+2s dance double Figs of 8 (1s start crossing down, 2s dancing up)
17-24::
    1s lead down the middle & back up, 1s end in middle of the set
    facing each other both hands joined, 2s step in ready for
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (4590, '2013-08-21 08:30:51.133072+00', '2023-02-04 01:19:06.867668+00', 1072, 3, NULL, 'ace', '1-8::
    1s & 3s set & 3/4 turn partners RH, 1s+3s dance 1/2 reel of 4
    up/down centre
9-16::
    3s & 1s 3/4 turn partner RH _while_ 2s set, 3s+2s+1s chase clockwise
    1/2 way & cross RH
17-24::
    1s+2s+3s dance Grand Chain
25-32::
    1s+2s dance Espagnole:
::
    _25-26_   1s+2s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _27-28_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _29-32_   2s turn RH as 1s turn LH', 0);
INSERT INTO 'dancecrib' VALUES (4591, '2013-08-21 08:30:51.141459+00', '2023-02-04 01:19:06.899515+00', 7358, 3, NULL, 'ace', '1-8::
    Ladies dance behind partners into centre & dance RH across once
    round & curve out to opposite Ladies place
9-16::
    Men dance behind new partners into centre & dance LH across once
    round & curve out to opposite Mans place
17-24::
    Ladies dance RH across 1/2 way & turn opposite Man LH 1.1/2 times
    (Men having moved into partners place)
25-32::
    All Set+Link with new partners, Set+Link with corners to meet own
    partner having moved 1 place clockwise', 0);
INSERT INTO 'dancecrib' VALUES (4592, '2013-08-21 08:30:51.149537+00', '2023-02-04 01:19:06.926167+00', 1074, 3, NULL, 'ace', '1-8::
    1s set, cast to 2nd place, set & turn 3/4 LH
9-16::
    1s dance reels of 3 across (1M with 2s & 1L with 3s) giving LSh to
    2M/3L to start & end 1M facing 2s (in double triangle position) & 1L
    facing 3s
17-20::
    1s set with facing couples, turn person on right RH (1M+2L & 1L+ 3M)
    _while_ 3L & 2M set.
21-24::
    1s dance 1/2 reels of 3 on opposite sides (1M down, LSh to 3L, 1L
    up, LSh to 2M) & end facing same couples (who have changed places)
25-28::
    1s set with facing couples, turn person on right RH (1M+2M & 1L+3L)
    _while_ 3M & 2L set
29-32::
    1s dance 1/2 reels of 3 on own sides (1M up, LSh to 3M, 1L down, LSh
    to 2L) ending in 2nd place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8559, '2015-02-13 12:47:32.418076+00', '2023-02-04 01:19:06.956063+00', 1077, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, dance circle 6H round to Left, set, circle 6H round to
    Left to places
9-16::
    1s turn RH, cast, to face 1st corners (2s step up 11-12).  1s set to
    1st corners, set to 2nd corners, finish between corners  2 (1) 3
17-24::
    1s+2s dance R&L
25-28::
    2s+1s+3s 1/2 Grand Chain (1 bar per hand).  Ladies turn right about
    to form circle with men
29-32::
    3s+1s+2s circle 6H 1/2 round to Left.  1s cross RH to 2nd place own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (15219, '2022-11-03 01:19:01.3001+00', '2023-02-04 01:19:06.983464+00', 19120, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 down round 2s _while_ 2s set, cross RH, set & cross
    back RH
9-16::
    1s cross RH, cast (2s step up 11-12) meet, dance down NHJ & cast up
    round 3s to 2nd place opp side
17-24::
    1s dance Fig 8 down round 3s _while_ 3s set, cross RH, set & cross
    back RH.  2 (1) 3
25-32::
    2s+1s+3s dance mirror reels of 3 on sides (1s in/up, 2s out/down 3s
    out/up) Bar 29: 1s cross down from 2nd place opp sides to 3rd place
    to continue reels.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4593, '2013-08-21 08:30:51.157615+00', '2023-02-04 01:19:07.021501+00', 10071, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance 1/2 Figs of 8 (1M round 2s & 1L round
    3s)
9-16::
    1s dance 1/2 reels of 3 on sides (LSh to 1st corner to start) & 1/2
    diagonal reel of 4 with 2nd corners (RSh to 2nd corner to start)
17-24::
    1s dance 1/2 reel of 3 across (LSh to 3rd corner to start) & 1/2
    diagonal reel of 4 with 4th corners (RSh to 4th corner) ending with
    a 3/4 turn LH,
25-32::
    1M dances up between 2s _while_ 1L dances down between 3s, cast left
    to 2nd places own sides & 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (9275, '2016-07-15 04:43:20.520437+00', '2022-12-03 11:58:54.903684+00', 4302, 2, 160, 'ace', '1-4::

  1C 2C chase:- 1L (followed by 1M) casts off and across to 2M''s place  *AS* 2M (followed by 2L) casts up and across to 1L''s place ; (2x 1x 3 4)

5-8::

  1C 3C chase:- 1M (followed by 1L) casts off and across to 3M''s place *AS* 3M (followed by 3M) casts up and crosses to 2L''s place.  (2x 3x 1 4)

9-16::

  All dance Left shoulder Reel of 4 on sides.

17-20::

  All set and cross over RH (2 3 1x 4x) ;

21-24::

  1C 4C chase:- 1M (followed by partner) casts off and across to own side *AS* 4L (followed by partner) casts up and across to own side. (2 3 4 1)', 2);
INSERT INTO 'dancecrib' VALUES (4527, '2013-08-21 08:30:50.118121+00', '2023-02-04 01:19:02.409024+00', 971, 3, NULL, 'ace', '1-8::
    1s set advancing, turn 2H & cast to 2nd place own sides
9-16::
    1s petronella turn to right, 2s+1s+3s set (lady with 2s & Man with
    3s), 2s+1s+3s Adv+Ret up/down set
17-24::
    1s petronella turn to right, 2s+1s+3s set (lady with 2M+3M & Man
    with 2L+3L), 2s+1s+3s Adv+Ret
25-40::
    1s repeat bars 9-24 (with Man between 2s)
41-48::
    1s set advancing, turn 2H & cast to bottom of set', 0);
INSERT INTO 'dancecrib' VALUES (14513, '2022-01-10 02:18:43.44626+00', '2023-02-04 01:19:07.049408+00', 17953, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1L followed by 1M & 2L followed by 2M dance Fig 8 round 4s & 2nd
    place (2s follow 1s - RSh to 4s) back to place pulling back LSh to
    face clockwise
9-16::
    1M followed by 1L & 2M followed by 2L dance Fig 8 round 3s & 1s
    place (1s follow 2s - LSh to 3s) back to place
17-24::
    1s+3s dance RH across 2.1/2 times round (Men lead in, RH across
    twice, Men lead out) to change places 3 2 1 4
25-32::
    All 4 couples set & Petronella in Tandem to right, face clockwise &
    chase clockwise 1/2 round to  4 3 2 1
33-64::
    Repeat  in Strathspey (Bars 1-16: 4s follow 3s then 3s follow 4s) 1
    2 3 4

{{title}}
Reel

65-128::
    Repeat 1-64 in Reel time but Bars 17-24 & 49-56 only dance 1.1/2 RH
    across', 0);
INSERT INTO 'dancecrib' VALUES (4595, '2013-08-21 08:30:51.177563+00', '2023-02-04 01:19:07.07067+00', 10185, 3, NULL, 'ace', '1-8::
    1s & 3s petronella turn & set twice to opposite sides _while_ 2s set
    & petronella turn twice to end between 1s/3s
9-16::
    1s & 3s cross RH & cast behind 2s (passing LSh) to other end _while_
    2s set & cross RH, all dance 1/2 reel of 3 on sides (2s out & up to
    start)
17-24::
    1s dance 1/2 Fig of 8 on own sides (dance between 2s to start),
    dance up to top & cast to 2nd place (2s cast to top on bars 17-18)
25-32::
    1s dance reels of 3 across (1s giving LSh to 1st corner to start)', 0);
INSERT INTO 'dancecrib' VALUES (4596, '2013-08-21 08:30:51.188673+00', '2023-02-04 01:19:07.10318+00', 10692, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance DoSioDo
9-16::
    1s dance reels of 3 on sides (in & down to start)
17-24::
    1s turn 1st corner, partner, 2nd corner & partner to end 2nd place
    own side
25-32::
    2s+1s+3s Adv+Ret & turn 2H twice', 0);
INSERT INTO 'dancecrib' VALUES (4597, '2013-08-21 08:30:51.198396+00', '2023-02-04 01:19:07.15867+00', 1084, 3, NULL, 'ace', '1-8::
    1s & 4s turn partner 2H & dance DoSiDo with partner
9-16::
    1s+2s also 3s+4s circle 4H round to left ending 1s & 3s facing down
    2s & 4s up, set, 1s & 4s cast in 1 place _while_ others dance out
17-24::
    1s+4s Diamond Poussette
25-32::
    1s+4s+3s dance the Knot to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4599, '2013-08-21 08:30:51.220383+00', '2023-02-04 01:19:07.202942+00', 1087, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance 1/2 Fig of 8 round 2s
9-16::
    1s set twice with 1L pulling back RSh on bars 11-12  to face out, 1L
    followed by partner casts up & dances down the middle 1L to face 3M
    _while_ 1M faces 2M
17-24::
    1s RSh reels of 3 across (1M with 2s & 1L with 3s)
25-32::
    1L followed by partner dances down cast up round 3M & crosses to end
    in 2nd place on own sides, 1s turn RH (4 bars)', 0);
INSERT INTO 'dancecrib' VALUES (4600, '2013-08-21 08:30:51.292988+00', '2023-02-04 01:19:07.229288+00', 14962, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s dance 1/2 diag reel with 1st crns & 1s
    end RSh to RSh in middle 1M facing up 1L down
9-16::
    1L+2s (Ladies'' side) & 1M+3s (Men''s side) dance LH across, 1s pass
    LSh & dance RH across with other cpl (1s end facing 2nd crnrs who
    face out)
17-24::
    1s dance 1/2 diag reel with 2nd crns & all end opposite sides,
    (3s)+(1s)+(2s) set & all cross RH
25-32::
    3s+1s+2s chase c/wise 1/2 way then turn partner RH 1/2 way, all face
    partners & cast by right to own sides   2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (13984, '2021-05-03 00:18:55.815386+00', '2023-02-04 01:19:07.255937+00', 15051, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-16::
    1s+2s dance 1/2 RH across, set facing in diagonally; 1s+2s pull back
    RSh & dance out to opp sides, 1s turn RH to face 1st corners _while_
    2s cross RH (2) (1) 3
17-20::
    Corner Pass & Twirl with 1st corners
::
    1s pass corners RSh, dance round corner place. 1s end facing 2nd
    corner _while_ 1st corners dance in, 1/2 turn RH, face & pulling
    back RSh dance out to opp corner place
21-24::
    1s repeat Corner Pass & Twirl with 2nd corners. 1s pass RSh to 2nd
    place own side facing out. (3) 1 (2)
25-32::
    3s+1s+2s dance RSh reels of 3 on sides (1s pass 3rd corner RSh to
    start). 3s+2s end reel crossing RH with partner.  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (10524, '2018-03-20 06:26:18.784418+00', '2023-02-04 01:19:07.350827+00', 17098, 3, NULL, 'ace', '1-4::
    1s turn RH & cast 1 place, 2s step up bars 3-4
5-8::
    2s+1s+3s turn partners 2H 1.1/2 times to opposite side, 2s & 3s face
    in, 1s face out (2) (1) (3)
9-12::
    1s dance RSh round 1st corner, cross RH up/down set, _while_ 1st
    corner positions (2L & 3M) dance in, 1/2 turn RH, twirl & dance out
    to each others place
13-16::
    Repeat bars 9-12, 1s dancing RSh round 2nd corner & cross RH to own
    side, 2nd corner positions dance similarly.
17-24::
    3s+1s+2s dance 6H round & back
25-32::
    1s+2s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (4603, '2013-08-21 08:30:51.322575+00', '2023-02-04 01:19:07.38028+00', 10502, 3, NULL, 'ace', '1-8::
    1s & 4s set & petronella turn into centre _while_ 2s & 3s step
    up/down, 1s+2s also 3s+4s dance RH across
9-16::
    1s & 4s set & petronella turn to 2nd/3rd place opposite sides, 1s+4s
    dance LH across to end facing corners
17-24::
    All set & pass facing person RSh, 2s+3s dance LH across 1/2 way to
    end facing corners & pass facing person RSh
25-32::
    1s+4s dance LH across, all (on opp sides) set & cross RH.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (4604, '2013-08-21 08:30:51.342568+00', '2023-02-04 01:19:07.411206+00', 11802, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All circle 4H round & back
9-16::
    Anticlockwise couple dance under arch made clockwise couple, all
    turn about & repeat back to places
17-24::
    All dance RH across & LH back
25-32::
    Ladies change places RH, Men change places LH, set to partner & 1/2
    turn RH to face new couple', 0);
INSERT INTO 'dancecrib' VALUES (9719, '2017-04-06 08:39:34.016557+00', '2023-02-04 01:19:07.465045+00', 1093, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up), cross LH & 1L casts up, 1M casts
    down to join LH with partner in centre, RH to 1st corners
9-16::
    1s dance the Spoke:
::
    _9-10_    Bal-in-Line, Drop RH & dancing couple move anticlockwise
    to next corner (PdeB throughout)
::
    _11-16_  Repeat with next 3 corners
17-24::
    1s dance LSh reels of 3 on opp sides (1L+3M & 1M+2L pass LSh to
    start).  1s end facing 1st corners
25-32::
    Diag RSh reels of 4.  1s end in 2nd place opp sides facing down
33-40::
    2s+1s+3s dance reflection reels of 3 on opp sides (1s dance
    out/down, 3s in/up, 2s in down to start). 1s cross from 1st place to
    2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (15057, '2022-09-05 00:18:56.986962+00', '2023-02-04 01:19:07.492563+00', 20916, 3, NULL, 'ace', '1-8::
    1s set, dance down NHJ below 3s (2s step up 3-4); 1s cast up & cross
    LH to face 1st corners
9-16::
    1s 1/2 turn corners RH into prom hold (corners on their right)  &
    promenade clockwise 1/2 round (4 bars). 1s leave corners in diag opp
    place & turn LH to face 2nd corners _while_ 2nd corners set, Adv+Ret
    diagonally & set
17-24::
    1s repeat 9-16 with 2nd corners to end in 2nd place own side _while_
    1st corners set, Adv+Ret diagonally & all 3 couples set
25-32::
    1s dance diag R&L (Lady up / Man down).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4541, '2013-08-21 08:30:50.247159+00', '2023-02-04 01:19:03.432888+00', 13752, 3, NULL, 'ace', '1-8::
    1M followed by 2M+3M+4M cross & dance down to face Ladies who turn
    right about, Men turn Ladies 2H 1.1/2 times to own side
9-16::
    4L followed by 3L+2L+1L cross & dance up to face Man who turn right
    about, Ladies turn Men 2H to own sides.  4 3 2 1
17-24::
    All circle 8H round & back
25-32::
    Top 3 couple dance allemande to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14899, '2022-06-27 00:19:05.607212+00', '2023-02-04 01:19:07.557227+00', 10751, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across; 1s cast (2s dance up), set advancing pulling
    back RSh to BtoB facing own side
9-16::
    2s+1s+3s dance Double Triangles, 1s end in centre facing up (1L
    pulls back RSh)
17-20::
    1M+2M+3M dance LH across _while_ 1L+2L+3L dance RH across
21-24::
    1M+3M+4M dance RH across _while_ 1L+3L+4L dance LH across, 3s end in
    2nd place _while_ 1s+4s continue turning on sides to end 2 3 4 1
25-32::
    All dance RSh reels of 4 on sides
33-40::
    1M+4M turn RH _while_ 1L+4L turn LH; 4s+1s dance RH across.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4606, '2013-08-21 08:30:51.361295+00', '2023-02-04 01:19:07.584671+00', 1096, 3, NULL, 'ace', '1-8::
    1s+2s 3/4 turn partners RH, 1M+2L turn LH 1.1/2 times _while_ their
    partners dance round them clockwise 1/2 way, 1s+2s 3/4 turn partners
    RH
9-16::
    2s+1s double Fig of 8 with 1s crossing up & 2s casting to start
17-24::
    1s reflection reels of 3 on own sides 1s dancing in & up to start
25-32::
    1s cross below 3s, cast down behind 4s & turn RH 1.1/2 times to 4th
    place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4607, '2013-08-21 08:30:51.369371+00', '2023-02-04 01:19:07.614875+00', 9148, 3, NULL, 'ace', '1-8::
    1s turn 2H, cast 1 place, turn 1.1/2 times to face 1st corners
9-16::
    1s dance 1/2 diagonal reels of 4 with 1st corners & turn 3rd corner
    (1st( corner person) RH to face 4th corner
17-24::
    1s dance 1/2 diagonal reel of 4 with 4th corners & turn 2nd corner
    (4th corner person) RH to end BtoB (Man facing up & Lady down)
25-32::
    1s circle 3H round to left (Man with 3s in top place & Lady with 2s)
    opening out to 6H round to left', 0);
INSERT INTO 'dancecrib' VALUES (4610, '2013-08-21 08:30:51.393773+00', '2023-02-04 01:19:07.697624+00', 10918, 3, NULL, 'ace', '1-8::
    1s dance down, cast up round 3s, between 2s & cast down to 2nd place
9-16::
    1s+1st corners dance RH across, 1s+2nd corners dance LH across 1s
    end facing 1st corners
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass LSh & dance
    1/2 reel with 2nd corners - 1s end 2nd place opposite sides
25-32::
    1s dance 1/2 reels of 3 across (Lady with 2s (3rd place) & Man with
    3s) & dance 1/2 reels of 3 on own sides', 0);
INSERT INTO 'dancecrib' VALUES (4611, '2013-08-21 08:30:51.401988+00', '2023-02-04 01:19:07.714836+00', 15076, 3, NULL, 'ace', '1-8::
    1s dance RSh reels of 3 on own sides
9-12::
    1L casts behind 2L+3L & in to face 3M _while_ 1M dances across casts
    round 2L (2s up) to face 2M
13-16::
    1s dance LSh round facing Man to face opp Lady
17-24::
    1s dance RSh reels of 3 across (1M with 2s, 1L with 3s)
25-28::
    1M dances RSh round 2L & turns right about to face down between 2s
    _while_ 1L dances RSh round 3L to face up between 3s
29-32::
    1s change places RH & casts to 2nd place own sides
33-40::
    2s+1s dance R&L to end facing down (no polite turn)', 0);
INSERT INTO 'dancecrib' VALUES (4612, '2013-08-21 08:30:51.410172+00', '2023-02-04 01:19:07.743007+00', 9168, 3, NULL, 'ace', '1-8::
    1s dance 4 slip steps down below 2s & set, dance down between 3s &
    cast up 1 place to face 1st corner
9-16::
    1s dance ''Hello-Goodbye'' setting & petronella turn to 2nd places
17-24::
    1s dance 4 slip steps down below 3s & set, dance down between 4s &
    cast up 1 place to face new 1st corner
25-32::
    1s turn corners RH & pass RSh to face 2nd corner, turn 2nd corner RH
    & pass partner RSh to end in 4th place own sides
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4613, '2013-08-21 08:30:51.420024+00', '2023-02-04 01:19:07.850265+00', 1100, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s RH across & LH across back to place
9-16::
    1s set, cast 1 place & R&L with 2s (one step to each hand)

{{title}}
Reel

17-24::
    1L dances a Fig of 8 round 2M+3M _while_ 1M dances round 3L+2L,
    start by giving RSh to 1st corner & ending facing 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting ending with a clap & petronella
    turn to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (4614, '2013-08-21 08:30:51.428097+00', '2023-02-04 01:19:07.875073+00', 1103, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reels of 3 on own sides, 1s end
    facing 2s in centre
17-24::
    1s dance down under arch made by 2s who dance up, 1s NHJ cast up on
    Men''s side _while_ 2s NHJ cast down on Ladies'' side, 1s+2s face in
    centre & change places RH with opposite person
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13051, '2020-08-10 00:18:56.354217+00', '2023-02-04 01:19:07.900632+00', 11618, 3, NULL, 'ace', '1-8::
    Bar 1: Men turn partner into Allemande hold & all promenade
    anticlockwise round to place, Bar 6: Men bring partner in to centre
    (Ladies BtoB); Bars 7-8:  Ladies Set, Men Retire (PdeB)
9-16::
    All dance »Crown Triangles« (Ladies set bars 1 3 5, move to right
    bars 2 4 6) Bars 15-16: All change places with partner (PdeB), Men
    BtoB
17-24::
    Repeat 9-16 with Ladies ending BtoB in centre
25-32::
    All dance 2/3 Schiehallion reel, passing partner RSh to start.  End
    facing partner having moved 1 place clockwise round
33-40::
    All turn partner RH; all turn corner LH & face partner', 0);
INSERT INTO 'dancecrib' VALUES (9177, '2016-06-16 22:41:36.140959+00', '2023-02-04 01:19:07.922926+00', 8042, 3, NULL, 'ace', '1-8::
    1L, followed by 2L+3L, dance across top, behind 1M+2M+3M & across to
    Ladies'' side and back to places
9-16::
    Men repeat, 1M leading
17-24::
    1s join 2H, slip step down (2 bars) and back to top (2 bars), cast
    to 4th place (2s+3s+4s step up 23-24)
25-32::
    All circle 8H round and back', 0);
INSERT INTO 'dancecrib' VALUES (8560, '2015-02-13 12:47:32.763029+00', '2023-02-04 01:19:07.943125+00', 15618, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up), 1s set, cast (3s step up)
9-16::
    1s dance up middle (3 bars), down middle (3 bars) & cast to 2nd
    place own sides (3s step down 15-16)
17-24::
    2s+1s dance R&L finishing 1s in centre & 3s step in (bar 24) ready
    for ...
25-32::
    1s+3s Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7865, '2013-08-21 08:31:50.073272+00', '2023-02-04 01:23:07.844057+00', 6996, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross LH & cast 1 place (Lady up & Man
    down) to end facing 1st corners
9-16::
    1s dance 1/2 RSh reels of 3 across (Lady with 2s & Man with 3s) &
    1/2 LSh reels of 3 on opposite sides ending facing 3rd corners
17-24::
    1s turn corner RH, partner LH, 2nd corner RH & partner LH to face
    own sides
25-32::
    1s dance out own sides, cast left & in to meet partner in centre
    _while_ 2s+3s dance 1/2 R&L, 2s+1s+3s turn RH 1s ending 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (14900, '2022-06-27 00:19:06.039172+00', '2023-02-04 01:19:07.973371+00', 20875, 3, NULL, 'ace', '1-2::
    1s cross RH, _while_ 2s & 3s set
3-6::
    1s set, cross RH, _while_ 2s+3s circle 4H to the left
7-8::
    1s+2s+3s set
9-16::
    1s+2s dance the Tourbillon:
::
    _9-12_ 1s & 2s turn partners 2H 1/2 way, 1M & 2L lead partners on 1
    place clockwise to end 1s on Ladies side & 2s on Men''s side, 1s set
    to 2s
::
    _13-16_ 1s & 2s 1/2 turn partners 2H, 1L & 2M lead partners on 1
    place to end 2s in 1st pl & 1s in 2nd pl & 2s+1s cross RH to own
    sides. (2 1 3)
17-24::
    1s dance out round 3rd corners, turn 3/4 LH, dance out round 2nd
    corners by the right
25-28::
    2s+1s+3s dance 1/2 reels of 3 on opposite sides (1s giving LSh to
    1st corners)
29-32::
    1s turn 1 1/2 with 2H. (3 1 2)', 0);
INSERT INTO 'dancecrib' VALUES (12631, '2020-03-02 01:51:49.520235+00', '2023-02-04 01:19:08.006221+00', 17745, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole ending 1s briefly retaining LH to face 1st
    corners
9-12::
    1s dance 1/2 diag reel of 4 with 1st corners. 1s pass LSh to face
    2nd corners
13-16::
    1s dance 1/2 diag reel of 4 with 2nd corners & finish facing 1st
    corner person (3rd corner pstn)
17-24::
    1s set & turn 1st corners 2H; face 4th corner pstn, set to & turn
    2nd corners 2H. 1s finish 2nd place on own side
25-28::
    1s+3L+2M dance 1/2 diag R&L (Man down, Lady up)
29-32::
    1s+3M+2L dance 1/2 diag R&L (Man down, Lady up). 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13052, '2020-08-10 00:18:56.470873+00', '2023-02-04 01:19:08.059924+00', 1114, 3, NULL, 'ace', '1-6::
    1s+3s dance »The Capstan«:
::
    _1-2_   1s NHJ dance down 2 places _while_ 3s cast up to 1st place
::
    _3-4_   3s NHJ dance down 2 places _while_ 1s cast up to 1st place
::
    _5-6_   1s NHJ dance down 2 places curving into 3rd place _while_ 3s
    cast up to first place
7-8::
    1s+2s 1/2 turn on side (Men RH, Ladies LH)
9-16::
    1s cross down to dance reels of 3 on opp sides (3s out/down, 2s
    out/up to start).  2s+3s end reels with loops, 1s face 2nd corner
    (pstn)
17-20::
    1s join LH with partner, RH with corner (1M+3L & 1L+2M)  &
    Bal-in-Line, 1s 1/2 turn LH _while_ corners chase 1 place clockwise
21-24::
    1s join LH with partner, RH with 4th corner pstn (1M+2L &1L+3M) &
    Bal-in-Line, 1s 1/2 turn RH
25-32::
    1M+2s (at top) also 1L+3s (at bottom) dance RH across to end all on
    opp sides (2) (1) (3); all turn partner 1.1/2 RH.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4616, '2013-08-21 08:30:51.565164+00', '2023-02-04 01:19:08.105909+00', 11803, 3, NULL, 'ace', '{{explanation}}
3 couples in triangular formation with 4th Man in centre, on chord all bow/curtsey inward with 4M bowing to 1s then faces 2s

1-8::
    4M sets to 2s, sets to 3s, circles 3H round to right with 1s & ends
    facing 3s
9-16::
    4M circles 3H round to left with 3s, turns right about to dance 3H
    round to right with 2s & ends facing 1s
17-24::
    4M dances RH across with 1s _while_ 2s+3s dance 1/2 R&L, 4M dances
    LH across with 3s _while_ 1s+2s dance 1/2 R&L
25-32::
    4M sets twice to 1s (3rd place) as 1L advances, giving RH she turns
    under 4M''s arm back to place, 4M+1M change places RH & 1M faces 2nd
    pl', 0);
INSERT INTO 'dancecrib' VALUES (4617, '2013-08-21 08:30:51.573399+00', '2023-02-04 01:19:08.125501+00', 11368, 3, NULL, 'ace', '1-8::
    1s+2s dance "Chain and Turn":
::
    _1-2_    1M+2L 3/4 turn RH into diag line 1M+2M, 1L+2L facing
::
    _3-4_    1M+2M also 1L+2L 1/2 turn LH, 1M end in 2M place & 2L in 1L
    place
::
    _5-8_    1L+2M turn RH 1.1/4 times to end 1L in 2L place, 2M in 1M
    place  (2 1 3)
9-16::
    2s+1s set, 1/2 turn RH to face down in centre (4 bars).  2s+1s lead
    down, 2s & 1s 1/2 turn (Men dancing below Ladies who dance under
    Man''s arm) & lead up
17-24::
    1s cross up to dance reels of 3 on opp sides (2s out/down, 3s cast
    up) 1s end 2nd place opp sides, 2s & 3s curve into places 2 (1) 3
25-32::
    2s+1s+3s Adv+Ret 1 step, 1s petronella turn to 1M between 2s & 1L
    between 3s, Adv+Ret 1 step & 1s Petronella turn to 2nd pl own sides
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4619, '2013-08-21 08:30:51.597131+00', '2023-02-04 01:19:08.165955+00', 1124, 3, NULL, 'ace', '1-16::
    1s & 3s set & cross passing partner RSh, clap (bar 3) & chase
    clockwise 1/2 way round standing 2s.  1s & 3s repeat back to places
17-24::
    2s & 4s 1/2 turn RH into prom hold facing up, set, dance up 1 place
    & cast off 1 place on opp sides  1 (2) 3 (4)
25-32::
    Men set advancing to Bal-in-Line pstn in centre _while_ Ladies set,
    Men retire _while_ Ladies advance to  Bal-in-Line pstn in centre.
    Repeat, Men advancing _while_ Ladies retire, Ladies advance _while_
    Men retire. Ladies end in Bal-in Line pstn in centre
33-40::
    All Ladies dance Fig of 8 round ptnr (RSh) & other Lady (LSh) &
    opposite Man (LSh), to finish in place
41-48::
    Men dance reel of 4 up/down middle (1M+2M also 3M+4M pass RSh to
    start) End in places
49-56::
    1s & 3s cross RH, cast 1 place (2s & 4s step up).  All 1/2 turn
    partners RH to face up in prom hold & all set
57-64::
    Promenade round set, 2s (top) & 4s (3rd place) to Left, 1s (2nd
    place) & 3s (4th place) to Right.  »Interleave« as couples pass at
    bottom & dance up to end 2 1 4 3.

{{title}}
Repeat from new positions as follows

65-88::
    Repeat bars 1-24 with new couples
89-96::
    Repeat bars 25-32 with new 1st & 3rd couples but  Ladies dance in
    first & Men end in centre in Bal-in-Line pstn
97-104::
    All Men dance Fig of 8 round ptnr (LSh) & other Man (RSh) & opposite
    Lady (RSh), to finish in place
105-112::
    Ladies dance RSh reel of 4 up/down middle
113-128::
    Repeat 49-64
129-144::
    All couples set, clap (bar 3) & cross RH, all chase clockwise round
    to opp sides.  Repeat set, clap & cross & chase, to finish in
    original places', 0);
INSERT INTO 'dancecrib' VALUES (4620, '2013-08-21 08:30:51.605388+00', '2023-02-04 01:19:08.189752+00', 8178, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on own sides (2s in & up as 1s
    & 3s cast) & end with 1s casting to face 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places
17-24::
    1s 3/4 turn RH & 1L turns 1.1/4 times under Mans right arm ready to
    dance RH across with 2L+3L _while_ 1M dances LH across with 2M+3M
25-32::
    1L dances LH across with 2M+3M _while_ 1M RH across with 2L+3L, 1s
    dance 1/2 Fig of 8 round 3s (cast to start)

{{explanation}}
NOTE	2nd time through - 1L dances LH across with 3M+4M while 1M RH across with 3L+4L & 1s cast down to 4th place & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (9910, '2017-06-05 11:30:51.074962+00', '2023-02-04 01:19:08.2354+00', 14136, 3, NULL, 'ace', '1-4::
    1s set, 1L crosses down to 2M place _while_ 1M crosses to 1L place
    (2M steps up 3-4)
5-8::
    1L+2M also 1M+2L turn 3/4 RH.  1s end BtoB in middle, 1M facing 2L,
    1L facing 2M.  1s+2s set.  (1s & 2s are between 1st & 2nd places)
9-24::
    1s+2s dance 16 bars of ''Celtic Reel'':
::
    _9-12_   1s+2s pass RSh as for reel of 4, 1s dance clockwise 1/4 way
    _while_ 2s turn 3/4 LH round each other to face other prtnr
    (up/down)
::
    _13-16_ 1s+2s pass RSh as for reel of 4, 2s dance clockwise 1/4 way
    _while_ 1s turn 3/4 LH round each other to face other partner
    (across)
::
    _17-24_ Repeat 9-16 ending with 2s dancing into 1st place, 1s to
    face up in centre, 2nd place on opp sides
25-28::
    1L+2M turn LH _while_ 1M+2L turn RH.  1s end in 2nd place opp sides
29-32::
    1s dance 1/2 Fig 8 up round 2s', 0);
INSERT INTO 'dancecrib' VALUES (4622, '2013-08-21 08:30:51.619877+00', '2023-02-04 01:19:08.255552+00', 7647, 3, NULL, 'ace', '1-8::
    1s Promenade anticlockwise acknowledging each couple in turn
9-16::
    1s+3s also 2s+4s dance Interlocking R&L (1s+3s change places RH on
    sides to start)
17-32::
    All with 2H joined set into middle, 1/4 turn to right, dance out &
    turn into next place Repeat 3 times to original place (when dancing
    into middle Men always have LSh to centre)
33-40::
    Set to & turn corner LH, set & turn partner RH
41-48::
    All dance Double Ladies'' Chain
49-56::
    Set to & turn corner RH, set & turn partner LH
57-64::
    All dance Double Men''s Chain
::
    Repeat 3 times with 2s, 3s & 4s starting in turn', 0);
INSERT INTO 'dancecrib' VALUES (4623, '2013-08-21 08:30:51.6283+00', '2023-02-04 01:19:08.293344+00', 1128, 3, NULL, 'ace', '1-8::
    All Ladies dance RH across once round as Men dance anticlockwise 1/2
    way, Ladies give LH to opp Man, set & 1/2 turn Men into centre
9-16::
    Men dance RH across once round as Ladies dance anticlockwise 1/2
    way, Men give LH to partners, set & 1/2 turn partners
17-24::
    1s+3s Adv+Ret 2 steps & dance 1/2 R&L End in original places
25-32::
    2s+4s Adv+Ret 2 steps & dance 1/2 R&L End in original places
33-40::
    All set to partners & turn RH, set to corners & turn corner RH into
    prom hold facing anticlockwise
41-48::
    Men Promenade their corners round anticlockwise & bring corners
    across in front of them to repeat dance with new partner on right', 0);
INSERT INTO 'dancecrib' VALUES (4624, '2013-08-21 08:30:51.63835+00', '2023-02-04 01:19:08.319886+00', 1127, 3, NULL, 'ace', '1-8::
    All set adv to partners & pass RSh to turn next person 2H & face
    partner, all set adv & turn next person 2H to end Men in middle
    facing partner
9-16::
    All dance "The Square Knot":
::
    _9-10_    All turn partner 1/2 RH into allemande hold, Ladies in
    centre & all facing clockwise
::
    _11-12_  All advance 1 place
::
    _13-16_  Ladies dance in front of partner & 1/4 turn LH tp new
    positions
17-24::
    Side couples (orig 1s+3s) advance passing opp person RSh & turning
    to face them, dance 1/2 RH across; 1L followed by partner dances out
    through couple in 3rd place _while_ 3L followed by 3M dance out
    through 1st place back to ''new'' pstns
25-32::
    All dance Grand Chain', 0);
INSERT INTO 'dancecrib' VALUES (4625, '2013-08-21 08:30:51.646551+00', '2023-02-04 01:19:08.348047+00', 7566, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance 1/2 R&L, set, 2s & 4s cross back RH _while_ 1s &
    3s 3/4 turn RH to face 2nd corners
9-16::
    1s & 3s dance full diagonal reels of 4 with 2nd corners
17-24::
    1s+3s dance Figs of 8 - Men round couple above them & Ladies round
    couple below _while_ 2s+4s+5s set, cross RH set & cross back LH
25-32::
    1s+3s dance RH across - Ladies with couple above them & Men with
    couples below, 1s & 3s turn LH & cast 1 place', 0);
INSERT INTO 'dancecrib' VALUES (4626, '2013-08-21 08:30:51.656543+00', '2023-02-04 01:19:08.378523+00', 12085, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 (1s in & down to start)
9-16::
    2s dance up behind 1s, meet & cross down through 2nd place, dance
    down behind 3s, meet & cross up to 2nd place own side
17-24::
    1s & 3s petronella turn into middle & set to partner, turn RH 1.1/4
    times to original place
25-32::
    1s+2s+3s circle 6H round & back
33-40::
    1s cross RH & cast 1 place, lead up crossing to own side & cast to
    bottom', 0);
INSERT INTO 'dancecrib' VALUES (4627, '2013-08-21 08:30:51.666453+00', '2023-02-04 01:19:08.404529+00', 9200, 3, NULL, 'ace', '1-8::
    2s set & cross RH, 2s cast round 2nd corner to end in lines of 3
    across, 2M between 1s facing down, 1L between 3s facing up & all set
9-16::
    2s dance 1/2 diagonal reels of 4 with 1st corners, pass LSh & dance
    1/2 reel of 4 with 2nd corners.2s end 2nd place opposite sides. (3)
    (2) (1)
17-24::
    All chase clockwise 1/2 way to own sides & dance RH across on own
    sides (2s slightly outside & 1s+3s on inside), all end in original
    places
25-32::
    1s+3s Set & Rotate:  set, rotate singly & dance on 1 place
    clockwise, change places RH on sides & dance on 1 place to own sides
::
    _while_ 2s set, turn RH, lead down to 3rd place & set.  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4628, '2013-08-21 08:30:51.674673+00', '2023-02-04 01:19:08.435254+00', 1131, 3, NULL, 'ace', '1-8::
    1s cross down for reels of 3 on opposite sides & 1s end facing down
    (nearer hands joined), 2s facing out & 3s facing up (nearer hands
    joined)
9-16::
    1s & 3s set & petronella turn twice in tandem _while_ 2s dance out,
    cast clockwise to top/bottom, cross down/up & cast clockwise back to
    place
17-24::
    2s dance RH across (2L with 3s (at top), 2M with 1s), 2M followed by
    1s also 2L followed by 3s dance clockwise to own places (1s & 2s opp
    sides)
25-32::
    1s & 2s dance »Kiwi Knot« - 1/2 turn partners RH to end facing up in
    Allemande hold, dance up & down Men''s side (2s following 1s), drop
    RH, dance into middle & turn LH to own side', 0);
INSERT INTO 'dancecrib' VALUES (4629, '2013-08-21 08:30:51.866623+00', '2023-02-04 01:19:08.654735+00', 7362, 3, NULL, 'ace', '1-8::
    1s set, 3/4 turn LH (as 2s step up), 1s set & 3/4 turn to face other
    partner in line across
9-24::
    1s+2s dance the Celtic Reel :
::
    _9-12_   1s+2s pass RSh as  for reel of 4, 1s dance clockwise 1/4
    way _while_ 2s dance 3/4 LSh round each other to face other prtnr
    (up/down)
::
    _13-16_  1s+2s pass RSh as  for reel of 4, 2s dance clockwise 1/4
    way _while_ 1s dance 3/4 LSh round each other to face other partner
    (across)
::
    _17-24_  1s+2s repeat bars 9-16
25-32::
    1s+2s set & 3/4 turn (1L+2M LH & 1M+2L RH), 1s dance 1/2 Fig of 8
    round 2s to own sides', 0);
INSERT INTO 'dancecrib' VALUES (4630, '2013-08-21 08:30:51.876601+00', '2023-02-04 01:19:08.688323+00', 10136, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & turn LH to 2nd place opposite sides
9-16::
    1s dance 1/2 reels of 3 on opposite sides (LSh to 2nd corner) & 1/2
    reels of 3 across (RSh to 3rd corner)
17-24::
    1s dance 1/2 reels of 3 on own sides giving LSh to 4th crnr (pstn),
    1/2 reels of 3 across giving RSh to 1st crnr (pstn) & end facing 1st
    crnr
25-32::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    Pass+Turn with 2nd corners & pass RSh to 2nd place
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4631, '2013-08-21 08:30:51.884731+00', '2023-02-04 01:19:08.710904+00', 12872, 3, NULL, 'ace', '1-8::
    1s cast 1 place & dance 1/2 Fig of 8 round 2s & turn LH
9-16::
    1s dance 1/2 reel of 3 on sides (LSh to 2nd corner) & 1/2 reel of 3
    across giving RSh to 3rd corner (pstn)
17-24::
    1s dance 1/2 reel of 3 on sides giving LSh to 4th corner (pstn), 1/2
    reel of 3 across giving RSh to 1st corner (pstn) & turn RH to face
    1st corner (pstn)
25-32::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners', 0);
INSERT INTO 'dancecrib' VALUES (4632, '2013-08-21 08:30:51.921899+00', '2023-02-04 01:19:08.795112+00', 10184, 3, NULL, 'ace', '1-8::
    All with LH joined dance in & pass Lady over to left, dance out RH
    with new partner again crossing Lady to left, repeat to meet partner
    opposite original place
9-16::
    All circle 8H round & back
17-24::
    Men dance 1/2 LH across, dance round opposite Lady RSh, dance 1/2 LH
    across & dance round partner RSh back to place
25-32::
    Ladies dance 1/2 RH across, dance round opposite Man LSh, dance 1/2
    RH across & dance round partner LSH back to place
33-40::
    All set to corner & change places RH, set to next person & Men dance
    clockwise round outside to original place _while_ Ladies chase
    anticlockwise to original place
41-48::
    All dance Interlocking reels of 4 passing partner RSh
49-64::
    All dance full Schiehallion Reel', 0);
INSERT INTO 'dancecrib' VALUES (9720, '2017-04-06 08:39:34.366523+00', '2023-02-04 01:19:09.012065+00', 10437, 3, NULL, 'ace', '1-8::
    All Men dance Fig of 8 round partner & corner, finishing BtoB in
    centre facing partner
9-24::
    All dance Double Celtic Reels:
::
    _9-12_    All pass partner RSh, Ladies dance 3/4 LH across as Men
    dance 1 place clockwise round to face partner.
::
    _13-16_  All pass partner RSh, Men dance 3/4 LH across as Ladies
    dance on 1 place clockwise round.
::
    _17-24_  Repeat 2 more times - back to positions as at end of bar 8
25-28::
    All Men dance out, taking partner by RH, then bars 27-28 promenade
    one place clockwise
29-32::
    All Ladies dance RH Across
33-40::
    All Grand Chain 1/2 way
41-48::
    All dance interlocking reels of 4, beginning RSh to partner
49-56::
    All Grand Chain 1/2 way
57-64::
    All Circle 8H round & back

{{explanation}}
Repeat in Reel time from new position', 0);
INSERT INTO 'dancecrib' VALUES (8175, '2014-02-10 10:26:09.250985+00', '2023-02-04 01:19:09.04051+00', 11949, 3, NULL, 'ace', '1-::
    _8_     1s turn RH and cast 1 place, 1s turn LH to face 1st corners
9-16::
    1s+1st corners dance 1/2 Celtic Reel on the diagonal:
::
    '' 9-12     1s+1st corners pass RSh (as for reel of 4) then 1s dance
    clockwise 1/4 way as 1st corners dance 3/4 LSh round each other to
    face 1s on the 2nd corner diagonal, whilst 2nd corners set and dance
    clockwise to 1st corner position.
::
    '' 13-16   1st corners and 1s pass RSh (as for reel of 4) then 1st
    corners dance clockwise 1/4 way _while_ 1s dance LSh right round
    each other to face 2nd corners who are in 4th corner position having
    again set and danced 1/4 way round clockwise.
17-24::
    Repeat with 2nd corners:
::
    1s+2nd corners dance 1/2 Celtic reel on the diagonal, (but 1s do not
    dance round each other at the end, instead turning RH to end in 2nd
    place), _while_ 1st corners set and dance 1 place clockwise, set and
    dance 1 place clockwise
25-32::
    All circle 6h round and back', 0);
INSERT INTO 'dancecrib' VALUES (4633, '2013-08-21 08:30:51.930216+00', '2023-02-04 01:19:09.063129+00', 10157, 3, NULL, 'ace', '1-8::
    Top 3 Ladies set diagonally to bottom 3 men, Ladies dance a round
    the same Men passing RSh & back to places
9-16::
    Top 3 Men repeat bottom 3 Ladies
17-24::
    1s set, cross down RH, cast down behind 3s & lead LH down crossing
    to 4th place on own side
25-32::
    2s+3s+4s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10826, '2018-06-11 00:36:03.121973+00', '2023-02-04 01:19:09.101591+00', 18286, 3, NULL, 'ace', '1-8::
    1L+3L, followed by partners, cast off to 3rd/5th place (2s & 4s step
    up 3-4), dance across set, cast up 1 place on opp sides & across to
    own side facing out. End 21435
9-16::
    1s+4s also 3s+5s RH across finishing on sidelines 1L+3L facing out;
    2s+1s also 4s+3s LH across, 1s+3s ending facing 1st corners
17-20::
    1s+3s dance RSh round 1st corners, pass RSh to face 2nd corner
    _while_ corners dance in diagonally, join RH, Ladies turn under
    Men''s arm & dance back to place as Men retire
21-24::
    1s+3s repeat 17-20 with 2nd corners ending in 2nd/4th place own side
    (Ladies pull back RSh to face in)
25-28::
    1s+3s set, cast (4s+5s step up), 3s end facing up NHJ
29-32::
    2s+4s also 1s+5s circle 4H round to Left _while_ 3s set twice
    retiring to place (bar 32)', 0);
INSERT INTO 'dancecrib' VALUES (9178, '2016-06-16 22:41:36.365647+00', '2023-02-04 01:19:09.126166+00', 16279, 3, NULL, 'ace', '1-8::
    1s+2s dance all round Poussette
9-16::
    1s+2s+3s Set+Link for 3 twice  (3)(2)(1)
17-20::
    3s+2s+1s set. 3s cross RH _while_ 2s+1s dance RH across 1/2 way.  3
    1 2
21-24::
    3s+1s+2s advance (no hands) towards partners (RSh to RSh) & retire
25-32::
    3s+1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (4634, '2013-08-21 08:30:51.938988+00', '2023-02-04 01:19:09.157556+00', 13757, 3, NULL, 'ace', '1-8::
    1M+2M Set+Link _while_ 1L+2L reverse Set+Link, 1s dance down between
    3s & cast to face 1st corners
9-16::
    1s set to 1st corner, pull back RSh & dance RSh round partner to
    face 2nd corner; repeat with 2nd corners to end facing out in 2nd
    place own sides
17-20::
    1s cast round 3rd corners (1M up, 1L down), meet in centre & 1/2
    turn RH _while_ corners Adv+Ret diagonally
21-24::
    1s pull back RSh & cast round 4th corners to 2nd place own sides
    _while_ corners Adv+Ret diagonally
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4635, '2013-08-21 08:30:51.948884+00', '2023-02-04 01:19:09.1939+00', 1141, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, turn partner RH 1.1/4 times to end Lady
    facing up & Man down
9-16::
    1s dance Crown Triangles & turn singly to face 1st corners
17-24::
    1s dance diagonal reel of 4 with 1st corners & pass partner LSh to
    face 2nd corners
25-32::
    1s dance diagonal reel of 4 with 2nd corners to in 2nd place own
    sides
33-40::
    1s dance Figs of 8 round 3s', 0);
INSERT INTO 'dancecrib' VALUES (4636, '2013-08-21 08:30:51.957165+00', '2023-02-04 01:19:09.225191+00', 1142, 3, NULL, 'ace', '1-8::
    All set, 1s & 3s cast down 1 place (2s & 4s step up); 1s & 3s dance
    1/2 Figs of 8 round couples above them to end in centre BtoB, 1s
    between 2s, 3s between 4s facing opp side
9-16::
    All set HS & dance 1/2 reel of 4 across to end all on opposite sides
    2 1 4 3
17-24::
    All dance Petronella to own sides ready for Poussette
25-32::
    2s+1s & 4s+3s dance 1/2 Diamond Poussette to original places; 1s
    progress to 4th place: 1M+2M change places RH, 1M+3M LH, 1M+4M RH
    _while_ 1L+2L change places LH, 1L+3L RH, 1L+4L LH.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4637, '2013-08-21 08:30:51.966867+00', '2023-02-04 01:19:09.263345+00', 10475, 3, NULL, 'ace', '1-8::
    1s & 3s set, turn RH 1.1/4 times & petronella turn to own places
9-16::
    1s+2s+3s dance reels of 3 on sides, 2s giving RSh to person on Left
    (2M up, 2L down)
17-24::
    2s turn RH 1.1/4 times, set & petronella turn to own places
25-32::
    1s+2s dance the Knot', 1);
INSERT INTO 'dancecrib' VALUES (11692, '2019-03-18 21:01:54.586963+00', '2023-02-04 01:19:09.327873+00', 19141, 3, NULL, 'ace', '1-4::
    1s dance in & cast to 2nd place _while_ 2s set & dance up & curve
    outwards to face down
5-8::
    1s dance in & up, turn 2s (1L RH, 1M LH). 1s finish facing 1st
    corners
9-24::
    1s dance Corner Chain (modified ending) with 1st & 2nd corners :
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end turning LH to 2nd place
    opposite sides facing 2nd corners
25-32::
    1s dance LSh reel of 3 on the opposite side. On bar 30, 1s cross
    diagonally from the end of the set back to 2nd place own sides
    _while_ 2s+3s finish the reel', 0);
INSERT INTO 'dancecrib' VALUES (9075, '2016-01-18 14:40:25.186062+00', '2023-02-04 01:19:09.359868+00', 9632, 3, NULL, 'ace', '1-8::
    1M+3L pass LSh to face others partner & 1/2 reel of 4 on diagonal,
    3M+1L chase round set clockwise into ptnrs pl _while_ 1M+3L loop to
    ptnr''s pl
9-16::
    1s+2s RH across, 1M casts below 3L place & up to 2L place _while_ 1L
    dances parallel path down middle, round 3M pl & to 2M pl (2s step
    up)
17-24::
    2s+1s+3s Grand Chain
25-32::
    2s+1s LH across, 1s+3s lead up to top, cross & cast on own sides.  2
    3 1', 0);
INSERT INTO 'dancecrib' VALUES (14514, '2022-01-10 02:18:44.715102+00', '2023-02-04 01:19:09.38893+00', 17955, 3, NULL, 'ace', '1-8::
    All dance Double Men''s Chain (Men 1/2 LH across in centre) Bars 7-8
    turn partners to end Men in centre
9-16::
    »Reverse Targe«:
::
    Men dance 3/4 LH across _while_ Ladies chase clockwise 1 place;
    repeat to end 3 4 1 2
17-24::
    All set & Petronella in Tandem to right; set to partner & turn RH.
    Ladies face out
25-32::
    All dance 1/2 Schiehallion reels to end 2 3 4 1
33-64::
    Repeat  in Strathspey time

{{title}}
Reel

65-128::
    Repeat 1-64 in Reel time to end in original places', 0);
INSERT INTO 'dancecrib' VALUES (4642, '2013-08-21 08:30:52.008598+00', '2023-02-04 01:19:09.475058+00', 9835, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels on opposite sides 1s ending
    in partner''s place
9-16::
    1M+2L turn 1.1/2 times LH _while_ 1L+2M turn 1.1/2 times RH, 1M+3L
    turn RH 1.1/2 times _while_ 1L+3M turn 1.1/2 times LH.  2 3(1)
17-24::
    1s cross up to dance reflection reels on own sides 1s ending in 3rd
    place in centre facing up
25-32::
    1s set to 3s, 1s set advancing to 2s as 3s step down, 1s dance to
    the top & cast into 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (12630, '2020-03-02 01:51:48.126417+00', '2023-02-04 01:19:06.170962+00', 17805, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels of 3 on opp sides, all couples cross down from
    1st place.  (1) (2) (3)
9-16::
    1s dance down , cast up round 3s into 2nd place opp sides; 2s+1s+3s
    Set+Link for 3 into lines across
17-28::
    R&L for 3 couples, starting up down (diagonal crossing is on 1st
    corner diagonal)
29-32::
    Set+Link for 3 to end on own sides 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4643, '2013-08-21 08:30:52.018525+00', '2023-02-04 01:19:09.504872+00', 1147, 3, NULL, 'ace', '1-8::
    1s & 4s set & cross RH _while_ 2s+3s dance 1/2 R&L, 1s+3s also 2s+4s
    circle 4H round to left
9-16::
    1s+3s also 2s+4s dance 1/2 R&L, 1s+4s circle 4H round to left
    _while_ 3s & 2s set & cross RH
17-24::
    All dance RSh reels of 4 on sides
25-32::
    All dance Grand Chain 1/2 way, turn partners 2H to own side (middle
    couples turn 1.1/2 times).  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4644, '2013-08-21 08:30:52.126238+00', '2023-02-04 01:19:09.51503+00', 1148, 3, NULL, 'ace', '1-8::
    1s cross down & cast behind 3s, 1s dance up middle & cast to 2nd
    places opposite sides (2s step up 7-8)
9-12::
    All set.  1s set advancing to face down side by side (1M pulls back
    LSh, 1L RSh)  _while_ 2s & 3s cross RH
13-16::
    1L dances RH across with 2L+3L (Men''s side) as 1M dances LH across
    with 2M+3M. 1s end in centre
17-24::
    1s slip step down for 4 steps & up to 2nd place opp sides facing
    out; 1/2 reflection reels of 3 on sides,1s out/up, 2s in/down, 3s
    in/up. (3) (1) (2)
25-32::
    All set & 1/2 turn RH to face up, all dance up & cast into places.
    2 1 3

{{explanation}}
At end of 2nd turn (bars 29-32):  
3s cast to bottom & dance up to 2nd place  
1s dance up to top & cast to bottom  
2s dance up to top & cast into 1st place', 0);
INSERT INTO 'dancecrib' VALUES (4645, '2013-08-21 08:30:52.140319+00', '2023-02-04 01:19:09.550361+00', 7645, 3, NULL, 'ace', '1-8::
    1s+2s turn RH 1.1/2 times on sides, 1s+3s turn LH 1.1/2 times on
    sides
9-16::
    2s+3s+1s set, cross LH & circle 6H round to left 1/2 way to own
    sides.  1 3 2
17-24::
    1s advance & cast 1 place, cross passing LSh & dance round 1st
    corner pstns into middle BtoB (Lady facing up & Man down)
25-32::
    1L+3s (at top) also 1M+2s dance RH across, pass RSh & dance LH
    across with other couple to end in 2nd place own sides.  End 312', 0);
INSERT INTO 'dancecrib' VALUES (4646, '2013-08-21 08:30:52.14867+00', '2023-02-04 01:19:09.579644+00', 11419, 3, NULL, 'ace', '1-4::
    1s set advancing to side by side giving RH, 1s turn about & give LH
    _while_ 3s set advancing & give LH
5-8::
    1M+3M dance round anticlockwise 1/2 way _while_ 1L+2s+3L dance RH
    across
9-12::
    3M+1L also 1M+3L change places LH _while_ 2s cross RH, all set
    facing about
13-16::
    1L+3L dance round clockwise 1/2 way _while_ 3M+2s+1M dance LH across
17-24::
    3s+1s dance 1/2 reel of 4 up/down & 3/4 turn partners RH to opposite
    sides, 1s+2s+3s set
25-32::
    1s+2s dance 1/2 R&L & 1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (9721, '2017-04-06 08:39:34.56329+00', '2023-02-04 01:19:09.612734+00', 17501, 3, NULL, 'ace', '1-8::
    1s cross RH & cast off 2 places, cross RH & cast back to place
9-16::
    1s followed by 2s lead down the middle, 2s separate and 1s followed
    by 2s lead up
17-24::
    1s cast off 1 place _while_ 2s dance to top & 1s dance reels of 3
    across (6 bars), Lady up & Man down (pass 1st crns LSh), 1s end
    facing 2nd crns
25-32::
    1s dance Pass+Turn with 2nd cnrs, pull back RSh (twirl) to face 1st
    corners & dance Pass+Turn with 1st crns.  1s finish 2nd place own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (4647, '2013-08-21 08:30:52.257204+00', '2023-02-04 01:19:09.642395+00', 9573, 3, NULL, 'ace', '1-8::
    1s+2s 3/4 turn 2H & dance first 6 bars of HS Poussette :
::
    1s set HS step with both hands joined dance out to Men''s side
    _while_ 2s set & dance out to Ladies'' side, both couples end with a
    1/4 turn to right
::
    1s dance HS down Men''s side _while_ 2s dance up Ladies'' side both
    couples end with a 1/4 turn to right
::
    2s+1s dance HS into middle to reform line of 4 & turn partner 2H to
    face partner up/down
9-16::
    2s+1s petronella turn to own sides, set & turn RH into Allemande
    hold
17-24::
    2s+1s dance Allemande
25-32::
    1s+2s Set+Link & circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (4648, '2013-08-21 08:30:52.267407+00', '2023-02-04 01:19:09.67736+00', 1152, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels of 3 on sides crossing over when dancing up
    from 3rd place (3s cross up to start)
9-16::
    Repeat reels crossing over when dancing up from 3rd place to end in
    original places with 2s+3s in middle ready for…
17-24::
    2s+3s dance the Rondel
25-32::
    1s+3s dance 1/2 double Fig of 8 (1s cross down to start) & dance 1/2
    R&L', 0);
INSERT INTO 'dancecrib' VALUES (4649, '2013-08-21 08:30:52.275572+00', '2023-02-04 01:19:09.699342+00', 1153, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig of 8 (1s crossing down to start)
9-16::
    1s lead down, cross & cast up round 3s, lead up between 2s, cross &
    cast 1 place & face 1st corners
17-24::
    1s turn 1st corner RH, pass RSh & turn 2nd corners RH ending BtoB in
    middle (Man facing up)
25-32::
    1s dance Double Triangles & end in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (15317, '2022-12-19 01:19:02.8875+00', '2023-02-04 01:19:09.805754+00', 21208, 3, NULL, 'ace', '1-4::
    1s cross down to 2nd place opp side _while_ 2s dance up to top, 1s
    cross down to 3rd place own side _while_ 3s dance up to 2nd place
5-8::
    2s cross down to 2nd place opp side & cross RH to face out _while_
::
    3s dance up to 2nd place & turn RH (2 bars), retain hands & face
    down _while_
::
    1s+4s turn RH (4 bars).  3 2 1 4
9-16::
    3s+2+1s dance Inveran Reels:
::
    _9-12_   3s cross down to 2nd place opposite sides & dance 1/2 reel
    of 3 on opposite sides
::
    _13-16_ 3s cross up to 2nd place own sides (from bottom) & dance 1/2
    reel of 3 on own sides. 3 2 1 4
17-24::
    »Split Reels of 3« on sides:
::
    3M+2M pass LSh as 3L crosses to 2nd place Man''s side to join reel of
    3.  Bars 23-24: 3M+2M pass LSh _while_ 3L crosses back to 2nd place
    own side _while_
::
    1L+4L pass LSh as 4M crosses to 3rd place Ladies'' side to join reel
    of 3.  Bars 23-24: 1L+4L pass LSh _while_ 4M crosses back to 3rd
    place own side.
25-32::
    3L+2L pass RSh as 3M crosses to 2nd place Ladies'' sidem to join reel
    of 3. Bars 31-32: 3L+2L pass RSh _while_ 3M crosses back to 2nd
    place own side _while_
::
    1M+4M pass RSh as 4L cross to 3rd place Man''s side to join reel of
    3. Bars 31-32: 1M+4M pass RSh _while_ 4L crosses to 3rd place own
    side. End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8306, '2014-07-29 12:58:50.413219+00', '2023-02-04 01:19:09.816315+00', 15033, 3, NULL, 'ace', '1-8::
    1s cast 1 place, dance up to top, cast off to face 1st corners, 2s
    step up on bars 7-8
9-12::
    1s dance  RSh round 1st  cnrs  _while_ 2nd  cnrs turn each other RH
    & return to places, 1s pass LSh  to face 2nd corners
13-16::
    1s dance  RSh round 2nd cnrs _while_ 1st  cnrs turn each other LH &
    return to places, 1s finish in 2nd place opp sides facing 1st
    corners
17-24::
    1s dance reels of 3 on opp sides giving LSh to 1st corner & 1s cross
    RH
25-32::
    1s dance 1/2 Fig 8, 1M round 2s, 1L round 3s; 1s cross RH, 2s+1s+3s
    set', 0);
INSERT INTO 'dancecrib' VALUES (4651, '2013-08-21 08:30:52.295462+00', '2023-02-04 01:19:09.903885+00', 1158, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast 2 places, lead up the middle and cross to
    original places
9-16::
    1s lead down for 3 steps, up for 3 & cast to face 1st corners
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH, partner LH to 2nd
    place own sides
25-32::
    2s+1s+3s Adv+Ret 1 step twice & turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (4652, '2013-08-21 08:30:52.305693+00', '2023-02-04 01:19:10.055905+00', 11223, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s also 5s+6s dance Set & Rotate to end 2 1 4 3 6 5 :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-12::
    Centre sets of 2 couples (1s+4s & 3s+6s) dance 1/2 LH across, end
    sets (2s+4s & 3s+5s) dance 1/2 RH flowing into ...
13-16::
    _1/2_ RSh reels of 3 on the sides 4s+2s+1s (4s pass 2s RSh to start)
    & 6s+5s+3s (3s pass 5s RSh to start) ending (1)(2)4 3(5)(6)
17-20::
    4L followed by partner casts up Ladies'' side & crosses to 1st place
    opposite sides _while_ 3M followed by partners casts down Men''s side
    & crosses to 6th place opposite sides (all now on opp sides)
21-24::
    Centre 4 couples chase clockwise 1/2 way _while_ end dancers turn RH
    1.1/2 times.  4 6 5 2 1 3
25-32::
    All circle 12H round & back.  4 6 5 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4653, '2013-08-21 08:30:52.315744+00', '2023-02-04 01:19:10.07965+00', 8202, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L+4L cross & dance down behind Men, cross & dance
    up to places
9-16::
    Men repeat above figure
17-24::
    1s slip step down middle back to top (in middle)
25-32::
    1s cast to below 4s, all step up & clap 3 times', 0);
INSERT INTO 'dancecrib' VALUES (12720, '2020-04-11 10:50:42.513696+00', '2023-02-04 01:19:10.110903+00', 9353, 3, NULL, 'ace', '1-8::
    1s turn RH and cast to 2nd place (2s step up); 1s+3s+4s dance 1/2
    mirror reels of 3 on sides (1M+3M pass RSh, 1L+3L pass LSh to
    start). 2 4 3 1
9-16::
    2s+4s also 3s+1s set to each other up/down sides & change places RH;
    set again and turn RH into lines across, 2M+4L BtoB facing 4M+2L,
    3M+1L BtoB facing 1M+3L
17-24::
    2s+4s also 3s+1 dance 3/4 reel of 4 to finish facing partners & 1/2
    turn 2H to finish in two diagonal lines (4s above 2s, 1s above 3s)
25-28::
    4s+2s also 1s+3s dance 1/2 Poussette
29-32::
    4s+3s (middle couples) dance 1/2 Poussette. End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4654, '2013-08-21 08:30:52.325809+00', '2023-02-04 01:19:10.150475+00', 1160, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    1L+2M & 3M+4L set Advancing to face partners, dance 1/2 diagonal
    parallel reels of 4. 1M+2L & 3L+4M turn LH to face partners
9-16::
    1s+2s & 3s+4s dance 3/4 diagonal reel of 4 & pivot to right on last
    2 bars into a long line up/down set (order 1L,1M,2L,2M,3M,3L,4M,4L)
    Continue pivoting to end with 2M & 4L on Men''s side opp 1L & 3M on
    Ladies'' side to form 2 circles with partners
17-24::
    1s+2s also 3s+4s circle 4H round & back to end with partners in
    centre facing each other (1s & 3s Facing down, 2s & 4s up)
25-32::
    All dance Interlocking Rondels - 2s & 3s dance the normal Rondel
    _while_ 1s/4s dance through arch made by 2s/3s & 1s dance between 4s
    to dance last 5 bars of the Rondel to end 2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (4655, '2013-08-21 08:30:52.335887+00', '2023-02-04 01:19:10.191566+00', 1161, 3, NULL, 'ace', '1-4::
    1s+2s+3s+4s set & turn RH _while_ 5s set & set advancing & pass LSh
5-12::
    1s & 3s (prom hold) dance RSh reel of 4 up/down with 5M+5L
13-20::
    5M+2s also 5L+4s dance RH across, pass LSh to dance LH across with
    other couple & 5s end facing each other
21-24::
    5s set, turn LH into prom hold facing 1s (also in prom hold)
25-32::
    5s+1s change places passing LSh, 1s+2s change places, 2s+3s change
    places & 3s+4s change places (4s now in centre)', 0);
INSERT INTO 'dancecrib' VALUES (14367, '2021-10-11 22:39:14.198553+00', '2023-02-04 01:19:10.386627+00', 18048, 3, NULL, 'ace', '1-4::
    All set, 1s+3s cast _while_ 2s+4s dance in & up to 1st & 3rd places
    (no long loop in) 2 1 4 3
5-8::
    1s & 3s dance 1/2 Fig of 8 up round 2s & 4s, 1s+3s finish facing up,
    2s+4s face down 2 (1) 4 (3)
9-16::
    All dance reflection reels of 4 on sides (1s+3s dance in to begin) 2
    1 4 3
17-20::
    1s+3s cross up RH to own sides _while_ 2s+4s dance back to original
    places. All set. 1 2 3 4
21-24::
    1s dance in & cast to 4th place _while_ 2s+3s+4s set advancing, meet
    partner & dance up one place
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15132, '2022-10-05 00:19:06.291947+00', '2023-02-04 01:19:10.41967+00', 20791, 3, NULL, 'ace', '1-8::
    1s+2s 1/2 turn partner RH to face up NHJ & set; 1s cast to 2nd place
    _while_ 2s dance up to top, 1s +2s cross RH to own side.  2 1 3
9-16::
    All dance reels of 3 on opp sides: 2s cross down to start (1s out
    up, 3s in/ up), 1s & 3s cross down on reaching top place. (2) (1)
    (3)
17-24::
    All dance Allemande Turn right:
::
    All advance to take partner''s RH,  Lady dances under Man''s arm. Lady
    curves out to place as Man retires; all set & cross RH.  2 1 3
25-32::
    1s+3s dance Tourbillon:
::
    1s & 3s 1/2 turn ptnrs 2H, 1M & 3L lead ptnrs by nearer hand 1 place
    cl''wise (end 1s on Ladies'' side & 3s Men''s side), 1s set to 3s
::
    1s & 3s 1/2 turn ptnrs 2H & lead ptnrs clockwise to end 3s in 2nd
    place & 1s in 3rd place then both cross RH to own sides  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4658, '2013-08-21 08:30:52.36237+00', '2023-02-04 01:19:10.571824+00', 13764, 3, NULL, 'ace', '1-8::
    1M followed by 1L casts below 2s & dances up between 2s,then casts
    on opposite side & crosses to 2nd place own side
9-16::
    2L followed by 2M casts below 1s & dances up between 1s then casts
    on opposite side & crosses to original place
17-24::
    1s+2s dance L&R (left hands on sides to start) ending in middle
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (10220, '2017-11-04 01:45:09.782394+00', '2023-02-04 01:19:10.588333+00', 16465, 3, NULL, 'ace', '1-4::
    1s set, cross down (no hands) to 2nd place facing out (2s step up
    3-4)
5-8::
    1s cast down behind 3s,meet & dance up centre with 1L leading, 1M
    following, to face 2M (her 1st corner)
9-16::
    1s, in tandem, dance LSh reel of 3 on 1st corner diagonal (out of
    top of set to start), finishing by 1s pulling back RSh to face down,
    1M leading, facing 3M
17-24::
    1s, in tandem, dance RSh reel of 3 on 2nd corner diagonal (out
    bottom of set to start), finishing with 1s facing own 1st corners
25-32::
    1s dance Pass+Turn with 1st corners, (pass RSh), Pass+Turn with 2nd
    corners, finishing passing RSh to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (12910, '2020-07-01 00:18:57.752253+00', '2023-02-04 01:19:10.615502+00', 17588, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s & 3s+4s face in diagonally, set & circle 4H 1/2 round; 1s & 4s
    drop hands, 1M dances down Ladies'' side, 4L up Men''s side to form
    large circle.  All dance 8H 1/2 round.  3 4 1 2
9-10::
    Dancers in top 3 Ladies'' places cross diagonally RH with dancers in
    bottom 3 Men''s places
11-12::
    Dancers in top 3 Men''s places cross diagonally LH with dancers in
    bottom 3 Ladies'' places.  End 4 Men at top, 4 Ladies at bottom
13-16::
    4M followed by 3M also 1L followed by 2L dance anticlockwise round
    to own sides.  All now in original places.

{{title}}
Jig

1-8::
    1s set, 1/2 turn RH; 1M followed by 1L cast 3 places to 4th place
    own sides _while_ 2s+3s+4s set, turn partner RH moving up 1 place &
    All couples set
9-16::
    2s+3s+4s+1s dance reels of 4 on sides.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4659, '2013-08-21 08:30:52.421649+00', '2023-02-04 01:19:10.647368+00', 1165, 3, NULL, 'ace', '1-8::
    1s set, dance down 2 steps (below 3s), set & cast up to 2nd places
9-16::
    1s dance 1/2 Figs of 8 round 2s & 1/2 Figs of 8 round 3s end facing
    1st corners
17-24::
    1s dance 1/2 diagonal reels of 4 with 1st corners & 1/2 reels with
    2nd corners
25-32::
    1s 1/2 turn 2H as 2s+3s chase clockwise to places, 2s+1s+3s turn
    partners RH', 0);
INSERT INTO 'dancecrib' VALUES (10061, '2017-09-03 23:44:25.121323+00', '2023-02-04 01:19:10.679499+00', 17779, 3, NULL, 'ace', '{{explanation}}
Round the Room, 2 facing 2

1-8::
    All circle 4H round & back
9-12::
    Ladies dance LSh round partner back to place
13-16::
    Ladies pull back RSh to face out & followed by opp Man, chase 1/2
    round clockwise
17-20::
    Men dance RSh round partner back to place
21-24::
    Men pull back LSh to face out & followed by opp Lady, chase 1/2
    round anticlockwise
25-32::
    All take prom hold with partner, pass opp couple LSh  & dance RH
    across with next couple', 0);
INSERT INTO 'dancecrib' VALUES (8527, '2015-02-13 12:47:20.399704+00', '2023-02-04 01:18:19.886212+00', 15645, 3, NULL, 'ace', '1-4::
    1M+2s+3L dance 1/2 diagonal reel of 4 (2s pass LSh to start). 2s
    pass RSh at end to face 1L / 3M
5-8::
    1L+2s+3M dance 1/2 diagonal reel of 4.  2s finish in middle, facing
    own sides, 2M above 2L
9-12::
    2M+3s at top & 2L+1s at bottom dance RH across
13-16::
    2s turn 1.3/4 times to finish back-to-back in middle facing opp.
    sides _while_ 3s+1s dance clockwise 1/2 way round to places
17-24::
    1s+2s+3s dance Double Triangles.  2s finish 2nd place own sides
25-32::
    1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (11180, '2018-09-30 22:19:29.457172+00', '2023-02-04 01:19:10.735103+00', 18613, 3, NULL, 'ace', '1-8::
    1s & 3s dance similar loops:
::
    1L & 3L followed by partner dance anticlockwise loops round 2s/4s
    (1s round 4s, 3s round 2s) with Men dancing in between the standing
    couples to take lead, continue dancing anticlockwise round standing
    couples with Ladies dancing between the standing couples & dancing
    couples face in
9-12::
    1L+4L & 3L+2L 1/2 turn & twirl out to change places _while_ partners
    change places by chasing clockwise 1/2 way (in 4s)
13-16::
    1M+4M & 3M+2M 1/2 turn & twirl out to change places _while_ prtnrs
    change places by chasing cl''wise 1/2 way (1s & 3s now back in the
    middle)
17-24::
    1s+3s dance LH across 1/2 way, 3M & 1M followed by partners dance
    out to partners original place
25-48::
    2s & 4s repeat bars 1-24
49-52::
    1M+3M dance into middle (pass LSh) & turn right to face 4s/2s
53-56::
    1M & 3M 1/2 sets to Men then Ladies as 4s/2s set, 1M & 3M dance out
    between 4s/2s & chase back to original places
57-64::
    2M+4M repeat bars 49-56
65-72::
    Ladies dance a double Ladies'' Chain
73-80::
    All Promenade anticlockwise round the set', 0);
INSERT INTO 'dancecrib' VALUES (14416, '2021-11-06 01:10:23.494889+00', '2023-02-04 01:19:10.76591+00', 18708, 3, NULL, 'ace', '1-8::
    1s & 5s lead down (2s & 4s step up/down bars 3-4); Bar 5, Ladies
    dance under partner''s raised arm as Men dance below, to change
    sides. All lead back up to end 1s in 2nd place facing out, 5s in 4th
    place facing out ready for …
9-16::
    All dance Double Triangles, ending with 1s facing in and 5s facing
    out on opposite sides.
17-28::
    1s & 5s dance the »Celtic Braid« figure:
::
    _17-18_  1s cross down between 3s _while_ 5s cast up behind 3s
::
    _19-20_  1s cast down behind 4s _while_ 5s cross up between 2s
::
    _21-22_  1s cross up between 4s _while_ 5s cast down behind 2s
::
    _23-24_  1s cast up behind 3s _while_ 5s cross down between 3s
::
    _25-26_  1s cross up between 2s _while_ 5s cast down behind 4s
::
    _27-28_  1s cast down behind 2s _while_ 5s cross up between 4s
29-32::
    1s+3s change places (Ladies LH, Men RH), 1s+5s change places (Ladies
    RH, Men LH). End 2 3 5 1 4', 0);
INSERT INTO 'dancecrib' VALUES (4663, '2013-08-21 08:30:52.4857+00', '2023-02-04 01:19:10.842104+00', 1170, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of 8 round 3s
9-16::
    1s+3s dance 1/2 R&L, 2s+3s also 1s+4s dance RH across
17-24::
    All dance RSh reels of 4 on sides but at end 3s & 1s do not pass to
    finish 2(1)(3)4
25-28::
    1s cross up & cast to 2nd place own side _while_ 3s cross down &
    cast up to 3rd place own side
29-32::
    1s 1/2 turn 3s RH & 1/2 turn 4s LH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4664, '2013-08-21 08:30:52.495649+00', '2023-02-04 01:19:10.860697+00', 10787, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, 1s dance 1/2 Figs of 8 (Man round 2s &
    Lady round 3s) & end facing 1st corners
9-16::
    1s dance Pass+Turn with 1st corners & 1s twirl round in centre to
    face 4th crnrs, 1s dance Pass+Turn with 4th crnrs & twirl round to
    face own sides
17-24::
    1s dance 6 bars of Double Triangles & end with 1L between 2s facing
    2L & 1M between 3s facing 3M
25-32::
    1s dance reel of 3 across giving RSh to 4th corners & 1s cross RH to
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (4666, '2013-08-21 08:30:52.511693+00', '2023-02-04 01:19:10.899663+00', 8926, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, dance RH across (1M with 2s & 1L with 3s)
    & 1s end by casting up/down round 3rd corners
9-16::
    1s dance reels of 3 across giving LSh to 2nd corners
17-24::
    1s pass RSh & set to 2nd corners, change places RH, corners turn LH
    1.1/4 times to face 1st corner (pstn) _while_ 1s+1st corner persons
    chase 1 place clockwise
25-32::
    1s change place RH with corner persons in middle & turn LH to 2nd
    place opposite sides, 2s+1s+3s set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (13737, '2021-03-02 01:19:10.57653+00', '2023-02-04 01:19:11.215773+00', 1173, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set, dance RH across, 1s/3s face out, 2s/4s remain
    in centre facing up; 1s/3s cast to 2nd/4th place own side as 2s/4s
    dance up to 1st/3rd place
9-16::
    1s & 3s turn partner 2H, cast up (2s/4s step down 11-12); 1s & 3s
    turn 2H, cast to 2nd/4th place (2s/4s step up 15-16)
17-24::
    2s+1s also 3s+4s 1/2 turn partner RH & circle 4H round to left (2
    bars) & circle back to right (4 bars) to end in original places
25-32::
    1s+2s also 3s+4s dance Bourrel:
::
    _25-28_  1M+2L also 3M+4L set advancing, 3/4 turn 2H & twirl to end
    BtoB (Lady facing up & Man down) _while_ partners chase
    anticlockwise to face partner
::
    _29-32_  1s take prom hold facing Ladies'' side & 3s do likewise
    facing Men''s side & 1s & 3s dance dance clockwise round to change
    places _while_ 2s & 4s set & turn partner 2H 3/4 round.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4668, '2013-08-21 08:30:52.729539+00', '2023-02-04 01:19:11.237082+00', 1176, 3, NULL, 'ace', '1-8::
    1s+2s set & Petronella-in-tandem twice to end with 2s+1s on opposite
    sides having changed places.  (2) (1) 3
9-16::
    2s+1s set, 2s cross RH _while_ 1s 3/4 turn LH; 1L+2s (at top) &
    1M+3s dance RH across
17-24::
    1s+3s Set+Link & circle 4H round to left. 3s face down, 1s face up
    ready for …
25-32::
    2s+3s+1s dance Grand Chain (2s cross, 3s+1s change places RH on
    sides)', 0);
INSERT INTO 'dancecrib' VALUES (9354, '2016-10-06 07:18:12.894125+00', '2023-02-04 01:19:11.45014+00', 17072, 3, NULL, 'ace', '1-8::
    1s+2s set & dance RH across 1/2 way, 1s+2s set & 2s cross LH _while_
    1s turn LH to face 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places
17-24::
    2s+1s+3s chase 1/2 way, set & 1/2 turn RH into Allemande hold facing
    up
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4602, '2013-08-21 08:30:51.312677+00', '2023-02-04 01:19:07.316801+00', 11627, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 on own sides (1s give RSh to 2s to start)
9-16::
    1s dance RSh reels of 3 on own sides
17-24::
    1s+2s circle 4H round to left to end 1s facing 2s in middle, set &
    1s cast to 2nd place as 2s lead up to 1st place
25-32::
    1s+3s Set & Rotate', 0);
INSERT INTO 'dancecrib' VALUES (4670, '2013-08-21 08:30:52.914145+00', '2023-02-04 01:19:11.479455+00', 1179, 3, NULL, 'ace', '1-8::
    1s set to 2s on sides & set to partners, 1s turn RH 1.1/2 times &
    cast 1 place _while_ 2s turn RH (once) & lead up to top
9-16::
    2s+1s dance RH across & LH back BUT on 2nd & 4th bars Ladies cast
    behind partner _while_ on 5th & 7th bar Men cast behind Ladies to
    end 2 (1)
17-24::
    1s+2s dance Ladies'' Chain
25-32::
    1s dance 1/2 Fig of 8 round 2s & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4672, '2013-08-21 08:30:52.932031+00', '2023-02-04 01:19:11.544673+00', 9369, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross RH & lead up to places
9-16::
    1s & 2s repeat
17-24::
    1s, 2s & 3s repeat
25-32::
    2s+3s RH across 1/2 way, set (leave space for 1s to cast), LH across
    1/2 way & set _while_ 1s cast, cross RH, cast to right & cross RH
    (up down)
33-40::
    2s+3s dance RH across 1/2 way _while_ 1s cast to right to 2nd places
    (opposite sides), 2s+1s+3s set, cross RH & set', 0);
INSERT INTO 'dancecrib' VALUES (12911, '2020-07-01 00:18:58.639306+00', '2023-02-04 01:19:11.614339+00', 17589, 3, NULL, 'ace', '1-8::
    1M dances RSh round 3L back to place & 1s cross RH
9-16::
    2s+3s+4s circle 6H round & back _while_ 1s cast to 4th place, cross
    LH & cast back up to place
17-24::
    All take hands on sides & set Coupé PdeB
25-32::
    1s cast to 4th place (2s+3s+4s step up 27-28); All couples turn RH.
    End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (10525, '2018-03-20 06:26:20.082844+00', '2023-02-04 01:19:11.643223+00', 14446, 3, NULL, 'ace', '1-8::
    Men LH 3/4 across to new place.  Ladies 3/4 RH across to new place
    facing out
9-16::
    All dance 8 bars of Schiehallion reels (1/2 round set)
17-20::
    Men dance across set (brief RH across in centre) & dance RSh round
    partner to end facing in on Ladies'' Left (all 1 place clockwise
    round from start)
21-32::
    "The Chiltern Chain":
::
    2s+4s (top & bottom place) dance R&L (8 bars), then stand 4 bars
    _while_
::
    1s+3s (side couples) set, dance 1/2 R&L, set, dance 1/2 R&L
33-40::
    All take allemande hold & promenade clockwise once round.  End 4 1 2
    3

{{explanation}}
Repeat 3 times & end by Men bringing partner into centre, retaining RH for bow/curtsey', 0);
INSERT INTO 'dancecrib' VALUES (4673, '2013-08-21 08:30:52.940151+00', '2023-02-04 01:19:11.671677+00', 9845, 3, NULL, 'ace', '1-8::
    2s followed by 1s dance down the middle, cast round 3s & up (2s to
    1st place & 1s to 2nd place) & turn partners RH
9-12::
    2s (top) cast to 3rd place & cross RH _while_ 1s (middle) set &
    cross RH up to top _while_ 3s (bottom) lead to top, cross & cast 1
    place
13-16::
    Repeat 9-12 from new positions (''Muirland Willie'' figure upside
    down!)
17-24::
    3s+2s+1s dance Allemande
25-32::
    1s & 2s 3/4 turn RH, 1M+2L turn LH 1.1/2 times in centre _while_
    their partners dance clockwise 1/2 way round to meet their partner
    again, 2s+1s turn partners RH 1.3/4 times to sidelines.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13053, '2020-08-10 00:18:59.458209+00', '2023-02-04 01:19:11.701541+00', 1187, 3, NULL, 'ace', '1-8::
    2s petronella turn & set; 2s turn LH _while_ 1s+3s petronella turn.
    All end in line up/down centre, Men facing up, Ladies facing down
9-16::
    Interlocking reels of 3:
::
    2M+1s also 2L+3s (1s & 3s pass partner RSh to start).  Dancers
    passing through 2nd place turn LH to reel back to place. 2s end BtoB
    in centre facing opp sides, 1s/3s end in 1st/3rd place opp sides
17-20::
    All set as Double Triangles, 1s+3s cross RH _while_ 2s rotate round
    each other
21-24::
    All set as Double Triangles, 1s+3s change places LH on sides _while_
    2s rotate round each other to end facing up (Man with Lady on left)
25-32::
    2s followed by 1s lead up & cast (all on opp sides), Bars 31-32: all
    cross RH.  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (13295, '2020-11-02 01:19:05.804403+00', '2023-02-04 01:19:11.883317+00', 14371, 3, NULL, 'ace', '1-8::
    1s+2s dance 3/4 R&L, set to partners.  2 1 3
9-16::
    1s turn 1st corner RH, pass RSh, turn 2nd corner RH & pass RSh to
    2nd place own side facing out (corners dance 4 bar turns)
17-24::
    2s+1s+3s dance RSh reels of 3 on sides (1M up, 1L down)
25-32::
    1s+3s dance 3/4 R&L &  set to partners.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4674, '2013-08-21 08:30:52.949914+00', '2023-02-04 01:19:11.922861+00', 11486, 3, NULL, 'ace', '1-8::
    1M & 2L cross to cast round partners, 1M+2L turn RH & end in each
    others place
9-16::
    2M+1L repeat casting round opposite person, turn LH & end facing
    down with 1L on left of 2M into a line of 4 facing down
17-24::
    All dance down for 2 bars & set turning right about, all dance up
    then 1M & 2L cast to 2nd place & pass LSh to end BtoB in middle
    _while_ 1L & 2M dance up to top & cast into a line of 4 across the
    dance.
25-32::
    1s & 2s dance a reel of four across the dance (1M & 2L omit last LSh
    pass dancing across to end 2 1)', 0);
INSERT INTO 'dancecrib' VALUES (4675, '2013-08-21 08:30:52.95794+00', '2023-02-04 01:19:11.954785+00', 14017, 3, NULL, 'ace', '1-8::
    1s & 2s cross passing RSh then circle left 1/2 way, 1s dance DoSiDo
9-16::
    1s turn partner RH & 1st corner LH, 1s turn partner RH & 2nd corner
    LH to end 1M between 2s (facing 2M) & 1L between 3s (facing 3L)
17-24::
    1s dance Figs of 8 across (RSh to start) _while_ 2s & 3s dance
    DoSiDo twice (RSh then LSh)
25-32::
    1s set to 1st corner then turn partner RH, set to 2nd corner then
    turn RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (4671, '2013-08-21 08:30:52.922241+00', '2023-02-17 18:29:27.225561+00', 1182, 3, NULL, 'ace', '1-8::

    1s turn RH, cast 1 place, turn LH 1.1/4 times to end with 1L facing

    her 1st corner with partner behind her

9-16::

    1L followed by partner dance full diagonal RSh Tandem reel of 3 with

    1st corners (RSh to 2M). At end, 1s pull back LSh to face Ladies''

    side

17-24::

    1M followed by partner dance diagonal LSh Tandem reel of 3 with 2nd

    corners (LSh to 2L). At end 1M pulls back RSh to face partner

25-32::

    1s turn RH 1.1/2 times & dance LH across (1M+2s & 1L+3s) ending in

    2nd places own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9180, '2016-06-16 22:41:37.222545+00', '2023-02-26 17:31:20.634788+00', 12948, 3, NULL, 'ace', '1-8::

    1s set, cast (2s step up) & 1s dance 1/2 Fig 8 round 2s

9-16::

    1s dance 1/2 Fig 8 (1L up round 2s, 1M down round 3s) _while_ 2s+3s

    set, cross LH to opp sides.  1M+2s & 1L+3s dance LH across   2 1 3

17-24::

    1s dance 1/2 Fig 8 to 2nd place own sides (1L up, 1M down) _while_

    2s+3s set, cross RH to own sides.  1M+2s & 1L+3s dance RH across  2

    (1) 3

25-32::

    1s dance 1/2 Fig 8 round 3s then 1s dance down and cast up into 3rd

    place (3s step up) 1s set', 0);
INSERT INTO 'dancecrib' VALUES (9472, '2016-11-09 08:48:18.195328+00', '2023-02-04 01:19:11.996101+00', 15021, 3, NULL, 'ace', '1-8::
    1s lead down (4 bars), 1L dance under 1M Right arm (2s step up), 1s
    lead up to face opp sides in Double Triangle position
9-16::
    All set.  1s turn 1st corners 3/4 RH _while_ 2nd corners cross LH &
    face out. 1/2 reels of 3 across (1s pass 4th corner pstn LSh to
    start). 1s pass RSh to Double Triangle position facing own sides
17-24::
    Repeat 9-16 finishing in Double Triangle position facing opp sides
    but do not take hands
25-32::
    1s dance out of sides, cast Right, meet in centre _while_ 3s+2s
    dance 1/2 R&L.  1s turn RH (or birl) to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4676, '2013-08-21 08:30:52.965958+00', '2023-02-04 01:19:12.028131+00', 9985, 3, NULL, 'ace', '1-8::
    1s cast 1 place, 3/4 turn RH, 1s dance up/down & cast to 2nd place
    in centre BtoB (Lady facing up & Man down)
9-16::
    1s circle 3H round to left (1L with 2s & 1M with 3s), set (facing) &
    set again advancing to pass LSh
17-24::
    1s circle 3H round to left (1M with 2s & 1L with 3s), set (facing) &
    turn LH to face 1st corners
25-32::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners', 0);
INSERT INTO 'dancecrib' VALUES (4677, '2013-08-21 08:30:53.027805+00', '2023-02-04 01:19:12.059469+00', 1193, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    2L+3L passing LSh dance a diagonal reel of 4 with 1L+4L
9-16::
    2M+3M passing LSh dance diagonal reel of 4 with 1M+4M
17-24::
    2s+1s also 4s+3s dance RH across, 1s+4s dance LH across 1/2 way then
    2s+4s also 1s+3s dance 1/2 RH across to end (2)(4)1 3
25-32::
    All dance clockwise 1/2 way &set to end (3)(1)4 2
33-40::
    3s+1s also 4s+2s dance 1/2 double Figs of 8. all turn 2H.  3 1(4)(2)', 0);
INSERT INTO 'dancecrib' VALUES (4678, '2013-08-21 08:30:53.035872+00', '2023-02-04 01:19:12.090215+00', 1194, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s & end in middle facing each other in 1st
    place
9-16::
    1s set, cast 1 place & turn RH 1.1/4 times to face 2nd corners
17-24::
    1s dance diagonal RSh reel of 4 with 2nd corners & end facing 1st
    corners
25-32::
    1s set to 1st corner, set to 2nd corner, set to partner down/up &
    3/4 turn RH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (4680, '2013-08-21 08:30:53.05195+00', '2023-02-04 01:19:12.160362+00', 13584, 3, NULL, 'ace', '1-8::
    1s set advancing & lead down below 3s crossing 1s cast to 2nd place
    opp sides & turn LH to face 1st corners
9-16::
    1s dance 1/2 reel of 4 with 1st corners, 1s turn 3rd corners (pstn)
    RH & turn LH to face 2nd corners
17-24::
    1s dance 1/2 reel of 4 with 2nd corners, 1s turn 4th corners (pstn)
    RH & turn LH to Man facing up Lady down
25-32::
    1M+3s (at top) also 1L+2s dance RH across, 1s turn LH to 2nd place
    own sides _while_ 2s+3s chase 1/2 way clockwise', 0);
INSERT INTO 'dancecrib' VALUES (8991, '2015-11-30 08:59:35.308208+00', '2023-02-04 01:19:12.186634+00', 10903, 3, NULL, 'ace', '1-8::
    All join hands on sides, set twice, cross RH (4 bars)
9-16::
    Repeat bars 1-8 back to places
17-24::
    1s, followed by 2s+3s+4s, lead down & cast up to original places
25-32::
    1s cross RH, cast to 4th place (2s+3s+4s step up 27-28); 1s turn
    1.1/2 RH.  End 2 3 4 1

{{explanation}}
Note: originally bars 29-32: 1s dance 1/2  Fig of 8 round 4s.  The dance was revised in 2004 with the new ending.', 0);
INSERT INTO 'dancecrib' VALUES (8308, '2014-07-29 12:58:50.986813+00', '2023-02-04 01:19:12.206834+00', 15064, 3, NULL, 'ace', '1-4::
    1L+3L pass RSh, curving to face, pull back RSh and dance out to each
    other''s place facing out
5-8::
    1s+3s dance 1/2 Men''s Chain.  1s and 3s now opposite original places
9-16::
    2s+4s repeat bars 1-8 but finish with 3/4 RH turn so 4s face up, 2s
    face down in promenade hold
17-24::
    4s+3M+1L and 2s+1M+3L dance RSh reels of 3 up/down, (4s RSh to 3M,
    2s RSh to 1M)
25-32::
    4s+3s also 2s+1s dance LSh reels of 3 across the set (4s LSh to 3L,
    2s LSh to 1L)
33-40::
    All set, Men dance in, twirl 3/4 to face next place clockwise, dance
    out through Ladies'' place, into Man''s place _while_ Ladies dance
    thru partner''s place, into middle, twirl 3/4 to follow track of
    partner   2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (11181, '2018-09-30 22:19:29.812829+00', '2023-02-04 01:19:12.256853+00', 18614, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 on sides (dancing between 2s to start) & end
    crossing RH to face 2s
9-16::
    1s dance a Modified Spurtle:
::
    _9-12_  1s dance a 1/2 reel of 4 with 2s, 1s turn RH moving down to
    face 3s
::
    _13-16_  1s dance a 1/2 reel of 4 with 3s, 1s turn RH moving down
    below 3s to face up in middle
17-24::
    3s+1s circle 4H round left 1/2 way & 2s+1s circle 4H round to right
    1/2 way to end in original places, 1s turn RH
25-32::
    1s in middle face 2L & set then set to 3s who step in, 1s set to 2M
    & cast to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (12385, '2019-12-05 01:29:13.932928+00', '2023-02-04 01:19:12.28862+00', 17073, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 2s+1s+3s dance DoSiDo
9-16::
    2s+1s+3s circle 6H round & back, 1s end BtoB in centre facing 1st
    corners
17-24::
    1s dance "Hello-Goodbye" setting, ending with petronella turn to 2nd
    place own side
25-32::
    1L+2s also 1M+3s dance RH across; 2s+1s+3s turn partner RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4681, '2013-08-21 08:30:53.08806+00', '2023-02-04 01:19:12.319402+00', 13075, 3, NULL, 'ace', '1-8::
    2s advance & 1/2 turn RH, twirl & dance out to opposite side, cast
    round 1st corners & turn LH to face 1st corners
9-16::
    2s dance 1/2 diagonal reel of 4 with 1st corners & face 3rd corner
    (pstn), turn corners RH & partner LH to face 2nd corners
17-24::
    2s dance 1/2 diagonal reel of 4 with 2nd corners & face 4th corner
    (pstn), turn corners RH & partner LH to end 2M between 3s (at top) &
    2L between 1s facing 3L/1M
25-32::
    2s dance 1/2 LSh reel of 3 across (2M+3s, 2L+1s) & dance to meet
    partner in middle facing down (NHJ), turn 1s with free hand 1.1/2
    times.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4682, '2013-08-21 08:30:53.096337+00', '2023-02-04 01:19:12.347002+00', 7366, 3, NULL, 'ace', '1-8::
    1M+2M+3M+4M also 4L+5L+6L+7L dance reels of 4 on sides
9-16::
    1L+2L+3L+4L also 4M+5M+6M+7M dance reels of 4 on sides
17-24::
    1s & 4s cross RH, cast 1 place & dance 1/2 Figs of 8 round couples
    (2s & 5s) above them
25-32::
    1s & 4s cross RH, cast 2 places & dance 1/2 Figs of 8 round couples
    (5s & 7s) above them', 0);
INSERT INTO 'dancecrib' VALUES (2715, '2012-01-22 19:29:54.271593+00', '2022-12-03 20:51:11.006033+00', 4002, 1, NULL, 'ace', '1–::

  1c set and cast off one, (2c up) ; 2c+1c ½ DblFig8 (1c cross up) (2x,1x,3)

9–::

  3c set and cast up one (1c down) ; 3c+1c ½ DblFig8 (3c cross down) (to 2x,3x,1)

17–::

  1W cast up, 1M following, (3c down) and cross (2x,1x,3x) ; 1c dance BtoB diagonally to the R (with 3cnr pos)

25–::

  1c dance BtoB diagonally to the L (with 4cnr pos) ; all set and cross (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14386, '2021-10-13 19:26:23.425116+00', '2022-12-03 23:38:35.098199+00', 16664, 2, 963, 'ace', '1-8::

  1c and 2c dance the Tourbillon.  1c finish facing out

9-14::

  1c, Rsh to 3rd crn, 6 bar R3 on the side to finish 1M btwn 3c facing up, 1W btwn 2c facing down  

15-16::

  While 2&3c set facing in diag, 1c pass Lsh to face out opp end  

17-22::  

  1c, Lsh to 3rd crn, 6 bar R3 across to finish 2nd plc opp side 

23-24::  

  While 2&3c set facing in diag, 1c pass Rsh to own side and face in  

25-32::  

  1c and 3c dance the tournée  2,3,1', 3);
INSERT INTO 'dancecrib' VALUES (9181, '2016-06-16 22:41:37.391844+00', '2023-02-04 01:19:12.534985+00', 12949, 3, NULL, 'ace', '1-8::
    1s & 3s cast 1 place as 2s & 4s dance up.  All 5 couples set.  1s &
    3s dance 1/2 Fig 8 through end couples (1s up, 3s down)
9-16::
    1s & 3s »loop« LSh round 3rd corner to own sides (1L+3M pass RSh).
    RH across (1L+2s, 1M+4s+3L, 3M+5s)
17-24::
    1s set, rotating to face down/out as 3s cross RH to face in/up (3M
    polite turn)  1s+3s dance 3/4 double Fig 8 round 4s (3s cross up, 1s
    dance down).  End 3s in middle 2nd place  2 (3) 4 (1) 5
25-32::
    2s+3s+4s dance mirror reels of 3 (2s down/out, 3s dance up, 4s cast
    up) _while_ 1s+5s circle 4H round and back.  All finish on sides
33-40::
    LH across (3L+2s, 3M+4s+1L, 1M+5s)  3s dance 1/2 Fig 8 up round 2s
    as 1s cross down to 5th place own sides (5s step up)  1s set.   2 3
    4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (13736, '2021-03-02 01:19:07.944633+00', '2023-02-04 01:19:08.089716+00', 13373, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s cross LH, cast to the left (1M
    down, 1L up) to  1L between 2s facing down, 1M between 3s facing up
9-16::
    1L+2s & 1M+3s set. All chase clockwise 1/4 round; 3M+2L change place
    RH,  2s+3s cross RH with partner. 2 1 3
17-24::
    All dance mirror reels of 3 on the side, 1s dance in/up to start
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (4684, '2013-08-21 08:30:53.118529+00', '2023-02-04 01:19:12.553055+00', 12734, 3, NULL, 'ace', '1-8::
    All circle 8H round to left
9-16::
    All set to partner & 3/4 turn RH (all Ladies BtoB), set to partner &
    change places RH with Men giving LH across (partner on right)
17-24::
    All dance anticlockwise 1/2 way, set to partner & change places RH
    with Ladies giving LH across (partner on right)
25-32::
    All dance anticlockwise 1/2 way, set to partner & 3/4 turn LH to
    original places
33-40::
    1s+3s dance in & lead out sides with opposite person, cross & dance
    to opposite positions to 1/2 turn partner RH
41-48::
    2s+4s repeat
49-56::
    All in circle Adv+Ret & turn partner RH to face corners
57-64::
    All set to corner, dance DoSiDo & set turning right about to face
    partner
65-72::
    All set to partner, dance DoSiDo & set to partner
73-80::
    All turn partners RH into circle & Adv+Ret
81-88::
    1s+3s dance in & lead out sides with opposite person, cross & dance
    to original positions to 1/2 turn partner RH
89-96::
    2s+4s repeat
97-104::
    All set to partner & 3/4 turn RH (all Ladies BtoB), set to partner &
    change places RH with Men giving LH across (partner on right)
105-112::
    All dance anticlockwise 1/2 way, set to partner & change places RH
    with Ladies giving LH across (partner on right)
113-120::
    All dance anticlockwise 1/2 way, set to partner & 3/4 turn LH to
    original places
121-128::
    All circle 8H round to right', 0);
INSERT INTO 'dancecrib' VALUES (4686, '2013-08-21 08:30:53.163472+00', '2023-02-04 01:19:12.740486+00', 1201, 3, NULL, 'ace', '1-8::
    1s dance down between 2s, behind 3s In front of 4s & up behind 4s,
    in front of 3s & behind 2s back to place
9-16::
    1s+2s dance RH across & LH back
17-24::
    1s+2s also 3s+4s circle 4H round & back
25-32::
    1s slip step down the room & back up to 4th place
33-40::
    2L followed by 3L+4L+1L dance across (with hands joined), down
    behind Men & up own side
41-48::
    2M followed by 3M+4M+1M dance across (with hands joined), down
    behind Ladies & up own side', 0);
INSERT INTO 'dancecrib' VALUES (14727, '2022-04-01 00:19:08.824356+00', '2023-02-04 01:19:12.840683+00', 14502, 3, NULL, 'ace', '1-8::
    All 3 couples Set+Link twice to original places
9-16::
    All dance RH across & LH across
17-24::
    All dance DoSiDo with partner (Pass RSh); all dance DoSiDo with
    partner (Pass LSh)
25-32::
    All circle 6H round & back, ending facing partner
33-40::
    All dance interlocking RSh reels of 4
41-44::
    All turn partner 1/4 with RH to bring Men in centre, Men dance LH
    across round 2 places _while_ Ladies chase 1 place round clockwise
45-48::
    Repeat 41-44 to end having moved 2 places round clockwise.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4688, '2013-08-21 08:30:53.180168+00', '2023-02-04 01:19:12.874228+00', 1204, 3, NULL, 'ace', '1-8::
    All Ladies cast behind partner into centre, dance RH across & dance
    LSh round partner back to places
9-16::
    All Men cast behind partner into centre, dance LH across & RSh round
    partner to places
17-24::
    All dance Star Grand Chain 1/2 way round, Ladies end with backs to
    centre facing partner
25-32::
    All dance DoSiDo, turn partner RH 1.1/4 times to end in circle
    holding hands
33-40::
    All dance Star Grand Chain 1/2 way round, Ladies end with backs to
    centre facing partner
41-48::
    All dance DoSiDo, turn partner RH 1.1/4 times to end Ladies facing
    out & Men in
49-64::
    All dance full Schiehallion Reel
65-72::
    All slip step left for 2 bars, set & slip step back, set & end with
    Ladies giving RH in centre with partner on left
73-80::
    All dance St Andrews Cross & dance out to original places
81-88::
    All circle 8H round & back
89-96::
    All advance, drop hands with corners & retire to Sq.Set with
    partner, face corner, turn LH & face partner for bow/curtsey', 0);
INSERT INTO 'dancecrib' VALUES (4689, '2013-08-21 08:30:53.193663+00', '2023-02-04 01:19:12.92303+00', 12506, 3, NULL, 'ace', '1-8::
    1s+3s turn partner RH & chase clockwise 1/2 way
9-16::
    1s+3s dance 1/2 R&L & turn other partner RH once round to face side
    couples
17-24::
    1s+3s dance 3/4 Fig of 8 round side couples  & dance back to
    original places
25-48::
    2s+4s repeat bars 9-24
49-56::
    1s+3s turn partners LH 1.1/2 times, 1L+3L dance clockwise as 1M+3M
    dance anticlockwise to meet other partner    & dance in between side
    couples to meet own partner in prom hold (Lady on Mans right)
57-64::
    1s dance 1/2 reel of 3 across with 2L+4M (RSh to 2L) _while_ 3s
    dance 1/2 reel of 3 with 2M+4L (RSh to 4L), 1s & 3s pass RSH to
    change reels & dance 1/2 reel of 3 with other persons ending in
    original places
65-80::
    2s+4s repeat bars 49-64
81-88::
    8H round & back ending dancing into centre', 0);
INSERT INTO 'dancecrib' VALUES (4690, '2013-08-21 08:30:53.202558+00', '2023-02-04 01:19:12.962902+00', 1207, 3, NULL, 'ace', '1-8::
    1s NHJ dance down, turn 3s on side NH to end in 2nd place (2s step
    up).  1s cross, passing RSh & turn 3s on sides (1M+3L RH, 1L+3M LH)
    1s end in middle facing up
9-16::
    1s NHJ dance up, turn 2s NH & 1s end in 2nd place opp sides.  1s
    cross passing RSh & turn 2s on sides (1M+2M RH, 1L+2L LH)  1s end in
    middle between 2s at top facing down
17-24::
    1s dance down below 3s, cast up to 2nd place & petronella turn into
    centre to 1L between 2s & 1M between 3s. All set
25-32::
    All change places RH with opp person, set, change places again with
    opp person; 1L casts down round 2L as 1M casts up round 3M into 2nd
    place own side', 0);
INSERT INTO 'dancecrib' VALUES (4691, '2013-08-21 08:30:53.206687+00', '2023-02-04 01:19:12.972259+00', 14679, 3, NULL, 'ace', '{{explanation}}
All form circle around the room with partner on Man''s right

1-8::
    All dance in 4 steps & out, repeat
9-16::
    Ladies dance in 4 steps, clap & out again, Men do the same but turn
    to face partner as they dance out
17-24::
    All swing partners & end facing anticlockwise round the room
25-32::
    All Promenade anticlockwise 8 steps

{{explanation}}
Note:  There are many variations to be found on the internet.  The dance source is unknown', 0);
INSERT INTO 'dancecrib' VALUES (4692, '2013-08-21 08:30:53.216587+00', '2023-02-04 01:19:13.086711+00', 1210, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All dance R&L
9-16::
    All set to partner twice & turn 2H
17-24::
    All dance Ladies'' Chain
25-32::
    All dance Poussette to change places & progress to face next couple', 0);
INSERT INTO 'dancecrib' VALUES (4693, '2013-08-21 08:30:53.224562+00', '2023-02-04 01:19:13.110828+00', 8043, 3, NULL, 'ace', '{{explanation}}
Circle, Man has Lady on his right

1-8::
    All Adv+Ret, Adv+Ret ending facing partner
9-16::
    All dance Grand Chain to face 5th person
17-24::
    All dance DoSiDo with new partner & turn RH
25-32::
    All circle round & back', 0);
INSERT INTO 'dancecrib' VALUES (4694, '2013-08-21 08:30:53.230687+00', '2023-02-04 01:19:13.137117+00', 8144, 3, NULL, 'ace', '{{explanation}}
Circle, Man has Lady on his right

1-4::
    All balance in & out, Men releasing partner''s hand swing the Lady on
    left in front of them to end on their right
5-16::
    Repeat bars 1-4 three more times
17-24::
    In waltz hold take 2 steps in & 2 steps out
25-32::
    Lady turns under Mans right arm, all waltz round room to reform
    circle', 0);
INSERT INTO 'dancecrib' VALUES (4695, '2013-08-21 08:30:53.243277+00', '2023-02-04 01:19:13.179908+00', 12874, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set+Link, 2M+1L also 4M+3L change places RH, 2L+1M
    also 4L+3M change places RH.  (1)(2)(3)(4)
9-16::
    1s & 4s petronella turn into middle & set, all petronella turn & set
    (1s & 4s to original places _while_ 2s+3s are in centre)
17-24::
    2s+3s dance reel of 4
25-32::
    2s+3s 1/2 turn RH, 2L dances reel of 3 across with 1s (RSh to 1M)
    _while_ 3M dances reels of 3 across with 4s (RSh to 4L) _while_
    2M+3L turn LH 1.1/2 times & cast 2M to top & 3L to bottom.  (2) 1 4
    (3)
33-40::
    1s+4s Set+Link, 1s+4s dance LH across _while_ 2s & 3s turn 2H 1.1/2
    times.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9722, '2017-04-06 08:39:35.269944+00', '2023-02-04 01:19:13.206432+00', 17534, 3, NULL, 'ace', '1-8::
    1s dance down between 2s & cast to 3rd place, 1s dance down between
    4s & cast up to 3rd place
9-16::
    All circle 8H round & back
17-24::
    1s followed by 4s dance up between 2s+1s & cast to 4th/3rd places as
    3s followed by 2s dance down & up (follow 1s+4s) & cast to 2nd/1st
    places
25-32::
    2s+3s also 4s+1s dance R&L.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4697, '2013-08-21 08:30:53.41408+00', '2023-02-04 01:19:13.234531+00', 13898, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s+3s on own sides (in to start), cross
    up & out between 2s+3s & behind 2s to meet in prom hold facing 2M
9-16::
    1s dance 1/2 RSh reel of 3 across with 2s & end facing 3L (2s dance
    up to 1st place), 1s dance 1/2 LSh reel of 3 across with 3s & end
    3rd place opp side (3s dance up to 2nd place)  (2) (3) (1)
17-24::
    3M+2s also 3L+1s dance RH across; all 1/2 turn partners RH to face,
    twirl & dance out to own sides
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10994, '2018-08-17 07:51:58.391343+00', '2023-02-04 01:19:13.25569+00', 18408, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up), turn 1.1/4 LH to face 1st corners
9-12::
    Corners Pass & Allemande Turn:
::
    As Corners Pass+Turn except corners dance in, join RH & Lady dances
    under Man''s arm. Lady curves out to place as Man retires.
13-16::
    1s in centre turn 1.1/4 LH to face 2nd corner pstns _while_ corners
    chase clockwise 1/2 round
17-24::
    Repeat 9-16 with 2nd corner pstns, with 1s turning 1.3/4 LH to end
    centre LSh to LSh facing opp sides
25-32::
    1L+2s & 1M+3s dance RH across; all turn partners RH (or birl)  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4698, '2013-08-21 08:30:53.532544+00', '2023-02-04 01:19:13.439985+00', 13847, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s, 1L+2M turn RH 1.1/4 times _while_
    1M+2L turn LH 1.1/4 times & 1s end BtoB facing opp sides
9-16::
    1s+2s dance reel of 4 across in 2nd place. 2s end in 1st places
    _while_ 1s pass LSh to face 1st corners
17-24::
    1s set to 1st corner & 2nd corner ending (turning to right) between
    corners, all set & 1s cross RH
25-32::
    1s+3s dance Espagnole:
::
    _25-26_   1s+3s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _27-28_   1s+3s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _29-32_   3s turn RH as 1s turn LH to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (10827, '2018-06-11 00:36:04.36492+00', '2023-02-04 01:19:13.463177+00', 17478, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s & 3s+4s dance a variation of Espagnole:
::
    _1-2_   1s+2s & 3s+4s cross (Ladies lead across RH passing between
    Men) with Ladies changing places RH
::
    _3-4_   1s+2s & 3s+4s cross back (Men lead across RH between Ladies)
    with Men changing places RH
::
    _5-8_   2s/3s turn RH _while_ 1s & 4s dance LH across to finish back
    to back in centre facing corners in St Andrews cross formation (1M
    facing 2M, 1L facing 2L, 4M facing 3M, 4L facing 3L)
9-16::
    1s & 4s dance ''Hello-Goodbye'' setting to face diagonally opposite
    corner
17-24::
    All couples dance reels of 4 on the sides, start by passing corner
    RSh.  End 2 4 1 3 all on sidelines
25-32::
    4s dance 1/2 Fig of 8 round 2s _while_ 1s dance 1/2 Fig of 8 round
    3s. 4s & 1s cross RH. All 4 couples set.', 0);
INSERT INTO 'dancecrib' VALUES (8309, '2014-07-29 12:58:51.405629+00', '2023-02-04 01:19:13.479187+00', 13679, 3, NULL, 'ace', '{{explanation}}
3s+4s start on opposite sides

1-8::
    1s+4s petronella into centre & set to partners (2s+3s step up/down),
    1s pass partner LSh, dance RSh round 2s (1L/2M, 1M/2L) as 4s dance
    similar round 3s
9-16::
    1s+4s dance 1/2 RSh reel of 4, All couples petronella 1 place right
    and set (2s+3s in centre facing prtnr, 4s in 1st place opp sides, 1s
    in 4th place own side)
17-20::
    2s+3s turn RH, 2L/3L dance RSh round 4M/1M as 2M+3M turn 3/4 LH to
    face out on sides
21-24::
    2s+3s dance 1/2 Ladies'' Chain (4) 3 (2) 1
25-30::
    4s+1s cross RH, cast up/down (3s+2s step up/down on 27-28), 4s+1s
    dance 1/2 RH across
31-32::
    All 4 couples set       3 1 (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (14643, '2022-03-07 02:19:00.809807+00', '2023-02-04 01:19:13.601588+00', 16597, 3, NULL, 'ace', '1-8::
    All Ladies dance RH across for 4 steps & dance out to 1 place
    anti-clockwise (2L+1M, 3L+2M, 4L+3M, 1L+4M). All set to new partner
    & turn RH
9-16::
    All Men dance LH across for 4 steps & dance out to 1 place clockwise
    (3L+1M, 4L+2M, 1L+3M, 2L+4M). All set to new partner & turn LH to
    finish opposite original partner (Men with new partner on left)
17-20::
    1s+3s set (2nd & 4th positions), 1s+3s advance into centre with
    Ladies finishing RSh to RSh facing clockwise _while_ their original
    partner dances towards them, pulling back LSh to finish in promenade
    hold.
21-24::
    1s+3s promenade clockwise round the middle of the set to finish 1s
    in 4th place & 3s in 2nd place
25-32::
    2s+4s (1st & 3rd positions), repeat bars 17-24 to finish 2s in 1st
    place & 4s in 3rd place 2 3 4 1
33-40::
    All dance 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4699, '2013-08-21 08:30:53.540772+00', '2023-02-04 01:19:13.61957+00', 11222, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place, 1s turn 1.1/2 RH as 4s turn RH
    once round to end in centre in prom hold, 1s facing up & 4s down
    (Lady on Man''s Right)
9-16::
    1s & 4s dance reels of 3 across (1s LSh to 2M & 4s LSh to 3L) 1s+4s
    end passing RSh
17-24::
    4s & 1s dance reels of 3 across (4s RSh to 2L & 1s RSh to 3M)
25-32::
    4s+1s dance RH across & 1s turn partners RH once round as 4s turn
    1.1/2 RH to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4700, '2013-08-21 08:30:53.550559+00', '2023-02-04 01:19:13.647669+00', 1215, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, set advancing & 1/4 turn with 2H
9-16::
    1L+2s also 1M+3s circle 3H round to left 1/2 way, set in lines
    across, 1s set advancing & 1/2 turn 2H
17-24::
    1M+2s also 1L+3s circle 3H round to left 1/2 way, set in lines
    across, 1s turn RH
25-32::
    1s dance round 1st corners RSh, pass partners RSh in centre & round
    2nd corners RSh
33-40::
    1s dance reels of 3 on opposite sides passing 1st corner LSh to
    start & crossing back to own sides', 0);
INSERT INTO 'dancecrib' VALUES (14168, '2021-07-23 10:11:14.236594+00', '2022-12-04 13:46:59.24406+00', 20064, 2, 35721, 'ace', '1-4::  1C cross RH, and cast into second place on opposite sides, with 2C stepping up on 3 and 4. 

5-8::  1C cross LH and cast 1L up around 2L and 1M down around 3M. 1M finishes between 3C facing up, and 1L between 2C facing down. 

9-12::  1L with 2C and 1M with 3C advance and retire up and down the set.

13-16::  2L and 3L turn RH back to place. 2M and 3M turn RH back to place. 1C cross RH and cast around their second corner positions, and finish in second place on opposite sides.

17-20::  1M with 2L and 3L; 1L with 2M and 3M advance and retire across the set.

21-24::  2C and 3C turn partner with LH back to place, while 1C change places LH and cast man down lady up around fourth corner positions to finish at the end of bar 8.

25-28::  Taking hands, all set twice three and three across.

29-32::  1C turn RH 1¼ times to finish in second place.', 3);
INSERT INTO 'dancecrib' VALUES (14417, '2021-11-06 01:10:26.074726+00', '2023-02-04 01:19:13.681772+00', 13611, 3, NULL, 'ace', '1-8::
    1s cross RH & cast (2s step up); 1s cross LH & cast to their left
    (1M down, 1L up) to end facing 1st corners
9-16::
    1s dance reels of 3 across (RSh to 1st corner). End 1L between 2s
    facing down, 1M between 3s facing up
17-24::
    Lines of 3 across Adv+Ret; 1s cross RH (up/down) & cast to their
    right. 2 (1) 3
25-32::
    2s+1s+3s Adv+Ret; all set & 1s cross RH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (4701, '2013-08-21 08:30:53.558661+00', '2023-02-04 01:19:13.711346+00', 13270, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Snowball Grand Chain (1s+2s change places on sides to
    start).  (3)(1)(2)
9-16::
    1s cross (pass RSh) & 1/2 turn RH person in 3rd corner, 1s followed
    by corners change places (diag) passing LSh & 1s cast to 2nd place
    (opp sides) as corners end in original places
17-24::
    1s cross (pass LSh) & 1/2 turn LH person in 4th corner, 1s followed
    by corners change places (diag) passing RSh & 1s cast to 2nd place
    (opp sides) as corners end in original places.  2(1)3
25-32::
    All turn RH (4 bars) & 1s dance 1/2 Figs of 8 (Lady up & Man down)', 0);
INSERT INTO 'dancecrib' VALUES (4702, '2013-08-21 08:30:53.5667+00', '2023-02-04 01:19:13.739458+00', 10154, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance RH across (Lady with 2s & Man with 3s)
    end facing 3rd corner
9-16::
    2s+1s+3s dance 1/2 reels of 3 on sides (LSh to 3rd corner), 1s turn
    LH 1.1/4 times to end between 2s/3s facing 1st corner (pstn)
17-24::
    2s+1s+3s dance 1/2 reels of 3 across (LSh to 1st corner), 1s turn LH
    1.1/2 times to 2nd place own sides
25-32::
    1s dance diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (13883, '2021-04-05 00:19:03.991318+00', '2023-02-04 01:19:13.774487+00', 19712, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance 3 couple Espagnole:
::
    _1-2_   1L+2L also 2M+3M lead across RH & change places _while_ 1M &
    3L chase 1 place clockwise (end Men''s side: 2L,1L,3L Ladies'' side:
    1M, 3M, 2M)
::
    _3-4_   1L+3L also 1M+3M lead across RH & change places _while_ 2L &
    2M chase 1 place clockwise (end Men''s side: 3M,1M,2M Ladies'' side:
    2L, 3L, 1L)
::
    _5-8_   3M+2L (in 1st place) also 2M+1L (in 3rd place) turn RH
    _while_ 1M+3L turn LH (in 2nd place)
9-16::
    All set, cross LH, chase anticlockwise 1/2 way (Men''s side: 2M,1M,3M
    Ladies'' side 1L,3L,2L)
17-24::
    1s+2s+3s dance 3 couple Bourrel:
::
    _17-20_   2M+3L also 1M+2L set advancing & 3/4 turn 2H to line
    up/down middle & twirl to end BtoB (Lady facing up, Man down)
    _while_ 1L+3M chase anticlockwise to face partner
::
    _21-24_   All set to partners & turn 2H to own sides 3 2 1
25-32::
    2s+1s dance 3/4 R&L, all set. End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4705, '2013-08-21 08:30:53.590963+00', '2023-02-04 01:19:13.867058+00', 10309, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Figs of 8 round 2s to end
    facing 1st corners
9-16::
    1s dance Pass & Twizzle with corners:
::
    1s dance out to 1st corners, turn & dance in, 1/2 turn RH, continue
    to turn individually & dance out thru 2nd corner places & cast thru
    2nd place (opposite sides) to face 2nd corners _while_ corners dance
    in, 1/2 turn RH, continue to turn & dance out to opposite corners
    Repeat with 4th corners & 1s end facing 3rd corner (pstns)
17-24::
    1s dance 1/2 reel of 3 on sides giving LSh to 1st corner (pstn) &
    1/2 of 3 across giving RSh to 4th corner (pstn)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4706, '2013-08-21 08:30:53.59927+00', '2023-02-04 01:19:13.892574+00', 1223, 3, NULL, 'ace', '1-8::
    1s cross RH & cast down 1 place, 2s+1s dance 1/2 RH across & set
9-16::
    1s+2s dance R&L, ending with Men turning Ladies into centre to form
    a line across
17-24::
    1s+2s dance the Targe :
::
    _17-18_ 1st & 2nd Ladies  3/4 turn RH _while_ Men dance 1/4 way
    round anticlockwise
::
    _19-20_ 1st Man with 2nd Lady & 1st Lady with 2nd Man full turn LH
::
    _21-22_ 1st & 2nd Ladies  3/4 turn RH _while_ Men dance 1/4 way
    round anticlockwise
::
    _23-24_ 1st Man with 2nd Lady & 1st Lady with 2nd Man turn 3/4 LH to
    end on sides 1s facing up & 2s facing down
25-32::
    2s+1s set facing on sides, turn to face partners & set, 1s lead up
    crossing RH & cast to 2nd place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (4708, '2013-08-21 08:30:53.618791+00', '2023-02-04 01:19:13.922253+00', 11078, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left; turn partners 2H & 1s cast 1 place
    own sides as 2s dance up. 2 1 3
9-16::
    1s dance diag R&L (Man down, Lady up).  ((3) 1 (2)
17-24::
    3s+1s+2s set advancing, 3s+2s retire _while_ 1s petronella turn into
    lines of 3 across, all set advancing, 3s+2s retire _while_ 1s
    petronella turn to 2nd place opp sides
25-32::
    All Set+Link for 3 twice.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4709, '2013-08-21 08:30:53.626757+00', '2023-02-04 01:19:14.033877+00', 7368, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to 2nd place in prom hold facing 2L
9-16::
    1s set to 2L, set to 3L, set to 3M & set to 2M
17-24::
    1s lead up & cast to 2nd place, 2s+1s+3s turn RH & face up for
    Promenade
25-32::
    2s+1s+3s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (13054, '2020-08-10 00:19:00.988609+00', '2023-02-04 01:19:14.06679+00', 18560, 3, NULL, 'ace', '1-8::
    1s+2s+3s also 4s+5s+6s dance 6 bars of Set & Rotate for 3 couples
::
    _1- 4_   1s+2s+3s Set & Rotate singly & chase clockwise to form
    lines of 3 across (Men facing down & Ladies up)
::
    _5- 8_   All change places with partner & set (now 3 lines of 4
    dances up/down centre, Ladies facing down, Men facing up)
9-16::
    All dance 1/2 RSh reels of 4; Bar12: Middle lines across (4L+5L+6L,
    1M+2M+3M) pull back LSh to face up/down & turn opp person LH
17-20::
    Middle line of Ladies (4L+5L+6L) dance RSh round opp Man _while_
    both lines of Men dance DoSiDo
21-24::
    Middle line of Men (1M+2M+3M) dance RSh round opp Lady _while_ both
    lines of Ladies dance DoSiDo
25-26::
    Middle lines of Men & Ladies pass opposite dancer RSh & end on left
    of next opp dancer (2 lines across, Men at top, Ladies at bottom)
27-32::
    All chase 1/4 clockwise (3) (6) (2) (5) (1) (4) & cross RH to own
    side.  End 3 6 2 5 1 4', 0);
INSERT INTO 'dancecrib' VALUES (15058, '2022-09-05 00:19:02.645476+00', '2023-02-04 01:19:14.091803+00', 20797, 3, NULL, 'ace', '1-4::
    1s dance down _while_ 4s dance up, 1L+4L dance out between 2L & 3L &
    cast back to place _while_ 1M+4M dance similar on Men''s side
5-8::
    1s+2s also 3s+4s turn 1.1/2 times on sides (1L+2L LH, 1M+2M RH,
    3L+4L RH, 3M+4M LH)  1s face down, 4s face up in centre
9-16::
    1s+4s dance R&L (cross RH up/down to start) _while_ 2s & 3s cross RH
    & chase clockwise 1/2 round, 2M faces out.  3 1 4 2
17-24::
    1L followed by 1M casts round 4L, dances up between 4s & casts round
    4M & across to 4th place own side _while_ 2M followed by 2L casts up
    behind 4M, across & casts up round 3L & across to own side (1L & 4L
    pass RSh in middle) 3s step down 23-24.  2 3 4 1
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4744, '2013-08-21 08:30:54.234862+00', '2023-02-17 12:35:06.698327+00', 1285, 3, NULL, 'ace', '1-8::

    1s+2s Adv+Ret, turn RH

9-16::

    1s+2s dance Allemande

17-24::

    1s dance Fig of 8 round 2s

25-32::

    2s+1s dance RH across & LH back', 0);
INSERT INTO 'dancecrib' VALUES (14259, '2021-08-21 16:14:58.903364+00', '2022-12-04 13:53:58.817512+00', 20397, 1, 202, 'ace', '1--::

  1c+2c set | turn P BH, opening into ; Circle4 L (1,2,3)

9--::c

  Parallel Reels3 on sides {6}, 1c RSh to 2c | 1c+2c change places RH (2,1,3)

17--::

  1c+3c set | ½ RHA ; set | cross RH (2,3,1)

25--::

  3c+1c Poussette', 2);
INSERT INTO 'dancecrib' VALUES (4711, '2013-08-21 08:30:53.721717+00', '2023-02-04 01:19:14.377109+00', 10885, 3, NULL, 'ace', '1-8::
    1s+2s set, 1M+2L change places RH, 1L+2M change places LH & 2s+1s
    cross RH
9-16::
    1s cross down between 3s & cast up to 2nd place, cross up between 2s
    & cast to 2nd places
17-24::
    1s dance reels of 3 on sides (1s in & down to start)
25-32::
    2s+1s+3s set & circle 6H round to left', 0);
INSERT INTO 'dancecrib' VALUES (12074, '2019-08-30 09:53:58.557403+00', '2023-02-04 01:19:14.470399+00', 1234, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s  dance RH across & LH across
9-16::
    1s & 4s cross RH, cast down/up 1 place (2s+3s step up/down 11-12);
    1s+4s circle 4H round to left
17-24::
    1s+2s also 3s+4s circle 4H round to right; 2s & 3s  cast down/up 1
    place & cross RH (1s+4s step up/down 23-24) End (1)(2)(3)(4)
25-32::
    1s followed by 2s+3s+4s cast off on opp sides; 1s 1/2 turn 2H to own
    side & make arch & 2s+3s+4s dance up under & cross to own sides. 2 3
    4 1', 0);
INSERT INTO 'dancecrib' VALUES (8561, '2015-02-13 12:47:34.567049+00', '2023-02-04 01:19:14.496849+00', 15578, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s also 3s+4s dance RH across & LH back
9-16::
    All set advancing & turn partners 2H, 1s+2s also 3s+4s circle 4H
    round to left
17-24::
    1L followed by 2L+3L+4L dance up & across then cast to weave in &
    out to end 2L+1L between 3M+4M & 4L+3L between 1M+2M & all Ladies
    cross to own side
25-32::
    Men repeat bars 17-24 all finishing 4s 3s 2s 1s

{{title}}
Reel

1-8::
    1s set with HS or PdB twice, turn partner twice with elbow grip
9-16::
    4s+3s+2s+1s dance reflection reels of 4 (Ladies give LSh to start,
    Men RSh)
17-24::
    4s (in 1st place) & 2s (in 3rd place) set & turn partners 2H (PdB),
    4s cast to 3rd place _while_ 2s lead up nearer hands joined to 1st
    place
25-32::
    2s+3s also 4s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4714, '2013-08-21 08:30:53.845453+00', '2023-02-04 01:19:14.513155+00', 1235, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    1s & 4s cross RH & cast in 1 place, 2s+1s also 4s+3s dance 1/2 R&L
9-16::
    1s & 4s pass RSh & dance 1/2 reel of 3 with 2M/3M, 1s & 4s pass LSh
    & dance 1/2 reel of 3 with 2L/3L ending 2s at top, 3s at bottom &
    1s+4s in line in centre (Ladies BtoB)
17-24::
    1s+4s set & 1/2 turn partners RH & dance 1/2 reel of 4
25-32::
    4L also 1L followed by partners dance out ends round to right to
    dance Tandem reels of 3 across with end couples & end 2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (8310, '2014-07-29 12:58:51.67288+00', '2023-02-04 01:19:14.542892+00', 15067, 3, NULL, 'ace', '{{explanation}}
5 Couple square set - 5s facing, 5M with back to 4s, 5L with back to 2s

1-4::
    5s dance up around 1st place (5L passing 1M LSh, 5M passing 1L RSh)
    meet, dance in finishing BtoB 5L facing down, 5M facing up _while_
    other dancers advance 2 steps, retire (2 small steps) on diagonal
    with corners
5-8::
    5M+1s, 5L+3s set as in ''DoubleTriangles'', pivot 1/4 to Right to set
    5M+2s, 5L+4s _while_ other couples set to partners (all setting 4
    bars)
9-12::
    5M+2s and 5L+4s dance RH across. 2s and 4s finish in original places
13-16::
    5s turn LH 1.1/4 to finish 5L facing 3s, 5M facing 1s
17-20::
    5M+1s and 5L +3s dance RH across. 1s and 3s finish in original
    places
21-24::
    5s turn LH to finish facing 1s (5L on 5M''s right)
25-32::
    5s+1s change places passing RSh, couples dancing in tandem with Man
    leading (2 bars)
::
    1s+4s repeat, 4s+3s repeat, 3s+2s repeat, finish with 2s in middle
    facing up', 0);
INSERT INTO 'dancecrib' VALUES (4715, '2013-08-21 08:30:53.85373+00', '2023-02-04 01:19:14.574573+00', 1237, 3, NULL, 'ace', '1-8::
    1L cross below 2M & casts up to 1M place _while_ 1M crosses & casts
    to 2L place, 1s cross LH, cast (L up & M down) & in to face 2s in
    line across
9-16::
    1s+2s (facing opposite partners) dance reel of 4 across
17-24::
    1s+2s set, 2s set again _while_ 1s petronella turn into middle &
    1s+2s dance LH across ending on own sides 1L+2L & 2M+1M
25-32::
    1s+2s cross (Ladies pass between Men), Ladies change places RH, turn
    inward & cross back to own side (order 2 1) & 2s turn RH as 1s turn
    LH', 0);
INSERT INTO 'dancecrib' VALUES (12462, '2020-01-02 06:59:12.072386+00', '2023-02-04 01:19:14.627478+00', 12829, 3, NULL, 'ace', '1-8::
    1M+2L+3M dance reel of 3 in centre of set (1M+2L pass RSh)
9-16::
    1L+2M+3L dance reel of 3 (1L+2M pass LSh). Bar 16 1M & 2L step in to
    join 2H with partner
17-24::
    1s+2s dance Poussette. Bars 23-24 1M pulls back LSh, 1L RSh to end
    BtoB
25-28::
    2s+1s+3s set (as Double Triangles), 1s pull back RSh, dance out to
    2nd place own side (2 PdeB) _while_ 2s & 3s set
29-32::
    2s+1s+3s turn partners RH.  2 1 3

{{explanation}}
Note: Repeats 2, 4, & 6 Bars 29-32:- 3s turn RH (4 bars) while 1s turn RH (2 bars) & cast while 4s turn RH (2 bars) & dance up to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (4718, '2013-08-21 08:30:53.880306+00', '2023-02-04 01:19:14.694996+00', 8653, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link; 2M+1M also 1L+3L Set+Link
9-16::
    1s+2s+3s dance R&L for 3 couples
17-24::
    1s set, set advancing to face 4th corners (pstn), dance 1/2 RSh reel
    of 4 with corners & 1s end passing RSh to face out opposite sides
25-32::
    1s dance RSh round 1st corners (pstn) into centre _while_ 2s+3s set
    & change places RH on sides, 1s turn RH to 2nd place own sides. 2 13', 0);
INSERT INTO 'dancecrib' VALUES (4713, '2013-08-21 08:30:53.739555+00', '2023-02-04 01:22:05.496866+00', 5520, 3, NULL, 'ace', '1-8::
    1M turns 2L with 2H then turns partner 2H
9-16::
    1L sets twice to 2M then turns partner 2H
17-24::
    1M+2L change places RH, 1L+2M change places RH
25-32::
    2s+1s Retire+Advance 2 steps then cross RH to own sides, 1s dance up
    & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (4716, '2013-08-21 08:30:53.862052+00', '2023-02-17 13:10:44.467511+00', 1238, 3, NULL, 'ace', '1-8::

    1s+2s set, 2s cast up & 1s cross down, turn 2nd corner LH & pass LSh

    to face 1st corners (2nd corners keep dancing)

9-20::

    Dance to Corners & Set: (12 bars) -Couple in middle change places

    with corners passing RSh, corners pass RSh in middle with a 1/4 turn

    to right to face next corner _while_ supporting corners set (2

    bars).  Repeat 5 more times to end with corners in diagonally

    opposite place and 1s end in middle facing partner

21-24::

    1s pass RSh & dance out through 2nd place (own side) then round 3rd

    corner into centre facing partner''s side _while_ 2s & 3s set

    advancing diagonally & dance 1/2 RH across to end in own places

    facing out

25-32::

    1s dance LSh reels of 3 across (Man with 2s) & 1M+2M also 1L+3L turn

    RH to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14267, '2021-08-28 04:19:18.443943+00', '2022-12-04 13:58:48.831388+00', 20404, 1, 202, 'ace', '1--::

  1c+3c NHJ set advancing | RHA to places | set (1,2,3,4)

9--::

  2c+4c repeat [1-8] (1,2,3,4)

17--::

  All NHJ A&R, all W turning under P''s arm and face out ; 4 bars of Schiehallion Reels (2,3,4,1)

25--::

  Circle8 and back (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (3896, '2013-08-21 08:30:38.718283+00', '2023-02-04 01:18:18.018546+00', 7332, 3, NULL, 'ace', '1-4::
    1L dances 1/2 reel of 3 across with 2s (passing 2M RSh)
5-8::
    1L dances 1/2 reel of 3 with 3s as 1M dances 1/2 reel of 3 with 2s
    (passing 3L/2M LSh)
9-12::
    1L dances 1/2 reel of 3 with 4s as 1M dances 1/2 reel of 3 with 3s
    (passing 4M/3L RSh)
13-16::
    1s in prom hold dance 1/2 reel of 3 with 4s (LSh to 4M)
17-24::
    1s cast up behind 4s (own side), dance between 3s & cast up round 2s
    & in to face 2s+3s opp sides
25-28::
    1M dances LH across with 2L+3L as 1L dances RH across with 2M+3M
29-32::
    1M dances RH across with 3M+4M as 1L dances LH across with 3L+4L to
    end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14279, '2021-09-08 00:18:17.967095+00', '2023-02-04 01:18:18.043487+00', 20443, 3, NULL, 'ace', '1-8::
    1s set, cross RH;  cast to 2nd place opp side & turn RH to face 1st
    corners (2s step up 7-8)
9-16::
    1s dance Corner Pass+1/2 Turn & Twirl with 1st corners, pass RSh &
    repeat with 2nd corners (as Corner Pass+Turn but corners only 1/2
    turn RH then pull back RSh & dance out to opp corner).  End (3) (1)
    (2)
17-24::
    3s+1s+2s Set+Link for 3 twice
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13979, '2021-05-03 00:18:17.846445+00', '2023-02-04 01:18:18.19033+00', 19495, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s followed by 2s (dance up sides to start) lead down (3
    bars), 2s+1s lead back up, 2s to 1st place, 1s to 2nd place
9-16::
    2s+1s+3s set, 1s Petronella turn to lines of 3 across (1L between
    2s, 1M between 3s); all set, 1s Petronella turn to face 1st corners
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & cross RH to own
    side 2nd place
25-32::
    1s+2s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4719, '2013-08-21 08:30:53.896624+00', '2023-02-04 01:19:14.845302+00', 1244, 3, NULL, 'ace', '1-8::
    1L+3M turn RH, dance round partner RSh to turn each other again RH
    ending in middle holding RH & partners LH
9-16::
    1s+3s Bal-in-Line, 1L+3M turn partners LH into the middle &
    Bal-in-Line again, turn partner LH to original pstns
17-24::
    1s+3s dance R&L
25-32::
    1s+3s dance Ladies'' Chain
33-40::
    All turn corners RH retaining hold & hold partners LH to form a
    circle (men facing out), all set & turn partner LH (4 bars) into
    prom hold
41-48::
    All dance round anticlockwise in prom hold to original pstns
::
    Repeat with 2L+4M, 3L+1M, 4L+2M', 0);
INSERT INTO 'dancecrib' VALUES (4720, '2013-08-21 08:30:53.904732+00', '2023-02-04 01:19:14.858159+00', 7369, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s, 1L+2M turn 1.1/2 times RH _while_
    1M+2L turn 1.1/2 times LH 1s end 2nd place facing out
9-16::
    1s dance 1/2 Fig of 8 round 2s (1s casting to start), 2L+1L turn
    1.1/2 times LH _while_ 2M+1M turn 1.1/2 times RH back to original
    places
17-24::
    1s lead down the middle & back to top for Allemande
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (9182, '2016-06-16 22:41:38.052546+00', '2023-02-04 01:19:14.869902+00', 13861, 3, NULL, 'ace', '1-8::
    1s+3s set, cast (2s+4s step up). 1s+3s dance 1/2 Fig 8 round couple
    above
9-16::
    Reels of 4 on sides, Ladies RSh, Men LSh:
::
    Bar 9:  1s+3s cross up 1 place (from 2nd/4th places) to dance reel
    on opp sides
::
    Bar 13: 4s+2s cross up 1 place (from 2nd/4th places) to dance reel
    on opp sides     (2) 1 (4)  3
17-20::
    All set.  2s+1s dance 1/2 RH across as 4s+3s dance 1/2 LH across.
    1M+3L face out
21-24::
    1M followed by partner casts down round 2L to 3rd place own sides as
    3L followed by partner cast up round 2M to 1st place own sides
25-32::
    3s+2s Set & Rotate as 1s+4s Reverse Set & Rotate (set, pull back
    LSh, cast anticlockwise, change places LH on side, chase
    anticlockwise 1 place) 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8311, '2014-07-29 12:58:51.752798+00', '2023-02-04 01:19:15.103026+00', 15427, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All circle 4H round and back
9-16::
    All Advance, Clap 4 times, Retire, Stamp 4 times
17-24::
    All dance RH Across, LH back
25-32::
    All set twice, clockwise facing couples make arch & all dance
    on/through to meet new couple', 0);
INSERT INTO 'dancecrib' VALUES (4725, '2013-08-21 08:30:53.949765+00', '2023-02-04 01:19:15.13741+00', 1251, 3, NULL, 'ace', '1-8::
    All circle 8H round & back. Ladies join NH, Men join NH
9-16::
    The Crescent:
::
    _9-12_    4L leads other Ladies up Men''s side _while_ 4M leads Men
    up Ladies'' side. Men dance outside Ladies'' crescent.  All on opp
    sidelines.
::
    _13-16_  All set & 1/2 turn partner RH to finish in middles ready
    for …
17-24::
    All dance Allemande
25-32::
    The Doorways & Gateways:
::
    _25-28_   1L+2L NHJ also 3L+4L NHJ dance between partners & cast
    behind partners & dance back to places
::
    _29-32_   1M+2M dance similar but going out partners to start, then
    between partners back to places.
::
    Bar 32  1M & 3M turn right about, 2M & 4M turn left about
33-40::
    1s cross RH, cast 1 place, cross down below 3s & cast to 4th place.
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4726, '2013-08-21 08:30:53.957813+00', '2023-02-04 01:19:15.147859+00', 11187, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 3rd place, 2s+3s+1s set & 1/2 turn RH to face
    down
9-16::
    2s+3s+1s dance Allemande (down) to end 1 3 2 on opposite sides
17-24::
    1M followed by 3M+2M chase 1/2 way anticlockwise _while_ 1L followed
    by 3L+2L chase 1/2 way clockwise (inside Men), 1s dance up to top &
    cast to 2nd places
25-32::
    1s dance RH across (Lady with 2s & Man with 3s) & pass RSh to dance
    LH across with other couple', 0);
INSERT INTO 'dancecrib' VALUES (9051, '2015-11-30 09:00:27.473028+00', '2023-02-04 01:23:08.078097+00', 6997, 3, NULL, 'ace', '1-8::
    1s+2s set & dance 1/2 R&L (no polite turns), 2s cross RH & face down
    as 1s turn 3/4 RH to finish back to back in centre, 1M facing up &
    1L down
9-16::
    1s dance Double Triangles (up/down) & end 1s pulling back RSh to 2nd
    place own sides facing out
17-24::
    1s dance RSh Reels of 3 on own sides to end 1s in 2nd place facing
    out
25-32::
    1s dance out, cast round person on right into centre. 1s turn 1.1/4
    LH to end 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (14398, '2021-10-23 01:16:02.074523+00', '2022-12-04 17:35:00.18668+00', 20533, 1, 202, 'ace', '1--::

  All set | cross RH ; chase clw ½ (3,2,1)

9--::

  1c set | cross RH ; cast up (2c down) | cross RH (3,1,2)

17--::

  All set | cross LH ; chase cclw ½ (2,1,3)

25--::

  1c set | cross LH ; cast off (3c up) | cross LH (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (4730, '2013-08-21 08:30:53.995298+00', '2023-02-17 12:59:43.572754+00', 1261, 3, NULL, 'ace', '1-8::

    1L+2M turn RH 1.1/4 times to end with 1L in 2L place & 2M in 1M

    place facing out _while_ their partners set to each other & cast

    down/up to face partner, 2s & 1s turn LH on sides

9-16::

    2s & 1s repeat back to place (1M & 2L turning to start)

17-24::

    1s+2s circle 4H round & back

25-32::

    1s cross RH, cast, dance 1/2 Fig of 8 ending in 2nd place _while_ 2s

    1/2 turn RH, dance up, cast 1 place & cross up to top place', 0);
INSERT INTO 'dancecrib' VALUES (4657, '2013-08-21 08:30:52.354153+00', '2023-02-04 01:19:10.542447+00', 1163, 3, NULL, 'ace', '1-8::
    1s dance 4 slip steps down middle, set to 3s, slip step back to top
    & cast 1 place
9-16::
    2s repeat above Fig
17-24::
    1s dance down 1 place (2s up), 2s+1s circle 4H round to left & 1s
    dance up to top (2s down)
25-32::
    1s set, cast to 2nd place & 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4727, '2013-08-21 08:30:53.969577+00', '2023-02-04 01:19:15.170815+00', 1252, 3, NULL, 'ace', '1-4::
    1s+2s cross Ladies dancing between Men, turning away from each other
    dance into centre to meet partner (1s facing down & 2s up)
5-8::
    1s dance down between 2s & turn LH to face 1st corners _while_ 2s
    dance up & cross LH to own sides
9-16::
    1s set & turn 1st corners 2H, 1L dances 1/2 reel of 3 with 2s as 1M
    dances with 3s 1s end facing 1st corners who are on opposite sides
17-24::
    1s set & turn 2nd corners 2H, 1M dances 1/2 reel of 3 with 3s (at
    top) to 2nd place opposite sides
25-32::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corners &
    cross RH to places', 0);
INSERT INTO 'dancecrib' VALUES (4728, '2013-08-21 08:30:53.977575+00', '2023-02-04 01:19:15.200678+00', 7650, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to face 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting & end BtoB Man facing up & Lady
    down
17-24::
    1s dance Double Triangles (up/down) & end facing 2nd corners
25-32::
    1s dance RSh reel of 3 on opposite sides giving RSh to 2nd corners &
    cross RH to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (14368, '2021-10-11 22:39:18.187915+00', '2023-02-04 01:19:15.218265+00', 20498, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance down below 3s, cast up to 2nd
    place in centre, 2s+3s step in, all taking prom hold facing up ready
    for …
9-16::
    2s+1s+3s dance 6 bars of Allemande, all in centre facing up set
    twice (option - Men turning Ladies under right arm or own choice)
17-24::
    3s+1s+2s dance up & cast to end 2 1 3; all turn partner RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14418, '2021-11-06 01:10:27.663883+00', '2023-02-04 01:19:15.231573+00', 1259, 3, NULL, 'ace', '1-8::
    1s+2s dance 4H round, 1s cast & 2s lead up to top; 1s dance down NHJ
    between 3s & cast up to face 1st corners
9-16::
    1s set to 1st & 2nd corners & turn right about onto sides; 2s+1s+3s
    turn partners RH 1.1/2 to change places (2) 1 (3)
17-20::
    2s+1s+3s Adv+Ret for 1 step. 1s RH turn to face up _while_ 2s+3s
    cross RH
21-24::
    1s lead up to top, cross & cast to meet facing down.
25-32::
    1s dance mirror reels of 3 on the sides (6 bars) (1s down between 3s
    to start). 1s cross back to 2nd place own sides _while_ 2s+3s end
    reels with loops', 0);
INSERT INTO 'dancecrib' VALUES (10828, '2018-06-11 00:36:05.007007+00', '2023-02-04 01:19:15.389922+00', 1264, 3, NULL, 'ace', '1-8::
    1s followed by 2s lead down to 3rd/2nd place _while_ 3s dance up
    sides to 1st place.  3s+2s+1s dance 1/2 reflection reel of 3 on
    sides (1s out/up, 2s in down)
9-16::
    1s+2s dance 1/2 RH across, cross RH and turn partners RH
17-24::
    2s+1s+3s set, dance DoSiDo, set
25-32::
    2s+1s+3s circle 6H once round to Left', 0);
INSERT INTO 'dancecrib' VALUES (4731, '2013-08-21 08:30:54.005095+00', '2023-02-04 01:19:15.402344+00', 11771, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, dance down between 3s & cast up to 2nd place
    own sides
9-16::
    1s dance 1/2 reels of 3 across (Lady with 2s & Man with 3s) into 1/2
    reel of 3 on opposite sides  (3)(1)(2)
17-24::
    1s dance RH across (1M with 3s at top & 1L with 2s) & end facing 3rd
    crnr (pstn), 1s dance 1/2 diag RSh reel of 4 & pass RSh to face 4th
    crnr (pstn)
25-32::
    1s dance 1/2 diag reel with 4th corners & end in 2nd place own side,
    1s dance RH across (1L with 2s at top & 1M with 3s)
33-40::
    2s+1s+3s circle 6H round to left for 6 steps, pivot & chase back to
    places', 0);
INSERT INTO 'dancecrib' VALUES (4732, '2013-08-21 08:30:54.013063+00', '2023-02-04 01:19:15.412569+00', 10158, 3, NULL, 'ace', '1-8::
    Top 3 Men turn bottom 3 Ladies RH, top 3 Ladies turn bottom 3 Men RH
9-16::
    2s+3s 1/2 turn partner, twirl to opposite side & turn corner with
    nearest hand 1.1/2 times.  (2) 1 4 (3)
17-24::
    2s & 3s petronella turn twice to own sides & all turn partners RH
25-32::
    1s+4s set & dance RH across 1/2 way, set & cross RH to own side', 0);
INSERT INTO 'dancecrib' VALUES (4733, '2013-08-21 08:30:54.021154+00', '2023-02-04 01:19:15.422548+00', 10943, 3, NULL, 'ace', '1-8::
    1M, 2L, 3M & 4L cross & pass partner RSh & cast to right 1 place,
    1s+2s also 3s+4s dance RH across
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1L, 2M, 3L & 4M dance down/up behind partner & cross, set to
    partners & cross RH.  2 1 4 3
25-32::
    1s+4s dance 1/2 Figs of 8 round end couples, 4s followed by 1s cross
    down between 3 & cast up to 2nd & 3rd places.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14515, '2022-01-10 02:18:48.492305+00', '2023-02-04 01:19:15.433272+00', 17582, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp side

1-8::
    1s+4s dance RH across (2s & 3s step up/down), 2s+1s & 4s+3s face on
    sides; all set, 2s+1s & 4s+3s change places RH. 1 2 (3) (4)
9-16::
    1s+4s chase clockwise 1/2 round _while_ 2s+3s dance LH across; 2s &
    3s dance out of ends & cast back to place. 4 2 (3) (1)
17-24::
    All set on sides; 4s+2s (at top) also 3s+1s (at bottom) dance 3/4
    R&L (6 bars - no polite turn). 2 4 (1) (3)
25-32::
    2s+4s+1s+3s circle 8H round & back. 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (4734, '2013-08-21 08:30:54.029182+00', '2023-02-04 01:19:15.443549+00', 10944, 3, NULL, 'ace', '1-8::
    1s dance down round 4s, cast back to places & 1/2 turn 2H to face
    down _while_ 2s stand for 2 bars & dance down round 4s & cast to
    place _while_ 3s stand for 4 bars & dance down round 4s & cast to
    place _while_ 4s stand for 6 bars & 1/2 turn 2H to face up [similar
    to »square set«]
9-16::
    All circle 8H round & back. Finish as at end of bar 8
17-24::
    1M+2L & 3M+4L turn LH 1.1/4 times _while_ 1L+2M & 3L+4M turn RH
    1.1/4 times [all now on sides 2 (1)(4) 3], 1s+4s dance 1/2 R&L to
    end 2 4 1 3
25-32::
    2s+4s also 1s+3s dance RH across, 4s+1s dance LH across', 0);
INSERT INTO 'dancecrib' VALUES (4735, '2013-08-21 08:30:54.03907+00', '2023-02-04 01:19:15.455925+00', 13807, 3, NULL, 'ace', '1-8::
    1s set & cross down RH below 3s (2s step up 3-4), cast up around 3s
    & dance up middle NHJ
9-16::
    1s dance reflection reels of 3 on opposite sides (1s dance up
    between 2s to start) & end in 2nd place opposite sides
17-24::
    1s cross up RH & dance round 2s to end 2nd place own sides & turn RH
    (or Tulloch turn / birl)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4737, '2013-08-21 08:30:54.065921+00', '2023-02-04 01:19:15.564896+00', 14637, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s petronella turn & set _while_ corners
    set & change places RH on sides
9-16::
    1s dance reels of 3 across (1M with 2s, 1L with 3s) giving LSh to
    2nd corner pstns ending with 1s petronella turn to 2nd place own
    sides.  3 1 2
17-24::
    1s 3/4 turn RH, 1s petronella turn to 2nd place opposite side & set
    _while_ corners set & cross RH.  (3)(1)(2)
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corner pstns
    & cross RH _while_ corners cross RH.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (8992, '2015-11-30 08:59:36.18159+00', '2023-02-04 01:19:15.575692+00', 10909, 3, NULL, 'ace', '1-8::
    1s lead down, cast up round 4s & back to place
9-16::
    1s+3s lead down (3 steps), lead up & cast, 1s to 2nd place, 3s to
    4th place
17-24::
    2s+1s also 4s+3s dance R&L
25-32::
    1s turn RH, cast to 4th place as 3s turn RH & dance up to 2nd place.
    All turn partners 2H (4 bars)', 0);
INSERT INTO 'dancecrib' VALUES (11693, '2019-03-18 21:01:56.460592+00', '2023-02-04 01:19:15.696817+00', 17473, 3, NULL, 'ace', '1-8::
    1s set & cast one place (2s step up 3-4). 1s 3/4 turn LH to 1M
    facing 2s and 1L facing 3s and Balance-in-Line
9-16::
    1M+2s & 1L+3s dance RSh reels of 3 across. On bars 15-16 1s 3/4 turn
    RH to 1L between 2s & 1M between 3s.
17-24::
    Repeat reels & on bars 23-24 1s 1/2 turn LH to finish facing down in
    middle of set, _while_ 2s face down & 3s face up
25-32::
    1s lead down between 3s & cast up one place, 1s dance up between 2s
    and cast to 2nd place _while_ 2s + 3s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4739, '2013-08-21 08:30:54.184645+00', '2023-02-04 01:19:15.70936+00', 11749, 3, NULL, 'ace', '1-8::
    1s+3s dance RH across 1/2 way, 1/2 turn partners RH & 1M leads his
    partner up behind 2M to end in 1st places (opposite sides) _while_
    3L leads her partner down behind 2L to end in 3rd place opposite
    sides
9-16::
    1s+3s repeat (from opposite sides) ending in original places
17-24::
    1s+2s+3s dance RSh reels of 3 (6 bars) & 1s+2s change places RH on
    sides
25-32::
    2s+1s+3s set twice & turn partners RH
33-40::
    2s+1s+3s circle 6H round to left for 6 steps, pivot left & chase
    back to places.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4743, '2013-08-21 08:30:54.226903+00', '2023-02-04 01:19:15.871466+00', 1283, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, lead down below 3s & cast back to 2nd place
9-16::
    2s+1s dance R&L
17-24::
    1s dance reels of 3 across (1L with 2s & 1M with 3s) 1s end in
    centre facing Ladies'' side
25-32::
    1s dance out between 2L+3L & cast (Man up & Lady down), dance Figs
    of 8 (1M round 2s & 1L round 3s) ending in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (10329, '2017-12-22 15:44:06.736489+00', '2023-02-04 01:19:16.062496+00', 15237, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up).  1s Petronella turn into lines of 3
    across (1L between 2s, 1M between 3s).  All set
9-16::
    1L+2M+3M also 1M+2L+3L dance RH across.  1s turn LH to 2nd place own
    sides & all set
17-24::
    1s followed by 2s dance down, cast up round 3s, dance up to top & 1s
    cast to face 1st corners _while_ 2s end in 1st place
25-32::
    1s dance Corner Pass+Turn with 1st corners, dance Corner Pass+Turn
    with 2nd corners.  1s pass RSh to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4746, '2013-08-21 08:30:54.254538+00', '2023-02-04 01:19:16.10162+00', 8732, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, dance petronella turns to end 1L between 2s
    facing down & 1M between 3s facing up & set
9-16::
    1s turn to right & dance RSh reels of 3 across Lady with 2s & Man
    with 3s, 1s turn LH ready to reel with other couple
17-24::
    1s dance RSh reels of 3 across Lady with 3s & Man with 2s ending
    with 1M between 2s facing down & 1L between 3s facing up
25-32::
    1s set adv passing RSh to face 1st crnrs, turn RH & end 1L between
    2s facing down & 1M b''tw''n 3s facing up, 1s set adv to 2nd crnrs &
    turn LH to end facing 1st crnrs
33-40::
    1s set to 1st corners, set to 2nd corners to end 2nd place opposite
    sides, 1s turn RH 1.1/2 times to own sides', 0);
INSERT INTO 'dancecrib' VALUES (4747, '2013-08-21 08:30:54.263502+00', '2023-02-04 01:19:16.136264+00', 1288, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L cross & dance down behind Men & dance up centre
    with ''new'' partner in prom hold
9-16::
    Top persons dance out & down into reels of 3 on own sides
17-24::
    1L followed by 2L+3L cast, dance down own side to face own partner &
    all 4 couples turn RH
25-32::
    3s+2s also 1s+4s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (4748, '2013-08-21 08:30:54.269154+00', '2023-02-04 01:19:16.158078+00', 10478, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH & 1s+2s set, 1s+2s Set+Link.  2(1)3
9-16::
    1s 1/2 turn RH & 1s+3s set, 1s+3s Set+Link.  2 3 1
17-24::
    1s turn RH & cast up 1 place, cross passing RSh & twirl to opposite
    side
25-32::
    1s cast round 1st corner into middle, twirl to dance out same end &
    cast to right round 4th corner pstn _while_  2L+3L also 2M+3M dance
    RSh round each other 1/2 way & twirl out to change places', 1);
INSERT INTO 'dancecrib' VALUES (12538, '2020-02-02 02:47:20.410848+00', '2023-02-04 01:19:16.479621+00', 13899, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across; 1s+2s dance LH across
9-16::
    LSh reels of 3 on sides (1s LSh to 2s). At end 1M+2M also 1L+2L pass
    LSh, 1s face down, 3s face up. 2 1 3
17-24::
    Grand Chain (2s cross, 1s+3s change places on sides to start)
25-32::
    1s turn 3/4 RH _while_ 2s & 3s cross LH with partner, 1L+2s also
    1M+3s dance LH across [now (2) (1) (3)], all cross LH to own sides.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12386, '2019-12-05 01:29:17.865332+00', '2023-02-04 01:19:16.506732+00', 17533, 3, NULL, 'ace', '1-8::
    1s dance in & cast, 2s+1s+3s turn 2H
9-16::
    1s petronella turn into lines across & all set, 1s petronella turn
    into 2nd place opp sides & all set 2 (1) 3
17-24::
    Reels of 3 on sides
::
    Start:  1s cross down to 3rd place & dance out & up, 2s dance out &
    down, 3s dance out & up (giving hands where possible)
::
    End:  1s +3s continue the reel one more place, 2s+1s curve into
    place to finish 2 3 1
25-32::
    2s+3s+1s circle 6H round & back.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13738, '2021-03-02 01:19:15.412349+00', '2023-02-04 01:19:16.627394+00', 12358, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reels of 3 on own sides
17-24::
    1s cross RH, cast to 2nd place (2s step up 19-20), 1s cross LH &
    cast to 3rd place (3s step up 23-24) 2 3 1
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4752, '2013-08-21 08:30:54.302809+00', '2023-02-04 01:19:16.644383+00', 1299, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s+2s+3s set, cross RH, set & turn RH into prom hold facing up
17-24::
    1s+2s+3s dance Promenade with 1s casting to 2nd place & 2s leading
    up in last bar
25-32::
    2s+1s dance double Fig of 8 (2s casting to start)
33-40::
    1s+3s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4753, '2013-08-21 08:30:54.311026+00', '2023-02-04 01:19:16.656328+00', 10308, 3, NULL, 'ace', '1-8::
    1s cross, cast 1 pl, Man dances down between 3s & round 3M to face
    1st corner _while_ Lady dances up between 2s & round 2L to face her
    1st crnr
9-16::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners ending with Man facing 2s & Lady
    facing 3s
17-24::
    1s dance Double Triangles (up/down) with corners dancing 1 place
    clockwise after each setting, 1s end BtoB facing 3rd crnrs (1st crnr
    person)
25-32::
    1s dance 1/2 diagonal reel of 4 with 3rd corners & 1/2 reel with 4th
    corners', 0);
INSERT INTO 'dancecrib' VALUES (4754, '2013-08-21 08:30:54.3248+00', '2023-02-04 01:19:16.840959+00', 1304, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All turn opposite partner RH, all turn own partner LH into prom hold
    (Men on inside facing anticlockwise)
9-16::
    Both couples Promenade LSh round each other to original places
17-24::
    Both couples dance Ladies'' Chain
25-32::
    All Adv+Ret, all advance 3 steps passing opposite partner by RSh &
    retire 1 step', 0);
INSERT INTO 'dancecrib' VALUES (4755, '2013-08-21 08:30:54.33297+00', '2023-02-04 01:19:16.856619+00', 10770, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s+3s+4s dance 1/2 reels of 3 on sides
    (1s in & down to start).  2 4 3 1
9-16::
    1s cross RH & cast up 1 place, 2s+4s+1s dance 1/2 reels of 3 on
    sides (2s in & down to start).  1 4 2 3
17-24::
    1s lead down the middle & back
25-32::
    1s+4s dance Allemande.  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (4756, '2013-08-21 08:30:54.342928+00', '2023-02-04 01:19:16.873256+00', 10305, 3, NULL, 'ace', '1-8::
    2s dance 1/2 Fig of 8 (Lady round 1s & Man round 3s) _while_ 1s & 3s
    set & cross RH, 2s 1/2 reels of 3 on opp sides (2L RSh to 3L & 2M
    RSh to 1M)
9-16::
    1s dance 1/2 Fig of 8 (Man round 2s & Lady round 4s) _while_ 2s & 4s
    set & cross RH, 1s 1/2 reel of 3 on own sides (1L RSh to 2L & 1M RSh
    to 4L)
17-24::
    3L+4L also 3M+4M turn RH _while_ 1s set & cross RH, 3s+4s+1s chase
    clockwise 1/2 way ending on own sides (2s stand for 8 bars).  1 4 3
    2
25-28::
    1s & 2s cross RH _while_ 3s & 4s dance 1/2 RH across, 1s+3s also
    4s+2s change places on sides LH,
29-32::
    3s & 4s cross RH _while_ 1s & 2s dance 1/2 RH across, 3s+2s also
    1s+4s change places on sides LH (Bars 25-32: 1/2 "Trip to Bavaria"
    Figure)', 0);
INSERT INTO 'dancecrib' VALUES (10062, '2017-09-03 23:44:26.950398+00', '2023-02-04 01:19:16.892309+00', 17900, 3, NULL, 'ace', '1-8::
    1M+2L Adv+Ret.  1M+2L dance DoSiDo
9-16::
    1L+2M repeat bars 1-8
17-24::
    1s cross RH, cast (2s step up 19-20).  2s cross RH cast (1s step up
    23-24)
25-32::
    1s+2s Adv+Ret.  1s+2s dance 1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (8694, '2015-03-03 08:47:25.927189+00', '2023-02-04 01:19:16.909625+00', 15275, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig 8 round 2s, then 1/2 Fig 8 round 3s.  1s finish in
    2nd place own sides (2s step up bars 7-8)
9-16::
    2s+1s+3s dance RSh round partner, dance out to own sides & all chase
    clockwise 1/2 way round to (3) (1) (2)
17-24::
    1s dance RH across (1L+2s in 3rd place, 1M+3s in 1st place).  1s
    swap ends to dance LH across with other couple
25-32::
    2s+1s+3s chase anticlockwise 1/2 way round, all dance round partner
    LSh & dance out to own sides   2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4759, '2013-08-21 08:30:54.732733+00', '2023-02-04 01:19:17.725267+00', 8569, 3, NULL, 'ace', '1-8::
    1M dances 1/2 LSh reel of 3 with 2s. 1M dances RSh 1/2 reel with 3s
    _while_ 1L dances RSh 1/2 reel with 2s
9-16::
    1L dances LSh 1/2 reel of 3 with 3s ending below 3s on Men''s side
    _while_ 1M casts up Ladies'' side to top & crosses to own side, 1s
    cast round 2M/3M into middle BtoB (Man facing up)
17-24::
    1s dance Double Triangles (up/down), 1s ending with a petronella
    turn to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back
33-40::
    1s lead down between 3s & cast up to 2nd places, lead up between 2s
    & cast down to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4760, '2013-08-21 08:30:54.741091+00', '2023-02-04 01:19:17.759231+00', 13139, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 on own sides (1s in & down)
9-16::
    1s set & cast, cross RH & cast round 1st corners
17-24::
    1s dance 1/2 reels of 3 across (1L with 2s, 1M with 3s) end between
    2s/3s facing down/up in lines of 3 across, all Set+Link for 3
25-32::
    2s+1s+3s circle 6H round back', 0);
INSERT INTO 'dancecrib' VALUES (4764, '2013-08-21 08:30:54.859581+00', '2023-02-04 01:19:18.009009+00', 12630, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 R&L; 1L+2M also 3L+4M change places RH,
    1M+2L also 3M+4L change places LH
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1s set & cast 1 place (2s step up), 1s+3s circle 4H round to left
25-32::
    1s dance down between 3s & out behind 4s to 4th place (3s+4s step up
    27-28); all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (4766, '2013-08-21 08:30:54.881224+00', '2023-02-04 01:19:18.288188+00', 1318, 3, NULL, 'ace', '1-4::
    1s petronella into centre, 1s face each other give RH & dance down
    for 2 steps _while_ 2s+3s face each other on sides give RH & dance
    up 2 steps
5-8::
    All turn facing person RH, 2s+3s dance back to places as 1s cast on
    own sides to original places
9-16::
    All dance Grand Chain
17-24::
    1s+2s dance RH across 1/2 way, 1s+3s dance LH across 1/2 way, all
    set & cross RH. (2) (3) 1
25-28::
    1s dance down 1 step & cast up 1 place (on opp sides) & lead up
    between 2s & cast to 2nd place _while_ 3s lead down between 1s & 1/2
    turn RH. 2 (1) (3)
29-32::
    1s+3s circle 4H round 1/2 way to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4757, '2013-08-21 08:30:54.351079+00', '2023-02-17 12:30:53.279046+00', 1307, 3, NULL, 'ace', '1-8::

    1M+2L turn 2H 1.1/4 times & change places passing partner RSh, cross

    back to own place LH

9-16::

    1L+2M pass RSh to face each other (1L facing up & 2M down) _while_

    partners dance down/up to diamond formation, 1s+2s set, dance RH

    across to end in line of 4 across with 1M & 2L on own sides facing

    partners

17-24::

    1s & 2s turn partners RH, middle couple pass RSh & turn other person

    (Men LH & Ladies RH), middle couple pass LSh to face own partner

25-32::

    1s+2s dance reel of 4 across & end 1s turning 2s on sides to end 2 1', 0);
INSERT INTO 'dancecrib' VALUES (14824, '2022-05-09 18:53:14.385701+00', '2022-12-04 18:00:05.555066+00', 20769, 1, 1645, 'ace', 'Set of 7 dancers: 1,2,3 & 6,5,4 on sides with 7 in the centre facing up  

1...2...3  

....7....  

6...5...4  



1--4::

  1+2+3 & 6+5+4 &frac12; Reels3 on sides, 2 & 5 start up & out, 7 follows 5 in tandem

5--8::

  3+2+1 & 4+5+6 &frac12; Reels3 on sides, 2 & 5 start down & out, 7 follows 2 in tandem

9--12::

  1+2+3 & 6+5+4 S&Link to lines across _while_ 7 loops RSh round 1pos

13--16::

  3+5+4 & 1+2+6 S&Link to sides _while_ 7 pulls RSh back & loops RSh round 3pos to face up in centre (4,5,6,1,2,3,7)

17--20::

  7+4+5+6 dance 1&frac14; RHA ending with 6 in centre (7,4,5,1,2,3,6)

21--24::

  6+3+2+1 dance 1&frac14; LHA ending with 1 in centre (7,4,5,2,3,6,1)

25--28::

  7+1+2 &frac12; diag Reel3, 1 starts RSh to 7 (2,4,5,7,3,6,1)

29--32::

  6+1+5 &frac12; diag Reel3, 1 starts RSh to 6 (2,4,6,7,3,5,1)

33--36::

  3+1+4 &frac12; Reel3 across, 1 starts RSh to 3 (2,3,6,7,4,5,1)

37--40::

  3+1+4 Pass & Turn, 1 loops _LSh_ round 3 as 3+4 turn _LH_ & face out (2,3,6,7,4,5,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15275, '2022-12-04 21:51:02.429999+00', '2022-12-04 21:51:12.274654+00', 20937, 1, 1645, 'ace', '1--::

  1c+2c adv to P, clap & ret ; set to P | set turning R about on the spot

9--::

  1c cross down RH into &frac12; Fig8 round 2c | 1c+2c &frac12; R&L, ending in centre (2x,1)

17--::

  Joining H behind neighbours back, dance the Basket ending in same places

25--::

  2c cross down RH into &frac12; Fig8 round 1c | all turn P RH (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (15210, '2022-11-03 01:18:24.762921+00', '2023-02-04 01:18:28.53381+00', 21146, 3, NULL, 'ace', '1-8::
    1s set, cast below 3s, meet joining RH & lead up to 2nd place (2s
    step up 3-4)
9-16::
    2s+1s dance RH across; 1s+3s dance LH across, remaining in middle
    facing up (2s step in bars 16-17 & face up)
17-24::
    2s+1s+3s dance Promenade finishing on sides 2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8993, '2015-11-30 08:59:36.963079+00', '2023-02-04 01:19:18.312967+00', 16099, 3, NULL, 'ace', '1-8::
    1M+4L & 3M+2L dance 1/2 R&L.  1L+2M & 3L+4M dance 1/2 R&L
9-16::
    All turn partners RH & turn corners LH to face partners
17-24::
    1s+3s set to partners, petronella turn into line up/down set, Ladies
    BtoB facing partners.  1s+3s turn partners RH remaining in line in
    middle
25-32::
    2s+4s repeat bars 17-24 into line across set (couples are now in a
    cross-shaped figure)
33-40::
    All set to partners & change places RH, all set to partners & change
    places LH. Ladies face in
41-48::
    Ladies dance RH across & LH back to face partners _while_ Men dance
    anticlockwise round set through each place (straight line paths)
    back to places
49-52::
    Men dance behind partners LSh, dance in front of next lady in
    clockwise direction to end in corner positions (1M between 2nd+3rd
    place, 3M between  4th+1st place) _while_ Ladies Adv+Ret
53-56::
    Ladies dance out, cast to Left (round Man to Left) then diagonally
    across to face partner (Ladies BtoB) _while_ Men Adv+Ret
57-64::
    Ladies dance »Hello-Goodbye« setting, end facing partner _while_ Men
    set, dance 1 place clockwise to next corner, set to next Lady,
    repeat until meet own partners. (Men dance behind Ladies)
65-76::
    Interlocking reels of 4 on diagonals, passing partner RSh & LH
    across 1/2 way in middle
77-80::
    All take promenade hold with partners facing clockwise (Ladies on
    inside) & promenade 1/2 way round
81-88::
    All circle 8H round and back to original places', 0);
INSERT INTO 'dancecrib' VALUES (13985, '2021-05-03 00:19:05.373152+00', '2023-02-04 01:19:18.341629+00', 19971, 3, NULL, 'ace', '{{explanation}}
Devised for »social distancing« dancers - 1 couple with traffic cones representing 2nd & 3rd couple

1-8::
    1s set, cast & dance 1/2 Fig 8 up round 2s
9-16::
    1s dance Figs 8 on opp sides (1s dance in/down to start)
17-24::
    1s cross LH, cast down round 3s; 1s meet NHJ & dance up to top &
    cast round 2s to face 1st corners
25-32::
    1s dance »Hello-Goodbye« setting ending with Petronella turn to 2nd
    place own side

{{explanation}}
If dance as R4x32:  Bars 9-16  2s+1s+3s dance mirror reels of 3 on sides (1s in/down to start)', 0);
INSERT INTO 'dancecrib' VALUES (4767, '2013-08-21 08:30:54.889297+00', '2023-02-04 01:19:18.36625+00', 1319, 3, NULL, 'ace', '1-8::
    All dance Snowball Grand Chain for 4 couples: 1s cross RH, 1s+2s
    change places LH on sides, 2s cross RH as 1s+3s change places RH on
    sides, 2s+1s also 3s+4s change places LH on sides to end 3(2)4(1)
9-16::
    All dance LSh reels of 4 on sides
17-24::
    3s+2s also 4s+1s dance Ladies'' Chain
25-32::
    3s+2s also 4s+1s dance RH across; 2s cross up RH to 1st place
    _while_ 1s cross RH & 3s step down to 2nd place & 4s set.  All set.
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4768, '2013-08-21 08:30:54.899118+00', '2023-02-04 01:19:18.407044+00', 7654, 3, NULL, 'ace', '1-8::
    1s set advancing & 1/2 turn 2H, 1s cast 1 place & turn RH to prom
    hold facing 2L
9-16::
    1s dance reel of 3 with 2s (RSh to 2L to start) & end facing 3L
17-24::
    1s dance reel of 3 with 3s (LSh to 3L to start) & end BtoB facing
    own sides
25-32::
    1s dance Double Triangles
33-40::
    1s dance LH across (Man with 2s & Lady with 3s), pass LSh to dance
    RH across with other couple
41-48::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4769, '2013-08-21 08:30:54.983223+00', '2023-02-04 01:19:18.592364+00', 11511, 3, NULL, 'ace', '1-8::
    1s lead down the middle & up to top
9-16::
    1s cast 1 place, set, turn RH 1.1/2 times to face 3L in prom hold
17-24::
    1s dance 1/2 diagonal reel of 3 with 1st corners, face 2L for 1/2
    reel with 2nd corners & loop individually into 2nd place opposite
    sides
25-32::
    3s+1s+2s chase clockwise 1/2 way, all set advancing & turn partner
    2H', 0);
INSERT INTO 'dancecrib' VALUES (4770, '2013-08-21 08:30:54.991418+00', '2023-02-04 01:19:18.62345+00', 10889, 3, NULL, 'ace', '1-8::
    All set, 1s followed by 2s+3s+4s dance down the middle & cast back
    to places
9-16::
    All set, 1M & 4L 3/4 turn RH & cast up/down back to places _while_
    1L & 4M cast down/up to ends & turn 3/4 RH to places
17-24::
    All dance RSh reels of 4 on own sides
25-32::
    1L also 4M followed by partner cast in 1 place & cross to opposite
    sides, 1s+4s dance 1/2 R&L
33-40::
    All circle 8H round & back.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4772, '2013-08-21 08:30:55.007427+00', '2023-02-04 01:19:18.674656+00', 1323, 3, NULL, 'ace', '1-8::
    All set, turn 2H & 1s+2s also 3s+4s circle 4H round left
9-16::
    All circle 8H round & back
17-24::
    All set twice, turn 2H (1s+2s twice, 3s+4s 1.1/2 times)
25-32::
    All dance 2 couple Interlocking Allemandes:
::
    1s & 2s dance normal Allemande but end in 3rd/1st places _while_
    3s+4s Allemande (down) ending in 4th/2nd places then 1s & 3s cross
    passing RSh to own side to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4774, '2013-08-21 08:30:55.023226+00', '2023-02-04 01:19:18.710506+00', 10365, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 3 facing 3

1-8::
    All circle 6H round & back
9-16::
    Centre dancer dance reel of 3 with person on right & opposite person
17-24::
    Centre dancers dance RH across & LH back with same persons
25-32::
    All Adv+Ret & pass through to next 3', 0);
INSERT INTO 'dancecrib' VALUES (8312, '2014-07-29 12:58:52.693943+00', '2023-02-04 01:19:18.74503+00', 15041, 3, NULL, 'ace', '1-10::
    All dance 10 bar Snowball Chain:
::
    1s cross RH & change places LH on side with 2s
::
    1s change places RH with 3s _while_ 2s cross over RH
::
    1s cross LH _while_ 2s & 3s change places LH.
::
    1s change places RH with 2s _while_ 3s cross over RH. (3) 1 (2)
11-20::
    1s turn LH, 1s turn 3rd corners (pstns) RH, pass RSh,1s turn 4th
    corners (pstns) RH, pass RSh to face 1st corner (pstn)
21-24::
    1M dances RH across with 2s as 1L dances RH across with 3s
25-26::
    1s 1/2 turn LH
27-30::
    1M dances RH across with 3s as 1L dances RH across with 2s. 1s end
    2nd place opposite sides.
31-38::
    1s cross RH & cast to right as 3s & 2s set & cross RH, 1s cross RH
    up/down centre & cast to 2nd places as 3s & 2s set on sides & change
    places RH
39-40::
    All set', 0);
INSERT INTO 'dancecrib' VALUES (4775, '2013-08-21 08:30:55.031348+00', '2023-02-04 01:19:18.763752+00', 1329, 3, NULL, 'ace', '1-8::
    1s & 2s dance Chain Progression :
::
    1s+2s 3/4 turn RH, 1M+2L turn LH 1.1/2 times as ptnrs chase cl''wise
    1/2 way, 2s+1s turn RH to end on sides in order 2 1
9-16::
    1M casts up 1 place _while_ 1L casts down 1 place, 1s turn LH 1.1/2
    times to face 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting
25-32::
    1s dance reels of 3 across giving LSh to 1st corners', 0);
INSERT INTO 'dancecrib' VALUES (4796, '2013-08-21 08:30:55.217428+00', '2023-02-04 01:19:20.015297+00', 1364, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back
9-16::
    1s cross RH, cast 1 place, 1s turn RH 1.1/4 times to Lady between 2s
    & Man between 3s facing up
17-24::
    2s+1s+3s Adv+Ret, 1s turn RH 1.1/4 times to 2nd place own sides
25-32::
    2s+1s+3s Adv+Ret & dance DoSiDo', 0);
INSERT INTO 'dancecrib' VALUES (15276, '2022-12-04 22:30:10.390333+00', '2023-01-16 17:11:20.918209+00', 21191, 1, 1645, 'ace', '1--::

  1c+2c &frac12; turn P RH | &frac12; RHA ; 2c+1c LHA, 1c end in tandem, 1W leading, facing down on centre line in 3pl

9--::

  1c+3M RHA, 1c in tandem, 1W leading, face 2W ; 1c+2cnrs &frac12; LSh alternating tandem Reel3, 1c face down, 1M below 1W

17--::

  1c+3W LHA, 1c in tandem, 1M leading, face 2M ; 1c+1cnrs &frac12; RSh alternating tandem Reel3, 1c separate, 1W pulling RSh back, to 2plx (3x,1x,2x)

25--::

  *Cross & Rotate:* all cross RH | chase &frac14; clw to lines of 3 across ; change pl RH up/down | chase &frac14; clw (2,1,3)

', 5);
INSERT INTO 'dancecrib' VALUES (13023, '2020-08-10 00:18:17.055015+00', '2023-02-04 01:18:18.490494+00', 14439, 3, NULL, 'ace', '1-8::
    1s+5s dance Fig 8 on own sides (1s RSh to 2s, 5s RSh to 4s). 1L & 5M
    face out
9-16::
    1L followed by 1M casts & crosses to opp sides _while_ 5M followed
    by 5L casts up & crosses to opp side (2s & 4s step down/up 3-4); 1s
    & 5s turn partner RH, pull back RSh to end BtoB in centre facing opp
    sides
17-24::
    1s & 5s set as in Double Triangles, all set advancing pulling back
    RSh to invert triangle; All set as Double Triangles, all set
    advancing pulling back RSh (2s+3s+4s on own sides, 1s+5s in line of
    4 in centre facing partner, Men face down, Ladies face up)
25-32::
    1s+5s dance 1/2 reel of 4; turn partner RH to face down in prom hold
    (Man with Lady on Right)
33-40::
    5s+3s & 1s+4s dance RSh reels of 3 across (5s RSh to 3M, 1s RSh to
    4M). 5s+1s finish in centre NHJ facing down. 2 (5) 3 (1) 4
41-48::
    1s followed by 5s dance down for 4 bars (4s step up 43-44); 5s+1s
    1/2 turn partner RH (Lady dances under Man''s arm) to own side (3s+4s
    step up 45-46) 5s+1s dance up 3 bars to 2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (3902, '2013-08-21 08:30:38.791917+00', '2023-02-04 01:18:18.529065+00', 11543, 3, NULL, 'ace', '1-8::
    1s cross down RH (2s step up bars 1-2) & dance out behind 3s & up to
    2nd place opp sides; 2s+1s+3s dance 1/2 reel of 3 on sides (1s out &
    up to start)
9-16::
    3s+1s+2s dance Grand Chain
17-24::
    3s+1s+2s Set+Link for 3 (once), 1s turn RH 1.3/4 times to face 1st
    corner (pstn) _while_ 2s+3s chase clockwise 1/2 way
25-32::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh to dance
    1/2 reel with 2nd corners & pass RSh to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (11327, '2018-11-03 18:48:19.750378+00', '2023-02-04 01:18:18.579975+00', 14600, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig 8 round 2s; 1s cross RH, cast to 2nd place own side
    (2s step up 7-8)
9-16::
    1s+1st corners turn RH, 1s end facing them _while_ 2nd corners set &
    change places RH; 1s dance 1/2 diag reel of 4 with 1st corners, pass
    RSh to face 2nd corner (posn)
17-24::
    Repeat 9-16 with 2nd corners, passing RSh to 2nd place own side
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (4776, '2013-08-21 08:30:55.039685+00', '2023-02-04 01:19:18.779834+00', 1330, 3, NULL, 'ace', '1-10::
    1s cast to 2nd place, dance full Fig of 8 round 2s & end facing 1st
    corners
11-20::
    1s 1/2 turn corners RH, corners turn LH 1.1/2 times in middle as 1s
    chase cl''wise to opp crnr & 1/2 turn crnr RH, 1s turn ptnr LH to
    face 2nd crnr
21-30::
    1s repeat with 2nd corners end facing 3rd corners (1st corner
    person)
31-40::
    1s dance 1/2 diagonal reel of 4 with 3rd corners, 1/2 diagonal reel
    with 4th corners & 1s turn LH to 2nd place own side

{{explanation}}
2nd time 1s end in 3rd place & cast to 4th place as new 1s start  
Note:  original instructions state that 2s step up bars 9-10.  Commonly 2s step up bars 1-2', 0);
INSERT INTO 'dancecrib' VALUES (13884, '2021-04-05 00:19:08.80037+00', '2023-02-04 01:19:18.793397+00', 16878, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 1s+3s dance 3/4 Double Fig 8 round 2s (1s cast, 3s
    cross up to start).  3s curve into 1st place to face down at end
9-16::
    3s+2s+1s dance Grand Chain (1s cross, 2s+3s change places RH on side
    to start)
17-24::
    1s dance up, change sides (1M dances above partner & Lady dances
    under Man''s right arm), 1s dance down & cast up into 2nd place own
    side
25-32::
    1M+3s (at top) also 1L+2s dance LH across
::
    All dance »Snake Pass«:
::
    1M followed by 3s & 1L followed by 2s pass RSh diagonally across
    through 2nd place to change ends, loop round to right & dance
    up/down sides, 1s end in 2nd place own side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13885, '2021-04-05 00:19:08.826369+00', '2023-02-04 01:19:18.821403+00', 19479, 3, NULL, 'ace', '1-8::
    1s+2s set, pull back RSh & chase clockwise 1/2 round, cross RH & 1s
    face out
9-16::
    RSh reels of 3 on sides (1M out/up, 1L out/down to start).  1s end
    join LH with partner in centre, RH with 1st corner
17-24::
    1s+1st corners Bal-in-Line, 1s turn 1.1/4 LH to join RH with 2nd
    corner; Bal-in-Line with 2nd corners
25-32::
    1M+2s & 1L+3s dance LSh reels of 3 across (6 bars), 1s cross RH to
    2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4777, '2013-08-21 08:30:55.053031+00', '2023-02-04 01:19:18.846607+00', 1331, 3, NULL, 'ace', '1-8::
    All dance reels of 4 on the sides
9-16::
    1s+2s also 3s+4s dance RH across & LH back
17-24::
    1s set, cast; 1s+3s circle 4H to the left
25-32::
    1s set, lead up to 1st place, cast to 4th place
33-40::
    2s+3s also 4s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (13055, '2020-08-10 00:19:05.82733+00', '2023-02-04 01:19:18.867731+00', 10268, 3, NULL, 'ace', '1-8::
    1L crosses passing 1M LSh _while_ 1M sets pulling back LSh; 1L
    followed by 1M cast one place (2s step up 3-4); 1s+3s dance RH
    across. 1s end in centre facing up, 2s dance in on bar 8 ready for …
9-16::
    2s+1s dance allemande
17-24::
    1M crosses passing 1L RSh _while_ 1L sets pulling back RSh; 1M
    followed by 1L cast one place (2s step up 19-20); 1s+3s dance LH
    across
25-32::
    RSh reels of three on the sides, 1s pass 2s RSh to start.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4778, '2013-08-21 08:30:55.058682+00', '2023-02-04 01:19:18.889257+00', 9460, 3, NULL, 'ace', '1-8::
    1s set, 1s cast below 3s _while_ 2s set, 1s dance in to prom hold
    _while_ 2s cast & 3s set, 1s dance up to top _while_ 2s dance in &
    3s cast
9-16::
    1s+2s+3s Promenade
17-24::
    1s cast _while_ 2s dance to top, 1s cross between 3s _while_ 2s
    cast, 1s cast to top _while_ 2s cross between 3s, 1s cross _while_
    2s cast up
25-32::
    2s dance to top & cross _while_ 1s cast to 2nd place, 2s+1s dance RH
    across 1/2 way & chase (slowly) round to 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4779, '2013-08-21 08:30:55.064387+00', '2023-02-04 01:19:18.911225+00', 9461, 3, NULL, 'ace', '1-8::
    1s set, cross down to below 3rd place, cast up to 2nd place & lead
    up to 1st place (opposite sides) _while_ 2s stand for 2 bars, set,
    cross down to below 3rd place & cast up to 2nd place _while_ 3s
    stand for 4 bars, set, cross RH.  End 1 2 3 on opp sides
9-16::
    1s+2s+3s dance reels of 3 on sides (1s out & down & 2s in & up to
    start)
17-24::
    1s cast down 1 place _while_ 2s dance in & up, 1s cross up _while_
    2s cast 1 place, 1s cast to 2nd place (own side) _while_ 2s 1/2 turn
    RH moving up to 1st places, 2s turn RH _while_ 1s+3s turn RH on
    sides
25-32::
    2s+1s+3s dance Grand Chain for 6 bars (until back in order 1 2 3 on
    own sides), 1s+2s change places RH on sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4780, '2013-08-21 08:30:55.0701+00', '2023-02-04 01:19:18.933258+00', 9459, 3, NULL, 'ace', '1-8::
    1L sets then 1M sets as 1L casts, 1M casts as 1L crosses up to start
    1/2 Fig of 8 round 2M & 1L completes 1/2 Fig as 1M starts 1/2 Fig
    round 2L
9-12::
    1M completes 1/2 Fig of 8 as 1L starts 1/2 Fig round 3L, 1L
    completes 1/2 Fig of 8 as 1M starts 1/2 Fig round 3M
13-16::
    1M completes 1/2 Fig of 8 as 1L dances up between 2s & petronella
    turns to face down, 1L sets as 1M petronella turns between 3s to
    face up
17-24::
    1s turn to right & dance RSh reels of 3 across to end facing 1st
    corners
25-32::
    1s dance Pass+Turn with 1st corners, pass RSh & dance LH across (1M
    with 2s & 1L with 3s) to end in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4781, '2013-08-21 08:30:55.078238+00', '2023-02-04 01:19:18.946097+00', 1338, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 R&L & dance 1/2 LSh reels of 4 on sides
    ending with 1s+4s turning RH on sides into line of 4 across (1L+4M
    BtoB)
9-16::
    1M+4M also 1L+4L set & turn RH to end on sides (3 4 1 2) & circle 8H
    round to left 1/2 way
17-24::
    All set, 1s & 3s cast up _while_ 2s & 4s dance down 1 place & 1s
    dance down to 4th place
25-32::
    All turn RH, 2s+3s also 4s+1s dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (4783, '2013-08-21 08:30:55.094192+00', '2023-02-04 01:19:18.968918+00', 11374, 3, NULL, 'ace', '1-8::
    1M+2L turn RH 1.1/2 times _while_ partners dance round anticlockwise
    1/2 way, 1s dance 1/2 Fig of 8 round 3s.  (2) 1 3
9-16::
    1L+3M turn LH 1.1/2 times _while_ partners dance round clockwise 1/2
    way, 3s dance 1/2 Fig of 8 round 2s.  (2) 3 (1)
17-24::
    2s+3s+1s set & 3s petronella turn to 3L between 2s facing down & 3M
    between 1s facing up, all Set+Link for 3 once.  2 3 1
25-32::
    3s dance RH across (Lady with 2s & Man with 1s), 3s pass RSh & dance
    LH across with other couples to end.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13056, '2020-08-10 00:19:06.004746+00', '2023-02-04 01:19:18.992055+00', 1345, 3, NULL, 'ace', '1-8::
    2s followed by 1s lead down; 1s followed by 2s lead up, remaining in
    middle 2H joined ready for …
9-16::
    1s+2s dance 6 bars of Poussette, Bar 14: 2s+1s 1/4 turn 2H into line
    up/down middle then turn partner RH once round. 2 1 with Ladies
    facing down, Men up
17-24::
    2s+1s dance reel of 4 up/down centre ending in centre facing own
    side, all joining NH
25-32::
    2s+1s Bal-in-Line & 1/2 turn partner RH; 2s+1s Bal-in-Line & turn
    3/4 RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (4785, '2013-08-21 08:30:55.12127+00', '2023-02-04 01:19:19.19764+00', 10890, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & turn RH 1.1/2 times to face 3rd corners
9-16::
    1s dance Pass+Turn with 3rd corners & pass RSh to face 4th corners,
    dance Pass+Turn with 4th corners & pass RSh to face 1st corners
17-24::
    1s dance Pass+Turn with 1st corners, pass RSh & dance Pass+Turn with
    2nd corners & end 2nd place opposite sides
25-32::
    1s dance reels of 3 on sides (LSh to 1st corner to start) & cross RH
    to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4786, '2013-08-21 08:30:55.134926+00', '2023-02-04 01:19:19.335323+00', 8490, 3, NULL, 'ace', '1-8::
    1s+2s cross (no hands) into RH across 1/2 way, 1s turn RH 1.1/2
    times to face 1st corners _while_ 2s turn RH to 1st place own side
9-16::
    1s dance ''Hello-Goodbye'' setting & end facing 3rd corner
17-24::
    1s dance 1/2 reel of 4, pass RSh & dance 1/2 reel of 4 with 4th
    corners
25-32::
    1s dance diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (4787, '2013-08-21 08:30:55.143074+00', '2023-02-04 01:19:19.356154+00', 1350, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, dance 1/2 Figs of 8 (Lady round 2s & Man
    round 3s) to end facing 1st corners
9-24::
    1s dance 4 x 1/2 reels with corners (as Mairi''s Wedding) _while_
    standing corners in each 1/2 reel chase round clockwise to opposite
    corner
25-32::
    1s pass LSh to dance RH across (Lady with 2s & Man with 3s), pass
    RSh to dance LH across with other couple & 1s end in 2nd places own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (8562, '2015-02-13 12:47:35.78522+00', '2023-02-04 01:19:19.387986+00', 15650, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up), turn 1.3/4 LH to face 1st corners
9-16::
    1s set to & turn corners (Edinburgh style - skip change). 1s finish
    facing partner''s 1st corner (3rd corners)
17-24::
    Repeat 9-16 with partner''s corners (3rd & 4th corners).  Finish
    passing partner LSh to face own 2nd corners
25-32::
    1s + 2nd corners dance reel of 4, 1s finishing in 2nd place own
    sides _while_ 2s+3s dance double diagonal (interlocking) reels of 4,
    LH across in middle (similar to Angus MacLeod)', 0);
INSERT INTO 'dancecrib' VALUES (4788, '2013-08-21 08:30:55.151116+00', '2023-02-04 01:19:19.42412+00', 1352, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    1s & 4s cross RH, cast in 1 place, set & 1/2 turn partner RH into
    prom hold (1s facing up & 2s down)
9-16::
    1s & 4s dance reels of 3 across giving RSh to corner & end with 1s
    on Men''s side & 2s on Ladies'' side
17-24::
    1s+4s dance LH across 1.1/4 times & face corner person. 1s turn
    corners RH (2bars) & 1s+4s turn LH on sides (2 bars)
25-32::
    All dance reels of 4 on sides.  1L & 4L end facing out
33-40::
    4L & 1L followed by partner cast & dance down/up centre, Ladies
    right about turn (BtoB) to face & 3/4 turn partner RH to end 2
    4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (4789, '2013-08-21 08:30:55.159099+00', '2023-02-04 01:19:19.45822+00', 1353, 3, NULL, 'ace', '1-8::
    1s+2s dance 3/4 R&L, 1s & 3s change places LH on side
9-16::
    1s cross RH, cast up 1 place & meet in middle, 1/2 turn LH & lead up
    to top casting to face 1st corners
17-24::
    1s set to 1st corners, set to 2nd corners, set to 3rd corners & set
    to 4th corners
25-32::
    1s dance reels of 3 on opp sides (LSh to 1st corner to start), Bars
    31-32: 1s cross to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (8024, '2013-09-09 06:46:59.112125+00', '2023-02-04 01:18:21.636703+00', 14974, 3, NULL, 'ace', '1-8::
    1s+2s+3s set to partners & turn 2H twice round & set to partners
    again
9-16::
    1L+2M set advancing & turn 2H, 1L+2M pass by right to each others
    place & set
17-24::
    1M+2L repeat bars 9-16
25-32::
    2s cross down to dance reels of 3 on own sides, 1s crossing up on
    last 2 bars  2 1 3', 4);
INSERT INTO 'dancecrib' VALUES (13057, '2020-08-10 00:19:06.410309+00', '2023-02-04 01:19:19.490837+00', 16898, 3, NULL, 'ace', '1-8::
    1s slip step down middle & lead up to face 1st corners (2s step up
    3-4)
9-16::
    1s+1st corners dance Corner Pass+Turn; 1s pass RSh, 1s+2nd corners
    dance Corner Pass+Turn. 1s end 2nd place opp side
17-24::
    1s set advancing, pulling back RSh, 1M faces up, 1L down, 1s dance
    Crown Triangles end 1L facing up, 1M down in centre
25-32::
    _6_ bar reels of 3 across, 1s pass 1st corners LSh to start. Bars
    31-32: all set', 0);
INSERT INTO 'dancecrib' VALUES (13296, '2020-11-02 01:19:13.082545+00', '2023-02-04 01:19:19.522318+00', 20027, 3, NULL, 'ace', '{{explanation}}
Even number of dancers »A« & »B« (all socially distanced) facing anticlockwise

1-8::
    All Adv+Ret twice
9-16::
    All individually dance small clockwise circle in place; All
    individually dance small anticlockwise circle in place. All face
    anticlockwise
17-20::
    All slip step left (2 bars) & right (2 bars)
21-24::
    Dancer »A« pulls back LSh & casts (long) to place vacated by
    adjacent »A« dancer to face clockwise _while_ »B« dancers set,
    pullback RSh to face clockwise
25-32::
    All chase clockwise (4 bars), turn & clap & chase back anticlockwise

{{explanation}}
Note:	2nd time through Bars 21-24: »A« dancers set, while«B« dancers cast', 0);
INSERT INTO 'dancecrib' VALUES (4790, '2013-08-21 08:30:55.167241+00', '2023-02-04 01:19:19.62711+00', 1356, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance 1/2 Fig of 8 round 3s into 2nd place
    opp sides (assume the 3 couples are in a circle for next 16 bars)
9-16::
    All 3 Men dance in front Lady on right, behind next Lady, in front
    of next Lady & behind next Lady (1M in 1st pl Men''s side)
17-24::
    All 3 ladies dance in front Man on right, behind next Man, in front
    of next Man & behind next Man (1L in 3rd pl Ladies'' side)
25-32::
    1M+3s (opp) also 1L+2s (opp) dance LH across 1.1/2 times to end
    (3)(1)(2) & all chase anticlockwise to own sides in order 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4791, '2013-08-21 08:30:55.17539+00', '2023-02-04 01:19:19.682114+00', 387, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All set to partners, Men dance anticlockwise in front of partner &
    next Lady, behind opposite Lady to face the next Lady & turn 2H
9-16::
    All set to ''new'' partners & Ladies dance clockwise in front of ''new''
    partner & next Man, behind opposite Man to face the next Man & turn
    2H
17-32::
    Repeat bars 1-16 to end in opposite places with original partner
33-40::
    All dance a double Men''s Chain
41-48::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L
49-56::
    All dance Ladies'' Chain
57-64::
    All dance Grand Chain starting with giving RH to corners

{{title}}
Reel

1-64::
    Repeat bars 1-56 & circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4793, '2013-08-21 08:30:55.193211+00', '2023-02-04 01:19:19.743337+00', 1358, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s followed by 2s+3s+4s cast to bottom, cross & dance up on opposite
    sides
17-24::
    All (facing up) slip step sideways into centre (Ladies pass in front
    of Men), advance with partner & retire, slip step sideways back
25-32::
    1L crosses diagonally RH with 2M, LH with 3L, RH with 4M, all clap &
    turn on spot
33-40::
    1M crosses diagonally LH with 2L, RH with 3M, LH with 4L, all clap &
    turn on spot', 0);
INSERT INTO 'dancecrib' VALUES (4794, '2013-08-21 08:30:55.201348+00', '2023-02-04 01:19:19.771914+00', 1359, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels of 3 on own sides (1s & 3s casting to start) &
    ending with 1s continuing reel to end in 2nd place
9-16::
    1s petronella turn to right 3 times (end Man between 2s & Lady
    between 3s) & full turn partners RH
17-24::
    1M circles 3H round to left with 2L+3L as 1L circles with 2M+3M, 1s
    dance LH across with same couple to end facing 1st corners
25-32::
    1s set & turn 1st corners 2H, set & turn 2nd corners RH & cross LH
    to 2nd places own sides', 0);
INSERT INTO 'dancecrib' VALUES (4795, '2013-08-21 08:30:55.209493+00', '2023-02-04 01:19:19.95832+00', 9420, 3, NULL, 'ace', '1-8::
    All dance a large Fig of 8: 3L followed by 4s+3M cross up to 2M
    place (persons dancing up have priority) & loop round to right as 2L
    followed by 1s+2M cross down to 3M place & loop round to left,
    repeat from new places back to original places
9-16::
    1s+2s turn RH on sides _while_ 3s+4s turn LH, 1L followed by
    2L+3L+4L dance down middle _while_ 4M followed by 3M+2M+1M dance up
    middle to face partner
17-24::
    4s+3s also 2s+1s circle left right round in 3 bars & dance out to
    sides, 4s & 2s turn RH, 4s lead down to 3rd place _while_ 2s cast to
    top
25-32::
    2s+3s also 4s+1s dance double Fig of 8  (2s & 4s cross down)', 0);
INSERT INTO 'dancecrib' VALUES (12539, '2020-02-02 02:47:23.281035+00', '2023-02-04 01:19:19.988236+00', 13900, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up); 1s turn 1.1/2 LH to face 1st corners
9-16::
    1s+1st corners dance diag RSh reel of 4. 1s end in centre LSh to LSh
    (1M facing  down, 1L facing up)
17-24::
    1M+2M+3M also 1L+2L+3L dance RH across, 1s pass RSh; 1M+2L+3L also
    1L+2M+3M dance LH across. End 1s join RH with partner, LH with 2nd
    corner
25-32::
    1s+2nd corners Bal-in-Line twice; 1s turn 1/4 RH, dance out of ends
    casting round 4th corner (1M down, 1L up) to 2nd place own side.  2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (4797, '2013-08-21 08:30:55.236349+00', '2023-02-04 01:19:20.070381+00', 1366, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels on opposite sides (2s
    out/up, 3s in/up to start)
9-16::
    1s cross down to dance reflection reels on own sides
17-24::
    1s+2s set, dance 1/2 RH across; set and dance 1/2 LH across back to
    places
25-32::
    1s cast to 3rd place (2s & 3s step up 27-28); 2s+3s+1s circle 6H
    round to left
33-40::
    1s lead up to top, cast to 2nd place (3s step down), 2s+1s+3s circle
    6H round to left', 0);
INSERT INTO 'dancecrib' VALUES (8994, '2015-11-30 08:59:37.304739+00', '2023-02-04 01:19:20.25112+00', 16537, 3, NULL, 'ace', '1-8::
    1s set, dance down below 3s, cast up to 2nd place & set advancing to
    face 1st corners (2s step up 3-4)
9-16::
    1s turn 1st corners RH, pass RSh, turn 2nd corners RH, pass RSh to
    2nd place own side facing out (corners dance 4 bars)
17-24::
    Promenade (Chaperoned) Chain progression:
::
    _17-18_     1M casts up, 1L casts down as 2s+3s turn 3/4 RH into
    line up/down set
::
    _19-22_     1M+2L & 1L+3M, in prom hold dance clockwise to opp end
    of line as 2M+3L (in middle) turn 1.1/2 LH
::
    _23-24_     1s dance clockwise to 2nd place own side as 3s+2s turn
    partners 3/4 RH to own sides. All face clockwise  3 1 2
25-32::
    3s+1s+2s dance clockwise 1/2 round set.  All set, cross RH to own
    sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15277, '2022-12-05 17:20:28.807879+00', '2022-12-06 09:57:54.795549+00', 6571, 1, 1645, 'ace', '1--::

  1M+2M+3M dance across, RSh round P & face up NHJ with P ; all A&R diagonally up then down centre

9--::

  All set facing up | set to P ; turn P RH to original places

17--::

  All circle6 to L & back

25--::

  W repeat [1-8], LSh round P

33--::

  All set facing up | set to P ; turn P LH into promhold facing up

41--::

  All promenade, 1c end casting to 4pl (4c up on [47-48]) as 2c+3c dance up (2,3,4,1)

', 2);
INSERT INTO 'dancecrib' VALUES (14501, '2022-01-01 21:20:46.393762+00', '2022-12-05 23:49:55.234656+00', 19870, 2, 963, 'ace', '1-8::  

  All dance interlocking R4, pass prtn R sh to begin  

9-12::    

  Set to prtn, RH turn W into middle, men face cw  

13-20::  

  Targe for 3 couples: M dance one plc cw while W LH turn 2/3, RH turn prtn once round,  Repeat finishing W back to back in ctr facing prtn  

21-24::  

  All set to prtn and LH turn to sidelines  2,3,1  

25-32::  

  All 3 W chase cw - in front of prtn, behind next man, in front and completely around next man continuing cw back to prtn', 5);
INSERT INTO 'dancecrib' VALUES (12075, '2019-08-30 09:54:00.414061+00', '2023-02-04 01:19:20.279538+00', 19083, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across once round, 1M+2M & 1L+2L 1/2 turn RH to
    change places.  1M & 2L face out
9-16::
    2s+1s+3s dance LSh reels of 3 on sides (1s+3s pass LSh).  1s end
    facing 1st corners
17-24::
    1s set to 1st corners, set to 2nd corners, pull back RSh to finish
    in 2nd place opp sides.  2s+1s+3s Adv+Ret (Bar 22: 1s 1/2 turn 2H &
    Retire to own sides)
25-32::
    2s+1s+3s circle 6H round & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4799, '2013-08-21 08:30:55.255962+00', '2023-02-04 01:19:20.413603+00', 1368, 3, NULL, 'ace', '1-8::
    1s cast to 3rd place, set, cast up to top & set
9-16::
    1s lead down the middle & back to end facing 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s turn RH 1.1/2 times & 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4800, '2013-08-21 08:30:55.265794+00', '2023-02-04 01:19:20.436543+00', 8332, 3, NULL, 'ace', '1-8::
    1L followed by partner casts below 3s, 1s lead up to top & cross to
    original places
9-16::
    1s+2s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
17-24::
    1s dance reels on own sides (RSh to 2s to start)
25-32::
    2s+1s+3s set, circle 6H round to left 1/2 way & chase clockwise 1/2
    way back to places', 0);
INSERT INTO 'dancecrib' VALUES (4801, '2013-08-21 08:30:55.27423+00', '2023-02-04 01:19:20.45576+00', 1372, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH to face 1st corners
9-32::
    Dance to Corners & Set: (24 bars):
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 11 more times until
    1s face 1st corners again
33-40::
    1s dance reels of 3 on opposite sides passing 1st corner LSh to
    start & cross to 2nd place own side
41-48::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9473, '2016-11-09 08:48:20.208652+00', '2023-02-04 01:19:20.512584+00', 17404, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance »Inveran Reels«
9-16::
    1s cross RH, cast (2s step up) to face 2nd corners.  1s+2nd corners
    dance »Pass & Gypsy Turn«
::
    _13-16_   1s dance RSh around corner positions back into centre
    _while_ corners dance round each with RSh »Gypsy Turn«
17-24::
    1s dance round each with RSh »Gypsy Turn« to face 1st corners.
    1s+1st corners dance »Pass & Gypsy Turn«. 1s turn RH into prom hold
    facing 1M place
25-32::
    1s dance 1/2 reel of 3 on Men''s side (1s+2M pass RSh).  1s dance 1/2
    reel of 3 on Ladies'' side (1s+3L pass RSh). 1s end in centre facing
    up, 2s+3s dance in ready for...
33-40::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4803, '2013-08-21 08:30:55.292022+00', '2023-02-04 01:19:20.542041+00', 1375, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, lead down below 3s & cast back to 2nd
    place facing 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting
17-24::
    1s dance out on opposite side & dance Figs of 8 on sides casting
    round 2nd corners to start _while_ 2s+3s dance R&L
25-32::
    1s dance reels of 3 on sides giving RSh to 2nd corners to start (6
    bars), 1s cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4804, '2013-08-21 08:30:55.30009+00', '2023-02-04 01:19:20.714025+00', 1376, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s set advancing & set again holding RH turning Lady under her right
    arm, repeat holding LH with Man turning under his left arm
17-24::
    1s dance down for 1 bar & back, cast 1 place, cross down between 3s
    & cast up to 2nd place on opposite sides
25-32::
    1s dance reflection reels of 3 on opposite sides dancing in & up to
    start, 1s cross RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4805, '2013-08-21 08:30:55.310023+00', '2023-02-04 01:19:20.75137+00', 12080, 3, NULL, 'ace', '1-8::
    All set, 1s+2s also 3s+4s dance RH across 1/2 way. 2s+1s also 4s+3s
    dance 1/2 double Fig of 8 (2s & 4s cross down to start)
9-16::
    All dance reflection ''Cross-Over'' reels of 4 (Men''s side RSh &
    Ladies'' side LSh, each couple crosses in centre of set, Lady in
    front of partner, when dancing up (crossing order 3 4 2 1). All end
    on opp sides (2) (1) (4) (3)
17-24::
    Top 3 couples (2s+1s+4s) dance 1/2 reels of 3 (1s out & up to
    start). 4s+1s also 2s+3s change places on sides (Men LH & Ladies RH)
    & set to person just passed.  (1)(4)(3)(2)
25-32::
    All dance RSh ''Cross-Over'' reels of 4, each dancer leaving top
    position Ladies'' side & bottom position Man''s side dance 1/2 RSh
    round each other quickly in centre of set  to change places & join
    reel on own side. End 2 3 4 1 on own sides', 0);
INSERT INTO 'dancecrib' VALUES (4806, '2013-08-21 08:30:55.318079+00', '2023-02-04 01:19:20.784607+00', 1378, 3, NULL, 'ace', '1-8::
    All advance 2 steps & retire, 1s & 4s turn RH 1.1/2 times to form
    square set
9-16::
    1s+4s advance 2 steps & retire, 1M+4M also 1L+4L turn RH 1.1/2 times
    to face corners
17-24::
    All set & change places with corners 2H, 2s+3s dance RH across once
    round
25-32::
    1s & 4s set to partners & change places RH, 2s+3s advance, turn to
    face top & dance into 1st & 2nd places longwise formation', 0);
INSERT INTO 'dancecrib' VALUES (13519, '2021-01-09 01:19:10.559082+00', '2023-02-04 01:19:20.814977+00', 19976, 3, NULL, 'ace', '1-4::
    1s »Covid Turn«:  1/2 turn 2H, pull back LSh to face partner, 1/2
    turn 2H, pull back LSh dancing out to own side
5-8::
    1s+2s circle 4H round to left 1 step, pull back LSh  to face
    partner, 1s+2s circle 4H round to left 1 step, pull back LSh  to end
    on opp sides (2) (1)
9-10::
    1s+2s set to diagonally opp dancer, pull back LSh to face out
11-12::
    All set (2M on Ladies'' side, 1M across bottom, 1L on Men''s side, 2L
    across top), pulol back LSh to face anticlockwise
13-14::
    All Adv+Ret (1 step each), pull back LSh to face clockwise
15-16::
    All Adv+Ret (1 step each), pull back LSh to finish on opp sides (2)
    (1)
17-20::
    All Petronella turn 1 place to right, repeat to end facing
    diagonally in. 1 2
21-24::
    All set, all Adv 1 step, pull back RSh & dance out to place
25-32::
    All circle 4H 1/2 round to left (2 bars), dance 1/2 RH across ( 2
    bars); all 1/2 turn partner RH (2 bars) & circle 4H 1/2 round to end
    on own sides.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (13400, '2020-12-02 01:19:11.338837+00', '2023-02-04 01:19:20.855376+00', 19927, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reels of 3 on own sides
17-20::
    1M Adv+Ret _while_ 1L sets & casts (2L steps up 19-20)
21-24::
    1L Adv+Ret _while_ 1M sets & casts (2M steps up 23-24)
25-28::
    1s dance 1/2 Fig of 8 (1M up round 2s, 1L down round 3s)
29-32::
    1s dance 1/2 Fig of 8 (1M down round 3s, 1L up round 2s)', 0);
INSERT INTO 'dancecrib' VALUES (4807, '2013-08-21 08:30:55.327799+00', '2023-02-04 01:19:20.887405+00', 10510, 3, NULL, 'ace', '1-8::
    1s cross RH, cast to bottom (2s+3s+4s step up), 4s+1s change places
    on sides (1s between 4s)
9-16::
    1s+4s circle 4H round & back
17-24::
    1s cross up to top & cast to 4th place own sides
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4809, '2013-08-21 08:30:55.344044+00', '2023-02-04 01:19:21.11545+00', 1383, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s pass RSh on sides, 2s and 3s cross RH _while_ 1s+4s
    dance LSh round each other on sides, repeat to end 1 2 3 4 on opp
    sides
9-16::
    Repeat from new positions to 1 2 3 4 own sides
17-24::
    All set, 1s+2s also 3s+4s dance 1/2 RH across, all set and cross RH.
    2143
25-32::
    1L and 3M followed by partners cast and dance 3/4 Fig of 8 round 4s
    (pass LSh between 4s) to end  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4810, '2013-08-21 08:30:55.352934+00', '2023-02-04 01:19:21.142806+00', 1385, 3, NULL, 'ace', '{{title}}
Fig 1

1-8::
    All petronella turn to face partner (Ladies BtoB in centre), set &
    turn RH
9-16::
    1s+3s dance 1/2 reel of 4 (pass partner RSh to start) _while_ 2L &
    4L dance round their partners RSh, all Ladies chase 1 place
    anticlockwise to face next Man (Ladies BtoB in centre), 1L+3L dance
    1/2 reel of 4 with 4M+2M _while_ 2L & 4L dance round ''new'' partner
    RSh, all Ladies chase 1 place anticlockwise to end facing own
    partners (Ladies BtoB)
17-24::
    All set to partner twice & turn RH to end facing partner in diagonal
    lines (1s with 2s & 3s with 4s & Ladies in centre of each line)
25-32::
    All dance diagonal RSh reels of 4

{{title}}
Fig 2

33-40::
    All turn partner RH & Promenade anticlockwise to end in longways set
    in order 1 2 3 4
41-48::
    End couples (1s & 4s) set, cross RH, change places LH on sides with
    next person & set to partners
49-56::
    1s & 4s dance 1/2 Figs of 8 round end couples & dance 1/2 Fig of 8
    round 2s+3s on own sides to end 2 4 1 3
57-64::
    4s+1s dance LH across, 2s+4s also 1s+3s dance RH across
65-72::
    All Promenade anticlockwise to end in longwise set across with 2s
    leading to their original place followed by 4s+1s+3s (all Men face
    down)
73-96::
    Repeat bars 41-64 (2s & 3s as main dancers) & ending in the same
    diagonal lines as at bar 24

{{title}}
Fig 3

97-104::
    1s+2s also 3s+4s dance diagonal RSh reels of 4
105-112::
    All set twice to partner & turn RH to end in square set with Ladies
    BtoB in centre facing partner
113-120::
    Repeat bars 9-16: 1s+3s dance 1/2 reel of 4 (pass partner RSh to
    start) _while_ 2L & 4L dance round their partners RSh, all Ladies
    chase 1 place anticlockwise to face next Man (Ladies BtoB in
    centre), 1L+3L dance 1/2 reel of 4 with 4M+2M _while_ 2L & 4L dance
    round ''new'' partner RSh, all Ladies chase 1 place anticlockwise to
    end facing own partners (Ladies BtoB)
121-128::
    All Petronella turn & set to partner, turn RH 1.1/4 times to end
    with Ladies in centre for bow/curtsey', 0);
INSERT INTO 'dancecrib' VALUES (4811, '2013-08-21 08:30:55.371996+00', '2023-02-04 01:19:21.317467+00', 1388, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s cross over (Men dance under arch made by Ladies),
    cross back (Ladies under arch made by Men), 1s & 4s lead out of ends
    & back as 2s+3s dance RH across & end with 2s dancing under arch
    made by 3s
9-16::
    1s+3s also 2s+4s circle 4H round to right & end with couples
    changing places (3s & 4s making arches), end couples lead out of
    ends & back as 1s+4s dance RH across & end with 1s dancing under
    arch made by 4s
17-24::
    All dance 1/2 Grand Chain (all changing places on the side to
    start), all Adv+Ret & turn 2H
25-32::
    2s+1s also 4s+3s circle 4H round to left 1/2 way, 1s cast 1 place,
    cross RH, cast 1 place, cross LH & cast to bottom', 0);
INSERT INTO 'dancecrib' VALUES (4813, '2013-08-21 08:30:55.388251+00', '2023-02-04 01:19:21.376585+00', 1393, 3, NULL, 'ace', '1-8::
    1s cast, turn 2H to make an arch facing 2L & dance into 1L place as
    2L dances under arch, 1s turn 2H to face 2L+3M who have turned 2H to
    face them (Ladies on Men''s left)
9-16::
    2L+3M make an arch & change places with 1s, both couples turn 2H to
    face across (to 2M/3L), dancing couples make arches & change places
    with 2M/3L, 2M+3L meet in centre & all 3 couples turn 2H into prom
    hold
17-24::
    All 3 couples dance a diagonal reel of 3 in prom hold & end all
    facing up
25-32::
    All 3 couples Promenade & end 3M casting to 2nd place as 2M dances
    up to top place', 0);
INSERT INTO 'dancecrib' VALUES (4814, '2013-08-21 08:30:55.396425+00', '2023-02-04 01:19:21.403089+00', 1398, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    2s & 3s petronella turn as 1s & 4s cast in 1 place, all set in 2
    diamond formations; 1s+2s also 3s+4s dance RH across (1s+4s return
    to original places as 2s+3s end BtoB facing out)
9-16::
    1s+2s also 3s+4s dance double Figs of 8 starting with 1s & 4s
    dancing between 2s & 3s, 2s & 3s 1/2 turn RH to face each other (L
    on Man''s R)
17-24::
    2s+3s set & pass opp couple LSh to change places, 1s+3s also 2s+4s
    circle 4H round to left & turn partner 2H to face nearer end
25-32::
    1s+3s dance Allemande up as 2s+4s dance Allemande down to end 3 1
    (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (4815, '2013-08-21 08:30:55.404673+00', '2023-02-04 01:19:21.424094+00', 10057, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 couples facing 2 couples

1-8::
    All circle 8H round & back
9-16::
    All dance RH across with opposite couple & LH back
17-24::
    All dance 1/2 R&L with opposite couple, middle couples dance 1/2 R&L
25-32::
    All dance RSh reels of 4
33-40::
    All with new partners Adv+Ret for 2 steps & dance on (under/over) to
    new line

{{explanation}}
Devisers note: Repeat 3 more times (Hoping the magic works - back with original partner) P.S. If one person goes wrong, the magic doesn''t work!!', 0);
INSERT INTO 'dancecrib' VALUES (4816, '2013-08-21 08:30:55.414542+00', '2023-02-04 01:19:21.446735+00', 1399, 3, NULL, 'ace', '1-8::
    1s also 3s passing RSh dance diagonal reel of 3 with 2L/4L
9-16::
    1s also 3s passing LSh dance diagonal reels of 3 with 2M/4M
17-24::
    1s & 3s lead down the middle & turn partners RH into 2nd/4th places
    (own sides), 2s & 4s dance DoSiDo
25-32::
    2L+1M also 4L+3M change places RH, 2M+1L also 4M+3L change pl RH, 1s
    turn 2H _while_ 2s+3s+4s advance & turn partners 2H 1/2 way
33-40::
    1s (on opposite sides) dance between 2s giving nearer hand to 2s in
    passing, other hand to 3s, between 4s to 4th place & cross RH to own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (4817, '2013-08-21 08:30:55.422674+00', '2023-02-04 01:19:21.475987+00', 7375, 3, NULL, 'ace', '1-8::
    1s+3s dance R&L
9-16::
    1s+3s dance Ladies'' Chain
17-32::
    2s+4s repeat bars 1-16
33-40::
    All Ladies Adv+Ret for 2 steps & dance RH across to places facing
    out
41-48::
    All Ladies dance clockwise round outside of set
49-56::
    All Men Adv+Ret for 2 steps & dance LH across to places facing out
57-64::
    All Men dance anticlockwise round set
65-72::
    1s+3s Promenade anticlockwise round inside of set & set facing in
73-80::
    2s+4s Promenade clockwise round inside of set & set facing in
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4818, '2013-08-21 08:30:55.430799+00', '2023-02-04 01:19:21.506115+00', 7575, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s cross RH & cast in 1 place (2s & 3s step down/up); 2s+1s &
    4s+3s dance RH across 1s & 4s end in centre - 1s facing down & 4s up
9-12::
    1s cast up as 4s cast down round nearest corner to end 1s between 2s
    facing down, 4s between 3s facing up
13-16::
    All set in lines across, 1s+4s Adv, 1M+4L & 4M+1L pass RSh into line
    across, Ladies BtoB in centre (1L facing 4M, 4L facing 1M)
17-24::
    1s+4s dance RSh reel of 4 across
25-28::
    1M+4L & 4M+1L turn 3/4 RH, retain hands & join LH with 2s & 3s to
    Bal-in-Line on sides.  2(1) 4 (3)
29-32::
    1M+4L & 4M+1L turn 1.1/2 RH on sides.  2 4 (1) (3)
33-40::
    All dance RSh reel of 4 on sides.   2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (7870, '2013-08-21 08:31:50.128477+00', '2023-02-04 01:23:08.235519+00', 11629, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH across back to place
9-16::
    1L followed by 2L dances across top, behind Men with 1L dancing
    below 2M & across to 2nd place own side as 2L dances between 1M+2M &
    into 1st place own side.  1L+2L set (Men do not set back)
17-24::
    1M followed by 2M repeat bars 9-16
25-32::
    2s+1s dance R&L (with polite turns)', 0);
INSERT INTO 'dancecrib' VALUES (15278, '2022-12-06 11:44:36.142426+00', '2022-12-10 00:18:52.570631+00', 21164, 2, 36088, 'ace', '1-8::  1s+2s set & rotate. 1s finish facing 1L’s 1st corner, 1M leading.

9-12::  1s RSh alt tandem ½ diag reel of three with 1st corners. 1s finish facing 1L’s 2nd corner, L now leading.

13-16::  1s RSh alt tandem ½ diag reel of 3 with 2nd corners. 

17-20::  3s+1s+2s ½ reels of 3 on sides. 1s pass 2s (in 3rd pl) RSh to begin. 1s finish facing 1M’s 1st crnr, 1M leading.

21-28::  Repeat bars 9-16. 1s end 2nd pl own sides facing up.

29-32::  3s+1s+2s ½ reels of 3 on sides. 1s pass 3s (in 2nd pl) RSh to begin.

33-40::  2s+1s+3s 6 hands round & back.

', 3);
INSERT INTO 'dancecrib' VALUES (13872, '2021-04-05 00:18:18.926902+00', '2023-02-04 01:18:18.766639+00', 9021, 3, NULL, 'ace', '1-8::
    1s+4 cross RH, cast in 1 place (2s & 3s step up/down); 1s+4s turn
    partner LH, 1s+4s join LH in centre & RH with corners (St Andrews
    Cross)
9-16::
    All set, 1s+4s dance 1/4 LH across (1 place round); repeat to end 2
    4 1 3, 1s & 4s facing corners
17-28::
    Interlocking RSh diagonal reels of 4 (LH across in middle). End 4s
    between 2s facing up, 1s between 3s facing down)
29-32::
    4s & 1s dance out of end & cast to end in 2nd/3rd place own side.  2
    4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15129, '2022-10-05 00:18:23.295745+00', '2023-02-04 01:18:18.970689+00', 10848, 3, NULL, 'ace', '1-8::
    1s+2s+3s set twice; 1M changes places RH with 2L, then LH with 3M
9-16::
    1s+2s+3s set twice; 1L changes places LH with 2M, then RH with 3L
17-20::
    2s+3s+1s set on sides, 1s+2s change places on the sides (1s cast up
    & 2s dance in & down) _while_ 3s set, pulling back RSh to turn about
    on the spot
21-24::
    1s turn 1.1/2 RH. (1) (3) (2)
25-28::
    1s+3s Set+Link
29-32::
    All dance clockwise to own side in a circular movement.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4819, '2013-08-21 08:30:55.43892+00', '2023-02-04 01:19:21.531022+00', 1402, 3, NULL, 'ace', '1-8::
    1s & 3s set, dance down middle (2s & 4s step up 3-4), 1s & 3s cast
    up round 4s/5s to 2nd/4th place 2 1 4 3 5
9-12::
    2s+1s also 4s+3s dance 1/2 Double Figs of 8 (1s & 3s crossing up to
    start) _while_ 5s set & cross RH (2) (1) (4) (3) (5)
13-16::
    1s+4s also 3s+5s dance 1/2 Double Figs of 8 (1s & 3s crossing down
    to start) _while_ 2s set & cross RH.  2 1 4 3 5
17-24::
    1s & 3s dance up between 2s/4s & cast down to 2nd/4th places; 1s+4s
    also 3s+5s set facing up/down on sides & change places 2H.  2 4 1 5
    3
25-32::
    2s+4s also 5s+3s dance R&L _while_ 1s set & cross RH then 1s set &
    cross back LH  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (4822, '2013-08-21 08:30:55.466789+00', '2023-02-04 01:19:21.757642+00', 9003, 3, NULL, 'ace', '1-2::
    1s cross down to 2nd place opp sides (no hands) - 1M faces out/down,
    1L out/up _while_ 2s dance up & face in
3-8::
    2s+1s+3s dance reels of 3 (1s pass 1st corners RSh to start). 1s end
    facing 1st corners
9-12::
    1s set to 1st corners & turn 2H opening out into lines of 3 across
    (1L between 2s & 1M between 3s) 1s+corner NHJ make an arch
13-16::
    1s+2s+3s cross up/down 2L/3M dancing under arches made by
    1s+corners, 1s turn 1st corners 2H onto sides 3 (1) 2
17-24::
    1s dance RH across (1M+3s at top & 1L+2s at bottom), 1L crosses up
    between 3s & casts to 2nd place own side as 1M crosses down between
    2s & casts to place
25-32::
    3s+1s+2s dance Allemande ending with 1s casting to 3rd place as 3s
    dance up to 2nd place. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4823, '2013-08-21 08:30:55.475087+00', '2023-02-04 01:19:21.778374+00', 9157, 3, NULL, 'ace', '1-8::
    1M sets & casts 1 place, sets & petronella turns between 3s facing
    up _while_ 1L stands for 2 bars then sets, casts 1 place & sets
9-16::
    1M sets in line with 3s & all 3 Adv+Ret then 1M advances to partner
    _while_ 1L petronella turns between 2s & sets in line with 2s then
    all 3 Adv+Ret, 1L pulling back RSh (bar 16) to face 2L
17-24::
    1L followed by partner dances tandem reel of 3 across with 2s (RSh
    to 2L) to end in 2nd place own sides
25-32::
    1s dance RSh reels of 3 on sides giving RSh to 3s.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11182, '2018-09-30 22:19:32.975723+00', '2023-02-04 01:19:21.800803+00', 18615, 3, NULL, 'ace', '{{explanation}}
Men with backs to centre facing partner

1-8::
    All set & change places RH with partner, all set & change back RH
    into promenade hold facing anticlockwise
9-12::
    All promenade for 2 steps & set facing partner (retain hold of
    hands) turning Lady under arms to face clockwise in prom hold
13-16::
    All repeat bars 9-12 & end Men with back to centre facing partner
17-20::
    All dance DoSiDo (or advance & holding RH Lady turns under her arm &
    both twirl to dance out to places)
21-24::
    All holding LH Man dances LSh 3/4 round partner (Lady stands still)
    to her right & all join hands in a circle
25-32::
    All circle round & back & end with Men back to centre facing new
    partner ready to start again', 0);
INSERT INTO 'dancecrib' VALUES (4824, '2013-08-21 08:30:55.64883+00', '2023-02-04 01:19:22.010966+00', 11763, 3, NULL, 'ace', '1-8::
    1s set, 1/2 turn RH to face down in prom hold, dance down below 3s,
    cross LH & cast up to 2nd place own sides
9-16::
    2s+1s+3s dance reflection reels of 3 on sides (1s in & up to start &
    all giving hands where possible)
17-24::
    1s dance 1/2 Fig of 8 round 2s & 1/2 Fig of 8 round 3s
25-32::
    1s dance RH across (1L with 2s & 1M with 3s), all chase clockwise
    1/2 way to opposite sides.  (3)(1)(2)
33-40::
    1M+3s (at top) also 1L+2s circle 3H round to left & 1s end turning
    to face each other, 1s set, dance out thru 2nd pl opp sides up to
    top.  (1)(3)(2)
41-48::
    1s+3s+2s Adv+Ret for 1 & Link for 3 & repeat to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4826, '2013-08-21 08:30:55.665126+00', '2023-02-04 01:19:22.045342+00', 9083, 3, NULL, 'ace', '1-8::
    1M followed by partner casts down Men''s side, crosses over at
    bottom, dances up behind Ladies & 1M dances between 2L & 3L to face
    2M _while_ 1L dances between 3L & 4L to face 3M (2s+3s+4s step up
    bars 3-4)
9-16::
    1s dance diagonal RSh reels of 3 (Man with 2M+3L & Lady with 3M+4L)
17-24::
    1s dance diagonal RSh reels of 3 (Man with 3M+2L & Lady with 4M+3L)
25-32::
    1L followed by partner dances down middle, cast up behind Ladies,
    crosses over above 3s & casts to bottom crossing to own side', 0);
INSERT INTO 'dancecrib' VALUES (4821, '2013-08-21 08:30:55.458569+00', '2023-02-17 12:08:02.526815+00', 1405, 3, NULL, 'ace', '1-8::

    1s cross RH & cast 1 place, cross LH & cast (Lady up, Man down), to

    meet in middle in prom hold facing 2nd Man

9-16::

    1s dance 1/2 diagonal reel with 1st corners & 1/2 reel with 2nd

    corners, end in middle facing Ladies'' side

17-24::

    1s lead out, cross & cast (Lady up, Man down) to meet in middle; 1s

    turn 1.1/4 RH in centre to face up (Lady on Man''s right) as 2s+3s

    dance 1/2 R&L round them

25-32::

    1s lead up & cast to 2nd place & 2s+1s+3s turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (15279, '2022-12-06 11:47:12.133579+00', '2022-12-09 15:43:54.112537+00', 21155, 2, 36088, 'ace', '1-8:: 1s turn RH & cast. 1s turn RH 1½ to face 1st corners 

9-16::  2s,1s+3s reels of 3 across 1s & 1st corners pass RSh to begin. 1s end facing 1st corners 

17-24::  1s dance corner pass & turn with 1st crnrs, pull back RSh, end BtB W facing up, M facing down, pass & turn with 4th corners, ending 2nd pl own side

25-32::  2s,1s+3s 6 hands round to left for 6 slip steps (3 bars), pivot and circle 6H back

', 3);
INSERT INTO 'dancecrib' VALUES (14892, '2022-06-23 23:13:36.78454+00', '2022-10-25 20:10:03.471397+00', 20906, 1, 202, 'ace', '1--::

  1c dance down and up and face out (1,2,3)

9--::

  Mirror Reels3 on sides, 1c out and down, 2c in and up. 1c face out (1,2,3)

17-20::

  1c+2c turn EH on sides 1½, finishing in centre NHJ, 2c facing down, 1c facing up. On [20] 3c step in and face up NHJ (2,1,3)

21-32::

  *Bob Campbell figure* :  

 All set, 2c+1c advancing to change places (to 1,2,3) | 1c turn BH to face down _while{2}_ 2c+3c set advancing to changes places (to 1,3,2) ; continue sequence [23-24] four more times (2,1,3)



*Deviser''s note* : After the first time through, 1st couple may choose to remain in the center, turning towards each other to face down and begin with down the middle and up. After the second time through, or if dancing once and to the bottom, they may choose to remain in the center similarly to dance down to fourth place on bars 1&2 while the new 1s dance down the center.', 2);
INSERT INTO 'dancecrib' VALUES (4856, '2013-08-21 08:30:56.008103+00', '2023-02-04 01:19:23.457284+00', 11277, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s, 1s cross RH & cast to face 1st
    corners
9-16::
    1s set & turn corners (2H Skip Change) ending 2nd place opposite
    sides
17-24::
    2s+1s+3s Adv+Ret, 1s petronella to middle as 2s & 3s set turning to
    face up/down & set
25-32::
    1M+2s also 1L+3s Adv+Ret up/down, 1s petronella to own sides as 2s &
    3s set turning to face partner & set', 0);
INSERT INTO 'dancecrib' VALUES (15280, '2022-12-06 11:51:47.540795+00', '2022-12-27 13:41:35.745313+00', 21165, 2, 36088, 'ace', '1-4::  1s+2s & 3s+4s dance 1st 4 bars of tourbillon: all ½ turn ptnrs 2H, 1M, 2L, 3M, 4L lead ptnrs by nearer hand 1 place cl''wise to end 1s & 3s on ladies'' side & 2s & 4s on men''s side, all set to couple opposite

5-8::  1s+2s & 3s+4s dance 4 hands round to the left. Finish facing partner on sidelines

9-16::  All reels of 4 on sides (pass partner RSh to start). Finish facing partner on sides

17-20::  All ½ grand chain, 1 bar per hand. Finish facing partner on sides, ½ way round set

21-24::  3s+4s & 1s+2s dance 2nd 4 bars of tourbillon: all ½ turn ptnrs 2H; 3W, 4M, 1W, 2M lead ptnrs on 1 place cl’wise & all cross RH to opposite sides. Finish (3412)

25-28::  2s dance up middle of set & curve into top position. (3s+4s+1s step down on bars 27-28)

29-32::  All set on sides & cross RH

', 3);
INSERT INTO 'dancecrib' VALUES (4740, '2013-08-21 08:30:54.19891+00', '2023-02-04 01:19:15.724578+00', 1278, 3, NULL, 'ace', '1-8::
    1s+2s 1/2 turn RH & dance RH across 1/2 way, 1/2 turn LH & dance LH
    across 1/2 way
9-16::
    1s+2s dance Chain Progression:
::
    1s+2s 3/4 turn RH, 1M+2L turn LH 1.1/2 times as ptnrs chase cl''wise
    1/2 way, 2s+1s turn RH. 2s end in 1st place own side, 1s facing 1st
    corners
17-24::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partner LH to
    end BtoB in centre (Lady facing up & Man down)
25-32::
    1s dance Figs of 8 on opp sides (LSh to 1st corner to start) & end
    NHJ facing 2M, Lady on Man''s left
33-40::
    1s set to 2M, turn inwards & set to 3L, swivel left & set to 2L &
    turn inwards to set to 3M
41-48::
    1s in prom hold dance reel of 3 across with 3s (RSh to 3M to start)
    & end with 1s dancing down to 4th place.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4742, '2013-08-21 08:30:54.218936+00', '2023-02-04 01:19:15.859011+00', 1282, 3, NULL, 'ace', '1-8::
    All set, 1s+2s also 3s+4s circle 4H left, 1s+2s also 3s+4s set
    facing on sides
9-16::
    All dance RSh ''interchanging'' reels of 4 on sides (when passing LSh
    in centre of reel the inner 2 dancers cross passing LSh & turn to
    right to continue the reels on opposite sides) to end 4 3 2 1 on
    opposite sides
17-24::
    4s+3s also 2s+1s set facing on sides, turn 2H, all dance 1/2 Grand
    Chain to 1 2 3 4
25-32::
    1s lead down to 4th place & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (14896, '2022-06-27 00:18:28.572389+00', '2023-02-04 01:18:25.385737+00', 20887, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast & turn 3/4 LH to face 1st corners (2s step up
    5-6)
9-12::
    1s dance 4 bars ''Hello-Goodbye'' setting (setting to 1st corners &
    partner) to face 2nd corners
13-16::
    1s dance 1/2 diagonal reel of 4 with 2nd corners
17-20::
    1s dance 4 bars ''Hello-Goodbye'' setting (setting to 4th corners pstn
    & partner) pulling back RSh to face 1st corner pstn
21-24::
    1s dance 1/2 diagonal reel of 4 with corners
25-32::
    1s dance RH across, (1M with 3s & 1L with 2s). 3s+1s+2s chase 1/2
    round clockwise to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4827, '2013-08-21 08:30:55.673276+00', '2023-02-04 01:19:22.062952+00', 10463, 3, NULL, 'ace', '1-8::
    1L followed by partner cast down 2 places & dance RH across with 3s
9-16::
    1L followed by partner dance up behind Men to original places &
    dance RH across with 2s
17-24::
    1s+2s+3s dance RSh reels of 3 on own side (1s RSh to 2s)
25-32::
    1L followed by partner cast down 1 place, dance up between 2s cast
    down round 2M to end 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (4828, '2013-08-21 08:30:55.681249+00', '2023-02-04 01:19:22.090364+00', 1410, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-16::
    1s+2s Set+Link & circle 4H round to left
17-24::
    2s+1s+3s RSh reels of 3 on own sides (1s dancing up to start)
25-32::
    2s+1s dance RH across, 1s+3s dance LH across', 0);
INSERT INTO 'dancecrib' VALUES (4829, '2013-08-21 08:30:55.689272+00', '2023-02-04 01:19:22.110551+00', 10007, 3, NULL, 'ace', '{{explanation}}
 Man+2 Ladies per side of square set

1-8::
    All dance RSh reels of 3 with partners
9-16::
    All Men set, 1/2 RH across, dance out thru opposite Ladies & cast to
    right to middle of next side Ladies
17-24::
    Top & bottom trios (side Men with new partners) advance, Ladies 1/2
    turn 2H opposite Lady & retire with new partners, side trios repeat
25-32::
    All circle 12H round & back

{{explanation}}
Repeat from new places & with new partners', 0);
INSERT INTO 'dancecrib' VALUES (11183, '2018-09-30 22:19:33.115882+00', '2023-02-04 01:19:22.141692+00', 13128, 3, NULL, 'ace', '1-8::
    1s set,  cross RH, cast (2s step up); 1s turn LH to face 1st corners
9-16::
    1s dance 1/2 reel of 4 with 1st corners, pass LSh & dance 1/2 reel
    of 4 with 2nd corners.  End in 2nd place opp sides  (3) (1) (2)
17-24::
    3s+1s+2s Set+Link for 3 & circle 6H 1/2 round to Left.  End 1M
    between 3s at top facing down, 1L between 2s facing up
25-32::
    All Set+Link for 3 & circle 6H 1/2 round to Left.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9911, '2017-06-05 11:30:55.124351+00', '2023-02-04 01:19:22.163448+00', 16488, 3, NULL, 'ace', '1-4::
    1s turn 1.1/4 with 2H, moving down then pass RSh to face 1st corners
    (2s step up 3-4)
5-16::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place &1s in middle 1/2 turn RH
    on bar 16 to face opp sides
17-20::
    1M+3s (at top) & 1L+2s dance LH across.  1s end RSh to RSh in middle
    facing opp sides
21-24::
    1M followed by 3L+3M dance down Ladies'' side, across at 3rd place &
    up to 2nd place own side _while_ 1L+2M+2L dance similarly up Men''s
    side, across & down to 2nd place  (2) 1 (3)
25-28::
    2s+1s+3s circle 6H 1/2 round to left
29-32::
    3s+2s turn 2H _while_ 1s turn 2H 1.1/2 times to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4830, '2013-08-21 08:30:55.697289+00', '2023-02-04 01:19:22.192888+00', 1413, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 R&L, 1s+4s (middle couples) dance 1/2 R&L
9-16::
    2s+4s also 1s+3s dance 1/2 R&L, 2s+3s (middle couples) dance 1/2 R&L
    All now on opposite sides 4 3 2 1
17-24::
    All dance 1/2 RSh reels of 4 on sides but middle dancers do not
    complete reel & end in same places, all set & 1/2 turn partners RH.
    1 3 2 4
25-32::
    1s+3s also 2s+4s dance Poussette.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (4831, '2013-08-21 08:30:55.705453+00', '2023-02-04 01:19:22.21397+00', 10159, 3, NULL, 'ace', '1-8::
    1s turn RH then 1L+2M turn LH & end facing 2L (nearer hands joined)
    _while_ 4s turn LH then 4L+3M turn RH & end facing 3L & 2M & 3M
    joining hands to form a crescent
9-16::
    All set twice, 1L turns right about to face partner as 4L turns left
    about to face her partner, 1L dances RSh round her partner to own
    place as 4L dances LSh round her partner to own place _while_ 2s+3s
    cross (Men between Ladies), 2s+3s cross back (Ladies between Men).
    4 2 3 1
17-24::
    All dance reels of 4 on sides
25-32::
    4s+2s also 3s+1s turn RH 1.1/2 times on sides, 1s+4s turn LH 1.1/2
    times on sides.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15220, '2022-11-03 01:19:13.967514+00', '2023-02-04 01:19:22.240059+00', 20458, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret; 1s & 3s Petronella turn & set. (1s+3s in line of 4
    up/down centre, Men facing up, Ladies down)
9-16::
    1s+2s+3s dance Weasel reels:
::
    1s+3s dance part reel of 4 up/down middle but when reaching either
    end they dance clockwise to top/bottom to re-enter reel _while_ 2s
    dance clockwise to replace dancer leaving the reel & all finish reel
    where they started
17-24::
    1s+3s turn partners 1.1/4 to own sides; 1s+2s Set+Link
25-32::
    2s+1s dance RH across; 1s+3s dance LH across', 0);
INSERT INTO 'dancecrib' VALUES (4838, '2013-08-21 08:30:55.763542+00', '2023-02-17 12:03:41.026021+00', 1428, 3, NULL, 'ace', '1-8::

    1L leads 2M down middle to 3rd places on own sides (others step up),

    1M leads 2L down middle to 3rd place (others step up)

9-16::

    1M picks up partner & leads up to top; 2s lead up to 2nd place as 3s

    step down

17-24::

    1s turn RH, cast & turn LH (4 bars) to face 2nd corners

25-32::

    1s set to 2nd corners, set to 1st corners & turn each other RH 1.1/2

    times to 2nd place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (4839, '2013-08-21 08:30:55.771615+00', '2023-02-04 01:19:22.41977+00', 1427, 3, NULL, 'ace', '1-8::
    1L+2M 1/2 turn RH & lead down to 3rd place (others step up), 1M+2L
    repeat
9-16::
    1s 1/2 turn RH & lead up to top (others step down), 2s 1/2 turn RH &
    lead up to 2nd place (3s step down)
17-24::
    1s cross down to dance reflection reels on opposite sides & 1s dance
    down to face 1st corners
25-32::
    1s set to 1st corners, pass RSh & set to 2nd corners & pass RSh to
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4840, '2013-08-21 08:30:55.779873+00', '2023-02-04 01:19:22.431638+00', 10179, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L dance across, down behind top 3 Men, cross &
    dance back to places
9-16::
    1M followed by 2M+3M repeat round top 3 Ladies
17-24::
    1s+2s dance the Knot 1s end facing 1st corners
25-32::
    1s dance RSh round 1st corner & turn LH to face 2nd corners
33-40::
    1s dance LSh round 2nd corners & turn RH 1.3/4 times to end in 2nd
    place own side
41-48::
    2s+1s+3s dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12715, '2020-04-11 10:50:05.698512+00', '2023-02-04 01:18:19.000464+00', 14980, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s also 3s+4s, Set & Rotate. Finish 2 1 4 3, with 1M and 4L
    facing out
9-10::
    1s+4s dance 1/2 LH across
11-12::
    1M casts down behind 3L _while_ 1L dances down in front of 3M. At
    same time, 4M dances up in front of 2L _while_ 4L casts up behind 2M
13-16::
    1L followed by partner casts up behind 3M, crossing to 3rd place, 1s
    finish in 3rd place own sides facing down
::
    At same time, 4M followed by partner casts behind 2L crossing to 2nd
    place, 4s finish in 2nd place own sides facing up

{{title}}
Reel

17-24::
    All dance reels of 4 own sides (1s face 3s, 2s face 4s, pass RSh)
25-28::
    2s+4s also 1s+3s dance RH across
29-32::
    4s+1s dance LH across. Finish 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3903, '2013-08-21 08:30:38.909946+00', '2023-02-04 01:18:19.031128+00', 10927, 3, NULL, 'ace', '1-4::
    1L+2M also 3L+4M cross passing LSh & cast RSh round partner into
    middle (Ladies face down & Men up)
5-12::
    1L+2M+3L+4M dance reel of 4 up/down middle
13-16::
    1L+2M also 3L+4M turn RH (4 bars) to end facing partners in diagonal
    line
17-24::
    1s+2s also 3s+4s dance diagonal LSh reels of 4 ending in original
    places
25-32::
    1s set & cross down between 2s, cast down behind 3s & cross to 4th
    places', 0);
INSERT INTO 'dancecrib' VALUES (4841, '2013-08-21 08:30:55.787983+00', '2023-02-04 01:19:22.442994+00', 1430, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on opposite sides, 1s & 2s dance on 1 more place
    to end with 1s facing 1st corners
9-16::
    1s set to 1st corners & turn 2H, set to 2nd corners & turn 2H & end
    2nd place opposite sides
17-24::
    2s+1s+3s circle 6H left for 2 bars, turn the woman on right 2H &
    continue to circle to places
25-32::
    All petronella turn into centre, 1s full turn 2H _while_ 2s & 3s 1/2
    turn 2H, all petronella turn to own sides & set
33-40::
    1s cast (Man up & Lady down) into reels of 3 across (Man with 2s &
    Lady with3s), 1s+3s 1/2 turn on sides to 3rd place (1s dancing out)', 4);
INSERT INTO 'dancecrib' VALUES (4842, '2013-08-21 08:30:55.797717+00', '2023-02-04 01:19:22.602018+00', 1431, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, in prom hold dance up between 2s & cast round
    2M
9-16::
    1s cross, cast round 3L & lead up to 2nd place, cast up 1 place on
    own sides & lead down to 2nd place
17-24::
    1s+3s circle 4H round & back
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4837, '2013-08-21 08:30:55.75526+00', '2023-02-04 01:19:22.628578+00', 1426, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on own sides (in & down to start)
9-16::
    1s+2s turn on sides 1.1/2 times (Men RH & Ladies LH0, 1s dance
    between 3s & cast up to 2nd place on own sides
17-24::
    1s+1st corners Adv+Ret, 1s+1st corners turn RH
25-32::
    1s+2nd corners Adv+Ret, 1s+2nd corners turn LH', 0);
INSERT INTO 'dancecrib' VALUES (4843, '2013-08-21 08:30:55.813446+00', '2023-02-04 01:19:22.660981+00', 10764, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    All set, 1s & 4s cross down/up _while_ 2s & 3s cast up/down, 2s+1s
    also 4s+3s turn on sides (LH on Ladies'' side & RH on Men''s side)
9-16::
    2L,1M, 4M & 3L dance Ladies'' Chain (diagonally)
17-24::
    All chase anticlockwise 1/2 way & 3s+4s also 1s+2s all turn RH on
    sides
25-32::
    3M,4L,1L & 2M dance Ladies'' Chain (diagonally)
33-40::
    1s+4s set, dance RH across 1/2 way, set & cross RH.  3 1 (4)(2)', 0);
INSERT INTO 'dancecrib' VALUES (4845, '2013-08-21 08:30:55.836014+00', '2023-02-04 01:19:22.72801+00', 9056, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross down LH to bottom & cast up round
    4s to 3rd place own sides _while_…
::
    2s stand for 2 bars, step up, cross RH & cast into 2nd place _while_
    …
::
    3s stand for 4 bars, set & dance up to top place
9-16::
    1s set, dance up to top & cast down to give partner LH & 1st corners
    RH _while_ …
::
    2s cross down LH to bottom, cast up round 4s to 3rd place, set &
    dance up to top place _while_ …
::
    3s cross RH, cast 1 place, cross down LH to bottom & cast up round
    4s to 3rd place
17-24::
    1s Bal-in-Line with 1st corners, 1/2 turn corners, Bal-in-Line, 1/2
    turn corners to end in centre facing opposite sides
25-32::
    1s set in double triangle formation with 2s+3s, cast down 1 place on
    opposite sides to end in centre facing own sides, 1s set in double
    triangle formation with 3s 4s, 1s cast to bottom on own sides', 0);
INSERT INTO 'dancecrib' VALUES (10441, '2018-02-24 07:52:19.900592+00', '2023-02-04 01:19:22.753687+00', 17468, 3, NULL, 'ace', '1-8::
    1s dance down between 3s (2s step up bars 3-4), cast up, cross LH &
    cast Left (1M up, 1L down) to end 1L facing 3L, 1M facing 2M
9-12::
    2s+1M, 3s+1L dance 1/2 RSh reels of 3 across
13-16::
    1s cross to opp sides to dance 1/2 RSh reels of 3 on sides (all on
    opposite sides)
17-20::
    3s+1L, 2s+1M dance 1/2 LSh reels of 3 across
21-24::
    1s cross to opp sides to dance 1/2 LSh reels of 3 on sides (2s & 3s
    on own sides), finishing 1s LHJ facing 1st corners
25-28::
    1s+1st corners set, 1s turn inwards to join RH facing 3rd corners,
    1s+3rd corners set with corners advancing
29-32::
    1s+1st corners dance RH across, 1s finishing RHJ facing 2nd corners
33-36::
    1s+2nd corners set, 1s turn inwards to join LH facing 4th corners,
    1s+4th corners set with corners advancing
37-40::
    1s+4th corners dance LH across, 1s finishing in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4844, '2013-08-21 08:30:55.822326+00', '2023-02-17 11:58:53.157069+00', 1437, 3, NULL, 'ace', '1-8::

    1s lead down below 2s, cross & cast down behind 3s to 3rd place

    opposite sides (2s+3s step up), 2s repeat this Fig (3s+1s step up)

9-16::

    3s repeat the Fig (1s+2s step up) & all turn partners 2H 1.1/2 times

17-24::

    1s lead down below 2s, cross & cast down behind 3s, lead up to top,

    cross & cast to 2nd place own sides (2s step up)

25-32::

    1s dance down below 3s, cast up to 2nd place & all turn 2H once

    round', 0);
INSERT INTO 'dancecrib' VALUES (15281, '2022-12-06 12:09:11.68299+00', '2022-12-06 13:29:20.910567+00', 21161, 2, 36088, 'ace', 'The tune is 6 bars + 6 bars + 10 bars + 10 bars

1-4::    1s+2s ½ double fig of 8. 2s finish facing out
5-6::    1M+2M LH, also 1L+2L RH, turn ½ 
7-10::   1s+3s ½ double fig of 8. 1s dance down sides to begin as 3s cross up. 1s finish facing out.
11-12:: 1M+3L LH, also 1L+3M RH, turn ½way
13-16:: 1s cross RH & cast up. 
17-22:: 2s+1s+3s set & link; all cross RH w/dancer opposite
23-26:: 2s, 1s & 3s set & link to finish on the sidelines
27-30:: 1M ½ fig of 8 round 3s as 1L ½ fig of 8 round 2s
31-32:: 2s+1s+3s set   
', 3);
INSERT INTO 'dancecrib' VALUES (12068, '2019-08-30 09:53:41.472665+00', '2023-02-04 01:18:19.090417+00', 19063, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up); 1L+2s & 1M+3s dance RH across.  1s
    pass RSh to flow into…
9-12::
    1M+2s & 1L +3s dance LH across flowing into.
13-16::
    "Snake Pass": 1M followed by 2M+2L dance down Ladies'' side, across &
    up to 2M place _while_ 1L followed by 3L+3M dance up Men''s side,
    across & down to 2L place.  3 1 2
17-24::
    1s+2s set, dance 1/2 RH across;  3s, 1M+2M, 1L+2L & 4s turn 2H to
    form square formation, NHJ with ''partner'' & all set
25-32::
    All set to corners & dance La Barratte with corners
::
    _27-28_   Man 1/2 turns opposite Lady RH & retains hand but at arm''s
    length from each other
::
    _29-30_   Man retraces steps with Lady turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies original
    place) & releasing Ladies RH she turns under Mans left arm until
    almost in original places
::
    _31-32_   Couple change places LH to opposite places, ending in
    square formation again NHJ
33-40::
    All set, 2s+1s turn partners 1.1/2 with 2H to end on sides in
    1st/4th place _while_ 3s+4s (side ''couples'') dance RH across to end
    in 2nd/3rd place.  All join hands on sides & set.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (3906, '2013-08-21 08:30:38.948187+00', '2023-02-04 01:18:19.334577+00', 8923, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, turn RH _while_ 2s+3s dance 1/2 R&L
    (3)(1)(2)
9-16::
    Men dance "Snowball Chase", all dancers travelling anticlockwise:
::
    3M crosses above partner & down behind Men''s side, crosses below 3rd
    place & up Ladies'' side back to place _while_ 1M stands for 2 bars &
    dances similarly _while_ 2M waits 4 bars & dances similarly
17-24::
    Ladies dance "Snowball Chase":
::
    2L crosses below partner & up Ladies'' side, across top, down Men''s
    side back to place _while_ 1L stands for 2 bars & dances similarly
    _while_ 3L waits 4 bars & dances similarly
25-32::
    1s Petronella turn & set twice, back to own side, _while_ 3s+2s set
    & Petronella turn twice to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4846, '2013-08-21 08:30:55.845707+00', '2023-02-04 01:19:22.907225+00', 1446, 3, NULL, 'ace', '1-8::
    1L sets advancing & turns 2M RH, 1L sets to 2L & turns LH
9-16::
    1M sets advancing & turns 2L LH, 1M sets to 2M & turns RH
17-24::
    1s+2s+3s dance Grand Chain with 1s+2s changing place RH on sides &
    3s crossing RH to start, end with 1s turning partner LH to face 2s
25-32::
    1s+2s dance reel of 4 across (1M+2M also 1L+2L pass RSh to start)
    ending with 1s in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (4847, '2013-08-21 08:30:55.85644+00', '2023-02-04 01:19:22.94309+00', 12023, 3, NULL, 'ace', '1-4::
    1M+3L change places passing RSh & twirl into each others place as
    1L+3M cast & chase clockwise to each others place
5-8::
    1M+3L chase clockwise to places as 1L+3M change places passing RSh &
    twirl into original places
9-16::
    2s set advancing & turn RH, dance down below 3s & cast back to
    places
17-24::
    2s reflection reels on the side (2s up between 1s to start)
25-32::
    1s+2s change places on the sides (Men LH, Ladies RH) & 1s turn RH,
    1s dance dow below 3s & cast up to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4848, '2013-08-21 08:30:55.866091+00', '2023-02-04 01:19:22.986158+00', 14395, 3, NULL, 'ace', '1-8::
    1s lead down & back to 2nd place in middle
9-16::
    1s turn RH, 3L followed by 1L+2L cast to top & dance down diagonally
    to 3L approx in 3M place _while_ 2M followed by 1M+3M cast to bottom
    & dance up diagonally (pass Ladies RSh) to 2M approx in 1L place
17-24::
    All set & turn partners 2H, all set & turn partners 2H to end on own
    sides
25-32::
    2s+1s dance Diamond Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14644, '2022-03-07 02:19:09.314112+00', '2023-02-04 01:19:23.034789+00', 20651, 3, NULL, 'ace', '1-8::
    1s+2s+3s chase clockwise 1/2 round; 1s dance up NHJ to 2nd place
    facing opp sides (2s step down 5-6) & all set as Double Triangles
9-12::
    1s dance out (PdeB) to opp sides, pull back RSh _while_ 3s & 2s
    cross set (3s pass RSh, 2s pass LSh i.e. Men on outside), join hands
    in Inverted Double Triangle & all set
13-16::
    1L+3M+2M & 1M+3L+2L dance 1/2 RH across. End 1L facing 3s, 1M facing
    2s in Crown Triangle & all set
17-20::
    1L dances down & 1M dances up (PdeB) & pull back RSh to face up/down
    _while_ 2s dance down to join with 1L & 3s dance up to join hands
    with 1M in Inverted Crown Triangle (3s pass 2s on outside) & all set
21-24::
    1M+3s & 1L+2s dance 1/2 RH across to end (3) (1) (2); 3s+1s+2s 1/2
    turn partner RH finishing in middle facing up
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4849, '2013-08-21 08:30:55.874124+00', '2023-02-04 01:19:23.062983+00', 10771, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of 8 (1M round 2s, 1L
    round 3s)
9-16::
    1s dance 1/2 reels of 3 on sides (1M gives RSh to 3M, 1L RSh to 2L),
    1s 1/2 reels of 3 across (giving LSh to 1st crnr pstn) all end opp
    sides
17-24::
    3s+1s+2s Set+Link for 3 twice
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14793, '2022-05-05 00:19:11.351386+00', '2023-02-04 01:19:23.131456+00', 17104, 3, NULL, 'ace', '1-8::
    1s & 4s dance in to dance Figs 8 on sides round 2s & 3s
9-16::
    All set & cross RH; all set & 1/2 turn partner RH, 1s & 3s face
    down, 2s & 4s face up NHJ
17-20::
    2s & 4s make arches & dance up as 1s & 3s dance down under arches;
    3s & 2s set turning in _while_ 1s & 4s change places,1s making arch
    & 4s dancing under
21-24::
    1s & 2s dance under arches made by 4s & 3s; 1s & 4s set turning in
    _while_ 2s & 3s change places, 2s making arch & 3s dancing under 4 3
    2 1
25-28::
    4s+3s also 2s+1s dance RH across, 4s & 2s face up in centre
29-32::
    4s cast to 3rd place _while_ 2s dance up to top & all couples set.
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (3920, '2013-08-21 08:30:39.161028+00', '2023-02-04 01:18:20.664585+00', 40, 3, NULL, 'ace', '1-8::
    1s+2s set on sides, turn 2H, set to partners & turn 2H into
    Allemande hold
9-16::
    1s+2s Allemande 1s end facing 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting, into middle facing partner, clap &
    petronella turn to 2nd place
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4851, '2013-08-21 08:30:55.89031+00', '2023-02-04 01:19:23.162209+00', 8165, 3, NULL, 'ace', '{{title}}
Northern Hemisphere

1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s (on opp sides) in prom hold dance a reel of 3 across with 2s
    giving RSh to 2nd Man
17-24::
    1s (on opp sides) dance down to bottom crossing & cast up to 2nd
    place, 1s turn RH (1s end facing out on own side)
25-32::
    1s cast right as 2s & 3s petronella turn into centre & 1s dance thru
    2s/3s as they set, 1s cast to 2nd place as 2s & 3s petronella turn
    to opposite sides & all set.  End 2 1 3 all on opposite sides

{{title}}
Southern Hemisphere

{{explanation}}
Repeat having crossed the Line into the Southern Hemisphere. New 1st couple are at the other end of the set reversing after each 32 bars', 0);
INSERT INTO 'dancecrib' VALUES (4852, '2013-08-21 08:30:55.898334+00', '2023-02-04 01:19:23.19433+00', 10356, 3, NULL, 'ace', '1-4::
    2L+3M turn RH 1.1/2 times _while_ 1M+4L cross down/up & cast to each
    others place
5-8::
    2M+3L turn RH 1.1/2 times _while_ 1L+4M cross down/up & cast to each
    others place.  (4)(3)(2)(1)
9-16::
    4s+3s also 2s+1s circle 4H round to left, 3s+2s circle 4H round to
    right
17-24::
    All dance 1/2 reels of 4 on sides, all set & 1/2 turn 2H.  1 2 3 4
25-32::
    1s+2s also 3s+4s dance 1/2 Diamond Poussette, 1s+4s dance 1/2
    Diamond Poussette.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4853, '2013-08-21 08:30:55.906428+00', '2023-02-04 01:19:23.227081+00', 1447, 3, NULL, 'ace', '1-4::
    2s cross RH & cast 1 place to right _while_ 3L/1M step up/down to
    2nd place
5-8::
    1M+3L cross LH & cast 1 place to left _while_ 1L/3M step up/down
    _while_ 2s set & change places RH diagonally
9-16::
    1L+3M cross RH & cast to right _while_ 2s step up/down _while_ 1M+3L
    set & change places LH, then 1L+3M set & change places RH.  3 2 1
17-24::
    3s+2s+1s cross RH & 2s+1s change places LH on sides, Men circle 3H
    to left _while_ Ladies also circle 3H to left
25-32::
    All drop hands & chase in separate interlacing circles (Men passing
    a Lady RSh) & open out into 6H round to left 1/2 way.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4855, '2013-08-21 08:30:55.996677+00', '2023-02-04 01:19:23.416348+00', 1451, 3, NULL, 'ace', '1-4::
    1s+2s+3s cross RH (1s & 3s face out), 1s & 3s cast 2 places to
    change places (passing LH)
5-8::
    1s & 3s dance 1/2 RH across in middle back to original places. &
    cast 2 places again to end 3 (2) 1
9-16::
    3s+2s dance 1/2 R&L; 1s+3s dance 1/2 R&L (1s end facing 1st
    corners). 2 (1) 3
17-24::
    1s dance ''Hello-Goodbye'' setting, end in centre facing partner &
    cross LH up/down
25-32::
    1s dance reels of 3 across (Lady with 2s & Man with 3s) giving LSh
    to 1st corners', 0);
INSERT INTO 'dancecrib' VALUES (4858, '2013-08-21 08:30:56.086854+00', '2023-02-04 01:19:23.668492+00', 9847, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross LH & cast round 4th corner to end
    Lady between 2s facing down & Man between 3s facing up
9-16::
    1s pass RSh to dance Crown Triangles & end facing 1st corners
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners & 1/2 reel with 2nd
    corners
25-32::
    1s dance RH across Man with 3s (at top) & Lady with 2s, 3s+1s+2s
    circle 6H round to left 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (4859, '2013-08-21 08:30:56.095169+00', '2023-02-04 01:19:23.697068+00', 8193, 3, NULL, 'ace', '{{explanation}}
Each couple dance 48 bars. A New Couple starts after 24 bars (ie on bars 1, 25, 49, 72 & 96)

1-8::
    1s+2s dance 3/4 double Fig of 8 (1s cross down to start), 1s cast
    (loop) into 2nd place _while_ 2s cross RH
9-16::
    2s+1s dance Diamond Poussette
17-24::
    1s+3s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
25-32::
    (New Couple starts as at bar 1) _while_ 1s+4s+5s dance reels of 3 on
    sides (1s out & down to start) & 1s cast 1 place as 4s dance up
33-40::
    1s+5s dance R&L
41-48::
    1s+5s 1/2 turn RH, circle to left 1/2 way & set twice to partners
    (New 1st couple now at bar 24 & another couple ready to start)', 0);
INSERT INTO 'dancecrib' VALUES (8313, '2014-07-29 12:58:53.618032+00', '2023-02-04 01:19:23.729432+00', 15071, 3, NULL, 'ace', '1-8::
    1L followed by 1M cast behind 2L, cross set, cast down behind 3M to
    3rd place own side (2s+3s step up 7-8)
9-16::
    1s dance Reflection Reels of 3 on sides (1s cross up, 3s out & down,
    2s in & down), 1s crossing down to own side on bar 13 (from 1st
    place)   (2 3 1)
17-24::
    All Set & Rotate for 3 couples    1 3 2
25-32::
    All set, 1s dance 1/2 reel of 3 on sides (1s pass 3s LSh to start),
    1s+3s continue reel to finish 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4860, '2013-08-21 08:30:56.103196+00', '2023-02-04 01:19:23.755363+00', 1457, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 3/4 turn RH & (retaining hands) set
    ending turning right about to face 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting & end turning RH into…
17-24::
    1s dance RSh reels of 3 across (1M with 2s, 1L with 3s) & end 2nd
    place own sides
25-32::
    1s dance RSh reels of 3 on own sides', 0);
INSERT INTO 'dancecrib' VALUES (4861, '2013-08-21 08:30:56.112839+00', '2023-02-04 01:19:23.78447+00', 8045, 3, NULL, 'ace', '1-8::
    1s turn RH, then LH back
9-16::
    1s+2s dance RH across, LH back
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (13059, '2020-08-10 00:19:09.817785+00', '2023-02-04 01:19:23.823205+00', 16466, 3, NULL, 'ace', '1-8::
    1s cross down (2s step up), 1s cast (1L down round behind 3M & 3L,
    1M round 2L & 2M) to face 1st corners LHJ with partner
9-16::
    1s+1st corners set, 1s 1/2 turn corner RH to flow into 1/2 RSh reel
    on 1st corner diagonal.  1s end in 3rd corner place _while_ 1st
    corner (persons) finish in centre LHJ facing 2nd corners
17-24::
    Repeat 9-16.  1st corner persons finish in 2nd corner places own
    side (2M in 3M place, 3L in 1L place) _while_ 2nd corner (persons)
    finish in centre facing 3rd corner (pstn)
25-32::
    Repeat 9-16. 1st couple finish in centre
33-40::
    1s turn 3/4 LH to 2nd place own side _while_ all corners chase 1
    place clockwise & set (now 2 1 3); 1s dance up & cast round 2s to
    2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (4862, '2013-08-21 08:30:56.120913+00', '2023-02-04 01:19:23.859379+00', 1461, 3, NULL, 'ace', '1-4::
    1s cross RH & cast 2 places to below 3s (2s step up 3-4)
5-8::
    1s cross RH & cast up 1 place & into centre (join LH) facing
    opposite sides _while_ 2s & 3s turn partners RH once round, retain
    RH & 1L+2s also 1M+3s join RH
9-16::
    All set & all 1/2 turn partner; 1M+2s also 1L+3s join RH, all set &
    all 1/2 turn partners to end with 2s & 3s on sides facing out, 1s in
    centre, 1L facing up, 1M facing down …
17-24::
    1s dance reels of 3 across, LSh to 1st corner (1M with 3s & 1L with
    2s) into…
25-32::
    1s dance reels of 3 on own sides, dancing up between 2s (1s in/up,
    2s out/down, 3s out/up to start) All give hands when meeting in reel', 0);
INSERT INTO 'dancecrib' VALUES (4863, '2013-08-21 08:30:56.128929+00', '2023-02-04 01:19:23.884562+00', 11996, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set+Link & circle 4H round to left
9-16::
    1s+4s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides  2 4 1 3
17-24::
    4s+1s circle 4H round to left, set advancing in diagonally & turn
    inwards to dance out to own sides to face corners
25-32::
    All dance RSh reels of 4 on sides.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4864, '2013-08-21 08:30:56.137021+00', '2023-02-04 01:19:23.91117+00', 1465, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels on own sides 1s dancing in & down, 2s dance out
    & up, 3s in & up to start
9-16::
    1s+2s dance double Fig of 8
17-20::
    "Muirland Wille" figure:
::
    1s dance down middle, cross over & cast up to 2nd place on opposite
::
    _while_ 2s set & cross RH to 3rd place on opposite side
::
    _while_ 3s cast up to 1st place & cross RH to opposite side
21-24::
    3s+1s+2s turn partners RH once round
25-32::
    3s+1s+2s Set+Link for 3 twice', 0);
INSERT INTO 'dancecrib' VALUES (4866, '2013-08-21 08:30:56.154693+00', '2023-02-04 01:19:24.097832+00', 1467, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on own sides (between 2s to start)
9-16::
    1s dance down for 2, up to top, cast 1 place & turn RH to give LH to
    1st corners
17-24::
    1s+1st corners Bal-in-Line, 1s turn to 2nd corners, Bal-in-Line &
    turn RH to 2nd places own sides
25-32::
    2s+1s+3s set, cross RH, set & cross back', 0);
INSERT INTO 'dancecrib' VALUES (8995, '2015-11-30 08:59:38.14083+00', '2023-02-04 01:19:24.125255+00', 12757, 3, NULL, 'ace', '1-8::
    1M dances in, casts to 2nd place (2M step up) & turns 3L RH.  1M
    finishes in 2nd place
9-16::
    1L repeats, turning 3M LH (2L steps up 11-12)
17-24::
    1M+3s also 1L+2s dance RH across. 1s pass RSh 1M+2s also1L+3s dance
    LH across   2 1 3 4
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4868, '2013-08-21 08:30:56.170851+00', '2023-02-04 01:19:24.193311+00', 1473, 3, NULL, 'ace', '1-4::
    1s & 3s advance & 1/2 turn opposite partner RH & cast out to
    opposite side
5-8::
    1s & 3s chase 1/4 round set cl''wise & dance in passing 2s/4s RSh
    curving in to face 2s/4s as 2s & 4s repeat bars 1-4 & turn right
    about to face 1s/3s
9-16::
    All dance parallel reels of 4 across set
17-24::
    2s+1s also 4s+3s circle 4H once round to left, set & dance RH across
    1/2 way
25-32::
    2s+4s dance LH across once round, 2s & 4s dance out through sides
    passing opp partner RSh & chase round set cl''wise to next place', 0);
INSERT INTO 'dancecrib' VALUES (4869, '2013-08-21 08:30:56.179026+00', '2023-02-04 01:19:24.214528+00', 9462, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-4::
    1s+2s also 3s+4s Set+Link ending with 1s+4s passing RSh to order 2
    (4) 1 (3)
5-8::
    4s+1s dance RH across & end with 4M+1L also 4L+1M in prom hold
    facing out
9-12::
    4M+1L & 4L+1M dance 1/2 diagonal reel of 4 with 2M & 3M (1st
    corners) & end turning inwards to face down/up
13-16::
    4M+1L & 4L+1M dance 1/2 diagonal reel of 4 with 2L+3L (4th corners)
    & end turning inwards to face out
17-20::
    4M+1L & 4L+1M dance 1/2 diagonal reel of 4 with 3M & 2M (3rd
    corners) & end turning inwards to face up/down
21-24::
    4M+1L & 4L+1M dance 1/2 diagonal reel of 4 with 3L+2L (2nd corners)
    & end in order 2 (4) 1 (3)
25-32::
    4s  & 1s dance 1/2 Figs of 8 round end couples, 2s+4s also 1s+3s
    circle 4H round to left.  2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (4870, '2013-08-21 08:30:56.187259+00', '2023-02-04 01:19:24.236552+00', 1474, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    1M & 4L dance Figs of 8 on the Mens side _while_ 1L & 4M dance Figs
    of 8 (1s & 4s dance in to start & give hands when passing)
9-12::
    1s & 4s cross RH & cast in 1 place _while_ 2s & 3s 1/2 turn RH &
    lead up/down to ends.  (2)(1)4 3
13-16::
    1s & 4s dance 1/2 Figs of 8 round end positions as 2s & 3s cast into
    1/2 Figs of 8.  2 1(4)(3)
17-24::
    1s+4s circle 4H round to left 1/2 way & 4L+1M also 4M+1L turn 2H,
    4s+1s circle 4H to left once round & turn right about to face
    up/down
25-32::
    All dance RSh reels of 4 on sides.  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (4873, '2013-08-21 08:30:56.214572+00', '2023-02-04 01:19:24.429552+00', 1477, 3, NULL, 'ace', '1-4::
    1L+2L also 3M+4M cross passing partner LSh & cast 2 places
5-8::
    3M+4M dance 1/2 diag R&L with 1L+2L
9-12::
    1M+2M also 3L+4L cross passing opposite dancer RSh & cast 2 places
13-16::
    3L+4L dance 1/2 diag R&L with 1M+2M.  2 1 4 3
17-24::
    1s & 4s (middle couples) dance 1/2 Figs of 8 round end couples &
    turn partners 1.1/2 RH. 3s dance in bar 24 ready for …
25-32::
    1s+4s+3s (bottom 3 couples) dance Allemande.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (10182, '2017-10-17 00:37:31.282744+00', '2023-02-04 01:19:24.742545+00', 1479, 3, NULL, 'ace', '1-8::
    1s+3s join both hands with partner & slip step across (Men BtoB) &
    slip step back (Ladies BtoB)
9-16::
    2s+4s repeat
17-24::
    1s+3s dance RH across & LH back to places
25-32::
    2s+4s repeat
33-40::
    1s+3s basket swing  (Alt. All dance Grand Chain 1/2 way & set)
41-48::
    2s+4s basket swing  (Alt. All dance Grand Chain 1/2 way back to
    places & set)
49-56::
    All circle left (Alt. All circle 8H round & back)
57-64::
    All promenade back to places (Alt. All swing partners)', 0);
INSERT INTO 'dancecrib' VALUES (4876, '2013-08-21 08:30:56.323417+00', '2023-02-04 01:19:24.860117+00', 1480, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, 2s cross RH _while_ 1s dance up to top to form
    a line of 4 across facing up, 1s+2s set & turn right to face down
9-16::
    1s+2s dance down in line, turning right dance back to top 1s ending
    back-to-back facing other partner
17-24::
    1s+2s dance RSh reel of 4 across & 1s end facing 1st corners
25-32::
    1s turn 1st corners RH, turn partner LH, turn 2nd corners RH & turn
    partners LH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (15284, '2022-12-08 10:41:37.570412+00', '2022-12-08 10:44:24.754762+00', 21193, 1, 202, 'ace', '1--::

  All W (1W leading) dance cclw round M line to places

9--::

  All W set | dance RSh round P _while_ all M with arms crossed tap right heel. All couples finished in centre facing P

17--::

  4C Poussette (2,3,4,1)

25--::

  All Turn half-way and Cast ; repeat (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (15287, '2022-12-08 16:03:55.428677+00', '2022-12-08 16:05:46.260423+00', 18019, 2, NULL, 'ace', '1-8:: 1s, 2s & 3s dance Inveran Reels

9-12:: 1s & 2s set & link

13-16:: 1s turn LH 1 1/2 times to face 2nd corners

17-24:: 1s & 2nd corners dance half a reel of four; 1s pass LS; 1s & 1st corners dance half a reel of four; 1s pass RS to finish on opp sides [3x, 1x, 2x]

25-32:: 3s, 1s & 2s set advancing, all pull back RS to face clw; al; all dance RH across half way [2,1,3]', 4);
INSERT INTO 'dancecrib' VALUES (13060, '2020-08-10 00:19:10.735005+00', '2023-02-04 01:19:24.918384+00', 19308, 3, NULL, 'ace', '1-8::
    1s turn 2H, dance down & cross below 3s; 1s cast up & 3/4 turn RH
    remaining in centre
9-16::
    1M+2s also 1L+3s dance LH across, pass LSh; 1s dance 3/4 RH across
    with other couple, 2s+3s 1/2 turn RH into line up/down _while_ 1s
    cast to 2nd place own side (1L face down, 1M face up)
17-24::
    2s+1s+3s dance Weasel reels:
::
    2s+3s dance part reel of 4 up/down middle but when reaching either
    end they dance clockwise to top/bottom to re-enter reel _while_ 1s
    dance clockwise to replace dancer leaving the reel & all end where
    they started
25-32::
    2s+3s set, turn 3/4 RH;  2s+1s+3s chase clockwise 1/2 round to opp
    sides
33-40::
    3s+1s+2s set & dance La Baratte:
::
    Men 1/2 turn Lady RH & retain hands but at arm''s length from each
    other
::
    Men retrace steps with Lady turning right under Man''s arm briefly
    into Allemande hold (Man behind Lady facing Ladies'' original place)
    & releasing Ladies'' RH she turns under Man''s left arm until almost
    in original places
::
    Couples change places LH to opposite places.  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4872, '2013-08-21 08:30:56.206514+00', '2023-02-17 11:49:26.112894+00', 1476, 3, NULL, 'ace', '1-8::

    1s set, turn 2H, 1s+2s dance 1/2 R&L

9-16::

    2s+1s turn 2H to own sides, 1s dance up to top & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (8769, '2015-06-15 11:40:21.503056+00', '2023-02-04 01:18:19.449538+00', 16117, 3, NULL, 'ace', '1-10::
    1s+2s change places on sides (Men LH, Ladies RH), 2s+1s+3s Set+Link;
    1M+3s (at top) & 1L with 2s dance 1/2 RSh reels of 3 across (RSh to
    person on right).  End (3) (1) (2)
11-20::
    1s lead down (4 bars) 1L turns under partner''s Left arm (2 bars), 1s
    lead up to 1st place own side & face out (3s step down 19-20)
21-30::
    1s+3s change places on sides (1M+3L LH, 1L+3M RH); 3s+1s+2s dance
    1/2 reflection (mirror) reels on sides (1s in/down); all set; 2s+3s
    cross LH as 1s turn LH to face 4th crnr pstns
31-40::
    1s dance Hello-Goodbye setting (6 bars) to 2nd place opp sides; 1s
    turn (birl) to face up NHJ

{{explanation}}
End of 2nd time:  1s end NHJ in middle facing down & on bars 1-2 of next repeat they1/2 turn couple below into 4th place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13061, '2020-08-10 00:19:10.765662+00', '2023-02-04 01:19:24.945753+00', 16893, 3, NULL, 'ace', '1-8::
    1s & 4s set, dance NHJ towards each other meeting in centre & circle
    4H round to left (2s/3s step up/down 3-4)
9-16::
    All 4 couples set, 1/2 turn partner RH pull back RSh & dance out to
    opp sides & all set
17-24::
    1s & 4s dance NHJ out of end (1s up, 4s down) & cast to 2nd/3rd
    place; 1s+4s Set+Link. (2) (4) (1) (3)
25-32::
    All 4 couples set, 1/2 turn partner 2H & face up NHJ, set & curve
    out to own sides 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4878, '2013-08-21 08:30:56.33939+00', '2023-02-04 01:19:24.967908+00', 1485, 3, NULL, 'ace', '1-8::
    1s+2s set adv & 1M also 2L cross in front of other ptnr to Men
    facing up & Ls down, all set & 2M also 1L cross to right, all set &
    retire to opp sides
9-16::
    1s lead up, cross to own sides & cast 1 place, 2s lead down, cross
    to own sides & cast up to 1st place
17-24::
    2s+1s cross RH & circle 4H round to left 1/2 way, 1s+2s cross LH &
    circle 4H round to right 1/2 way
25-32::
    2s+1s dance double Fig of 8 (1s crossing up to start)', 4);
INSERT INTO 'dancecrib' VALUES (12861, '2020-06-03 16:25:41.243079+00', '2023-02-04 01:19:24.998981+00', 19733, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 2 places, meet taking prom hold & dance up to face
    2L (2s step up 5-6)
9-12::
    1s dance path of 1/2 diag reel of 3 (RSh to 2L) & end facing 2M
    _while_ 2L+3M 1/2 turn RH, pull back RSh & dance out to opp corners
13-16::
    1s dance path of 1/2 diag reel of 3 (RSh to 2M) & end in centre,
    drop hands & facing partner''s side _while_ 2M+3L 1/2 turn RH, pull
    back RSh & dance out to opp corners. (3) (1) (2)
17-24::
    3s+1s+2s dance reels of 3 on opp sides (1M down RSh to 2M, 1L up,
    RSh to 3L).  End in lines of 3 across, 1M between 3s at top, 1L
    between 2s at bottom)
25-28::
    1s 1/2 turn RH, pull back RSh & dance out to opp ends facing out
    _while_ 3s+2s dance 1/2 R&L
29-32::
    1s cast to right into 2nd place own side, all set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4879, '2013-08-21 08:30:56.34977+00', '2023-02-04 01:19:25.031411+00', 1486, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, dance 1/2 Fig of 8 round 2s
9-16::
    1s turn 3s with nearer hands (1s dancing between 3s) & turn 2s with
    other hand
17-24::
    1s+3s dance RH across, 1s+2s dance LH across
25-32::
    2s+1s+3s dance reels of 3 on sides (1s giving RSh to 3s to start)', 0);
INSERT INTO 'dancecrib' VALUES (4880, '2013-08-21 08:30:56.357848+00', '2023-02-04 01:19:25.052329+00', 14519, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, turn LH 1.1/2 times to 1L facing her 1st
    corner with her partner behind her
9-16::
    1s dance Alternating Tandem 1/2 reel of 3 with 1st corners, 1s dance
    Alternating Tandem 1/2 reel with her 2nd corner
17-24::
    1s dance Alternating Tandem 1/2 reels of 3 with Mans 1st corner
    (pstn),1s dance Alternating Tandem 1/2 reel with Mans 2nd corner
    (pstn)
25-32::
    1s dance down between 3s & cast up, 1s dance up between 2s & cast to
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (14516, '2022-01-10 02:18:54.752354+00', '2023-02-04 01:19:25.070328+00', 17957, 3, NULL, 'ace', '1-8::
    1s cross down to dance 1/2 mirror reels of 3 on opp sides; 1s turn
    2s 1.1/2 times (1M+2L RH, 1L+2M LH) to end facing 1st corners
9-24::
    "Best Set in the Hall" figure:
::
    _9-12_    1s set to 1st corners & dance RSh round each other into
    3rd corner (pstn) _while_ 1st corners dance in & turn right about to
    face their original position
::
    _13-16_  1s+1st crnr person set & 1st crnr persons dance RSh round
    each other into diag opp crnrs _while_ 1s dance in & pivot to right
    to face 2nd crnrs
::
    _17-24_  1s repeat bars 9-16 with 2nd corners & end in centre RSh to
    RSh facing opp sides
25-32::
    1s dance LH across on sides (1M+2M+3M also 1L+2L+3L); dancers in 2nd
    corner position (2M & 3L) lead Men / Ladies & chase anticlockwise to
    own side (Ladies 3 2 1, Men 1 3 2)
33-40::
    All dance 3 couple Bourrel:
::
    1M+2L & 3M+1L set, turn 2H & twirl to BtoB (Lady facing up, Men
    down) _while_ 3L & 2M chase anticlockwise 1/2 round to face partner
    in line up down centre & all Petronella turn to own side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13453, '2020-12-04 11:12:17.49133+00', '2023-02-04 01:19:25.21241+00', 20150, 3, NULL, 'ace', '1-8::
    1s & 5s set & turn partner RH; 1s+5s cast down/up 1 place (2s & 4s
    step up/down) & finish BtoB with partner facing own sides
9-16::
    1s & 5s dance Double Triangles ending with Petronella turn to end in
    centre facing partner, Men facing up, Ladies facing down
17-24::
    1s+5s dance reel of 4
25-28::
    1L followed by 1M dance out between 2L & 3L, in between 3L & 4L to
    4th place opp sides _while_ 5M followed by 5L dance out between 3M &
    4M, in between 2M & 3M to 2nd place opp sides.  2 (5) 3 (1) 4
29-32::
    5s cross down RH to 3rd place _while_ 3s cast up to 2nd place
    _while_ 1s cross RH, all set.  End 2 3 5 1 4', 0);
INSERT INTO 'dancecrib' VALUES (7871, '2013-08-21 08:31:50.136525+00', '2023-02-04 01:23:08.257651+00', 13283, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1M followed by 1L cast to 2nd place & cross to opp sides, 1s face
    down (1M facing 3L, 1L facing 3M), 1s dance RSh round 3s to end in
    2nd place facing up (2s step up 11-12)
17-24::
    1s dance reels of 3 on opp sides (passing 2s LSh to start)
25-32::
    2s+1s dance LH across; 1s turn LH 1.1/2  times to end 2nd place own
    side', 0);
INSERT INTO 'dancecrib' VALUES (15285, '2022-12-08 11:02:39.771408+00', '2022-12-08 11:21:27.287363+00', 21195, 1, 1645, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 1c cross LH | set R to P, set L facing 3c

9--::

  2c+1c+3c Gr-Chain, 1c end BtoB facing own side

17--::

  Inverting DTr

25--::

  2c+1W & 1M+3c RHA, pass _LSh_ ; 2c+1M & 1W+3c LHA (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (2278, '2012-01-22 19:29:29.368685+00', '2022-12-08 16:58:45.355647+00', 2332, 1, NULL, 'ace', '1–::

  1M+2W turn RH ; 1W+2M turn 1¼ LH to face partners on diagonal

9–::

  1c+2c diag. Reel4, finish (2,1,3)

17–::

  1c set advancing, finish in middle BtoB 1W facing up, 1M down, then set »Crown Triangles« for 6 bars: all set (hands joined), 1c turning ¼ R to face own sides on second step ; repeat to own sides, repeat to other couple

25–::

  Reels3{6} on the sides, Rsh to 2cnrs | 1c cross.', 3);
INSERT INTO 'dancecrib' VALUES (3912, '2013-08-21 08:30:39.061783+00', '2023-02-04 01:18:19.836462+00', 15, 3, NULL, 'ace', '1-8::
    1s turn RH once round & turn LH 1.1/2 times to end in 2nd place on
    opposite side facing up (2s in 1st place face down)
9-16::
    2s+1s set & turn 2H on the sides, 2L+1L cross to change places RH,
    1s & 2s turn partners LH to original places
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (14517, '2022-01-10 02:18:54.872071+00', '2023-02-04 01:19:25.243641+00', 17958, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All Adv with partner, Ret with corner to finish BtoB with corner
    facing partner; all turn partner 3/4 RH to bring Ladies into centre
    facing partners
9-16::
    Double Celtic Reel:
::
    _9-12_    All pass partner RSh, Men in centre, shoulder to shoulder
    dance 3/4 round anticlockwise _while_ partners dance 1/4 clockwise
    round
::
    _13-16_  All pass partner RSh, Ladies in centre, shoulder to
    shoulder dance 3/4 round anticlockwise _while_ partners dance 1/4
    clockwise round
::
    _17-24_  Repeat 9-16
25-32::
    All set to partner, turn RH 1.1/4 to sides in original places & all
    set
33-40::
    Interlocking reels of 4. Ladies end facing out
41-48::
    All dance 1/2 Schiehallion reels to opp sides.  3 4 1 2
49-56::
    All set to partner & dance 1/2 Grand Chain back to original places
57-64::
    All circle 8H round & back

{{title}}
Reel

65-128::
    Repeat 1-64 in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (14518, '2022-01-10 02:18:54.891923+00', '2023-02-04 01:19:25.270524+00', 17882, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate
9-16::
    2s+1s+3s dance reels of 3 on sides (1s RSh to 2s)
17-24::
    2s+1s dance RH across; 1s+3s dance LH across
25-32::
    1s+3s+4s Adv+Ret; 1s+3s+4s turn partner RH
33-40::
    1s+3s+4s circle 6H round & back finishing in middle facing partner
41-48::
    1s+3s+4s dance 3 couple Poussette. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (15410, '2023-02-04 01:19:25.295624+00', '2023-02-04 01:19:25.296698+00', 21336, 3, NULL, 'ace', '1-8::
    1s set & dance 3/4 Fig of 8 on the sides (1M casts as 1L dances down
    centre to pass 2s LSh). 1M ends in 2nd place own side, 1L in centre
    facing 1M (2s step up bars 3-4)
9-10::
    All 3 Men join nearer hands on the side as 1L joins outer hands with
    2M+3M to form a »D« shape. All set in a »D« shape
11-12::
    1L pulls back RSh & Petronella turns to 2nd place own side _while_
    1M sets advancing to face her (2M+3M set facing in on the sides)
13-16::
    1s repeat bars 9-12 on the Ladies'' side. On the last 2 bars, 1M,
    pulling back RSh, sets turning & advancing slightly to face 2M on
    the diagonal _while_ 1L sets advancing to end behind 1M (in tandem).
    2L+3L set facing in for 4 bars.
17-20::
    1s dance 1/2 alternating tandem reel of 3 on 1st diagonal giving RSh
    to 2M & end in tandem, 1L leading, facing 3M.
21-24::
    1s dance 1/2 alternating tandem reel of 3 on 2nd diagonal, giving
    RSh to 3M, & end in 2nd place opposite sides.
25-28::
    All chase 1/2 way clockwise to own sides.
29-32::
    All turn partner RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4882, '2013-08-21 08:30:56.384726+00', '2023-02-04 01:19:25.324053+00', 1492, 3, NULL, 'ace', '1-8::
    1s dance down below 3s, cast up round 3s to 2nd place own side,
    2s+1s+3s set & cross RH
9-16::
    1s dance up round 2s & cast down to 2nd place opposite sides,
    2s+1s+3s set, 1s turn LH to face 1st corners _while_ 2s & 3s cross
    LH
17-24::
    1s set to corner (1), set to partner (1) & turn 3/4 RH (2 bars) to
    face 2nd corner; 1s set to corner (1), set to partner (1) & turn 3/4
    RH (2 bars) to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14281, '2021-09-08 00:19:15.289935+00', '2023-02-04 01:19:25.349548+00', 20441, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s lead down (2 bars), turn RH (2s step up 3-4); 1s+3s dance RH
    across.  Finish 1L with 1M following facing 3L
9-16::
    1s dance tandem reel on 1st corner diagonal finishing facing 3L
    again

{{title}}
Jig

17-24::
    1L followed by 1M dances behind 3L, up between 3s, behind 3M &
    across to place (3s step up 23-24).  2 3 1
25-32::
    All circle 6H 1/2 round to right (6 slip steps), pull back RSh &
    chase back to place.', 0);
INSERT INTO 'dancecrib' VALUES (9355, '2016-10-06 07:18:16.444048+00', '2023-02-04 01:19:25.410731+00', 17074, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across 1/2 way then 1s+3s dance LH across 1/2 way, 1L
    followed by partner dances up behind 3M & crosses to opposite side
9-16::
    1L dances RSh round 2L (in 1M place) as 1M dances RSh round 2M,
    1s+3s circle round to right & 1s end facing 2L (Lady in front of
    partner)
17-24::
    1s dance Alternating Tandem 1/2 reel of 3 with 1st corners, 1s dance
    Alternating Tandem 1/2 reel with 2nd corners
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4884, '2013-08-21 08:30:56.423556+00', '2023-02-04 01:19:25.446263+00', 10016, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 2s+1s dance RH across 1s ending in prom hold facing
    2L (Mans 2nd corner)
9-16::
    1s in prom hold dance 1/2 diagonal reel of 3 with corners, 1s split
    & dance 1/2 reels of 3 across (Lady with 2M+3M (in 1st places)
    giving LSh to 2M & Man with 3L+2L giving LSh to 2L) to end in prom
    hold facing 2L (Mans 1st corner pstn)
17-24::
    1s in prom hold dance 1/2 RSh diagonal reel of with corners, 1s
    dance up to top & cast to 2nd place opp sides
25-32::
    2s+1s+3s set, petronella turn into centre, set & turn partners 2H to
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (4908, '2013-08-21 08:30:56.77165+00', '2023-02-04 01:19:27.881029+00', 8603, 3, NULL, 'ace', '1-8::
    All Ladies Adv+Ret, all Men repeat
9-16::
    1s+2s dance RH across & LH back
17-24::
    All set twice, 1s cast to the bottom as others step up
25-32::
    1s dance Fig of 8 around couple above them', 0);
INSERT INTO 'dancecrib' VALUES (7872, '2013-08-21 08:31:50.158891+00', '2023-02-04 01:23:08.276782+00', 8082, 3, NULL, 'ace', '{{explanation}}
Round the Room, 2 facing 2

1-8::
    All turn opposite person RH, turn partner LH
9-16::
    All circle 4H round & back
17-24::
    All dance Ladies'' Chain
25-32::
    All Adv+Ret & Advance passing opposite person RSh to meet new couple', 0);
INSERT INTO 'dancecrib' VALUES (15286, '2022-12-08 11:11:48.008057+00', '2022-12-08 11:14:04.322885+00', 2704, 1, 1645, 'ace', '1--::

  1c cross RH | cast off (2c up) ; all set | 1c turn &frac34; RH to lines of 3 across all facing down

9--::

  2W+1M+2M & 3W+1W+3M dance down & up, end facing clw

17--::

  All chase &frac12; way clw ; A&R up/down

25--::

  All chase &frac12; way clw ; 1c turn &frac34; to own sides (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (15289, '2022-12-08 22:29:34.535633+00', '2022-12-08 22:29:43.743471+00', 21196, 1, 1645, 'ace', '1--::

  1c & 2c dance BtoB with opposite ; turn opposite RH

9--::

  Circle4 to L & back

17--::

  L-Chain, M take W''s RH on her hip while turning LH

25--::

  A&R with same hold ; Chassé 2 steps diag R, then 2 steps diag L & face new couple (2,1)

', 2);
INSERT INTO 'dancecrib' VALUES (13520, '2021-01-09 01:19:14.24228+00', '2023-02-04 01:19:25.512185+00', 17695, 3, NULL, 'ace', '{{title}}
Strathspey

1-2::
    1s lead down between 2s & 3s
3-4::
    1s cross RH below 3s _while_ 2s & 3s change places on the sides
    (Ladies LH, Men RH)
5-8::
    1s cast up round 3rd position & turn LH to face 1st corners _while_
    3s NHJ dance up on bars 5-6
9-12::
    Corner Pass & Twirl with 1st corners
::
    1s pass corners RSh, dance round corner place. 1s end 2nd place own
    sides _while_
::
    1st corners dance in, 1/2 turn RH, face & pulling back RSh dance out
    to opp corner place
13-16::
    All chase clockwise 1/2 way round
17-20::
    1s repeat Pass & Twirl with 4th corners.1s ending 2nd place opp
    sides facing clockwise
21-24::
    All chase clockwise 1/2 way round (2) 1 (3)
25-32::
    1s turn 1/2 RH, pull back RSh & dance out to opposite sides; All set
    & cross RH to own sides 2 1 3 4

{{title}}
Reel

1-32::
    1s+3s+4s repeat 1-32', 0);
INSERT INTO 'dancecrib' VALUES (4887, '2013-08-21 08:30:56.447546+00', '2023-02-04 01:19:25.706217+00', 10542, 3, NULL, 'ace', '1-8::
    1s lead down, cross below 3s & cast up to 2nd place opp sides & turn
    LH remaining in centre, 2nd place, ready for …
9-16::
    1s dance RH across with 1st+2nd crnrs, 1M followed by 3L+2L dance up
    & cast down Men''s side as 1L followed by 2M+3M dance down below 3s &
    up Ladies'' side
17-24::
    All chase anticlockwise 1/2 way, 1s+2s+3s Set+Link for 3 once to
    lines across
25-32::
    1M dances reel of 3 on opposite sides with 2L+3L (starting by giving
    RSh to 3L) _while_ 1L dances reel of 3 with 2M+3M (starting by
    giving RSh to 2M) & end with 1s crossing RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4888, '2013-08-21 08:30:56.474459+00', '2023-02-04 01:19:25.73538+00', 11633, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    Ladies dance LSh round partner & RSh round corner
17-24::
    Men dance RSh round partner & LSh round corner
25-32::
    Ladies dance clockwise round set back to places _while_ Men dance LH
    across in centre 1.1/2 times to opposite places
33-40::
    All set (facing in) & Men petronella on 1 place to their right, all
    set & Men petronella on 1 place to right (back to original places)
41-48::
    All set & advance with partner, retire with corner & set
49-56::
    All pass partner RH, turn next person LH, pass partner RH & turn
    corner LH
57-64::
    Men dance anticlockwise round set back to places _while_ Ladies
    dance RH across in centre 1.1/2 times
65-72::
    1s+3s dance 1/2 Ladies'' Chain , 2L+4L dance 1/2 Ladies'' Chain
73-80::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14901, '2022-06-27 00:19:20.485625+00', '2023-02-04 01:19:26.034867+00', 16579, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+3s dance Figs 8 through side couples (1M+3L through 2s, 1L+3M
    through 4s)
9-16::
    All set & turn partner RH, set & turn partner LH
17-24::
    2s+4s repeat 1-8
25-32::
    All set & turn partner RH; set & turn partner LH
33-40::
    All circle 8H round & back
41-48::
    1s+3s dance 1/2 Ladies'' Chain; 2s+4s dance 1/2 Ladies'' Chain
49-52::
    All Ladies dance 1/2 RH across & turn partner LH
53-56::
    All turn corner RH & join partner in prom hold facing anticlockwise
57-64::
    All promenade once round

{{title}}
Jig

1-64::
    Repeat bars 1-64 above in jig time', 0);
INSERT INTO 'dancecrib' VALUES (4889, '2013-08-21 08:30:56.484476+00', '2023-02-04 01:19:26.06198+00', 1498, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, cross RH & 1M casts up & into middle above 2s
    as 1L down & into middle below 3s
9-16::
    1s dance LH across (1M with 2s & 1L with 3s) with 2s & 3s continuing
    to places as 1s change places LSh in middle to dance RH across with
    other couple (1s dance only 1/2 LH across bars 9-10 and pass LSh
    bars 11-12; 2s & 3s dance full LH across) Finish 2 1 3
17-24::
    1s dance 1/2 Fig of 8 round 2s & 1/2 Fig of 8 round 3s to end facing
    1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting & Petronella turn to 2nd place own
    side', 0);
INSERT INTO 'dancecrib' VALUES (12387, '2019-12-05 01:29:25.97845+00', '2023-02-04 01:19:26.120885+00', 19422, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up), turn LH to end in 2nd place opp
    sides
9-12::
    All Advance, 2s+3s Retire _while_ 1s petronella turn to 1M between
    2s facing down, 1L between 3s facing up
13-16::
    Lines of 3 Advance, 2s+3s Retire _while_ 1s petronella turn to 2nd
    place own side  2 1 3
17-24::
    2s+1s+3s dance "Slip Knot" (as Knot but bars 23-24:  3s+1s dance 1/2
    LH across _while_ 2s finish in 3rd place)  1 3 2
25-32::
    3s followed by 2s dance up & cast round 1s; 2s followed by 1s dance
    down & cast up round 3s.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4891, '2013-08-21 08:30:56.502195+00', '2023-02-04 01:19:26.283071+00', 1501, 3, NULL, 'ace', '1-8::
    1s (with nearer hands joined) set to 2L & circle 3H round to the
    left, set to 2M & circle 3H round to the left
9-16::
    1s lead down the middle & back (2s step up 11-12), 1M pass Lady
    across to end with 1s BtoB between 2s facing opposite sides
17-24::
    1s+2s dance RSh reel of 4 across, 1s pass LSh to end in middle
    facing 1st corner
25-32::
    1s turn 1st corner RH, partner LH, 2nd corner RH & cross LH to own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (4892, '2013-08-21 08:30:56.510255+00', '2023-02-04 01:19:26.306388+00', 1505, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on own sides dancing between 2s to start
9-16::
    2s dance Fig of 8 round 3s (casting to start) _while_ 1s cross down
    & follow the 2s ending below 3s on own sides
17-24::
    1s turn RH & cast back to places, 1s+2s cross RH & circle 4H round
    to left 1/2 way
25-32::
    1s+3s cross LH & circle 4H round to right 1/2 way, 3s+1s change
    places on sides (Men RH & Ladies LH)', 0);
INSERT INTO 'dancecrib' VALUES (4893, '2013-08-21 08:30:56.518298+00', '2023-02-04 01:19:26.331521+00', 1507, 3, NULL, 'ace', '1-8::
    1s cross RH, 1s+2s change places LH on sides (no polite turns),
    2s+1s+3s cross RH & all 4 couples set. (2) 1 (3) 4
9-16::
    2s+1s+3+4s circle 8H round & back.
17-20::
    1s+3s dance 1/2 RH across, 3s cast to place _while_ 1s turn 1/2 RH
    moving up to 2nd place opposite side
21-24::
    1s+2s dance 1/2 LH across, 2s cast to top _while_ 1s cross down LH
    to 2nd place own side facing down
25-32::
    2s+1s+3s+4s dance Grand Chain (1 step per hand), 4L polite turn to
    face in, 2M & 3M face out
33-40::
    1s+3s+4s dance reels of 3 on sides (1s give RSh to 3s to start) & 1s
    dance down to 4th place (3s+4s step up). 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4894, '2013-08-21 08:30:56.528134+00', '2023-02-04 01:19:26.401775+00', 9098, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+2s also 3s+4s dance reels of 4 across (1M+2L similarly 3M+4L pass
    LSh to start)
17-24::
    3s followed by 1s lead down & 1s lead back & both couples turn to
    face 2s/4s who step in
25-32::
    All set, 1s+2s also 3s+4s dance 1/2 RH across to end with 1s facing
    4s in centre, 1s+4s set & dance 1/2 LH across to end facing 3s/4s
33-40::
    All dance reels of 4 on sides with 1s & 4s ending by passing RSh to
    face up/down
41-48::
    1s+4s set, dance 1/2 RH across, all set & cross RH to end 2 1 4 3', 0);
INSERT INTO 'dancecrib' VALUES (15290, '2022-12-09 15:39:33.17718+00', '2022-12-09 15:43:54.12222+00', 21155, 1, 202, 'ace', '1--::

  1c turn RH | cast off (2c up) ; turn RH 1½ to face 1cnrs

9--::

  Reels3 across, 1c RSh to 1cnrs. 1c face 1cnrs

17--::

  Corners Pass and Turn with 1cnrs. On [4] 1c meet P on midline, pull RSh back and face ends ; Corners Pass and Turn with 4cnrs (2,1,3)

25--::

  Circle6 L {3}, cross R foot over and pivot L ; Circle6 R (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9912, '2017-06-05 11:30:56.401548+00', '2023-02-04 01:19:26.469814+00', 16489, 3, NULL, 'ace', '1-4::
    1s+2s+3s set.  2s turn 3/4 RH to end 2L between 1s facing 1L & 2M
    between 3s facing 3M
5-8::
    _1/2_ RSh reels of 3 across 2L+1s & 2M+3s.  End (1) 2 (3)
9-12::
    1s+2s+3s set.  2s turn 3/4 LH to end 2M between 1s facing 1L & 2L
    between 3s facing 3M
13-16::
    _1/2_ LSh reels of 3 across 2M+1s & 2L+3s. 2s pass LSh to face 1st
    corners
17-20::
    2s+1st corners dance Corners Pass+Turn (1st corners turn 2H)  2s
    pass RSh to face 2nd corners
21-24::
    2s+2nd corners repeat 17-20.  2s pass RSh to 2nd place own sides
25-28::
    2s followed by 3s dance up, cast round 1s to 3rd/2nd place.  1 3 2
29-32::
    3s followed by 1s dance down, cast up round 2s to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4896, '2013-08-21 08:30:56.622009+00', '2023-02-04 01:19:26.498357+00', 1513, 3, NULL, 'ace', '1-4::
    1s+2s+3s set, 1s dance down to 2nd place (in middle) _while_ 2s cast
    up & 3s set turning to face out (Man - right about & Lady left
    about)
5-8::
    1L dances LH across on sides with 2L+3L & 1M RH across with 2M+3M
9-16::
    1s dance down (4 bars), Lady dances under Man''s arm & 1s dance to
    3rd pl opp sides _while_
::
    2s+3s dance double Fig of 8 (2s cross down, 3s cast up). 3s end
    facing out
17-24::
    2s+3s+1s dance 6 bar mirror reels of 3 on sides (1s in/up, 2s
    in/down, 3s out/down to start).  Bars 31-32: 1s cross to 2nd place
    own sides _while_ 3s cast to 3rd place
25-32::
    2s+1s+3s dance Inverted Grand Chain (3s cross RH as 1s+2s change
    places RH on sides)', 0);
INSERT INTO 'dancecrib' VALUES (14728, '2022-04-01 00:19:20.468517+00', '2023-02-04 01:19:26.533539+00', 18304, 3, NULL, 'ace', '1-4::
    1s cast (2s step up 1-2) & cross passing RSh
5-8::
    1L dances LSh round 3M _while_ 1M dances LSh round 2L & 1s pass LSh
    in centre flowing into …
9-16::
    1L+2s & 1M+3s dance RH across, 1s face 1st corners; 1s dance 1/2
    diag reel of 4 with 1st corners, 1s pass RSh in centre
17-24::
    1M+2L+3L (at top) & 1L+2M+3M dance LH across, 1s dance 1/2 diag reel
    of 4 with 2nd corners ending in 2nd place opp side. (3) (1) (2)
25-32::
    Reels of 3 across, 1L+2s (at top, 1L+2M pass LSh) & 1M+3s (1M+3L
    pass LSh)
33-40::
    All join hands on sides & set, circle 6H 1/2 round to left (4 bars),
    & all set on sides
41-48::
    1s+3s dance the Knot. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4897, '2013-08-21 08:30:56.630113+00', '2023-02-04 01:19:26.550535+00', 3383, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s circle left, 1s+2s also 3s+4s turn 2H 1.1/2 times
    on sides
9-16::
    Top 3 Men turn bottom 3 Ladies RH, top 3 Ladies turn bottom 3 Men LH
17-24::
    1M+4L set & 3/4 turn 2H into centre to face partners who chase
    clockwise 1/2 way, 4s & 1s set & 3/4 turn RH to 2nd/3rd places own
    sides
25-32::
    2s+4s also 1s+3s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (4898, '2013-08-21 08:30:56.638201+00', '2023-02-04 01:19:26.568111+00', 10513, 3, NULL, 'ace', '1-8::
    1s+3s dance reels of 3 on own sides (1s cast to start) as 2s cross
    down to 3rd pl to reel on opp sides.  1(2)3
9-16::
    1s+2s Petronella inTandem to other side.  2(1)3
17-24::
    1s+2s 1/2 turn partners RH dance RH across once round & 1s 1/2 turn
    RH into prom hold to face 3M as 2s cross RH to 1st place own side
25-32::
    1s dance RSh reel of 3 with 3s & 1s end between 3s facing down
33-40::
    1s turn 3s with nearer hand & cross down to 3rd place own sides as
    3s dance up, 1s turn 4s 1.1/2 times with other hand', 0);
INSERT INTO 'dancecrib' VALUES (4899, '2013-08-21 08:30:56.648092+00', '2023-02-04 01:19:26.591944+00', 14565, 3, NULL, 'ace', '1-8::
    1s+2s also 4s+5s dance Diamond Poussette (2s/4s end facing 1st
    corners) as 3s set & dance DoSiDo & set again
9-16::
    2s/4s dance 1/2 RSh reel of 4 with 1st corners, pass LSh to turn 2nd
    corners RH & pass RSh to face 4th corners
17-24::
    2s/4s turn 4th corners LH & pass LSh to face 3rd corner (pstn),
    2s/4s dance 1/2 LSh reel of 4 with 3rd corners back to original
    places
25-32::
    1s cross down to 2nd place as 2s dance up & 1s dance out 1/2 turning
    3s, 1s cross down to 4th place as 4s dance up & 1s dancing out 1/2
    turning 5s', 0);
INSERT INTO 'dancecrib' VALUES (4900, '2013-08-21 08:30:56.657823+00', '2023-02-04 01:19:26.622414+00', 10175, 3, NULL, 'ace', '1-8::
    All circle 6H round & back ending in centre facing up
9-16::
    All Promenade
17-24::
    1s cast 1 place & dance 3/4 Fig of 8 round 3s to end in 3rd place
    own side
25-32::
    All dance reels of 3 on side (1s out & up to start)', 0);
INSERT INTO 'dancecrib' VALUES (4901, '2013-08-21 08:30:56.665956+00', '2023-02-04 01:19:26.827565+00', 14566, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 3/4 turn LH into prom hold facing 3L
9-16::
    1s dance 1/2 RSh reel of 3 with 1st corners & 1s dance 1/2 RSh reel
    with 2nd corners ending in 2nd place Ladies'' side
17-20::
    1s cross leading with LH & cast (Man up, lady down) dancing into
    middle to meet partner _while_ 3s+2s dance 1/2 R&L
21-24::
    2s+1s+3s turn partners RH to end own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12721, '2020-04-11 10:50:55.228394+00', '2023-02-04 01:19:26.960969+00', 19906, 3, NULL, 'ace', '1-8::
    All set NHJ, 1s &2s also 3s+4s dance RH across. 1s & 4s cast into
    centre _while_ 2s & 3s step out to ends. 2 1 4 3
9-12::
    1s+4s Petronella turn and set, remaining in centre ready for …
13-20::
    1s+4s dance 1/2 Celtic Reel:
::
    _13-16_   1s+4s pass partner RSh, 1M+4L dance1/4 clockwise round to
    opp sides _while_ partners dance 3/4 LSh round each other to face
    own partner across dance.
::
    _17-20_   Repeat (4M+1L dancing clockwise round) to form a line up &
    down centre, facing partner again
21-24::
    4s+1s set & petronella turn to own side. 2 4 1 3
25-32::
    2s+4s+1s+3s circle 8H round & back.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14282, '2021-09-08 00:19:16.401632+00', '2023-02-04 01:19:27.100444+00', 10978, 3, NULL, 'ace', '1-8::
    1M casts below 3s _while_ 1L dances down middle, 1L followed by 1M
    casts up round 3L, dance down & cast up round 3M & into 2nd place
    own side. 2 1 3
9-16::
    2s+1s+3s set, 1s turn 1/2 RH, face partner & pull back RSh & dance
    RSh round 1st corners, flowing into …
17-24::
    Reels of 3 across (1s LSh to 4th corners).  1s end in 2nd place own
    side
25-32::
    2s+1s+3s circle 6H round & back.', 0);
INSERT INTO 'dancecrib' VALUES (4902, '2013-08-21 08:30:56.673929+00', '2023-02-04 01:19:27.166783+00', 12086, 3, NULL, 'ace', '1-8::
    1s dance down & back to top
9-16::
    1s cast on own sides, in down between 3s, cast up to 2nd place & set
17-24::
    2s+1s+3s set, circle 6H round 3/4 way into lines across (all Ladies
    at top) & all set
25-32::
    2s+1s+3s Adv+Ret (up/down), 1s turn RH to own sides _while_ 2s+3s
    set & dance on 1 place clockwise', 0);
INSERT INTO 'dancecrib' VALUES (15291, '2022-12-09 23:18:14.471141+00', '2022-12-09 23:21:23.281673+00', 9882, 1, 202, 'ace', '1--::
  1c & 4c set | cast inwards (2c & 3c step out) ; 1c+4c ½ R&L (2,4x,1x,3)
9--::
  All repeat pattern of [1-8] (4x,3x,2x,1x)
17--::
  4c+3c & 2c+1c RHA ; 3c+2c LHA _while{4}_ 4c+1c chase clw ½. All finish as for Reel4 position (1,3x,2x,4)
25--::
  All set facing on sides | change places RH (to 3,1x,4,2x) ; 3c & 2c turn P BH 1½ _while{4}_ 1c & 4c turn P BH (3,1,4,2)', 2);
INSERT INTO 'dancecrib' VALUES (15411, '2023-02-04 01:19:27.200577+00', '2023-02-04 01:19:27.210511+00', 20296, 3, NULL, 'ace', '1-8::
    1s cross down to dance mirror reels of 3 on sides
9-16::
    1s cross RH, cast (2s step up); 1s dance down between 3s & cast up
    to finish facing 1st corners
17-24::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh & dance 1/2
    diag reel of 4 with 2nd corners ending in 2nd place opp sides. (3)
    (1) (2)
25-32::
    2s+1s+3s Set+Link for 3 couples twice.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4833, '2013-08-21 08:30:55.721429+00', '2023-02-04 01:19:22.30036+00', 1415, 3, NULL, 'ace', '1-8::
    1s+2s set & cross RH, set & cross RH back to places
9-16::
    1s lead down the middle & lead up & 1L turns under her own right arm
    to face 1st corners
17-24::
    1s set to 1st corners, set to 2nd corners, set to each other across
    the dance & cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4836, '2013-08-21 08:30:55.747305+00', '2023-02-04 01:19:22.381938+00', 7662, 3, NULL, 'ace', '1-8::
    1s set, dance down & Lady dances LH across with 2L+3L _while_ Man
    dances RH across with 2M+3M all ending back in places
9-16::
    1s dance down & cast up behind 2s, dance down below 3s & cast up to
    2nd place
17-24::
    2s+1s+3s turn RH into centre & turning individually to right dance
    out to opposite sides, repeat back to own sides
25-32::
    1s & 3s 3/4 turn RH into centre, dance 1/2 reel of 4 & turn RH to
    own sides.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (9185, '2016-06-16 22:41:40.657999+00', '2023-02-04 01:19:27.29034+00', 17037, 3, NULL, 'ace', '1-8::
    1s & 2s slip down & back
9-16::
    1s+2s dance RH across & LH back
17-24::
    1s turn RH & cast to bottom
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8055, '2013-10-01 08:46:42.441561+00', '2023-02-04 01:19:27.330444+00', 15129, 3, NULL, 'ace', '1-8::
    All Men take hands on side & Adv+Ret, All Ladies take hands on side
    & Adv+Ret
9-16::
    1s+2s dance RH across 1/2 way. 1s+3s dance LH across 1/2 way, 1s+4s
    dance RH across 1/2 way & all set Advcg to form zigzag line (L above
    M)
17-24::
    Bal-in-Line then 1/2 turn partner RH, all Bal-in-Line & 3/4 turn RH
    to Ladies facing down & Men up all on own sides.  2 3 4 1
25-32::
    All chase clockwise round set back to places', 0);
INSERT INTO 'dancecrib' VALUES (4904, '2013-08-21 08:30:56.739305+00', '2023-02-04 01:19:27.367853+00', 12106, 3, NULL, 'ace', '1-8::
    All set, 1s+2s also 3s+4s dance LH across & couple facing couple set
9-16::
    1s+2s also 3s+4s dance the Rondel
17-24::
    1s dance 1/2 Fig of 8 round couple below (4s), 1s cross down (no
    hands) _while_ 4s dance up sides & 1s+4s turn on sides (Ladies LH &
    Men RH)
25-32::
    All dance reflection reels of 4 on sides (Ladies RSh & Men LSh).  2
    4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4906, '2013-08-21 08:30:56.755591+00', '2023-02-04 01:19:27.440475+00', 13964, 3, NULL, 'ace', '1-4::
    1L followed by 1M casts round 2L & crosses up between 2s _while_ 4M
    followed by 4L casts round 3M & crosses down between 3s
5-8::
    1L casts to 2nd place & crosses to own side _while_ 4M casts to 3rd
    place & crosses to own side.  2 1 4 3
9-16::
    2s+1s also 4s+3s dance RH across then LH across
17-24::
    All dance RSh reels of 4 on sides ending with 1L+4L also 1M+4M NHJ
    facing out
25-32::
    1M+4M also 1L+4L change places LH & set to partners, 4s+1s circle 4H
    round to right.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4907, '2013-08-21 08:30:56.763696+00', '2023-02-04 01:19:27.631135+00', 1521, 3, NULL, 'ace', '1-4::
    1L & 3M cast & chase clockwise 1/2 way to change places _while_
    1M+2s+3L dance 1/2 Diag R&L
5-8::
    3L & 1M chase clockwise 1/2 way as 3M+2s+1L dance 1/2 Diag R&L.  All
    end in original places
9-16::
    1s set advancing, cast to 2nd place & turn RH 1.1/2 times to face
    1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting & into centre to end BtoB
25-32::
    1s dance LH across (1M with 2s & 1L with 3s), pass LSh to dance RH
    across with other couple', 0);
INSERT INTO 'dancecrib' VALUES (13297, '2020-11-02 01:19:19.099497+00', '2023-02-04 01:19:27.652528+00', 19166, 3, NULL, 'ace', '1-8::
    1s+2s+3s 1/2 turn RH, pull back RSh & dance out to opp sides flowing
    into all chase clockwise 1/2 round.  3 2 1
9-16::
    2s+1s dance Tourbillon:
::
    _9-12_    2s & 1s 1/2 turn ptnrs 2H, 2M & 1L lead ptnrs by nearer
    hand 1 place cl''wise to end 2s on Ladies side & 1s on Men''s side, 2s
    set to 1s
::
    _13-16_  2s & 1s 1/2 turn ptnrs 2H & lead ptnrs on 1 place clockwise
    & 1s+2s cross RH to own sides. 3 1 2
17-24::
    1s dance »Figure of Love«:
::
    _17-20_   1s dance LSh round 1st corner (pstn), meet in centre &
    touch 2H
::
    _21-24_   1s pull back LSh & dance LSh round 2nd corner (pstn) into
    2nd place own side
25-32::
    1M+2s (at bottom) & 1L+3s (at top) dance reels of 3 across (LSh to
    1st corner pstn to start).  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (13063, '2020-08-10 00:19:12.523181+00', '2023-02-04 01:19:27.681567+00', 16857, 3, NULL, 'ace', '{{title}}
Strathspey

1-4::
    1s dance down between 3s & 1s+3s 3/4 turn (Ladies LH, Men RH), 1s
    end in 2nd place own side (2s step up 3-4)
5-8::
    1s dance up between 2s & 1s+2s 3/4 turn (Ladies RH, Men LH) to end 2
    1 3
9-16::
    2s+1s+3s circle 6H round to left (3 bars), pivot pulling back LSh &
    chase anticlockwise, 1s finish facing 1st corners
17-24::
    »Interrupted Hello-Goodbye« setting:
::
    _17-20_   1s set to 1st corner and set to partner, turn 3/4 RH to
    face 2nd corners;
::
    _21-24_   Repeat with 2nd corner; 1s end on own side in 2nd place.
    2 1 3 4
25-32::
    1s+3s dance Diamond Poussette.  End 2 1 3 4

{{title}}
Reel

1-16::
    Repeat 1-16 above
17-24::
    »Interrupted Hello-Goodbye« setting but Bar24: 1s remain in centre,
    & 4s step in
25-32::
    1s+4s dance Poussette to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4909, '2013-08-21 08:30:56.78352+00', '2023-02-04 01:19:27.911284+00', 5171, 3, NULL, 'ace', '1-8::
    1s dance down below 3s, cast up & dance 1/2 Fig of 8 round 2s
9-16::
    1s dance reels of 3 on opposite sides dancing down between 3s to
    start
17-24::
    1s cross down below 3s, cast up on own sides & turn LH 1.1/4 times
25-32::
    1s dance reels of 3 across (Lady with 2s & Man with 3s) giving LSh
    to 1st corners', 0);
INSERT INTO 'dancecrib' VALUES (12540, '2020-02-02 02:47:28.620055+00', '2023-02-04 01:19:28.125677+00', 13901, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-8::
    1L (also 4L) dances Fig 8 round 2s (3s) _while_ 1M (also 4M) sets
    dances 1/2 Fig 8 round 2s (3s) & dances across to place facing out 1
    2 (3) (4)
9-16::
    LSh reels of 4 on sides. Bar 16 2L+3M also 2M+3L turn 1/2 RH
    (instead of passing RSh) & retain RH, 1M & 4M face out
17-20::
    1M followed by 1L & 4M followed by 4L chase 1/2 round clockwise to
    opposite ends _while_ 2L+3M & 2M+3L continue to turn RH.  4 2 (3)
    (1)
21-24::
    4s+2s & 3s+1s change places LH on sides; 4L+1M & 4M+1L turn RH 3/4
    into line of 4 across _while_ 2s & 3s set
25-32::
    1s+4s dance reel of 4 across, finishing 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (14236, '2021-08-14 00:22:29.576517+00', '2023-02-04 01:23:09.97728+00', 12420, 3, NULL, 'ace', '1-8::
    1s lead up out of the set (2 bars), face each other & set; 1s lead
    back to place, face each other & set
9-10::
    All 3 couples turn RH to finish Men facing in, Ladies facing out
11-22::
    All dance 12 bars of Schiehallion reels back to place
23-24::
    All 3 couples turn partner 2H to face in (2 bars)
25-26::
    All 3 couples set.
27-28::
    All circle 6H round to the left
29-30::
    All turn partner 2H
31-32::
    All circle 6H round to the left to new positions (2 places round
    clockwise). 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4903, '2013-08-21 08:30:56.68183+00', '2023-02-12 16:29:10.366972+00', 1524, 3, NULL, 'ace', '1-8::

    1s+2s+3s circle 6H round & back

9-16::

    1L+3M set & change places RH, 1M+3L set & change places RH

17-24::

    2s set & cross RH, 2s cast to 3rd place & 3s+1s+2s 1/2 turn RH to

    end in middle facing up

25-32::

    3s+1s+2s dance 3 couple Allemande', 0);
INSERT INTO 'dancecrib' VALUES (9723, '2017-04-06 08:39:36.925269+00', '2023-02-04 01:19:21.062068+00', 13259, 3, NULL, 'ace', '1-8::
    1s cast behind own lines, turn outward & dance back up to place
9-16::
    1s+2s dance RH across, 1s+2s dance LH across
17-24::
    1s lead down (3 bars), lead up (3 bars) & cast to 2nd place own
    sides (2s step up 23-24)
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (8773, '2015-06-15 11:40:36.312127+00', '2023-02-04 01:19:28.188229+00', 15659, 3, NULL, 'ace', '1-8::
    1s dance down (NHJ) between 2s, cast up, dance down between 3s &
    cast up to face 1st corners
9-20::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s meet again in
    middle & pass RSh, twirl to finish BtoB (1M faces down, 1L up)
21-24::
    1s dance out of ends, cast to R into 2nd place own side _while_
    3s+2s set & dance 1/2 RH across  2 1 3
25-32::
    1s+3s dance Rose Progression
::
    _25-26_     1M+3L set as 1L+3M change places RH
::
    _27-28_     1M+3L 1/2 turn RH, pull back RSh as 1L & 3M dance into
    partner''s place
::
    _29-30_     1M+3L cast into each others place as 1L+3M 1/2 turn RH,
    pull back RSh
::
    _31-32_     1M & 3L dance into 2nd/1st places own side as 1L & 3M
    cast to right to new places. End  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4911, '2013-08-21 08:30:56.880892+00', '2023-02-04 01:19:28.21888+00', 10051, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 2s+1s dance RH across & end in middle facing
    down
9-16::
    1s followed by 2s lead down & cross below 3s, cast round 3s & lead
    up & cross 1s cast to face 1st corners & 2s to 1st place own sides
17-24::
    1s dance 1/2 reel of 4 with corners, 1s turn RH as all corners chase
    1/2 way clockwise
25-32::
    1s dance 1/2 reel of 4 with 2nd corners (pstn), all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4912, '2013-08-21 08:30:56.963849+00', '2023-02-04 01:19:28.37236+00', 13267, 3, NULL, 'ace', '1-8::
    Ladies dance reel of 4 across (1L RSh to 4L & 3L RSh to 2L) ending
    in original places
9-16::
    Men dance reel of 4 up/down (2M LSh to 3M & 4M RSh to 1M) ending in
    original places
17-32::
    1s+3s Adv+Ret, 2s+4s Adv+Ret, repeat bars 17-24
33-40::
    Ladies dance LH across twice round _while_ Men dance clockwise once
    round
41-48::
    Men dance RH across twice round _while_ Ladies dance anticlockwise
    once round
49-64::
    1s+2s also 3s+4s circle 4H round to left, all circle 8H round to
    left for 4 bars
57-64::
    All circle 8H round to right to end in opposite places

{{explanation}}
Repeat in jig time but end with 1s leading off the floor', 0);
INSERT INTO 'dancecrib' VALUES (15222, '2022-11-03 01:19:18.465446+00', '2023-02-04 01:19:28.399313+00', 21120, 3, NULL, 'ace', '1-8::
    All dance Interlocking Ladies'' Chain:
::
    _1-2_   Ladies dance 1/2 RH across _while_ Men dance towards Ladies''
    places
::
    _3-4_   Men turn Lady LH
::
    _5-6_   Repeat bars 1-2
::
    _7-8_   Men turn partner LH back to place
9-16::
    All dance 1/2 Grand Chain
17-24::
    All turn partners 1.1/4 into Promenade hold facing anticlockwise &
    dance 3 places round to finish facing partners
25-32::
    All set to partners, turn partner 3/4 RH; Men dance on 1 place
    clockwise round outside back to original place & all set to new
    partners', 0);
INSERT INTO 'dancecrib' VALUES (13064, '2020-08-10 00:19:13.142677+00', '2023-02-04 01:19:28.436456+00', 20042, 3, NULL, 'ace', '1-8::
    1s NHJ dance down, cast up round 3s to 2nd place own side (2s step
    up); 2s+1s+3s dance 1/2 mirror reel of 3 on sides (1s in/up, 2s
    out/down, 3s out/up). 1s end facing 2nd corners (pstn)
9-16::
    1s turn 2nd corner (pstn) RH, partner LH, 1st corner (pstn) RH,
    partner LH. 1s end in centre, 1M facing up, 1L facing down
17-24::
    1M+3s (at top) & 1L+2s (3rd place) dance RH across (2 bars), 3M
    followed by 1M+3L also 2L followed by 1L+2M chase clockwise round to
    end  (Bar: 23) with 2s in 1st place, 3s in 3rd place & Bar24: 1L
    dances behind 2L, 1M behind 3M to 2nd place own side
25-32::
    2s+1s+3s Advance (1 step), pull back RSh & curve out to place (Men
    face up, Ladies down); All turn partners RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4913, '2013-08-21 08:30:56.975499+00', '2023-02-04 01:19:28.47551+00', 9559, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH & set, lead down the middle, cross below 3s & cast up
    to 2nd place own sides
9-16::
    2s+1s+3s Adv+Ret for 2 steps, 1s dance 1/2 LSh reels of 3 across
    (Lady with 2s & Man with 3s) to end in 2nd place opposite sides
17-24::
    2s+1s+3s Adv+Ret, 1s dance 1/2 reels of 3 across (Lady with 3s & Man
    with 2s) end in diag line with 4th crnr (RH with crnrs & LH ptnr)
25-32::
    1s dance the Spoke : Bal-in-Line with 4th crnr, repeat with own 1st
    crnr, 2nd crnr & 3rd crnr', 0);
INSERT INTO 'dancecrib' VALUES (13886, '2021-04-05 00:19:15.965327+00', '2023-02-04 01:19:28.508396+00', 19480, 3, NULL, 'ace', '1-8::
    1L followed by 1M & 4M followed by 4L cast 1 place & cross to opp
    sides (2s & 3s step up/down); All dance 1/2 reels of 4 on sides.  3
    (4) (1) 2
9-16::
    3s & 2s repeat bars 1-8 (3L & 2M lead).  1 2 3 4
17-24::
    All dance 8 bars of 4 Couple R&L:
::
    _17-18_   All cross RH with partner
::
    _19-20_   Top 2 on Men''s side + bottom 2 on Ladies'' side change
    places LH on sides _while_ others cross diagonally LH
::
    _21-24_   Repeat 17-20 to end facing partner 4 3 2 1
25-32::
    Bottom 3 couples set, cross RH & chase clockwise 1/2 round.  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (4914, '2013-08-21 08:30:56.983596+00', '2023-02-04 01:19:28.532831+00', 10891, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set, dance RH across 1/2 way & chase clockwise 1/2
    way.  3 4 1 2
9-16::
    3s+4s also 1s+2s set, dance LH across 1/2 way & chase anticlockwise
    1/2 way.  1 2 3 4
17-24::
    All set, turn 2H to end in middle (1s/3s facing down, 2s/4s facing
    up), 1s+2s also 3s+4s circle 4H round to left (remain in middle
    facing down/up)
25-28::
    All set advancing passing facing person, 1s+4s set advancing & pass
    _while_ 2s & 3s dance to top/bottom places
29-32::
    4s dance up to top & cast to 2nd place _while_ 1s dance down to
    bottom & cast up to 3rd place.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4916, '2013-08-21 08:30:56.999786+00', '2023-02-04 01:19:28.599311+00', 12729, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, cross RH & cast to right to end 1L between 2s
    & 1M between 3s
9-16::
    2s+1s+3s Adv+Ret (up/down), 1s change places RH & cast to right
    _while_ 2M+3M & 2L+3L turn RH
17-24::
    2s+1s+3s Adv+Ret (across), 1s dance 1/2 Figs of 8 (1M round 2s, 1L
    round 3s)
25-32::
    1s dance RH across (1L with 2s, 1M with 3s) & LH across with other
    couple', 0);
INSERT INTO 'dancecrib' VALUES (9186, '2016-06-16 22:41:40.933993+00', '2023-02-04 01:19:28.622644+00', 16830, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, LH back
9-16::
    1s dance (NHJ) down the middle & back, finish back-to-back 2nd place
    facing own sides (2s step up 11-12)
17-24::
    1s dance Double Triangles & end facing down in middle on own sides
    (1M pulls back RSh)
25-32::
    1s (taking hands where possible) dance between 3s, cast up, dance up
    between 2s & cast off to 2nd place, own sides', 0);
INSERT INTO 'dancecrib' VALUES (15292, '2022-12-10 00:18:33.086104+00', '2022-12-10 01:06:47.452001+00', 21164, 1, 202, 'ace', '1--::
  2C Set&Rotate. 1c in tandem (1M leading) face 2W
9--::
  ½ Reel3 on 1diag in tandem (with lead change), 1M RSh to 2M ; ½ Reel3 in tandem (with lead change), 1W RSh to 3M (3x,1x,2x)
17--::
  ½ Reels3 on sides, 1c RSh to 2c. 1c in tandem (1M leading) face 3M ;  ½ Reel3 on 1diag in tandem (with lead change), 1M RSh to 3M
25--::
  ½ Reel3 in tandem (with lead change), 1W RSh to 2M (to 3,1,2) ; ½ Reels3 on sides, 1c RSh to 3c (2,1,3)
33--::
  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3924, '2013-08-21 08:30:39.216124+00', '2023-02-04 01:18:21.51448+00', 9424, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s, 1s lead down (LHJ) & cross below 3s
    & cast up round 3s to face 1st corners
9-24::
    1s dance Corner Chain with 1st & 2nd corners :
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s who finish in centre, 1L facing up,
    1M facing down
25-32::
    1L+2s also 1M+3s dance RH across, 1M+2s also 1L+3s dance LH across.
    End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4905, '2013-08-21 08:30:56.747358+00', '2023-02-04 01:19:28.645201+00', 9222, 3, NULL, 'ace', '1-8::
    1s dance down & cast up behind 2s, 1s+2s dance RH across
9-16::
    1s dance Fig of 8 round 2s as 2s set & change places RH then set
    again & cross back
17-24::
    1s followed by 2s (who cast up) dance down middle, all turn in &
    dance up (2s to top)
25-32::
    2s+1s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (4917, '2013-08-21 08:30:57.017462+00', '2023-02-04 01:19:28.692623+00', 9680, 3, NULL, 'ace', '1-8::
    All set to partners, turn RH, turn corners LH & turn partner RH
    (Ladies end facing out)
9-16::
    All dance 1/2 Schiehallion Reel (2 places)
17-24::
    All turn partners RH, turn corners LH, partners RH & set to partners
25-32::
    1s & 3s dance Figs of 8 round nearest side couple dancing in front
    of corner person to start
33-40::
    2s & 4s repeat
41-48::
    1s & 3s dance 1/2 R&L, 2s & 4s dance 1/2 R&L back to places
49-56::
    Ladies dance RH across once round _while_ Men dance 1/2 way round
    anticlockwise, set to opposite partner & 1/2 turn Men into centre
57-64::
    Men dance RH across once round _while_ Ladies dance 1/2 way round
    anticlockwise, set to partner & 1/2 turn to places
65-72::
    1s & 3s advance (1s nearer hands joined), 1s (with outer hands) turn
    opp person once round, cross & dance out behind side couples to orig
    places
73-80::
    2s & 4s repeat
81-88::
    All dance Grand Chain
89-96::
    All with RH over LH (as Auld Lang Syne) circle to left once round On
    final chord all turn outwards retaining hands to bow or curtsey', 0);
INSERT INTO 'dancecrib' VALUES (11444, '2019-01-01 01:56:36.522038+00', '2023-02-04 01:19:28.722406+00', 18961, 3, NULL, 'ace', '1-8::
    1s & 4s petronella turn into centre (2s+3s step slightly up/down to
    form 2 diamond shapes) & all set, all Petronella turn & set again
9-16::
    1s & 4s cross RH, cast to meet other prtnr on sides & turn 2H, 1s+4s
    dance LH across as 2s & 3s set, turn 2H, dance out to 1st/4th pl &
    set
17-24::
    1s & 4s dance Figs of 8 round end couples
25-32::
    1s set advg & turn 2H, dance down middle for 3 bars followed by
    4s+3s (who dance up through 2nd pl into middle) & cast to sides.  2
    3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4918, '2013-08-21 08:30:57.043163+00', '2023-02-04 01:19:28.748632+00', 1537, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place (2s step up). 1s turn LH 1.1/4 times to
    end facing Ladies'' side, 1L on 1M''s right (*see note)
9-16::
    1s dance Alternating Tandem reel of 3 on Ladies'' side (1L leads
    starting RSh to 3L)
17-24::
    1s dance Alternating Tandem reel on Men''s side (1L leads starting
    LSh to 3M) & end in prom hold facing Ladies'' side
25-32::
    1s dance out between 2L+3L, cast round 3L & dance up to top of set,
    drop hands & cast to 2nd place own side
::
    *Note:  1s cover, remaining parallel to line of set throughout reels
    (bars 9-24)', 0);
INSERT INTO 'dancecrib' VALUES (4919, '2013-08-21 08:30:57.051473+00', '2023-02-04 01:19:28.76648+00', 8344, 3, NULL, 'ace', '1-8::
    All set on sides & 1/2 turn partners 2H, 1M & 2L also 3M & 4L lead
    partners by nearer hand on 1 place clockwise (1s & 3s on Ladies''
    side & 2s & 4s on Men''s side), all set, 1L & 3L cast down 1 place
    _while_ 2M & 4M cast up 1 place as others cross to own side to face
    partner
9-16::
    All set, 2s & 3s (end couples) cross RH _while_ 1s & 4s dance 1/2 RH
    across. All change places LH on side, end couples cross RH _while_
    middle couples dance 1/2 RH across (4s & 2s face down 3s & 1s face
    up).  4 2 3 1
17-24::
    All turn facing person LH, set advancing & pass LSh, 1s & 4s (centre
    couples) turn facing person RH & set advancing & pass LSh
25-32::
    3s+1s also 4s+2s circle 4H round to left, all ending in a line
    up/down set (Ladies facing up & Men down), all set & petronella turn
    to sides.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (15223, '2022-11-03 01:19:18.82472+00', '2023-02-04 01:19:28.781239+00', 18275, 3, NULL, 'ace', '1-8::
    2s dance Fig of 8 (2L up round 1s, 2M down round 3s)
9-16::
    1s+2s+3s dance reels of 3 on the sides. 2L dances in/down, 2M dances
    in/up to start
17-18::
    2s dance down curving into 3rd place _while_ 3s dance up to 2nd
    place
19-24::
    3s turn RH 1.1/4; 1s+3M also 3L+2s dance LH across
25-32::
    1s+3L also 3M+2s dance RH cross; 1s+3s+2s dance Snake Pass passing
    LSh in centre:
::
    3L followed by 1L+1M dances down to 3M''s place, across set & up to
    2L''s place _while_ 3M, followed by 2M+2L, dance up to 1L''s place,
    across set & down to 2M''s place.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (14729, '2022-04-01 00:19:22.275769+00', '2023-02-04 01:19:28.82166+00', 16817, 3, NULL, 'ace', '1-8::
    1s+2s+3s set &cross RH; all set, 1s+3s cross back RH _while_ 2s turn
    2H to face 1st corners
9-16::
    2s dance Corner Pass+Turn with 1st corners (corners turn 2H), 2s
    pass RSh to repeat with 2nd corners. 2s pass RSh to 2nd place own
    sides 1 2 3
17-24::
    1s+2s dance Espagnole
::
    _17-18_   1s+2s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _19-20_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _21-24_   2s turn RH as 1s turn LH to finish in diagonal line with
    3s who step in bar 24 ready for ….
25-32::
    1s+3s dance 1/2 Poussette, 2s+3s+1s turn 2H.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4920, '2013-08-21 08:30:57.06167+00', '2023-02-04 01:19:28.856612+00', 13391, 3, NULL, 'ace', '1-8::
    _While_ 3s cross RH, set on the sidelines, cross back RH and set,
    1s+2s dance the Tourbillon:
::
    _1- 4_  1s & 2s 1/2 turn ptnrs 2H, 1M & 2L lead ptnrs by nearer hand
    1 place cl''wise to end 1s on Ladies'' side & 2s Men''s side, 1s set to
    2s
::
    _5- 8_  1s & 2s 1/2 turn ptnrs 2H & lead ptnrs on 1 place clockwise
    & 2s+1s cross RH to own sides
9-16::
    1M dances Fig 8 round 2s _while_ 1L dances Fig 8 round 3s
17-24::
    1s advance to 1st corners as 1s+1st corners set & turn 2H to end in
    lines of 3 across (1L between 2s, 1M b''tw''n 3s), 1s+2nd crnrs repeat
    to 2(1)3
25-36::
    2s+1s+3s dance R&L for 3 couples
37-40::
    1s cross down between 3s to own sides & cast up to 3rd place as 3s
    dance up 1 place on sides in last 2 bars.', 0);
INSERT INTO 'dancecrib' VALUES (15293, '2022-12-10 10:03:51.390588+00', '2022-12-10 10:07:56.839431+00', 18711, 1, 202, 'ace', '1--::

  1c set | dance down to bottom (2c up) ; meet and cast up to 2pl (2,1,3)

9--::

  ½ Reel4 on 1diag _while{4}_ 2cnrs chase clw ½ to exchanged places. 1c pass RSh ; ½ Reel4 on 2diag _while{4}_ 1cnrs chase clw ½ to original places. 1c pass P RSh into BtoB position on midline, 1M facing up, 1W facing down

17--::

  Fig8 across, 1c LSh to 3cnrs. 1c finish as on [17]

25--::

  2c+1M & 1W+3c Circle3 L. On [28], 1c swivel R to face P ; 1c set | Petronella turn to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (4867, '2013-08-21 08:30:56.162724+00', '2023-02-04 01:19:24.14486+00', 1469, 3, NULL, 'ace', '1-8::
    1s cross RH _while_ 2s+3s change places on sides (Ladies LH & Men
    RH) & dance reels of 3 on the sides (1s out & down, 3s in & up)
9-16::
    1s cast 1 place on opposite sides (3s dance up) & dance 1/2 Figs of
    8 (Lady up & Man down), 1s meet in centre & turn LH 1.1/4 times
17-24::
    RH across 1L+3s (at top) & 1M+2s (3rd place), 1s finish in 2nd place
    own sides; 1s pass RSh & dance LH across with other couple
25-32::
    3s+1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (13610, '2021-02-04 01:19:12.913499+00', '2023-02-04 01:19:24.176055+00', 15242, 3, NULL, 'ace', '1-8::
    1s+2s dance ''Espangnole''. Bars 5-8: 1s turn LH to face 1st corners
9-16::
    1s turn corner RH, partner LH, 2nd corner RH, partner LH. 1s end
    facing 1st corners
17-24::
    1s dance 1/2 dig reel of 4 with 1st corners, pass RSh; 1s dance 1/2
    diag reel of 4 with 2nd corners. 1s end in 2nd place opp side. (3)
    (1) (2)
25-32::
    3s+1s+2s dance Set+Link for 3 couples twice.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4921, '2013-08-21 08:30:57.06987+00', '2023-02-04 01:19:28.888607+00', 9406, 3, NULL, 'ace', '1-8::
    1s set, 1/2 turn RH moving down to 2nd place (1s move up), 1s twirl
    right to face 1st corner, set to & turn 1st corner 2H (skip change)
9-16::
    1s dance reels of 3 across (Lady with 2s & Man with 3s) giving LSh
    to 4th corner 1s end facing each other up/down
17-24::
    1s set, 1/2 turn RH, twirl right to face 2nd corner, set to & turn
    2nd corners 2H (skip change)
25-32::
    1s dance reels of 3 across (Lady with 3s & Man with 2s), 1s cross RH
    to own side in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (9724, '2017-04-06 08:39:38.425004+00', '2023-02-04 01:19:29.079979+00', 1539, 3, NULL, 'ace', '1-8::
    2s set, Petronella turn, set & Petronella turn to 2nd place opp
    sides
9-16::
    _1/2_ reels of 3 on sides (2M+1L & 2L+3M pass RSh).  1/2 reels of 3
    across 2M+3M (in 1st place) & 2L+1L (in 3rd place) pass LSh.  1s end
    facing 3rd corner (1st corner person)
17-24::
    2s turn corner RH, partner LH, 4th corner pstn (2nd corner person)
    RH, partner LH to 2nd place opp sides  (3) (2) (1)
25-32::
    3s+2s+1s set, 3s cross LH _while_ 2s+1s dance 1/2 RH across.  2s
    turn 2H (4 bars)  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4922, '2013-08-21 08:30:57.077924+00', '2023-02-04 01:19:29.102025+00', 13083, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s dance RH across (1L with 2, 1M with 3s)
9-16::
    1s turn LH & turn 1st corners RH, turn partner LH & turn 2nd corners
    RH to end 2nd place opposite sides
17-24::
    1s dance 1/2 reels of 3 on opposite sides giving LSh to 1st corner,
    1s dance 1/2 reel of 3 across giving RSh to 4th corner & end in 2nd
    pl own sides
25-32::
    1s turn RH 1.3/4 times _while_ 2s+3s dance 1/2 R&L (up/down to
    start), 1s dance up/down & round 4th corner to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (4923, '2013-08-21 08:30:57.180335+00', '2023-02-04 01:19:29.290948+00', 12675, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s turn RH as 2s turn LH to dance 1/2 Diamond Poussette &
    end facing down
9-16::
    1s followed by 2s dance down the middle & back
17-24::
    2s+1s+3s dance reels of 3 on own sides (1s dance up between 2s to
    start) & 1s end facing 1st corners
25-32::
    1s set to 1st corners, dance round each other RSh to 2nd corners,
    set & dance round each other to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (9187, '2016-06-16 22:41:41.030388+00', '2023-02-04 01:19:29.319796+00', 16845, 3, NULL, 'ace', '1-4::
    1s+2s petronella turn, set advancing passing partner LSh, Men pull
    back LSh to all face down with Men following partners
5-8::
    2s+1s dance down below 3s, cast up, 2s to 1st place own side, 1s to
    2nd place opp. sides   2 (1) 3 4
9-12::
    1M+2s (at top) dance RH across, 1L+3s (at bottom) dance 1/2 reel of
    3 across (3s cast up to start, 1L passes 3M RSh)
13-16::
    1M+1L pass RSh to swap end, 1L dances LH across with 2s, 1M 1/2 reel
    of 3 across with 3s, 1M passes 3M (in 1st corner pstn) LSh  2 (1) 3
17-24::
    1s+3s dance R&L
25-28::
    2s+1s+3s set advancing (2 bars), 2s dance up (1 step) & cast back to
    1st place as 3s dance (NHJ) up to 2nd place as 1s cast to 3rd place
    opp. sides
29-32::
    1s+4s turn once round (1M+4L with LH, 1L+4M RH), 1s cross down to
    4th place own sides _while_ 4s cast up to 3rd place    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4924, '2013-08-21 08:30:57.188644+00', '2023-02-04 01:19:29.37516+00', 11872, 3, NULL, 'ace', '1-4::
    1s lead down below 3s & cast up to 2nd place
5-16::
    2s+1s+3s dance 3 couple R&L
17-20::
    1s turn RH to face 4th corners (pstn) _while_ corners dance 1 place
    anticlockwise, 1s turn 4th corners LH _while_ 1st corners (pstn) set
21-24::
    1s turn RH to face 1st corner (pstns) _while_ corners dance 1 place
    anticl''wise, 1s turn 1st crnrs LH to end 2nd pl opp sides _while_
    2nd corners set 3 1 2
25-32::
    3s+1s+2s Set+Link for 3 twice.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4925, '2013-08-21 08:30:57.196601+00', '2023-02-04 01:19:29.399869+00', 10788, 3, NULL, 'ace', '1-8::
    1s+3s turn 3/4 RH, dance 1/2 reel of 4 in centre, 3s+1s turn 3/4 RH
    to own sides.  3 2 1 4
9-16::
    3s+2s also 1s+4s dance RH across & LH across (remain facing
    anticlockwise)
17-24::
    All chase 1/2 way & circle 8H round to right 1/2 way ready for…
25-32::
    3s+2s also 1s+4s dance Poussette to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14283, '2021-09-08 00:19:18.260798+00', '2023-02-04 01:19:29.436575+00', 14553, 3, NULL, 'ace', '1-8::
    1s set, lead down cross below 3s & cast up to 1st place opp side
9-16::
    1s+2s dance ''Bourrel'':
::
    _9-12_   1L+2L set advancing, 3/4 turn 2H & twirl to end BtoB (2L
    facing up & 1L down) _while_ partners chase anticlockwise to face
    partner
::
    _13-16_  Set to partners & turn RH. 2s end in 1st place own side, 1s
    finish in centre facing down, 1L on right of 1M
17-24::
    Mirror reels of 3 on sides, 1s dance down between 3s, 3s out/up, 2s
    out down to start. 1s end in centre facing down.  2 (1) 3
25-32::
    1s cross down below 3s & cast up to 2nd place own side; 2s+1s+3s
    turn partner RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7896, '2013-08-21 08:31:50.682229+00', '2023-02-04 01:23:09.987914+00', 7042, 3, NULL, 'ace', '1-8::
    1s cross below 2s to opposite sides, set to 3s on sides, set to
    partner, set to 2s
9-16::
    2s+1s dance 1/2 double Fig of 8, 1s+3s dance 1/2 double Fig of 8
17-24::
    2s+1s+3s petronella into centre & set, 2L followed by 1L+3L dance up
    to top & dn own side as 3M followed by 1M+2M dance dn & up own side
25-32::
    3s+1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (11403, '2018-12-17 14:21:50.863709+00', '2022-12-10 10:07:56.836636+00', 18711, 2, 160, 'ace', '1-8::  1C set, dance down, cast up round 3C. (2C up 3-4).

9-12::  1C+1cor. half diag. reel4 AS 2cor. chase CW 1/2 round - 1C pass Rsh to face 2nd cor. positions

13-16::  1C+2cor. half diag. reel4 AS 1cor. chase CW 1/2 round back to place. 1C pass Rsh to end in center 1M facing up, 1W facing down.

17-24:: Lsh fig. 8 across - 1M around 2C & 1W around 3C - 1C finish in center.

25-32::  1M+2C, 1W+3C circle to the left once round, 1C pull Rsh back to face; petronella to own side.', 3);
INSERT INTO 'dancecrib' VALUES (15294, '2022-12-10 21:55:44.969947+00', '2023-01-10 18:42:56.550885+00', 21197, 1, 202, 'ace', '1--::

  1c cross RH | cast off (2c up) ; 3C Set&Link

9--::

  3c+2c DblFig8 across, M crossing to W side

17--::

  3C Set&Link ; all turn P BH (3x,1,2x)

25--::

  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (4927, '2013-08-21 08:30:57.244159+00', '2023-02-04 01:19:29.486333+00', 1544, 3, NULL, 'ace', '1-8::
    1s & 3s set & pivot to right & dance round 1/4 cl''wise inside set (L
    follows M) & face in, 1s+3s change places with other partner RH &
    dance clockwise back to partners place (M follows L)
9-16::
    1s & 3s dance RH across with corner 2L/4L, 1s & 3s dance across & LH
    across with other corner 4M/2M to end in pl facing cl''wise (M behind
    L)
17-24::
    1s also 3s dance Tandem reels of 3 with corners, 1s & 3s ending in
    prom hold facing out
25-32::
    1s & 3s dance clockwise 1/2 way round outside of set & dance in back
    to original places (pass RSh) _while_ 2s & 4s (prom hold) Adv+Ret
33-64::
    2s & 4s repeat above Figs from beginning (bars 1-32)
65-72::
    All set to partners & change place RH, Ladies dance 3/4 RH across
    _while_ Men cast 1 place clockwise to meet opposite Lady
73-80::
    All repeat this Fig (bars 65-72) to end with own partners (opposite
    to where they started)
81-88::
    All dance 1/2 Schiehallion Reel (2 places) back to original places
89-96::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15412, '2023-02-04 01:19:29.556082+00', '2023-02-04 01:19:29.557359+00', 20300, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole:
::
    _1- 2_  1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3- 4_  1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5- 8_  2s turn RH as 1s turn LH & face out
9-16::
    1s cast to left to 1L between 2s, 1M between 3s, 1s cross LH; cast
    to right to 2nd place own side, all set
17-24::
    RSh reels of 3 on sides (1s RSh to person on right - 1M down, 1L up)
    2s & 3s loop into place
25-32::
    1L+2s also 1M+3s dance RH across; 1s swap ends to dance LH across
    with other couple', 0);
INSERT INTO 'dancecrib' VALUES (4929, '2013-08-21 08:30:57.264009+00', '2023-02-04 01:19:29.584694+00', 10105, 3, NULL, 'ace', '1-8::
    1s dance in, touch & cast 1 place _while_ 2s set, cross up to top
    (no hands), 1s dance in, touch, cast down 1place _while_ 3s set,
    cross up to 2nd pl
9-16::
    2s+3s+1s dance reels of 3 on sides (1s cross up to start, 3s
    out/down, 2s in/down) end 2 3 1 on opposite sides
17-24::
    1s dance up to top & cast 1 place (3s step down 19-20), 2s+1s+3s set
    & 1/2 turn partners RH for…
25-32::
    2s+1s+3s dance Promenade', 0);
INSERT INTO 'dancecrib' VALUES (13986, '2021-05-03 00:19:13.626413+00', '2023-02-04 01:19:29.615325+00', 9425, 3, NULL, 'ace', '{{title}}
Strathspey

{{explanation}}
(Square)

1-8::
    1s cross NH, dance out between side couples to dance Fig 8 round
    side couples (7 bars). 1s (1L on 1M''s left) +3s advance to centre
9-16::
    1s+3s dance Rondel & end facing out
17-24::
    2s & 4s take prom hold & dance reels of 3 on sides, 2s RSh to 3L, 4s
    RSh to 1M (3s & 1s cast away from partner to start reels & give
    hands in reel)
25-28::
    2s+4s advance in prom hold to dance Tournee (Men with prtnr on
    right, 2s face 4s'' side & 4s 2s'' side), couples 1/2 wheel
    anticl''wise & Men turn Ladies into middle _while_ 3s & 1s cast to
    opp ends passing RSh on sides
29-32::
    All turn 1.3/4 (1s & 2s LH, 4s & 3s RH).  End 1 4 2 3 now in
    longways set

{{title}}
Reel

{{explanation}}
(Longways)

33-40::
    1s & 2s set, cross RH & cast 1 place (4s & 3s step up); 1s+3s
    (middle couples) dance 1/2 RH across.  3M+1L in prom hold face
    down/out, 3L+1M in prom hold face out/up
41-48::
    _3/4_ reels of 3 on sides.  End 3M+1L in 1st place opp sides, 4s in
    2nd place, 2s in 3rd place, 3L+1M in 4th place opp sides
49-56::
    All set & turn 3/4 RH; all set & turn 3/4 RH to end in centre NHJ
    ready for …
57-64::
    1L+3M with 4s also 2s with 1M+3L dance Poussette (Men retire to
    start).  Bars 63-64: 1s & 3s retire to sides _while_ 2s & 4s set,
    opening out to reform square set.  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (14902, '2022-06-27 00:19:22.73331+00', '2023-02-04 01:19:29.711289+00', 20878, 3, NULL, 'ace', '1-8::
    1s cross RH, cast off (2s step up), 1s cross LH & cast to the left
    to end 1L between 2s facing down & 1M between 3s facing up
9-16::
    Lines of 3 across Adv+Ret up/down, then Set+Link for 3  (2) 1 (3)
17-24::
    2s+1s+3s Adv+Ret, Set+Link for 3. 1M ends between 3s facing down &
    1L between 2s facing up & 2s & 3s facing partners
25-28::
    1s Petronella turn to own sides and set, _while_ 3s & 2s set &
    Petronella turn into centre
29-32::
    3s & 2s RSh pass partner & chase clockwise to own sides. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4931, '2013-08-21 08:30:57.281909+00', '2023-02-04 01:19:29.75887+00', 12719, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-12::
    1s 1/2 turn LH & lead down to bottom _while_ 2s+3s cross LH & cast
    up 1 place
13-16::
    2s stand for 2 Bars then cross LH _while_ 3s dance up & cast back to
    2nd place _while_ 1s turn LH 1.1/2 times
17-24::
    3s turn 1st corner LH, partner RH, 2nd corner LH & partner RH to end
    2nd place own sides
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15288, '2022-12-08 22:19:32.081589+00', '2022-12-10 19:10:57.220798+00', 20863, 1, 1645, 'ace', '1--16::

  Fugue: 1M set | cast (2M up) ; set | petronella to between 3c ;;

  set with 3c | advance with 3c ; retire with 3c | advance alone _while{16}_

  1W waits{2} and then repeats 1M''s [1-14], dancing with 2c, on [16] 1W pivots R to give RSh to 2W

17--::

  1W with 1M following tandem Reel3 across with 2c, finish (2,1,3)

25--::

  Parallel Reels3 on own sides, 1c start RSh to 3c (2,1,3)

::

  *Repeat 1-32 with set inverted: 3W starts in 1M role with 3M waiting 2 bars then following in 1W role, end (2,3,1). Invert set on each subsequent repeat.*

', 2);
INSERT INTO 'dancecrib' VALUES (4939, '2013-08-21 08:30:57.474844+00', '2023-02-04 01:19:30.789848+00', 1564, 3, NULL, 'ace', '1-8::
    1M+2L also 3M+4L turn RH 1.1/2 times into RH across with partners
    1/2 way & all cross (2s & 4s under arches made by 1s & 3s)
9-16::
    2M+1L also 4M+3L turn LH 1.1/2 times into LH across with partners
    1/2 way & all cross (Ladies under arches made by Men)
17-24::
    1s+4s (centre cpl) dance RH across 1/2 way, change places RH with
    partners, 2s+4s also 1s+3s dance RH across 1/2 way & all change pl
    on sides
25-32::
    All dance RSh reels of 4 on sides', 0);
INSERT INTO 'dancecrib' VALUES (14932, '2022-06-29 17:44:30.707253+00', '2022-12-10 21:30:28.706076+00', 20927, 1, 202, 'ace', '1--::
  1c long cast to 2pl (2c up) ; 3C Set&Link
9--::
  1c turn RH ½, face P and cast away to exchanged places ; 3C Set&Link (3x,1,2x)
17--::
  1c Fig8 L RSh round 2cnrs[pos] (3x,1,2x)
25--::
  Diagonal R&L (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (13025, '2020-08-10 00:18:18.145088+00', '2023-02-04 01:18:20.074617+00', 19169, 3, NULL, 'ace', '1-8::
    1s+2s dance Rose Progression:
::
    _1-2_   1M+2L facing in diagonally set _while_ 2M+1L change places
    RH to face out
::
    _3-4_   1M+2L 1/2 turn 2H to face each other as 1L+2M dance into
    partners place
::
    _5-6_   1M+2L cast into each others place as 1L+2M 1/2 turn 2H to
    face each other
::
    _7-8_   1M+2L dance into 2nd/1st place own side _while_ 2M+1L cast
    to right to new places   2 1 3
9-16::
    2s+1s+3s dance 8 bars of R&L for 3 Couples:
::
    _9-10_    All 3 couples cross RH with dancer opposite
::
    _11-12_  Dancers in 1L place & 3M place change places diagonally LH
    _while_ other couples change places LH on side
::
    _13-16_  Repeat bars 1-4 from new places. Ladies'' side: 1M 2M 2L;
    Men''s side: 3M 3L 1L
17-20::
    All set, 3s & 2s 3/4 turn partners 2H on sides _while_ 1s 1/2 turn
    RH. All now on own side 3 1 2
21-24::
    3s+1s+2s dance 1/2 reels of 3 on sides (1s RSh to 3s)
25-32::
    1L+2L+3L dance LH across _while_ 1M+2M+3M dance RH across; 1s dance
    down to 3rd place (3s step up) & 1s turn 2H.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (15318, '2022-12-19 01:19:20.727295+00', '2023-02-04 01:19:29.77653+00', 21121, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp sides

1-4::
    2s+3s dance RH across _while_ 1M+4M, followed by their partners,
    chase 1/2 way anti-clockwise 4 2 (3) (1)
5-8::
    4s+2s also 3s+1s Set+Link 2 4 (1) (3)
9-14::
    2s+4s also 1s+3s dance 4H round to left. All set
15-16::
    4s & 1s dance LSh round partner ending in tandem, Men leading, to
    face 2M/3M
17-24::
    4s & 1s dance alternating tandem LSh reels of 3 across with 2s/3s to
    end on sides facing up/down 2 4 (1) (3)
25-32::
    All dance RSh reels of 4 on the sides. Bars 31-32: 1M+4L also 1L+4M
    turn 1/2 way RH instead of passing LSh. 2 4 (1) (3)
::
    Except for last repeat, they retain hands ready for RH across as new
    2s+3s', 0);
INSERT INTO 'dancecrib' VALUES (12541, '2020-02-02 02:47:29.785047+00', '2023-02-04 01:19:29.814209+00', 1546, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole, 1s finish facing 1 corners
9-16::
    1s dance 1/2 diag reel of 4 with 1st corners, pass partner RSh, 1s
    dance 1/2 diag reel of 4 with 2nd corners. (3)(1)(2)
17-24::
    1s turn RH, 1s dance 1/2 RSh reel of 3 across, (1L up 1M down) 312
25-32::
    1s dance the Snake Pass:
::
    1s dance RH across (1L with 3s & 1M with 2s), 1L followed by 3s also
    1M followed by 2s pass LSh diagonally across through 2nd place to
    change ends & loop round to left to end in 2nd place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4932, '2013-08-21 08:30:57.290038+00', '2023-02-04 01:19:30.041603+00', 1547, 3, NULL, 'ace', '1-8::
    2s+4s cast up 1 place _while_ 1s+3s lead down for 2 & back, 1s+3s
    dance individual Allemandes in centre & 1s end facing 1st corners 3s
    in 4th place
9-16::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partner LH to
    2nd places
17-24::
    1s+4s+3s (bottom 3 couples) dance reels of 3 on sides 1s dancing out
    & down to start
25-32::
    1s turn 4s on sides 1.1/2 times (1s dancing out) & Bal-in-Line on
    sides twice', 0);
INSERT INTO 'dancecrib' VALUES (11694, '2019-03-18 21:02:00.763044+00', '2023-02-04 01:19:30.059846+00', 19137, 3, NULL, 'ace', '{{explanation}}
May be danced as Medley(72R+72S)

1-8::
    1s+3s Set+Link to finish facing clockwise. 1L+3L followed by ptnr
    dance clockwise outside and around side couples & finish facing them
    in the middle of the set (1L facing 2L, 1M facing 2M, 3L facing 4L,
    3M facing 4M)
9-16::
    1s+2s & 3s+4s dance RH across. 1s+3s then snake chase around each
    other to the left to finish in each other''s positions _while_ on bar
    12 2M+4M pull back LSh & turn partners LH
17-32::
    2s+4s repeat bars 1-16 to finish all couples facing in
33-40::
    Ladies dance RH across 3 places, rotate on the spot (pulling back
    RSh on bar 36) to face Man . All set & change places LH (Ladies
    finish on outside facing in, Men face in)
41-48::
    Men dance RH across 3 places, rotate on the spot (pulling back RSh).
    All set, turn ptnr 3/4 LH to finish in a square (end Lady on Man''s
    left, Men facing in, Ladies facing out)
49-60::
    All dance 3/4 reverse Schiehallion reel (3 places to left & Ladies
    follow Men) to end in original places
61-64::
    All 1/2 turn ptnr LH to finish facing in, all set
65-72::
    _8_ Hands round & back

{{explanation}}
Medley: Strathspey starts with 2s&4s, end bars 65-72: 8H round to left, all pivot (pull back LSh) & circle 8H round to right, back to places', 0);
INSERT INTO 'dancecrib' VALUES (15059, '2022-09-05 00:19:16.655808+00', '2023-02-04 01:19:30.081925+00', 14797, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 3 facing 3

1-8::
    All circle 6H round & back
9-16::
    Middle persons Petronella turn to right & all set; middle persons
    Petronella turn to opposite side & all set
17-24::
    Middle parsons stand _while_ outside persons dance RH across & chase
    clockwise 1/2 way round
25-28::
    Each line of 3 dances 1/2 reel of 3 (middle person RSh to person on
    their right)
29-32::
    All turn opposite person RH to face the same way as originally &
    dance forward to meet next 3 dancers', 0);
INSERT INTO 'dancecrib' VALUES (10330, '2017-12-22 15:44:11.022881+00', '2023-02-04 01:19:30.342986+00', 11837, 3, NULL, 'ace', '1-8::
    1s NHJ dance down, cast up round 2s back to place.  1s dance down,
    cast up round 3s into 2nd place own side (2s step up 7-8)
9-16::
    LSh reels of 3 across, 1s passing 1st corners LSh to start.  1s pass
    RSh to end facing 1st corners
17-24::
    1s+1st corner set & dance La Baratte:
::
    _17-18_   1s+1st corners set
::
    _19-20_   Man 1/2 turns opposite Lady RH & retains hand but at arm''s
    length from each other
::
    _21-22_   Man retraces steps with Lady turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies original
    place) & releasing Ladies RH she turns under Mans left arm until
    almost in original places
::
    _23-24_   Couple change places LH, 1s end facing out to Left _while_
    corners remain facing in
25-28::
    1s cast round 2nd corners & in at ends of set (1M between 2s, 1L
    between 3s) _while_ 1st corners turn RH back to place
29-32::
    1s turn RH to 2nd place own sides & 2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (6191, '2013-08-21 08:31:20.118281+00', '2023-02-04 01:21:04.00147+00', 3888, 3, NULL, 'ace', '1-8::
    1M sets advancing & turns 2L RH, 1s turn LH
9-16::
    1L sets advancing & turns 2M LH, 1s turn RH
17-24::
    1s lead down between 2s, cast down behind 3s & turn 2H, lead up to
    top & cast to face 1st corners
25-32::
    1s set to 1st corners, set to 2nd corners & turn 2H 1.1/2 times to
    places', 0);
INSERT INTO 'dancecrib' VALUES (4933, '2013-08-21 08:30:57.298643+00', '2023-02-04 01:19:30.368651+00', 1549, 3, NULL, 'ace', '1-8::
    Men dance in, set, turn right about & dance out to next place
    clockwise passing behind corner person
9-16::
    Ladies dance in, set, turn left about & dance out to next place
    anticlockwise passing behind corner person
17-24::
    1L+3L turn RH 1.1/4 times, dance LH across 1/2 way (1L with couple
    in 1st place, 3L with couple in 3rd place) & chase anticlockwise
    back to ''new'' places _while_ couples in 1st & 3rd places 1/2 turn LH
25-32::
    1M+3M turn LH 1.1/4 times, dance RH across 1/2 way (1M with couple
    in 1st place, 3M with couple in 3rd place) & chase clockwise back to
    ''new'' places _while_ couples in 1st & 3rd places 1/2 turn RH
33-40::
    Men repeat bars 1-8
41-48::
    Ladies repeat bars 9-16 & all end with own partners in opposite
    original places
49-56::
    2L+4L repeat bars 17-24
57-64::
    2M+4M repeat bars 25-32
65-72::
    1s+3s dance 1/2 R&L to end facing corner person, change places with
    corner RH & set then face in
73-80::
    2s+4s dance 1/2 R&L to end facing corner person, change places with
    corner RH to meet own partner & set then face in
81-88::
    All dance 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8659, '2015-02-14 00:35:50.361522+00', '2023-02-04 01:19:30.392222+00', 16053, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place (2s step up), 1s turn LH to face 4th
    corners
9-16::
    1s dance 1/2 Diag reel with 4th crnrs & pass RSh to face 1st
    corners, 1s dance 1/2 Diag reel with 1st crnrs to end 1L between 3s
    (at top), 1M between 2s (3rd place)
17-24::
    1s dance Diag R&L (up/down):
::
    _17-20_   1s change places RH with dancer diagonally to Right,
    dancers change places LH at ends of set
::
    _21-24_   1s change places RH with dancer diagonally to Left,
    dancers change places LH at ends of set. 1s end facing 4th corners
25-32::
    RSh reels of 3 across, 1L+2s (at top) & 1M+3s (at bottom) & 1s cross
    RH to own sides bars 31-32', 0);
INSERT INTO 'dancecrib' VALUES (10626, '2018-04-16 21:41:42.893819+00', '2023-02-04 01:19:30.423003+00', 1551, 3, NULL, 'ace', '1-8::
    1L casts round 2L & dances up above 1M; 1s take prom hold, cast
    round 2M & across to 1L place facing out
9-12::
    1s cast round 2L, dance up NHJ to 1M place making arch _while_ 2M
    casts up & crosses down under arch to below 2L
13-16::
    1s cast down & 2s cast up & cross set, 1s dancing under arch made by
    2s (1s on ladies'' side, 2s on Men''s side).  All face in
17-20::
    1s+2s circle 4H 1/2 round & set (Men NHJ facing up, Ladies NHJ
    facing down)
21-24::
    1s+2s circle 4H 1/2 round & set (on sides, NHJ with partner)
25-32::
    1M+2L 1/2 turn RH, 1L+2M join in & dance 1/2 RH across, 1s+2s dance
    1/2 LH across to own sides & set to partners', 0);
INSERT INTO 'dancecrib' VALUES (13065, '2020-08-10 00:19:14.625471+00', '2023-02-04 01:19:30.510869+00', 1554, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across; 2s+3s dance LH across _while_ 1s &
    4s chase clockwise 1/2 round to change places.  (4) 2 3 (1)
9-16::
    All dance RSh reels of 4 on the sides
17-24::
    4s+2s also 3s+1s dance LH across; 2s+3s dance RH across _while_ 1s &
    4s chase anticlockwise 1/2 round to original places. 1 2 3 4
25-32::
    1s+2s also 3s+4s dance R&L
33-40::
    1s cast to 4th place (2s+3s+4s step up 35-36); All turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (11184, '2018-09-30 22:19:35.656749+00', '2023-02-04 01:19:30.539767+00', 18616, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reels of 3 on own sides
17-24::
    All set & dance DoSiDo then all set
25-32::
    1L followed by partner cast to 2nd place & 1L crosses to Mens side,
    1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (13887, '2021-04-05 00:19:17.511237+00', '2023-02-04 01:19:30.606833+00', 19485, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across; set & 2s cross RH to own side
    _while_ 1s turn LH to face 1st corners
9-16::
    1s+1st corners turn RH & dance 1/2 diag reel of 4; 1s pass LSh to
    face 2nd corners
17-24::
    1s+2nd corners turn RH & dance 1/2 diag reel of 4.1s end in 2nd
    place opp side.  (3) (1) (2)
25-32::
    1M+3s (at top) & 1L+2s dance 1/2 reels of 3 across (1M+3L & 1L+2M
    pass LSh); 1s+2s+3s dance 1/2 RSh reels of 3 on sides (1M down/1L
    up)
33-40::
    1s dance up to top, cast, meet & dance down between 3s & cast up to
    2nd place own side.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4935, '2013-08-21 08:30:57.436718+00', '2023-02-04 01:19:30.619832+00', 8725, 3, NULL, 'ace', '1-8::
    1s set & cross RH, cast 1 place turn LH to face 1st corners
9-16::
    1s turn corners RH & pass RSh to face 2nd corners, turn corners RH &
    pass RSh to face 3rd corners
17-24::
    1s turn corners RH & pass RSh to face 4th corners, turn corners RH &
    pass RSh to face 1st corners
25-32::
    1s dance RSh reel of 3 on opposite sides ending 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4936, '2013-08-21 08:30:57.444946+00', '2023-02-04 01:19:30.639858+00', 1558, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, Set+Link back to places
9-16::
    1s+2s dance reel of 4 across, 1M passes 2L LSh to start, end with
    1L+2M passing RSh to flow into …
17-20::
    1s+2s dance a Little Spiral (dancers advance, turn right about,
    dance out to places & dance in passing partner RSh) to change places
21-24::
    1s+2s dance »Big Spiral« (dancers advance diagonally, turn right
    about to places & chase clockwise 1/2 way) to progress
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (13232, '2020-10-16 00:19:27.08022+00', '2023-02-04 01:19:30.664152+00', 20084, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-8::
    1s & 4s dance in, touch hands & cast to 2nd/3rd place (2s & 3s step
    down/up bars 3-4); 1s & 4s dance 1/2 Fig 8 round end couples. 2 (1)
    4 (3)
9-16::
    1s+4s dance LH across, face up/down on sides; all dance 1/2 RSh
    reels of 4 on sides. End facing down/up on sides. (3) 4 (1) 2
17-24::
    3s+4s also 1s+2s turn 1.1/4 RH on sides into 2 lines of 4 across;
    all dance 1/2 RSh reels across
25-32::
    3s+4s also 1s+2s turn 1.1/4 RH to sides, 1s facing 4s; 1s+4s change
    places LH on sides, face partners & all 4 couples set
33-40::
    All 1/2 turn partner 2H, pull back RSh & dance out to sides;
    3s+1s+4s+2s circle 8H 1/2 round to left.  End (2) (4) 1 3

{{explanation}}
Repeat once as Strathspey then twice as Reel (RH turn 33-34)', 0);
INSERT INTO 'dancecrib' VALUES (4940, '2013-08-21 08:30:57.558188+00', '2023-02-04 01:19:30.801904+00', 9945, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s set & dance RH across 1/2 way, all set & dance LH
    across 1/2 way to original places
9-16::
    1s+2s & 3s+4s dance reels of 4 across the dance (2L & 1M pass LSh
    also 4L & 3M pass LSh to start)
17-24::
    All chase clockwise 1/2 way, all cross RH.  4 3 2 1
25-32::
    2s+3s+4s dance the Knot to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9189, '2016-06-16 22:41:41.328528+00', '2023-02-04 01:19:30.814586+00', 16846, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up) & pass LSh to dance RSh round 1st
    corners.  End 1L between 2s facing 2L, 1M between 3s facing 3M
9-16::
    1s dance 1/2 LSh reel of 3 across finishing in 2nd place opp sides,
    1M facing up, 1L down.  1s dance 1/2 LSh reel of 3 on sides
    finishing by crossing to 2nd place own sides (3) 1 (2)
17-18::
    1s 1/2 turn LH, 1L face down, 1M face up _while_ 3s+2s turn 3/4 LH
    to finish in middle facing opp sides
19-20::
    All set (no hands) & pull back RSh, Ladies face up, Men down
21-24::
    3s+1s+2s dance clockwise to own sides  2 1 3
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (12862, '2020-06-03 16:25:44.835508+00', '2023-02-04 01:19:30.825742+00', 1567, 3, NULL, 'ace', '1-8::
    1s+2s+3s petronella turn into centre & set, 1s+3s turn 1.1/4 RH to
    place _while_ 2s turn LH to finish in centre
9-12::
    2L+1s & 2M+3s dance RH across, 2s pass LSh to face 1st corners
13-16::
    2s dance 1/2 diagonal Reel of 4 with 1st corners, 2s pass LSh to
    face 2nd corners
17-20::
    2s dance 1/2 diagonal Reel of 4 with 2nd corners, 2s finish in
    centre LSh to LSh (2M above 2L) facing own side
21-24::
    2M+3s & 2L+1s dance RH across, 2s 1/2 turn LH to face 2nd corner
    person now on opp sides (2L facing 3M, 2M facing 1L)
25-28::
    2nd corners turn 2s RH into corner places, 2nd corners (1L+3M) turn
    1.1/4 LH to face partners
29-32::
    1L+3M turn partners RH to end in their partners places, 1M+3L 3/4 LH
    turn to 2nd place own sides.
::
    End: Ladies 2 3 1, Men 3 1 2
::
    Repeat twice more with new partners to end back with original
    partner', 0);
INSERT INTO 'dancecrib' VALUES (4942, '2013-08-21 08:30:57.580379+00', '2023-02-04 01:19:30.981003+00', 13597, 3, NULL, 'ace', '1-8::
    1s & 3s 3/4 turn 2H & set passing partner LSh, 1M & 3L cast right to
    other end as 1L+2s+3M circle 4H to left & end 3L facing 1L also 3M
    facing 1M
9-12::
    3s+1s turn 2H & set passing partner LSh
13-16::
    3M & 1L dance out ends & cast right to other end (3s/1s end facing
    own partner up/own middle) as 3L+2s+1M circle 4H to left
17-20::
    3s & 1s 3/4 turn RH to face down/up & all set
21-24::
    3s turning inwards dance out to 1st place _while_ 2s dance in & down
    to 3rd place as 1s cast up to 2nd pl & 3/4 turn LH to face up/down
25-32::
    1s dance RH across (1M with 3s at top, 1L with 2s) 1s ending 2nd
    place opp sides, 1s turn 2H 1.1/2 times to 2nd place own sides.  3 1
    2', 0);
INSERT INTO 'dancecrib' VALUES (4943, '2013-08-21 08:30:57.590465+00', '2023-02-04 01:19:31.003585+00', 10793, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, dance down between 3s & cast up to join
    LH with partner & RH with 2nd corners
9-16::
    1s+2nd corners Bal-in-Line, face corners & set, turn corners RH &
    pass partner LSh to face 3rd corner (pstn) _while_ 1st corners set
    turning left to dance clockwise 1/2 way to change places & set
17-20::
    1s dance 1/2 diagonal RSh reel of 4 with corners to join LH with
    partner & RH with 1st corners (pstn)
21-28::
    1s+1st corners Bal-in-Line, face corners & set, turn corners RH &
    pass partner LSh to face 2nd corner (pstn) _while_ 2nd corners set
    turning left to dance clockwise 1/2 way to change places & set
29-32::
    1s dance 1/2 diagonal reel with corners, give LH briefly to end
    LSh/LSh
33-40::
    1s dance RH across (1L with 2s & 1M with 3s), pass RSh & dance LH
    across with other couple to end 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (8774, '2015-06-15 11:40:36.824879+00', '2023-02-04 01:19:31.032143+00', 14438, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 2s+1s circle 4H round to Left
9-16::
    1s+3s dance »Bourrel«
::
    _9-12_      1M+3L set advancing, 3/4 turn 2H & twirl to end BtoB
    (Lady facing up & Man down) _while_ partners chase anticlockwise to
    face partner
::
    _13-16_    Set to partners & turn 2H staying in middle ready for …
17-24::
    3s+1s dance 1/2 Poussette, 2s+1s dance 1/2 Poussette with 1s
    continuing to turn 2H to finish in 1st place opp sides NHJ facing
    down (1) 2 3
25-32::
    1s dance down between 3s (2s step up), cross & cast up to 2nd place
    own sides.  2s+1s+3s turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (11735, '2019-03-26 02:05:10.960968+00', '2023-02-04 01:19:31.052798+00', 14405, 3, NULL, 'ace', '1-8::
    1s/3s dance 1/2 Fig 8 round 2s/4s. 1M+2L & 3M+4L turn 1.1/2 LH,
    1L+2M & 3L+4L turn 1.1/2 RH. 1s & 3s end BtoB with partner facing
    opp sides
9-16::
    1s & 3s dance Double Triangles finishing facing 1st corners
17-24::
    1s & 3s dance Corner Pass+Turn with 1st corners, pass partner RSh &
    repeat with 2nd corners, passing partner RSh to face out own sides
25-32::
    1s & 3s cast round 3rd corner & cross diagonally to opp sides, 1s to
    2nd place, 3s to 4th place (1L+3M pass RSh); 1s & 3s cross RH with
    partner and cast off 1 place.  End 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (4944, '2013-08-21 08:30:57.600615+00', '2023-02-04 01:19:31.076757+00', 1573, 3, NULL, 'ace', '1-8::
    1L & 4M change places giving RH to dance & 1L dances behind 3M in
    front of 2M & behind 1M into his place as 4M dances behind 2L  in
    front of  3L & behind 4L into her place (2L+3L+4L step up as  Men
    step down
9-16::
    2L+3L+4L also 1M+2M+3M set & change places diagonally RH, all turn
    2H to end in middle (1s+2s turn 1.1/2 & face up as 3s+4s turn & face
    down)
17-24::
    1s+2s & 3s+4s dance an Allemande to end 2 1 (4) (3)
25-32::
    2L+1L also 4L+3L dance across (between their partners) & cast back
    to end facing each other, 2s+1s also 4s+3s change places on sides
    giving LH & cross with partners RH to end (1) (2) 3 4
33-36::
    2s+3s dance 4H round, _while_ 1s & 4s turn partner 2H once round,
    2s+3s+4s return to place _while_ 1s stay in middle & face down
37-40::
    1s lead down LH & cross to 4th place _while_ 2s lead up RH & cross
    into 1st place as 3s+4s step up. End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4945, '2013-08-21 08:30:57.610362+00', '2023-02-04 01:19:31.097153+00', 11634, 3, NULL, 'ace', '1-8::
    1s Adv+Ret (touching RH), cross RH & dance 1/2 reels of 3 on opp
    sides (1M RSh to 2L & 1L LSh to 2M) ending with 1s & 3s looping to
    face in
9-16::
    1s Adv+Ret (touching RH), cross RH & dance 1/2 reels of 3 on own
    sides (1M LSh to 2M & 1L RSh to 2L) ending with 1s & 3s looping to
    face in
17-24::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 2s
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4948, '2013-08-21 08:30:57.710248+00', '2023-02-04 01:19:31.533367+00', 1579, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s lead down for 3 steps, back to top & cast to 2nd places
17-24::
    2s+1s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (12881, '2020-06-03 16:28:16.514179+00', '2023-02-04 01:23:08.299355+00', 18451, 3, NULL, 'ace', '1-8::
    1s dance down, cast behind 3s, meet & dance up, cast behind 2s back
    to 1st place
9-16::
    1s turn RH, cast (2s step up); 1s turn 1.1/4 LH to face 4th corner
    (pstn) _while_ 2s+3s dance clockwise 1/2 round
17-20::
    1s+corners dance 1/2 diag RSh reel of 4, dance LSh round each other
    to face 3rd corner (pstn)
21-24::
    1s+corners dance 1/2 diag RSh reel of 4, 1s pass LSh to end in
    middle LSh to LSh (1M below 1L) facing opp sides
25-32::
    1M+3s also 1L+2s dance RH across; 2s+1s+3s turn partner RH
33-40::
    2s+1s+3s circle 6H round & back.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14393, '2021-10-16 11:52:59.51663+00', '2022-12-10 23:04:30.871392+00', 3651, 2, 2784, 'ace', '1-::

  1M adv to P {2} sets {2} and dances round her Lsh back to pl

9-::

  1M repeats with 2W

17-::

  1M repeats with 3W

25-::

  1M adv to 4W {2} 1M+4W turn RH {2} to face W side, 1M+4W lead up behind W’s line and dance in to face P _while{4}_ 4M,followed by 3M+2M cast up to finish 4,3,2; 1c+4c end in line across top of set (1M&4W BtoB)

33-::

  All set twice, 3W+2M advancing to P (pass Lsh), all turn P BH {4} to end in 2 lines across the dance (2c on W side, 3c on M side, all M BtoB in middle of lines)

41-::

  1c+4c, 2c+3c Reel4 across the dance, end as started facing down NHJ

49-::

  All dance down and back, turning by the R at the bottom, top line turns by the R to end with lines facing

57-::

  1c+2c, 4c+3c R&L, setting to each person as they meet {16} (start by passing RH up & down) end facing P

73-::

  All promhold with P dance round set clw (1c follow 2c down W side, 3c follow 4c up M side) end _either_ in original places _or_ 2,3,4,1 ', 3);
INSERT INTO 'dancecrib' VALUES (4949, '2013-08-21 08:30:57.720267+00', '2023-02-04 01:19:31.551645+00', 8235, 3, NULL, 'ace', '{{explanation}}
Square Set

1-8::
    All Ladies dance LH across _while_ Men dance Highland Schottische
    setting (4 bars). Ladies dance LSh round partner to end BtoB facing
    partner
9-16::
    All set & dance La Baratte :
::
    Men 1/2 turn Lady RH & retains hand but at arm''s length from each
    other
::
    Men retrace steps with Lady turning right under Man''s arm briefly
    into Allemande hold (Man behind Lady facing Ladies'' original place)
    & releasing Ladies'' RH she turns under Man''s left arm until almost
    in original places
::
    Couples change places LH to opposite places
17-24::
    All Promenade anticlockwise to original places
25-32::
    All Petronella-in-Tandem 1 place to right, set & turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (4950, '2013-08-21 08:30:57.72658+00', '2023-02-04 01:19:31.568656+00', 10781, 3, NULL, 'ace', '1-8::
    1s set, cast & turn LH 1.1/2 times to face 1st corner
9-16::
    1s dance 1/2 reel of 4 with 1st corners & 1/2 reel of 4 with 2nd
    corners to end facing 3rd corners (pstn)
17-28::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s meet in middle
    again & pass RSh to 2nd place own side
29-32::
    2s+1s+3s turn partners 2H', 0);
INSERT INTO 'dancecrib' VALUES (4953, '2013-08-21 08:30:57.851485+00', '2023-02-04 01:19:31.762683+00', 1584, 3, NULL, 'ace', '1-8::
    All circle 8H round to left; Men join LH in centre & RH with partner
    to dance LH across 1/2 way. Men end BtoB facing partners
9-16::
    1s+3s also 2s+4s dance 3/4 reel of 4 (LH across in centre). End with
    Men on side opp original pstn & Ladies BtoB facing new partner, 1
    place clockwise from original place (1L facing 4M in 2nd place), All
    clap & set
17-24::
    Ladies (with new partner on left) dance RH across for 4 steps & open
    out to circle 8H round to right
25-32::
    All dance 3/4 Grand Chain (1 bar per hand) Ladies travelling
    clockwise, Men anticlockwise, to end Ladies in original places & Men
    1 place anticlockwise from original places, All clap & set
33-40::
    Couple in 1st place (2M+1L) dance out through couple in 3rd place,
    separate & cast into centre; 2M dances RH across with couple in 2nd
    place _while_ 1L dances LH across with couple in 4th place (2M+1L
    ending back in 1st place)
41-48::
    All Ladies cast anticlockwise behind original partner, turn next
    corner RH & all clap & set (with original partner). End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4956, '2013-08-21 08:30:57.905465+00', '2023-02-04 01:19:32.047734+00', 1587, 3, NULL, 'ace', '1-8::
    1L+2L turn LH as 1M+2M turn RH, 1s+2s dance 1/2 double Fig of 8 (1s
    cross down to start)
9-16::
    1s with 2s+3s dance RH across on Men''s side & LH across on Ladies''
    side, 1s+3s dance 1/2 double Fig of 8 (1s cross down to start)
    (2)1(3)4
17-24::
    3s with 1s+4s dance RH across on Men''s side & LH across on Ladies''
    side 1s ending 3rd pl & turn 4s 1.1/2 times (1L+4L LH, 1M+4M RH)
    (2)(3)41
25-32::
    All dance reflection reels of 4 on sides (LSh Ladies'' side, RSh
    Men''s side).  (2)(3) 4 1
::
    Note - 2nd & 4th repeat, new 1s & 2s start on opposite side', 0);
INSERT INTO 'dancecrib' VALUES (4957, '2013-08-21 08:30:57.919268+00', '2023-02-04 01:19:32.073853+00', 1588, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 1s+3s Set+Link
9-16::
    2s+3s+1s advance for 1 step & retire, 1/2 turn 2H into centre, set &
    twirl out to opposite sides
17-24::
    2s+3s+1s dance Grand Chain for 2 hands (2s in 1st pl cross) to end
    (1)2 3, 1s+2s Set+Link (1s end in double triangle position facing
    opp sides)
25-26::
    All Adv+Ret (1 step)
27-28::
    All advance 1 step & turn right about
29-30::
    All Adv+Ret (1 step)
31-32::
    1s cross RH as 2s+3s repeat bars 27-28', 0);
INSERT INTO 'dancecrib' VALUES (4958, '2013-08-21 08:30:57.93836+00', '2023-02-04 01:19:32.113421+00', 11724, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, 1M dances 1/2 Fig of 8 round 2s _while_ 1L
    dances 1/2 Fig of 8 round 3s
9-16::
    2s+1s+3s Adv+Ret (1 step) & cross RH, Adv+Ret (1 step) & cross RH
17-24::
    1s dance reels of 3 across (1M with 2s & 1L with 3s) & turn LH to
    face 1st corners
25-32::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners & pass RSh to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4960, '2013-08-21 08:30:57.966662+00', '2023-02-04 01:19:32.163885+00', 1596, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, 2s+1s+3s dance 1/2 Grand Chain (3s+1s+2s on
    opposite sides with 3s+2s facing diagonally in)
9-16::
    3s+1s+2 advance 2 steps, 1s turn to right & dance out to sides
    _while_ 3s+2s set diagonally, 1s cast round 1st corner pstns &
    dances down/up the middle to face 1st corners _while_ 3s+2s dance LH
    across for 1/2 way & loop round to right to corner pstns
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13611, '2021-02-04 01:19:18.752154+00', '2023-02-04 01:19:32.197421+00', 15239, 3, NULL, 'ace', '1-4::
    1s & 4s set, cross down/up (no hands) to 2nd/3rd place & face out
    (2s & 3s step down/up bars 3-4)
5-8::
    1s cast up & 4s cast down through ends, meet partner & dance towards
    centre NHJ
9-12::
    1s+4s dance RH across to face corners _while_ 2s+3s chase
    anticlockwise 1/2 round
13-16::
    1s & 4s turn corner LH, pass LSh to end BtoB in centre facing diag
    opp corner
17-24::
    2s+3s dance diag reel of 4 (LH across in centre) _while_
::
    1s+4s dance 1/2 diag reel round corner, pass LSh, dance RSh round
    next anticlockwise corner. End 4L between 3s at top, 1M between 2s
    at bottom, 1L & 4M on own side in middle
25-32::
    1s+4s set advancing & dance 1/2 RH across to opp sides facing
    partner, (3) (1) (4) (2);  All set & cross RH to own side.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (4954, '2013-08-21 08:30:57.87024+00', '2023-02-04 01:19:32.581736+00', 1582, 3, NULL, 'ace', '1-8::
    1s+2s set & dance RH across 1/2 way, set & dance LH across 1/2 way
    back to place
9-16::
    1s lead down the middle & back to top
17-24::
    1s+2s dance Allemande
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15295, '2022-12-11 00:06:13.678017+00', '2022-12-11 00:12:53.88791+00', 15025, 1, NULL, 'ace', '1--::

  1c  start inwards into Fig8 on own side round 2c & 3c 

9--::

  1c lead down and up (1,2,3)

17--::

  1c+2c set | ½RHA ; 1c+3c set | ½LHA (2x,3x,1)

25--::

  2c & 3c advance | turn RH ½ to own side _while{4}_ 1c A&R ; all turn P RH (2,3,1)

', 3);
INSERT INTO 'dancecrib' VALUES (14770, '2022-04-23 09:52:53.721634+00', '2022-12-11 05:11:01.737152+00', 20773, 1, 202, 'ace', '1--::
  1c set | *Tom Bombadil Turn* : 1c turn P RH ½ and face up, 1W pivoting L under joined arms ; cast off (2c up) to face 3cnrs
9--::
  Set H&G. 1c face 1cnrs
17--::
  ½ Reel4 on 1diag, pass P RSh ; ½ Reel4 on 2diag (3,1x,2)
25--::
  Diagonal R&L (2,1x,3)
33--::
  1c & 3c set advancing | 1c cross up and cast off to 3pl _while{6}_ 3c following 1c dance up and cast off to 2pl (2,3,1)', 5);
INSERT INTO 'dancecrib' VALUES (4961, '2013-08-21 08:30:57.994652+00', '2023-02-04 01:19:32.248568+00', 12790, 3, NULL, 'ace', '1-10::
    1s+2s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (order 2 1),
::
    then dance on clockwise 1 more place
11-20::
    1s+2s dance full R&L & then 2M+1L change places RH.  1 2 3
21-30::
    1s+2s+3s Set+Link for 3 couples twice, 3s cross RH _while_ 2s+1s
    dance RH across 1/2 way.  3 1 2
31-40::
    1s dance reels (8 bar) of 3 on opp sides (1L gives LSh to 3M at top
    as 1M LSh to 2L), 1s cross RH _while_ 2s+3s continue reel to change
    pls.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4962, '2013-08-21 08:30:58.008806+00', '2023-02-04 01:19:32.276689+00', 1600, 3, NULL, 'ace', '1-8::
    1s & 5s dance Figs of 8 round next couple ending in middle facing
    down/up
9-16::
    2s+3s+4s dance reels of 3 on sides (2L & 3L, 3M & 4M pass RSh to
    start)
17-24::
    1s & 5s advance to centre of dance & dance RH across, 5s return to
    place _while_ 1s dance to top & turn towards each other to face down
25-32::
    1s change places with 2s, then 3s, 4s & 5s (dancing between 2s+4s &
    outside 3s & 5s)', 0);
INSERT INTO 'dancecrib' VALUES (4963, '2013-08-21 08:30:58.022683+00', '2023-02-04 01:19:32.299092+00', 8859, 3, NULL, 'ace', '1-8::
    1s+2s Tourbillon (6 bars) & Link :
::
    _1-6_  1s & 2s 1/2 turn ptnrs 2H & 1M also 2L lead ptnrs by nearer
    hand 1 place cl''wise (end 1s on Ladies'' side & 2s Men''s side), 1s
    set to 2s & 1/2 turn partners 2H & lead ptnrs cl''wise into centre so
    2s (1st pl) facing down & 1s (2nd pl) facing up.
::
    _7-8_  2s+1s Link - Persons on right of each couple casts to own
    side _while_ person on left dances in to own side
9-16::
    2s+1s+3s set, circle 6H round to left 1/2 way, Set+Link for 3 to end
    in lines across
17-24::
    Repeat to end on opposite sides.  (3)(1)(2)
25-32::
    3s+1s+2s Advance 1 step & Retire 1 step, all turn 2H 1.1/2 times &
    all set', 0);
INSERT INTO 'dancecrib' VALUES (4964, '2013-08-21 08:30:58.036586+00', '2023-02-04 01:19:32.334731+00', 8838, 3, NULL, 'ace', '1-8::
    All set twice & turn RH into square formation
9-16::
    Men dance LH across twice round _while_ Ladies dance clockwise for 4
    bars & back
17-24::
    Ladies dance LH across twice round _while_ Men dance clockwise &
    back
25-32::
    All Promenade anticlockwise for 4 bars & back
33-40::
    All circle to left & back
41-48::
    Ladies dance RH across twice round _while_ Men dance anticlockwise &
    back
49-56::
    Men dance RH across twice round _while_ Ladies dance anticlockwise &
    back
57-64::
    All Promenade clockwise for 4 bars & back
65-72::
    All circle to right & back
73-80::
    All set twice & turn RH (4 bars)
81-96::
    All dance Grand Chain (1 bar RH & 2 bars LH) & turn RH (4 bars) into
    longwise formation', 0);
INSERT INTO 'dancecrib' VALUES (10380, '2018-01-17 20:30:31.614581+00', '2023-02-04 01:19:32.369935+00', 12508, 3, NULL, 'ace', '1-8::
    1s cross down RH, cast behind 3s, cross RH, cast up 1 place, turn
    3/4 LH to join RH with 3rd corners in a diagonal line
9-12::
    Balance in Line figure:
::
    _9_     All set 1 step Right, change hands so that 1s and 3rd
    corners take LH
::
    _10_   1s and 3rd corners 1/2 turn LH, retain LH and 1s join RH in
    middle of line
::
    _11_  All set 1 step R, 1s join LH & drop hands with corners
::
    _12_  1s 1/2 turn LH to face 3rd corners _while_ corners set 1 step
    Left turning to face diagonally in
13-16::
    1s dance1/2 diagonal reel of 4 with 3rd corners, finish facing 4th
    corners
17-24::
    Repeat bars 9-16 with 4th corners, 1s crossing LH to finish in 2nd
    place opp sides End (3)(1)(2)
25-32::
    Set and link for 3 couples twice to finish 213 on own sides', 0);
INSERT INTO 'dancecrib' VALUES (4965, '2013-08-21 08:30:58.056746+00', '2023-02-04 01:19:32.402477+00', 9848, 3, NULL, 'ace', '1-8::
    1M change places RH with 2L, 1L with 2M, 1M with 3M & 1L with 3L
9-16::
    All dance RH hand across & back
17-24::
    1s dance up 1 place & turn to face out & hold corners RH, all rotate
    clockwise 2 places & end with 1s in 2nd place opposite sides facing
    down
25-32::
    All dance 1/4 Grand Chain (2 bars per hand), all set, end couples
    turn RH _while_ 3s cross over', 0);
INSERT INTO 'dancecrib' VALUES (8563, '2015-02-13 12:47:38.239367+00', '2023-02-04 01:19:32.443679+00', 12683, 3, NULL, 'ace', '1-8::
    1s in prom hold+4M+2L dance reels of 3 (1s pass 4M by Right) also 3s
    dance similar with 2M+4L (3s pass 2M by Right) 2s & 4s begin by
    casting away from partner
9-16::
    1s+3s dance Ladies'' Chain to finish back-to-back with partner
17-24::
    2s in prom hold repeat bars 1-8 with 1M+3L _while_ 4s dance similar
    with 3M+1L
25-32::
    2s+4s dance Ladies'' Chain .  All end facing in
33-36::
    Diagonal 1/2 R&L (1M+4L also 2L+3M give RH to start)
37-40::
    _1/2_ R&L up/down (1s+3s give RH to partner to start)
41-44::
    Diagonal 1/2 R&L (1L+4M also 2M+3L give RH to start)
45-48::
    _1/2_ R&L across (2s+4s).  All finish facing corners
49-56::
    Reel round set (Grand Chain no hands) finish facing corners
57-60::
    All set to & turn corners 2H to face partner
61-64::
    All set to and turn partners 2H 3/4 way round so Ladies in centre
    back-to-back for bow/curtsey', 0);
INSERT INTO 'dancecrib' VALUES (4967, '2013-08-21 08:30:58.087343+00', '2023-02-04 01:19:32.613851+00', 1613, 3, NULL, 'ace', '{{explanation}}
Man with 2 Ladies - Ladies face clockwise & Man anticlockwise ("Double Triangles" positions)

1-8::
    Man dances 1/2 reel of 3 with Ladies (RSh to Lady on right) & all
    set twice
9-16::
    Man dances 1/2 reel of 3 with Ladies (LSh to Lady on left) & all set
    twice
17-24::
    Man turns Lady on right RH, turns Lady on left LH to end Ladies
    facing cl''wise & Men anticl''wise holding nearer hands (as Double
    Triangles)
25-32::
    Ladies Advance 2 steps as Man Retires, Ladies Retire as Man
    Advances. All  drop hands & advance to meet new partners, join hands
    & set', 0);
INSERT INTO 'dancecrib' VALUES (4968, '2013-08-21 08:30:58.109682+00', '2023-02-04 01:19:32.64894+00', 13754, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 reels of 3 on opposite
    sides (1s in & down to start)
9-16::
    1s cross up & cast 1 place, 1s dance 1/2 reels of 3 on own sides (1s
    in & down to start)
17-24::
    2s+1s+3s cross passing RSh & chase clockwise 1/4 way to lines across
    (Ladies face down & Men up), change places with partner passing RSh
    & chase clockwise 1/4 way to (3)(1)(2)
25-32::
    1s dance 1/2 reel of 4 with 3rd corners (pstn), pass RSh & dance 1/2
    reel with 4th corners (pstn)', 0);
INSERT INTO 'dancecrib' VALUES (4970, '2013-08-21 08:30:58.352711+00', '2023-02-04 01:19:32.725479+00', 1615, 3, NULL, 'ace', '1-8::
    1s+2s set & cross passing RSh, set & cross back passing RSh
9-16::
    1s lead down the middle & back for Allemande
17-24::
    1s+2s dance Allemande 1s end facing 1st corners
25-32::
    1s turn 1st corner 2H, pass partner RSh, turn 2nd corner 2H & cross
    passing RSh to 2nd place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (11085, '2018-09-09 17:04:32.683137+00', '2023-02-04 01:19:33.675982+00', 18561, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s
9-16::
    1s lead down middle & cast up to 2nd places
17-24::
    1s dance reels of 3 across (1M with 2s, 1L with 3s)
25-32::
    1s cross RH & cast to 3rd place, 1s cross LH & cast to 4th place', 0);
INSERT INTO 'dancecrib' VALUES (14645, '2022-03-07 02:19:13.835139+00', '2023-02-04 01:19:29.352465+00', 20645, 3, NULL, 'ace', '1-8::
    Ladies dance 1/2 RH across, turn opp Man LH; Ladies dance 1/2 RH
    across & turn partner LH back to place
9-16::
    Men dance 1/2 LH across, turn opp Lady RH; Men dance 1/2 LH across &
    turn partner RH back to place
17-24::
    All 4 couples set, Adv+Ret (1 step each); men Petronella turn 1
    place & set with new partner
25-32::
    All circle 8H round & back

{{explanation}}
Repeat 3 more times with new partners to end with original partner', 0);
INSERT INTO 'dancecrib' VALUES (14284, '2021-09-08 00:19:21.058482+00', '2023-02-04 01:19:32.753781+00', 20440, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp side

1-8::
    1s & 4s set & cast in 1 place (2s & 3s step down/up); 1s+4s dance RH
    across
9-16::
    1L+4M in prom hold dance reel of 3 across at bottom (RSh to 3M)
    _while_ 1M+4L in prom hold dance reel of 3 across at top (RSh to
    2L). End 2 1 (4) (3)
17-24::
    1s/4s dance 1/2 Fig 8 round end couples; 1s+4s turn 1.1/2 to change
    places on side (1M+4L LH, 1L+4M RH).  2 4 (1) (3)
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4971, '2013-08-21 08:30:58.360678+00', '2023-02-04 01:19:32.785034+00', 1616, 3, NULL, 'ace', '1-8::
    1s+2s+3s turn RH, 1s set, cast 1 place into middle facing up in prom
    hold
9-16::
    1s dance reel of 3 with 2L+3M giving RSh to 2L
17-24::
    1s dance reel of 3 with 2M+3L giving LSh to 2M & 1s end BtoB facing
    own side ready for…
25-32::
    1s dance Double Triangles with 2s+3s', 0);
INSERT INTO 'dancecrib' VALUES (13066, '2020-08-10 00:19:16.717101+00', '2023-02-04 01:19:32.957521+00', 14427, 3, NULL, 'ace', '1-8::
    1s & 4s cast down/up 1 place (2s/3s step up/down),  1s+4s cross to
    opp sides, Ladies dancing NHJ between Men; 1s+4s cross back to own
    side, Men dancing NHJ between Ladies, 1s & 4s set
9-16::
    2s & 3s repeat 1-8
17-24::
    1s+2s also 3s+4s dance RH across; all 4 couples turn partner RH
    remaining in centre 2H joined ready for …
25-32::
    _4_ couple Poussette', 0);
INSERT INTO 'dancecrib' VALUES (13067, '2020-08-10 00:19:16.746529+00', '2023-02-04 01:19:32.970068+00', 18017, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across; Set again, 2s cross LH back to own
    side as 1s turn LH to face 1st corners
9-16::
    1s turn 1st corners RH, pass RSh; 1s turn 2nd corners RH, dance
    round partner RSh to face 1st corner again (corners loop into place
    or »twirl«)
17-24::
    1s set to 1st corner, dance RSh round partner to face 2nd corner; 1s
    set to 2nd corner, dance RSh round partner to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9606, '2017-02-20 11:55:56.974783+00', '2023-02-04 01:19:32.983612+00', 8927, 3, NULL, 'ace', '{{explanation}}
2 chords - on 2nd chord 2s & 3s cross to opposite sides

1-8::
    1s & 4s cross RH, cast in 1 place & dance 1/2 Figs of 8 round 2s/3s
    (2s & 3s step up/down bars 3-4)  (2) 1 4 (3)
9-16::
    All dance reels of 4 on sides, Bar 16: 1s & 4s curve in to finish
    BtoB in centre facing corner persons (4s facing 2s & 1s facing 3s)
17-24::
    1s+4s dance ''Hello-Goodbye'' setting (6 bars) Bars 23-24: 1L+4M
    petronella turn to opp sides _while_ 1M+4L set. All now on opp sides
    (2)(1)(4)(3)
25-28::
    2L+1L & 4M+3M turn LH once round whilst 2M+1M & 4L+3L turn RH once
    round (so that centre couples dance out the middle of the ends).
29-32::
    1s+4s dance RH across 1/2 way, retain partner''s hand _while_ 2s+3s
    cross RH, 1s+4s cross RH.  End 2 (4) (1) 3

{{explanation}}
Note: Dance instruction revised by deviser February 2017', 0);
INSERT INTO 'dancecrib' VALUES (4974, '2013-08-21 08:30:58.385002+00', '2023-02-04 01:19:33.13983+00', 9404, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place (2s step up); 1s dance 1/2 Fig of 8 round 2s
9-16::
    1s dance reels of 3 across (1M+2s & 1L+3s) giving LSh to 3rd corners
    & pass LSh to face own sides BtoB
17-24::
    1s dance Double Triangles finishing in 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4975, '2013-08-21 08:30:58.393051+00', '2023-02-04 01:19:33.165813+00', 1621, 3, NULL, 'ace', '1-8::
    1s & 3s cross passing partner RSh & dance round to right to face
    them in line up/down centre (M facing up), set & turn partner RH &
    end in prom hold (1s facing 2M & 3s facing 4L)
9-16::
    1s & 3s dance reels of 3 across (1s giving LSh to 2M & 3s RSh to 4L)
    ending in original places
17-24::
    1s+2s+3s dance the Knot
25-32::
    3s+2s also 1s+4s dance 1/2 R&L, all set & cross RH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4976, '2013-08-21 08:30:58.401115+00', '2023-02-04 01:19:33.183881+00', 12186, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    1s+2s dance RH across, 1s+3s dance LH across
17-24::
    1s dance Reels of 3 on sides, 2s+1s pass RSh to start
25-32::
    2s+1s+3s dance 6H round & back  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4978, '2013-08-21 08:30:58.417407+00', '2023-02-04 01:19:33.416009+00', 1625, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1L+4M also 1M+4L dance Figs of 8 on own sides (dance between 2s/3s
    to start)
9-16::
    2s dance Fig of 8 round 1s _while_ 3s dance Fig of 8 round 4s
    meeting in centre to form a circle
17-24::
    2s+3s set twice (in circle) on 2nd setting pivot right & dance LH
    across back to original places
25-32::
    All dance reels of 4 on sides with 2s+3s ending with a 1/2 turn LH
    onto sides for Balancing in Line
33-40::
    All Bal-in-Line twice, 1s+2s also 3s+4s 1/2 turn RH on sides, middle
    couples (4s+1s) dance LH across 1/2 way.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (4981, '2013-08-21 08:30:58.469771+00', '2023-02-10 15:18:23.256963+00', 1635, 3, NULL, 'ace', '1-8::

    1s 1/2 turn RH moving down to 2nd pl & face up _while_ 2s dance up &

    face 1s, 2s+1s set & LH across (end on sides 2s in top & 1s in 2nd

    pl opp side)

9-16::

    1s 1/2 turn LH moving down to 3rd pl & face up _while_ 3s dance up &

    face 1s, 3s+1s set & RH across (end on sides 3s in 2nd pl & 1s in

    3rd pl)

17-24::

    3s & 1s change places RH on sides, 2s+1s+3s set & 1s dance RH across

    (1L with 2s & 1L with 3s)

25-32::

    2s+1s+3s cross RH, set & dance 1/2 reels of 3 (1L with 2s & 1M with

    3s)', 0);
INSERT INTO 'dancecrib' VALUES (13521, '2021-01-09 01:19:20.900858+00', '2023-02-04 01:19:33.97116+00', 17696, 3, NULL, 'ace', '1-8::
    1s+3s dance double Figs of 8 round 2s (1s cross down, 3s cast up to
    start)
9-16::
    1s cross RH, cast & 3/4 turn RH, pull back RSh to face 2nd corners
    (2s set up 11-12)
17-20::
    1s dance DoSiDo with 2nd corners. 1s finish facing each other in
    middle
21-24::
    1s 3/4 turn RH, pull back RSh to face 1st corners
25-32::
    1s repeat bars 17-20 with 1st corners. 1s 3/4 turn RH to 2nd place
    own sides

{{explanation}}
Note: At end of 2nd time, 1s 3/4 turn moving down to 4th place while 4s step up 29-30', 0);
INSERT INTO 'dancecrib' VALUES (4980, '2013-08-21 08:30:58.43363+00', '2023-02-12 15:58:15.379772+00', 1634, 3, NULL, 'ace', '1-8::

    1s set & turn RH, cast 1 place & 3/4 turn LH

9-16::

    1s dance the Snake: 1s dance RH across (1M with 2s & 1L with 3s), 1M

    followed by 2s & 1L by 3s cross diagonally passing LSh to change

    ends & loop round to left ready for…

17-24::

    1s dance the Snake again: 1s dance LH across (1L with 3s & 1M with

    2s), 1L followed by 3s & 1M by 2s cross diagonally passing RSh to

    change ends & loop round to right into places (1s on opp sides)

25-32::

    2s+1s+3s set & 1s Petronella turn into lines across, set in lines

    across & 1s Petronella turn to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13729, '2021-03-02 01:18:28.504448+00', '2023-02-04 01:18:20.516269+00', 19768, 3, NULL, 'ace', '{{explanation}}
3 dancers arranged as Triangular set

1-12::
    All 3 dancers Petronella turn & set 3 times back to place
13-16::
    All dance RH across ending with dancer 1 facing down between 2 & 3
    facing up
17-24::
    All  set as Double Triangles, all set advancing, pull back RSh to
    invert Double Triangles; repeat back to original place
25-32::
    All dance Coupé PdeB and Set
33-36::
    All dance in, passing RSh in centre to end 1 place to right of start
    place
37-40::
    All circle 3H round to left.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4982, '2013-08-21 08:30:58.477933+00', '2023-02-04 01:19:34.000042+00', 1638, 3, NULL, 'ace', '1-8::
    1s also 4s cross, cast in 1 place & dance 1/2 Fig of 8 round end
    couples
9-16::
    1s+4s RH across, 2s+1s also 4s+3s LH across ending in centre 1s
    facing 2s & 4s facing 3s
17-24::
    1s+2s also 3s+4s set, change places RH with opposite person & all
    turn partners RH
25-32::
    All dance Poussette (for 4 couples)', 0);
INSERT INTO 'dancecrib' VALUES (4983, '2013-08-21 08:30:58.485919+00', '2023-02-04 01:19:34.025034+00', 1639, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance 1/2 reel of 3 on sides (1s in & down to start); 1s &
    3s turn RH 1.1/2 times.  (3) 2 (1)
9-16::
    3s+2s+1s dance 1/2 reel of 3 on sides (1s out & up to start), 2s
    turn RH 1.1/2 times.  (1) (2) (3)
17-20::
    1s+3s dance 1/2 Double Fig 8 round 2s (3s cross up, 1s cast)
21-24::
    1s cast to 2nd place and lead up RHJ remaining in centre _while_ 2s
    cross up & cast into centre behind 1s, ready for …
25-32::
    1s+2s dance Allemande.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13404, '2020-12-02 01:19:22.298437+00', '2023-02-04 01:19:34.055256+00', 19153, 3, NULL, 'ace', '1-8::
    1s+2s set, 1/2 turn partner 2H opening out into 4H 1/2 round to
    left, 2s+1s set
9-16::
    1s+3s repeat bars 1-8. 2 3 1 4
17-24::
    1s+4s set, turn partner RH; 1s cast to 4th place _while_ 4s lead up
    & curve into 3rd place; all 4 couples set. 2 3 4 1
25-32::
    2s+3s also 4s+1s dance RH across; all 4 couples turn partner RH.
    End  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4984, '2013-08-21 08:30:58.494071+00', '2023-02-04 01:19:34.087553+00', 1641, 3, NULL, 'ace', '1-8::
    All (with nearer hands joined on sides) slip step right, slip step
    back & turn partner RH
9-16::
    All (with nearer hands joined on sides) slip step left, slip step
    back & turn partner LH
17-24::
    1s cast 1 place, dance to top & cast to 4th place
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4985, '2013-08-21 08:30:58.502134+00', '2023-02-04 01:19:34.115979+00', 12628, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place & turn LH (4 bars) to face 1st corner
9-16::
    1M dances reel of 3 on opposite sides (LSh to 1st crnr) _while_ 1L
    dances Fig of 8 round 1st+2nd Corners, both end facing 1st corners
17-24::
    1L dances reel of 3 on opposite sides (LSh to 1st crnr) _while_ 1M
    dances Fig of 8 round 1st+2nd Corners, both end facing 1st corners
25-32::
    1s dance reels of 3 on opposite sides (LSh to 1st crnr) & cross to
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (8775, '2015-06-15 11:40:37.482187+00', '2023-02-04 01:19:34.143934+00', 16218, 3, NULL, 'ace', '1-8::
    1s & 3s petronella turn & set.  Repeat to (1) 2 (3) 4
9-16::
    All 4 couples Adv+Ret. 1M+2M also 3M+4M change places passing RSh,
    curve to Left, cross & finish beside opp Lady in promenade hold
17-24::
    All promenade anticlockwise round. Finish on sides (Lady on Man''s
    Right)  2 (1) 4 (3)
25-32::
    1s & 3s set.  1s cast to 4th place, 3s lead up to 2nd place.  1s &
    3s dance 1/2 Figs 8 round couples above.   2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14646, '2022-03-07 02:19:18.244511+00', '2023-02-04 01:19:34.379369+00', 16595, 3, NULL, 'ace', '{{title}}
Strathspey

1-2::
    1s & 3s Petronella turn to middle _while_ 2s & 4s step up
3-8::
    2s+1s+4s+3s set, Petronella turn & set to partners to finish 1s+3s
    on opp sides & 2s+4s facing in the middle (Men up, Ladies down)
9-12::
    2s+4s dance 1/2 Reel of 4 up & down centre of set
13-16::
    2L followed by partner casts up Men''s side, behind 3L & across set
    to 3rd place _while_ 4M followed by partner casts down Ladies''
    side, behind 1M & across set to finish in 2nd place (1L/3M step
    up/down on bars 13-14, 1M/3L step up/down on bars 15-16) (1) 4  2
    (3)
17-20::
    1s+3s set, 1s cast down _while_ 3s cast up (4s/2s step up/down) 4
    (1) (3) 2
21-24::
    1s+3s dance 1/2 R&L 4 3 1 2
25-28::
    1s+2s Set+Link 4 3 2 1
29-32::
    2s+1s dance 4H round to the left 4 3 2 1

{{explanation}}
Repeat from new positions in Reel time back to original places', 0);
INSERT INTO 'dancecrib' VALUES (8316, '2014-07-29 12:58:55.404485+00', '2023-02-04 01:19:34.399403+00', 15058, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 on own side, 1s dance in & down to
    start
9-16::
    1s dance in, cast 2 places, lead up LH to finish in middle 1L facing
    up, 1M down (2s step up 13-14)
17-24::
    1s dance Crown Triangles, 1s finish facing 1st corners
25-32::
    1s dance 1/2  reel of 4 with 1st corners, pass RSh, 1/2 reel of 4
    with 2nd corners. 1s finish 2nd place opp. sides
33-40::
    2s+1s+3s  Set+Link for 3 twice.  End:  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8777, '2015-06-15 11:40:37.551171+00', '2023-02-04 01:19:34.41916+00', 16217, 3, NULL, 'ace', '1-8::
    All Men dance round Lady on Right (pass RSh) finish between that
    Lady & partner _while_ Ladies turn on the spot.  All set twice
9-16::
    Men dance 1/2 RH across to face out. All set, Men dance
    anticlockwise round Ladies to original places
17-24::
    Ladies petronella turn 1 place to Right & set. Repeat
25-32::
    All advance setting, Men retire as Ladies petronella 1 place to
    Right.  All set & turn new partner RH
33-40::
    All Ladies dance round Man on Left (pass LSh) finish between that
    Man & partner _while_ Men turn on the spot.  All set twice
41-48::
    Ladies dance 1/2 LH across to face out.  All set, Ladies dance
    clockwise round Men back to (new) place
49-56::
    Ladies dance 1/2 RH across _while_ Men dance 1 place to Right. All
    turn partners LH. Ladies dance 1/2 RH across _while_ Men dance 1
    place to Right. All 1/2 turn LH.
57-64::
    Repeat 49-56 with Men dancing RH across & Ladies moving  round and
    finishing in place
65-80::
    Repeat 1-16
81-88::
    All advance setting, turn away from (new) partner to face original
    partner. All promenade out and to Left to opposite original start
    position
89-96::
    All dance 1/2 Schiehallion Reels - ending in original start position', 0);
INSERT INTO 'dancecrib' VALUES (9292, '2016-09-15 07:21:40.983927+00', '2022-12-11 02:20:46.553845+00', 8462, 1, 202, 'ace', '1--::

 All Turn P RH ; All Turn P LH

9--::

 All chase cclw

17--::

 1c cross RH | cast to 4pl (2c+3c+4c step  up) ; 1c dance ½ Fig8 round 4c

25--::

 All circle8 and back (2,3.4.1)

  

A simplified version has 

17--::

   1M (1W following) cast off one (2c up) | cross : cast off two (3c+4c up) | cross to own side (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (12388, '2019-12-05 01:29:29.374056+00', '2023-02-04 01:19:30.48293+00', 1553, 3, NULL, 'ace', '1-8::
    1s set, lead down, crossing below 2s & dance out behind 3s, meet &
    lead up to to end in 2nd place BtoB facing own sides ready for…
9-16::
    2s+1s+3s dance double triangles,  bars 15-16 1s dance RSh round each
    other to finish facing 1st corners
17-24::
    1s dance diag reel of 4 with 1st corners, pass LSh to face 2nd
    corners
25-32::
    1s dance diag reel of 4 with 2nd corners & finish in 2nd place own
    side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4991, '2013-08-21 08:30:58.554763+00', '2023-02-04 01:19:34.596903+00', 14798, 3, NULL, 'ace', '1-8::
    All Ladies dance LSh round next Man to left then LSh round next Man
    to left to end in opposite places
9-16::
    All Ladies dance 1/2 RH across & turn partner LH, Ladies again dance
    1/2 RH across & turn opposite partner LH
17-24::
    1L/3L followed by 3M/1M chase anticl''wise behind 2s/4s & round in
    front, then dance between them & chase back to 3rd/1st pl (Lady in
    Man''s pl)
25-32::
    All circle 8H left 1/2 way, all couples Set+Link
33-40::
    2L/4L followed by 4M/2M chase cl''wise behind 3s/1s & round in front,
    then dance between them & chase back to 2nd/4th pls (Ladies now back
    in original places)
41-48::
    All circle 8H left once round & set
49-56::
    All Men dance 1/2 LH across & turn partner RH, Men again dance 1/2
    LH across & turn opposite partner RH
57-64::
    All Men dance RSh round Lady on their right then RSh round next Lady
    on right ending in original places', 0);
INSERT INTO 'dancecrib' VALUES (9725, '2017-04-06 08:39:39.523029+00', '2023-02-04 01:19:34.617162+00', 17648, 3, NULL, 'ace', '1-4::
    1M+3M dance RSh round partner, pass RSh in centre into line up/down
    joining LH with opp. lady and RH with each other
5-8::
    1s+3s Balance in Line. 1M+3L & 3M+1L turn 1/2 LH. End Men facing in
    & Ladies BtoB in centre.
9-12::
    1L+3L dance RSh round »new« partner, pass RSh in centre into line
    up/down joining LH with partner & RH with each other
13-16::
    1s & 3s Balance in Line.  1s+3s turn 3/4 LH all facing in
17-24::
    _8_ Hands round & back
25-28::
    All face partners, set, turn RH into prom hold - 1s+3s facing to
    Right & 2s+4s facing Left
29-32::
    Passing RSh, 1s (3s) change places with 2s (4s) and all face in -
    having progressed one place clockwise', 4);
INSERT INTO 'dancecrib' VALUES (12722, '2020-04-11 10:51:00.44407+00', '2023-02-04 01:19:34.654245+00', 19949, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance RH across and back
9-16::
    1s+3s lead down the middle and back to place
17-24::
    1s+2s & 3s+4s dance R&L
25-32::
    1s change on the side with 2s (Ladies RH, Men LH)
::
    1s change on the side with 3s (Ladies LH, Men RH)
::
    1s change on the side with 4s (Ladies RH, Men LH)
::
    1s turn with RH to finish in 4th place.  (Other couples step up one
    place)', 0);
INSERT INTO 'dancecrib' VALUES (4993, '2013-08-21 08:30:58.571195+00', '2023-02-04 01:19:34.678917+00', 1646, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s set to partners & turn 2H,set to corners & turn 2H
9-16::
    2s & 4s repeat bars 1-8
17-24::
    All dance Grand Chain to opposite sides
25-32::
    Ladies dance RH across once round _while_ Men dance round
    anticlockwise 1/2 way, set to opposite partner & 3/4 turn LH
33-40::
    Men dance RH across once round _while_ Ladies dance round
    anticlockwise 1/2 way, set to partners & turn 2H

{{title}}
Reel

1-8::
    All set to partners & 1/2 turn RH (give LH to next person), all set
    & 1/4 turn partner RH to Ladies BtoB facing partner
9-16::
    All petronella turn, set to partner, petronella turn to Men BtoB
    facing partner & set
17-24::
    All petronella turn, set to partner, turn 2H to Men facing partner
    (Men face diagonally to next place to right)
25-28::
    All travel PdB to next place (Ladies travel backwards), 3/4 turn 2H
    to new place facing diagonally right
29-40::
    Repeat bars 25-28 3 times back to places & face in', 0);
INSERT INTO 'dancecrib' VALUES (9913, '2017-06-05 11:30:58.247096+00', '2023-02-04 01:19:34.702996+00', 17738, 3, NULL, 'ace', '1-8::
    1s+2s dance The Knot, 1s end facing 1st corners
9-16::
    1s turn 1st corner RH, partner LH, 2nd corner RH, partner LH to end
    facing 1st corners again
17-24::
    _1/2_ diagonal reels with 1st corners, 1/2 diagonal reels with 2nd
    corners, 1s ending in 2nd place opp sides
25-28::
    3s+1s cross RH with partner, then dance 1/2 RH across _while_ 2s
    turn RH
29-32::
    1s+2s+3s chase clockwise 1/2 way.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4994, '2013-08-21 08:30:58.581105+00', '2023-02-04 01:19:34.735705+00', 11278, 3, NULL, 'ace', '1-8::
    1s dance Progressive Fig 8:  1s cross RH as 2s set, 1s+2s dance 3/4
    double Fig of 8 with 1s casting & 2s crossing up to start
9-16::
    2s+1s+3s dance reflection ("mirror") reels of 3 on sides (2s
    out/down, 1s in/down, 3s out/up)  1s finish facing 1st corner
17-24::
    1s set to corners & partner ("Hello-Goodbye")  1s finish facing 3rd
    corners
25-32::
    1s dance corner Pass+Turn with 3rd and then 4th corners', 0);
INSERT INTO 'dancecrib' VALUES (4995, '2013-08-21 08:30:58.589541+00', '2023-02-04 01:19:34.768533+00', 7679, 3, NULL, 'ace', '1-4::
    1M+2L & 2M+3L 1/2 turn 2H to face other pair on diagonal & set
5-8::
    1M+2s+3L circle 4H round to left with 1M ending in 3rd pl opp side
    as 3L ends in 1st pl opp side as 2s end in original places
9-12::
    1L+2M & 2L+3M 1/2 turn 2H to face other pair on diagonal & set
13-16::
    1L+2s+3M dance LH across with 1L ending in 3rd pl opp side as 3M
    ends in 1st pl opp side as 2s turn LH to face 1st corners (pstn)
17-24::
    2s dance 1/2 Diamond Reels of 4 with 1st corners:
::
    _17-20_    2s dance out (pass RSh) as corners petronella turn to
    just in front of 2nd corner pstn (Long steps) into diamond shape &
    3L+2s+1M set ending with 3L+1M petronella turning to BtoB facing
    original places
::
    _21-24_    1M+3L dance out to their original places as 2s dance in &
    petronella turn into 2nd pstn on opp sides into diamond shape & 2s
    set ending with 2s petronella turning to BtoB facing 2nd corners
25-32::
    2s dance 1/2 Diamond Reels of 4 with 2nd corners:
::
    _25-28_    2s dance out (pass RSh) as corners petronella turn to
    just in front of 1st corner pstns (long step)  into diamond shape &
    3M+2s+1L set ending with 3M+1L petronella turning to BtoB facing
    orig places
::
    _29-32_    1L+3M dance out (pass RSh) as 2s dance in & 1/2 turn RH
    to face up
::
    2s dance up to 1st place as 1s cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (4997, '2013-08-21 08:30:58.60565+00', '2023-02-04 01:19:34.820067+00', 10434, 3, NULL, 'ace', '1-8::
    1s set & dance 3/4 Fig of 8 round 2s to end facing out in 2nd place
    on own sides
9-16::
    1s dance 1/2 reels of 3 own side (out & down), 1s cast to top &
    cross down to Double Triangle position on opp side
17-24::
    All set & 1s 3/4 turn 1st corner person RH into 1/2 reels across end
    moving into Double Triangle position on own side
25-32::
    All set & 1s turn 3rd corner person RH, 1s turn LH to own side
    _while_ 2s+3s chase clockwise to own side.', 0);
INSERT INTO 'dancecrib' VALUES (4998, '2013-08-21 08:30:58.613659+00', '2023-02-04 01:19:34.848718+00', 9192, 3, NULL, 'ace', '1-8::
    1s set, cross down RH through 2nd place opp. sides (2s step up 3-4)
    & cast round 1st corners to 2nd place opposite sides
9-16::
    1s dance reels of 3 on opposite sides giving LSh to 2nd corners to
    start & end facing 1st corners
17-24::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partner LH for…
25-32::
    1L+2s & 1M+3s dance RH across ending in 2nd place own sides &
    2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (3921, '2013-08-21 08:30:39.166951+00', '2023-02-04 01:18:20.69447+00', 4397, 3, NULL, 'ace', '{{title}}
Strathspey

1-16::
    Reel of 4 Chain:
::
    _1-2_    1L & 3L cast 1 place, 2M & 4M cast up 1 place _while_ 1M+2L
    & 3M+4L turn 3/4 RH to end on own side up/down 1 place
::
    _3-4_    1s+4s change places LH on sides _while_ 2s set facing down
    & 3s set facing up
::
    _5-16_  Repeat bars 1-4 from new positions until back to original
    places (no casting after setting - dance directly up or down)

{{title}}
Reel

1-8::
    1L followed by partner casts 1 pl, crosses down & out behind 4M,
    crosses & 1L casts up to 2nd place as 1M dances up middle to 2nd pl
    own sides (2s step up 3-4).  1s end in centre 2H joined, 3s+4s step
    in ready for …
9-16::
    1s+3s+4s dance Poussette to end  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4999, '2013-08-21 08:30:58.623445+00', '2023-02-04 01:19:34.881798+00', 1653, 3, NULL, 'ace', '1-8::
    All set, cross RH, set & cross back RH
9-16::
    All Ladies dance round partner RSh & set in front of them & turning
    to right dance back to place
17-24::
    All chase 1/2 way clockwise & turn partners RH
25-32::
    All Men dance round partner RSh & set in front of them & turning to
    right dance back to place
33-40::
    All chase 1/2 way clockwise & all turn partners RH
41-48::
    1s followed by 2s+3s+4s cast to bottom, 1s make arch & 2s+3s+4s
    dance under & up to new places', 0);
INSERT INTO 'dancecrib' VALUES (5001, '2013-08-21 08:30:58.637365+00', '2023-02-04 01:19:34.9619+00', 9469, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place _while_ 2s set, dance up to face out;
    2s+1s dance 1/2 Double Fig of 8 (1s cross up, 2s cast) 2s face out
9-16::
    1s dance reels of 3 on sides (1s dance in & down to start)
17-24::
    1s dance 1/2 reels of 3 across (1L with 2s, 1M with 3s), 1s turn LH
25-32::
    1s dance 1/2 reels of 3 across (1M with 2s, 1L with 3s), 1s turn RH
33-40::
    2s+1s+3s circle left for 6 steps, pivot left & chase back to places', 0);
INSERT INTO 'dancecrib' VALUES (10064, '2017-09-03 23:44:31.673515+00', '2023-02-04 01:19:35.023+00', 16828, 3, NULL, 'ace', '1-8::
    1M dances clockwise round set (pass 1L RSh) _while_ 1L dances
    petronella turn & sets to 2L,3L, 3M & 2M in turn.  Bars 7-8 1L
    dances petronella turn back to place. (2L sets on bars 3-4, 3L bars
    4-5, 3M bars 5-6, 2M bars 6 and 7)
9-16::
    _1/2_ reel, set, 1/2 reel:
::
    _9-11_    1/2 reels of 3 on sides (1M+2M pass RSh, 1L+2L pass LSh)
::
    _12-13_  All set (start on Left foot), 3s facing across, 2s facing
    1s on sides
::
    _14-16_  1/2 rees of 3 on sides (1M+2M pass LSh, 1L+2L pass RSh)
17-24::
    1L dances across to take prom hold with partner (1M on right of 1L).
    1s dance down (2 bars), turn RH or birl (4 bars) _while_ bars 19-20
    2s+3s step up & dance RH across
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5003, '2013-08-21 08:30:58.656979+00', '2023-02-04 01:19:35.089375+00', 1664, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s dance Figs of 8 round 1st & 2nd corners & end facing 1st corners
17-24::
    1s set to 1st corners twice & turn 2H to face 2nd corners
25-32::
    1s set to 2nd corners twice & turn 2H & pass RSh into double
    triangle positions
33-40::
    1s dance double triangles', 0);
INSERT INTO 'dancecrib' VALUES (5004, '2013-08-21 08:30:58.66508+00', '2023-02-04 01:19:35.113241+00', 7243, 3, NULL, 'ace', '1-16::
    All dance modified Grand Chain - change places RH as normal BUT turn
    next person LH (elbow hold) 1.1/2 times & so on - but on last bars
    1s+2s turn LH once only to end 2 1 3 4
17-24::
    1s dance RH across with 3s & LH across with 2s
25-32::
    1s dance reels of 3 on own sides (1s pass person on right RSh)
33-40::
    1s dance LSh reels of 3 across (Lady with 2s & Man with 3s) & 1s end
    in centre facing down
41-48::
    1s cross down below 3s, cast behind 4s & dance 1/2 Fig of 8 round 4s', 0);
INSERT INTO 'dancecrib' VALUES (13071, '2020-08-10 00:19:18.534908+00', '2023-02-04 01:19:35.389171+00', 8770, 3, NULL, 'ace', '1-8::
    1L casts down _while_ 2M casts up & 1L+2M turn 1.1/2 RH back to
    place
9-16::
    1M casts down _while_ 2L casts up & 1M+2L turn 1.1/4 LH to end on
    opp sides facing partner (Men face up, Ladies face down)
17-24::
    Modified Poussette:
::
    1s move up Ladies''side as 2s move down Men''s side, 1/4 turn to
    across set, 1s move to M''s side as 2s move to L''s side, 1/4 turn
::
    2s move up L''s side as 1s move down M''s side, 1/4 turn, couples move
    to centre & 1/4 turn to line up/down centre. 2L 2M 1L 1M
25-32::
    2s+1s dance RSh reel of 4, Bars 31-32: all dance to own side, 1M
    follows 2M (from bottom), 2L follows 1L from top.  End 2 1', 0);
INSERT INTO 'dancecrib' VALUES (13405, '2020-12-02 01:19:23.508209+00', '2023-02-04 01:19:35.560223+00', 18576, 3, NULL, 'ace', '{{explanation}}
No hands are given throughout the dance

1-8::
    1s cross down to dance reflection reels of 3 on opp sides (2s out/up
    to start)). 1s end in 1st place opp sides & 2s between 3s in 3rd
    place facing up
9-16::
    1s cross passing RSh & cast 1 place _while_ 2s dance up to top, 2M
    facing out;  2s+1s chase anticlockwise 1/2 round, 1L&2M end facing
    out (1) (2) 3
17-24::
    1L followed by 1M cast down 2 places _while_ 2M followed by 2L cast
    down 1 place behind 3s, 2s+1s dance 3/4 double Fig of 8 round
    standing 3s (2s always cross first).  1s+2s finish on opposite
    sides, 2M+1L above 3s & 1M+2L below 3s
25-26::
    1L+2M & 2L+1M cross up 1 place (Ladies cross first) _while_ 3s dance
    up 1 place on the sides. Ladies finish facing up. 1 3 2
27-32::
    1L followed by 2L+3L dance up, cross at the top, dance down behind
    the Men & cross (LSh) below partner to own side.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (14520, '2022-01-10 02:19:00.618415+00', '2023-02-04 01:19:35.584656+00', 17960, 3, NULL, 'ace', '1-8::
    1s cross passing RSh, turn 2s on sides 1.1/2 to change places (1M
    RH, 1L LH), 1s pass RSh to own sides & face out
9-16::
    1s turn 3s on sides 1.1/2 to change places (1M LH, 1L RH); 3s+1s Set
    & Mirror Link (1s cast up, 3s dance down). 2 1 3
17-24::
    2s+1s dance Poussette
25-32::
    1s+3s dance the Tourbillon. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5006, '2013-08-21 08:30:58.681387+00', '2023-02-04 01:19:35.611953+00', 9855, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up), turn LH _while_ 2s & 3s turn RH to end in
    lines across with 2L between 1L+2M facing down & 3M between 1M+3L
    facing up
9-16::
    1L+2L also 1M+3M Set+Link; all set, 1s (in middle) cast to 2nd place
    own side _while_ 2s+3s change places on side (Men RH & Ladies LH)
17-20::
    Top couple (3s) lead down & cross RH to 3rd place & cast up to 2nd
    place _while_ middle couple (1s) set & cross to 3rd place _while_
    bottom couple (2s) cast to top & cross RH
21-24::
    All repeat from new places
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (13299, '2020-11-02 01:19:25.340158+00', '2023-02-04 01:19:35.819721+00', 20136, 3, NULL, 'ace', '1-8::
    1s cross passing RSh, cast (2s step up 3-4); 1s dance 1/2 Fig 8 (1L
    up round 2s, 1M down round 3s). 2 1 3
9-16::
    2s+1s+3s set, cross passing partner RSh; all chase clockwise 1/2
    round to own sides. 3 1 2
17-24::
    3s+2s dance Double Fig 8 (3s cast, 2s cros up to start)
25-32::
    3s+1s+2s set, cross passing partner LSh; all chase anticlockwise 1/2
    round to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13739, '2021-03-02 01:19:30.161021+00', '2023-02-04 01:19:35.830677+00', 12187, 3, NULL, 'ace', '1-8::
    1L+2M set, change places RH _while_ 3s Petronella turn & set, 1s+2s
    dance 1/2 R&L (start by changing places RH up/down) _while_ 3s
    passing LSh dance RSh round 4s (3L down round 4M, 3M up round 3L) to
    end  in line of 4 across (3s BtoB between 4s)
9-16::
    1M & 2L set, change places RH, 1s+2s dance RH across once round
    _while_ 3s+4s dance reel of 4 across (3s finish in 4th place) 1 2 4
    3
17-20::
    1s NHJ dance down to 4th place _while_ 3s cast up to 1st place 3 2 4
    1
21-28::
    3s+2s set, dance 1/2 RH across, 2s+3s set & cross RH to own sides
    _while_ 4s+1s dance RH across & LH back 2 3 4 1
29-32::
    2s & 3s turn partners RH _while_ 4s & 1s turn LH', 0);
INSERT INTO 'dancecrib' VALUES (5007, '2013-08-21 08:30:58.689401+00', '2023-02-04 01:19:35.840952+00', 9084, 3, NULL, 'ace', '{{explanation}}
5 person Sq.Set with 5th person in centre facing top looking out between 1 & 4

{{title}}
Start

::
    _2_·····3
::
    ···5
::
    _1_·····4
::
    ··Top
1-8::
    _5_+1+2 dance RH across, 5+3+4 dance LH across
9-16::
    _5_+1+3 dance RSh reel of 3 on diagonal (5 & 1 pass RSh to start)
17-24::
    _5_+4+2 dance LSh reel of 3 on other diagonal (5 & 4pass LSh to
    start)
25-32::
    _5_ changes place with 1 (pass RSh), 1 change pl with 4, 4 change pl
    with 3, 3 change pl with 2 & 2 becomes new 5 (similar to Fisherman''s
    Reel)', 0);
INSERT INTO 'dancecrib' VALUES (5008, '2013-08-21 08:30:58.697447+00', '2023-02-04 01:19:35.852224+00', 13275, 3, NULL, 'ace', '1-8::
    1s & 3s turn RH & cast down 1 place, 1s & 3s turn LH 1.1/4 times to
    face 1st corners
9-24::
    1s & 3s dance Corner Chain with 1st & 2nd corners :
::
    1s (3s) change pl RH with 1st crnrs, 1st crnrs turn LH in centre &
    return to places giving RH to 1s (3s) who turn LH in centre to face
    2nd crnrs
::
    1s (3s) change places RH with 2nd crnrs, 2nd crnrs turn LH in centre
    & return to places giving RH to 1s (3s) then 1s & 3s end with a 1/2
    turn LH to Ladies facing up & Men facing down
25-32::
    1L+2s & 1M+3L+4s & 3M+5s dance RH across, 1s+3s 3/4 turn LH & cast
    to 3rd/5th places', 0);
INSERT INTO 'dancecrib' VALUES (5009, '2013-08-21 08:30:58.705582+00', '2023-02-04 01:19:35.863123+00', 1672, 3, NULL, 'ace', '1-8::
    1M+2L set & change places RH, cast round partner, into centre & turn
    RH to own place
9-16::
    1L+2M repeat but turning LH
17-24::
    1s & 2s set, turn 2H to end 1s facing down & 2s up, set & turn
    opposite person 2H & end facing out BtoB with partner
25-32::
    1M+2M also 1L+2L dance out for 2 steps, turn & dance back in &
    taking partners hand 1s & 2s dance up/down for 2 steps & back
33-40::
    1s+2s dance the Rondel', 4);
INSERT INTO 'dancecrib' VALUES (14521, '2022-01-10 02:19:00.85237+00', '2023-02-04 01:19:35.87455+00', 17961, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All Adv with partner, Ret with corner; Adv with corner, Ret with
    partner
9-14::
    »Circle Reels«:
::
    1s+3s (Ladies followed by partners) pass LSh & dance 1/2 tandem reel
    of 4 across with couple to right, 2s & 4s (Men followed by partners)
    finish on opp sides (big loops). 1s+3s do not pass finishing in
    middle LSh to LSh, 1s facing down, 3s facing up
15-16::
    1s+3s dance 1/2 LH across to change places. 3 4 1 2
17-22::
    Repeat 9-14 from new places
23-24::
    1s+3s dance back to original places
25-32::
    All set to partners & change places RH; repeat & Ladies face out
33-48::
    All dance Schiehallion reels
49-64::
    2s+4s repeat »Circle Reels« (bars 9-24) up/down set with 1s+3s

{{title}}
Reel

65-128::
    Repeat 1-64 in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (5010, '2013-08-21 08:30:58.804456+00', '2023-02-04 01:19:36.051796+00', 11013, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides &
    ending on opposite sides facing down nearer hands joined
9-16::
    1s dance down for 2, Lady dances under Mans right arm to change
    sides, dance up & cast to 2nd places
17-24::
    1s dance RH across (Lady with 2s & Man with 3s), 1s turn LH 1.1/2
    times _while_ 2s+3s chase clockwise 1/2 way
25-32::
    1s dance RH across (Man with 3s at top & Lady with 2s), 1s turn LH
    1.1/2 times _while_ 3s+2s chase clockwise 1/2 way
33-40::
    1s dance up, cast 1 place on own sides & turn 3s (Lady LH & Man RH)
    into 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5011, '2013-08-21 08:30:58.819248+00', '2023-02-04 01:19:36.100742+00', 11224, 3, NULL, 'ace', '{{explanation}}
Man+2 Ladies on each side of triangular set

1-8::
    All Men set to partner on right & change places RH, set to next Lady
    (in next trio) & change places LH (2 Ladies on right)
9-16::
    All Men dance RH across & LH across ''new'' partners (2 Ladies on
    right)
17-24::
    All Men set to ''new'' partner on right & change places 2H to face her
    (between ''new'' partners) & dance 1/2 reel of 3 with ''new'' partners
25-32::
    All circle 9H round & back (Men now 1 place anticlockwise, LH Lady 1
    place clockwise & RH Lady remains in the same place)

{{explanation}}
Repeat with new partners', 0);
INSERT INTO 'dancecrib' VALUES (5012, '2013-08-21 08:30:58.827477+00', '2023-02-04 01:19:36.127792+00', 1676, 3, NULL, 'ace', '1-8::
    1s set & cross RH, 1s cast 1 place & turn LH to face 1st corners
9-16::
    1s dance 1/2 reel of 4 with 1st corners & pass LSh to face 3rd
    corners, 1s turn 3rd corners RH & partner LH to face 2nd corners
17-24::
    1s dance 1/2 reel of 4 with 2nd corners & pass LSh to face 4th
    corners, 1s turn 4th corners RH & partner LH to end 2nd place own
    side
25-32::
    1s dance Diag R&L (1M crossing diagonally down & 1L crossing
    diagonally up to start)', 0);
INSERT INTO 'dancecrib' VALUES (5013, '2013-08-21 08:30:58.835478+00', '2023-02-04 01:19:36.153736+00', 1677, 3, NULL, 'ace', '1-8::
    1s dance reflection (mirror) reels on own sides (1s in & down to
    start)
9-16::
    1s+2s dance RH across (3 bars) & 1s cast down 1 place as 2s dance up
    to top; 1s+3s dance LH across
17-24::
    All circle 6H round & back, 1s end facing 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (5015, '2013-08-21 08:30:58.950474+00', '2023-02-04 01:19:36.402561+00', 1679, 3, NULL, 'ace', '1-8::
    1s cross down & dance reels of 3 on sides & cross to own sides
9-16::
    1s dance RSh reels of 3 on own sides (giving RSh to 2s) & continue
    reel to change places with 2s
17-24::
    1s set advancing to 1st corners, turn 2H to end between 2s/3s, 1s
    set advancing to 2nd corners & turn 2H to end 2nd place opposite
    side
25-32::
    1s 1/2 turn 2H to face up, dance up & cast 1 place & 1L dance down
    under arch made by 3L+4L as 1M dances under 3M+4M arch into 4th
    places', 0);
INSERT INTO 'dancecrib' VALUES (5016, '2013-08-21 08:30:58.95875+00', '2023-02-04 01:19:36.424761+00', 10515, 3, NULL, 'ace', '{{explanation}}
5s in centre, 5M with back to 4s faces partner across the set

1-8::
    5s dance LH across (5M with 1s & 5L with 3s), pass LSh & dance RH
    across with other couple
9-16::
    5s dance RSh reels of 3 across (5L with 4M+2L & 5M with 2M+4L)
17-24::
    5s dance out Lady between 4s & Man between 2 & cast down, meet
    partner & dance up crossing between 3s to face 1s & dance 1/2 R&L
25-32::
    1s (in centre) turn RH (4 bars) & LH (4 bars) _while_ others circle
    8H round to left for 3 bars, pivot left & chase back to put 2s in
    top place', 0);
INSERT INTO 'dancecrib' VALUES (15296, '2022-12-12 07:17:15.705936+00', '2022-12-12 09:19:02.971494+00', 20141, 1, 202, 'ace', '1--::

  1c+2c Circle4 and back

9--::

  1c+2c RHA ; LHA

17--::

  1c cross RH | cast off (2c up) ; ½ Fig8 up round 2c (2,1)

25--::

  2c+1c R&L (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (3930, '2013-08-21 08:30:39.497523+00', '2023-02-04 01:18:21.786543+00', 10491, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, 2s+1s+3s set advancing & turning right
    about dance out
9-16::
    2s+1s+3s chase cl''wise 1/2 way, 1s continue chase to 2nd places own
    sides _while_ 2L+3M change places (diag) RH then 2M+3L change places
    RH
17-24::
    2L+1L+3L set, Adv+Ret & set _while_ partners set twice & Adv+Ret
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5017, '2013-08-21 08:30:58.968481+00', '2023-02-04 01:19:36.449792+00', 8164, 3, NULL, 'ace', '1-8::
    1s dance Inveran Reels with 2s+3s
9-16::
    1s+2s Petronella-in-tandem into centre & set, Petronella-in-tandem
    to opposite side & set
17-24::
    1s+2s RH across 1/2 way; 1s cast down as 2s dance up to top, 1s+3s
    Petronella-in-tandem & set
25-32::
    1s+3s Petronella-in-tandem to opposite sides & set; 3s & 1s turn
    partners 2H 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (5018, '2013-08-21 08:30:58.978484+00', '2023-02-04 01:19:36.480501+00', 7297, 3, NULL, 'ace', '1-8::
    Bar 1   1M+3L advance for 2 & retire for 2 & stand for 4 bars
    _while_
::
    Bar 3   2s advance for 2 & retire for 2 & stand for 2 bars _while_
::
    Bar 5   1L+3M advance for 2 & retire for 2
9-16::
    1M dances across & dances down behind partner (who turns right about
    to follow him) in front of 2L, behind 3L & both dance up to 2nd
    place opposite sides
17-24::
    2s+1s dance 1/2 Ladies'' Chain.  2s+1s dance 1/2 Men''s Chain & 2s end
    with an extra turn to own sides
25-32::
    1s+2s+3s Promenade ending with 1s casting to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (5019, '2013-08-21 08:30:58.984624+00', '2023-02-04 01:19:36.513194+00', 8928, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s+2s dance RH across & LH back to place
17-24::
    1s dance down the middle & back
25-32::
    1s followed 2s+3s+4s cast on own sides to bottom, 1s make arch as
    other dance up under to new places', 0);
INSERT INTO 'dancecrib' VALUES (5020, '2013-08-21 08:30:58.992762+00', '2023-02-04 01:19:36.534846+00', 10015, 3, NULL, 'ace', '1-8::
    1s & 3s set, turn partners 2H, cast 1 place & advance setting to
    face 1st corners
9-16::
    1s & 3s dance Pass+Turn with 1st corners & pass RSh to face 2nd
    corners, dance Pass+Turn with 2nd corners ending in 2nd/4th places
    opp side
17-24::
    1L & 3L dance Figs of 8 with couple above _while_ Men dance Figs of
    8 round couple below
25-32::
    1s & 3s dance RH across with couple below & cross RH & cast 1 place.
    2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (10830, '2018-06-11 00:36:12.028585+00', '2023-02-04 01:19:36.569321+00', 17470, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    All dance Snowball Grand Chain for 4 couples:
::
    1s cross RH, 1s+2s change places LH on sides, 2s cross RH as 1s+3s
    change places RH on sides, 2s+1s also 3s+4s change places LH on
    sides to end 3(2)4(1)
9-16::
    All 4 couples dance a reel of 4 on opposite sides. 3s+2s, 4s+1s pass
    LSh to begin.
17-24::
    All set & dance La Baratte:
::
    Man 1/2 turns Lady RH, retaining hands but at arm''s length from each
    other
::
    Man retraces steps with Lady turning right under Man''s arm briefly
    into Allemande hold (Man behind Lady facing Lady''s original place) &
    releasing Lady''s RH she turns under Man''s left arm until almost in
    original places
::
    Couple change places LH to opposite place
25-32::
    3s+2s also 4s+1s circle 4H round to right. 3s+2s Set+Link _while_
    4s+1s set & cross RH 2 3 (4) (1)', 0);
INSERT INTO 'dancecrib' VALUES (9357, '2016-10-06 07:18:18.777605+00', '2023-02-04 01:19:36.608997+00', 17137, 3, NULL, 'ace', '{{explanation}}
Round the Room, 2 facing 2

1-4::
    Ladies turn 1.1/4 RH _while_ Men dance 3/4 round clockwise.  All end
    in partner''s place
5-8::
    Men turn 1.1/4 RH _while_ Ladies dance 3/4 round clockwise.  All end
    in original places
9-12::
    All NHJ with partner set, advancing on 2nd step, all set retiring
    NHJ with opp dancer (facing partners) & then set on 2nd step
    (couples now facing in/out of circle)
13-16::
    All dance RH across
17-20::
    All NHJ with "new partner" set, advancing on 2nd step, all set
    retiring NHJ with partner, and then set on 2nd step (all in original
    places)
21-24::
    All dance LH across
25-32::
    All dance DoSiDo with opp dancer & all pass opp dancer RSh to meet
    new couple', 0);
INSERT INTO 'dancecrib' VALUES (5021, '2013-08-21 08:30:59.000802+00', '2023-02-04 01:19:36.637511+00', 8929, 3, NULL, 'ace', '1-8::
    1s turn 2H to face up, dance up & cast to face 1st corners
9-16::
    1s set & turn 2H 1st corners, set to 2nd corners & turn 2H to end
    2nd place opposite sides
17-24::
    1s dance reels of 3 on sides giving LSh to 1st corners
25-32::
    1s 1/2 turn RH to face up, lead up to top, cast on own sides behind
    2s, dance in & down to 3rd place as 3s cast up 1 place', 0);
INSERT INTO 'dancecrib' VALUES (10442, '2018-02-24 07:52:23.840611+00', '2023-02-04 01:19:36.666573+00', 15579, 3, NULL, 'ace', '1-8::
    2s+3s Set & Rotate  1 3 2 4
9-16::
    3s dance diag R&L with 1s & 2s (3M down, 3L up each time)  (2) 3 (1)
    4
17-24::
    1s dance diag R&L with 3s & 4s (1M down, 1L up each time)
    (2)(4)(1)(3)
25-32::
    Reels of 4 on sides (2s+4s & 1s+3s pass RSh to start)
33-40::
    All set, all cross RH to own sides, 2s+4s also 1s+3s dance RH across
    to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5022, '2013-08-21 08:30:59.010646+00', '2023-02-04 01:19:36.820765+00', 9849, 3, NULL, 'ace', '1-8::
    1s petronella turn & set, turn 2H to end between 2s facing opposite
    partner
9-16::
    1s dance the Spurtle: 1s dance 1/2 reel of 4 with 2s & turn partner
    RH to face 3s, 1s dance 1/2 reel of 4 with 3s & turn partner RH to
    face 4s
17-24::
    1s dance 1/2 reel with 4s & turn RH to 4th place opposite sides, all
    set & cross RH 1s ending in 4th place
25-32::
    1s followed by 4s+3s+2s lead to top, cross & lead down own sides
33-40::
    2s+3s also 4s+1s dance Diamond Poussette
41-48::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5024, '2013-08-21 08:30:59.089964+00', '2023-02-04 01:19:36.967144+00', 1698, 3, NULL, 'ace', '1-8::
    1L+2M also 3L+4M cross RH, all turn partners LH on sides, 1L+2M also
    3L+4M cross back RH & 1s+2s also 3s+4s turn LH on sides
9-16::
    1M+2L also 3M+4L repeat bars 1- 8
17-24::
    All dance reels of 4 on sides
25-32::
    1s & 4s set, cast in 1 place & dance 1/2 Figs of 8 round end couples
33-40::
    2s & 3s repeat bars 25-32
41-48::
    1s followed by 2s+3s+4s lead down to bottom & cast up to original
    places
49-56::
    1s+2s dance 4 bars of Poussette, 1s+3s dance 4 bars of Poussette
    _while_ 2s set
57-64::
    1s+4s dance 4 bars of Poussette _while_ 2s & 3s set & all dance last
    4 bars of Poussette', 0);
INSERT INTO 'dancecrib' VALUES (5023, '2013-08-21 08:30:59.018667+00', '2023-02-10 14:35:26.589442+00', 1697, 3, NULL, 'ace', '1-8::

    1s+2s+3s dance reflection reels of 3 on own sides (1s in & down to

    start)

9-16::

    1M+3L 1/2 turn RH & turn to right to dance out to each others place,

    1L+3M repeat

17-24::

    1s+3s chase clockwise back to places _while_ 2s turn 2H, 1s+2s dance

    RH across 1/2 way _while_ 3s cross RH, 2s+1s+3s cross RH

25-32::

    1s cross down below 3s, cast up to 2nd place, cross up to top & cast

    to 2nd place _while_ 2s+3s set & cross RH & repeat back to own sides', 0);
INSERT INTO 'dancecrib' VALUES (15297, '2022-12-12 16:50:47.283862+00', '2022-12-12 16:54:28.617939+00', 4956, 1, NULL, 'ace', '1--::

 Mirror Reels3 on the sides, 1c start inwards (1,2,3)

9--::

  1c+2c R&L (1,2,3)

17--::

  1c cast off two places on own side, dance up to the top and cast off one (2c up) (2,1,3). 

::

  On second time through1c cast to 4pl as 4c step up

', 3);
INSERT INTO 'dancecrib' VALUES (5026, '2013-08-21 08:30:59.106317+00', '2023-02-04 01:19:37.032606+00', 11393, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Diamond Poussette
9-16::
    1L+2M also 3L+4M pass RSh turn to face each other & turn about to
    dance into others place, 1M+2L also 3M+4L repeat
17-24::
    1s & 3s dance 1/2 Fig 8 round couple above them, 2s & 4s dance 1/2
    Fig 8 round couple below
25-32::
    1s+4s+3s (bottom 3 cpls) dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (5027, '2013-08-21 08:30:59.114287+00', '2023-02-04 01:19:37.04373+00', 10886, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 double Fig of 8 (1s cross down & 4s cross
    up to start), 1M+2M also 3L+4L turn LH _while_ 1L+2L also 3M+4M turn
    RH
9-16::
    All repeat back to places but turn with other hands
17-24::
    1s+2s also 3s+4s dance Petronella-in-tandem to opposite sides
25-32::
    1s+4s dance 1/2 R&L _while_ 2s & 3s 1/2 turn & twirl to own sides,
    2s+4s also 1s+3s dance RH across.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5028, '2013-08-21 08:30:59.124311+00', '2023-02-04 01:19:37.056157+00', 11512, 3, NULL, 'ace', '1-8::
    All dance RSh reel of 4 on sides
9-16::
    All set, 1M+2L also 3M+4L cross RH, 1L+2M also 3L+4M cross LH, 2s &
    3s cross RH _while_ 1s+4s turn RH 1.1/4 times to end in centre
    facing partner (L face down, M face up)
17-24::
    1s+4s dance HS Poussette :
::
    1s set HS step with both hands joined dancing out to Men''s side
    _while_ 4s set & dance out to Ladies'' side ending with a 1/4 turn to
    right
::
    1s dance HS down Men''s side & 4s up Ladies'' side ending with a 1/4
    turn to right
::
    4s+1s dance HS into centre to reform line of 4 in middle with
    couples having changed places
::
    4s+1s 3/4 turn partners with both hands to own sides
25-32::
    2s+4s also 1s+3s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8695, '2015-03-03 08:47:29.644274+00', '2023-02-04 01:19:37.066758+00', 15276, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to Right. 1s set, cast (2s step up)
9-16::
    1s lead down and back up, dancing behind 3s into 2nd place own side
17-24::
    1s turn 1st corner RH, pass partner RSh, turn 2nd corner RH, pass
    RSh to finish with 1L between 2s (facing up), 1M between 3s (facing
    down)
25-32::
    1s dance out of ends, cast to Right (round 4th corner) into 2nd
    place (2 bars).  2s+1s+3s set, 1s+3s circle 4H round to Left

{{explanation}}
Repetition:  1s & original 3s (now 2s) retain hands ready to start again with circle 4H round to right', 0);
INSERT INTO 'dancecrib' VALUES (5029, '2013-08-21 08:30:59.134208+00', '2023-02-04 01:19:37.083769+00', 1707, 3, NULL, 'ace', '1-8::
    3s followed by 2s lead down below 4s, cross & cast up to 3rd place,
    cross up RH to 2nd place own sides with 2s ending in 3rd place opp
    sides, all set
9-16::
    3s+2s petronella turn into centre & set to partner, 3M+2M turn right
    about to face each other & 3s+2s dance 1/2 reel of 4 (Men pass RSh)
17-24::
    2M+3M turn RH (elbow) 1.1/2 times to face other Lady, turn other
    Lady LH (elbow) 1.1/2 times to Lady facing Lady
25-32::
    2L+3L turn LH (elbow) 1.1/2 times to end on right of partner, 3s
    lead down (LH) between 2s & 4s, cross & cast up to original places
    _while_ 2s dance up & cast to original places
33-40::
    2s+3s dance 1/2 R&L _while_ 1s & 4s change places with partners &
    set, 1s+3s also 2s+4s dance 1/2 R&L to end 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (5030, '2013-08-21 08:30:59.142526+00', '2023-02-04 01:19:37.109491+00', 1708, 3, NULL, 'ace', '{{explanation}}
4s & 5s & 6s start on opp sides

1-8::
    All Ladies Adv+Ret, all Men dance round partners RSh & end in centre
    with partners
9-16::
    1s+2s+3s slip step down & back _while_ 4s+5s+6s slip step up & back
    (Men pass BtoB)
17-24::
    1s+2s+3s dance modified Allemande & end with 2s dancing to top (2 3
    1) as 4s+5s+6s dance reverse Allemande down (5s to end).  2 3 1 6 4
    5
25-32::
    1s+6s (centre couples) dance RH across & LH back
33-40::
    2s+3s also 4s+5s dance R&L
41-48::
    1s cross up & dance out between 2s & 3s, up round 2s & dance down to
    meet 6s who dance similarly round 5s, 1s+6s 1/2 turn opp dancer 2H
49-56::
    Repeat bars 41-48 at opposite ends & end by turning opposite dancer
    2H to places
57-64::
    All set twice & turn RH.  2 3 1 6 4 5

{{explanation}}
Repeat with new end couples', 0);
INSERT INTO 'dancecrib' VALUES (5031, '2013-08-21 08:30:59.159927+00', '2023-02-04 01:19:37.158292+00', 14231, 3, NULL, 'ace', '1-8::
    1s+3s dance into centre & dance out through side couples with other
    partner, dance back to places & set to partner
9-16::
    2s+4s repeat
17-32::
    All dance full Schiehallion Reel
33-40::
    1s+3s dance 1/2 R&L, 1L & 3L followed by partners chase back to
    places
41-48::
    2s+4s repeat
49-56::
    All Ladies dance LH across, set to partner & dance to place
57-64::
    All Men dance RH across, set to partner & dance to place
65-72::
    1s (prom hold) dance a RSh reel of 3 across with 4M+2L _while_ 3s
    dance RSh reel of 3 across with 2M+4L
73-80::
    2s (prom hold) dance LSh reel of 3 up/down with 3L+1M _while_ 4s
    dance LSh reel of 3 up/down with 1L+3M
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12463, '2020-01-02 06:59:27.761395+00', '2023-02-04 01:19:37.172299+00', 10014, 3, NULL, 'ace', '1-4::
    1s dance down to 3rd place (2s+3s step up), 1s+3s change places (Men
    RH, Ladies LH)
5-8::
    1s+2s turn (Men LH, Ladies RH), 2s face out
9-16::
    2s+1s+3s dance mirror reels of 3 on sides (1s in/down, 3s out/up, 2s
    out/down). 1s end facing 1st corners
17-24::
    1s dance 1/2 diag reel of 4 with 1st corners, pass LSh to face 2nd
    corners; 1s dance 1/2 diag reel of 4 with 2nd corners & end in 2nd
    place opp side
25-28::
    2s+1s+3s form circle & set, drop hands & petronella turn 1 place to
    right
29-32::
    All form circle & set, drop hands & petronella turn 1 place to
    right. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5032, '2013-08-21 08:30:59.168325+00', '2023-02-04 01:19:37.199741+00', 1709, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, petronella turn into middle, set Lady
    turning to face down to form lines of 3 across
9-16::
    1M+2s & 1L+3s dance down & back in ''Triumph'' & 1M+2s turn to face
    down
17-24::
    2s+1s+3s set twice, 2s+3s turn on sides _while_ 1s change places &
    turn ending in 2nd places
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9358, '2016-10-06 07:18:18.944346+00', '2023-02-04 01:19:37.228346+00', 17140, 3, NULL, 'ace', '1-8::
    1M+4L set, Adv+Ret  & set _while_ 1L+4M stand (2 bars), set, Adv (2
    bars) & set. (Bar 5 both couples join RH with partner and retain
    hands)
9-12::
    1s+2M & 4s+3L dance RH across, ending 2M in 1st place, 3L in 4th
    place
13-16::
    1s+2L & 4s+3M dance LH across, ending 1M behind 1L (above 1st place
    facing Men''s side) 4L behind 4M (below 4th place facing Ladies''
    side), 2L in 1st place, 3M in 4th place
17-20::
    1L followed by 1M casts 2 places _while_ 4M followed by 4L casts up
    2 places.  Bar 20: 1s+4s in line up/down middle BtoB with partner,
    Men facing up, Ladies down
21-24::
    4M+2s & 1L+3s circle 3H round to left _while_ 4L+1M 1/2 turn LH,
    clap, 1/2 turn RH. 4s & 1s finish BtoB with partners
25-26::
    4M+2s & 1L+3s join hands (as ''Crown Triangles'') & set _while_ 4L+1M
    turn 2H 1/2 way (PdeB)
27-28::
    4s+1s dance to Right (PdeB) round person behind to change places
    _while_ 2s+3s set
29-30::
    1M+2s & 4L+3s set (as ''Crown Triangles'') _while_ 4M+1L turn 2H 1/2
    way (PdeB)
31-32::
    1s & 4s dance to Right (PdeB) round partner to centre facing up
    (Lady on Man''s Left) _while_ 2s+3s set
33-36::
    1s+4s lead up to top, cast on opp sides, 1s to 3rd place, 4s to 2nd
    place
37-40::
    _1/2_ Figs 8, 4s round 2s & 1s round 3s.  2 4 1 3
41-48::
    All 1/2 turn partner RH, retain hands & set, release hands & pass
    partners RSh dancing out to own sides, all set', 0);
INSERT INTO 'dancecrib' VALUES (14203, '2021-08-14 00:19:24.969028+00', '2023-02-04 01:19:37.256521+00', 12192, 3, NULL, 'ace', '1-8::
    1s+4s cross RH & cast down/up (2s & 3s step up/down on bars 3-4);
    1s+4s dance RH across
9-12::
    1M followed by partner casts down 2 places, cross to finish in 4th
    place on own sides facing up _while_ 4L followed by partner casts up
    2 places & cross to finish in 1st place on own sides (2s/3s step
    down/up on bars 9-10 to face ends) 4 2 3 1
13-16::
    All RH turn person facing
17-20::
    All dance 1/2 reel of 4 on the sides to finish 1s & 2s facing down,
    3s+4s facing up. 1 3 2 4
21-24::
    All set to person facing & change places RH on the side. 3 1 4 2
25-32::
    All dance 8H round & back. 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (5034, '2013-08-21 08:30:59.18661+00', '2023-02-04 01:19:37.325733+00', 1716, 3, NULL, 'ace', '1-8::
    1s cross & cast into reflection reels of 3 on opposite sides with 2s
    & 3s, 1s ending with extra loop to change places with 2s
9-16::
    1s cross down into reflection reels of 3 on own sides with 3s & 4s
    (1s end 2nd place own sides)
17-24::
    1M+3L change places RH & set _while_ partners set & change places
    RH, 1s & 3s set to partners & cross RH to own sides
25-32::
    2s+3s circle 4H round & back _while_ 1s+4s circle 4H round to Left
    for 3 bars & back with 1s casting 4th places
33-40::
    All dance Grand Chain (End couples cross to begin)', 0);
INSERT INTO 'dancecrib' VALUES (5035, '2013-08-21 08:30:59.194937+00', '2023-02-04 01:19:37.357418+00', 1719, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-4::
    All set then 1s & 4s 1/2 turn RH moving to centre into prom hold as
    2s & 3s cast to ends
5-8::
    1s & 4s in prom hold dance 1/2 reels of 3 across with 2s/3s (1s RSh
    to 2M, 4s RSh to 3M)
9-16::
    1s+4s dance RH across 1/2 way & 1/2 turn partner into prom hold, 4s
    & 1s prom hold 1/2 reels of 3 across with 2s/3s (4s RSh to 2M, 1s
    RSh to 3M)
17-24::
    4s+1s dance RH across 1/2 way & 1/2 turn partner into prom hold, 1s
    & 4s dance 1/2 reels of 3 on sides (4s RSh to 2M, 1s RSh to 3M)
25-32::
    4s & 1s dance into 1/2 reels of 3 across (4s LSh to 3M, 1s LSh to
    2M), 4s+1s dance 1/2 RH across & cross RH to end 3 1 (4)(2)
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5037, '2013-08-21 08:30:59.213125+00', '2023-02-04 01:19:37.450667+00', 8665, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s set, cast 1 place _while_ 2s set & lead up, 2s & 1s repeat
17-24::
    1s followed by 2s & 3s cast 2 places & lead up to places
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (8997, '2015-11-30 08:59:40.83677+00', '2023-02-04 01:19:37.652282+00', 16782, 3, NULL, 'ace', '1-2::
    1L+2M also 3L+4M 1/2 turn 2H to end NHJ facing up in middle of lines
    across with 1M/2L & 3M/4L (2L & 4L step up)
3-8::
    Inner dancers (1L+2M & 3L+4M) cast 1 place & all
    petronella-in-tandem & set facing up/down  (2)1(4)3
9-16::
    All turn facing person 2H & 1s+4s 1/2 turn LH on sides, 1s & 4s 1/2
    turn & twirl to partners place (2)4(1)3
17-24::
    All dance reflection reels of 4 (2s dance out to start & all giving
    hands where possible)
25-26::
    2L+4L also 1L+3L 1/2 turn 2H to end NHJ facing up in middle of lines
    across with 1M/2L & 3M/4L (4M & 3M step up)
27-32::
    Inner dancers (4L+2L & 3L+1L) cast 1 place & all
    petronella-in-tandem & set facing across  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8998, '2015-11-30 08:59:40.845354+00', '2023-02-04 01:19:37.688279+00', 16100, 3, NULL, 'ace', '1-8::
    1s lead down (3 bars) & back up (3 bars) & cast (2s step up 7-8)
9-16::
    1s set to 1st corners & dance La Baratte:
::
    _11-12_    1s 1/2 turn corners RH & retain hands but at arm''s length
    from each other
::
    _13-14_    Men retrace steps with Lady turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies original
    place) & releasing Ladies RH she turns under Mans left arm until
    almost in original places
::
    _15-16_    1s+1st corners change places LH to opposite places
17-20::
    2M followed by 1M dance up behind 2L & down middle _while_ 3L
    followed by 1L dance down behind 3M & up middle
21-24::
    1s + 1st corners (2M+3L) dance LH across.  1s end in 2nd place own
    sides, corners in diagonally opp corner place
25-32::
    1s set to 2nd corners & dance La Baratte (start with LH turn)
33-36::
    3M+1M dance down behind 2M (in 3rd place) & up middle _while_ 2L+1L
    dance up behind 3L (in 1st place) & down middle
37-40::
    1s + 2nd corners dance RH across.  Is end in 2nd place own sides,
    2nd corners in diagonally opp corner place
41-44::
    1s dance 1/2 reels of 3 across (1M up, passing 3M by RSh, 1L down,
    passing 2L by RSh)
45-48::
    1s turn RH 1.1/2 times to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13522, '2021-01-09 01:19:24.022594+00', '2023-02-04 01:19:37.71376+00', 10641, 3, NULL, 'ace', '{{explanation}}
Circle, Men on inside facing partner

1-8::
    All face to right & dance 4 steps; all face to left & dance 4 steps
    back to place
9-16::
    All turn partner RH; all turn partner LH
17-24::
    All Adv+Ret; all dance DoSiDo with partner moving 1 place to right
    to meet new partner
25-32::
    All Adv+Ret; all turn new partner LH', 0);
INSERT INTO 'dancecrib' VALUES (5039, '2013-08-21 08:30:59.28155+00', '2023-02-04 01:19:37.73153+00', 1731, 3, NULL, 'ace', '1-4::
    2s adv PdB for 2 steps & turn singly right & face own sides _while_
    1s dance up for 2 steps & cast back to pl _while_ 3s dance down &
    cast back to pl
5-8::
    1M+2M+3M also 1L+2L+3L dance RH across once round to end in original
    places
9-16::
    2s turn LH 1.1/2 times & dance RH across with other side to end in
    2nd place opposite sides
17-20::
    All advance for 2 steps & retire
21-24::
    1L dances under arch made by 2M+3L to 3rd place as 2M+3L turn under
    own arch with 3L dancing to 1st place _while_ Men dance similarly
25-32::
    3s+2s (top couples) dance 1/2 R&L, 3s cross RH & all set', 0);
INSERT INTO 'dancecrib' VALUES (5040, '2013-08-21 08:30:59.297122+00', '2023-02-04 01:19:37.804278+00', 1733, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH across back to places
9-16::
    1M+2L set advancing, turn RH & dance back to places, 1L+2M set
    advancing, turn RH & dance back to places
17-24::
    1s dance down the middle & dance up behind 3s to 2nd place own sides
25-32::
    1s+3s circle 4H round & back
33-40::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (11865, '2019-05-27 12:36:59.119309+00', '2022-12-13 23:14:40.222063+00', 19363, 1, 202, 'ace', '1--::

  1c+2c the Espagnole. 1c finish with backs to 1cnrs

9--::

  »Corners Chase and Turn« with 1cnrs [: 1c cross RSh to 3cnr place, face in and set _while{4}_ 1cnrs pass RSh, turn BH and finish with backs to 3cnr ; repeat figure, finishing with 1cnrs in own place and setting, and 1c with backs to 2cnr]

17--::

  Repeat [9-16] with 2cnrs, and finish (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (9886, '2017-05-28 07:14:29.194431+00', '2022-12-14 16:07:16.320596+00', 14040, 1, 202, 'ace', '1--::

  1c+2c+3c set | cross RH ; chase clw ½ (3,2,1)

9--::

  1W+2W & 1M+2M turn RH 1 ½, 1W facing out  (to 3,1,2) ; 1W followed by P cast R, dance up into facing lines of 3 across

17--::

  All set | 1c set advancing pivoting R into BtoB 1W(1M) facing up(dn) _while_ 2c & 3c set ; all set in DTr | 1c dance Rsh to P to 2plx facing out _while_ 2c & 3c set (3,1x,2)

25--::

  ½ Reels3, 1c start Rsh to 1cnr[pos] ; 1c set |cross RH (3,1,2)', 3);
INSERT INTO 'dancecrib' VALUES (15298, '2022-12-15 13:10:35.789495+00', '2022-12-15 17:04:30.33897+00', 21199, 1, 1645, 'ace', '1--::
  1c long cast (2c up) ; "gipsy turn" 1&frac14; RSh & twirl to end BtoB on midline 1M/1W facing up/down
9--::
  1M+2c & 1W+3c set as Crown Triangles | 1c set rotating to face 1cnrs _while_ cnrs set pulling RSh back to place ;
  1c+1cnrs &frac12; RSh Reel4, 1c end facing opp side
17--::
  Repeat [9-16] on sides, 1c &frac12; Reel4 with 4cnrs & pass RSh to opp side (3x,1x,2x)
25--::
  3c+1c+2c Circle6 &frac14; to L | adv to centre ; cast clw round to own sides (2,1,3)
', 5);
INSERT INTO 'dancecrib' VALUES (3979, '2013-08-21 08:30:40.765285+00', '2023-02-04 01:18:25.032902+00', 107, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross LH & cast up to places
9-16::
    1s dance reels of 3 on own sides dancing down between 2s to start
17-24::
    1s dance down for 4 steps, set & dance up to 2nd place (in middle)
25-32::
    1M+2M+3M dance LH across _while_ Ladies dance RH across, 1s dance to
    top & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (5041, '2013-08-21 08:30:59.312707+00', '2023-02-04 01:19:37.822412+00', 9984, 3, NULL, 'ace', '1-8::
    1s dance down between 2s, behind 3s, between 4s & cast up to top
9-16::
    1s+2s+3s set & dance *Triple Petronella-in-Tandem into lines of 3
    across, set & Triple Petronella-in-Tandem to opposite sides (3) (2)
    (1) (4)
17-20::
    1s followed by 2s & 3s dance down NHJ for 2 steps, cross, Lady
    turning under Man''s arm (2 bars).
21-24::
    3s followed by 2s & 1s dance up & 3s cast to 3rd place, 2s dance up
    to top & 1s to 2nd place in centre
25-32::
    1M+2M+3M dance LH across as Ladies dance RH across, 1s followed by
    3s dance down between 4s & dance L/RH across with 4s to end 2 3 4 1

{{explanation}}
Note:	*Triple Petronella-in-Tandem is similar to Petronella-in-tandem but 3 dancers petronella in line together', 0);
INSERT INTO 'dancecrib' VALUES (5043, '2013-08-21 08:30:59.327992+00', '2023-02-04 01:19:37.865602+00', 8105, 3, NULL, 'ace', '1-8::
    1s+2s set, set facing on sides & turn (LH Ladies & RH Men)
9-16::
    1s+2s+3s dance reels of 3 on sides (1s in & down to start)
17-24::
    1s cross down into Double Triangle position & all set, 1s dance out
    round 1st corners & across into 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8696, '2015-03-03 08:47:29.794782+00', '2023-02-04 01:19:37.883478+00', 15277, 3, NULL, 'ace', '1-8::
    1s dance Progressive Fig 8:  1s cross RH as 2s set, 1s+2s dance 3/4
    double Fig of 8 with 1s casting & 2s crossing up to start
9-16::
    1s set, turn 3/4 RH. 1s dance LH across (1L+2s at top, 1M+3s in 3rd
    place)
17-24::
    1s set, turn 3/4 RH. 1s dance LH across (1M+2s at top, 1L+3s in 3rd
    place). 1s finish in 2nd place own side
25-32::
    1s+3s dance »Bourrel«:
::
    _25-28_     1M+3L set advancing, 3/4 turn 2H & twirl to end BtoB
    (Lady facing up & Man down) _while_ partners chase anticlockwise to
    face partner
::
    _29-32_     Set to partners & turn 2H to own sides having changed
    places', 0);
INSERT INTO 'dancecrib' VALUES (13072, '2020-08-10 00:19:20.43637+00', '2023-02-04 01:19:37.917617+00', 1743, 3, NULL, 'ace', '1-8::
    1s set advancing passing RSh as 2s set,   1/2 turn on sides (1M+2L
    RH, 1L+2M LH); 1s dance 1/2 Fig 8 up round 2s
9-16::
    1s set advancing passing RSh as 3s set, 1s+3s set & 1/2 turn on
    sides (1M+3L LH, 1L+3M RH); 1s dance 1/2 Fig 8 down round 3s
17-20::
    2s+1s+3s set, 2s & 3s cross RH _while_ 1s turn 3/4 RH into line
    across (1L between 2s, 1M between 3s)
21-24::
    All set, 2s+3s change places RH _while_ 1s 1/2 turn LH to face 3rd
    corner (pstn)
25-32::
    _1/2_ diag reel of 4 on 1st corner diagonal, 1s pass RSh; 1/2 diag
    reel of 4 on 2nd corner diagonal.  1s end 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13371, '2020-11-11 20:57:03.057387+00', '2023-02-04 01:19:38.024064+00', 9059, 3, NULL, 'ace', '1-8::
    1s set, lead down, cross & dance down behind 3s;  1s meet, dance up
    to face1st corners _while_ corners set facing in diagonally
9-12::
    1s+1st corners set, Petronella turn to face diagonally across NHJ
13-16::
    1s+1st corners Set+Link, corners cast to place _while_ 1s dance into
    2nd place opp sides
17-24::
    1s dance 6 bar reels of 3 on opp sides (LSh to 2nd corners). Finish
    1M between 3s, 1L between 2s, then pass LSh to face 2nd corners
    _while_ corners face in diagonally & set
25-32::
    1s+2nd corners repeat bars 9-16 ending 1M between 2s, 1L between 3s
33-40::
    1s dance 6 bar reels of 3 across (LSh to 3rd corner).  Bars 39-40:
    1s pass LSh to 2nd place own sides _while_ corners face in
    diagonally & set right, face partner & set left.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5044, '2013-08-21 08:30:59.336131+00', '2023-02-04 01:19:38.048705+00', 9204, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, cross passing RSh. 1s turn 1st corner 3/4 RH
    moving inwards to centre slightly. 1s retain hands with corner for…
9-16::
    1s+1st corners dance RH across & LH back, 1s end facing 1st corners
17-24::
    1s dance full diagonal reel of 4 with 1st corners 1s end facing 4th
    corner (partner''s 2nd corner)
25-32::
    1s dance Corner Pass+Turn with 4th corners & pass RSh to face own
    1st corners; dance Corner Pass+Turn with 1st corners & end in 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (10331, '2017-12-22 15:44:13.826826+00', '2023-02-04 01:19:38.228626+00', 11839, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up), 1s turn 1.1/4 LH to face 1st corners
9-12::
    1s dance 1/2 diag reel of 4 with 1st corners & dance 1/4 LSh round
    partner ready for …
13-16::
    1s + couple in 1st place & 1L + couple in 3rd place dance RH across.
    1s end facing 2nd corners
17-20::
    1s dance 1/2 diag reel of 4 with 2nd corners (1s slowing on bars
    19-20 to pass LSh)
21-24::
    1s turn 1.1/4 LH
25-28::
    _1/2_ LSh reel of 3 across, 1M+2M (in 3L place) & 1L+3L (in 1M
    place) pass LSh to start. 1s finish facing out at ends of set
29-32::
    1s cast to Right to 2nd place own side _while_ 3s+2s change places
    RH on side & all set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13073, '2020-08-10 00:19:20.708184+00', '2023-02-04 01:19:38.258543+00', 13100, 3, NULL, 'ace', '{{explanation}}
Start:	Line of 3 dancers 3  4  5  (facing up), 2 & 1s facing spaces between 3 4 5

1-8::
    Dancers 1 & 2 dance Fig 8 (Dancer 1: LSh round 4, RSh round 5 & back
    to place,  Dancer 2: dances similar round 3 & 4)
9-16::
    All circle 5H round & back to starting positions
17-24::
    _1_+2 Set+Link twice _while_ 3+4+5 Set+Link for 3 twice
25-32::
    _1/2_ Diag R&L: 2+1 with 5+3 (diagonal to right); 1/2 Diag R&L 3+5
    with 4+1 (diagonal to left).  End 4 1 (at top) 5 3 2 (at bottom)', 0);
INSERT INTO 'dancecrib' VALUES (5045, '2013-08-21 08:30:59.344396+00', '2023-02-04 01:19:38.28077+00', 12577, 3, NULL, 'ace', '1-8::
    2s followed by 1s dance down for 3 bars, dance back up (3 bars),
    then 1s cast to 2nd place
9-16::
    1s set & dance La Baratte:
::
    _11-12_  1s 1/2 turn RH & retain hand but at arm''s length from each
    other
::
    _13-14_  1M retraces steps with 1L turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies original
    place) & releasing Ladies RH she turns under Mans left arm until
    almost in original places
::
    _15-16_  1s turn 3/4 LH (1M faces 2M, 1L faces 3L)
17-24::
    1s dance reels of 3 across (1M LSh to 2M, 1L LSh to 3L) ending with
    RH turn to face same couples
25-32::
    1s dance reels of 3 across (1M RSh to 2L, 1L RSh to 3M) ending in
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (10065, '2017-09-03 23:44:32.34884+00', '2023-02-10 15:04:30.037465+00', 1668, 3, NULL, 'ace', '1-8::

    1s slip step down & back

9-16::

    2s repeat bars 1-8

17-24::

    1M+2L cross RH, 1L+2M cross RH, 2s+1s set, 2s cross RH _while_ 1s

    turn LH to face 1st corners

25-32::

    1s turn 1st corner RH, partner LH, 2nd corner RH & cross LH to own

    sides.', 0);
INSERT INTO 'dancecrib' VALUES (14172, '2021-07-28 14:23:03.751661+00', '2022-12-16 08:40:32.671908+00', 11563, 1, 202, 'ace', '1--::

  1c cast off to midline (2c up on [3-4]) and finish BtB. 1M faces down, 1W faces up ; all set as for DTr | 1c dance RSh ¾ round P and finish BtoB facing opposite sides _while{2}_ 2c & 3c set

9--::

  ½ Reels3 on sides, 1c RSh to 1cnrs. 1c finish as on [9]  ; all set as for DTr | 1c dance RSh ¾ round P and finish BtoB 1M facing up, 1W facing down _while{2}_ 3c & 2c set

17--::

  ½ Reels3 across, 1c RSh to 2cnrs[pos] (to 3x,1x,2x) ; all set |all turn P RH ½ (3,1,2)

25--::

  3C Allemande (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (5046, '2013-08-21 08:30:59.352674+00', '2023-02-04 01:19:38.336924+00', 10433, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+3s dance the Swirl:
::
    _9_ -10 Turn partner RH into Allemande hold
::
    _11-12_  Dance LSh round other couple 1/2 way, on bar 12 drop right
    hands
::
    _13-16_ 1s+3s dance LH across. On bar 16, pull back LSh & dance on
    to face side couples (BtoB with ptnr & Lady facing Man, 1L & 3M face
    2s, 3L&1M face 4s)
17-24::
    All dance reels of 4 across
25-32::
    All set & dancing couples dance out between side couples, cross &
    cast to change places RH with partner back into places
33-40::
    All set & advance with partners, retire diagonally with corners &
    set
41-48::
    1L+4M dance R&L with 3L+2M (on diagonal)
49-56::
    1M+2L dance R&L with 3M+4L (other diagonal)
57-64::
    All set with corners, Adv+Ret with partners & set
65-88::
    2s & 4s repeat bars 9-32
89-96::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13131, '2020-09-15 00:19:21.466023+00', '2023-02-04 01:19:38.364931+00', 12196, 3, NULL, 'ace', '1-8::
    1s+4s cross RH & cast down/up (2s &3 step up/down), 1s+4s dance RH
    across to finish in lines across facing top (1s b''tw''n 2s & 4s
    b''tw''n 3s, Men with partner on left)
9-16::
    All join hands for Highland Schottische set right & left. Bar 12 all
    turn to face across set, 1s&4s back to back with partner. Repeat
    Highland Schottische set right & left.
17-22::
    1s turn 2s 2H & 4s turn 3s 2H to finish in middle facing partner, 1s
    & 4s set, turn partners 2H. Bars 21-22 2s & 3s step down/up
23-24::
    1s & 4s pass partner RSh & curve to right to original place to flow
    into
25-32::
    1s+2s 1/2 RH across, 1s+3s dance 1/2 LH across, 1s+4s 1/2 RH across.
    All cross RH. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8317, '2014-07-29 12:58:56.054177+00', '2023-02-04 01:19:38.392754+00', 15069, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross down round 3s, cast up to 2nd place
9-16::
    2s+1s+3s Set+Link for 3 couples twice      (3) (1) (2)
17-20::
    1s dance 1/2 Fig. 8 round 4th corner positions (1L up, 1M down) to
    face 1st corner positions
21-32::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s meet again in the
    middle & pass RSh to face 3rd corner positions
33-40::
    1s dance RSh round 3rd corners, dance up/down middle of set,
    crossing RH, cast round 4th corners to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (14419, '2021-11-06 01:10:47.904225+00', '2023-02-04 01:19:38.618062+00', 20540, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig 8 on sides (in/down to start) to below 3s; 1s dance
    1/2 Fig 8 up round 3s to end above 3s in centre on opp sides facing
    up
9-16::
    1s lead up (RH) to top, cross & cast (2s step up 11-12); 2s+1s+3s
    turn partner RH remaining in centre facing up ready for …
17-24::
    2s+1s+3s dance Allemande
25-32::
    3s+1s+2s set, cross RH & chase clockwise 1/2 round to own sides.  2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (5048, '2013-08-21 08:30:59.370976+00', '2023-02-04 01:19:38.766976+00', 1757, 3, NULL, 'ace', '1-8::
    1s turn RH, cross down to 2nd place opposite sides _while_ 2s cross
    RH & cast to top places; 1s cast back to top & dance down to face
    1st corners _while_ 2s cross down to 2nd place own sides & cast to
    top place
9-16::
    1s dance ''Hello-Goodbye'' setting & end facing up/down (BtoB in
    centre)
17-24::
    1s circle 3H round (1M with 2s & 1L with 3s) ending 1s in 2nd place
    opposite side; 1s turn LH to face 2nd corners _while_ 2s & 3s turn
    RH
25-32::
    1s dance Pass+Turn with 2nd corners & turn quickly RH to face 2nd
    corners; dance Pass+Turn with 1st corners ending in 2nd places own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (5049, '2013-08-21 08:30:59.380845+00', '2023-02-04 01:19:38.780453+00', 1758, 3, NULL, 'ace', '1-8::
    All cross RH & dance 1/2 RH across (1s+2s & 3s+4s); all cross LH &
    dance 1/2 LH across back to place
9-16::
    All set, circle 8H round to left 1/2 way to end in square formation
    & retaining hands all set
17-24::
    1s & 4s dance 1/2 R&L (up/down set) back to original places, 2s & 3s
    dance 1/2 R&L (across) back to original places (now longways set
    again)
25-32::
    All turn partners RH, 1s dance down middle _while_ 2s+3s+4s set &
    dance up 1 place', 0);
INSERT INTO 'dancecrib' VALUES (5050, '2013-08-21 08:30:59.388996+00', '2023-02-04 01:19:38.791868+00', 9472, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-4::
    1s & 4s set & cross down/up to next place _while_ 2s & 3s cross RH &
    cast to ends
5-8::
    2s & 3s cross down/up & cast to ends _while_ 1s & 4s cast to ends &
    cross LH down/up to next place.  2 1 (4)(3)
9-16::
    All dance Grand Chain
17-24::
    1s+4s set, dance RH across 1/2 way, 4s+1s circle 4H round to left
25-32::
    4s+1s set & 1/2 turn partners, lead up/ between end couples, cross &
    cast in 1 place.  2 4  (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (13888, '2021-04-05 00:19:24.825307+00', '2023-02-04 01:19:38.839403+00', 19497, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance DoSiDo
9-16::
    All set with 1s advancing join LH with partner & RH with 2s/3s,
    1L+2s & 1M+3s dance RH across, 1s turn RH & retain hands _while_ 2s
    & 3s cross RH to opp side
17-24::
    All set with 1s joining LH with 2s/3s, 1L+3s & 1M+2s dance LH
    across, 1s 1/2 turn RH to face down _while_ 2s & 3s cross LH to own
    side facing out
25-30::
    Mirror reels of 3 on sides (1s down & cast up round 3rd place, 2s
    out/down, 3s out/up to start)
31-32::
    1s cross down RH to 3rd place own side _while_ 3s cast up to 2nd
    place & polite turn', 0);
INSERT INTO 'dancecrib' VALUES (5053, '2013-08-21 08:30:59.423321+00', '2023-02-04 01:19:38.864059+00', 7385, 3, NULL, 'ace', '1-8::
    1s & 5s cross RH & cast in 1 pl, 1s+3s+5s dance 1/2 LSh reel of 3
    (3L up & 3M down to start) end with 5s & 1s facing opp sides BtoB
9-16::
    All dance Double Triangles
17-24::
    All dance RH across & back (5L with 2s, 5M+1L with 3s & 1M with 4s)
    1s & 5s passing RSh to own sides
25-32::
    5s+3s also 1s+4s dance 1/2 R&L, 5s+4s dance 1/2 R&L _while_ 3s & 1s
    set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (5054, '2013-08-21 08:30:59.431567+00', '2023-02-04 01:19:38.89925+00', 1763, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance RH across (1M with2s & 1L with
    3s)  2(1)3
9-16::
    2s+1s+3s dance "The Fiddich":
::
    2M+3L chase clockwise to each others place _while_ 1s with person on
    their right set advancing & dance RH across 1/2 way (3 1 2 on
    opposite sides)
::
    Repeat but with 2L+3M chasing & 1s with person on left advancing &
    dancing LH across.  2(1)3
17-24::
    2s+1s+3s dance reels of 3 on sides (giving RSh to 2nd corner to
    start) & 1s end crossing RH.  2 1 3
25-32::
    2s+1s+3s dance "Wheelie Chain":
::
    1M dances 1/2 RH across with 2s as 1L dances 1/2 RH across with 3s,
    Men dance 1/2 LH across on Ladies'' side as Ladies dance LH across on
    Men''s side to end (3)(1)(2) all on opposite sides
::
    Repeat to end 2 1 3 on own sides', 0);
INSERT INTO 'dancecrib' VALUES (5055, '2013-08-21 08:30:59.441311+00', '2023-02-04 01:19:38.930665+00', 1768, 3, NULL, 'ace', '1-8::
    1s+2s+3s Promenade ending with 1s crossing RH & cast to 2nd place
    opposite side _while_ 2s dance up to top
9-16::
    _9-10_    1s+2s+3s set, 1s petronella turn to right on 2nd setting
    step into lines across
::
    _11-16_  1s repeat, setting across & on side lines to end facing 1st
    corners. 2s & 3s continue setting throughout
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corner, pass LSh & dance
    1/2 reel with 2nd corner. 1s end in 2nd place opposite sides (3) (1)
    (2)
25-32::
    3s+1s+2s circle 6H 1/2 round to left; all turn partners RH back to
    place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15299, '2022-12-16 11:10:20.229125+00', '2022-12-16 11:14:35.768872+00', 16934, 1, 202, 'ace', '1--::

  All set advancing | turn opposite person BH (PdB) and face P ; repeat pattern of [1-4]

9--::

  All RHA ; turn P RH

17--::

  Circle4 and back

25--::

  1c+2c A&R ; cross opposite person RH | cross next opposite person LH', 2);
INSERT INTO 'dancecrib' VALUES (10059, '2017-09-03 23:44:12.377126+00', '2023-02-04 01:18:26.50016+00', 17896, 3, NULL, 'ace', '1-8::
    All join hands in a circle & Adv+Ret twice
9-16::
    All turn partner RH, turn partner LH
17-24::
    All join 2H with partner & slip step towards centre (2 bars), clap
    x4, slip step back, clap x4
25-32::
    All dance DoSiDo with partner;  Ladies dance clockwise, Men
    anticlockwise 1/4 round, passing partner & 1 more dancer RSh (ie
    Ladies on outside, Men inside)', 0);
INSERT INTO 'dancecrib' VALUES (5056, '2013-08-21 08:30:59.451176+00', '2023-02-04 01:19:38.968903+00', 7687, 3, NULL, 'ace', '1-8::
    1L followed by partner casts 1 place & crosses to 2nd place opposite
    sides, 2M+1L also 2L+1M turn RH
9-16::
    1L followed by partner casts down 1 place & crosses to 3rd place own
    sides, 3s+1s set facing on sides & 1s turn into double triangle
    position
17-24::
    1s dance Double Triangles & end with a petronella turn to end 1L
    between 2s & 1M between 3s facing down/up
25-32::
    1L+2s & 1M+3s Adv+Ret, 1s Petronella turn to 2nd place opposite
    sides & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (10066, '2017-09-03 23:44:32.517837+00', '2023-02-04 01:19:39.031007+00', 12983, 3, NULL, 'ace', '1-8::
    1s set & cross RH, cast 1 place & set advancing & turn about to face
    opposite sides (2s step up 5-6)
9-16::
    1s dance Double Triangles & end facing opposite sides (as at bar 9)
17-24::
    1s dance Figs 8, 1L round 2s, 1M round 3s passing 1st corner RSh to
    start. 1s end passing RSh to face 3rd corner
25-32::
    1s dance 6 bars of ''Hello-Goodbye'' setting & on bars 31-32 turn 3/4
    LH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (13075, '2020-08-10 00:19:21.435705+00', '2023-02-04 01:19:39.100812+00', 16700, 3, NULL, 'ace', '1-4::
    1s+3s turn partner 3/4 RH _while_ 2s+4s petronella turn & set
    (Ladies now BtoB in centre facing partner)
5-8::
    2s & 4s make arches & 1M & 3M followed by partners chase clockwise
    1/2 round dancing under arches
9-12::
    3s+1s petronella turn & set (in middle BtoB) _while_ 2s & 4s turn
    partner RH
13-16::
    1s & 3s make arches & 2M & 4M followed by partners chase clockwise
    1/2 round dancing under arches. (3s & 1s facing partner, drop hands)
17-24::
    3s+1s  dance 1/2 reel of 4 passing partner RSh to start; 1M & 3M
    followed by partners chase clockwise 1/2 round
25-28::
    All change places RH with corner, retain RH with corner, all join LH
    to form circle & all set;
29-32::
    All change places LH with next person, retain LH, all join RH to
    form circle & set
33-40::
    Ladies dance 1/2 RH across, turn partners LH into prom hold; all
    promenade clockwise 1/2 round. End 4 1 2 3
41-48::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9727, '2017-04-06 08:39:40.460771+00', '2023-02-04 01:19:39.176581+00', 12076, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across & LH across
9-12::
    1s+4s join NH with partner & dance towards each other.  1s+4s face
    own sides & 1M+4M NHJ set to 2M+3M as 1L+4L NHJ set to 2L+3L
13-16::
    1s+4s dance out of sides, 1s crossing in front of 4s.  1s dance to
    4th place, 4s to 1st place on own sides
17-22::
    2s+3s cast up/down, meet partner at ends facing down/up NHJ.   2s+3s
    change places, 2s making arch & 3s dancing under
23-24::
    2s set turning to face up, 3s set & 4s set advancing to face up
25-32::
    4s+3s+2s dance allemande
33-40::
    2L+3M+4L+1M dance reel of 4
41-48::
    2M+3L+4M+1L dance reel of 4
49-56::
    All 1/2 turn partners RH, balance across with partner, continue RH
    turn to own sides & all set
57-64::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5059, '2013-08-21 08:30:59.478963+00', '2023-02-04 01:19:39.197441+00', 7568, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cast to 2nd place & dance 1/2 Figs of 8 (Lady round 2s
    & Man round 3s) as 2s+3s set & cross RH (facing out)
9-16::
    1s dance 1/2 reels of 3 on sides giving RSh to 2nd crnrs, 1s dance
    1/2 reels of 3 across (Lady up Man down) & 1s turn LH to face 2nd
    crnrs
17-24::
    1s dance modified Pass+Turn with 2nd corners (pass corners RSh but
    corners turn LH in centre), 1s turn LH & dance modified Pass+Turn
    with 1st corners with all 3 couples end in centre for Allemande
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5060, '2013-08-21 08:30:59.48867+00', '2023-02-04 01:19:39.247695+00', 1773, 3, NULL, 'ace', '1-8::
    1L crosses down to dance reel of 3 on Men''s side,  with 1L  passing
    2M LSh. 1L crosses back to place from 1M''s place
9-16::
    1M dances across top to dance reel of 3 with 1L+2L on Ladies'' side,
    1L passing 2L LSh. 1L & 2L dance loops back to original place as 1M
    crosses back to 1st place own side
17-24::
    1s set, turn 2H, lead down below 2s & cast up to top
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (14486, '2021-12-18 01:43:44.571038+00', '2023-02-04 01:19:39.552565+00', 15536, 3, NULL, 'ace', '1-8::
    1s+2s+3s cross RH & set; 1s & 3s Petronella turn & set _while_ 2s
    pull back RSh & cast, dance between 1st / 3rd couples to original
    places
9-16::
    1s+2s+3s dance Weasel reel:
::
    1s+3s dance part reel of 4 up/down middle but when reaching either
    end they dance clockwise to top/bottom to re-enter reel _while_ 2s
    dance clockwise to replace dancer leaving the reel & all end where
    they started the reel
17-20::
    1M followed by 1L casts round 2L to 3rd place own side _while_ 3L
    followed by 3M casts up round 2M to 1st place own side
21-24::
    3s+2s+1s turn partner RH, 2s+1s finishing in centre facing up in
    prom hold.  3 2 1
25-32::
    2s+1s dance Allemande.  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5065, '2013-08-21 08:30:59.623985+00', '2023-02-04 01:19:39.584626+00', 14567, 3, NULL, 'ace', '1-8::
    2s & 4s set & turn RH, 2s lead up to top & cast to face 1st corners
    _while_ 4s lead down & cast up to face 1st corners
9-16::
    2s & 4s dance diagonal reels of 4 with 1st corners & end facing 1st
    corners
17-24::
    2s & 4s turn corners RH & partners LH, turn 2nd corners RH & partner
    LH to end in original places
25-32::
    1s+2s also 3s+4s Set+Link, 1s+4s also 3s+5s Set+Link.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (5066, '2013-08-21 08:30:59.638039+00', '2023-02-04 01:19:39.758174+00', 1780, 3, NULL, 'ace', '1-8::
    1L casts 1 place, turns 3M RH to end in 2nd place opp side, 1M casts
    & turns 3L RH to end between 3s in line across as 1L goes between 2s
9-16::
    2s+1s+3s set twice with 1s turning onto opposite sides, all set
    twice with 1s turning to face 1st corners
17-24::
    1s turn 1st corners RH, turn partners LH, 2nd corners RH & partners
    RH to 2nd place on own sides
25-32::
    2s+1s+3s set twice & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (8373, '2014-07-29 12:59:37.983002+00', '2023-02-04 01:23:08.324707+00', 15373, 3, NULL, 'ace', '1-8::
    1s set twice (option to pivot around on 2nd setting step), 1s dance
    in & cast to 2nd place.
9-16::
    1s dance RSh Reels of 3 across the dance, (Man with 2s & Lady with
    3s)
17-24::
    1s dance RH across (1L with 2s, 1M with 3s); all dance 6H round 1/2
    way
25-32::
    All set twice (option to pivot around on 2nd setting step), chase
    clockwise 1/2 way to own side', 0);
INSERT INTO 'dancecrib' VALUES (5063, '2013-08-21 08:30:59.519493+00', '2023-02-10 14:28:38.144423+00', 1776, 3, NULL, 'ace', '1-8::

    1s cross RH, cast 1 place, 1s+3s set & turn RH

9-16::

    1s+3s dance Allemande

17-24::

    1s cast up 1 place, cross LH, cast up to top, 1s+2s set & turn RH

25-32::

    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (15300, '2022-12-17 13:17:25.780023+00', '2022-12-17 13:22:47.438896+00', 11461, 1, 202, 'ace', '1--::

  G-Chain (face P, 1 bar per hand)

9--::

  1c+3c set advancing | turn opposite person BH opening into ; Circle4 L breaking to end in original places, 1M & 3M leading

17--::

  1c+3c & 2c+4c Intersecting R&L, 1c+3c crossing RH _as_ 2c+4c change places RH with P

25--::

  2c+4c LHA ; all chase one place cclw | all set (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (12389, '2019-12-05 01:29:36.839815+00', '2023-02-04 01:19:39.790137+00', 19691, 3, NULL, 'ace', '1-8::
    1s+3s dance R&L
9-16::
    2s+4s dance R&L
17-24::
    1s+3s 1/2 turn RH, pull back RSh & chase 1/4 round clockwise & dance
    in to face 4s/2s (Men between side couples, Ladies round 4M/2M)
25-32::
    1s+4s also 3s+2s dance RH across, drop hands, Men followed by
    partners chase clockwise round to original places
33-64::
    Repeat 1-32 with 2s+4s starting
65-72::
    Ladies dance Fig 8, in front of partner, behind next Man, behind
    partner to places
73-80::
    Men repeat, dancing in front of partner, behind next Lady, behind
    partner to places
81-88::
    All Grand Chain 1/2 way (1 bar per hand) & all turn partners (birl)
    4 bars
89-96::
    Repeat 81-88 back to original places', 0);
INSERT INTO 'dancecrib' VALUES (5067, '2013-08-21 08:30:59.648015+00', '2023-02-04 01:19:39.81139+00', 11514, 3, NULL, 'ace', '1-8::
    1M followed by partner casts 1 place, crosses, casts behind 3L+4L &
    crosses to 4th place own side (partner to 4L place) 2s+3s+4s step up
    bars 7-8
9-16::
    2s+3s+4s+1s circle 8H round & back
17-24::
    2s+3s also 4s+1s dance RH across & LH back
25-32::
    2s+3s+4s+1s turn RH for 4 bars & LH for 4 bars
33-40::
    1s cross up between 4s, dance up behind 3s & dance 1/2 Fig of 8 up
    round 2s to end in 2nd place own side. 2 1 3 4

{{explanation}}
2nd time through end 1s dancing to bottom place', 0);
INSERT INTO 'dancecrib' VALUES (5072, '2013-08-21 08:30:59.968776+00', '2023-02-04 01:19:40.39051+00', 14249, 3, NULL, 'ace', '1-8::
    All set, 3/4 turn RH, set & 3/4 turn RH into prom hold facing down
9-16::
    4s followed by 3s+2s+1s cross at bottom, cast up to top & dance down
    to places
17-24::
    All dance reflection reels of 4 (1s & 3s in & down to start)
25-32::
    1s dance down the middle & turn out to 4th places _while_ 2s+3s+4s
    step back & up, all advance & turn right about to places', 0);
INSERT INTO 'dancecrib' VALUES (14113, '2021-07-07 00:19:13.003956+00', '2023-02-04 01:19:40.501371+00', 1789, 3, NULL, 'ace', '{{explanation}}
Fig. 1

1-8::
    Ladies advance, 1L+3L turning to Right to form diag line (1L+2L &
    4L+3L facing each other) & set. Ladies dance 1/2 reel of 4. End
    facing opp. man
9-12::
    Ladies dance out and into opp. man''s place (4 bars). Men dance in
    and turn to face Ladies (11-12)
13-16::
    Couples set to each other and turn to form square set
17-32::
    Repeat 1-16 back to places (1L+3L turning to Left to form line on
    other diagonal)
33-64::
    Repeat 1-32 with Men making the diagonal lines

{{explanation}}
Fig. 2

::
    Ladies step back and kneel
1-8::
    Men set, petronella turn, double setting or high cuts
9-32::
    Repeat 1-8 back to places.  Bar 32 Men finish facing partners (who
    stand up)

{{explanation}}
Fig. 3

1-8::
    All set twice; Men turn partner RH & move on anticlockwise to next
    Lady
9-32::
    Repeat 3 more times, Men turning each Lady until back in original
    places

{{explanation}}
Fig. 4

::
    Men kneel
1-4::
    Ladies dance 1 place round anticlockwise towards next Man & they set
9-16::
    Repeat 3 more times until back in original places. Men stand up

{{explanation}}
Fig. 5

1-4::
    All set to partner & turn 1/4 RH into allemande hold facing
    anticlockwise
5-8::
    All promenade 1/2 round & form »longways set« 3 2 4 1
9-24::
    All dance full Petronella figure (set to partner & Petronella turn 4
    times)
25-32::
    All set to partner & turn 1/4 RH into allemande hold facing
    anticlockwise; All promenade 1/2 round & reform original square set', 0);
INSERT INTO 'dancecrib' VALUES (5073, '2013-08-21 08:30:59.978643+00', '2023-02-04 01:19:40.650682+00', 1790, 3, NULL, 'ace', '1-8::
    1M+2L & 1L+2M turn RH 1.1/2 times end on sides with 1s in 2nd place
    opposite sides, 1s+2s turn LH 1s end on own sides in centre facing
    up
9-16::
    1s dance up, set, cast down 1 place & turn 2H to face 1st corners
17-24::
    1s set to & turn 1st corner; set to & turn 2nd corner ending in 2nd
    place opposite sides
25-32::
    2s+1s+3s Adv+Ret; 1s turn 2H 1.1/2 times to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (13076, '2020-08-10 00:19:23.170397+00', '2023-02-04 01:19:41.041043+00', 1791, 3, NULL, 'ace', '{{explanation}}
(Longways set for as many as will)

1-8::
    1s+2s dance RH across & LH across back to place
9-16::
    1s slip step down middle (2 bars) & back (2 bars) & cast (2s step
    up)
17-24::
    2s & 1s join RH with partner, balance forward & back, Lady turns
    under Man''s raised arm to change sides; repeat joining LH
25-32::
    All turn dancer opp to right RH; all turn partner LH

{{explanation}}
Note:  1s remain 1s as they progress down line until reaching bottom.  Crib based on English Country Dance videos', 0);
INSERT INTO 'dancecrib' VALUES (5074, '2013-08-21 08:30:59.997954+00', '2023-02-04 01:19:41.234668+00', 1793, 3, NULL, 'ace', '1-8::
    1s set, cast 2 places (2s+3s step up 3-4)); 1s set, cast up 1 place
    to 1L between 2s facing down, 1M between 3s facing up (3s step down
    7-8)
9-16::
    2s+1s+3s set, 2s+3s set again _while_ 1s Petronella turn to sides,
    1L between 2M+3M, 1M between 2L+3L; 2s+1s+3s set twice
17-24::
    1s dance 6 bar reels of 3 on sides giving RSh to 2nd corner, 1s
    cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5075, '2013-08-21 08:31:00.006037+00', '2023-02-04 01:19:41.26666+00', 1796, 3, NULL, 'ace', '1-8::
    1s Petronella to opposite sides _while_ 2s step up slightly, cross
    RH, cast to right into middle & change places RH (up/down)
9-16::
    1s Petronella back to 2nd place own sides _while_ 2s cast to right,
    cross RH, cast to right into middle & turn RH into 1st place
17-24::
    1s dance RSh reels of 3 on sides & end facing 4th corner as 2s & 3s
    loop round to places
25-32::
    1s dance Pass+Turn with 4th corners & pass RSh to face 1st corners,
    dance Pass+Turn with 1st corners to end in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5076, '2013-08-21 08:31:00.014028+00', '2023-02-04 01:19:41.292789+00', 1799, 3, NULL, 'ace', '1-8::
    1s dance RSh reels on own sides
9-16::
    1s lead down the middle & back to top
17-24::
    1s+2s dance Allemande 1s end with Lady between 2s facing down & Man
    between 3s facing up
25-32::
    All set twice 1s turning to left to 2nd place own sides (reverse
    petronella turn), all set twice', 0);
INSERT INTO 'dancecrib' VALUES (8565, '2015-02-13 12:47:39.899094+00', '2023-02-04 01:19:41.322899+00', 1804, 3, NULL, 'ace', '1-8::
    1s+2s  1/2 Espagnole figure, 1s end in 2nd place 1L facing up, 1M
    down.  1s turn LH to face 1st corners
9-16::
    1s set to 1st corner, 2nd corner, 3rd corner & 4th corner finishing
    in middle facing opp. sides (LSh to LSh)
17-24::
    RH across (1L+2s, 1M+3s), 1s dance through 2nd place own side to
    swap ends for LH across. 1s end in 2nd place own side
25-32::
    1s set, cast off (3s step up).  All 3 couples turn partners 2H', 0);
INSERT INTO 'dancecrib' VALUES (4446, '2013-08-21 08:30:48.997675+00', '2023-02-04 01:21:50.60081+00', 1792, 3, NULL, 'ace', '1-8::
    1s turn RH, cast to 2nd place, turn LH to face 1st corners
9-16::
    1s turn 1st corner, partner, 2nd corner, & partner to face 1st
    corners
17-24::
    1s set to & turn 1st corner 2H, set to & turn 2nd corner
25-32::
    1s dance Reel of 3 on opposite sides giving LSh to 1st corner &
    cross back to own sides', 0);
INSERT INTO 'dancecrib' VALUES (15301, '2022-12-18 01:13:55.460137+00', '2022-12-18 01:30:56.258898+00', 21200, 1, 202, 'ace', '1--::
  1c set | dance down to bottom and cast up to 2pl (2c up on [3-4] (2,1,3)
9--::
  3C Set&Rotate (3,1,2)
17--::
  1c turn RH 1¼ ; dance RSh round 2cnrs[pos] to 2plx (3,1x,2)
25--::
  Pick-up Chain, 3c crossing RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15304, '2022-12-18 10:24:41.123209+00', '2022-12-18 11:11:58.781758+00', 15525, 1, 202, 'ace', '_Strathspey_  

1--::

  All set | turn P BH. 1W faces out ; 1c cast off to 3plx (2c+3c up) (2,3,1x)

9--::

  All set | turn P BH. 1W faces out ; 1c cast up to 1pl (2c+3c down) (1,2,3)



_Reel_  

17--::

  1c+2c set | ½ RHA ; 2c+1c set | cross RH (2,1,3)

25--::

  Circle6 and back (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (5077, '2013-08-21 08:31:00.022098+00', '2023-02-04 01:19:41.464602+00', 11897, 3, NULL, 'ace', '1-8::
    2s & 3s dance 1/2 Fig of 8 round end couples & ending in middle 2s
    facing down 3s up, 2s+3s set & dance LH across 1/2 way.  1 3 2 4
9-16::
    All dance reels of 4 on sides (2s & 3s pass corner RSh to start)
17-24::
    1s+3s also 2s+4s change places RH on sides, all set, 3s+1s also
    4s+2s dance RH across
25-32::
    All circle 8H round & back.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (11185, '2018-09-30 22:19:38.937338+00', '2023-02-04 01:19:41.636732+00', 1806, 3, NULL, 'ace', '1-8::
    1s set, cross RH; 1s+2s set then 1M casts to 2L place, 2M casts up
    to 1M place & Ladies dance across, 1L to original place, 2L to
    partner''s place
9-16::
    1s+2s dance RH across end 1s on Ladies'' side, 2s on Men''s; 1s+2s
    set, turn partners 2H to end facing across NHJ
17-24::
    1s+2s dance the Rondel across, all turning to face partner (1s on
    Men''s side, 2s on Ladies'', Men have partner on their left)
25-26::
    1L+2L cross RH curving round to face partner in centre _while_ Men
    set to each other (1st step) then turn to face partner in centre
    (2nd step)
27-28::
    1s turn 2H to face up _while_ 2s 1/2 turn 2H to face down
29-32::
    2s+1s circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (13987, '2021-05-03 00:19:23.669496+00', '2023-02-04 01:19:41.704734+00', 13778, 3, NULL, 'ace', '1-4::
    1L dances down diagonally to 4M''s place, 2L, 3L, 4L follow dancing
    up side to start, 4L ends at the top of Ladies'' side _while_
::
    1M dances down diagonally to 4L''s place; 2M, 3M, 4M follow, dancing
    up side to start. 4M ends at top of Men''s side (Ladies cross in
    front of partner in centre). All end facing clockwise, 2s+3s join RH
    in centre & LH with neighbours on corners in »flattened« double RH
    across (St Andrew''s cross)
5-8::
    All dance 1/2 RH across, 1s end at top own sides, 4s at bottom
    opposite sides, all facing down on diagonals
9-16::
    4L dances up Men''s side to top, 3L, 2L, 1L follow, i.e. down
    diagonal to 4M''s place & up Men''s side _while_
::
    4M dances up Ladies'' side to top, 3M, 2M, 1M follow, i.e. down
    diagonal to 4L''s place, & up Ladies'' side to end (4) (3) (2) (1);
    all turn partners RH
17-20::
    4s+2s (1st & 3rd places) dance slow 1/2 RH across to diagonally
    opposite places own sides (touch hands only in 18-19)
21-24::
    3s+1s (2nd & 4th places) dance similar slow 1/2 LH across.  2 1 4 3
25-32::
    1s & 4s dance 1/2 Figs 8 (1s cross LH out through top, 4s cross RH
    out through bottom) & cast to centre; 1s+4s dance 1/2 R&L.  End 2 4
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (5080, '2013-08-21 08:31:00.132907+00', '2023-02-04 01:19:41.943871+00', 1814, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    Ladies dance RH across 1/4 way, turn next Man LH, dance RH across
    1/4 way & turn next Man LH to end beside him
17-32::
    1s+3s dance in turning to face their crnrs & set, all dance full
    reels of 4 across dance, 1s+3s dance out thru side couples back to
    pl as at bar 16
33-40::
    Men dance LH across 1/4 way, turn next Lady RH, dance LH across 1/4
    way & turn next Lady RH to end beside her
41-56::
    2s & 4s repeat bars 17-32
57-68::
    1s+3s set, 3/4 turn partners RH & dance 1/2 reel of 4 up & down
    dance, 1s+3s 3/4 turn partners LH & set
69-80::
    2s+4s repeat bars 57-68
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5081, '2013-08-21 08:31:00.175056+00', '2023-02-04 01:19:41.967563+00', 7387, 3, NULL, 'ace', '1-8::
    1s & 4s set & cast in 1 place (2s & 3s step down/up bars 3-4); 1s+4s
    dance 4 bars of Espagnole.  2 4 1 3
9-16::
    2s & 3s set, cast in 1 place (4s & 1s step down/up bars 11-12);
    2s+3s dance 1/2 RH across & all 4 couples set.  4 (3) (2) 1
17-24::
    4s+3s also 2s+1s dance 1/2 R&L; 4s+1s dance 1/2 R&L to end 3 1 4 2
25-32::
    RSh reels of 4 on sides.', 0);
INSERT INTO 'dancecrib' VALUES (5082, '2013-08-21 08:31:00.18372+00', '2023-02-04 01:19:41.995718+00', 10073, 3, NULL, 'ace', '1-8::
    1s dance reflection reels on opposite sides ending in prom hold
    facing down
9-16::
    1s dance 1/2 reel of 3 across with 2s (RSh to 2M), 1/2 reel of 3
    with 3s (LSh to 3L) ending in middle facing down between 3s
17-24::
    1s cast up to 1st place opposite sides & dance 1/2 Fig of 8 round
    2s.  1 (2)(3)
25-32::
    1M+2L & 1L+2M petronella turn & set, petronella turn & set.  2
    (1)(3)
33-40::
    1M+3M & 1L+3L petronella turn & set, petronella turn & set.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5083, '2013-08-21 08:31:00.19188+00', '2023-02-04 01:19:42.033305+00', 1816, 3, NULL, 'ace', '1-8::
    1s & 2s turn partners RH, set & 1s cast to 2nd place as 2s dance up
9-16::
    2s+1s+3s dance reel of 3 on sides with 1s crossing down to 3rd place
    opposite sides (2s out & down to pass 3s - LSh M''s side & RSh L''s
    side)
17-24::
    1s cross RH, cast RSh round 3rd corner to meet partner & turn LH
    1.1/2 times to face 1st corners _while_ 2s+3s set & dance RH across
    1/2 way & chase clockwise to own places
25-32::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh & repeat
    with 2nd corners 1s ending in 2nd place opposite sides
33-40::
    3s+1s+2s turn RH & chase clockwise 1/2 way to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5084, '2013-08-21 08:31:00.200111+00', '2023-02-04 01:19:42.056095+00', 1817, 3, NULL, 'ace', '1-8::
    1s cross RH & set, cross down LH to 2nd place own side & set (2s
    step up 5-6)
9-16::
    1s turn RH & dance out own sides, cast round 3rd corner, dance into
    centre, pass RSh to face opp sides in Double Triangle position & set
17-20::
    1st corners persons dance along sides to 2nd corner (pstn) _while_
    1s dance out to 1st corner (pstn) _while_ 2nd corner persons dance
    into centre passing RSh to end with 3M facing up & 2L down in Crown
    Triangle position & all set
21-24::
    Original 1st corner persons cross to opposite sides _while_ 1s pass
    RSh to face own sides in Double Triangle position _while_ original
    2nd corner persons dance out to 2nd corner positions opposite sides
    & all set.  (3)1(2)
25-32::
    1s dance 1/2 diag reel of 4 with 3rd corners (pstns), 1s pass LSh to
    dance 1/2 diag reel of 4 with 4th corners (pstns)', 1);
INSERT INTO 'dancecrib' VALUES (5085, '2013-08-21 08:31:00.209793+00', '2023-02-04 01:19:42.268087+00', 1818, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, 1s lead down below 3s & cast up to
    2nd place
9-16::
    1s+3s circle 4H round to left, 1s cross up RH & cast 1 place to face
    1st corners
17-24::
    1s turn 1st corner 2H & end between corners, 2s+1s+3s set & 1s face
    2nd corners, 1s turn 2nd corners 2H ending between corners & all set
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners &
    cross passing RSh to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5087, '2013-08-21 08:31:00.225812+00', '2023-02-04 01:19:42.332213+00', 12876, 3, NULL, 'ace', '1-8::
    1s+2s walk RH across 1/2 way, set, walk RH across 1/2 way & set
9-16::
    1s+2s repeat above Fig
17-24::
    2s+3s+4s join both hands to make arches & 1L dances under arches
    _while_ 1M dances down behind own side, 1M dances up under arches as
    1L dances up own side
25-32::
    1s dance under arches to bottom & all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (14114, '2021-07-07 00:19:13.950187+00', '2023-02-04 01:19:42.359271+00', 1823, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All set & dance 8H round to left 2 places; 4 Men (at top) & 4 Ladies
    (at bottom) circle 4H round to left
9-16::
    All set & dance 8H round to left 2 places to end (4) (3) (2) (1);
    4s+3s also 2s+1s circle 4H round to left

{{title}}
Reel

1-8::
    All dance reels of 4 on sides
9-12::
    4s+2s dance dance 1/2 R&L, set _while_ 3s+1s set & dance Petronella
    turn into centre
13-16::
    3s+1s dance Petronella turn to own side & all 4 couples set.  End 2
    3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13451, '2020-12-02 01:22:21.539152+00', '2023-02-04 01:23:13.537028+00', 7164, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up); 1s turn 1.1/2 LH to face 1st corners
9-16::
    1s set to & turn 1st corners 2H; set to & turn 2nd corners 2H to end
    in 2nd place opp sides facing 1st corner
17-24::
    1s dance Fig 8 round 1st & 2nd corners (LSh to 1st corner to start)
25-32::
    1s+3s set, 1s cross down to 3rd place own side _while_ 3s cast up to
    2nd place; 2s+3s also 1s+4s dance RH across
33-40::
    1s+4s dance the Knot.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5088, '2013-08-21 08:31:00.23397+00', '2023-02-04 01:19:42.393185+00', 1826, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 2nd place, 1s dance RH across (1L with 2s, 1M
    with 3s) 1s end passing RSh into Double Triangle position up/down
    (1M facing 2s & 1L facing 3s)
9-16::
    All set & advance turning about into Inverted Double triangle
    position, all set & 1s pass RSh to face 1st corners _while_ 2s & 3s
    return to corners
17-24::
    1s dance 1/2 RSh reels of 3 on sides & end facing 2nd corner pstn,
    1s dance 1/2 LSh reels of 3 across & end facing 3rd corner pstn
25-32::
    1s dance 1/2 RSh reels of 3 on own sides & end facing 4th corner
    pstn,1s dance 1/2 LSh reels of 3 across ending in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5089, '2013-08-21 08:31:00.242212+00', '2023-02-04 01:19:42.427307+00', 1829, 3, NULL, 'ace', '{{explanation}}
Each couple dance 32 bars. A New Couple starts after 16 bars (ie on bars 1, 17, 33, 49 & 65)

1-8::
    1s turn out & join hands with 2s on sides & set, 1s 1/2 turn 2s on
    sides & dance 1/2 Figs of 8 round 2s
9-16::
    1s dance reels of 3 on opposite sides with 2s+3s dancing in between
    3s to start & ending by 1/2 turning 3s
::
    2s (at top) now start repeating the dance from bar 1 _while_
    original 1s continue as follows: -
17-24::
    (New Couple starts as at bar 1) as 1s face out NHJ with 4s & set, 1s
    1/2 turn 4s on sides, cross RH to own side & cast down to 5th place
25-32::
    5s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (9728, '2017-04-06 08:39:40.98379+00', '2023-02-04 01:19:42.461356+00', 1830, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on sides (1s in/down) finishing
    BtoB in centre 2nd place facing own sides (2s in 1st place)
9-16::
    2s+1s+3s dance Reverse Double Triangles (1s move to Left
    throughout). 1s end in centre BtoB, Man facing up, Lady down
17-24::
    1M+2s & 1L+3s dance RH across (3 bars), 1s pass RSh to dance LH
    across with other couple (3 bars), 1s end in 2nd place opp sides.
    All set.
25-32::
    1s dance 1/2 Fig 8, 1M up round 2s, 1L round 3s to 2nd place own
    sides.  1s turn RH   2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (9191, '2016-06-16 22:41:43.76815+00', '2023-02-04 01:19:42.497691+00', 14183, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up), 1s dance 1/2 Fig 8 round 3s
    finishing facing 1st corners
9-16::
    1s set to 1st corners, dance RSh round partner to face 2nd corners,
    1s dance 1/2 reel of 4 with 2nd corners finishing facing 4th corner
    position (2nd corner person)
17-24::
    1s set to 4th corners, dance RSh round partner to face 1st corners,
    1s dance 1/2 reel of 4 with 1st corners, passing RSh to face out in
    2nd place (3) 1 (2)
25-32::
    »Dragon''s Chains«:
::
    _25-26_     1s cast to Left as 2nd corners cross RH
::
    _27-28_     1s 1/2 turn corners LH (1L+2L also 3M+1M) finish in 2nd
    place own side, facing out
::
    _29-30_     1s cast to Right as 1st corners cross LH
::
    _31-32_     1s 1/2 turn corners RH (3L+1L also 1M+2M)   End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5090, '2013-08-21 08:31:00.251877+00', '2023-02-04 01:19:42.643507+00', 1834, 3, NULL, 'ace', '1-8::
    1s dance RSh reels of 3 on own sides
9-16::
    1s+2s+3s dance RH across, LH back
17-24::
    1s lead down the middle & back (1s end facing 1st corners)
25-32::
    1s set & turn 1st corners 2H, set & turn 2nd corners 2H (1s end
    between 2s & 3s on opposite sides)
33-40::
    2s+1s+3s Adv+Ret, 1s turn RH 1.1/2 times back to own side 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (5091, '2013-08-21 08:31:00.261941+00', '2023-02-04 01:19:42.857767+00', 8133, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on opposite sides with 1s ending 1st place
    opposite sides
9-16::
    1L followed by partner casts 1 place, crosses to own side & turn LH
    to end side by side in the centre facing up
17-24::
    1s set to 2s, set turning inwards to face down, set to 3s & set
    passing LSh to face 1st corners
25-32::
    1s turn 1st corners RH, pass RSh & turn 2nd corners RH & pass RSh to
    2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (5092, '2013-08-21 08:31:00.270115+00', '2023-02-04 01:19:42.873317+00', 1836, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    Change places RH with opposite partner cross back LH, change places
    with partner RH & back LH
9-16::
    Ladies turn RH 1.3/4 times to face opposite Man & set, all 3/4 turn
    2H & Ladies turn LH back to places.
17-24::
    Men turn RH 1.1/4 times to face opposite Lady & set, all turn 1.1/4
    times 2H & Men turn RH back to places
25-32::
    All set twice, all turn opposite person RH 1.1/2 times to face new
    couple', 0);
INSERT INTO 'dancecrib' VALUES (5093, '2013-08-21 08:31:00.276344+00', '2023-02-04 01:19:42.886276+00', 9983, 3, NULL, 'ace', '1-8::
    1s+2s 1/2 turn RH & 2s followed by 1s lead down for 2 steps, set to
    partners & dance up
9-16::
    1s cast to 2nd place opposite sides & dance reflection reels of 3 on
    sides (1s in & down)
17-24::
    1s dance 1/2 Fig of 8 round 3s _while_ 2s cast to 2nd place opposite
    sides & cross up to top places, 2s+1s+3s turn RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8566, '2015-02-13 12:47:40.205301+00', '2023-02-04 01:19:42.925873+00', 15946, 3, NULL, 'ace', '1-8::
    1L followed by partner casts 2 places & crosses to 3M place, 1M to
    3L place _while_ 2s+3s set & cross up (no hands), 3s+1s dance RH
    across, 1L finish facing out
9-16::
    1L followed by partner casts up 1 place & crosses to 2L place, 1M to
    2M place (3s step down 11-12), 2s+1s dance LH across, 1L finish
    facing out
17-20::
    1s dance 1/2 Alternating Tandem reel of 3 across with 2s (1L  LSh to
    2M in 1L place)
21-24::
    1s dance 1/2 Alternating Tandem reel of 3 across with 3s (1M LSh to
    3L in 3M place) ending 2nd place own side    2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5095, '2013-08-21 08:31:00.321382+00', '2023-02-04 01:19:42.946612+00', 1841, 3, NULL, 'ace', '{{explanation}}
3 Couple Circles

1-8::
    All circle 6H round & back
9-16::
    All dance DoSiDo with partner & turn partner RH
17-24::
    All dance RH across, Lady (whose hand is underneath) dances out
    under arch into prom hold with next partner followed by next Lady
    etc
25-32::
    All Promenade with new partners anywhere round the room & meet with
    another 2 couples to start again', 0);
INSERT INTO 'dancecrib' VALUES (13612, '2021-02-04 01:19:27.72448+00', '2023-02-04 01:19:43.238404+00', 15241, 3, NULL, 'ace', '1-8::
    All Petronella turn into centre & set; 1s+2s & 4s+5s turn partner
    1/4 LH & each 2 couples chase anticlockwise 1/2 round _while_ 3s
    turn LH to face 1st corner pairs (3L facing 2M+1M & 3M facing 5L+4L)
9-14::
    3L+2M+1M & 3M+5L+4L dance 1/2 RH across, corner pairs dance LH
    across
15-16::
    3L+2M+1M & 3M+5L+4L dance 1/2 RH across, 3s pass RSh to face 2nd
    corner pairs
17-24::
    3s repeat 9-16 with 2nd corner pairs, 3s pass LSh to 3rd place own
    side
25-32::
    1s+3s & 5s+4s dance 1/2 R&L; 2s (at top) turn RH _while_ 3s+1s+4s+5s
    turn partner 1.1/2 RH. 3 2 1 4 5
33-40::
    Bottom 3 couples (1s+4s+5s) dance 3 couple Poussette.  End 2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (15302, '2022-12-18 02:00:55.668471+00', '2022-12-18 02:06:00.032618+00', 21201, 1, 202, 'ace', '1--::

  1c+2c+3c set | Petronella turn to midline ; 2c set | change places LH into BtoB with P

9--::

  1W,1M+2M,2W+3W,3M Reel4 on midline in tandem (with lead change)

17--::

  All set | Petronella turn to opposite sides (to 1x,2x,3x) ; 2c+3c changes places on sides, 3c in and up | 1c+3c repeat [21-22], 3c out and up (3x,1x,2x)

25--::

  3C Set&Link twice (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15305, '2022-12-18 12:33:52.00282+00', '2022-12-18 12:36:11.443891+00', 15524, 1, 202, 'ace', '1--::

  1c & 4c cast inwards (2c & 3c step out) ; 1c & 4c dance BtoB (2,1,4,3)

9--::

  1c-4c ½ R&L ; 4c+1c set| cross RH (2,4,1,3)

17--::

  Reels4 on sides

25--::

  2c+4c RHA ; LHA _while{8}_ 1c+3c LHA ; RHA (2,4,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (15319, '2022-12-19 01:19:32.931625+00', '2023-02-04 01:19:43.255893+00', 21177, 3, NULL, 'ace', '1-8::
    1s+4s turn RH (birl); 1s+4s cast down/up & cross RH (2s+3s step
    up/down on bars 5-6).
9-16::
    2s+3s repeat 1-8
17-20::
    1s+2s & 3s+4s dance right RH across
21-24::
    2s+3s dance LH across, finish 2M+3M facing up, 2L+3L facing down.
    (1) (2) (3) (4)
25-28::
    2M followed by 3M dance 1/2 Tandem Reel across with 1s (LSh to 1L)
    _while_ 3L followed by 2L dance 1/2 Tandem Reel across with 4s (LSh
    to 4M) to finish 1 3 2 4.
29-32::
    1s+3s & 2s+4 Set+Link.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (12076, '2019-08-30 09:54:07.000601+00', '2023-02-04 01:19:43.300093+00', 19079, 3, NULL, 'ace', '1-4::
    1s+3s change places RH on sides _while_ 2s petronella turn to 2L
    between 3s facing down, 2M between 1s facing up.  All set
5-8::
    3s+1s cross RH _while_ 2s petronella turn to 2nd place opp sides.
    All set on sides.  (3)(2)(1)
9-16::
    1s followed by 2s+3s lead down. Bar 12 Ladies dances under partner''s
    arm to change sides.  All lead up to end 3 2 1
17-24::
    All dance Grand Chain (3s cross at top to start)
25-32::
    2s+1s (bottom 2 couples) dance Espagnole.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5099, '2013-08-21 08:31:00.439137+00', '2023-02-04 01:19:43.358981+00', 1847, 3, NULL, 'ace', '1-8::
    1s+2s turn 1.1/2 times on sides (Ladies LH & Men RH), 1s+3s turn
    1.1/2 times on sides using other hand
9-16::
    2s+3s+1s dance reels of 3 on sides (2s in & down to start, 3s out &
    up)
17-24::
    2s+3s+1s Grand Chain
25-32::
    1s cross up for 1/2 Fig of 8 round 3s, lead up to top, cross & cast
    to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (5100, '2013-08-21 08:31:00.447272+00', '2023-02-04 01:19:43.390873+00', 1848, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on opposite sides 1s ending in
    1st place opposite sides
9-16::
    1s turn 2s with nearer hand on sides 1.1/2 times, 1s cross to turn
    (once) 3s on own side (with other hand) 1s end facing 1st corner
17-24::
    1s set to 1st corners, pass by the right, set to 2nd corners, pass
    by the right to BtoB position in centre Man facing up & Lady down
25-32::
    1M dances up & casts to 2nd place own side as 1L dances down & casts
    up to 2nd place own side, 1L dances RH across with 2s & 1M with 3s', 0);
INSERT INTO 'dancecrib' VALUES (5101, '2013-08-21 08:31:00.456982+00', '2023-02-04 01:19:43.4124+00', 5693, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L+4L dance across top of set, down behind Men,
    across the bottom & back to places
9-16::
    Men repeat above Fig
17-24::
    All circle 8H round & back
25-32::
    All Adv+Ret for 2 steps, 1s dance down to bottom', 0);
INSERT INTO 'dancecrib' VALUES (5097, '2013-08-21 08:31:00.424844+00', '2023-02-10 13:42:25.034878+00', 1843, 3, NULL, 'ace', '1-8::

    1s cross down & cast up behind 2s, 1M+2L lead across between 1L+2M,

    Lady casts up Man down & dance back to Ladies'' side

9-16::

    1L+2M lead across between 2L+1M, Lady casts down, Man up & dance

    back Man''s side. 2s cross down & cast up behind 1s

17-24::

    1M+2L pass RSh turning to right to face each other, pull back RSh &

    dance out to original places, 1L+2M repeat this Fig

25-32::

    1s+2s dance the Tournee :

::

    1s+2s dance into prom hold (Men with prtnr on right, 1s face M''s

    side & 2s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies

    into middle, both couples turn 1.1/2 times (2s RH, 1s LH) & dance

    out to places', 0);
INSERT INTO 'dancecrib' VALUES (5103, '2013-08-21 08:31:00.473085+00', '2023-02-04 01:19:43.464011+00', 7694, 3, NULL, 'ace', '1-8::
    All Set+Link for 3 twice
9-16::
    2s followed by 1s dance double Fig of 8 round 3s to end 3 1 2 on
    opposite sides
17-28::
    3s+1s+2s dance 3 couple R&L
29-32::
    All set & cross RH.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5105, '2013-08-21 08:31:00.49128+00', '2023-02-04 01:19:43.636101+00', 1853, 3, NULL, 'ace', '1-8::
    1s+2s+3s cross RH, set & chase 1/2 way clockwise
9-16::
    1L+2M cross RH, 1M+2L also 1L+3L cross LH, 3L+2M also 3M+1M cross
    RH, 3M+2L cross LH.  1 2 3
17-24::
    1s set, cast 1 place& dance RH across (Man with 3s, Lady with 2s)
25-32::
    2s+1s+3s circle 6H left for 2 bars, set, circle right & set on sides', 0);
INSERT INTO 'dancecrib' VALUES (5106, '2013-08-21 08:31:00.499824+00', '2023-02-04 01:19:43.670942+00', 8981, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s cross down between 3s & cast up to 2nd
    place opposite sides
9-16::
    1s set & turn 3/4 LH, 1L+2s also 1M+3s dance RH across 1s end facing
    1st corners
17-24::
    1s set to 1st corners & turn 2H, set to 2nd corners & turn 2H & 1s
    end 2nd place opposite sides
25-32::
    2s+1s+3s circle 6H round to left & 1s cross RH to own sides 2nd
    place', 0);
INSERT INTO 'dancecrib' VALUES (5104, '2013-08-21 08:31:00.481313+00', '2023-02-09 18:27:18.195453+00', 1852, 3, NULL, 'ace', '1-8::

    1s turn 2H, cast 1 pl & turn 2H to face 2L _while_ 2M dances down &

    turns 3L 2H to end in 3rd pl _while_ 3M dances up behind 2M to turn

    2L 2H

9-16::

    1s make an arch as 2L dances down to face partner, 1s+2s turn 2H &

    open out to face diagonally with Lady on Mans left, 2s make an arch

    & change places with 1s, 1s+2s turn 2H & open out to face 3M/3L

    diagonally with Lady on Mans right

17-24::

    2s make an arch & change places with 3M _while_ 1s make an arch &

    change places with 3L, 2s turn 2H _while_ 1s 1/2 turn 2H to face

    diagonally _while_ 3s dance round each other LSh to end with 3L

    facing 2s & 3M facing 1s, 2s+3L also 1s+3M circle 3H round to left

    for 2 steps & 3s dance to 2nd place on own side _while_ 2s end in

    centre in top place facing down & 1s in centre in 3rd place facing

    up

25-32::

    All set, circle 6H round to left & spiral out to place on last 2

    bars to 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5102, '2013-08-21 08:31:00.46505+00', '2023-02-09 18:35:52.561426+00', 1851, 3, NULL, 'ace', '1-8::

    1s turn RH, 1L crosses below 2M & casts up to face 2L _while_ 1M

    crosses & casts round 2L to face up in centre of dance

9-16::

    1M nearer hands joined with 2s & set twice _while_ 1L sets once

    holding 2L by LH & once holding 2M by LH, 1s+2s dance RH across

17-24::

    1s & 2s lead down & back 2s ending at top & 1s in centre 2nd place

25-32::

    1s dance reflection reels of 3 on own sides (1s dance up between 2s

    to start)', 0);
INSERT INTO 'dancecrib' VALUES (15303, '2022-12-18 02:13:03.232008+00', '2022-12-18 02:15:02.168662+00', 21202, 1, 202, 'ace', '1--::

  1c+2c set | cross RH ; set | turn P RH into promhold

9--::

  2C Promenade

17--::

  1c cross RH | cast off (2c up) ; ½ Fig8 up round 2c (2,1)

25--::

  R&L (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (2428, '2012-01-22 19:29:38.181827+00', '2022-12-18 13:06:50.020235+00', 2918, 1, NULL, 'ace', '1–::

  1c dance in touching NH & cast off (2c up) ; ½Reels3 across (w up, M down)

9–::

  1c dance between 3c and cast up on opposite sides ; ½Reels3 across (M up, W down)

17–::

  2c+1c R&L

25–::

  1c dance down between 3c and cast up ; 2c+1c+3c turn RH', 3);
INSERT INTO 'dancecrib' VALUES (15307, '2022-12-18 16:10:17.264026+00', '2022-12-19 00:41:47.884815+00', 21204, 1, 202, 'ace', '1--::

  1c set | cross RH ; set | turn P LH. 1M faces 2M, 1W behind 1M

9--::

  Reel3 across in tandem (with lead change), 1c RSh to 2M. 2c end in 1pl. 1c face 1cnrs

17--::

  Corners Pass and Turn, cnrs turning BH in centre. On [23-24] 1c turn P LH ½. 1W faces up, 1M faces down

25--::

  Reels3 on sides, 1c RSh to 4cnrs (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (5042, '2013-08-21 08:30:59.319692+00', '2023-02-04 01:19:37.843098+00', 10543, 3, NULL, 'ace', '1-8::
    All dance reels of 3 on sides (1s in & down to start)
9-16::
    1L followed by partner casts to 3rd place & crosses _while_ 3M
    followed by partner casts up to 1st place & crosses, 2s dance RH
    across (Lady with 3s & Man with 1s)
17-24::
    2s pass RSh to dance LH across with other couple, 1M followed by
    partner chase back to place _while_ 3L followed by partner do
    likewise
25-32::
    All set & turn partner RH, 1s cast to 3rd place as 2s+3s dance up 1
    place', 0);
INSERT INTO 'dancecrib' VALUES (5107, '2013-08-21 08:31:00.508285+00', '2023-02-04 01:19:43.706634+00', 1854, 3, NULL, 'ace', '1-8::
    1s+3s dance reel of 4 Ladies passing LSh to start
9-16::
    2s+4s dance reel of 4 Ladies passing LSh to start
17-24::
    1s+4s also 2s+3s dance RH across & LH back to places
25-32::
    1s+3s dance R&L
33-40::
    2s+4s dance Ladies Chain
41-48::
    All 4 Ladies dance RH across once round & Men dance RH across once
    round to end in centre facing partners
49-56::
    All couples set to partners twice & turn 2H back to original places
57-64::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5109, '2013-08-21 08:31:00.52481+00', '2023-02-04 01:19:43.743259+00', 1857, 3, NULL, 'ace', '1-8::
    2s followed by 1s dance a Fig of 8 round the 3s & end with 2s
    dancing up to 1st place
9-16::
    1L dances RH across with 2s & 1M with 3s, pass LSh to dance 1/2
    diagonal reel with 2nd corners
17-24::
    1M dances RH across with 2s on Men''s side & 1L with 3s on Ladies''
    side, 1s pass LSh to dance 1/2 diagonal reel with 1st corners & 1s
    end turning right about to BtoB (1L facing up & 1M down)
25-32::
    1L+ 3s (in top place) & 1M+2s circle 3H round to left (3 bars).
    Circles open out (1s leading) into 6H round (3 bars)  & 1s cross RH
    to own sides
::
    2nd time through - 1s cross to 4th place as 4s cast up to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (5110, '2013-08-21 08:31:00.533166+00', '2023-02-04 01:19:43.7625+00', 1858, 3, NULL, 'ace', '1-8::
    1s lead down for 3 steps, 1/2 turn RH lead up crossing to dance up
    behind 2s to places
9-16::
    1L+3M change places RH, cast into 2nd place opposite sides _while_
    2L+3L also 1M+2M set & Petronella-in-tandem, 1L+3M cross RH & cast
    into middle _while_ others set & Petronella-in-Tandem
17-24::
    All set, circle 6H round left to original places & set
25-32::
    2s followed by 1s dance down, cast up (2s to top), 1s followed by 3s
    dance up & cast to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5111, '2013-08-21 08:31:00.541992+00', '2023-02-04 01:19:43.77997+00', 1862, 3, NULL, 'ace', '{{title}}
Strathspey

1-4::
    Men advance into centre 1 step & out to left as Ladies move 1 step
    to right & 1 step forward, all turn new partner 2H 1.1/2 times
5-16::
    Repeat above Fig 3 more times except that the last turn is once
    round only to end with original Lady partner on Mans left
17-24::
    All dance reels of 4 round circle & back passing own partner RSh
    ending in partners original place Men facing out & Ladies in
25-32::
    All dance interlocking reels of 4 across pass LSh in centre end with
    Men BtoB in centre facing out between partner & Lady originally on
    their right

{{title}}
Reel

1-8::
    All set holding hands as in Double Triangles, all dance petronella
    turn to bring Ladies in centre & Men out, repeat back to places at
    beginning of reel time
9-16::
    All set as in Double Triangle & change places with partner RH,
    repeat this Fig but change places with person on left hand
17-24::
    Repeat the Fig again changing places with person on left hand, all
    set & turn partners RH back to original pstns
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5112, '2013-08-21 08:31:00.551784+00', '2023-02-04 01:19:43.882466+00', 1864, 3, NULL, 'ace', '1-8::
    1s lead down the middle, Lady crosses under own arm & they lead up
    to 2nd place opposite sides
9-16::
    2s+1s dance R&L 1s end facing 1st corners
17-24::
    1s turn 1st corners RH, turn partner LH, turn 2nd corners RH & turn
    partner LH to places
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5113, '2013-08-21 08:31:00.561764+00', '2023-02-04 01:19:43.916011+00', 7696, 3, NULL, 'ace', '1-8::
    1s & 4s set, dance up/down centre _while_ 2s & 3s step up/down,
    1s+4s circle 4H round & end facing corners
9-16::
    All set, change places with corners RH & dance 1/2 double diagonal
    reel of 4 (give LH in centre), 2s & 3s (middle couples) end facing
    corners
17-24::
    All set, change places with corners RH & dance 1/2 double diagonal
    reel of 4
25-32::
    1s & 4s dance out ends & cast to meet in centre, 1s dance under 4s
    arch & both couples dance out other end & cast to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5114, '2013-08-21 08:31:00.569763+00', '2023-02-04 01:19:43.945483+00', 9851, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, turn LH to side by side facing 1st corners
9-16::
    1s set to 1st corners, turn in to face 3rd corner & set, turn 3rd
    corner LH & face 2nd corners (RH with partner)
17-24::
    Repeat with 2nd corners but turn corners RH & end in 2nd place own
    sides
25-32::
    1s dance reels of 3 across Man with 2s & Lady with 3s', 0);
INSERT INTO 'dancecrib' VALUES (9359, '2016-10-06 07:18:20.140501+00', '2023-02-04 01:19:43.981343+00', 17105, 3, NULL, 'ace', '1-8::
    1s+2s also 4s+5s dance RH across 1/2 way & 1s+5s chase 1/2 way
    anticlockwise round 3s then 2s+5s also 1s+4s dance RH across 1/2 way
9-16::
    2s+4s chase anticlockwise 1/2 way round 3s, 4s+3s+2s chase
    anticlockwise 1/2 way.  (5)2(3)2(1)
17-24::
    5s dance Fig of 8 on sides round 2s+3s _while_ 1s dance Fig of 8 on
    sides round 4s+3s (5s & 1s giving LSh to start)
25-32::
    5s+3s+1s cross RH to own sides & 3s cast up to 1st place _while_ 1s
    cast up to 4th place & all turn RH.  3 5 2 1 4', 0);
INSERT INTO 'dancecrib' VALUES (5115, '2013-08-21 08:31:00.675506+00', '2023-02-04 01:19:44.093329+00', 1866, 3, NULL, 'ace', '1-8::
    1s set, cast down below 3s, lead up, cross over & cast to 2nd place
    opposite sides
9-16::
    2s+1s+3s circle 6H round & back 1s ending facing 1st corners
17-24::
    1s set to 1st corners & turn 2H, set to 2nd corners & turn 2H
25-32::
    1s dance reels of 3 on opposite sides (giving LSh to 1st corners to
    start) & cross to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5116, '2013-08-21 08:31:00.683671+00', '2023-02-04 01:19:44.431998+00', 8116, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, 2s+1s+3s set & 1s 1.1/4 turn RH to face 1st
    corners pstns _while_ 2s & 3s cross LH
9-16::
    1s dance 1/2 LSh reel of 4 with 1st corner pstns & 1/2 RSh reel of 4
    with 2nd corners. 1s end in 2nd place opposite side
17-24::
    1s petronella turn & set, petronella turn to own sides & on bars
    23-24 3s+1s+2s set advancing to meet partner
25-32::
    2s+1s+3s dance Allemande to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13889, '2021-04-05 00:19:29.193556+00', '2023-02-09 13:07:27.468935+00', 1868, 3, NULL, 'ace', '1-4::

    1L casts round 2L to face 2M. On bar 4 both bow

5-8::

    1L 2H turns 2M & crosses to 2nd place own side (2L steps up)

9-16::

    1M repeats bars 1-8 with 2L (2M steps up)

17-24::

    1s lead down, cast up round 3s. 1s lead up middle to top & face down

    NHJ _while_ 2s step down & join hands to face up

25-32::

    1s+2s dance RH across for 3 bars, LH back. 1s cast down to 2nd place

    _while_ 2s dance up to 1st place', 0);
INSERT INTO 'dancecrib' VALUES (15306, '2022-12-18 13:34:20.435034+00', '2022-12-19 00:42:48.456961+00', 21203, 1, 202, 'ace', '1--::

  1c set advancing | turn P BH opening to face down ; 1c turn 2c EH. 1M faces 2M, 1W behind 1M

9--::

  Reel3 across in tandem (with lead change), 1c RSh to 2M. 2c end in 1pl. 1M faces 3M, 1W behind 1M

17--::

  1c+3c repeat pattern of [9-16]. 1c end in 1pl, 1M faces out (2,1,3)

25--::

  Parallel Fig8 on sides (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (12723, '2020-04-11 10:51:02.939747+00', '2023-02-04 01:19:38.598957+00', 8600, 3, NULL, 'ace', '1-8::
    1M+2L set & cross RH _while_ 1L+2M cross RH  & set; Repeat
9-16::
    1s dance down NHJ (2 bars) set, dance up and cast to 2nd place (2s
    step up 15-16)
17-24::
    1s+2s dance double figure of 8  (1s cross up to start)
25-32::
    1s+2s circle 4H round and back. 2 1', 0);
INSERT INTO 'dancecrib' VALUES (5117, '2013-08-21 08:31:00.693568+00', '2023-02-04 01:19:44.467103+00', 9817, 3, NULL, 'ace', '1-8::
    1s & 4s set & 1/2 turn RH _while_ 2s+3s dance RH across, 1s+2s also
    3s+4s dance RH across
9-16::
    All dance 1/2 reels of 4 on sides, 2s & 3s change places LH on sides
    & cross LSh to face out.  (4) 2 3 (1)
17-24::
    3s & 2s turn corners with nearer hands, 2L followed by partner
    dances 1/2 RSh reel of 3 with 4s _while_ 3M followed by partner
    dances 1/2 RSh reel of 3 with 1s to end 2 4 1 3 (on own sides)
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5118, '2013-08-21 08:31:00.701601+00', '2023-02-04 01:19:44.502443+00', 12201, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across, 1M+2L also 3M+4L turn RH, Men
    dance round next Man into middle _while_ Ladies cast down 1 pl into
    middle
9-16::
    1M+2L+3M+4L dance Reel of 4 up/down middle
17-24::
    1M+2L also 3M+4L turn RH & Bal-in-Line, on last 2 bars standing
    dancers advance to meet partners
25-32::
    1s+2s also 3s+4s dance Poussette but end with 1s & 4s passing each
    other to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8318, '2014-07-29 12:58:57.173527+00', '2023-02-04 01:19:44.672694+00', 15337, 3, NULL, 'ace', '1-8::
    1s cross RSh & cast 1 place, set Advancing passing partner LSh &
    turning right about to face partner then turn with 2H to face 1st
    corners
9-16::
    1s set to & turn 1st corners to end 1L between 2s & 1M b''tw''n 3s,
    set advcg passing prtnr LSh turning right about then turn prtnr 2H
    to face 2nd crnr
17-24::
    1s set to & turn 2nd corners to end 2nd place opp sides, set advcg
    pass prtnr LSh turning right about then turn prtnr 2H to 1L facing
    up & 1M down
25-32::
    1L+2s also 1M+3s dance RH across, 1L (passing partner LSh) followed
    by 2s dance down Men''s sides & crosses at bottom up to 2nd place own
    side as 1M followed by 3s dance up Ladies'' side & crosses at top &
    down to 2nd place to end in order 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (13069, '2020-08-10 00:19:18.429342+00', '2023-02-04 01:19:44.882587+00', 16617, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret (1 step each), set advancing passing LSh to BtoB,
    pull back RSh & dance back to place, all turn partners 2H
9-16::
    1s dance down NHJ & set _while_ 2s stand (2 bars) then cross up to
    1st place opp sides; 1s dance up passing 2s by RSh & loop into 2nd
    place
17-24::
    _1/2_ Reels of 3 on sides, 1s pass 3s LSh to start; 3M+1L turn 1.1/2
    LH _while_ 1M+3L chase clockwise 1/2 round. (1) (3) (2)
25-32::
    1s+3s+2s Set+Link for 3 twice:
::
    _25-26_   All 3 couples set
::
    _27-28_   1st corners (dancers at left end of lines) dance to the
    right & curve round to face up/down _while_ the middle 2 dancers
    cast & chase clockwise to form lines across with the other 1st
    corner person
::
    _29-32_   Repeat to all end on sides 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (12542, '2020-02-02 02:47:39.640518+00', '2023-02-04 01:19:44.93795+00', 1873, 3, NULL, 'ace', '1-8::
    1s lead down, cast up round 3s back to 1st place & all set
9-16::
    1s+3s petronella turn to centre & set; 1s+3s dance 1/2 reel of 4
    (RSh to partner to start)
17-24::
    3s+1s turn partners 1.3/4 2H, stay in centre, open out for 2s to
    join in & 3s+2s+1s circle 6H 1/2 round to left, all end on opp sides
    (1) (2) (3)
25-32::
    All set & cross RH with partner; all set & 1s cast to 2nd place (2s
    step up)', 0);
INSERT INTO 'dancecrib' VALUES (5120, '2013-08-21 08:31:00.74838+00', '2023-02-04 01:19:44.994168+00', 10367, 3, NULL, 'ace', '1-8::
    1s petronella turn & set; petronella turn & set to end on opposite
    sides
9-16::
    1s cross RH, cast 1place (2s step up) & turn LH to face 1st corners
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners, touch RH in
    passing to dance 1/2 diag onal reel with 2nd corners & turn RH to
    face up NHJ
25-32::
    1s dance up to top & cast to 2nd place _while_ 2s+3s dance 1/2 R&L
    (RH on sides to start), 1s dance RH across (Lady with 2s & Man with
    3s)
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10627, '2018-04-16 21:41:46.674844+00', '2023-02-04 01:19:45.016128+00', 1876, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up), set & cast (1L up, 1M down) to 1L between
    2s, 1M between 3s, facing 1st corners
9-16::
    _1/2_ RSh reels of 3 across, ending with 1s curving to Right into
    2nd places opp. sides as corners curve in to meet partners NHJ at
    top & bottom of set; All set facing centre & circle 6H 1/2 round to
    Left onto sidelines (3) 1 (2)
17-24::
    1s turn 2H, cast (1L down, 1M up), cross RH up/down set  to end
    facing each other, 1L between 3s at top, 1M between 2s at bottom
25-32::
    All set to partners, 1s pull back RSh & cast (1L down, 1M up) to 2nd
    place own sides _while_ corners 1/2 turn RH to face centre NHJ; 1s
    cross RH _while_ 2s set to 3s & all circle 6H 1/2 round to Left to
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (5122, '2013-08-21 08:31:00.767897+00', '2023-02-04 01:19:45.075335+00', 12522, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+3s change places, 1s dancing under arch made by 3s & set; 3s+1s
    change places (1s making arch) & set
17-24::
    2s+4s repeat bars 9-16 (4s making 1st arch)
25-32::
    Ladies dance RH across & Men dance LH across 1.1/4 times to meet new
    partner
33-40::
    All Promenade anticlockwise round set', 0);
INSERT INTO 'dancecrib' VALUES (5123, '2013-08-21 08:31:00.776193+00', '2023-02-04 01:19:45.105377+00', 1884, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s+2s also 3s+4s face on sides, all set & change places RH, all set
    & change back RH
17-24::
    1M reel of 3 with 2s (LSh to 2L) picking up partner in prom hold to
    complete reel as 3M dances similarly with 4s, 1s+3s end on Men''s
    side facing in/down (2s & 4s in original places)
25-32::
    3s followed by 1s dance down below 4s, 3s cast, in & lead up to top,
    cross & cast back to place _while_ 1s cast up & turn LH to face 1st
    crnrs(2s step up 31-32)
33-40::
    1s turn 1st corners RH pass partner RSh, turn 2nd corner LH, pass
    LSh to end 2nd place in centre facing up
41-48::
    1L+2L+3L dance RH across (on side) as 1M+2M+3M LH across, 1s
    followed by 3s dance down to 4s & Ladies dance LH across as Men RH
    across to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5124, '2013-08-21 08:31:00.871947+00', '2023-02-04 01:19:45.136961+00', 9385, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link & circle 4H round to left
9-16::
    2s & 1s dance DoSiDo & turn partner 2H into prom hold
17-24::
    2s+1s dance Allemande ending in centre with RH joined
25-32::
    1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (13077, '2020-08-10 00:19:26.190163+00', '2023-02-04 01:19:45.298904+00', 1892, 3, NULL, 'ace', '1-4::
    1s & 4s set, 1s pass 2s LSh (2s step up) _while_ 4s pass 3s LSh (3s
    step down)
5-8::
    1s+4s turn 1.1/2 LH on sides. 4s face 2s, 1s face 3s.  2 4 1 3
9-16::
    All dance Grand Chain 1/2 round (1 step per hand) (3) (1) (4) (2);
    All set & cross RH with partner, 1s & 4s face out 3 1 4 2
17-20::
    1s followed by 4s cast up to top, lead down, remaining in centre (1s
    in 3rd place, 4s in 2nd place)
21-24::
    4s+1s+2s dance 1/2 reels of 3 on sides (1s lead down, 2s out/up, 4s
    out/ down to start). 3 2 1 4
25-32::
    3s+2s also 1s+4s dance 1/2 R&L; All set & cross RH.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (3927, '2013-08-21 08:30:39.357064+00', '2023-02-04 01:18:21.740059+00', 50, 3, NULL, 'ace', '1-8::
    1L followed by 1M also 4M followed by 4L cast in 1 place, 1L & 4M
    cross to opposite sides & all dance 1/2 RSh reel of 4 on sides
9-16::
    Repeat with 3L & 2M leading all ending in partners original places
17-24::
    1s+2s also 3s+4s dance 1/2 RH across, set, 1s+4s dance 1/2 LH across
    & set
25-32::
    4s & 1s dance 1/2 Figs of 8 round end couples & all turn partners
    RH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3928, '2013-08-21 08:30:39.365118+00', '2023-02-04 01:18:21.757659+00', 9631, 3, NULL, 'ace', '1-8::
    1s cross RH, 1L+2M also 1M+2L change LH on sides, 1M followed by
    ptnr casts up & dances down middle to 1M between 3s & 1L between 2s
9-16::
    2s+1s+3s dance down the middle & back
17-24::
    1L followed by partner casts 1 place (Men''s side), crosses to own
    side & 1s turn LH (4 bars) ready for…
25-32::
    1s dance RH across (1L with 2s & 1M with 3s) & pass RSh for LH
    across with other couple.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14285, '2021-09-08 00:19:25.137624+00', '2023-02-04 01:19:39.070126+00', 20212, 3, NULL, 'ace', '1-8::
    1s lead down & back up
9-16::
    1s set, cast (2s step up 11-12); 1s+3s dance RH across
17-24::
    2s+1s dance R&L
25-32::
    2s+1s+3s circle round & back', 0);
INSERT INTO 'dancecrib' VALUES (13613, '2021-02-04 01:19:29.503732+00', '2023-02-04 01:19:45.323737+00', 16469, 3, NULL, 'ace', '1-8::
    Men dance RSh round partners; all 3 couples turn partner RH
9-16::
    Ladies dance LSh round partners; all 3 couples turn LH, remaining in
    middle facing up ready for …
17-24::
    1s+2s+3s dance Allemande
25-32::
    3s+2s dance Tourbillon
::
    _25-28_   3s & 2s 1/2 turn ptnrs 2H, 3M & 2L lead ptnrs by nearer
    hand 1 place cl''wise to end 3s on Ladies side & 2s Men''s side, 3s
    set to 2s
::
    _29-32_   3s & 2s 1/2 turn ptnrs 2H & lead ptnrs on 1 place
    clockwise & 2s+3s cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5127, '2013-08-21 08:31:00.940617+00', '2023-02-04 01:19:45.352566+00', 11678, 3, NULL, 'ace', '1-8::
    1s cross down to dance Inveran reels
9-16::
    1s followed by 2s+3s dance down middle, 3s followed by 2s+1s dance
    up & 3s cast to 3rd place & 2s to 1st place with 1s in middle at 2nd
    place
17-24::
    1M dances LH across with 2M+3M as 1L dances RH across with 2L+3L, 1s
    change places to dance RH/LH across on other sides
25-32::
    1s dance up & cast 1 place on opposite sides, 1s dance 1/2 Fig of 8
    up round 2s

{{explanation}}
Note:  Bar 32  2nd time through, 1s dance down outside to 4th place while 4s dance up & into Inveran reel', 0);
INSERT INTO 'dancecrib' VALUES (5128, '2013-08-21 08:31:01.047663+00', '2023-02-04 01:19:45.522186+00', 13483, 3, NULL, 'ace', '1-8::
    All Men dance LH across 1/2 way & turn opposite Lady RH, all Men
    dance 1/2 LH across & turn partner RH.
9-24::
    All dance Grand Chain 1/2 way & set (HS) to partner, continue Chain
    back to place & set (HS) to partner.
25-32::
    All dance Set+Link twice (with partner)
33-48::
    All dance full Schiehallion reels
49-56::
    All circle 8H round & back
57-64::
    All dance DoSiDo with partner, turn partners RH 1.1/4 into Allemande
    hold
65-72::
    All Allemande anticlockwise to end with Ladies in the middle', 0);
INSERT INTO 'dancecrib' VALUES (12543, '2020-02-02 02:47:40.34502+00', '2023-02-04 01:19:45.746983+00', 13902, 3, NULL, 'ace', '1-8::
    1L+2L Set+Link _while_ 1M+2M Reverse Set+Link (1M casts, 2M dances
    up); 1s turn 1.1/4 LH remaining in centre
9-16::
    1L+2s & 1M+3s dance RH across, 2s+1s+3s dance Snake Pass:       1L
    followed by 2L & 2M, 1M followed by 3L & 3M, pass LSh in the middle,
    dance out to the side, down to 3rd/up to 1st place, cross to own
    side and cast up/down to 2nd place in middle.  End 3 1 2
17-24::
    1s dance out of ends (1M down, 1L up), cast left to 2nd place opp
    sides; 1/2 RSh reels of 3 across (1M+2M, 1L+3L pass RSh)  (3) 1 (2)
25-32::
    3s+1s+2s dance diag R&L.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5129, '2013-08-21 08:31:01.056009+00', '2023-02-04 01:19:45.771488+00', 1896, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    2s+4s dance R&L
17-24::
    1s+3s turn opposite partners RH (4 bars), 2s+4s repeat
25-32::
    1s+3s set, set turning inwards to face out & cast round corners back
    to place
33-40::
    2s+4s repeat bars 25-32
41-56::
    All dance full Schiehallion Reel
57-64::
    All join hands with 1s making an arch, 1L & 4M drop hands & 4M leads
    everyone under the arch back to places

{{explanation}}
Repeat with 1s & 3s dancing bars 9-16 also 2s & 4s dancing bars 17-24 At end 4M can lead everyone on a merry dance!', 0);
INSERT INTO 'dancecrib' VALUES (5130, '2013-08-21 08:31:01.063974+00', '2023-02-04 01:19:45.798698+00', 9852, 3, NULL, 'ace', '1-16::
    All dance 4 couple R&L (as 3 couple R&L but with persons in 1st &
    2nd Ladies pstns crossing LH with 3rd & 4th Men''s pstns)
17-24::
    1s & 4s cross RH, cast (2s & 3s step down/up) & dance 1/2 R&L in
    centre
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5131, '2013-08-21 08:31:01.077663+00', '2023-02-04 01:19:45.911204+00', 1897, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s dance into centre of set (others move down/up) & PdB Coupe
    once, circle 4H round to left & end facing corner persons
9-16::
    1s & 4s set to corners & change places LH, corners dance RH across &
    end in prom hold facing ''own'' end of set
17-24::
    1s+2s also 4s+3s dance RSh reels of 3 across set (going right) & 2s
    & 3s end in 1st/4th places _while_ 1s & 4s curve round into centre
    to face each other (1s facing down)
25-32::
    1s+4s dance Men''s Chain passing partner with RH
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5132, '2013-08-21 08:31:01.085766+00', '2023-02-04 01:19:45.939056+00', 9980, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Petronella-in-tandem & set, dance RH across to end
    1s & 3s on Men''s side & 2s & 4s on Ladies'' side
9-16::
    All dance reels of 4 on sides
17-24::
    All set to partners & turn 2H, 1s+2s also 3s+4s circle 4H round to
    left 1.1/4 way & ending 1s facing 2s & 3s facing 4s
25-32::
    All set passing facing couple (2s dancing to top & 3s to bottom)
    _while_ 1s+4s pass & cast round end couples to 2nd/3rd place.  2 4 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (11556, '2019-01-31 23:31:04.182582+00', '2022-12-18 16:39:19.140086+00', 14155, 1, 202, 'ace', '1--::

  1M+2W & 3M+4W cross RH | 1W+2M & 3W+4M cross RH ; 1M+4W change places RH | 1W+4M change places RH (2x,4,1,3x)

9--::

  1c+4c ½ R&L ; 2c+1c & 4c+3c ½ R&L (1,2,3,4)

17--::

  1c & 4c cross | cast inwards (2c & 3c step out) ; 1c+4c RHA finishing all BtoB in centre facing nearest cnr (2,1x,4x,3)

25--::

  All set | 1W & 4M (1M & 4W) turn this cnr ¾ RH(LH) into facing lines4 across ; all A&R

33--::

  1c+4c Reel4  up/down, 1W & 4M passing LSh. On [39-40] 2c & 3c step in _as_ 1c & 4c finish in original places (1,2,3,4)

41--::

  1c set | 1W casts to 4pl (2W+3W+4W up) _as_ 1M casts (2M up) ; 1M sets to 3W | casts to 4pl (3M+4M up) (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (15320, '2022-12-19 01:19:35.277715+00', '2023-02-04 01:19:46.003104+00', 20777, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret diagonally, (touching hands in square), then turn
    partner RH
9-16::
    1s+2s dance RH across & LH across
17-24::
    1s cross RH, cast to 3rd place (2s+3s step up 19-20); 1s dance 1/2
    Fig 8 up round 3s
25-32::
    3s+1s dance R&L.  2 3 1

{{explanation}}
As a 4 couple dance: 17-24 1s cross, cast to 2nd place & dance 1/2 Fig down round 3s.  25-32  1s+3s dance R&L.  2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (5133, '2013-08-21 08:31:01.220321+00', '2023-02-04 01:19:46.318753+00', 14239, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s dance down middle & back
17-24::
    1s+2s Promenade round
25-32::
    1s+2s dance R&L for 6 bars & set', 0);
INSERT INTO 'dancecrib' VALUES (11695, '2019-03-18 21:02:05.174906+00', '2023-02-04 01:19:46.349784+00', 19136, 3, NULL, 'ace', '1-8::
    1L+2L+3L Adv+Ret, 1s+2s+3s turn RH
9-16::
    1M+2M+3M Adv+Ret, 1s+2s+3s turn LH, 1s finish facing out
17-24::
    1s cast behind lines (2s+3s step up bar 19-20). 1s meet below 4s,
    dance up one place & cast round 4s to bottom (4s step up 23-24)
25-32::
    4s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5134, '2013-08-21 08:31:01.230261+00', '2023-02-04 01:19:46.37244+00', 9372, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place, 1s turn RH 1.1/2 times to opposite sides
9-16::
    1s dance reels of 3 on sides (RSh to 1st corner to start)
17-20::
    1s dance RSh round 1st crnrs to lines across (1L between 2s & 1M
    between 3s) _while_ 2s+3s dance RH across
21-24::
    2s+1s+3s Adv+Ret up/down (1 step each) & set
25-28::
    1s cast to 2nd place own sides _while_ 2s+3s dance LH across,
29-32::
    2s+1s+3s Adv+Ret (1 step each) & set', 0);
INSERT INTO 'dancecrib' VALUES (8567, '2015-02-13 12:47:41.036121+00', '2023-02-04 01:19:46.556962+00', 12848, 3, NULL, 'ace', '1-8::
    1s dance Fig. 8 on own sides (1s dance in/down to start), taking
    nearer hands where possible
9-16::
    1s+2s+3s mirror (reflection) reels on own sides (1s in/down, 2s
    out/up, 3s in/up to start)
17-24::
    1s lead down (3 bars), lead back up (3 bars) cast into 2nd place own
    sides
25-32::
    1M with 3s, 1L with 2s, dance RH across, 1s pass RSh to dance LH
    across other end (1M with 2s, 1L with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (12544, '2020-02-02 02:47:41.201659+00', '2023-02-04 01:19:46.728801+00', 13903, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, circle 6H 1/2 round to left; 1L followed by 1M casts
    up 1 place & dances down middle to end 1s BtoB between 2s (1L facing
    2M, 1M facing 2L). 2s step down 7-8
9-16::
    1s+2s dance "Iso-Birl"
::
    _9-10_    All set advancing passing LSh
::
    _11-12_  1s (outside) chase 1/4 round clockwise _while_ 2s turn 3/4
    2H & pull back RSh
::
    _13-16_   Repeat 9-12 to end in original line of 4 across
17-24::
    1s+2s dance RSh reel of 4 across. 1s end joining LH facing up
25-32::
    1s lead up, cross & cast to 1st place opp sides (3s step down); All
    set, circle 6H 1/2 round to left.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5137, '2013-08-21 08:31:01.256113+00', '2023-02-04 01:19:46.797396+00', 9853, 3, NULL, 'ace', '1-8::
    1s dance down the middle, divide cast up round 3s, dance up between
    2s & cast to 2nd place
9-16::
    1s set advancing to 1st corner & turn 2H, 1s+1st corners circle 4H
    round to left to end 1M between 3s facing up & 1L between 2s facing
    down
17-24::
    1s set advancing to 2nd corner & turn 2H, 1s+2nd corners circle 4H
    round to left to end 2(1)3
25-32::
    1s+3s set & dance 3/4 double Fig of 8  (1s cast to start) to end 2 3
    1', 0);
INSERT INTO 'dancecrib' VALUES (5139, '2013-08-21 08:31:01.278093+00', '2023-02-04 01:19:46.980455+00', 1908, 3, NULL, 'ace', '1-8::
    1s cast down behind own lines, turning out dance back to places
9-16::
    1s lead down for 3 steps, lead up to top & cast 1 place to face 1st
    corners
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH to end
    in middle facing out Ladies'' side (Man below Lady)
25-32::
    1s dance out between 2L+3L, divide & cast up/down into middle, dance
    out between 2M+3M divide & cast up/down to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5140, '2013-08-21 08:31:01.286307+00', '2023-02-04 01:19:47.004582+00', 7388, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
    (passing between 2s & 3s) 1s end 1st place opposite sides
9-12::
    1s dance down the middle below 3s & cast up to 2nd place opposite
    side
13-24::
    2s+1s+3s dance 3 couple R&L, 1s end facing 1st corners
25-32::
    1s set to 1st corners, set to 2nd corners, turn right to face
    partner, set & petronella turn to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5141, '2013-08-21 08:31:01.295953+00', '2023-02-04 01:19:47.105751+00', 1909, 3, NULL, 'ace', '1-8::
    1s set, 1M casts 1 place & turns 3L RH to end between 2L+3L
9-16::
    1L sets to 2M, casts 1 place, turns 3M RH & 1s cross RH to own sides
17-24::
    2s+1s+3s circle 6H round & back
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (3709, '2013-02-09 21:27:55.028668+00', '2022-12-18 16:41:06.346005+00', 12769, 1, NULL, 'ace', '1–::

  1c+3c ½ R&L ; All turn cnr RH | set to P

9–::

  1c+3c repeat, to places

17–::

  All: Interlocking Reels4, Rsh to P, finish facing cnr

25–::

  All: Interlocking Lsh Reels4, Lsh to cnr, finish in places.

33-48::

  2c+4c repeat [1-16]

49–::

  All W RHA ; dance Lsh ¾ round P to place

57–::

  1c+3c ½ L-Chain ; 2c+4c ½ L-Chain

65–::

  All M RHA ; pick up the new P NHJ and continue ½ RHA in big wheel

73–::

  M still in middle face new P and set | M ½ LHA and face own P ; set | turn ¾ RH to places

81–::

  Circle8 and back', 2);
INSERT INTO 'dancecrib' VALUES (5142, '2013-08-21 08:31:01.30532+00', '2023-02-04 01:19:47.124956+00', 1913, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s cross RH & cast 1 place to meet in centre facing down, 1L dances
    RH across with 3M+4M as 1M dances LH across with 3L+4L
9-16::
    1s dance down between 4s & cast up to 3rd place in centre facing up,
    1L dances LH across with 2M+3M & 1M RH across with 2L+3L

{{title}}
Jig

17-24::
    1s with nearer hands joined set to 2s (on sidelines), 1s set to each
    other, set to 3s, 1s in prom hold dance down to face 4M
25-32::
    1s in prom hold dance reel of 3 with 4s giving RSh to 4M, 1s end in
    4th place own sides', 0);
INSERT INTO 'dancecrib' VALUES (10067, '2017-09-03 23:44:34.801878+00', '2023-02-04 01:19:47.147475+00', 17891, 3, NULL, 'ace', '1-8::
    1s set, dance down & cast up round 3s (2s step up 3-4), 2s+1s+3s set
9-16::
    _1/2_ Fig 8 (1L round 2M, 1M round 3L) to 2nd place opp sides,
    2s+1s+3s set & 1s turn LH to face 1st corners
17-24::
    1s turn 1st corner RH, pass partner RSh, turn 2nd corner RH, pass
    partner RSh to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5143, '2013-08-21 08:31:01.315102+00', '2023-02-04 01:19:47.168074+00', 1916, 3, NULL, 'ace', '1-8::
    1L+2M turn RH, 1s turn RH (2 step up) ending in lines across (1L
    between 2s facing 1M between 3s)
9-16::
    2s+1s+3s set, 1s petronella turn to right, 2s+1s+3s set facing
    across & 1s set & turn 2H to 2nd place own sides
17-24::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5144, '2013-08-21 08:31:01.324791+00', '2023-02-04 01:19:47.188035+00', 8930, 3, NULL, 'ace', '1-8::
    1M+2L also 3M+4L Adv+Ret diagonally & dance DoSiDo diagonally
9-16::
    1L+2M also 3L+4M repeat
17-20::
    1s 1/2 turn RH, 1s+2s dance 1/2 RH across
21-24::
    1s 1/2 turn RH, 1s+3s dance 1/2 RH across _while_ 2s turn RH once
    round (4 bars)
25-28::
    1s 1/2 turn RH, 1s+4s dance 1/2 RH across _while_ 2s+3s dance RH
    across once round
29-32::
    1s set (4 bars) _while_ 2s+3s+4s set and cross RH    2 3 4 1', 3);
INSERT INTO 'dancecrib' VALUES (5145, '2013-08-21 08:31:01.334482+00', '2023-02-04 01:19:47.209991+00', 8668, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, turn LH 1.1/4 times & dance LSh round 1st
    corner to end in 2nd place opposite sides
9-16::
    1s dance reels of 3 on sides giving RSh to 2nd corner to start & end
    facing 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places
25-28::
    All three couples turn RH
29-40::
    1s+2s+3s dance 3 couple R&L', 0);
INSERT INTO 'dancecrib' VALUES (5146, '2013-08-21 08:31:01.34258+00', '2023-02-04 01:19:47.231188+00', 10291, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast to 2nd place (2s step up 5-6) & 2M+1M 3/4
    turn 2H (skip change) into centre facing down with NHJ to form an
    arch
9-16::
    1L dances up under arch, casts on Ladies'' side, dances up under arch
    & casts to 2nd place Men''s side _while_ 2L casts & dances up under
    arch, casts on Men''s side, dances up under arch to top place Ladies''
    side
17-24::
    1M+2M 1/2 turn 2H (skip change) & cast back to place, 1s dance 1/2
    Fig of 8 round 2s
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (11086, '2018-09-09 17:45:52.392131+00', '2023-02-04 01:19:47.399203+00', 18562, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, turn RH to opposite sides facing 1st
    corner.  2 1 3
9-16::
    1s dance reels of 3 on sides giving RSh 1st corners & end BtoB
    facing 1st corners
17-24::
    1s set to corners & turn RH then pass LSh to face 2nd corners, 1s
    set to corners & turn RH to end facing 3rd corners
25-32::
    1s dance LSh reel across (1M with 2s, 1L with 3s) & cross RH to 2nd
    places own sides', 0);
INSERT INTO 'dancecrib' VALUES (15413, '2023-02-04 01:19:47.435822+00', '2023-02-04 01:19:47.438416+00', 20301, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place (2s & 3s step down/up); 1s+4s
    dance LH across, finish facing nearest corner
9-16::
    All dance double diag reels of 4 (LH across in middle)
17-24::
    1s+4s dance LH across to end in 2nd/3rd places opp sides; 1s+4s
    dance 1/2 R&L (no polite turn). 2 4 1 3
25-32::
    2s+4s also 1s+3s circle 4H round to left; 4s+1s circle 4H round to
    right.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12914, '2020-07-01 00:19:25.694599+00', '2023-02-04 01:19:47.594311+00', 19987, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance RSh reels of 3 on sides.  1L ends facing out
9-16::
    1s dance The Chase:
::
    1L casts 2 places, crosses below 3s, cast up behind 3M, in front of
    2M & turns right about at top to face down _while_
::
    1M dances across, casts 2 places, dances round & up in front of 3L,
    behind 2L to top & faces down with partner in middle of set (Lady on
    Man''s Right)
17-24::
    1s dance down; Bar 21: 1M dances below partner who turns under man''s
    arm to change sides & 1s dance up to 2nd place (2s step up 19-20)
25-32::
    2s+1s+3s circle 6H round & back.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5148, '2013-08-21 08:31:01.386781+00', '2023-02-04 01:19:47.619434+00', 9107, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to top. 2s & 3s step in on bar 8
    ready for …
9-16::
    1s+2s+3s Promenade ending with 1s casting to 2nd place
17-24::
    1s pass by the right & turn 1st corners RH to end L between 2s & M
    between 3s, 1s pass by the right & turn 2nd corners RH to end
    between crnrs
25-32::
    1M dances RH across with 2s & 1L with 3s, 1L dances up between 2s &
    casts to 2nd place own side as 1M dances between 3s & casts up', 0);
INSERT INTO 'dancecrib' VALUES (5149, '2013-08-21 08:31:01.396868+00', '2023-02-04 01:19:47.764184+00', 14269, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, cross RH & cast right (1M ends between
    2s, 1L ends between 3s
9-12::
    1s in lines of 3 Adv+Ret (for 1 up/down) & change places RH
13-16::
    All repeat bars 9-12
17-24::
    1s cross RH & cast to 2nd place own side, 1s turn RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5151, '2013-08-21 08:31:01.415169+00', '2023-02-04 01:19:47.931963+00', 10772, 3, NULL, 'ace', '{{explanation}}
8 Dancers in »8 of Diamonds« formation  
Top square numbered clockwise 1.2.3.4. & 5 in centre facing up between 4 & 1, bottom square 2.6.7.3. & 8 in centre facing down between 6 & 7

::
    _6_ · · · ·7
::
    · · ·8
::
    _2_ · · · ·3
::
    · · ·5
::
    _1_ · · · ·4
::
    · Top
1-8::
    _1_+2+5 also 7+3+8 dance RH across, 3+4+5 also 2+6+8 dance LH across
9-16::
    _1_+5+3 also 7+8+2 dance RSh diagonal reels of 3
17-24::
    _4_+5+2 also 6+8+3 dance LSh diagonal reels of 3
25-32::
    Passing RSh 1 & 5 also 7 & 8 change places, 1 & 4 also 6 & 7 change
    places, 3 & 4 also 2 & 6 change places ending with 4 & 6 looping
    round to right then 4 & 2 also 6 & 3 change places

{{explanation}}
Repeat with new centre dancers (6 & 4)', 0);
INSERT INTO 'dancecrib' VALUES (8778, '2015-06-15 11:40:40.22993+00', '2023-02-04 01:19:48.114545+00', 16258, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 Figs of 8 (1M round 2s, 1L
    round 3s) to end facing 1st corners
9-14::
    Dance to Corners & Set: (6 bars):
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 2 more times to end
    with corners in diagonally opposite place and 1s meet in the middle
    again & pass RSh
15-16::
    1s turn RH to BtoB position in middle (1M facing up 1L down) _while_
    corners dance clockwise 1 corner to end 2s facing down & 3s up
17-24::
    All dance Crown Triangles & end 1s dancing RSh round partner to face
    out in 2nd place opposite sides
25-32::
    1s dance reels of 3 on opposite sides passing 1st corner RSh & end
    passing LSh to 2nd places own sides', 0);
INSERT INTO 'dancecrib' VALUES (5152, '2013-08-21 08:31:01.454119+00', '2023-02-04 01:19:48.248749+00', 1931, 3, NULL, 'ace', '{{title}}
Introduction

1-8::
    All circle 8H round & back
9-16::
    Ladies dance RH across (partners on their left) in St Andrews Cross
    formation, change to Men dancing LH across in centre back to places
17-24::
    All set to partners twice & turn 2H
25-40::
    All dance Grand Chain (2 bars per hand)

{{explanation}}
Dance:	8 times through firstly with 1L in centre, then 2L, 3L, 4L, 1M, 2M, 3M, 4M

1-8::
    1L sets in centre (any suitable reel steps) _while_ others dance 7H
    round & back
9-16::
    1L sets to partner & turns 2H, 1st Lady sets & turns 3rd Man
17-24::
    1L dances reel of 3 with partner & 3rd Man passing partner LSh
25-32::
    1L sets in centre _while_ others circles 7H round & back
33-40::
    1L sets to 4th Man & turns 2H, 1st Lady sets to 2nd Man & turns 2H
41-48::
    1L dances a reel of 3 with 4M+2M across dance passing 4M LSh & 1L
    retires to place as 2L goes into centre

{{title}}
Finale

1-40::
    Repeat Introduction', 0);
INSERT INTO 'dancecrib' VALUES (5150, '2013-08-21 08:31:01.406973+00', '2023-02-09 12:28:32.900654+00', 1927, 3, NULL, 'ace', '1-8::

    All couples set twice, cross passing RSh

9-16::

    All couples set twice again & cross back passing RSh

17-24::

    All couples facing up Adv+Ret & then give hands to turn partners RH

25-32::

    1s set, cast to 2nd place (2s step up) & turn RH



{{explanation}}

Repeat with 1s in 2nd place (all 4 couples dance bars 1-24 of each time through)', 0);
INSERT INTO 'dancecrib' VALUES (3952, '2013-08-21 08:30:40.00996+00', '2023-02-04 01:19:41.735427+00', 77, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast 1 place & turn LH to face 1st corner
9-16::
    1s dance reels of 3 across giving RSh to 1st corner _while_ 2s+3s
    dance reels of 3 on sides & 1s end turning LH to face 3rd corner
17-24::
    1s dance reels of 3 across giving RSh to 3rd corner _while_ 2s+3s
    dance reels of 3 on sides & 1s end turning LH to face 1st corner
25-32::
    1s+1st corners turn RH, pass RSh to turn 2nd corner LH & cross LH to
    places', 0);
INSERT INTO 'dancecrib' VALUES (5153, '2013-08-21 08:31:01.464114+00', '2023-02-04 01:19:48.319201+00', 10549, 3, NULL, 'ace', '1-8::
    1s dance down the middle below 4s (4 bars), set passing LSh & cast
    up to 3rd place opposite sides
9-16::
    1s dance 1/2 RSh reels of 3 across (1L with 3s & 1M with 4s), 1s
    dance up to top, set passing LSh
17-24::
    1s+2s dance 3/4 double Fig of 8 (1s cast on opp sides to start) &
    cross (2s RH & 1s LH).  (2)(1)(3)(4)
25-32::
    1s+3s change places on sides (RH Ladies'' side & LH Men''s side),
    1s+4s change places with other hand, all set & cross RH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5154, '2013-08-21 08:31:01.472535+00', '2023-02-04 01:19:48.469842+00', 1934, 3, NULL, 'ace', '1-8::
    1s lead down between 2s & 3s, cross & cast back to top, pass RSh to
    face opposite couple (Man faces 2s & Lady faces 3s), all set
9-16::
    1s dance under arches made by 2s/3s, 1s cast to meet at bottom, turn
    RH & cast back to original places (Man behind 2s & Lady behind 3s)
17-24::
    All petronella turn to face partner, set & repeat to end in
    partner''s place
25-32::
    All Men chase clockwise 1 place _while_ Ladies LH across 2/3 to meet
    partner to form star & Balance, all turn RH 1/2 way
33-40::
    All Ladies chase clockwise 1 place _while_ Men LH across 2/3 to meet
    partner to form star & Balance, all 3/4 turn RH to end in new pstns
41-48::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5155, '2013-08-21 08:31:01.480645+00', '2023-02-04 01:19:48.552754+00', 12793, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, lead down LH crossing below 3s & cast up
    to 2nd place own side
9-16::
    2s & 3s petronella turn into middle & set, 1s petronella turn into
    middle (1L between 2s & 1M between 3s) & all set
17-24::
    2L+1L & 1M+3M (both couples dancing in tandem) dance an Alternating
    Tandem reel of 4 with 2M & 3L up/down (2M & 3L do not pass LSh at
    end of reel) & end Men face down, Ladies up
25-32::
    All chase clockwise 1/2 way to own sides & turn RH.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5156, '2013-08-21 08:31:01.488789+00', '2023-02-04 01:19:48.583775+00', 12794, 3, NULL, 'ace', '1-8::
    All set, 1s cast _while_ 2s dance in & up to face out, 3s dance in &
    down to face out.  2s+1s+3s dance 1/2 reel of 3 on sides
9-16::
    1s petronella turn into lines across (1L between 3s at top & 1M
    between 2s) & all set, 1s dance 1/2 Diag R&L (up/down)
17-24::
    1s petronella turn onto sides (1L between 2s on Ladies'' side & 1M
    between 3s Men''s side) & all set, 1s dance 1/2 Diag R&L (across)
    (2)(1)(3)
25-32::
    All set, turn partners RH & chase clockwise 1/2 way.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (14286, '2021-09-08 00:19:33.386109+00', '2023-02-04 01:19:48.674578+00', 20354, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance »Figure 8 With Turning«:
::
    _1-2_   1s/3s cross to 2nd/4th place opp sides _while_ 2s & 4s cast
    up
::
    _3-4_   1M+2L, 3M+4L 1/2 turn LH, _while_ 1L+2M, 3L+4M 1/2 turn RH
    (i.e. turning corners)
::
    _5-6_   1s/3s cross to 2nd/4th place own side _while_ 2s & 4s cast
    up
::
    _7-8_   1L+2L, 3L+4L 3/4 turn LH _while_ 1M+2M, 3M+4M 3/4 turn RH
    (i.e. turning corners)
::
    End 1s between 2s, 3s between 4s, all facing down
9-16::
    All dance down for 3 bars, 1s & 3s form arches & turn outer dancers
    in & up under arches (order now 2 1 4 3) & all dance up. 1s & 3s
    remain in centre facing up.
17-24::
    1s & 3s lead up to top & cast, 1s to 4th place, 3s to 2nd place. 2 3
    4 1. 2s+3s also 4s+1s dance RH across
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13133, '2020-09-15 00:19:30.279812+00', '2023-02-04 01:19:48.70006+00', 14001, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up); 1s turn 1.1/4 LH to face 1st corner
9-12::
    1s set to & turn 1st corner 2H, end facing 2nd corner
13-24::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s meet in the middle
    again & pass RSh to face 3rd corner positions
25-32::
    1s+corners dance 1/2 diag reel of 4, pass RSh to face 1st corner
    (pstn) & 1s+corners dance 1/2 diag reel of 4.  1s end 2nd place own
    side
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13406, '2020-12-02 01:19:34.067021+00', '2023-02-04 01:19:48.732488+00', 19154, 3, NULL, 'ace', '1-8::
    1s lead down & back up, remain in centre facing up, 2s step in
    behind 1s ready for …
9-16::
    1s+2s dance allemande, 1s end facing 1st corners
17-32::
    1s dance Corner Chain with 1st & 2nd corners :
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end in centre, facing up NHJ.
    2 1 3
33-40::
    1s dance up to top, cast, meet, dance down & cast up to 2nd place
    own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12077, '2019-08-30 09:54:09.20339+00', '2023-02-04 01:19:48.949916+00', 19427, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig 8 (1s cast, 2s cross up) _while_ 5s+4s+3s
    dance mirror reels of 3 giving hands (5s in/up). End 5s in centre
    NHJ between 4th/5th place, 4s in 5th place, 3s in 4th place
9-12::
    1s turn 2s (Ladies RH,  Men LH) 1s end in orig place, 2s NHJ face up
    _while_ 5s dance RH across on own sides with 4s+3s.  5s end facing
    up NHJ
13-16::
    2s followed by 5s dance up between 1s & cast, 2s to 3rd place, 5s to
    2nd place  _while_ 3s+4s Set+Link
17-20::
    1s+5s also 4s+3s turn partners 3/4 2H into line in centre facing
    partner (Men facing up, Ladies facing down) & set
21-28::
    1s+5s also 4s+3s dance half a Celtic Reels (8 bars)
29-32::
    1s+5s also 4s+3s turn partners 3/4 2H to own side and all set.
    Finish 5 1 2 3 4', 0);
INSERT INTO 'dancecrib' VALUES (11552, '2019-01-30 01:57:05.901079+00', '2022-12-18 16:42:54.549379+00', 12772, 1, 202, 'ace', '1--::

  1c & 4c cross RH | cast inwards (2c & 3c step out) ; 1c+4c ½ RHA | all set (2,4,1,3)

9--::

  All repeat same pattern from new positions (4,3,2,1)

17--::

  All W A&R ; all M A&R

25--::

  1c dance up to top ; 1c followed by 4c+3c+2c cast (2,3,4,1)', 2);
INSERT INTO 'dancecrib' VALUES (9192, '2016-06-16 22:41:45.089709+00', '2023-02-04 01:19:48.977005+00', 16908, 3, NULL, 'ace', '1-8::
    All dance 1/2 Grand Chain, set & turn partners 2H.  (3)(2)(1)
9-16::
    All dance Reflection reels of 3 (1s in & up to start) ending with 1s
    dancing up to face 1st corners pstns as 2s continue to 3rd place
17-24::
    1s dance 1/2 diag reel with 1st crnrs & pass RSh to face 2nd crnr
    pstns, 1s dance 1/2 reel with 2nd crnrs & curve to right to 1M
    b''tw''n 2s, 1L b''tw''n 3s
25-32::
    All Set+Link for 3 to 2 1 3 (all on opp sides), all chase clockwise
    1/2 way to 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5157, '2013-08-21 08:31:01.627162+00', '2023-02-04 01:19:49.060738+00', 2484, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+3s advance NHJ & with free hand join with 2s & 4s,  retire into
    longwise set across the dance; all dance 1/2 parallel RSh reels of 4
    across
17-24::
    All dance 1/2 R&L at each end of set (across to start); end couples
    & middle couples turn RH 1.1/2 times to form Sq.Set
25-32::
    All Ladies petronella turn to next Ladies'' place to right & set,
    repeat to meet partner (all have progressed 1 place to right),
    Ladies face out
33-48::
    All dance full Schiehallion Reel.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (15321, '2022-12-19 01:19:38.040142+00', '2023-02-04 01:19:49.081216+00', 21122, 3, NULL, 'ace', '1-8::
    1s+3s dance R&L
9-16::
    All dance 8H round & back
17-24::
    1s+3s dance Men''s chain to finish 1L+3L facing out
25-40::
    All dance Schiehallion reels. 1M+3M finish facing clockwise
41-44::
    1s & 3s (Men leading) chase 1/4 clockwise passing behind 2s/4s.
    1M/3M dance RSh round 2M/4M to face them _while_ 1L/3L dance RSh
    round 2L/4L to face
45-48::
    2s+1s also 3s+4s circle 4H round to left
49-56::
    All dance parallel RSh reels of 4 across set.
57-60::
    1s & 3s pass 2s/4s RSh & chase 1/4 way clockwise (Men leading) to
    finish in 3rd/1st places
61-64::
    3s+1s dance 1/2 R&L to finish in original positions 1 2 3 4
::
    Repeat with 2s+4s starting', 0);
INSERT INTO 'dancecrib' VALUES (8056, '2013-10-01 08:46:47.037348+00', '2023-02-04 01:19:49.109634+00', 15104, 3, NULL, 'ace', '1-8::
    All set & 1/2 turn RH, pull back RSh & dance out to opposite sides &
    set
9-16::
    1s dance down to 2nd place & 1/2 turn 2H, 1s cast round 3rd corner
    to meet in middle RSh to RSh 1M (facing down 1L up)
17-24::
    1s dance modified "Snake Pass":
::
    1L+2L+3L & 1M+2M+3M dance LH across, 1s pass RSh as 1L leads up
    followed by 3L+2L to 1L place & down Ladies'' side to end 1L between
    3s in 3rd place
::
    _while_ 1M followed by 2M+3M dance down to 3M place & up Men''s side
    to end 1M between 2s in 1st place
25-32::
    1s 1/2 turn 2H & pull back RSH & dance out ends & cast into 2nd
    place own sides then 1s dance down to 3rd place as 3s step up', 0);
INSERT INTO 'dancecrib' VALUES (14522, '2022-01-10 02:19:09.652183+00', '2023-02-04 01:19:49.132714+00', 15136, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L; 1s+2s turn partner 1.1/4 RH to face partner in
    line up/down centre, Men facing up, Ladies facing down
9-16::
    All set, dance 1/2 reel of 4, middle couple (2M+1L) turn 1.1/4 LH
    _while_ partners chase clockwise 1/4 round to face partner again in
    line across
17-24::
    All set, dance 1/2 reel of 4, middle couple (2M+1L) turn 1.1/4 LH
    _while_ partners chase clockwise 1/4 round to face partner again in
    line up/down centre
25-32::
    1s+2s dance 1/2 reel of 4; all turn partner 1.1/4 RH to own side.  2
    1', 0);
INSERT INTO 'dancecrib' VALUES (5158, '2013-08-21 08:31:01.667058+00', '2023-02-04 01:19:49.14714+00', 9004, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-16::
    1L & 3M set advcg to face prtnrs & dance 1/2 diag reel then 3L & 1M
    cross to own side as 1L & 3M dance into 3rd & 1st pls own side  3 2
    1
17-24::
    2s+1s dance RH across & end facing on own sides, 3s+2s+1s dance 1/2
    Grand Chain  (1)(2)(3)
25-32::
    All set & 1s cast down _while_ 2s cross up as 3s cross RH  2 (1) 3,
    1s cross RH & cast 1 place as 3s step up', 0);
INSERT INTO 'dancecrib' VALUES (8753, '2015-04-22 21:47:46.197887+00', '2023-02-04 01:19:49.18511+00', 1949, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place (2s step up 3-4); 1s turn LH once round &
    cast to 3rd place (3s step up 7-8)
9-16::
    2s+3s+1s dance reflection reels of 3 on sides (1s cross up LH, 3s
    dance out/down, 2s in/up to start)
17-24::
    1s cross up RH to BtoB in centre 2nd place facing own side & dance 6
    bars of Crown Triangles ending facing out between 2s & 3s on
    partner''s side
25-32::
    1s dance out between 2s & 3s, cast to right, across top/bottom of
    set & cast to 2nd place own sides, 2s+1s+3s Adv+Ret.  2 1 3', 3);
INSERT INTO 'dancecrib' VALUES (5160, '2013-08-21 08:31:01.69097+00', '2023-02-04 01:19:49.330926+00', 1951, 3, NULL, 'ace', '1-8::
    1s+2s RH across 1/2 way, 1s+3s LH across 1/2 way. 2s+3s RH across
    1/2 way _while_ 1s set, 1s dance up to top _while_ 3s cast to bottom
9-16::
    All set, top 2 Men change places diagonally RH with bottom 2 Ladies,
    all cross LH. Top 2 on Ladies'' side cross diag RH with bottom 2 on
    Men''s side
17-24::
    All reel of 3 on sides with 2M dancing out & up _while_ 2L dances
    out & down, 1s+2s turn RH (ready for Poussette) _while_ 3s cross RH
25-32::
    1s+2s dance 1/2 Diamond Poussette, 1s+3s dance 1/2 Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (13740, '2021-03-02 01:19:41.467902+00', '2023-02-04 01:19:49.383704+00', 12205, 3, NULL, 'ace', '1-4::
    1s & 3s cross RH, 1s+2s also 3s+4s change places LH on sides (all
    Men finish facing out)
5-12::
    2s+1s also 4s+3s dance Ladies'' Chain. 2 (1) 4 (3) 5
13-16::
    1s/3s  dance 1/2 Fig of 8 round 4s/5s then cross to face 1st corners
17-24::
    1s+3s set to & turn corners 2H, set to & turn 2nd corners 2H
25-32::
    All set, 1s & 3s turn partners 1.1/2 RH & cast down 1 place. 2 4 1 5
    3', 0);
INSERT INTO 'dancecrib' VALUES (13078, '2020-08-10 00:19:29.674451+00', '2023-02-04 01:19:49.414254+00', 1953, 3, NULL, 'ace', '1-8::
    1s & 4s set, 1s lead down under arch made by 4s who dance up, 1s
    cast up to 3rd place as 4s cast to 2nd place (2s/3s step up/down
    5-6) & all couples set.  2 4 1 3
9-16::
    2s+4s also 1s+3s dance LH across & RH across back to place
17-24::
    2s+4s also 1s+3s dance reels of 4 across (2M+4L, 1M+3L pass LSh to
    start)
25-32::
    All circle 8H round & back.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12755, '2020-04-11 10:53:32.019454+00', '2023-02-04 01:23:08.350393+00', 18550, 3, NULL, 'ace', '1-8::
    1s set, lead down, cross & cast up behind 3s into 2nd place on opp
    sides (2s step up 3-4)
9-16::
    2s+1s+3s dance mirror reels of 3 on sidelines (1s in/up, 2s
    out/down, 3s out/up) joining NH with partner where possible. 2s and
    3s loop into place at end of reel
17-24::
    2s+1s+3s Adv+Ret; 2s+1s+3s circle 6 hands 1/2 round to Left (3) 1
    (2)
25-28::
    1s dance 1/2 diag R&L with 2M and 3L (dancers in 1st cnr pstns)
29-32::
    1s dance 1/2 diag R&L with 3M and 2L (dancers in 2nd cnr pstns). End
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7954, '2013-08-21 08:31:51.813512+00', '2023-02-04 01:23:13.563191+00', 7172, 3, NULL, 'ace', '1-8::
    1s dance RSh parallel reels of 3 on opposite sides (RSh to 2s)
9-16::
    1s dance RSh parallel reels of 3 on own sides (RSh to 2s)
17-24::
    1s lead down & cross over below 2s & cast down behind 3s, lead back
    to top & cast to 2nd place on opposite sides to face 1st corners
25-32::
    1s set & turn 1st corners, set & turn 2nd corners (1s end on sides
    in 2nd place opposite sides)
33-40::
    2s+1s+3s Adv+Ret, 1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (11553, '2019-01-30 02:13:40.304614+00', '2022-12-18 16:45:07.013698+00', 14161, 1, 202, 'ace', '1--::

  1c cast to 3pl _as_ 3c dance up and loop to 1pl ; all set | cross RH (3x,2x,1x)

9--::

  All Petronella Turn | PdB R then PdB L to places as on [8] facing clw ; chase clw ½ (1,2,3)

17--::

  2c (1c following) lead down ; and up ready for

25--::

  1c+2c Allemande (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3934, '2013-08-21 08:30:39.550954+00', '2023-02-04 01:18:22.160334+00', 56, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s set & dance 1/2 RH across, all set & dance 1/2 LH
    across,  2s & 4s back to places, 1s & 3s in middle facing down NHJ
9-16::
    1s & 3s dance down 1 place, set, dance back up to places & cast 1
    place to face 1st corners
17-24::
    1s & 3s set & turn 1st corners RH, set & turn 2nd corners RH
25-32::
    1s & 3s turn partner LH, cast 1 place on opp sides & turn partner RH
    1.1/2 times to 2nd place own side.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (5164, '2013-08-21 08:31:01.740957+00', '2023-02-04 01:19:49.52831+00', 1966, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, DoSiDo & set
9-16::
    1s lead down, cross below 2s & cast down round 3s.  1s lead up,
    cross & 1M casts down round 3M _while_ 1L casts round 2L to face 1st
    corners
17-24::
    1s dance 1/2 reel of 4 with 1st corners & 1/2 reel of 4 with 2nd
    corners
25-32::
    1s 1/2 turn partner LH (2 bars), turning inwards to turn partner RH
    (2 bars) to end in 2nd place opp sides. All circle 6H 1/2 round to
    left to places 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13134, '2020-09-15 00:19:31.137183+00', '2023-02-04 01:19:49.553498+00', 17904, 3, NULL, 'ace', '1-8::
    1M+2L also 3M+4L set, cross RH; 1L+2M also 3L+4M set, cross LH.  (2)
    (1) (4) (3)
9-16::
    All set, all Adv+Ret; 2s+1s 1/2 turn partner RH to face up in centre
    _while_ 4s+3s turn partner RH & face down ready for …
17-24::
    2s+1s Allemande up, 3s+4s Allemande down.  Bar 22: 3s+4s drop hands
    & pass RSh to own side.  1 2 3 4
25-32::
    1s dance 1/2 Fig 8 down round 2s; 1s+2s change placeson side (dance
    between 2s), 1s+3s change places on side (dance between 3s)
33-40::
    1s dance 1/2 Fig 8 down round 4s; 1s dance in/down & loop into 4th
    place (4s step up) _while_ 2s dance in/down & loop round 3s to 1st
    place. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5165, '2013-08-21 08:31:01.748965+00', '2023-02-04 01:19:49.585327+00', 1969, 3, NULL, 'ace', '1-8::
    1L+3M change places RH & dance round 2s to end on partner''s right,
    1s & 3s dance clockwise to end 1s facing up (3rd pl) 3s facing down
    _while_ 2s advance & about turn back to places
9-16::
    3s+2s+1s circle 6H round & back
17-24::
    3s+1s set, dance RH across & 3s cast to original places _while_ 1s
    dance up to top
25-32::
    1s+2s dance 3/4 double Fig of 8 (1s cast to start) & 1s cross RH', 0);
INSERT INTO 'dancecrib' VALUES (5166, '2013-08-21 08:31:01.75703+00', '2023-02-04 01:19:49.615961+00', 10102, 3, NULL, 'ace', '1-8::
    1L dances RSh round prtnr to face 2L, 1s (1L leads) dance 1/2 Tandem
    reel of 3 across with 2s (LSh to 2L) ending 2s to top & 1s facing
    down
9-16::
    1s dance down (4 bars), Lady turns under Mans arm & dance up to face
    3L
17-24::
    1s (1L leads) dance 1/2 Tandem reel of 3 across with 3s (RSh to 3L),
    1s dance up to top & cast to 2nd place opposite sides
25-32::
    2s+1s+3s Set+Link for 3 twice to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (15322, '2022-12-19 01:19:38.611308+00', '2023-02-04 01:19:49.637302+00', 18555, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp sides

1-8::
    1s & 4s dance Figs of 8 1s round 2s, 4s round 3s 1 2 (3) (4)
9-10::
    1s+4s set (Men turn left about to face out) _while_ 2s & 3s 1/2 turn
    2H (skip change) & release inside hands
11-14::
    1s+4s chase 1/2 way anticlockwise to change places _while_ 2s+3s
    dance 4H round to left & release hands to join 2H with partner.
15-16::
    4s & 1s set _while_ 2s & 3s 1/2 turn 2H using skip change to sides 4
    2 (3) (1)
17-24::
    4s+1s cross RH & cast. (2s+3s step up/down 19-20); 4s+1s Set+Link 2
    1 (4) (3)
25-32::
    1s & 4s dance the Spiral Progression to change places:
::
    _25-28_ 1L+4L turn 3/4 RH to give LH to prtnr & Bal-in-Line, on 2nd
    setting step 1M & 4M turn left about (face clockwise) & join nearer
    hands with partner
::
    _29-30_ 1s+4s in a diagonal line rotate 1/4 way clockwise
::
    _31-32_ 1M+4M drop hands & dance to next position on side lines
    _while_ 1L+4L continue turning RH to finish on sides 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (12078, '2019-08-30 09:54:09.379743+00', '2023-02-04 01:19:49.660502+00', 1974, 3, NULL, 'ace', '1-8::
    1s set to 2s on side & change places RH; 1s set to 2s on sides &
    change places LH
9-16::
    1s+2s dance DoSiDo on sides (1s dance down middle, 2s up sides to
    begin); 1s+2s repeat DoSiDo, 2s dancing up middle, 1s down sides
17-24::
    1s+2s dance R&L up/down set ending in centre, 2H joined with partner
25-32::
    1s+2s dance Poussette. End 2 1', 0);
INSERT INTO 'dancecrib' VALUES (9914, '2017-06-05 11:31:02.237552+00', '2023-02-04 01:19:49.727102+00', 17650, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-4::
    1s & 4s cross RH, cast down/up into 2nd / 3rd place (2s step up, 3s
    down)
5-8::
    1s+4s dance 1/2 R&L, end with 4s facing 2s, 1s facing 3s
9-16::
    All turn person facing RH.  All dance DoSiDo with same person
17-24::
    2s+4s & 1s+3s dance RH across.  1s+ 4s set to partner and cross RH
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15323, '2022-12-19 01:19:38.748625+00', '2023-02-04 01:19:49.747301+00', 19637, 3, NULL, 'ace', '1-8::
    1s dance down (2s step up), cast behind 3s to 3rd place (3s dance in
    & up to 2nd place); 2s+3s+1s dance 1/2 mirror reels of 3 on the
    sides (3s out/up to start). 1 3 2
9-16::
    1s+3s dance double Fig of 8 (1s cross down, 3s dance up to start). 1
    3 2
17-20::
    1s+3s+2s dance 1/2 mirror reels of 3 (3s dance out/up to start). 2 3
    1
21-24::
    1s cross RH & cast up to 2nd place (3s step down 23-24)
25-32::
    1s dance 1/2 Fig of 8 (1M up between 2s, 1L down between 3s). All
    turn RH & set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15308, '2022-12-19 00:32:38.703001+00', '2022-12-19 00:39:56.91498+00', 21093, 1, 202, 'ace', '1--::

  1c turn RH | cast off (2c up) ; Petronella turn into facing lines3 across | all set

9--::

  Reels3 across, 1c RSh to 1cnrs

17--::

  Diagonal R&L

25--::

  All set | 1c Petronella turn to 2plx ; all chase clw ½ (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (5108, '2013-08-21 08:31:00.516607+00', '2023-02-04 01:19:43.723893+00', 1856, 3, NULL, 'ace', '1-8::
    1s+2s+3s set twice & turn partner 2H
9-16::
    1s+2s+3s circle 6H round & back
17-24::
    1s cast 1 pl, cross LH & cast down 1 pl, lead up to top turning to
    own sides to face down _while_ 2s dance up, cast & follow 1s to face
    them in 2nd pl
25-32::
    1s+2s dance the Rondel', 0);
INSERT INTO 'dancecrib' VALUES (5167, '2013-08-21 08:31:01.763431+00', '2023-02-04 01:19:49.769682+00', 14363, 3, NULL, 'ace', '1-8::
    1L sets & casts 1 place, 1L dances 1/2 Fig of 8 round 3s & ends in
    middle _while_ 1M stands for 2 bars & sets then crosses & casts to
    end behind 1L
9-16::
    1s+3L dance LH across & end facing 2M, 1s dance (1L leading) 1/2
    diagonal Tandem reel of 3 with 2M+3L passing 2M Rsh to start
17-24::
    1s+3M dance RH across & end facing 2L, 1s dance 1/2 diagonal Tandem
    reel of 3 with 2L+3M passing 2L Lsh to start & 1L ends between 2s in
    3rd place as 1M ends between 3s in 1st place
25-32::
    All set & pivot, 1s turn RH 1.1/4 to end in 2nd place opposite sides
    _while_ 2s+3s chase clockwise 1/2 way
::
    Repeat from 2nd place with1M starting & dancing the track previously
    danced by 1L', 0);
INSERT INTO 'dancecrib' VALUES (5168, '2013-08-21 08:31:01.840847+00', '2023-02-04 01:19:49.941053+00', 1977, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s cast 1 place as 2s dance up, 2s+1s+3s set
9-16::
    1s+3s dance RH across, 1s cast 1 place as 3s dance up, 2s+3s+1s set
17-24::
    2s+3s+1s circle 6H round & back
25-32::
    1s dance up to top, cast to 2nd places & 2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (10332, '2017-12-22 15:44:17.467241+00', '2023-02-04 01:19:49.969262+00', 17770, 3, NULL, 'ace', '{{explanation}}
3s+4s start on opp sides

1-4::
    1s dance down, 4s dance up 1 place _while_ 2s cast up, 3s cast down.
    1s+4s circle 4H 1/2 round to Left
5-8::
    4s+1s turn partner 2H to finish NHJ 4s facing up, 1s facing down
9-12::
    4s+1s take prom hold with partner & dance 1/2 reels of 3 across (4s
    pass 2L RSh, 1s pass 3L RSh).  Drop hands bar 12, 1M+4L face up,
    4M+1L down in prom hold
13-16::
    _1/2_ reels of 3 across (1M+4L pass 2L LSh, 4M+1L pass 3L LSh).
    Drop hands bar 16, join hands in prom hold with partner, 1s facing
    up 4s facing down
17-20::
    _1/2_ reels of 3 across (1s pass 2L RSh, 4s pass 3L by RSh) Bar 20
    1s end on Ladies'' side, 4s on Men''s side
21-24::
    2M+1L & 4L+3M turn RH _while_ 2L+4M & 1M+3L turn LH
25-32::
    1s+4s dance the Tournée.  Begin bar 25 taking prom hold dancing into
    centre.  Finish on sidelines  2 4 1 3
33-40::
    1s+4s dance 1/2 RH across _while_ 1s+3s dance 1/2 LH across.  All
    set.  4s+2s dance 1/2 LH across _while_ 3s+1s dance RH across.  All
    set
41-44::
    2s dance 1/2 Fig 8 crossing down to start _while_ 4s cast up one
    place & dance down one place _while_ 1s+3s dance 1/2 double Fig 8
    (1s cast, 3s cross up to start)
45-48::
    2L+4L & 1L+3L turn LH _while_ 2M+4M & 1M+3M turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5169, '2013-08-21 08:31:01.854216+00', '2023-02-04 01:19:50.003401+00', 14766, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, turn RH once round (4bars) & set
9-16::
    1s cross down between 2s & cast down round 3s, cross up & cast up
    round 2s to places
17-24::
    All set & 1s cross RH _while_ 2s+3s dance RH across 1/2 way, all set
    & 1/2 turn RH ending in Prom hold
25-32::
    All dance Allemande.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5170, '2013-08-21 08:31:01.862668+00', '2023-02-04 01:19:50.025729+00', 1982, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, passing LSh dance RSh round 1st corner to
    end 2nd place in centre facing opposite sides
9-16::
    1L+2s dance also 1M+3s dance RH across, 1s pass RSh & dance LH
    across with other couple 1s end 2nd place own sides
17-24::
    2s+1s+3s set, 1/2 turn 2H & twirl to opposite sides & cross back RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5171, '2013-08-21 08:31:01.87186+00', '2023-02-04 01:19:50.050966+00', 10554, 3, NULL, 'ace', '{{title}}
Reel

1-8::
    1s set to partner, petronella turn, set advancing to join RH, set
    moving (Lady backwards) into centre of set
9-16::
    1M+2s also 1L+4s dance reels of 3 on sides, 2s & 4s pass partner RSh
    & 1M passes 2L LSh _while_ 1L passes 4L LSh, 2s & 4s continue reel
    to end in partners place _while_ 1s 1/2 turn RH end in centre facing
    3s (M facing M)
17-24::
    1s+3s Set+Link & circle 4H round to left
25-32::
    1s+3s set to partner (1L+3L & 1M+3M nearer hands joined) & 1s cross
    out between 3s, 1s dance round (1L behind 2s, 1M behind 4s) to
    partners original place (All now in partners place)

{{title}}
Strathspey

1-8::
    All set to partners, petronella turn (Lady facing in & Man out) &
    dance DoSiDo with partner
9-16::
    All dance double reels of 4 passing LSh in centre
17-24::
    All 1/2 turn RH into allemande hold facing clockwise, all turn left
    about (Man dancing on the spot) & dance anticlockwise 1 place, all
    turn LH to new positions
25-32::
    All dance interlocking reels of 4', 0);
INSERT INTO 'dancecrib' VALUES (8319, '2014-07-29 12:58:58.188728+00', '2023-02-04 01:19:50.081801+00', 15364, 3, NULL, 'ace', '1-8::
    1s+2s / 3s+4s dance the Bourrel;
::
    _1- 4_   1M+2L & 3M+4L set advancing, 3/4 turn 2H & twirl to end
    BtoB (Lady facing up & Man down) as prtnrs chase anticlockwise to
    face prtnr
::
    _5- 8_   Set to partners & turn 2H, 2s+3s ending on own sides having
    changed places _while_
::
    1s and 4s remain in the centre with both hands joined ready for
9-16::
    1s+4s dance 1/2 Diamond Poussette to end on the sidelines; 2s+4s
    also 1s+3s Set+Link, to 4 2 3 1
17-20::
    2s turn partner LH  1.1/2 times _while_ 3s turn partner RH 1.1/2
    times, as 4s+1s chase clockwise 1/2 way round (1) (2) (3) (4)
21-24::
    1L+2M cross RH then 1M+2L cross LH as 1L+3L cross LH
25-28::
    1M+3L also 1L+4M cross RH; 1M+4L cross LH
29-32::
    1s+4s & 2s+3s dance LH across once round', 0);
INSERT INTO 'dancecrib' VALUES (9193, '2016-06-16 22:41:45.325292+00', '2023-02-04 01:19:50.136031+00', 17007, 3, NULL, 'ace', '1-8::
    1s set  (2s step up) & cast 1 place. 1s turn RH  to 2nd  place on
    own sides, 1M facing  up, 1L down.
9-16::
    1s+2s+3s dance 1/2  RSh reel of three on sidelines. 1L+2L & 1M+3M
    dance Set+Link
17-24::
    1s+2s+3s dance 3 couple Bourrel:
::
    _17-20_    1M+2L also 3M+1L set advcg & 3/4 turn 2H to line up/down
    middle then pull back RSh to face own prtnrs as 3L& 2M chase
    anticl''wise to face them
::
    _21-24_    All set & turn 2H to own sides.  2 1 3
25-32::
    1s+3s Set & Rotate', 0);
INSERT INTO 'dancecrib' VALUES (15324, '2022-12-19 01:19:39.231051+00', '2023-02-04 01:19:50.29122+00', 18276, 3, NULL, 'ace', '1-4::
    1s dance LSh round each other & cast to 2nd place own side (2s step
    up bars 3-4)
5-8::
    1s lead down crossing over, 1M dances above partner _while_ 1L turns
    under his R arm. 1s cast up round 3s to 2nd place on opposite sides.
    2 (1) 3
9-16::
    1s dance 1/2 diag R&L (1M up, 1L down), 1s dance 1/2 diag R&L (1M
    up, 1L down) (3) (1) (2)
17-20::
    1s dance 1/2 diagonal RSh reel of 4 with 3rd corners, 1s pass RSh to
    face 4th corners
21-24::
    1s dance 1/2 diagonal RSh reel of 4 with 4th corners 2 1 3
25-32::
    2s+1s+3s dance the knot.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5172, '2013-08-21 08:31:01.888412+00', '2023-02-04 01:19:50.337377+00', 13367, 3, NULL, 'ace', '1-8::
    All set & dance reflection reels of 3 on sides (1s in & down to
    start)
9-16::
    1s dance DoSiDo, 1s cast 1 place & cross RH
17-20::
    1s dance RSh round 1st crns & turn right about (end 1L facing up to
    2s, 1M facing down) _while_ 1st crns dance DoSiDo
21-24::
    1s dance 1/2 Double Triangles
25-28::
    1s dance RSh round 2nd crns & turn right about to end 1L facing M''s
    side, 1M facing L''s side _while_ 2nd crns dance DoSiDo
29-32::
    1s dance 1/2 Double Triangles ending 2nd place own sides.', 0);
INSERT INTO 'dancecrib' VALUES (12379, '2019-12-05 01:28:28.668337+00', '2023-02-04 01:18:16.322031+00', 18537, 3, NULL, 'ace', '1-8::
    1s dance in, cast (2s step up), dance down between 3s, cast up &
    pass LSh to face 1st corners
9-24::
    "Best Set in the Hall" figure:
::
    _9-12_    1s set to 1st corners & dance RSh round each other into
    3rd corner (pstn) _while_ 1st corners dance in & turn right about to
    face their original position
::
    _13-16_  1s+1st crnr person set & 1st crnr persons dance RSh round
    each other into diag opp crnrs _while_ 1s dance in & pivot to right
    to face 2nd crnrs
::
    _17-24_  1s repeat bars 9-16 with 2nd corners & end passing RSh to
    2nd place opposite sides.  (3)(1)(2)
25-28::
    3L followed by 1L+2L cast down (behind Men''s line) _while_ 2M
    followed by 1M+3M cast up (behind Ladies'' side). (2)(1)(3)
29-32::
    2s cross RH _while_ 1s+3s dance 1/2 RH across & all set. 2 3 1

{{explanation}}
Repeat 2 more times Strathspey then 3 times Reel', 0);
INSERT INTO 'dancecrib' VALUES (5173, '2013-08-21 08:31:01.896764+00', '2023-02-04 01:19:50.366361+00', 9069, 3, NULL, 'ace', '1-8::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L
9-16::
    All dance the Targe:
::
    _9-10_    Ladies 3/4 turn RH _while_ Men dance 1/4 way round
    anticlockwise
::
    _11-12_  Men turn partners once round LH
::
    _13-16_  Repeat bars 9-12
17-24::
    Set to partner & 1/2 turn 2H to face corners, all set & 1/2 turn 2H
25-32::
    2s+4s dance 1/2 Ladies'' Chain, 1s+3s dance 1/2 Ladies'' Chain.  2 3 4
    1', 0);
INSERT INTO 'dancecrib' VALUES (13136, '2020-09-15 00:19:31.731761+00', '2023-02-04 01:19:50.497043+00', 10370, 3, NULL, 'ace', '1-8::
    All 4 couples set, cross RH, all chase clockwise 1/2 round
9-16::
    All turn partner 1.1/2 2H, all chase clockwise 1/2 round
17-24::
    All dance 1/2 reels of 4 on sides; 3s+2s+1s (bottom 3 couples) dance
    1/2 reels of 3 on sides (1s+2s pass RSh to start)
25-32::
    4s+1s also 2s+3s dance "Slip Knot" (as Knot but bars 31-32:  4s+1s
    also 2s+3s dance 1/2 LH across).  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (5176, '2013-08-21 08:31:01.922393+00', '2023-02-04 01:19:50.520638+00', 10892, 3, NULL, 'ace', '1-8::
    1s+2s set, 1M+2L change places RH, 1L+2M change places LH & 2s+1s
    cross RH
9-16::
    2s+1s dance RH across, 1s+3s dance LH across
17-24::
    2s+1s+3s dance reels of 3 on sides (2s RSh to 1s to start)
25-32::
    2s+1s+3s circle 6H round for 6 steps, pivot left & chase back to
    place', 0);
INSERT INTO 'dancecrib' VALUES (5177, '2013-08-21 08:31:01.932209+00', '2023-02-04 01:19:50.549327+00', 1996, 3, NULL, 'ace', '1-8::
    2s+3s+4s set, petronella turn into middle & set twice with Ladies
    turning to face up on 2nd setting
9-16::
    2s+3s+4s dance up between 1s, cast on opposite sides 1 place, dance
    down middle & cast to places on opposite sides
17-24::
    1s set & cast to bottom _while_ 2s+3s+4s set & cross up 1 place, all
    set & cross RH
25-32::
    1s dance 1/2 Fig of 8 round 4s & turn RH 1.1/2 times

{{explanation}}
All end on opposite sides in order 2 3 4 1 & repeat the dance with Men dancing Ladies part', 0);
INSERT INTO 'dancecrib' VALUES (5178, '2013-08-21 08:31:01.940376+00', '2023-02-04 01:19:50.571086+00', 1998, 3, NULL, 'ace', '1-8::
    1s cast 1 place, cross LH & cast round their 2nd corners to 2nd
    place opp sides facing 1st corners
9-16::
    1s dance reel of 3 on opposite sides passing 1st corner RSh to
    start.  2 (1) 3
17-28::
    1s dance Fig of 8 Grand Chain:
::
    1s change places RH with 1st crnrs on sides as 2nd crnrs cross diag
    RH, 1s cross diag LH as others change pl LH on sides, continue this
    Fig back to place (Ladies in top pl always cross diag with Man in
    3rd pl as others change pl on sides)
29-32::
    1s set & cross RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10068, '2017-09-03 23:44:35.801776+00', '2023-02-04 01:19:50.657712+00', 16199, 3, NULL, 'ace', '{{explanation}}
Circle, Man has Lady on his right

1-8::
    All circle round to Left and back
9-16::
    All turn partner RH, dance LSh round corner back to place (Ladies
    polite turn)
17-24::
    Men Adv (2), Ret (2) twice _while_ Ladies stand (2), Adv (2), Ret
    (2), Adv (2)
25-32::
    Men circle round to Right, pivot (bar 28) & chase back to place
    _while_ Ladies circle round to Left, pivot & slip step to Right to
    finish facing partner
33-40::
    All turn partner RH (4 bars) & turn corner 1.1/4 LH to end in circle
    with new partner', 0);
INSERT INTO 'dancecrib' VALUES (11446, '2019-01-01 01:56:44.44222+00', '2023-02-04 01:19:50.68483+00', 19010, 3, NULL, 'ace', '1-8::
    1s set, join 2H & slip down middle (4 steps),  drop hands, set &
    cast up round 3s into 2nd place own side (2s step up 3-4)
9-16::
    1s dance reflection reels of 3 on own side giving hands as
    appropriate (1s in/up, 2s out down, 3s out up). 2s & 3s dance
    "loops" at end of reel into place
17-24::
    1s turn 1st corner RH, pass RSh, turn 2nd corner RH, pass RSh into
    2nd place own side (corners dance 4 bars)
25-28::
    2s+1s+3s circle 6H round to Left into lines across (Men in 3rd place
    facing up, Ladies in 1st place facing down)
29-32::
    All set, pull back RSh & cast to own sides  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5179, '2013-08-21 08:31:01.950089+00', '2023-02-04 01:19:50.7884+00', 2004, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, set & cross back RH
9-16::
    1s lead down the middle & back to place
17-24::
    1s set, cast 1 place & turn RH (long turn)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5175, '2013-08-21 08:31:01.914299+00', '2023-02-09 12:06:19.618091+00', 1992, 3, NULL, 'ace', '1-8::

    All set, 1s+2s also 4s+5s Petronella-in-tandem (skip change steps)

    to opposite side _while_ 3s cast & dance clockwise thru end couples

    to opp side

9-16::

    All set, 2s+1s also 5s+4s dance RH across 1/2 way _while_ 3s cross

    RH & all turn partner RH

17-24::

    1s & 3s set, cross RH, cast down 1 place & turn partner RH 1.1/4

    times to face 1st corner

25-28::

    1s & 3s dance RSh round 1st corner _while_ corners advance to hold

    RH as Ladies dance under Men''s arm & retire to places, 1s & 3s pass

    RSh to end in line in centre of set facing opposite sides (RSh to

    RSh)

29-32::

    1M+2s also 3L+5s dance LH across _while_ 1L+3M 3/4 turn LH to end

    between 4s & Bal-in-Line across

33-40::

    1M followed by 2M+2L chase down behind 4L to bottom of set & loop

    round as 3L followed by 5L+5M dance behind 4M to top & loop round

    _while_ 1L+4L also 4M+3M turns RH & join in chase (1L behind 2L & 3M

    behind 5M) to form 1 large circle (5 3 4 1 2) & all dance clockwise

    for 4 steps

41-48::

    All circle 10H round to Left for 4 steps, set (retaining hands) & 8

    steps back to right.  (5 3 4 1 2)', 0);
INSERT INTO 'dancecrib' VALUES (11901, '2019-06-20 21:03:01.065044+00', '2022-12-18 21:26:49.5916+00', 8865, 1, 1645, 'ace', '1-::

  1c+2c set | &frac12; RHA ; 2c & 1c turn P 1&frac12; RH (2,1,3)

9-::

  1c pass LSh, cast round 1cnr & turn away to end BtoB, 1W facing up ; 2c+1W & 1M+3c Circle3 to L & 1c turn to face P

17-::

  1c pass LSh into Reels3{6} on sides starting RSh to 2cnr | 1c cross RH & retain hands facing down as 3c cast out & back to 3pl

25-::

  1c+3c RHA ; 2c+1c LHA (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (13742, '2021-03-02 01:19:42.574323+00', '2023-02-04 01:19:50.824946+00', 12207, 3, NULL, 'ace', '1-8::
    1s Adv+Ret, 1s dance 1/2 Fig of 8 round 2s. (1) 2 3
9-16::
    1s dance 1/2 reels of 3 on opposite sides (1s dance in & down to
    start); 1s cross RH, cast up 1 place & cross to face 1st corner (2s
    step down 15-16)
17-24::
    1s dance 1/2 diagonal RSh reel of 4; 1s pass RSh to dance 1/2 reel
    with 2nd corners & finish on opp sides  (2) (1) (3)
25-32::
    2s+1s+3s Adv+Ret; All turn partners 1.1/2 RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5180, '2013-08-21 08:31:01.958088+00', '2023-02-04 01:19:50.856294+00', 10160, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set, dance RH across 1/2 way, set, 1s+4s dance LH
    across 1/2 way _while_ end couples cross RH
9-16::
    All dance reels of 4 on sides
17-24::
    All set, cross RH & chase clockwise to own side.  3 1 4 2
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5181, '2013-08-21 08:31:01.967874+00', '2023-02-04 01:19:50.887268+00', 14388, 3, NULL, 'ace', '1-4::
    1s & 4s cross RH & cast in 1 place (2s+3s step up/down bars 3-4).
5-12::
    1s & 4s dance Figs of 8 (1s round 2s, 4s round 3s)
13-16::
    1s dance up between 2s turning them with nearer hand _while_ 4s
    dance down between 3s turning them with nearer hand to end 2 (1) (4)
    3
17-24::
    All 4 couples set & 1s+4s dance RH across 1/2 way, all turn partners
    RH (4 bars) & end 2 4 1 3
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5182, '2013-08-21 08:31:01.976143+00', '2023-02-04 01:19:50.917277+00', 10344, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left (end 1s facing down & 2s up), 1s+2s
    set, 2s turning inwards cast to 1st places _while_ 1s lead down to
    2nd places
9-16::
    1s dance down behind 3s & 3/4 turn 2H, set & 1L followed by partner
    dance up
17-24::
    1s dance RH across with 2L & dance LH across with 3M 1s end facing
    1st corners
25-32::
    1s set to 1st corners & turn 2H, set to 2nd corners & turn 2H, 1s
    end facing 3rd corners
33-40::
    1s dance diagonal reel of 4 with corners ending in 2nd places own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (5183, '2013-08-21 08:31:01.984568+00', '2023-02-04 01:19:50.944752+00', 2008, 3, NULL, 'ace', '1-8::
    1s cross RH & change places LH with 2s on sides, 1s cross RH &
    change places LH with 3s on own sides
9-16::
    3s+1s set, cross RH, dance 1/2 Fig 8 round 2s, dancing up behind 2s
    (3s leading) & crossing down to places own side    2 1 3
17-24::
    2s+1s set, cross RH, dance 1/2 Fig 8 round 3s, casting down behind
    3s (1s leading) & crossing up between 3s staying in the centre ready
    for…
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5184, '2013-08-21 08:31:01.994272+00', '2023-02-04 01:19:51.055278+00', 2010, 3, NULL, 'ace', '1-8::
    1M+2L set & turn RH, 1s set & cast to 2nd place
9-16::
    1L+2M repeat above Fig
17-24::
    1s & 2s dance DoSiDo, 1M+2M & 1L+2L dance DoSiDo on sides
25-32::
    1s+2s dance double Fig of 8 (1s down between 2s) 1s dancing down to
    2nd place & 2s up to top to end', 0);
INSERT INTO 'dancecrib' VALUES (13137, '2020-09-15 00:19:32.248944+00', '2023-02-04 01:19:51.068533+00', 8146, 3, NULL, 'ace', '{{explanation}}
Round the Room, Couples facing anticlockwise, Man with partner on Right NH joined.  Start on outside foot

1-4::
    _3_ steps forward & point (2 bars), partners change places Lady
    crossing in front of Man (3 steps & point)
5-8::
    Partners change places, Man crossing in front of Lady (3 steps &
    point), 3 steps backwards & point (2 bars)
9-12::
    Partners turn about (turn away from each other), take 2H & step
    along line of dance, swing foot (Man R, Lady L), step back & swing
    other foot
13-16::
    Take ballroom hold & waltz anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (13890, '2021-04-05 00:19:35.00938+00', '2023-02-04 01:19:51.148762+00', 19486, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s+4s cross to opp sides

1-8::
    1s+2s & 3s+4s set, dance RH across, 1s & 4s cast out of ends to
    2nd/3rd place (2s & 3s lead up/down).  2 1 (4) (3)
9-16::
    1s+4s dance RH across. 1M+4L face up, 4M+1L face down & dance 1/2
    LSh Alternating Tandem reels of 3 on sides (2s & 3s dance loops at
    end)
17-24::
    1s+4s repeat, dancing LH across & 1/2 RSh Alternating Tandem reels
    of 3 on sides
25-32::
    Reels of 3 across, 1s & 4s, in prom hold with partners (1s RSh to
    2L, 4s RSh to 3L). 1s end on Men''s side (1M in 2nd place, 1L in 3rd
    place) _while_ 4s end on Ladies'' side (4M in 3rd place, 4L in 2nd
    place)
33-40::
    1L+4L change places RH & retain hands _while_ 1M & 4M set, 1s+4s
    dance 1/2 RH across, 1s+4s turn partner RH (4 bars).  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (8780, '2015-06-15 11:40:40.70863+00', '2023-02-04 01:19:51.181262+00', 2014, 3, NULL, 'ace', '1-8::
    1s turn RH, cast down to bottom & dance up to face 1st corners
9-16::
    1s set to 1st corners & turn 2H, set to 2nd corner & turn 2H
17-24::
    1s dance reels of 3 on opposite sides giving LSh to 1st corner & end
    turning LH to …
25-32::
    1s dance RH across (Lady with 2s & Man with 3s, pass RSh & dance LH
    across with other couple
33-40::
    1s+3s dance the Knot
41-48::
    1s+4s dance 1/2 R&L & turn partners RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (5187, '2013-08-21 08:31:02.162586+00', '2023-02-04 01:19:51.203558+00', 12877, 3, NULL, 'ace', '1-8::
    All circle 6H round to right & back
9-16::
    All dance Ladies'' Chain for 3 couples:
::
    _9-12_     Ladies dance RH across for 2 places _while_ Men chase
    anticlockwise 1 place, all turn partners LH.
::
    _13-16_   Repeat 9-12 ending new places in promenade hold facing in.
    3 1 2
17-24::
    All dance Tournee for 3 couples:
::
    All dance in (Men LSh to LSh) facing anticlockwise & dance on 2
    places, drop RH & turn to sidelines in new places, Ladies facing in,
    Men facing out.  All turn LH twice round (4 bars).  2 3 1
25-32::
    All dance reverse Schiehallion Reels for 8 bars
::
    _25-26_     Ladies dance 1 place clockwise to next Man''s place (to
    left) facing out, Men dance into partner''s place & face in
::
    _27-28_     Ladies dance into Man''s place facing in, Men dance 1
    clockwise to next Ladies'' place (to left) & face out
::
    _29-32_     Repeat 25-28 to end 1 place clockwise round set facing
    in   3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (14523, '2022-01-10 02:19:10.794581+00', '2023-02-04 01:19:51.225523+00', 17962, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L (no polite turns); 1s followed by 2s lead down
    middle
9-16::
    2s followed by 1s lead up; 2s+1s set & cross to own sides. 2 1
17-24::
    2s+1s dance RH across; 2s+1s chase clockwise back to place
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5189, '2013-08-21 08:31:02.256158+00', '2023-02-04 01:19:51.480509+00', 2016, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place & dance LH across to end facing
    corners
9-16::
    1s & 4s change places with corners RH, 2s+3s dance LH across _while_
    1s+4s chase clockwise 1/2 way & all set.  4 2 3 1
17-24::
    4s+2s also 3s+1s turn 2H on sides into 4H round to left & turn
    partners 2H in centre ready for…
25-32::
    4s+2s also 3s+1s dance 1/2 Diamond Poussette, 4s+1s dance out ends &
    cast to places.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14287, '2021-09-08 00:19:35.529831+00', '2023-02-04 01:19:51.515142+00', 20439, 3, NULL, 'ace', '{{title}}
Strathspey

1-4::
    1s+3s dance 3/4 RH across finishing in centre, 1s with backs to 4s,
    3s with backs to 2s
5-8::
    All dance forward (2 steps) passing 2 people RSh & turn about so 2s
    face 4s in centre, & all set
9-16::
    4s+2s dance 3/4 LH across to finish in square set 2 1 4 3 (Ladies on
    partner''s LH); All Set+Link, Ladies face out
17-24::
    All dance 8 bars of Schiehallion reels.  4 3 2 1
25-32::
    All circle 8H round & back
33-64::
    Repeat 1-32

{{title}}
Reel

65-128::
    Repeat 1-64 in reel time', 0);
INSERT INTO 'dancecrib' VALUES (5138, '2013-08-21 08:31:01.264234+00', '2023-02-04 01:19:46.819772+00', 1907, 3, NULL, 'ace', '1-8::
    1s cross down RH, cast down behind 3s & turn RH
9-16::
    2s+3s+1s circle 6H round & back
17-24::
    3s+1s 1/2 turn RH into Allemande hold (3s face down & 1s up) & dance
    LSh round each other to change places, 1s+3s dance LH across & 1s
    end facing 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (14487, '2021-12-18 01:43:55.256979+00', '2023-02-04 01:19:51.979274+00', 15537, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 2s+1s+3s dance 1/2 mirror reels of 3 on
    sides (2s out/down, 1s in/up, 3s out/up). 1s end NHJ facing down
9-16::
    1s dance down (3 bars), 1L dances under 1M''s left arm to change
    sides; 1s dance up, cast up behind 2s to 2nd place & turn LH to face
    1st corner (pstn)
17-24::
    1s turn corner RH, partner LH, 2nd corner (pstn) RH & partner LH to
    end 1L between 3s at top, 1M between 2s at bottom
25-32::
    All Set+Link for 3; 1s turn RH to 2nd place own side _while_ 2s & 3s
    chase clockwise 1/2 round to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8999, '2015-11-30 08:59:43.604579+00', '2023-02-04 01:19:52.008938+00', 10908, 3, NULL, 'ace', '1-8::
    1L casts, followed by 1M, crosses below 3s, casts up behind Men &
    across to original place.  1s face down
9-16::
    RSh reels of 3 on sides
17-24::
    1s dance down NHJ (3 steps), dance up & cast to 2nd place (2s step
    up 23-24)
25-32::
    1s+3s dance RH across, 1s+2s dance LH across', 0);
INSERT INTO 'dancecrib' VALUES (5195, '2013-08-21 08:31:02.417897+00', '2023-02-04 01:19:52.045145+00', 12107, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s+2s+3s dance 1/2 RSh reels of 3 on sides
9-16::
    2s+1s dance LH across, 3s+2s+1s dance 1/2 LSh reels of 3 on sides
17-24::
    1s cross RH, cast 1 place & dance 1/2 Figs of 8 Lady round 2s & Man
    round 3s
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8177, '2014-02-10 10:26:20.641973+00', '2023-02-04 01:19:52.075854+00', 15098, 3, NULL, 'ace', '1-8::
    Ladies dance RH across & keeping hold of RH in middle take partners
    LH & Bal-in-Line then 1/2 turn partners LH into centre
9-16::
    Men dance RH across & keeping hold of RH in middle take partners LH
    & Bal-in-Line then 1/2 turn Ladies LH into centre & face partners
17-32::
    All dance double Celtic Reel:
::
    Each couple passes partner RSh to change places, Men dance LSh round
    each other 3/4 way _while_ Ladies dance on 1 place clockwise. This
    is repeated with Ladies dance LSh 3/4 round each other _while_ Men
    dance on 1 place clockwise.
::
    Repeat back to positions
33-48::
    All dance full Schiehallion reels
49-56::
    1s & 3s take partners 2H & slip step to the opposing position (Men
    pass BtoB) & turn partners 2H, slip step back to original positions
    (Ladies pass BtoB) & turn partners 2H to original positions.
57-64::
    2s & 4s repeat bars 49-56
65-80::
    All dance 1/2 Grand Chain & set to partner (bars 71-72); continue
    Grand Chain back to place & set to partner (bars 79-80)
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5196, '2013-08-21 08:31:02.43044+00', '2023-02-04 01:19:52.383574+00', 13328, 3, NULL, 'ace', '1-8::
    1s & 4s set & cast in 1 place, 2s+1s dance RH across _while_ 4s+3s
    dance LH across.  2 1 4 3
9-16::
    1L followed by 2L+2M+1M cross down to 3M place & chase round
    anticlockwise to 3L place _while_ 4L followed by 3L+3M+4M cross up
    to 2M place & chase round clockwise to 2L place.  3 4 1 2
17-24::
    4s+1s dance 1/2 RH across _while_ corners set diagonally & set twice
    in St.Andrews Cross (1s & 4s facing clockwise as 3s & 2s facing
    anticlockwise) then 1s & 4s, giving RH to partners, dance out to own
    sides as corners set diagonally.  3 1 4 2
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10069, '2017-09-03 23:44:36.251955+00', '2023-02-04 01:19:52.508244+00', 16803, 3, NULL, 'ace', '1-8::
    All 4 couples DoSiDo.  All turn partners RH, 2s+3s end in middle
    facing up in allemande hold, 1s+4s end on sides
9-16::
    2s+3s dance allemande. 1 3 2 4
17-24::
    1s+4s cross RH, cast down/up (3s & 2s step up/down) & 1s+4s dance
    1/2 Figs 8 round end couples (1s up round 3s, 4s down round 2s)
25-32::
    All circle 8H round & back.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (13138, '2020-09-15 00:19:33.363051+00', '2023-02-04 01:19:52.534967+00', 18355, 3, NULL, 'ace', '1-8::
    1s+3s dance RH across _while_ 2s+4s chase anticlockwise 1/2 round to
    opp side; 1s+3s chase clockwise 1/2 round _while_ 4s+2s dance LH
    across
9-12::
    1M+3M chase anticlockwise 1/2 round set _while_ 1L+3L set advancing,
    1/2 turn 2H, pull back RSh to face partner up/down set
13-16::
    1s+3s set to partner & turn 1.1/4 RH to reform square set
17-24::
    2s+4s repeat bars 9-16. All Ladies face out
25-32::
    All dance 4 bars Schiehallion Reel (1 place round anticlockwise);
    set to partner (Ladies touch hands in centre) & turn 2H.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5198, '2013-08-21 08:31:02.450146+00', '2023-02-04 01:19:52.558425+00', 2033, 3, NULL, 'ace', '1-8::
    All Adv+Ret 1 step, all dance DoSiDo with partner, all Adv+Ret 1
    step
9-16::
    1s dance 1/2 Fig of 8 round 2s then 1/2 Fig of 8 round couple in 3rd
    place (4s), ending in 2nd place own sides (2s cross up to 1st place
    bars 15-16)
::
    _while_ 3s+4s dance 1/2 RH across, 3s dance 1/2 Fig of 8 round
    couple in 3rd place (4s) & Adv+Ret 1 step.  (2) 1 (4) 3
17-24::
    2s+1s also 4s+3s dance full Ladies'' Chain. Bars 23-24 1s+4+3s turn
    partner LH to face up in centre _while_ 2s turn LH to 1st place own
    sides
25-32::
    1s+4s+3s dance Allemande. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5199, '2013-08-21 08:31:02.458271+00', '2023-02-04 01:19:52.586257+00', 11816, 3, NULL, 'ace', '1-8::
    1s set cast 1 place & lead down between 3s & cast up round 3s into
    middle
9-16::
    1s in prom hold dance diagonal reel of 3 with 2nd corners (RSh to
    2L)
17-24::
    1s dance reel of 3 with 1st corners (LSh to 2M) & end BtoB in 2nd
    place facing own sides
25-32::
    1s set in double triangles position, turn 3rd corner RH into lines
    across, all set & 1s turn RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5200, '2013-08-21 08:31:02.466322+00', '2023-02-04 01:19:52.608038+00', 2034, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, set & 1/2 turn RH to face 1st corners
9-16::
    1s turn 1st corner LH, turn partner RH, turn 2nd corner LH & turn
    partner RH to end 2nd place own sides
17-24::
    1s dance reels of 3 on sides (RSh to 3rd corner to start) ending
    BtoB facing own sides
25-32::
    1s dance Double Triangles ending 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (12390, '2019-12-05 01:29:47.077218+00', '2023-02-04 01:19:52.638185+00', 2035, 3, NULL, 'ace', '1-8::
    Reels of 4 on sides - start 1L & 3L cross down to pass 2M & 4M RSh
    _while_ 1M & 3M cross up to pass 2L & 4L RSh. End 2 (1) (3) 4
9-16::
    1s turn RH twice round to face 2nd corners _while_ 3s turn 1.1/2 RH
    to own sides; 1s set to 2nd corners & set to 1st corners
17-24::
    1s dance RSh round each other & dance 1/2 Fig 8 on opp sides (1M RSh
    round 2L, LSh round 3L, 1L RSh round 3M, LSh round 2M). 2 (1) 3 4
25-32::
    2s+1s+3s Adv+Ret; 1s lead down & cross to 4th place own sides (3s+4s
    step up 31-32).  2 3 41', 0);
INSERT INTO 'dancecrib' VALUES (3936, '2013-08-21 08:30:39.783547+00', '2023-02-04 01:18:22.521626+00', 60, 3, NULL, 'ace', '1-8::
    2s turn LH, 2s cast 1 pl (L up & M dn) as 1s & 3s petronella turn to
    middle, 2s cross between 1s/3s & cast to 2nd pl as 1s & 3s
    petronella to opp side
9-16::
    1s & 3s set as 2s cross RH & all dance RSh reels of 3 on sides (2M
    up & 2L down)
17-20::
    1L+2M also 2L+3M change places RH (on sides), 1L+3L also 1M+3M
    change places LH (on sides)
21-24::
    3L+2M also 1M+2L change places RH (on sides), 2s turn LH to end
    facing 3rd corner (pstn)
25-28::
    2s change places with 3rd corners RSh, corner persons turn in middle
    LH to face their partners (in 4th corner positions)
29-32::
    1s & 3s pass partner RSh to change places & corner persons turn LH
    in middle to end in 2nd place own sides.  (All now have new
    partners)
::
    Repeat with new partners', 0);
INSERT INTO 'dancecrib' VALUES (13139, '2020-09-15 00:19:33.550319+00', '2023-02-04 01:19:52.692579+00', 11280, 3, NULL, 'ace', '1-8::
    1s lead down & back remaining in middle, 2s step in ready for …
9-16::
    1s+2s dance Poussette, Bars 15-16: 1s dance additional 1/4 turn,
    pull back RSh , 1M facing up, 1L down
17-24::
    1M+2s also 1L+3s dance reels of 3 across (RSh to 2nd corner to
    start), 1s turn RH to face 1st corners
25-32::
    1s turn 1st corner LH, partner RH, 2nd corner LH, partner RH,
    remaining in centre to repeat or lead down to 4th place at end of
    2nd turn', 0);
INSERT INTO 'dancecrib' VALUES (5202, '2013-08-21 08:31:02.484383+00', '2023-02-04 01:19:52.71+00', 2037, 3, NULL, 'ace', '1-8::
    1s dance reflection reels on opposite sides
9-16::
    1s dance down to end BtoB facing 3s, 1s+3s set, dance 1/2 reel of 4
    & 1s end turning RH to face up (on opp sides)
17-24::
    1s dance up to end BtoB facing 2s, 1s+2s set, dance 1/2 reel of 4 &
    1s end turning RH to 2nd place opp sides
25-32::
    1s cast round 1st crnrs into lines across _while_ 2s+3s cross RH,
    all set, 1s cast to 2nd pl own side _while_ 2s+3s change pl RH on
    sides & all set. 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (12547, '2020-02-02 02:47:45.243804+00', '2023-02-04 01:19:52.992974+00', 13905, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig 8 round 2s; 1s turn 2H remaining in centre facing
    each other, 1s+2s set with 1s advancing to end BtoB (2s step up 5-6)
9-16::
    RSh reels of 4 across, bars 15-16 1s dance across/down to 2nd place
    own sides
17-24::
    2s+1s dance Slip Knot (as Knot but bars 23-24 1s+2s dance 1/2 LH
    across)
25-32::
    1s set, cross RH, cast up round 2s & cross to 2nd place own side.  2
    1', 0);
INSERT INTO 'dancecrib' VALUES (9000, '2015-11-30 08:59:43.684519+00', '2023-02-04 01:19:53.031503+00', 10883, 3, NULL, 'ace', '{{explanation}}
2 facing 2 round room, Lady on Man''s right

1-8::
    All dance RH across & LH across
9-16::
    1s (couple facing clockwise) lead thro'' 2s, drop hands, cast away
    from each other back to places & turn RH (4 bars)
17-24::
    2s repeat bars 9-16 dancing thro'' 1s
25-32::
    1s make arch, 2s with NHJ dance under.  Each couple continues
    dancing under arch or making arch alternately, passing 4 couples.
    Face 5th couple to start again', 0);
INSERT INTO 'dancecrib' VALUES (11186, '2018-09-30 22:19:42.414324+00', '2023-02-04 01:19:53.066609+00', 18617, 3, NULL, 'ace', '1-8::
    2s+3s dance RH across, giving LH to corners in St Andrews Cross set
    & turn corners into centre
9-16::
    1s+4s dance RH across, giving LH to corners in St Andrews cross set
    & turn to original places
17-24::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L
25-32::
    1s+4s dance 1/2 R&L, all set & cross RH
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5204, '2013-08-21 08:31:02.530715+00', '2023-02-04 01:19:53.19331+00', 2042, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place & turn LH to end Lady between 2s facing
    down & Man between 3s facing up
9-16::
    2s+1s+3s set twice & 1s turn RH 1.1/4 times to end 2nd place on own
    sides
17-24::
    2s+1s+3s set, cross RH, set & cross back LH (1s end facing 1st
    corners)
25-32::
    1s set to 1st corners, set to 2nd corners & turn RH 1.1/2 times back
    to places', 0);
INSERT INTO 'dancecrib' VALUES (15133, '2022-10-05 00:19:43.062371+00', '2023-02-04 01:19:53.335261+00', 21024, 3, NULL, 'ace', '1-4::
    1s dance 1/2 reels of 3 on own sides (1s in & down to start) 3 2 1
5-8::
    1s cross up into 1/2 reels of 3 on opposite sides (1) 2 3
9-16::
    1s+2s+3s dance reels of 3 on the sides (all cross down from top to
    2nd places on opposite sides). 1 (2) (3)
17-20::
    1s set, cast 1 place (2s step up bars 19-20) (2) 1 (3)
21-24::
    1L+2M also 1M+3L dance Modified Set+Link.
::
    _21-22_ 1L+2M also 1M+3L set
::
    _23-24_ All dance diagonally right, pull back RSh to face up or
    down, then finish 1L between 2s facing down & 1M between 3s facing
    up _while_ 2M & 3L dance back to same places. (2M/3L facing down/up)
25-32::
    1L+2s & 1M+3s Set+Link for 3. All turn RH. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5206, '2013-08-21 08:31:02.548901+00', '2023-02-04 01:19:53.365055+00', 2045, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, 1s cast 1 place & cross RH
9-16::
    1s+3s set, dance 1/2 RH across, set & 1s cross up to 2nd place
    _while_ 3s cast to 3rd place
17-24::
    2s+1s+3s dance reels of 3 on sides with 2s crossing down to start
25-32::
    2s+1s dance double Fig of 8 (2s cross down to start)', 0);
INSERT INTO 'dancecrib' VALUES (5207, '2013-08-21 08:31:02.556856+00', '2023-02-04 01:19:53.399326+00', 2048, 3, NULL, 'ace', '{{explanation}}
Circle around the room with partner on Mans right

1-8::
    All circle round to left & back
9-16::
    Ladies dance Figs of 8 (in front & round partner, in front of next
    Man & round back to place)
17-24::
    Men dance Figs of 8 (in front & round partner to start)
25-32::
    All dance Grand Chain

{{explanation}}
Repeat with new partner', 0);
INSERT INTO 'dancecrib' VALUES (5208, '2013-08-21 08:31:02.566851+00', '2023-02-04 01:19:53.433065+00', 13447, 3, NULL, 'ace', '1-8::
    All Set+Link dancing on to meet next person in corner position, All
    Set+Link dancing on to meet next person in square formation
9-12::
    All set to new partner & 1/2 turn 2H (couples in 1st & 3rd places
    facing in, couples in 2nd & 4th places facing each other)
13-16::
    Couples in 1st & 3rd places advance to meet original partner &
    retire to 2nd or 4th places _while_ couples in 2nd & 4th places
    retire (2 steps) & advance to meet original partner in 1st or 3rd
    places
17-24::
    Ladies dance RH across 1/2 way _while_ Men dance 1 place
    anticlockwise & turn new partner LH, repeat bars 17-20
25-32::
    Dancers in 1st & 3rd places dance 1/2 Ladies Chain, dancers in 2nd &
    4th place dance 1/2 Ladies Chain (all now in original places)
33-40::
    All dance 8H once round to left (6 bars) & turn right about to dance
    on 1 place clockwise to end 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (5209, '2013-08-21 08:31:02.579341+00', '2023-02-04 01:19:53.461178+00', 14694, 3, NULL, 'ace', '1-8::
    1s dance in, touch hands & cast to 2nd place (2s step up bars 3-4),
    1s cross up RH & cast to 2nd place opposite sides
9-16::
    1s dance DoSiDo with 3rd corners, 2s+1s+3s PdB Coupe
17-24::
    1s slip step down & back, remain in middle with both hands joined
25-32::
    1s 1/2 turn 2H _while_ 2s+3s set advancing, 2s+1s+3s »Celtic Curve«
    (dance out 2 bars, pulling back RSh & curve by right back to place).
    All set', 0);
INSERT INTO 'dancecrib' VALUES (3938, '2013-08-21 08:30:39.807059+00', '2023-02-04 01:18:22.582687+00', 11258, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, 2s+1s+3s set & cross RH
9-16::
    1s cast round 1st corners, change places RH to form lines of 3
    across (1M between 2s & 1L between 3s), 2s+1s+3s set & all change pl
    RH
17-24::
    1s cast round 4th corners, cross RH & dance 1/2 reels of 3 on
    opposite sides RSh to person on right
25-32::
    1s dance 1/2 reels of 3 across (1M LSh to 3L & 1L LSh to 2M) & turn
    LH in middle to end in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5205, '2013-08-21 08:31:02.540755+00', '2023-02-04 01:19:53.304329+00', 2044, 3, NULL, 'ace', '1-8::
    1L+2L+3L circle 3H round to left on own sides, 1M+2M+3M circle 3H
    round to left
9-16::
    1s lead down the middle & back ending facing 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners ending in 2nd
    place opposite sides
25-32::
    1s set twice & turn RH 1.1/2 times to places', 0);
INSERT INTO 'dancecrib' VALUES (5212, '2013-08-21 08:31:02.67976+00', '2023-02-04 01:19:53.565637+00', 10459, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, cross LH & cast round 2nd corners to 1M
    between 2s facing down & 1L between 3s facing up
9-16::
    All Adv+Ret (1 step), change places with opposite person RH, Adv+Ret
    again & 2s+3s change places RH _while_ 1s turn RH to face 1st crnrs
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5213, '2013-08-21 08:31:02.688105+00', '2023-02-04 01:19:53.596531+00', 9854, 3, NULL, 'ace', '1-8::
    All circle 8H round to left to places
9-16::
    All dance round in St Andrews Cross formation with Ladies in centre
    RH & back with Men in centre LH
17-24::
    1s+3s dance RH across once round & each couple dances out to chase
    clockwise (Men leading) to opposite side
25-32::
    2s+4s repeat
33-40::
    1s+3s repeat but LH across & Ladies leading
41-48::
    2s+4s repeat
49-56::
    All Men dance R&L (1M+4M & 2M+3M to start)
57-64::
    All Ladies dance R&L (1L+2L & 3L+4L to start)
65-72::
    1s+3s in prom hold cross passing LSh & turn to left & cast back to
    own place
73-80::
    2s+4s repeat
81-88::
    All dance round in St Andrews Cross formation with Ladies in centre
    RH & back with Men in centre LH
89-96::
    All circle 8H round to right & end advancing into centre with hands
    raised', 0);
INSERT INTO 'dancecrib' VALUES (5214, '2013-08-21 08:31:02.69853+00', '2023-02-04 01:19:53.774665+00', 2053, 3, NULL, 'ace', '1-8::
    1s pass RSh to face 1st corners, sets to corners (1 step each), 1s
    turn to 2nd place opposite sides, 2s+1s+3s Adv+Ret
9-16::
    1M circle 3H round to left with 2L+3L as 1L circle round with 2M+3M,
    1s 1/2 turn 2H to top of set for Poussette
17-24::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8570, '2015-02-13 12:47:42.452378+00', '2023-02-04 01:19:53.80848+00', 15573, 3, NULL, 'ace', '1-4::
    1s cross down to 2nd place on opp. sides giving RH and face in (2s
    move up on [1-2]) and all set.
5-16::
    R&L for 3 couples
17-20::
    1L dance half a diagonal Reel of 3 with 2M and 1M, giving LSh to 2M,
    she finishes where she started the reel.
::
    Order is now:   Ladies'' side:2L  2M  3L  Men''s side: 1M  1L  3M
21-24::
    1L dance another half diagonal Reel of 3 with 3M and 2M, giving RSh
    to 3M, to finish again where she started.
::
    Order: Ladies'' side2L  3M  3L  Men''s side:  1M  1L  2M
25-28::
    1s change places diagonally with 3s RH, all set on the sidelines
::
    Order: Ladies'' side: 2L  1M  1L  Men''s side: 3M  3L  2M
29-32::
    1M with 3L (middle places) change places LH, all set on the
    sidelines.
::
    All have got now a new partner: Ladies'' side: 2L   3L   1L  Men''s
    side:  3M  1M  2M

{{explanation}}
Note:	Repeat the dance with new partners. After 3 times through all will be back with their original partners

::
    First lady in bars 17 - 24 actually dances the track of a complete
    reel of 3 on the men''s sideline.', 0);
INSERT INTO 'dancecrib' VALUES (15060, '2022-09-05 00:19:36.944033+00', '2023-02-04 01:19:53.830972+00', 21098, 3, NULL, 'ace', '1-8::
    1s+2s set, turn partner 2H flowing into circle 4H round to left
9-16::
    1s set, cross RH & cast (2s step up), 1s turn LH to face 1st corners
17-24::
    1s turn corner RH, partner LH, 2nd corner RH & cross LH with partner
    to 2nd place own side
25-32::
    1s+2s also 1M+3s dance RH across, 1s pass RSh to dance LH across
    with other couple', 0);
INSERT INTO 'dancecrib' VALUES (13743, '2021-03-02 01:19:44.889215+00', '2023-02-04 01:19:53.861633+00', 12214, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Grand Chain
9-12::
    1s NHJ dance down & cast up round 3rd couple to 2nd place & cross to
    face 1st corners (2s step down 11-12)
13-20::
    1s dance 1/2 diagonal reel; pass RSh to dance 1/2 reel with 2nd
    corners
21-24::
    3s+1s+2s set to partners & turn RH into Allemande hold
25-32::
    3s+1s+2s dance Allemande 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5215, '2013-08-21 08:31:02.723434+00', '2023-02-04 01:19:53.885061+00', 2056, 3, NULL, 'ace', '{{explanation}}
1s & 3s start on opp sides

1-8::
    All set, turn 2H, 1s+2s also 3s+4s circle left
9-12::
    All dance 1/2 RSh reels of 4 on sides & begin to pass RSh again to
    form lines across (Men facing same Lady as at bar 9)
13-16::
    All dance 1/2 reels of 4 across & begin to pass RSh again to form
    lines on sides (Men facing same Lady as at bar 9)
17-24::
    Repeat bars 9-16
25-32::
    1s+2s also 3s+4s dance 1/2 RH across 1/2 way, 1s+4s set & dance 1/2
    R&L.  (2)4(1)3', 0);
INSERT INTO 'dancecrib' VALUES (5216, '2013-08-21 08:31:02.731721+00', '2023-02-04 01:19:53.902711+00', 7572, 3, NULL, 'ace', '{{explanation}}
Round the Room 3 facing 3

{{title}}
Strathspey

1-8::
    All set HS, dance DoSiDo with opposite dancer
9-16::
    Middle dancers (passing LSh) dance 1/2 diagonal reel of 4 with
    opposite person on their right, pass LSh in middle to dance 1/2
    diagonal reel of 4 with opposite person on their left.  All finish
    on opposite sides.
17-24::
    Middle dancers dance RH across with partner on their right &
    opposite person. Repeat dancing LH across with partner on left &
    opposite person
25-32::
    All circle 6H round 1/2 way to left (to original places), all
    advance passing other dancer RSh to meet next trio
33-64::
    Repeat bars 1-32 with next trio

{{title}}
Reel

1-64::
    Repeat above but set twice in place of HS & end 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5217, '2013-08-21 08:31:02.741643+00', '2023-02-04 01:19:54.087953+00', 2060, 3, NULL, 'ace', '1-8::
    1s+2s set twice, set advancing to face up/down with nearer hands
    joined with partner & set again
9-24::
    1s+2s dance 12 bar reel of 4 on 3 sides of a square (pass facing
    person RSh & couple at top pass LSh _while_ others dance round in
    2nd place to face up but DO NOT CROSS) 1s+2s pass RSh on sides & 1s
    pass each other LSh to face 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting & end facing 2nd corners
33-40::
    1s dance RSh reels of 3 across (Lady with 2s & Man with 3s) & pass
    LSh to
41-48::
    1s dance reels of 3 on sides giving RSh to 2nd corners & 1s cross LH
    to 2nd place on own side', 0);
INSERT INTO 'dancecrib' VALUES (3939, '2013-08-21 08:30:39.816946+00', '2023-02-04 01:18:22.633777+00', 9196, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Figs of 8 (Man up round 2s &
    Lady down) & end facing 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting & end BtoB facing 2nd corners
17-24::
    1s dance reels of 3 across (Man with 2s & Lady with 3s, 1s pass 2nd
    corner RSh to start) & end facing 1st corners
25-32::
    1s turn 1st corners RH, partner LH, 2nd corners RH  & partner LH to
    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (3940, '2013-08-21 08:30:39.830434+00', '2023-02-04 01:18:22.687431+00', 10663, 3, NULL, 'ace', '1-8::
    1s set, dance down to face out 2nd place, 1M+3M turn LH _while_
    1L+3L turn RH into double triangle positions
9-16::
    2s+1s+3s dance Double Triangles (15-16 1s turn right about on spot
    to face 1st corners)
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & cross RH to 2nd
    places
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5218, '2013-08-21 08:31:02.749805+00', '2023-02-04 01:19:54.11622+00', 2063, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s cross RH & cast 1 place (Man up, Lady
    down)
9-16::
    1s dance 1/2 reels of 3 across (1M with 2s & 1L with 3s), set in
    lines across & change places RH with opposite person
17-24::
    2s+1s+3s chase clockwise 1/2 way, 1s dance in & turn 1.1/4 RH to
    face 1st corner positions as 2s & 3s continue to chase on to places
    (as bar 16)
25-32::
    1s dance 1/2 reel of 4 with 1st corners, passing RSh dance 1/2 reel
    with 2nd corners & cross passing RSh to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5219, '2013-08-21 08:31:02.757895+00', '2023-02-04 01:19:54.134577+00', 9085, 3, NULL, 'ace', '1-8::
    1s cast 1 place, dance 1/2 Fig of 8 round 2s & turn LH to face 1st
    corners
9-16::
    1s turn 1st corners RH, pass RSh to 3rd corner & turn LH, pass LSh
    to own 2nd corner (corners dance 4 bars)
17-24::
    1s repeat with 2nd & 4th corners & end passing LSh to face 2nd
    corner (corners dance 4 bars)
25-32::
    1s dance reels of 3 on opposite sides (RSh to 2nd corners) & cross
    to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5220, '2013-08-21 08:31:02.864334+00', '2023-02-04 01:19:54.315356+00', 2069, 3, NULL, 'ace', '1-8::
    1M+2L also 2M+3L turn 2H, 1L+2M also 2L+3M turn 2H
9-16::
    All petronella to opposite side but passing partner RSh in turns
17-24::
    2s & 3s set to partners, 2s cross down LH to 3rd place _while_ 3s
    cast up 1 place, 3s lead up to top (opp side) _while_ 1s cast 1
    place & all set
25-32::
    All dance Grand Chain for 8 hands until all are back on owns sides
    2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (10016, '2017-07-23 15:58:13.621875+00', '2023-02-04 01:19:54.37237+00', 13603, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret, turn partners RH finishing in middle in prom hold,
    all facing up
9-16::
    1s+2s+3s Promenade, ending in original places
17-24::
    1s set, cast (2s step up), turn 1.1/4 RH into prom hold (1L on right
    of 1M) facing 3L
25-32::
    1s in prom hold dance RSh diag reel of 3 with 1st corners (3L+2M),
    1s end curving round to face 2L
33-40::
    1s in prom hold dance 1/2 LSh diag reel of 3 with 2nd corners
    (2L+3M). _While_ 2L+3M continue reel (i.e. 8 bar reel for 2L+3M), 1s
    dance down, cross below 3rd place & cast up to 2nd place own sides
41-48::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (13140, '2020-09-15 00:19:35.175019+00', '2023-02-04 01:19:54.562197+00', 8128, 3, NULL, 'ace', '1-8::
    1s cross L, face side couples (1M+3s, 1L+2s) & all set; 1M+3s also
    1L+2s dance RH across. All finish in original place in prom hold,
    1s+2s facing
9-16::
    1s+2s+3s dance promenade reel of 3 (1s+2s pass RSh). All finish in
    partner''s place facing partner
17-24::
    All set, pass partner RSh & join NH with ''new partner'' facing in;
    all Adv+Ret (1 step each) & cast back to original place facing
    partner
25-32::
    "Triangular Knot":
::
    _25-28_   All turn partner 1/2 RH into Allemande hold facing out,
    dance 1 place anticlockwise
::
    _29-32_   All turn Ladies into centre LH, all turn 3/4 LH to new
    place (1 place anticlockwise round).  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (8571, '2015-02-13 12:47:42.573016+00', '2023-02-04 01:19:54.598743+00', 15307, 3, NULL, 'ace', '1-4::
    1s+ 5s cross RH & cast down/up 1 place (2s+4s step up/down)
5-8::
    1M+2s  also 1L+3s+5M also 5L+4s dance circles round to Left.  1s+5s
    end in middle facing partners (Men facing down, Ladies facing up)
9-16::
    1s+5s set, dance 1/2 reel of 4; set advancing to partners & pass LSh
    to face 2nd corner positions
17-24::
    1s+5s dance 1/2 diag. reel of 4 with 2nd corners, turn LH to face
    1st corner positions, dance 1/2 diag. reel of 4 with 1st corners,
    turn LH to face 4th corner positions (partner''s 2nd corner position)
25-32::
    1s+5s dance 1/2 diag. reel of 4 with 4th corners, turn LH to face
    out on own sides, cast 1 place (3s+2s step up 31-32)    4 3 5 2 1', 0);
INSERT INTO 'dancecrib' VALUES (5221, '2013-08-21 08:31:02.879677+00', '2023-02-04 01:19:54.669493+00', 2077, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s cross RH, cast in 1 place & dance 1/2 Fig of 8 round 2s/3s
9-16::
    1s+4s dance RH across, Men loop round & in behind ptnr to dance LH
    across back to face crnrs (1s face 2s & 4s face 3s - Ladies facing
    Men)
17-24::
    All dance double reels of 4 giving LH in centre 1s & 4s do not
    complete reel but turn in to face other corners
25-32::
    All set twice & turn RH to form lines across
33-40::
    All dance reels of 4 across
41-48::
    1s & 4s lead up/down & cross, cast in 1 place own sides & all turn
    RH', 0);
INSERT INTO 'dancecrib' VALUES (10995, '2018-08-17 07:52:11.635952+00', '2023-02-04 01:19:54.703424+00', 18272, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s+2s Set+Link; 1s+3s Set+Link
17-24::
    *2s start* _while_ 1s+4s+5s dance mirror reels of 3 on sides (1s
    in/down to start)
25-32::
    1s set, cross down RH to 4th place (4s step up); 1s set, cross down
    LH to 5th place (5s step up)
::
    *New top couple start every 16 bars. Repeat until 1s back in 1st
    place, they stand for 16 bars _while_ 5s continue bars 17-32 ending
    back in 5th place*', 0);
INSERT INTO 'dancecrib' VALUES (8025, '2013-09-09 06:47:21.315983+00', '2023-02-09 11:54:48.131993+00', 2072, 3, NULL, 'ace', '{{explanation}}

2 chords - 3s+4s cross to opp sides on 2nd chord



1-8::

    1s cross down RH between 2s as 4s cross up RH between 3s, 1s+4s

    dance Fig of 8 round 2s & 3s on opposite sides to end 1s at top & 4s

    at bottom in prom hold facing 2M/3M.

9-16::

    1s dance RSh reel of 3 with 2s as 4s dance RSh reel of 3 with 3s

    ending with both hands in joined (Man behind partner) 1s facing 2M &

    4s facing 3M (1M & 4M BtoB}

17-24::

    1s+4s dance ''Hello Goodbye'' setting

25-32::

    1s+4s dance RH across (1L & 4L leading) with 3M+2M then LH across

    with 3L+2L & end 1s in 3rd place (opposite side) & 4s in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (7956, '2013-08-21 08:31:51.830437+00', '2023-02-04 01:23:13.686902+00', 7173, 3, NULL, 'ace', '1-8::
    1M+2L set & turn RH, 1L+2M set & turn RH
9-16::
    1s dance reflection reels of 3 on opposite sides
17-24::
    1s dance reflection reels of 3 on own sides
25-32::
    1s set, cross RH, cast 1 place & cross LH
33-40::
    1s+3s circle 4H round & back
41-48::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (14722, '2022-04-01 00:18:31.842243+00', '2023-02-04 01:18:29.098216+00', 20708, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s, set to partner, turn partner 2H flowing into 4H
    once round to left to finish in middle of set, 1s facing 2s & 3s
    facing 4s with NHJ with partners
9-16::
    All dance Interlocking Rondels:
::
    1s+2s  also 3s+4s dance Rondels but 1s & 4s pass each other (1s
    dance under arch made by 4s) on bar 16 to end 2 4 1 3 on the sides
17-24::
    2s+4s also 1s+3s dance RH across. 4s+1s dance LH across
25-32::
    2s+4s also 1s+3s dance Diamond Poussette.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14420, '2021-11-06 01:11:01.35056+00', '2023-02-04 01:19:54.846718+00', 19119, 3, NULL, 'ace', '1-4::
    1s+2s set, 1s+2s 1/2 turn partner 2H, finishing in centre, 1s facing
    down, 2s facing up NHJ
5-8::
    1s+2s set advancing to pass other couple LSh & 1/2 turn partner 2H
    to own side, 1s facing out.  2 1 3
9-16::
    2s+1s+3s dance 6 bar RSh reels of 3 on sides (1s pass 3rd corner RSh
    to start), 2s+1s change places (Ladies LH, Men RH).  1 2 3
17-24::
    1s Petronella turn & set; 1s turn 1.1/4 RH to own sides facing in
25-32::
    1s+2s+3s dance the Slip Knot:
::
    _25-30_   All 3 couples dance first 6 bars of standard Knot.  (3)
    (2) (1)
::
    _31-32_   1s (at bottom) turn LH to own side _while_ 3s+2s dance 1/2
    LH across to end on own side.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5222, '2013-08-21 08:31:02.891855+00', '2023-02-04 01:19:54.880028+00', 2084, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across 1/2 way & 2s+1s+3s dance 1/2 reel of 3
    (1s pass 2s RSh)
9-16::
    1s+2s (centre couples) dance LH across as 3s+4s chase 1/2 way
    clockwise all end on opp sides (4)(1)(2)(3), 1s+4s & 2s+3s turn RH
    on sides
17-24::
    All dance full reels of 4 on sides
25-32::
    All set, 4s & 2s (in 1st & 3rd places) cast 1 place (1s+3s step up)
    & all circle 8H round 1/2 way to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5223, '2013-08-21 08:31:02.900146+00', '2023-02-04 01:19:54.89275+00', 2085, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 1s+3s Set+Link
9-16::
    2s+3s+1s reel of 3 on sides (1s pass 3s RSh to start)
17-24::
    3s+1s+4s reel of 3 on sides (1s pass 4s LSh to start) & 1M+4M also
    1L+4L 1/2 turn LH to 2 3 4 1
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8572, '2015-02-13 12:47:42.605422+00', '2023-02-04 01:19:55.06839+00', 14138, 3, NULL, 'ace', '1-6::
    1M+2L set as 1L+2M 3/4 turn LH to finish 2M facing 1M, 1L facing 2L.
    1s+2s dance 1/2 diagonal reel of 4
7-8::
    2L dances across to 1L place, 1L to 1M place, 2M to 2L place, 1M to
    2M place (1s on men''s side, 2s on ladies'' side)
9-12::
    1s+2s set, Petronella-in tandem to middle, 1s facing up, 2s facing
    down
13-16::
    1s+2s Set+Link.  1s finish in 2nd place facing out, 2s in 1st place
17-20::
    2s+1s+3s dance 1/2 reels of 3 on sides (1M+2M, 1L+3L pass RSh).  Bar
    20 1s 3/4 turn LH to face opposite sides
21-24::
    3s+1s+2s dance 1/2 reels of 3 on sides (1M+3L, 1L+2M pass LSh).  Bar
    24 1s turn RH to own sides 2nd place
25-32::
    2s+1s+3s dance 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (13744, '2021-03-02 01:19:45.747064+00', '2023-02-04 01:19:55.103203+00', 20203, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s turn 1.1/2 LH to own side facing
    out/up
9-16::
    2s+1s+3s dance mirror reels of 3 on sides giving hands (2s in/down,
    1s out/up to start).  All end in centre NHJ with partner facing up
17-24::
    All advance (2 steps) & retire diagonally back down & out to own
    side; all turn partners RH to end Men facing up, Ladies facing down
25-32::
    All chase clockwise (3 steps), pull back RSh to turn all round &
    continue chase clockwise to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5224, '2013-08-21 08:31:02.908497+00', '2023-02-04 01:19:55.135436+00', 2089, 3, NULL, 'ace', '1-8::
    All cross RH & set, 1s & 3s petronella turn & set
9-16::
    1s+3s dance 1/2 reel of 4 in middle, 3s & 1s petronella turn & set.
    (3)(2)(1)(4)
17-20::
    3s+2s also 1s+4s circle 4H round to left but 2M+3L/4M+1L turn RH
    when on own sides as partners continue circle
21-24::
    3s+2s also 1s+4s circle 4H round to left but 2L+3M/4L+1M turn RH
    when on own sides as partners continue circle to end (3)(2)(1)(4)
25-32::
    3s+2s also 1s+4s dance the Knot but start setting in to join partner
    in Allemande hold.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5225, '2013-08-21 08:31:02.918689+00', '2023-02-04 01:19:55.171035+00', 14948, 3, NULL, 'ace', '1-8::
    1s set & cross RH, 1s cast 1 place & cross down between 3s then cast
    behind 4s to bottom of set
9-16::
    Men cross & pass partners RSh to face down, Men chase clockwise to
    own side (1M leading)
17-24::
    End couples turn RH & cast 1 place, set & dance 1/2 RH across
25-32::
    The new end couples repeat bars 17-24
33-40::
    All set & cross RH with new partners, top 2 couples & bottom 2
    couples dance RH across
41-48::
    Ladies cross & pass new partners RSh to face up, Ladies chase
    clockwise back to own side (1L leading)  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13988, '2021-05-03 00:19:34.304052+00', '2023-02-04 01:19:55.2901+00', 19828, 3, NULL, 'ace', '1-8::
    1s+2s dance 4H round & back
9-16::
    1s Petronella turn & set & repeat to 2nd place opposite sides (2s
    step up bars 11-12).  2 1
17-24::
    1s dance 1/2 Fig of 8 round 2s; 2s+1s turn partner RH into Promenade
    hold facing up
25-32::
    2s+1s dance Promenade.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (5228, '2013-08-21 08:31:02.94884+00', '2023-02-04 01:19:55.421969+00', 2100, 3, NULL, 'ace', '1-8::
    1s lead down the middle for 3, back to top & cast to 2nd place
9-16::
    1s dance 1/2 Diag R&L (Man down, Lady up) & circle 3H round to left
    part way (Man with Ladies in top place & Lady with Men 3rd pl) with
    3L & 2M leading their circles clockwise down/up own sides to end 2
    (1) 3
17-24::
    1s dance 1/2 Diag R&L & circle 3H round to right part way (Man with
    Men at top, Lady with Ladies) with 2L & 3M leading their circles
    anticlockwise up/down own sides to end 2 1 3
25-32::
    2s+1s+3s set, turn partners 2H & set', 0);
INSERT INTO 'dancecrib' VALUES (5229, '2013-08-21 08:31:02.957682+00', '2023-02-04 01:19:55.457949+00', 2101, 3, NULL, 'ace', '{{title}}
Jig

1-8::
    1s+2s also 3s+4s dance LH across & RH back
9-16::
    All dance reels of 4 on sides
17-24::
    1s+2s also 3s+4s dance Poussette
25-32::
    All circle 8H round & back.  2 1 4 3

{{title}}
Strathspey

1-8::
    1s & 4s set, cross RH & cast to ends, all set.  (1)2 3(4)
9-16::
    All dance a Progressive Grand Chain for 4 cpls: 1s & 4s turn once
    round RH as 2s+3s change places RH on sides, 1s+3s also 2s+4s change
    LH on sides, 3s & 2s turn once round RH as 1s+4s change places RH on
    sides, 3s+1s also 4s+2s change places LH on sides to end (4)3 2(1)
17-24::
    2s+3s dance 1/2 R&L, all set & cross RH.  4 2 3 1
25-32::
    All circle 8H round & back.

{{title}}
Reel

1-8::
    4s+2s also 3s+1s turn on sides (4s & 1s turning in b''tw''n 2s/3s to
    start), 1s lead up to 1st pl making an arch for 4s who dance down to
    4th pl
9-16::
    All dance Coupe PdB
17-24::
    1s+2s also 3s+4s dance the Chain Progression:
::
    1s+2s also 3s+4s 3/4 turn RH, 1M+2L also 3L+4L turn LH 1.1/2 times
    as  ptnrs chase cl''wise 1/2 way, 2s+1s also 4s+3s turn RH to…
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5230, '2013-08-21 08:31:02.967948+00', '2023-02-04 01:19:55.483563+00', 10017, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place & dance RH across
9-16::
    2s & 3s cross RH, cast in 1 place & dance LH across
17-24::
    All dance Tandem LSh reels of 3 on sides (2M+3M also 3L+2L dance as
    1 person, Men up & Ladies down to start) ending 1 2 3 4 all on opp
    sides
25-32::
    All set advg, 1/2 turn 2H, 2s+3s+4s end making arches facing up as
    1s end facing dn, 1s dance dn under arches to 4th pl as others dance
    up 1 pl', 0);
INSERT INTO 'dancecrib' VALUES (12549, '2020-02-02 02:47:47.151399+00', '2023-02-04 01:19:55.572877+00', 19819, 3, NULL, 'ace', '1-4::
    1s set turning away from each other (1M pull back LSh, 1L RSh),
    1s+2s change places (Men LH, Ladies RH), 2s face out
5-8::
    2s+1s+3s dance 1/2 mirror reels of 3 on sides (2s out/down,1s
    in/down, 3s out/up). 3s end with loop & face in, 2s face out
9-16::
    3s+2s dance double Fig 8 round standing 1s (3s cross down, 2s dance
    up to start)
17-24::
    1s set advancing, 1/2 turn 2H & pull back RSh to end BtoB facing opp
    sides; 3s+1s+2s set as in Double Triangles, 1s petronella turn to
    2nd place opposite  side on bars 23-24
25-32::
    1s cast (1M down, 1L up) change places LH up/down centre & cast to
    left to 2nd place own side _while_ 3s+2s dance 6 bars R&L, all set.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5233, '2013-08-21 08:31:02.992875+00', '2023-02-04 01:19:55.603645+00', 9856, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s & 4s turn RH, cast in 1 place, 1L+4L also 1M+4M change places RH
    on sides & cross LH to face corner
17-24::
    1L dances Fig of 8 round 3M+2M _while_ 1M dances Fig of 8 round 3s
    _while_ 4L dances round 2s & 4M dances round 2L+3L. All end on side
    lines
25-32::
    4s+1s dance LH across, set & cross RH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5234, '2013-08-21 08:31:03.001087+00', '2023-02-04 01:19:55.635512+00', 8503, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 3 facing 3

1-8::
    All circle 6H round & back
9-16::
    Middle persons petronella turn & set twice to change places
17-24::
    Middle persons turn their original partner to their right RH, pass
    each other RSh & turn other partner LH
25-32::
    Middle persons dance 1/2 reels of 3 giving RSh to their original
    partner to their right & all chase 1/2 way round clockwise to meet
    new threesome', 0);
INSERT INTO 'dancecrib' VALUES (12550, '2020-02-02 02:47:47.235951+00', '2023-02-04 01:19:55.663662+00', 13907, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s lead down middle; 2s+3s divide & 1s+2s+3s lead
    up remaining in middle
9-16::
    1s+2s+3s promenade
17-24::
    1s cross RH, cast (2s step up); 1s cross RH, cast (3s step up)
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5235, '2013-08-21 08:31:03.009648+00', '2023-02-04 01:19:55.697316+00', 2110, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides. Order 2 1 3 4
9-16::
    1s dance 1/2 diag R&L with 1st corners _while_ 2nd corners set &
    change places diagonally RH, 1s dance 1/2 RSh reels of 3 on opposite
    sides (1M up, 1L down). (2)(1)(3) 4
17-24::
    1s dance 1/2 diag R&L with 3rd corner (pstn) _while_ 2nd corners
    (pstn) set & change places diagonally, 1s dance 1/2 RSh reels of 3
    on own sides (1M down, 1L up). 2 1 3 4
25-32::
    1s dance reels of 3 across Lady with 2s & Man with 3s (LSh to 1st
    corner)
33-40::
    1s cross down between 3s, 1L casts up round 3M & 1M casts down round
    4L, 1s change places LH in centre & cast to 3rd place own sides
41-56::
    3s+1s+4s (bottom 3 couples) repeat bars 9-24. Order 2 3 1 4
57-64::
    All (or bottom 3 couples only) circle 8(6)H round & back. 1s step
    down to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (10221, '2017-11-04 01:45:21.614571+00', '2023-02-04 01:19:55.719099+00', 15443, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate, 1s end facing up, 2s facing down
9-16::
    2s+1s+3s dance RSh reels of 3 on sides (1s RSh to 2s to start)
17-24::
    2s+1s+3s Set+Link for 3 couples twice to end on opp sides, Men
    facing down, Ladies facing up
25-32::
    3s+1s+2s chase 1/2 round clockwise to own side (4 bars) & all turn
    partners RH', 0);
INSERT INTO 'dancecrib' VALUES (13141, '2020-09-15 00:19:36.054302+00', '2023-02-04 01:19:55.87052+00', 18265, 3, NULL, 'ace', '1-8::
    1L sets advancing (1M sets), dances RSh round 1M, 1s join RH & 1L
    pulls back RSh to turn under 1M''s arm. Retaining hands 1L leads 1M
    following down to face 2M
9-16::
    1s (1L leading) dance 1/2 tandem reel of 3 across with 2s (RSh to
    2M);  1s (1L leading) dance 1/2 tandem reel of 3 across with 3s (LSh
    to 3L). 1s end facing 3rd corner (pstn)
17-24::
    1s dance 1/2 diag reel of 4 with 3rd corners (pstn), 1s pass RSh, 1s
    dance 1/2 diag reel of 4 with 4th corners (pstn). 1s end in 2nd
    place opp sides, 1M facing down, 1L facing up
25-32::
    3s+1s+2s dance 1/2 RSh reel of 3 on sides; 1s turn 1.1/4 RH to 2nd
    place own side', 0);
INSERT INTO 'dancecrib' VALUES (13142, '2020-09-15 00:19:36.090385+00', '2023-02-04 01:19:55.90506+00', 13307, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across, 2s+3s dance LH across
9-16::
    1s+2s also 3s+4s dance Double Fig 8 (1s/4s cross down/up to start)
17-24::
    1s lead down & 4s lead up 2 steps (2s cast up/3s cast down), 1s+4s
    dance 1/2 RH across; 1s & 4s 1/2 turn partner RH, pull back RSh &
    dance out to 2nd/3rd place own side
25-32::
    2s+4s also 1s+3s dance Poussette.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15325, '2022-12-19 01:19:43.874806+00', '2023-02-04 01:19:55.937113+00', 21123, 3, NULL, 'ace', '1-8::
    1s+2s set to partners & turn 2H; 1s+2s circle 4H round to left
9-16::
    1s cross down RH below 2s & cast behind 3s; 1s cross up RH & cast up
    behind 2s to finish in 1st place own side
17-24::
    1s+2s+3s dance mirror reels of 3 on the sides (1s dance in/down, 2s
    out/up to start)
25-32::
    1s+2s Set+Link; 1s+3s Set+Link.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (10070, '2017-09-03 23:44:37.077433+00', '2023-02-04 01:19:55.960906+00', 16207, 3, NULL, 'ace', '{{explanation}}
Circle, Man has Lady on his right

1-4::
    All circle Left (2 bars), Men dance in front of partner to finish on
    her right
5-8::
    All circle Left (2 bars), Ladies dance in front of partner to finish
    on his right
9-16::
    With partner, all Set+Link.  All change places RH with partner, LH
    to next person to finish with Men behind Ladies, all facing
    anticlockwise
17-24::
    All chase round (4 bars), pull back RSh & chase back (4 bars).  Bar
    24 Men pull back RSh to join in ballroom hold with partner
25-32::
    All dance (slip steps) in (2 bars), out (2 bars) & then polka (4
    bars)', 0);
INSERT INTO 'dancecrib' VALUES (10071, '2017-09-03 23:44:37.084202+00', '2023-02-04 01:19:55.981562+00', 16208, 3, NULL, 'ace', '{{explanation}}
Circle, Man has Lady on his right

1-8::
    All circle round to Left and back
9-16::
    With partner, all Set+Link.  All change places RH with partner, LH
    to next person to finish with Men behind Ladies, all facing
    anticlockwise
17-24::
    All chase round (4 bars), pull back RSh & chase back (4 bars).  Bar
    24 Men pull back RSh to join in ballroom hold with partner
25-32::
    All dance (slip steps) in (2 bars), out (2 bars) & then polka (4
    bars)', 0);
INSERT INTO 'dancecrib' VALUES (13143, '2020-09-15 00:19:36.409279+00', '2023-02-04 01:19:56.256927+00', 2119, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    All circle 4H round & back
9-16::
    All dance RH across & LH across back to place
17-24::
    Ladies Chain
25-32::
    Partners NHJ Adv+Ret; drop hands & pass facing person RSh to meet
    new couple', 0);
INSERT INTO 'dancecrib' VALUES (5236, '2013-08-21 08:31:03.102097+00', '2023-02-04 01:19:56.126784+00', 7714, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, 1s dance 1/2 Fig 8 round 3s
9-16::
    1s dance reel of 3 on opposite sides (up between 2s to start) ending
    double triangle position facing opposite sides
17-24::
    1s dance Crown Triangles, 1s dance out & up to 1st pl own side
25-32::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)', 0);
INSERT INTO 'dancecrib' VALUES (5239, '2013-08-21 08:31:03.263631+00', '2023-02-09 11:33:11.708687+00', 2124, 3, NULL, 'ace', '1-8::

    1s+2s dance 1/2 RH across & LH back, 1s set advancing & pass LSh

9-16::

    1s cast RSh round 1st corner & pass partner RSh, turn 2nd corners LH

    pass partner LSh

17-24::

    1s dance reels of 3 on opposite sides giving LSh to 1st corner

    ending in 2nd place opposite sides & 2s+1s+3s set

25-32::

    1s petronella turn & set, petronella turn & 2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (10831, '2018-06-11 00:36:17.991104+00', '2023-02-04 01:19:56.278333+00', 17467, 3, NULL, 'ace', '1-8::
    1s set to 2s on side & change places (Men RH, Ladies LH). 1s+3s set
    on sides & turn once round (Men LH, Ladies RH). 1s face out  2 1 3
9-16::
    1s dance Fig of 8 on sides, 1M dancing down behind 3M, 1L up behind
    2L to start.  1s pass RSh to face 1st corners
17-24::
    1s turn 1st corners RH, pass RSh, turn 2nd corner RH, pass RSh to
    end 1M facing 3M, 1L facing 2L (corners dance 4 bars in turns)
25-32::
    RSh reels of 3 across (6 bars) & 1s cross RH (bars 31-32) with 1M
    polite turn to face down', 0);
INSERT INTO 'dancecrib' VALUES (5240, '2013-08-21 08:31:03.272142+00', '2023-02-04 01:19:56.550719+00', 2125, 3, NULL, 'ace', '1-8::
    1s set, 1/2 turn RH to 2nd place opposite sides (2s step up), set &
    turn RH to end 1L facing her 1st corner with partner following
9-16::
    1s dance RSh Tandem diagonal reel of 3 with 1st corners end facing
    3M
17-24::
    Repeat with 2nd corners 1s end by turning LH bars 23-24 to face own
    1st corners
25-32::
    1s turn 1st corners RH (corners dance 4 bars), pass RSh to turn 2nd
    corners RH & cross RSh to place own side', 0);
INSERT INTO 'dancecrib' VALUES (5241, '2013-08-21 08:31:03.38865+00', '2023-02-04 01:19:56.774498+00', 8630, 3, NULL, 'ace', '1-8::
    1s & 3s petronella into centre as 2s & 4s step up, all set.  2s & 4s
    petronella into centre as 1s & 3s petronella onto opposite sides,
    all set
9-16::
    2s+4s dance full reel of 4 up/down centre
17-24::
    1s+2s also 3s+4s dance RH across once round, 2L leads top couples
    down Ladies'' side as 4M leads bottom couples up Men''s side
25-32::
    All Men (at top) also all Ladies circle 4H round once round to left
    then centre 4 dancers dance 1/2 R&L
33-36::
    1M+4L also 3M+2L (all on Ladies'' side) lead across between opposite
    couple, cross & cast back to Ladies'' side (opposite their ptnrs)
37-40::
    1s & 3s (in 2nd & 4th places) dance 1/2 Figs of 8 round couples
    above them to end 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (5242, '2013-08-21 08:31:03.397177+00', '2023-02-04 01:19:56.801198+00', 12623, 3, NULL, 'ace', '1-8::
    1s cross RH, cast to bottom, all set & cross RH
9-16::
    All chase 1/2 way, 1s+2s continue chase _while_ 3s stand & end with
    1M & 2M followed by partner dance up/down middle, 2M+1M pass RSh &
    1/2 turn other Lady RH into a line of 4 up/down middle
17-24::
    1s+2s dance reel of 4
25-32::
    2M & 1M change places with other Lady, Men change pl LH to meet own
    partner & turn RH (4 bars) to sides.  (2)3 1
33-40::
    2s cross down to dance reels of 3 on own sides to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5244, '2013-08-21 08:31:03.413827+00', '2023-02-04 01:19:56.843783+00', 2129, 3, NULL, 'ace', '{{explanation}}
 Circle Dance - Ladies on Men''s right

1-8::
    All Men Adv+Ret & all circle left
9-16::
    All Ladies Adv+Ret & all circle right
17-24::
    All dance Grand Chain (pass partner RH to start) & face 5th person
    (new partner) joining both hands
25-32::
    All Slip-Step into centre (2 bars) & back, all turn new partners RH', 0);
INSERT INTO 'dancecrib' VALUES (5245, '2013-08-21 08:31:03.423923+00', '2023-02-04 01:19:56.883102+00', 2130, 3, NULL, 'ace', '1-8::
    1s turn RH 1.1/2 times, 1s+2s dance 1/2 R&L
9-16::
    1s followed by 2s lead down middle, 2s lead back to top to end in
    line across with Men BtoB facing partner
17-24::
    1s & 2s set to partner, turn RH & Men pass RSh to face other
    partner, set & turn 1s end in orig places & 2s in 2nd place opp
    sides
25-32::
    1M+2M change places RH, 1L+2L change places RH, 1s dance 1/2 Fig of
    8 round 2s', 0);
INSERT INTO 'dancecrib' VALUES (5246, '2013-08-21 08:31:03.516841+00', '2023-02-04 01:19:57.064266+00', 11773, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast 2 places & dance up to face 1st corners
9-12::
    1s set to 1st corner & change places RH with 1st corner persons who
    pass LSh to face 2nd corners (3L facing 2L & 2M facing 3M)
13-16::
    Original 1st corner persons set to 2nd corners & change places RH;
    2nd corners pass LSh to face 1st corner positions (2L facing 1L & 3M
    facing 1M)
17-20::
    Original 2nd corner persons set to 1st corners (1s), change places
    RH & 1s end BtoB facing opposite sides as for double triangles
21-24::
    All set as in double triangles, corner persons chase 1 place
    clockwise _while_ 1s PdB round each other to face down (Man with
    partner on left)
25-32::
    1s NHJ dance down between 3s, cast up to 2nd place, dance up between
    2s & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (14647, '2022-03-07 02:19:36.793707+00', '2023-02-04 01:19:57.090976+00', 20654, 3, NULL, 'ace', '1-8::
    1s dance down under arch made by 4s who dance up (2s & 3s step
    down/up 1-2); 1s & 4s cast in 1 place & all 4 couples set.  2 4 1 3
9-16::
    RSh reels of 4 on sides
17-24::
    2s & 3s cross RH with partner, 2s cast to 4th place, 3s cast up to
    1st place; 2s & 3s repeat back to place
25-32::
    2s+4s+1s+3s dance 8H round & back

{{explanation}}
Note: May be danced as a Reel or a Jig', 0);
INSERT INTO 'dancecrib' VALUES (5247, '2013-08-21 08:31:03.525291+00', '2023-02-04 01:19:57.119749+00', 13385, 3, NULL, 'ace', '{{explanation}}
Circle around the room with partner on Mans right

1-8::
    All circle left & back
9-16::
    All couples with nearer hands raised as Ladies dance in front &
    round partner (Men stand still), Men dance in front & round partner
17-24::
    All in circle Adv+Ret twice
25-32::
    All turn partner RH, Men turn Lady on left LH into prom hold
33-40::
    All with new partners promenade round to reform circle with new
    partners', 0);
INSERT INTO 'dancecrib' VALUES (8573, '2015-02-13 12:47:43.144058+00', '2023-02-04 01:19:57.146662+00', 15403, 3, NULL, 'ace', '1-8::
    1s set, cross down RH to 2nd place opposite sides, set, turn LH 3/4
    to finish 1L between 2s, 1M between 3s, facing opposite sides
9-16::
    1L+2s, 1M+3s dance 1/2 LSh reels of 3 across.  Bar12 1s pass by Left
    to continue reels with other couples.  1s finish in middle 1L facing
    up, 1M facing down
17-20::
    1L+2L+3L also 1M+2M+3M dance RH across on own sides
21-24::
    1s dance out of end (1L up, 1M down) and cast to Right into 2nd
    place own sides _while_ 2M+3M also 2L+3L set and change place RH on
    sides
25-32::
    3s+1s+2s Set & Rotate for 3 couples
::
    Set & rotate singly & chase 1 place clockwise, all change places RH
    with opposite person & chase clockwise to own sides.', 0);
INSERT INTO 'dancecrib' VALUES (13614, '2021-02-04 01:19:34.20428+00', '2023-02-04 01:19:51.119851+00', 2013, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across; set, dance 1/2 LH across back to
    place
9-16::
    1s lead down (3 bars), lead up (3 bars) & cast to 2nd place (2s step
    up)
17-24::
    2s+1s+3s dance DoSiDo with partner passing RSh;  2s+1s+3s dance
    DoSiDo with partner passing LSh
25-32::
    2s+1s+3s dance RH across, dance LH across', 0);
INSERT INTO 'dancecrib' VALUES (5250, '2013-08-21 08:31:03.575448+00', '2023-02-04 01:19:57.322269+00', 10194, 3, NULL, 'ace', '1-8::
    1s set & turn 2H, 1s+2s+3s set & turn 2H
9-16::
    1s+2s+3s circle 6H round to left to places, 1s set & cast to face
    1st corners
17-24::
    1s turn 1st corners RH & pass RSh, turn 2nd corners RH & pass RSh to
    2nd place own sides facing out
25-32::
    1s dance ''Paper Clip'' reels on sides : 1s pass 3rd corners RSh,
    cross down/up & dance RSh round 1st corner (pstn) & cross up/down to
    2nd place own sides _while_ 2s & 3s dance normal reels of 3 on sides', 0);
INSERT INTO 'dancecrib' VALUES (5251, '2013-08-21 08:31:03.585569+00', '2023-02-04 01:19:57.35659+00', 11281, 3, NULL, 'ace', '1-8::
    1s set, cross RH, 1s+2s set 1M casts down 1 place as 2M casts up
    _while_ 1L+2L turn LH to face partner in diagonal line
9-16::
    1s+2s dance diagonal reel of 4 with Ladies ending opposite partners
17-24::
    1s+2s dance Ladies'' Chain
25-32::
    1s cross up RH, cast to 2nd place & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5252, '2013-08-21 08:31:03.593808+00', '2023-02-04 01:19:57.382159+00', 2141, 3, NULL, 'ace', '1-8::
    4s followed by 3s+2s+1s lead down & back all crossing to partners
    place
9-16::
    1s cast 2 places on opposite sides, dances up to top, cast 1 place,
    dance up to top & loop into place
17-24::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L
25-32::
    1s+4s dance 1/2 R&L & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5253, '2013-08-21 08:31:03.60233+00', '2023-02-04 01:19:57.410659+00', 868, 3, NULL, 'ace', '1-8::
    1s+3s 1/2 turn partners RH & dance RH across 1/2 way, 3s & 1s turn
    partners RH.  3 2 1
9-16::
    2s dance RSh reels of 3 on own sides with 3s+1s (2L up & 2M down)
17-20::
    2s petronella turn into middle & set as 3M+1M also 3L+1L 1/2 turn RH
    & dance 1/2 RH across to end in lines across
21-24::
    All turn opposite person RH once round & 2s end facing 3rd corner
    (pstns)
25-32::
    2s dance 1/2 diagonal reels of 4 with 3rd corner (pstns) then with
    4th corner (pstns) & 2s end in 2nd place own side  1 2 3
33-40::
    1s+2s 1/2 turn partners RH & dance RH across 1/2 way, 2s turn
    partners RH
41-48::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5254, '2013-08-21 08:31:03.612635+00', '2023-02-04 01:19:57.442242+00', 12216, 3, NULL, 'ace', '1-8::
    1s+2s+3s turn RH, chase clockwise 1/2 way & face down in prom hold
9-16::
    3s+2s+1s promenade down & round to left, 1s cast 1 place to face 1st
    corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners ending in original
    places
25-32::
    1s dance diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (5255, '2013-08-21 08:31:03.62084+00', '2023-02-04 01:19:57.477014+00', 9582, 3, NULL, 'ace', '1-8::
    1s+2s set, cross to other side with Ladies dancing under Men''s arch,
    set & cross back Men under Ladies arch
9-16::
    1s followed by 2s dance down centre, 2s followed by 1s dance up to
    top
17-24::
    1s dance Fig of 8 round 2s above them
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5256, '2013-08-21 08:31:03.629273+00', '2023-02-04 01:19:57.539161+00', 2151, 3, NULL, 'ace', '1-8::
    1s cast 1 place, 2s+1s+3s dance 1/2 reel of 3 on sides (1s in & down
    to start), 1s turn 2H to diagonally face 3L (in top 1L place)
9-12::
    1s making an arch dance to corner _while_ 3L dances under to centre,
    1s 1/2 turn 2H to face in _while_ 3L changes place RH with 2M (in 3M
    place)
13-16::
    1s (making arch) dance in _while_ 2M dances out to 1L place & 1s
    turn 2H to face 2L (in 3L place)
17-24::
    1s repeat this Fig with 2L+3M & 1s end facing own sides Lady between
    2s & Man between 3s
25-32::
    All dance 1/2 RSh reels of 3 across, 1s cast LSh round 2M/3L, cross
    to 2nd place own side passing LSh', 0);
INSERT INTO 'dancecrib' VALUES (15326, '2022-12-19 01:19:45.593368+00', '2023-02-04 01:19:57.951203+00', 21124, 3, NULL, 'ace', '1-4::
    1s+2s dance RH across
5-8::
    1L+2L also 2M+3M Set+Link _while_ 1M+3L dance 1/2 way clockwise
    round set
9-12::
    3M+1L (in 2nd place) 1/2 RH turn & pull back RSh (twirl) dancing
    away to change places
13-16::
    2L+3M also 1L+2M Set+Link _while_ 3L+1M dance 1/2 way clockwise
    round set
17-20::
    2s cross passing RSh to opposite sides, 2s set Advancing to face 4th
    corners
21-24::
    2s dance 1/2 diagonal RSh reel of 4 with 4th corners
25-32::
    1s+2s dance 6 bars R&L, 2s+1s+3s set 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5258, '2013-08-21 08:31:03.659392+00', '2023-02-04 01:19:58.064512+00', 2156, 3, NULL, 'ace', '1-8::
    1s cast down below 3s turn out & cast back to top
9-16::
    1s lead down the middle for 3 steps, back to top & cast to 2nd place
    & face 1st corners
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH to end
    2nd place opposite sides
25-32::
    2s+1s+3s Adv+Ret, 1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (5259, '2013-08-21 08:31:03.667783+00', '2023-02-04 01:19:58.0908+00', 2157, 3, NULL, 'ace', '1-8::
    1s dance 1/2 reflection reels of 3 on own sides (1s dance in/down to
    start). 1s dance up to top & cast to 2nd place own sides.  3 1 2
9-12::
    1L+3M 1/2 turn RH, 3M followed by 1L dances down through 2nd place
    to 3rd place Ladies'' side
::
    _while_ 1M+2L 1/2 turn RH, 2L followed by 1M dances up through 2nd
    place to top place Man''s side
13-16::
    1L+2M 1/2 turn RH, 2M followed by 1L dances up through 2nd place to
    top place Ladies'' side
::
    _while_ 1M+3L 1/2 turn RH, 3Lfollowed by 1M dances down through 2nd
    place to 3rd place Man''s side
17-24::
    1s set & cross RH, 2s+1s+3s set & 1/2 turn RH into prom hold facing
    up.  2 1 3
25-32::
    All dance 3 couples Promenade', 0);
INSERT INTO 'dancecrib' VALUES (5261, '2013-08-21 08:31:03.686498+00', '2023-02-04 01:19:58.16167+00', 2162, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, set facing up/down & change places 2s
    making arch
9-16::
    2s+1s dance DoSiDo, 2M+1M turn RH _while_ 2L+1L turn LH
17-24::
    1s dance down below 3s & cast up to 2nd places, dance up between 2s
    & cast to 2nd places
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7873, '2013-08-21 08:31:50.167118+00', '2023-02-04 01:23:08.372737+00', 9765, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All Set+Link with partner, all Set+Link with corner
17-24::
    All turn new partner LH & dance 1/2 Ladies'' Chain (1/2 RH across in
    centre)
25-32::
    All set to corner & turn RH, set to own partner & turn LH
33-40::
    All Ladies set advancing & cast round to right into a clockwise
    spiral for 3/4 way round & 1/2 turn standing Man
41-48::
    All Men set advancing & cast round to right into a clockwise spiral
    for 3/4 way round & 1/2 turn own partner (all now in opp position to
    original place)
49-56::
    All dance Grand Chain (1 bar per hand)
57-64::
    All petronella turn (Ladies BtoB) & set, all turn partners 2H 1.1/4
    times.  3 4 1 2
::
    Repeat in reel time 1-64 to original place but end turning RH', 0);
INSERT INTO 'dancecrib' VALUES (14794, '2022-05-05 00:19:33.77224+00', '2023-02-04 01:19:52.24185+00', 2026, 3, NULL, 'ace', '1-8::
    1s cross down RH, dance behind 3s, meet & dance up the middle & cast
    to 2nd place opp sides (2s step up 7-8)
9-16::
    2s+3s Adv+Ret diagonally; 1s dance DoSiDo
17-24::
    1s give LH to 1st corner (i.e.1L+2M also 1M+3L NHJ) and Adv, 1s swap
    partners & face 2nd corners (1M+2M facing 2L 1L+3L facing 3M) & set
    to corners; 1M+2M+3L & 1L+3L+3M circle 3H round to left. 1s end in
    2nd place opp sides
25-32::
    1s join RH with 2nd corner & repeat figure bars 17-24 (1M+3M face
    3L, 1L+2L face 2M, set, & circle 3H round to left). 1s end in 2nd
    place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5262, '2013-08-21 08:31:03.695155+00', '2023-02-04 01:19:58.194836+00', 2163, 3, NULL, 'ace', '1-8::
    1s+3s dance in & dance out sides with opposite partner to stand
    between side couple (who separate to make room) facing out & all
    set, 1s+3s cast back to own places _while_ 2s & 4s turn individually
    to stand alongside 1s/3s in lines of 4 across facing out & all
    Bal-in-Line
9-16::
    1s+3s dance into centre & face partner _while_ 2s & 4s turn on the
    spot to face in, all set & 1s+3s dance 1/2 R&L to end 1M+3L & 1L+3M
    in prom hold facing out between 4s/2s
17-24::
    1s+3s dance 1/2 diagonal reel of 4 with 2M+4M _while_ 2L & 4L dance
    track of 1/2 reel of 4 giving LH to partners in centre, 1M+3L pass
    RSh round 4L pl _while_ their partners dance round 2L pl then into
    the middle & change prtnrs so that 1s face 4th pl & 3s face 2nd pl
    _while_ 4s & 2s set twice
25-32::
    Repeat bars 17-24 to end with 1s facing 2M & 3s facing 4M
33-40::
    1s & 3s dance RSh reels of 3 across (1s with 2M+4L & 3s with 4M+2L)
41-48::
    1s+3s Adv+Ret (PdB), 2s+4s Adv+Ret
49-56::
    2M+4L dance Fig of 8 round 1s _while_ 2L+4M dance Fig of 8 round 3s
57-64::
    1M+3L dance 1/2 Fig of 8 round 4s _while_ 1L+3M dance 1/2 Fig of 8
    around 2s, 1s & 3s turn partners RH 1.1/2 times to end in own places

{{explanation}}
Repeat with 2s & 4s as main dancers etc', 0);
INSERT INTO 'dancecrib' VALUES (14205, '2021-08-14 00:19:42.980247+00', '2023-02-04 01:19:58.259289+00', 19116, 3, NULL, 'ace', '1-4::
    1s & 3s set & 3/4 turn partners RH into line of 4 up/down
5-8::
    2s & 4s set & 3/4 turn partners RH _while_ 1s+3s dance 1/2 reel of
    4. (All now in cross formation, Men at ends, 3 2 1 4 clockwise from
    top)
9-12::
    1s & 3s continue reel of 4 _while_ 2s & 4s dance 1/2 reel of 4
    across (i.e. intersecting 1/2 reels; all Men touch LH on Bar 10,
    Ladies on Bar 12). End in cross formation, 1 4 3 2 clockwise
13-16::
    1s & 3s set & 3/4 turn RH to face in Ladies on left of partner
::
    _while_ 2s & 4s pass partners RSh (1 bar), 2M+4M turn LH (2 bars)
::
    _while_ 2L, 4L loop tightly and dance in to right to end on right of
    partner with NHJ, then (1 bar) 2s & 4s pass LSh to end BtoB in line
    up/down, 1s facing 4s (M‑M, L-L), 2s facing 3s likewise
17-24::
    1s+4s & 2s+3s dance »Rose Rondel« (same timing as Rondel, all arches
    made by dancers at ends):
::
    _17_      All couples NHJ, 1s+4s also 2s+3s change places, with
    1s/3s making arches for 4s/2s
::
    _18-19_ Facing out, 2L/4L pass in front of 2M/4M & dance 1/4 round
    set to form new pairs NHJ at sides facing in _while_ 1s+3s  circle
    4H 1/2 round to left & turn sharply away from partners (Men to
    right, Ladies to left) to form new pairs NHJ facing sides. (All now
    in line across, all Ladies on left: 2L+4M facing 3L+1M, 1L+3M facing
    4L+2M)
::
    _20-22_ Repeat 17-19 but turned sideways, to end back with original
    partners NHJ in line up/down, 1s/3s (in original places) facing
    2s/4s (with Ladies on left), so M-M, L-L again facing.
::
    _23-24_ 1s+2s also 3s+4s change places with 1s/3s making arches,
    turn inward to face couple just passed
25-28::
    2s+1s also 3s+4s dance LH across
29-32::
    1s dance up, 3s dance down passing 2s/4s LSh, 1L followed by 1M & 3L
    followed by 3M dance down/up sides to 4th/2nd place.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5263, '2013-08-21 08:31:03.703507+00', '2023-02-04 01:19:58.276962+00', 11367, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    2s & 3s set, 1/2 turn RH, 2s lead up, cross & cast to original
    places _while_ 3s lead down, cross & cast to original places
9-16::
    1s+2s also 3s+4s dance double Fig of 8 (2s & 3s cross up/down to
    start)
17-24::
    1M+2M also 3M+4M turn LH 1.1/2 times _while_ their partners turn
    similarly RH, 1s+4s dance 1/2 R&L (no polite turn)
25-32::
    All dance RSh reels of 4 on sides with centre dancers ending with
    1/2 turn 2H into…
33-40::
    All circle 8H round & back.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (13145, '2020-09-15 00:19:37.945252+00', '2023-02-04 01:19:58.294931+00', 15455, 3, NULL, 'ace', '1-8::
    1s+3s take prom hold, dance RSh round each other; 1s dance behind
    2s, 3s behind 4s to opp place
9-16::
    2s+4s repeat 1-8
17-24::
    All dance Grand Chain (1 bar/hand).  Ladies face out, Men face in
25-32::
    All dance Schiehallion reel 1/2 round back to original places
33-40::
    _33-36_   All turn partner 3/4 RH, Ladies dance LH across 1/2 way
    _while_ Men chase clockwise 1 place
::
    _37-40_  Ladies 1/2 RH turn nearest Man, Men dance LH across 1/2 way
    _while_ Ladies chase clockwise 1 place.  End 2 3 4 1

{{explanation}}
Repeat from new places Strathspey then twice Reel', 0);
INSERT INTO 'dancecrib' VALUES (5264, '2013-08-21 08:31:03.713796+00', '2023-02-04 01:19:58.319814+00', 9857, 3, NULL, 'ace', '1-4::
    1M & 3M cross & cast 1 place into middle _while_ 1L & 3L cross down
    thru couple below & cast up into middle (as Belle of Bon Accord)
5-8::
    1s & 3s dance 1/2 reel of 4 up/down middle
9-12::
    3s & 1s turn partners RH 1.1/2 times & twirl to face out to own
    sides
13-16::
    3s & 1s dance out & cast right then loop round to face 2s/4s for a
    reel of 4 _while_ 2s & 4s turn partners RH 1.1/2 times to change
    places facing in
17-24::
    All dance full reels of 4 across
25-28::
    3s & 1s cast RSh round the standing 2s/4s then 3M & 1M cross to opp
    sides _while_ 3L & 1L cross up thru couple above. (3)(2)(1)(4)
29-32::
    1s & 3s cast down as 2s/4s step up, all cross RH. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5266, '2013-08-21 08:31:03.730326+00', '2023-02-04 01:19:58.379934+00', 13470, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s, 1M+2L turn LH 1.1/4 times _while_
    1L+2M turn RH 1.1/4 times
9-16::
    1s in prom hold dance reel of 3 across with 2s (RSh to 2M to start)
    & 1s end in middle facing down
17-24::
    1M dances LH & RH across with 2L+3L _while_ 1L dances RH & LH across
    with 2M+3M 1s & 3s ending in middle facing up
25-32::
    1s followed by 3s dance up & cast to 3rd/2nd places & 1s dance 1/2
    Fig of 8 round 3s', 0);
INSERT INTO 'dancecrib' VALUES (5267, '2013-08-21 08:31:03.817612+00', '2023-02-04 01:19:58.547739+00', 9389, 3, NULL, 'ace', '1-8::
    All set to partners, turn 2H & circle 8H round to left 1/2 way
9-16::
    Turn partner RH 1.1/2 times, pass corner LSh, turn following person
    RH 1.1/2 times & pass next person LSh back to original places
17-24::
    1s+3s change places RH with opposite person & circle 4H round 1/2
    way, 2s & 4s repeat
25-32::
    All set prom hold (Ladies on Men''s left), advance setting, turning
    towards each other (prom hold) lead back to places & dance 1 pl
    clockwise', 0);
INSERT INTO 'dancecrib' VALUES (5203, '2013-08-21 08:31:02.492553+00', '2023-02-04 01:19:52.734144+00', 2039, 3, NULL, 'ace', '1-8::
    2s petronella turn & set, all petronella turn & set
9-16::
    1s+3s dance RSh reel of 4 up/down ending with 1M+3L 1/2 turning RH
    to face opposite sides
17-24::
    2s+1M+3L set, dance RH across, 1M+3L 1/2 turn RH to face own sides
    _while_ 2s set
25-32::
    2s+1M+3L dance RSh reel of 4 across, 1M+3L end in middle facing
    partners
33-40::
    1s & 3s set & 3/4 turn RH to 1s facing up & 3s in 3rd pl opp sides,
    1s lead up to top, cast on opp sides & into middle 1M facing up & 1L
    facing down
41-48::
    1M+2s & 1L+3s circle 3H round to Left, 1M leads 2s down Ladies'' side
    as 1L leads 3s up Men''s side, all circle 6H round to left 1/2 way to
    own sides & set.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (13146, '2020-09-15 00:19:38.214529+00', '2023-02-04 01:19:58.56048+00', 19663, 3, NULL, 'ace', '1-8::
    1s set, cross down RH, cast behind 3s, meet & dance up to end BtoB
    facing opp sides
9-16::
    2s+1s+3s set as Double Triangles, all set advancing & pull back RSh
    to invert triangle; 1s (outside set) dance RH across with corners
17-24::
    2s+1s+3s set in inverted Double Triangle, all set advancing & pull
    back RSh to Double Triangle position; 1s (in centre) dance RH across
    with corners & 1s pass RSh to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5269, '2013-08-21 08:31:03.834139+00', '2023-02-04 01:19:58.786897+00', 13261, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, cross RH & cast (Man up & Lady down)
    into lines of 3 across
9-16::
    2s+1s+3s Adv+Ret (up/down), 1s 3/4 turn LH to end 2nd place opposite
    sides
17-24::
    2s+1s+3s Adv+Ret (across), 1s turn RH 1.1/2 times to 2nd place own
    sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5270, '2013-08-21 08:31:03.842617+00', '2023-02-04 01:19:58.804571+00', 2169, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    2s+3s advance to form circle with hands crossed as in Auld Lang Syne
    & set, circle L (hands crossed) end 2s facing up & 3s facing down
    (NHJ)
9-16::
    1s & 4s cast in 1 place & 1/2 turn RH _while_ 2s & 3s dance up/down
    & cast into top/bottom places, 1s dance RH across with 2L _while_ 4s
    dance RH across with 3L, end 1M behind 1L facing up & 4M behind 4L
    facing down in centre of set
17-24::
    1s dance LH across with 2M _while_ 4s dance LH across with 3M, 1s+4s
    dance RH across & on last step turn to right to face corners (1M
    facing 2M, 1L+2L, 4M+3M, 4L+3L)
25-32::
    ''Hello-Goodbye'' setting: 1s set to corners, set between corners, set
    to next corner & into centre (1s in 3rd place & 4s in 2nd place)
33-40::
    All turn next corner RH onto sides, 4s+1s turn LH on side
41-48::
    All reel of 4 on sides ending 2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (5271, '2013-08-21 08:31:03.851844+00', '2023-02-04 01:19:58.828+00', 2170, 3, NULL, 'ace', '{{title}}
Jig

1-8::
    Middle couple (2s) set, cross RH, set to 1st corner & change places
    LH on sides
9-16::
    New middle couple (3L+1M) set _while_ corners chase anticlockwise 1
    corner place, middle couple cross RH _while_ corners set, middle
    couple set to 1st corners & change places LH
17-24::
    New middle couple (1L+3M) set _while_ corners chase anticlockwise 1
    corner place, middle couple cross RH _while_ corners set, middle
    couple set to 1st corners & change places LH (2s now in original
    place)
25-32::
    2s stand _while_ corners chase anticlockwise 1 corner place (all now
    in original places), all set, petronella into centre to form line &
    set to partner

{{title}}
Strathspey

1-8::
    All dance 1/2 RSh reel of 6 & set to partner
9-16::
    All Ladies dance RSh round partners & turn partner RH
17-24::
    All dance 1/2 RSh reel of 6  & set to partner
25-32::
    All Men dance RSh round partners & turn partners RH to end in
    original places

{{title}}
Reel

1-8::
    1L dances in front of 2L & behind 3L into centre _while_ 3M dances
    in front of 2M & behind 1M into centre, 2M dances in front of 1M &
    behind 3M to 1L place _while_ 2L dances in front of 3L & behind 1L
    to 3M place to form lines across
9-16::
    All turn opposite person RH, 1M dances in front of 3M & behind 2M to
    2L place _while_ 3L dances in front of 1M & behind 2L to 2M place
17-24::
    1L dances in front of 2L & behind 3L to 1M place _while_ 3M dances
    in front of 2M & behind 1M to 3L place, all turn opposite person RH
25-32::
    2s dance clockwise round to original places _while_ 1s & 3s turn
    partners RH 1.1/2 times to original places, all circle 6H round to
    left', 0);
INSERT INTO 'dancecrib' VALUES (15414, '2023-02-04 01:19:58.850407+00', '2023-02-04 01:19:58.851318+00', 21318, 3, NULL, 'ace', '1-8::
    1s set, cast: dance 1/2 Fig 8 up round 2s (2s step up 7-8)
9-16::
    1M+2s & 1L+3s dance RH across, 1s finishing BtoB in centre, 1M
    facing up, 1L facing down; all dance 4 bars of Double Triangles (1M
    now facing down, 1L facing up)
17-24::
    1L+2s & 1M+3s dance LH across, 1s finishing BtoB in centre, 1M
    facing down, 1L facing up; all dance 4 bars of Double Triangles, 1s
    Petronella turn to 2nd place own side
25-32::
    2s+1s danve R&L', 0);
INSERT INTO 'dancecrib' VALUES (5272, '2013-08-21 08:31:03.860166+00', '2023-02-04 01:19:58.865874+00', 12219, 3, NULL, 'ace', '1-8::
    1s cross down RH to 2nd place & Bal-in-Line with 1st+2nd corners,
    turn 1st corner RH, partner LH to 2nd place own sides facing out
9-16::
    1s dance reels of 3 on own sides (Man down, Lady up - 1M+3M & 1L+2L
    pass LSh to start). End 1L at bottom facing up, 1M at top facing
    down, to cross LH ready for…
17-24::
    1s dance RH across (1L with 2s, 1M with 3s) into 2nd place own sides
    & 2s+1s+3s chase clockwise 1/2 way
25-32::
    All Set+Link for 3 twice', 0);
INSERT INTO 'dancecrib' VALUES (5273, '2013-08-21 08:31:03.868497+00', '2023-02-04 01:19:58.891875+00', 9634, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back
9-16::
    1s+2s+3s dance Allemande
17-24::
    1s dance in & cast up to top, 2s dance in & cast up to top
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5274, '2013-08-21 08:31:03.878857+00', '2023-02-04 01:19:58.917474+00', 2171, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place (2s step up) & 1s dance 1/2 Figs of 8 round
    2s to end in 2nd place opp sides
9-16::
    1s set, petronella turn to 1M facing 2M & 1L facing 3L (3rd
    corners), set to & turn corners RH
17-24::
    1s dance 1/2 reels of 3 across (Man with 2s & Lady with 3s), 1s end
    facing in centre & turn RH to 2nd place own sides
25-32::
    1s set, petronella turn to 1M facing 3M & 1L facing 2L (1st corner
    pstns), set to & turn corners RH
33-40::
    1s dance 1/2 reels of 3 across (Lady with 2s & Man with 3s), 1s end
    facing in centre & turn LH to 2nd place own sides
41-48::
    1s dance RH across (Lady with 2s & Man with 3s), pass RSh to dance
    LH across with other couple to end 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8574, '2015-02-13 12:47:43.484242+00', '2023-02-04 01:19:58.939794+00', 14963, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set & Rotate   2 1 4 3 5
9-16::
    1s+3s pass partners RSh, turn 1st corners RH, pass partners RSh, and
    turn 2nd corners RH retaining hands
17-24::
    1M with 2s, 1L+3M with 4s & 3L+5s dance RH across once round. 1s+3s
    join LH with partners, set facing own sides and cast 1 place (4s+5s
    step up bars 23-24)  2 4 1 5 3
25-32::
    All circle 10H round and back', 0);
INSERT INTO 'dancecrib' VALUES (5275, '2013-08-21 08:31:03.891832+00', '2023-02-04 01:19:59.093146+00', 2173, 3, NULL, 'ace', '1-8::
    1s dance 1/2 RSh reel of 3 on own sides; 1L followed by partner
    casts up behind Ladies & 1L crosses to end in 1st place opposite
    side
9-16::
    1s dance 1/2 LSh reel of 3 on opposite sides; 1L followed by partner
    casts up behind Men & 1L crosses to end in original places
17-24::
    3s followed by 2s & 1s dance down middle & back
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5276, '2013-08-21 08:31:03.90025+00', '2023-02-04 01:19:59.107919+00', 3094, 3, NULL, 'ace', '{{explanation}}
2 chords - on 2nd chord 3s+4s cross to opp sides

1-8::
    1s+2s also 3s+4s set, turn 2H & open out to 4H round to end 1s & 3s
    facing down & 2s & 4s facing up with nearer hands joined
9-16::
    1s & 4s Set+Link twice _while_ 2s & 3s Set+Link "BtoB" twice (set,
    person on left moves forward & curves right to place left by partner
    who dances slightly forward & casts to place left by person behind).
    Repeat to end 1 3 (2) (4) with 3s & 2s BtoB (3s facing up & 2s down)
17-20::
    3s & 2s in prom hold dance Corner Pass+Turn with 1L & 4L (3s pass
    1L, 2s pass 4L, RSh, 1L+4L turn RH & return to places)  3s+2s dance
    3/4 RSh round each other to 3s in 2nd place Men''s side facing up, 2s
    in 3rd place Ladies'' side facing down still in promenade hold
21-24::
    2s & 3s dance Corner Pass+Turn with 1M & 4M. 3s+2s meet in middle,
    drop LH ready for ...
25-32::
    3s+2s dance RH across ending 1 (3) 2 (4).  3s & 2s cross RH & cast
    up/down to 1st/4th place.  3 1 (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (9360, '2016-10-06 07:18:22.980108+00', '2023-02-04 01:19:59.124134+00', 2179, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    All dance RH across, LH across back to places
9-16::
    All circle 4H round & back
17-24::
    Ladies turn RH. Men turn LH
25-32::
    All dance DoSiDo with Man/Lady opposite then NHJ with partner all
    slip step Left (3 step/close) advancing to pass opposites & slip
    step Right (3 steps/close) to face new couple', 0);
INSERT INTO 'dancecrib' VALUES (5277, '2013-08-21 08:31:03.908768+00', '2023-02-04 01:19:59.140302+00', 11516, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+3s dance 3/4 RH across, dance out LSh to facing person & cast
    left to opposite places
17-24::
    2s+4s repeat bars 9-16
25-32::
    All face partners & set, dance 1/2 Grand Chain back to places & set
    to partners
33-40::
    1s+3s dance Ladies'' Chain
41-48::
    2s+4s dance Ladies'' Chain
49-56::
    All Set+Link chase clockwise to opposite places
57-64::
    1s+3s advance, turn opposite person RH (full turn) & lead out
    through side couples, cross & cast back to original places
65-72::
    2s+4s repeat bars 57-72
73-80::
    All set & turn partner RH, set & turn corner LH retaining nearer
    hands
81-88::
    All advance with corners to join hands in circle, set & retire with
    partners & all set
89-96::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5279, '2013-08-21 08:31:03.927101+00', '2023-02-04 01:19:59.185113+00', 8726, 3, NULL, 'ace', '{{explanation}}
4s & 5s & 6s start on opp sides

1-8::
    1s+2s+3s also 4s+5s+6s circle 6H round & back
9-16::
    All dance 1/2 Grand Chain (1s & 6s cross to start) to end in reverse
    order 6 5 4 (3)(2)(1)
17-24::
    6s+5s also 4s+3s also 2s+1s set & dance RH across 1/2 way, end
    couples stand _while_ 6s+3s also 4s+1s set & dance LH across 1/2 way
25-32::
    Centre couples (1s+6s) set to each other on sides & change places
    RH, all set & cross RH.  5 3 1 (6)(4)(2)', 0);
INSERT INTO 'dancecrib' VALUES (8057, '2013-10-01 08:46:49.349621+00', '2023-02-04 01:19:59.199516+00', 10649, 3, NULL, 'ace', '1-8::
    1L+2L turn LH 1.1/2 times as 1M+2M turn RH 1.1/2 times, 1L+3L turn
    RH 1.1/2 times as 1M+3M turn LH 1.1/2 times
9-16::
    1s dance up to top & cast to 2nd place, all dance DoSiDo
17-24::
    1L+2s also 1M+3s dance RH across & 1s pass RSh to dance LH across
    with other couple
25-32::
    1s dance 1/2 Fig of 8 round3s, 1s dance 1/2 Fig of 8 round 2s', 0);
INSERT INTO 'dancecrib' VALUES (5280, '2013-08-21 08:31:03.942271+00', '2023-02-04 01:19:59.368825+00', 2189, 3, NULL, 'ace', '1-8::
    1M casts to 2nd place, crosses & turns 2L RH to end in 2nd place opp
    side, 1L casts, crosses & turns 2M LH to end in 2nd pl opp side
9-16::
    1s lead down & cast up round 3s, 2s+1s dance 1/2 R&L (2s end 2nd
    place opposite sides)  1 (2) 3
17-24::
    1s+2s set & petronella turn moving anticl''wise to next position to
    Right, 1s+2s repeat     2 (1) 3
25-32::
    2s+1s+3s dance 6 bar reels of 3 on opposite sides giving RSh to 2nd
    corners (1M up, 1L down), 1s cross to own side 2nd place on bars
    31-32', 0);
INSERT INTO 'dancecrib' VALUES (5281, '2013-08-21 08:31:03.950748+00', '2023-02-04 01:19:59.400754+00', 485, 3, NULL, 'ace', '1-8::
    1s+2s dance Tournee :
::
    1s+2s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 2s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (2s RH, 1s LH) & dance
    out to places
9-16::
    1s dance RH across (Lady with 2s & Man with 3s), 1s turn LH 1.1/2
    times to face 3rd corner (pstn) _while_ 2s+3s chase clockwise 1/2
    way
17-24::
    1s dance 1/2 reel of 4 with 3rd corners, turn LH & dance 1/2 reel
    with 4th corners & end 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5282, '2013-08-21 08:31:03.961004+00', '2023-02-04 01:19:59.43518+00', 13438, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, turn LH to face 1st corner
9-16::
    1s 1/2 turn 1st corner RH as 2nd corners dance clockwise 1 corner
    position to be behind 1s, all dance 1/2 Diagonal reel of 4 with
    1s+2nd corners in tandem, 1s 1/2 turn 1st corner person RH to end
    facing 4th corner (pstn) as 2nd corner persons dance clockwise back
    to place.
17-24::
    1s 1/2 turn 4th corner RH as 1st corners dance clockwise 1 corner
    position to be behind 1s, all dance 1/2 Diagonal reel of 4 with
    1s+1st corners in tandem, 1s 1/2 turn 4th corners RH to end BtoB 1M
    facing up & 1L down as 1st corners dance clockwise to 3rd corner
    position
25-32::
    1s dance double triangles up/down ending in 2nd place own side
33-40::
    1s dance Diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (5283, '2013-08-21 08:31:03.969845+00', '2023-02-04 01:19:59.464307+00', 13544, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 figures of 8 (1L round 2s,
    1M round 3s) & end facing 1st corners
9-12::
    1s set moving out between corners (as in Hello-Goodbye setting) & 1s
    turn LH to face 1st corners
13-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners & end facing 2nd
    corners
17-24::
    1s repeat bars 9-16 with 2nd corners & end 2nd place opposite sides
    (3)(1)(2)
25-32::
    1s dance 1/2 reel of 3 on opposite sides (1M in & down, 1L in & up),
    1s dance 1/2 reel of 3 across (1M with 2s & 1L with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (5284, '2013-08-21 08:31:03.978143+00', '2023-02-04 01:19:59.498432+00', 1533, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s circle 4H round to left, 1s+2s also 3s+4s Set+Link.
    2 1 4 3
9-16::
    2s+1s also 4s+3s dance RH across, 1s+4s dance LH across
17-24::
    All dance RSh reels of 4 on sides but with 1s+4s 1/2 turning LH to
    end reel
25-32::
    1s+4s continue with another 1/2 turn LH & set to partner, all turn
    partners RH', 0);
INSERT INTO 'dancecrib' VALUES (9002, '2015-11-30 08:59:44.944259+00', '2023-02-04 01:19:59.516706+00', 16525, 3, NULL, 'ace', '1-8::
    1s dance down, cast up round 3s, meet, dance up to 1st place facing
    out.  1s+2s 1/2 turn (Men LH, Ladies RH)
9-16::
    2s+1s dance double Figs 8 (1s cross up, 2s cast to start)
17-20::
    1s+3s 3/4 turn RH into line up/down in middle facing partner & set
21-28::
    1s+3s dance 1/2 Celtic Reel:
::
    _21-22_     1s+3s pass partner RSh
::
    _23-24_     1M+3L dance clockwise _while_ 1L+3M dance 3/4 round each
    other LSh to face partners in line across
::
    _25-26_     1s+3s pass partner RSh
::
    _27-28_     1L+3M dance clockwise _while_ 1M+3L dance 3/4 round each
    other LSh to face partners in line up/down
29-32::
    3s+1s 3/4 turn partners RH to sidelines & 2s+3s+1s set', 0);
INSERT INTO 'dancecrib' VALUES (8836, '2015-08-13 20:33:35.878241+00', '2023-02-04 01:19:59.58964+00', 14286, 3, NULL, 'ace', '1-8::
    1s set twice, 1s cross down (2s step up) & dance round 1st corners
    to face 1st corners
9-16::
    1s set (HS) to 1st corners, 1s turn 1st corners 2H, turn 2nd corners
    2H & finish facing 1st corners
17-24::
    1s dance reels of 3 on opp sides, LSh to 1st corners
25-28::
    1s petronella turn into centre, petronella turn to 2nd place own
    sides
29-32::
    1s+3s dance 1/2 Diamond Poussette    End  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5287, '2013-08-21 08:31:04.159975+00', '2023-02-04 01:19:59.614539+00', 2199, 3, NULL, 'ace', '1-4::
    3s set advancing to 1st corner couples as corner couples (nearer
    hands joined) set, 3s circle 3H round to left with corners & end 3L
    between 1s facing down & 3M between 5s facing up
5-8::
    3s set advancing to 2nd corner couple as corners set, 3s circle 3H
    round to left with corners & 3s end 3rd place opposite sides
9-16::
    3s dance Figs of 8 round corner couples (LSh to 1st corner to start)
    _while_ corners set, Advance (to form circle) & Retire twice
17-24::
    3s petronella turn into centre, set to each other, turn 2H 1.3/4
    times to face up _while_ others set, circle 8H round to left & dance
    in to face up
25-32::
    1s followed by others cast (on own sides) to bottom, dance up & 1s
    cast to bottom as others dance up 1 place.  2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (5288, '2013-08-21 08:31:04.171083+00', '2023-02-04 01:19:59.830896+00', 2203, 3, NULL, 'ace', '{{explanation}}
5 couple square set, 5s in centre facing, 5M back to 4s, 5L back to 2s

1-8::
    1s+2s+3s+4s circle 8H round & back _while_ 5s turn RH once & LH
    1.1/2 times to end 5M facing 2s & 5L facing 4s
9-16::
    5M+2s also 5L+4s dance RH across, 5s pass LSh & dance LH across with
    next couple anticlockwise (M with 1s & L with 3s)
17-24::
    5M dances reel of 3 with 1s+2s (in prom hold) giving RSh to 2s
    _while_ 5L reels with 3s+4s giving RSh to 4s
25-32::
    All take ptnrs in prom hold, 5s change pl with 1s RSh, 1s pass 4s
    RSh, 4s pass 3s RSh, 3s pass 2s RSh & 2s end in centre facing each
    other', 0);
INSERT INTO 'dancecrib' VALUES (9915, '2017-06-05 11:31:04.685894+00', '2023-02-04 01:19:59.854747+00', 14137, 3, NULL, 'ace', '{{title}}
Strathspey

1-4::
    Men dance clockwise 1/2 round set _while_ Ladies set advancing,
    circle 4H 1/2 round to Left, pull back RSh to face partners
5-8::
    All set to partners & turn 2H to end in opp place to start position
9-16::
    All couples Set+Link, Ladies face in, Men face out & all turn
    corners LH to end facing partners
17-24::
    All dance interlocking reels of 4 back to place, Ladies facing in,
    Men facing out
25-32::
    All dance 4 bars of Schiehallion reels & all turn partners RH to end
    with Ladies on left of partner

{{title}}
Reel

33-64::
    Repeat bars 1-32 in Reel time - Men advancing & Ladies dancing 1/2
    round
65-128::
    Repeat bars 1-64 (Strathspey & Reel) to end with all dancers in
    original places', 0);
INSERT INTO 'dancecrib' VALUES (12079, '2019-08-30 09:54:12.512531+00', '2023-02-04 01:19:59.883806+00', 2205, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L+3M+2M dance across, behind 1M, down Men''s side,
    across below 3rd place & up Ladies'' side, all back to place
9-16::
    1M followed by 2M+3M+3L+2L dance across, behind 1L, down Ladies''
    side, across below 3rd place & up Men''s side, all back to place
17-24::
    1s set, cast (2s step up); 1s set, cross LH to face 1st corners
25-32::
    1s+1st corners dance diagonal reel of 4. Bar 32 1s dance round each
    other LSh to face 2nd corners
33-40::
    1s+2nd corners dance diagonal reel of 4. 1s end in 2nd place opp
    sides.  2 (1) 3 4 5
41-48::
    1s cast up to top, lead down between 2s crossing to own side, dance
    behind 3s, lead up between 3s & cast to 3rd place (3s step up).  2 3
    1 4 5
::
    Repeat having passed 2 couples', 0);
INSERT INTO 'dancecrib' VALUES (13523, '2021-01-09 01:19:41.395993+00', '2023-02-04 01:19:59.916632+00', 17699, 3, NULL, 'ace', '1-2::
    All cross RH
3-4::
    1s+2s & 4s+5s change places LH on sides _while_ 3s set
5-6::
    2s+3s+4s cross RH to own sides _while_ 1s+5s set
7-8::
    2s+3s+4s set _while_ 1s+5s turn 3/4 RH to finish in middle of set,
    Men facing down, Ladies facing up
9-16::
    1s+5s dance reel of 4
17-24::
    1M+2s & 1L+3s+5M & 5L+4s dance LH across to finish on sidelines (2 1
    3 5 4) , 2s+1s & 5s+4s dance RH across
25-28::
    2s+1s+3s dance 1/2 RSh reels of 3 on the sides (2s & 1s pass RSh to
    begin) 3 1 2 5 4
29-32::
    2s+5s+4s dance 1/2 RSh reels of 3 on the sides (2s & 5s pass RSh to
    begin) 3 1 4 5 2', 0);
INSERT INTO 'dancecrib' VALUES (5289, '2013-08-21 08:31:04.179647+00', '2023-02-04 01:19:59.947049+00', 2208, 3, NULL, 'ace', '1-8::
    1s & 5s in prom hold dance reel of 3 across with 2s/4s ending in
    2nd/4th place (2s & 4s step up/down)
9-16::
    1s+3s+5s circle 6H round & back _while_ 2s & 4s turn partners 1/2
    way & chase clockwise to opposite end of set all on own sides
17-24::
    4s & 2s pass 1s/5s RSh on own side & weave parallel back to other
    end of set, 2s continuing to 2nd place & 4s to 4th place (1s & 5s
    step up/down)
25-32::
    1s cross between 2s, cast behind 3s, cross between 4s & cast behind
    5s to 5th place as others step up', 0);
INSERT INTO 'dancecrib' VALUES (9361, '2016-10-06 07:18:23.159959+00', '2023-02-04 01:20:00.028567+00', 13209, 3, NULL, 'ace', '1-8::
    1s & 5s cross RH, cast 1 place down/up, 1s+5s dance 1/2 RH across.
    1s cast round 4s to 5th place, 5s cast up to 1st place
9-16::
    5s & 1s dance DoSiDo with partners & turn partners RH (4 bars)
    _while_ 2s+3s+4s dance Grand Chain
17-24::
    All circle 10H round & back  5 2 3 4 1
25-32::
    5s cast to 4th place (2s+3s+4s step up 27-28) & all turn partners 2H
    (4 bars)  End 2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (8576, '2015-02-13 12:47:43.647645+00', '2023-02-04 01:20:00.063909+00', 15572, 3, NULL, 'ace', '1-4::
    1s and 2s dance Back-to-Back.
5-8::
    1s and 2s turn partner RH 1.1/4, to finish in line of 4 up and down
    in the middle, keeping RH joined, 1L joining LH with 2M. (Order from
    the top: 1M, 1L, 2M, 2L)
9-12::
    Balance-in-Line. 1L and 2M turn LH 3/4 , _while_ 1M and 2L chase
    clockwise round a quarter, to form a line of 4 across the set.
13-16::
    Repeat bars 9 - 12, to finish again in a line up and down the set,
    joining RH with partner.
17-24::
    1M and 2M lead their ladies down the middle, 1s leading, 2s
    following, then 2s divide to let 1s pass up between them, and follow
    them up, ready for
25-32::
    Allemande.', 0);
INSERT INTO 'dancecrib' VALUES (5292, '2013-08-21 08:31:04.303283+00', '2023-02-04 01:20:00.128525+00', 2222, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & turn LH to 1M facing his 1st corner with his
    partner behind him
9-16::
    1M followed by partner dance a full RSh diagonal Alternating Tandem
    reel of 3 with 1st corners & end facing Ladies 2nd corner
17-24::
    1M followed by partner dance a RSh Alternating Tandem reel of 3 with
    2nd corners & 1s end facing own 1st corners
25-32::
    1s turn 1st corners RH, pass RSh, turn 2nd corner RH & pass RSh to
    2nd place own sides (corners turn for 4 bars)', 0);
INSERT INTO 'dancecrib' VALUES (13615, '2021-02-04 01:19:41.137269+00', '2023-02-04 01:20:00.1549+00', 15236, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cast _while_ 2s dance up; 1s dance 1/2 Fig 8 down
    round 3s
9-16::
    Mirror reels of 3 on sides (6 bars), 1s dance in/up, 2s out/down.
    Bars 15-16: 1s+2s change places RH on side _while_ 3s cross RH.  End
    (1) 2 (3) with Men facing out
17-28::
    1s+2s+3s dance path of 3 couple Schiehallion rreel:
::
    _17-18_   Ladies dance 1/2 way across touching RH, 1Lto 3L''s place,
    2L to 2M''s place, 3L to 1L''s place _while_
::
    Men loop out to 1 place clockwise round, 1M to 2L''s place, 2M to
    1M''s place, 3M to 3M''s place
::
    _19-20_   Men dance 1/2 way across touching RH, 1M to 2M''s place, 2M
    to 3L''s place, 3M to 1L''s place _while_
::
    Ladies loop out to 1 place clockwise round, 1L to to 3M''s place, 2L
    to 1M''s place, 3L to 2L''s place
::
    _21-28_   Repeat 17-20 twice more to end as in Bar 16  (1) 2 (3)
29-32::
    1s+2s change places RH on side _while_ 3s cross to own side RH; 1s
    cross LH to 2nd place own side.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9346, '2016-10-06 07:18:00.534265+00', '2023-02-04 01:18:17.038248+00', 17136, 3, NULL, 'ace', '{{explanation}}
Note: All turns with Elbow Grip - RE=Right Elbow, LE=Left Elbow

{{title}}
Part A

1-8::
    1s NHJ dance between 3s, separate, cast into centre & dance out
    between 2s/4s back to place (1M between 2s, 1L between 4s)
9-16::
    1s turn RE, turn corners LE, 1s turn RE, 1M+2M also 1L+4L turn LE
17-24::
    1s turn RE, 1M+3L also 1L+3M turn LE.  1s dance to original places
    facing out, set & turn inwards to face partner

{{title}}
Part B

1-4::
    Men pass LSh dancing to Right into next Lady''s place, face out
    _while_ Ladies cast to partner''s place & face in.  All turn corner
    (dancer on Left) LE to finish NHJ with corner facing in
5-8::
    All Advance with corner & Men Retire with Lady on Left
9-12::
    Ladies pass LSh dancing to Right into next Lady''s place, face out
    _while_ Men cast to next Man''s place & face in.  All turn corner
    (dancer on Left) LE to finish NHJ with corner facing in
13-16::
    All Advance with corner & Men Retire with partner to new position (1
    place round anticlockwise)
17-24::
    All circle 8H round & back

{{explanation}}
Note: bars 1-2 & 9-10 of Part B resemble 2 bars of Schiehallion Reel', 0);
INSERT INTO 'dancecrib' VALUES (5293, '2013-08-21 08:31:04.311551+00', '2023-02-04 01:20:00.187083+00', 11483, 3, NULL, 'ace', '1-8::
    1M+3L dance Fig of 8 round 2s _while_ 1L+3M dance Fig of 8 round 4s
9-16::
    1s in prom hold dance reel of 3 across with 4M+2L (RSh to 4M to
    start) _while_ 3s dance reel of 3 with 2M+4L (RSh to 2M)
17-24::
    All Set+Link, 1/2 turn partners RH & all chase clockwise 1 place
25-32::
    All circle 8H round & back

{{explanation}}
Repeat from new places', 0);
INSERT INTO 'dancecrib' VALUES (5294, '2013-08-21 08:31:04.321821+00', '2023-02-04 01:20:00.218496+00', 9382, 3, NULL, 'ace', '1-8::
    1s & 3s set, 3/4 turn ptnrs RH into middle (Man facing up & Lady
    down), dance 1/2 reel of 4 end with 3M facing Ladies'' side & 1L
    facing Men''s side
9-16::
    1L & 3M followed by partners chase clockwise (all the way round)
    _while_ 2s turn RH & join in chase to end all on opposite sides.
    (3)(2)(1)
17-24::
    3s+2s dance 1/2 R&L, 3s+1s dance 1/2 R&L
25-32::
    1s dance 1/2 Fig of 8 round 3s, 1s & 3s set on sides & cross to own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (4487, '2013-08-21 08:30:49.546804+00', '2023-02-04 01:20:00.354913+00', 895, 3, NULL, 'ace', '1-8::
    1L casts 1 place & sets, casts to 3rd place & sets
9-16::
    1s cast up/down to 2nd place & set, 1L casts up into middle facing
    down _while_ 1M casts down 1 place into middle facing up & both set
17-24::
    1s circle 3H round & back (Lady with 2s & Man with 3s) ending facing
    2s/3s (2s facing up & 3s down)
25-32::
    1s+2s+3s set, 1s dance under arches made by 2s/3s to 2nd place own
    sides & 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5295, '2013-08-21 08:31:04.339777+00', '2023-02-04 01:20:00.41496+00', 9338, 3, NULL, 'ace', '1-8::
    1L followed by 2M cast round 2L, dance up, cast down round 1M & back
    to original places & turn right about to…
9-16::
    2M followed by 1L cast round 1M, dance down, cast up round 2L & back
    to original places (2M turning right about at the end)
17-24::
    1s set advancing, turn 2H, dance down between 2s & cast up round 2s
    into middle
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (11187, '2018-09-30 22:19:44.579816+00', '2023-02-04 01:20:00.458664+00', 18618, 3, NULL, 'ace', '1-8::
    1s+2s dance the Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH to face 1st corners
9-12::
    1s with 1st cnrs in prom hold dance 1/2 way round set anticlockwise
    _while_ 2nd cnrs Adv+Ret (1st cnrs stay in new pstn)
13-16::
    1s pass LSh & dance out ends of set (L up M down) & cast to 2nd pl
17-24::
    1s+2nd cnrs in prom hold dance 1/2 way round set anticlockwise
    _while_ 1st cnrs Adv+Ret (2nd cnrs stay in new pstn), 1s turn LH to
    2nd pl own side
25-32::
    1s dance diag R&L (L up, M down)
33-40::
    2s+1s+3s circle round & back.', 0);
INSERT INTO 'dancecrib' VALUES (12632, '2020-03-02 01:52:24.48183+00', '2023-02-04 01:20:00.476642+00', 2233, 3, NULL, 'ace', '1-8::
    1s & 4s set & cast in 1 place (2s & 3s step down/up); 1M & 4L dance
    1/2 Fig 8 round end couple (1M up, 1L down) _while_ 1L & 4M dance
    across thru'' partner''s place & cast Right  into lines across, 1L
    between 2s (top), 4M between 3s (bottom)
9-16::
    1M & 4L dance LSh reels of 3 on opp sides (1M down, 4L up) _while_
    1L & 4M set facing up/down, change places RH, set change places RH
    to 1L facing 2L (top), 4M facing 3M (bottom)
17-24::
    1L & 4M dance RSh reels of 3 across (1L+2L & 4M+3M pass RSh) _while_
    1M & 4L set facing across, change places RH, set, turn 3/4 RH to end
    4L behind 1L facing up, 1M behind 4M facing down
25-32::
    1L followed by 4L chase out of top of set & cast to Right _while_ 4M
    followed by 1M dance similar out of bottom of set to 2 4 1 3; All
    turn RH. 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7874, '2013-08-21 08:31:50.176881+00', '2023-02-04 01:23:08.390604+00', 7013, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance, 2 facing 2

1-8::
    All set, circle 4H round to left, 1s cast as 2s advance to face next
    couple
9-16::
    All dance Grand Chain (2 bars per / hand)
17-24::
    All dance Ladies'' Chain
25-32::
    All dance the Rondel (2s make arch & couple facing centre make arch)', 0);
INSERT INTO 'dancecrib' VALUES (15282, '2022-12-07 10:34:17.600874+00', '2022-12-07 16:44:48.927113+00', 21169, 1, 202, 'ace', '*Square set with 5c in centre facing P, 5M facing down, 1W facing up (1,2,3,4,5)*  

_Strathspey_

1--::

  1c & 3c S&Link finishing facing P _while{4}_ 5c set | cast R to change places and face P ; 1c, 3c & 5c set to P | turn P BH ½ and twirl on spot. 1c & 3c face centre as on [1] _as_ 5c finish BtoB, 5M facing 1c, 5W facing 3c

9--::

  1c+5M & 5W+3c RHA ; *LSh Snake Pass* : unwind the RHA, 5c leading, pass other snake LSh and chase cclw, 1c to 3pl, 3c to 1pl, 5c ending in centre LSh to P, 5M facing up, 5W facing down _while{8}_ 2c & 4c repeat [1-8]

17--::

  2c, 5c & 4c repeat [9-16]. 5c finish in centre facing P across, 5M with back to 4pl

25-28::

  All W cast off and chase 1pl cclw _while{4}_ 5c dance BtoB

29-40::

  *Mixer Chain* (2 bars per hand) : All change places with P RH | 1W+3M+5M & 1M+3W+5W LHA 2/3  _while{2}_ 2c & 4c change places LH ; repeat pattern of [29-32] twice more and face P (4,1,2,3,5)

41--::

  All change places RH. 5c finish in centre facing P across, 5M with back to 2pl | 4c, 1c, 2c & 3c set NHJ _while{2}_ 5c set to P. 5c face 4c  ; 5M+4M & 5W+4W cross RH | 4c in centre Petronella turn to face P, 4M facing down, 4W facing up (5,1,2,3,4)



Repeat four more times, alternately in Reel time and Strathspey time.', 4);
INSERT INTO 'dancecrib' VALUES (3893, '2013-08-21 08:30:38.683493+00', '2023-02-04 01:18:17.566214+00', 10779, 3, NULL, 'ace', '1-8::
    2s & 4s turn RH & 2L & 4L cast up 1 place _while_ 2M & 4M cast down
    1 place, 2L+1s also 2M+4L+3s also 4M+5s dance LH across
9-16::
    All dance RH across, 2L & 4L cast down 1 place _while_ 2M & 4M cast
    up 1 place & 1/2 turn partners RH in middle to 2s facing down & 4s
    up
17-24::
    2s+3s+4s set & circle 6H round to left 1/2 way, Men turn Lady on
    right 2H & circle left 1/2 way
25-32::
    2s & 4s 1/2 turn RH in middle to face down & dance down to 3rd/5th
    places,1s & 2s turn RH & cast 1 place.  3 1 5 2 4', 0);
INSERT INTO 'dancecrib' VALUES (5297, '2013-08-21 08:31:04.385337+00', '2023-02-04 01:20:00.500676+00', 2235, 3, NULL, 'ace', '1-8::
    1s+2s set, petronella turn, set & turn partners 2H
9-16::
    1s+2s dance reel of 4 in middle
17-24::
    1s+2s dance HS Poussette :
::
    1s set HS step with both hands joined dance out to Men''s side
    _while_ 2s set & dance out to Ladies'' side. Both couples end with a
    1/4 turn to right
::
    1s dance HS down Men''s side _while_ 2s dance up Ladies'' side, both
    couples end with a 1/4 turn to right
::
    2s+1s dance HS into centre to reform line of 4 in middle
::
    2s+1s 3/4 turn partners with 2H, 2s to own sides & 1s end facing 2nd
    corners
25-32::
    1s dance Pass+Turn with 2nd corners, turn RH & dance Pass+Turn with
    1st corners, 1s dance to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5298, '2013-08-21 08:31:04.393869+00', '2023-02-04 01:20:00.528953+00', 2236, 3, NULL, 'ace', '1-8::
    1s+3s+5s set advcg to join hands (RH to prtnrs) & set, all turn RH &
    1s cast to 5th pl _while_ 3s lead up to 1st pl as 5s lead up to 3rd
    pl.  3 2 5 4 1
9-16::
    Repeat bars 1-8 to end 5 2 1 4 3
17-24::
    5s & 1s lead down & back to 2nd & 4th places.  2 5 4 1 3
25-32::
    2s+5s also 1s+3s dance R&Ls

{{explanation}}
(popular variation - in bars 4/5 1s do not turn but use 4 bars to cast )', 0);
INSERT INTO 'dancecrib' VALUES (5299, '2013-08-21 08:31:04.468086+00', '2023-02-04 01:20:00.550273+00', 2237, 3, NULL, 'ace', '1-8::
    1s dance down the middle, set facing each other with 2H joined, cast
    up behind 3s on own side & cross LH
9-16::
    1s dance reels of 3 on sides giving LSh to 2nd corner & 1s end
    turning LH to end 1M between 2s facing up & 1L between 3s facing
    down
17-20::
    2s+3s dance 1/2 R&L changing RH on sides to start _while_ 1s cast to
    2nd place opp sides & cross LH back to own sides
21-24::
    3s+1s+2s set, 3s+1s turn 2H 1.1/4 times to end facing partner in
    middle _while_ 2s cross RH
25-32::
    3s+1s dance HS Poussette :
::
    3s set HS step with both hands joined dance out to Men''s side
    _while_ 1s set & dance out to Ladies'' side both couples end with a
    1/4 turn to right
::
    3s dance HS down Men''s side _while_ 1s dance up Ladies'' side both
    couples end with a 1/4 turn to right
::
    1s+3s dance HS into centre to reform line of 4 in middle
::
    1s+3s turn partners with 2H & 1s+3s+2s end ready for Allemande
33-40::
    1s+3s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5300, '2013-08-21 08:31:04.47766+00', '2023-02-04 01:20:00.576982+00', 12803, 3, NULL, 'ace', '1-8::
    All set & 3/4 turn RH, Men chase clockwise 1/2 way _while_ Ladies
    dance LH across once round to face new partner
9-16::
    All set & 1/2 turn new partner RH, Ladies chase clockwise 1/2 way
    _while_ Men dance LH across once round to face own partner
17-24::
    All dance 1/2 reverse Schiehallion reel (2 places to left & Men
    follow Ladies) to end in original places
25-32::
    All set (facing in) & set facing next couple (1s face 2s & 3s face
    4s), all dance 1/2 R&L with next couple
33-40::
    All set (facing in) & set facing other couple (1s face 4s & 3s face
    2s), all dance 1/2 R&L with other couple
41-48::
    All circle 8H round & back
::
    Repeat back to original places', 0);
INSERT INTO 'dancecrib' VALUES (5302, '2013-08-21 08:31:04.496065+00', '2023-02-04 01:20:00.623056+00', 9463, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s circle, all set, Ladies Link for 2 _while_ Men set
    again
9-16::
    1s+2s also 3s+4s dance RH across & LH back ending with 2s & 3s
    casting onto sides _while_ 1s & 4s end BtoB facing 2s/3s (M face M)
17-24::
    All dance reels of 4 across & 2s/3s end in 1st/4th places _while_ 1s
    face 4s in middle
25-32::
    1s+4s set, change places RH with other prtnr & 4s lead up cross &
    cast to 2nd pl own sides _while_ 1s lead down cross & cast up to 3rd
    pl opp side', 0);
INSERT INTO 'dancecrib' VALUES (11188, '2018-09-30 22:19:44.661597+00', '2023-02-04 01:20:00.654521+00', 16509, 3, NULL, 'ace', '1-4::
    1s+3s Petronella turn & set to partners
5-8::
    1s+3s dance 1/4 reel of 4(i.e. pass RSh) _while_ 2s set, 1L+2s+3M
    dance 1/4 reel of 4 across _while_ 1M+3L set
9-16::
    Repeat 1/4 reel of 4 figure (bars 5-8) twice more from new places
    (End 3M+3L+1M+1L in line in centre, 2s in 2nd place opp sides)
17-20::
    1s+3s turn partners 3/4 RH to own sides & 3s+2s+1s set
21-24::
    3s+2s dance 1/2 RH across, 3s+1s dance 1/2 LH across. 2 (1) 3
25-32::
    1s turn 2H 1.1/2 times; dance down & cast up round 3s into 2nd place
    own side

{{explanation}}
Note: Bars 31-32 of 2nd time through, 4s step up into 3rd place while 1s loop into 4th place instead of casting up.', 0);
INSERT INTO 'dancecrib' VALUES (8320, '2014-07-29 12:59:00.200483+00', '2023-02-04 01:20:00.879436+00', 15365, 3, NULL, 'ace', '1-4::
    1s+2s+3s set & 1/2 turn 2H, 1s+3s retain nearer hands. 1s face down,
    3s face up, 2s face out opp sides
5-8::
    1s+2s+3s dance 1/2 Reflection reels (1s down and in), 1s curve in to
    end BtoB facing opp. sides, 2s dance ''loop'' to 3rd place (3) (1) (2)
9-16::
    Petronella Double Triangles: 1s dance normal double triangles but
    corners petronella 1 place anticlockwise as 1s pivot round   2 1 3
17-24::
    1s dance Corners Pass & DoSiDo (rather than turn): as corners
    Pass+Turn but corners dance DoSiDo instead of turning, 1s pass RSh
    to finish in 2nd place own side
25-32::
    All circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (15134, '2022-10-05 00:19:49.368575+00', '2023-02-04 01:20:00.899543+00', 20787, 3, NULL, 'ace', '1-4::
    1L+2M dance towards each other (1 step), pull back RSh & cast
    _while_ 1M & 2L dance towards each other (1 step), pass LSh & dance
    out to sides. 2 1 3
5-8::
    2s+1s circle 4H round to left
9-16::
    2s+1s+3s 1/2 turn partner RH, pull back RSh & dance out to opp
    sides; 2s+1s+3s circle 1/2 round to left. Finish 3s at top in centre
    NHJ, 1s in 2nd place own side, 2s in centre at bottom NHJ
17-24::
    2s+3s dance 1/2 R&L then Set+Link _while_ 1s set, dance DoSiDo &
    set.  2 1 3
25-32::
    2s+1s+3s dance Grand Chain (2s cross, 1s+3s change places RH on
    sides to start)', 0);
INSERT INTO 'dancecrib' VALUES (5303, '2013-08-21 08:31:04.50446+00', '2023-02-04 01:20:00.95294+00', 14387, 3, NULL, 'ace', '1-8::
    1s lead down & back finishing facing out in place
9-16::
    1s dance Figs 8 on own sides, casting down to start
17-24::
    1s followed by other couples cast behind own lines.  1s make arch &
    other couples dance up under
25-32::
    All circle round & back', 0);
INSERT INTO 'dancecrib' VALUES (3894, '2013-08-21 08:30:38.695947+00', '2023-02-04 01:18:17.762584+00', 9386, 3, NULL, 'ace', '1-8::
    1s cast 1 place & 1s+3s+4s dance reel of 3 on sides (1s in & down to
    start)
9-16::
    2s+1s+3s dance reel of 3 on sides (1s in & up to start) & end 2s
    casting down 1 place as 1s dance to top
17-24::
    1s cast 1 place & cross RH, cast to 4th place & cross LH to own side
25-32::
    All set twice, all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (3895, '2013-08-21 08:30:38.707815+00', '2023-02-04 01:18:17.802879+00', 9451, 3, NULL, 'ace', '1-8::
    1s set & advance to 2nd place opposite sides, 1s dance circle of 3
    on each side & end turning into sidelines
9-16::
    All advance (1 bar) & retire then 1M passes 2L RSh to dance reel of
    3 across as 1L gives RSh to 3M for reel across 1s end between 2s/3s
17-24::
    All set twice, 1s turn 2H 1.3/4 times & face down as 2s step in
25-32::
    1s followed by 2s dance down middle & up, all set & turn partner 2H
    to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13147, '2020-09-15 00:19:40.110538+00', '2023-02-04 01:20:00.97958+00', 14262, 3, NULL, 'ace', '{{explanation}}
6 couple square set, 5s & 6s in centre, 5s facing 1s, 6s facing 3s

1-8::
    1s+5s+6s+3s dance RSh reels of 4 up/down set
9-12::
    1s+5s also 6s+3s dance RH across _while_ 2s & 4s 1/2 turn partner RH
    & set
13-16::
    1s+5s also 6s+3s dance 1/2 LH across _while_ 2s & 4s 1/2 turn
    partner LH, 1s & 3s (centre couples) chase clockwise 1/2 round in
    centre _while_ others chase anticlockwise 1 place
17-24::
    6s+3s+1s+5s dance LSh parallel reels of 4 across set
25-32::
    3s+1s (centre couples) join NH with corners & set as Double
    Triangles moving 1 place clockwise & repeat (outer couples may join
    NH). End 2 6 4 5 1s In centre facing up, 3s in centre facing down', 0);
INSERT INTO 'dancecrib' VALUES (13148, '2020-09-15 00:19:40.133138+00', '2023-02-04 01:20:01.007271+00', 18046, 3, NULL, 'ace', '1-8::
    1s+3s dance Double Fig 8 round standing 2s (1s cross down, 3s dance
    up)
9-16::
    1s & 2s dance Chain Progression:
::
    1s+2s 3/4 turn RH, 1M+2L turn LH 1.1/2 times as ptnrs chase cl''wise
    1/2 way, 2s+1s 3/4 turn RH to end on sides in order 2 1, 1s facing
    out
17-24::
    1s cast (1M up, 1L down), meet in centre & 1/2 turn RH, pull back
    RSh 1s cast to Right (1L up, 1M down) to end 2nd place own side
25-32::
    1s+3s Mirror Set+Link (1s cast, 3s dance up), 1s turn 2H, dance down
    slightly & cast up to 3rd place facing out', 0);
INSERT INTO 'dancecrib' VALUES (5304, '2013-08-21 08:31:04.512796+00', '2023-02-04 01:20:01.0292+00', 2242, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s & 3s+4s circle 4H round to Left to end in middle, 1s facing
    2s, 3s facing 4s. All set, 1s+4s turn inwards towards partner & cast
    in 1 pl down/up (2s dance up, 3s dance down one pl)  & 1M+4L also
    1L+4M change places LH on sides  2 (4) 1 (3)
9-12::
    1s+4s lead out of ends, cross & cast. 1s+4s change places LH on
    sides.
13-16::
    1s & 4s repeat 9-12, leading out other end, cross & cast & 1s+4s
    change places LH on side. 1s face down, 4s face up
17-24::
    All dance reels of 4 on sides & end facing same person as at start
    of reel.   2 4 1 3
25-32::
    2s+4s also 1s+3s set facing on sides, 1s & 4s turn end couples
    (dancing between ends) & dance 1/2 Figs of 8 round end couples to
    end 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (9195, '2016-06-16 22:41:47.593185+00', '2023-02-04 01:20:01.183098+00', 17027, 3, NULL, 'ace', '{{explanation}}
4 Bar intro - Bow to partners, bow to centre

1-4::
    Ladies dance RH across 3/4 way, Men dance RH across _while_ Ladies
    dance round facing positions
5-8::
    Ladies dance RH across 3/4 way _while_ Men dance round facing pstns,
    Men dance RH across 3/4 way _while_ Ladies dance round facing pstns
9-16::
    Repeat bars 5-8 twice more & Men end in centre facing partners
17-24::
    Ladies dance RH across 1/2 way _while_ Men dance round facing
    positions, Men dance RH across 1/2 way _while_ Ladies dance round
    facing positions & repeat 3 more times & Men end in centre facing
    partners
25-28::
    Ladies change places RH with partners & dance LH across 3/4 way
    _while_ Men dance clockwise 1 place round set
29-32::
    Ladies dance out to place beside partner & all bow to centre

{{explanation}}
Repeat from new places', 0);
INSERT INTO 'dancecrib' VALUES (5305, '2013-08-21 08:31:04.546472+00', '2023-02-04 01:20:01.20177+00', 12941, 3, NULL, 'ace', '1-8::
    1L followed by partner casts 2 places, 1L crosses & casts up on
    Men''s side to 2nd place _while_ 1M dances up the middle to 2nd place
    Ladies'' side. All set advancing into prom hold (2s & 3s face up, 1s
    down) 2(1)3
9-16::
    2s+1s+3s dance "Circulating Allemande":
::
    2s & 3s dance normal Allemande but end in 3rd/1st place as 1s
    Allemande (down) & up to 2nd place opposite sides.  3(1)2
17-24::
    1s dance 1/2 Figs of 8 (1L up round 3s, 1M down round 2s), all turn
    partners 2H.  3 1 2
25-32::
    1s+2s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (14524, '2022-01-10 02:19:16.847014+00', '2023-02-04 01:20:01.254095+00', 17963, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig round 2s; 1s dance down between 3s & cast up into
    3rd place opp sides (2s+3s step up 7-8)
9-16::
    1s dance 1/2 Fig 8 up round 3s; 1s dance up & cast off (3s step down
    13-14), passing LSh to BtoB in middle (1M facing down, 1L facing up)
17-24::
    All set as Double Triangles, 1s+1st corner turn LH & join RH with
    partner; all Bal-in-Line, 1s turn RH to end BtoB in middle (1M
    facing up, 1L facing down)
25-32::
    All set as Double Triangles, 1s+2nd corner turn RH & join LH with
    partner; all Bal-in-Line, 1s turn LH to 2nd place opp side facing
    out
33-40::
    Reels of 3 on sides, 1s+2nd corner pass LSh to start, Bars 39-40 1L
    crosses down between 2s, 1M crosses up between 3s to 2nd place own
    side
41-48::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5308, '2013-08-21 08:31:04.574513+00', '2023-02-04 01:20:01.280282+00', 2245, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on sides & 1s turn 2s
    (1M+2L LH & 1L+2M RH) to form line of 4 across face down (1s in
    centre)
9-16::
    1s+2s dance down for 3 bars, dance up to 2nd place, 1s dance to top
    & cast on opp sides as 2s follow dancing up to top & casting into
    1st pl
17-24::
    1s cross RH, cast down 1 place & dance up to top & cast into 1st
    place (2s step down)
25-32::
    1s+2s dance 1/2 R&L & turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (11696, '2019-03-18 21:02:09.172549+00', '2023-02-04 01:20:01.290599+00', 19138, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-12::
    "Flirt & Cast":
::
    _9-10_   1L+2M dance 1 step towards each other, pull back RSh, dance
    out again to place (1 step) & face out
::
    _11-12_ 1L+2M cast to Right (1L down, 2M up) _while_ 1M+2L dance
    towards the middle & curve into their own sidelines
13-16::
    2s+1s circle 4H round to the left
17-24::
    2s+1s+3s set, dance back to back (DoSiDo), all set
25-32::
    1s cross RH & cast to 3rd place (3s step up 27-28). 1s 1.1/2 turn 2H
    to finish in 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (10072, '2017-09-03 23:44:38.570144+00', '2023-02-04 01:20:01.301635+00', 17772, 3, NULL, 'ace', '{{title}}
Strathspey

1-4::
    1s cross down (no hands) as 2s cast up.  1s 1/2 turn 2s (1M+2L LH,
    1L+2M RH)
5-8::
    1s cross down (no hands) to 2nd place own side & cast up to top
    _while_ 2s cast up & dance down to 2nd place
9-16::
    2s cast up to top _while_ 1s dance down below 4s, then 1M followed
    by 1L cast up round 4M & up 2 places, finishing in middle,  pulling
    back RSh to face 2M with 1M following 1L
17-24::
    1s in tandem dance Corner Pass+Turn with 2M+3L, pull back RSh to
    face 2L (1L following 1M) & dance Corner Pass+Turn with 2L+3M.  End
    in 2nd place own side
25-32::
    2s+1s+3s circle 6H 1/2 round to Left, 1s turn 3/4 2H, petronella
    turn to 2nd place own side _while_ 2s+3s chase clockwise 1/2 round
    2 1 3 4

{{title}}
Reel

1-4::
    1s cross down (no hands) as 3s cast up.  1s 1/2 turn 3s (1M+3L LH,
    1L+3M RH)
5-8::
    1s cross down (no hands) to 3rd place own side & cast up to 2nd
    place _while_ 2s cast up & dance down to 3rd place
9-16::
    3s cast up to 2nd place _while_ 1s dance down, cast down round 4s,
    meet and dance up to 3rd place in middle facing each other joining
    2H.  1s set, dropping hands, pulling back RSh to face own sides
17-24::
    3s+1s+4s dance Double Triangles, 1s end in 3rd place own sides
25-32::
    3s+1s+4s circle 6H 1/2 round to Left, 1s turn 1.1/2 RH to 3rd place
    own side _while_ 3s+4s chase clockwise 1/2 round to end 2 4 1 3
::
    1st couple step down to 4th place (4s step up) as new 1st couple
    start reel', 0);
INSERT INTO 'dancecrib' VALUES (5309, '2013-08-21 08:31:04.660184+00', '2023-02-04 01:20:01.45153+00', 12674, 3, NULL, 'ace', '1-8::
    1s+2s also 4s+5s dance RH across & LH back
9-16::
    2s+3s+4s Adv+Ret & turn partners RH
17-24::
    1s dance in front of 2s & behind 3s, in front of 4s & behind 5s to
    5th place 2s+3s+4s+5s step up as 1s pass them
25-32::
    All circle 10H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10073, '2017-09-03 23:44:38.714431+00', '2023-02-04 01:20:01.587238+00', 2251, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s lead down the middle & up to 2nd place (2s step up 3-4)
17-24::
    1s turn RH & 1s turn LH', 0);
INSERT INTO 'dancecrib' VALUES (12916, '2020-07-01 00:19:35.818015+00', '2023-02-04 01:20:01.743927+00', 2253, 3, NULL, 'ace', '1-8::
    All set & cross RH, set & cross back RH
9-16::
    1s set, cast 1 place to face 1st corners (2s step up 11-12); 1s
    dance 1/2 reel of 4 with 1st corners & do a quick 1/2 turn RH to end
    in centre in 2nd place NHJ facing down
17-24::
    1s dance down, cross below 3s & cast up to face 2nd corners; 1s
    dance 1/2 reel of 4 with 2nd corners to finish back to back in
    centre in 2nd place facing opp side
25-28::
    3L+1L+2L dance RH across on Men''s side _while_ 3M+1M+2M dance LH
    across on Ladies'' side
29-32::
    1s dance to top place on opposite side, cast down 2 places & cross
    RH to finish in 3rd place _while_ 2s cross RH, retain hands, lead up
    middle & curve into top place on bar 32 _while_ 3s dance down side,
    cross diagonally to giving RH curve up into 2nd place. End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5307, '2013-08-21 08:31:04.565696+00', '2023-02-04 01:20:01.756761+00', 8049, 3, NULL, 'ace', '1-8::
    1L followed by 1M casts 2 places & 1L crosses then casts up to 1M
    place as 1M dances up middle to 1L place & 1s set
9-16::
    1s repeat bars 1-8 with 1M leading to end in original places
17-24::
    1s lead down middle & up to top ready for…
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5311, '2013-08-21 08:31:04.679178+00', '2023-02-04 01:20:01.769707+00', 2254, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s turn RH, cast in 1 place, cross RH with partner (2s & 3s
    step up/down), 1M+4L & 4M+1L turn 3/4 LH on sides into line of 4
    across (Ladies in centre)
9-16::
    4s+1s dance the Targe :
::
    _9-10_  1st & 4th Ladies  3/4 turn RH _while_ Men dance 1/4 way
    round anticlockwise
::
    _11-12_ 1st Man with 4th Lady & 1st Lady with 4th Man full turn LH
::
    _13-14_ 1st & 4th Ladies  3/4 turn RH _while_ Men dance 1/4 way
    round anticlockwise
::
    _15-16_ 1st Man with 4th Lady & 1st Lady with 4th Man turn LH to end
    on sides 2 1 (4)(3)
17-24::
    All dance RSh parallel reels of 4 on sides
25-32::
    End couples (2s+1s & 4s+3s) 1/2 turn RH on sides, middle couples
    (2s+3s) dance LH across _while_ end couples chase clockwise to other
    ends, end couples 1/2 turn RH on sides to end 2 4 (1)(3)
33-40::
    All set, turn partners 2H into two circles of 4H round to left
    (2s+4s & 1s+3s). End  2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (5313, '2013-08-21 08:31:04.699399+00', '2023-02-04 01:20:01.800226+00', 10390, 3, NULL, 'ace', '1-8::
    1s set & turn 2H, dance down NHJ & cast up round 3s to 2nd place,
    own sides (2s step up 5-6)
9-16::
    1s dance reflection (mirror) reels of 3 on sides (1s dance in & up
    to start), 1s end facing 1st corners, 2s & 3s dance loops into place
17-24::
    1s dance ''Hello-Goodbye'' setting in centre (not dancing out to sides
    or ends) & 1s petronella turn to 2nd place own sides
25-32::
    1s+3s dance the Knot with 2s also turning LH for last 4 bars', 0);
INSERT INTO 'dancecrib' VALUES (5314, '2013-08-21 08:31:04.709319+00', '2023-02-04 01:20:01.936926+00', 2257, 3, NULL, 'ace', '1-8::
    1L followed by partner casts below 2s, lead up & cross back to
    places
9-16::
    1L followed by partner dances down the middle, about turn & lead
    back to places
17-24::
    1s+2s circle 4H round to left, 1s+2s Adv+Ret
25-32::
    1s+2s dance RH across & LH back to places
33-40::
    1s+2s circle 4H round to left, 1s+2s Adv+Ret
41-48::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (5315, '2013-08-21 08:31:04.719577+00', '2023-02-04 01:20:01.960116+00', 2258, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place (2s step up); 1s dance 1/2 Fig of 8 up
    round 2s
9-16::
    1s dance 1/2 Fig of 8 down round 3s; 1s cross RH & cast to 3rd place
    (3s step up).  2 3 1
17-24::
    1s dance reels of 3 on opp sides (1s cross up, 2s dance in/down, 3s
    dance out/down to start), 1s end 3rd place opposite side.  2 3(1)
25-32::
    1s cross RH to face up NHJ (1L on 1M''s right) & 2s+3s+1s circle 6H
    round to left.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5317, '2013-08-21 08:31:04.737945+00', '2023-02-04 01:20:02.23171+00', 11518, 3, NULL, 'ace', '1-8::
    1s cross, cast & turn 3s on sides (LH Ladies'' side & RH Men''s side)
9-16::
    2s+1s+3s set, 1s turn LH & dance RH across (1L+2s & 1M+3s) ending on
    own sides
17-24::
    2s+1s+3s set, 1s turn LH & dance RH across (1M+2s & 1L+3s) ending
    opposite sides
25-32::
    1s dance 1/2 Fig of 8 round 2s & dance down and cast into 4th place
    (as 3s+4s step up)', 0);
INSERT INTO 'dancecrib' VALUES (5318, '2013-08-21 08:31:04.748134+00', '2023-02-04 01:20:02.263459+00', 2260, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L cross, cast behind 1M, in front of 2M, behind
    3M, cross & dance up to places
9-16::
    1M followed by 2M+3M repeat around Ladies
17-24::
    1s slip step down the middle & up to 2nd place
25-32::
    2s+1s+3s slip step down & back', 0);
INSERT INTO 'dancecrib' VALUES (5319, '2013-08-21 08:31:04.756522+00', '2023-02-04 01:20:02.279774+00', 2263, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place (2s up), 1s dance 1/2 Figs of 8 (1M round
    2s & 1L round 3s) _while_ 2s+3s set & cross RH
9-16::
    1s dance reels of 3 own sides (RSh to 4th corner pstns-3L/2M) 1s end
    in centre (1L above 2s & 1M below 3s) _while_ 2s+3s cast to meet on
    sides
17-24::
    1s set & petronella turn onto opposite sides _while_ 2s+3s cross
    Ladies under Men''s arch & cast to 1st/3rd places, 2s+1s+3s turn RH
25-32::
    1s dance down below 3s & cast up on opp sides to 2nd place, 1s dance
    1/2 Figs of 8 round 2s _while_ 2s+3s dance R&L (RH on sides to
    start)', 0);
INSERT INTO 'dancecrib' VALUES (5320, '2013-08-21 08:31:04.766703+00', '2023-02-04 01:20:02.29522+00', 9802, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, dance down between 3s & cast up to 2nd
    place
9-16::
    1s dance reels of 3 across (1L with 2s & 1M with 3s)
17-24::
    1s turn RH to face 1st corner & turn corner LH to face 2nd corner,
    turn corner RH to 2nd place opposite side & all set
25-32::
    1s turn RH to face 3rd corner &  turn corner LH to face 4th corner,
    turn corner RH to 2nd place own side & all set
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8321, '2014-07-29 12:59:00.558322+00', '2023-02-04 01:20:02.199185+00', 15366, 3, NULL, 'ace', '1-8::
    1s+2s dance the Tourbillon, linking on bars 7-8, 1s stay facing out
9-16::
    1s cast to their right (around 3rd corner), change places with 1/2
    RH turn  and twirl, cast right (around 4th corner) back to places
17-24::
    All  Adv+Ret for 1 step & cross RH; chase clockwise 1/2  way round
    the set
25-32::
    1s dance 1/2 LSh reel of three on the sides (2L / 3M casting); 1s
    turn RH, face, pull back RSh and dance out to places', 0);
INSERT INTO 'dancecrib' VALUES (5316, '2013-08-21 08:31:04.727796+00', '2023-02-04 01:20:02.212538+00', 2259, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance bottom crossing ''U'' Chain (As Grand Chain but 3s
    cross to start & top couples set instead of crossing)
9-16::
    1s+2s set, cross RH, 1s lead up LH cross & cast to face 3rd corners
    (1st corner person)
17-24::
    1s dance 1/2 reel of 4 with 3rd corners, pass RSh & dance 1/2 reel
    with 4th corners
25-32::
    1s dance reel of 3 on opposite sides giving RSh to 1st corners & end
    crossing to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (5321, '2013-08-21 08:31:04.775035+00', '2023-02-04 01:20:02.311417+00', 10161, 3, NULL, 'ace', '1-8::
    1M (RH hand raised for 2 bars) followed by 1L+2L+3L+4L cast behind
    2M, in front of 3M, behind 4M, across & up Ladies'' side back to
    place
9-16::
    1M followed by 2M+3M+4M cross down, out behind 2L, in front of 3L,
    behind 4L & across & up to places
17-24::
    1s+2s dance RH across 1/2 way, 1s+3s dance LH across 1/2 way, 1s+4s
    dance RH across 1/2 way & all cross RH to own side
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5323, '2013-08-21 08:31:04.793197+00', '2023-02-04 01:20:02.347583+00', 2267, 3, NULL, 'ace', '1-8::
    1s set & cross RH, cast 1 place & turn LH (ending in a diagonal line
    LH to partner & RH with 1st corner)
9-16::
    1s Bal-in-Line with 1st crnrs, 1/2 turn crnrs & 1s followed by crnrs
    chase cl''wise to 3rd crnr (pstn),1s dance in, join RH with partner &
    LH with 2nd crnrs
17-24::
    1s Bal-in-Line with 2nd crnrs, 1/2 turn crnrs & 1s followed by crnrs
    chase anticl''wise to 4th crnr (pstn), 1s crossing LSh to 2nd pl opp
    sides facing out
25-32::
    3s+1s+2s dance 1/2 reels of 3 on the sides 1s giving LSh to 2nd
    corner (position); 2s+1s+3s set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (5324, '2013-08-21 08:31:04.803702+00', '2023-02-04 01:20:02.366458+00', 2269, 3, NULL, 'ace', '1-8::
    All Men dance clockwise & RSh round next Lady to face her, continue
    to turn to right & dance behind next Lady to opposite place _while_
    all Ladies dance Coupé Pas de Basque
9-16::
    All Ladies dance RSh behind & round ''new'' partner to face him,
    continue to turn to right & dance behind next Man to opposite place
    _while_ all Men dance Coupé Pas de Basque
17-32::
    All Promenade clockwise to original places & dance in prom hold reel
    of 4 up/down (2s & 4s pass LSh to give RSh to 1s/3s) ending in orig
    places
33-48::
    All dance Grand Chain
49-56::
    All dance Double Ladies Chain (all Ladies give RH in middle)
57-64::
    All Promenade anticlockwise (Men on inside)
65-72::
    All dance Coupé Pas de Basque (facing in)
73-80::
    All set to corner & turn RH, set to partner & turn RH & end Ladies
    facing out
81-96::
    All dance full Schiehallion Reel
97-104::
    All repeat bars 9-16 (Ladies dance clockwise etc)
105-112::
    All repeat bars 1- 8 (Men dance clockwise)
113-128::
    All repeat bars 17-32 with reel of 4 across (1s & 3s pass LSh to
    give RSh to 4s/2s) ending in original places', 0);
INSERT INTO 'dancecrib' VALUES (5325, '2013-08-21 08:31:04.812156+00', '2023-02-04 01:20:02.3809+00', 9537, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH, 1s+2s dance RH across 1/2 way, 1s+3s dance LH across
    1/2 way & 1s+4s dance RH across 1/2 way
9-16::
    1s cast to top on own sides, cross RH & cast 1 place to face 3rd
    corner (pstns)
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners to end facing out in 2nd place
    opposite sides
25-32::
    1M+3M change places RH on sides as 1L+3L change places LH, 1M+4M
    change places LH as 1L+4L change places RH, all set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (14648, '2022-03-07 02:19:41.546384+00', '2023-02-04 01:20:02.440541+00', 20398, 3, NULL, 'ace', '1-8::
    All circle 8H round and back
9-16::
    All dance reels of 4 on sides
17-24::
    1s & 4s cross RH & cast in (2s & 3s step down/up). 1s+4s dance 1//2
    R&L. 2 4 1 3
25-32::
    2s+4s also 1s+3s dance RH across, all turn partner RH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15327, '2022-12-19 01:19:49.993982+00', '2023-02-04 01:20:02.452209+00', 21125, 3, NULL, 'ace', '1-8::
    1s cross RH & cast to 2nd place (2s step up); 1s+3s Set+Link (1L
    faces out)
9-16::
    1L followed by 1M dance tandem Fig of 8 on the side round 3M+2M (RSh
    to 3M to start). Bars 15-16: 1L crosses to 2nd place own side facing
    out
::
    (3s step down). 2 1 3
17-24::
    2s+1s+3s dance parallel reels of 3 on own sides (1s pass 3s RSh)
25-32::
    2s+1s+3s Set & Rotate for 3 couples. 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (15328, '2022-12-19 01:19:50.014937+00', '2023-02-04 01:20:02.469897+00', 21178, 3, NULL, 'ace', '1-4::
    1s Advance for 2 steps, 1M+2M turn LH _while_ 1L+4L turn RH.
5-8::
    1M+3L turn 3/4 RH _while_ 1L+3M turn 3/4 LH, 1s meet and dance back
    to place. All face partners.
9-12::
    All dance grand chain 1/2 way round (1 bar/hand).
13-16::
    All turn partner RH (or birl).
17-24::
    All dance double R&L:
::
    _17-18_  1s+3s change RH with opp person _while_ 2s+4s change RH
    with partner.
::
    _19-20_  1s+3s change LH with partner _while_ 2s+4s change LH with
    opp person.
::
    Repeat bars 17-20
25-32::
    All Advance 2 steps & touch hands in circle, Retire 2 steps (with
    partners).  All turn partner 3/4 RH and promenade 1 pl clockwise
    round set.', 0);
INSERT INTO 'dancecrib' VALUES (13149, '2020-09-15 00:19:41.630924+00', '2023-02-04 01:20:02.490376+00', 18077, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to end 1M leading with 1L following facing
    2M (1st place)
9-16::
    1s dance 1/2 Alternating Tandem Reel, 1M leading RSh to 2M  1s+2nd
    corners repeat, 1L leading RSh to 3M to start. 1s end in centre
    facing down (1L on 1M''s right)
17-24::
    1s lead down , cast up, dance up to top & cast to 2nd place opp
    sides _while_ 3s+2s dance R&L up/down.  (3) (1) (2)
25-32::
    3s+1s+2s Set+Link for 3 twice.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5328, '2013-08-21 08:31:04.83956+00', '2023-02-04 01:20:02.506845+00', 2275, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, 1s lead down to 3rd place, cross & cast to
    2nd place _while_ 2s set & cross to 3rd place _while_ 3s cast to top
    & cross RH (as Muirland Willie)
9-16::
    3s+1s+2s dance reels of 3 on sides (1s dance in & up to start)
    ending with partner in centre facing down
17-24::
    2s followed by 1s+3s lead down & 3s lead back to top
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (8577, '2015-02-13 12:47:44.355046+00', '2023-02-04 01:20:02.519616+00', 2276, 3, NULL, 'ace', '1-8::
    1s turn RH moving down then lead down, cross below 3s, cast up thro''
    2nd place & turn RH to finish in middle (1L facing down/1M up)
    _while_
::
    2s+3s dance up to top, lead down following 1s, cross, cast up to
    1s/3rd place opp. sides
9-16::
    1s dance Fig. 8 on opp. sides, 1M down & in/1L up & out to start (6
    bars).  1s turn RH to 2nd place own sides  (2) 1 (3)
17-24::
    2s+1s+3s RSh reels of 3 on sides 1M up/1L down to start (6 bars). 1s
    turn RH 1+ times _while_ 2s+3s cross to own sides passing RSh
25-32::
    2s+1s+3s RSh reels of 3 on sides (1M+2L, 1L+3M pass RSh) in 6 bars.
    1s cross RH to 2nd place own side.', 0);
INSERT INTO 'dancecrib' VALUES (5329, '2013-08-21 08:31:04.849648+00', '2023-02-04 01:20:02.544041+00', 13442, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 2s+1s+3s set twice.
9-16::
    1s dance RSh reels of 3 on sides (1M up, 1L down)
17-24::
    1s cross LH & cast LSh round 4th corners into lines across (1L
    between 2s, 1M between 3s), all set twice
25-32::
    1s dance reels of 3 across 1s LSh to the person on their left & end
    in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (11171, '2018-09-29 09:42:51.691747+00', '2023-02-04 01:20:02.562136+00', 18665, 3, NULL, 'ace', '1-8::
    1s cross down (2s step up 1-2), turn 3s (1M+3L RH, 1L+3M LH) to meet
    in middle NHJ.  1s dance up between 2s & cast to 2nd place opp sides
9-16::
    Mirror reels of 3 on sides (2s out/down, 1s in/down, 3s out/up to
    start)
17-24::
    1s cross passing LSh, turn 3rd corner RH to face up/down; cross
    passing partner LSh, turn 4th corner RH to finish in 2nd place own
    side
25-32::
    2s+1s+3s chase clockwise round back to place', 0);
INSERT INTO 'dancecrib' VALUES (5330, '2013-08-21 08:31:04.85798+00', '2023-02-04 01:20:02.589541+00', 2278, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place (2s step up); 1s dance up, cross & cast
    into 2nd place on opposite sides
9-16::
    2s & 3s cross RH & dance mirror reels of 3 on opposite sides with 1s
    (1s in/down, 2s out/down & 3s out/up to start).  (2) (1) (3)
17-24::
    2s+1s+3s set & 3/4 turn partner to line up/down centre (Men facing
    down, Ladies up retaining hands), set & 3/4 turn to own sides. 2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5331, '2013-08-21 08:31:04.866328+00', '2023-02-04 01:20:02.612023+00', 9858, 3, NULL, 'ace', '1-8::
    All circle 6H round & back
9-16::
    1s+2s+3s dance »Inveran Reels« on sides, each couple crossing down
    from 1st place & crossing up from 3rd place (1s cross down, 2s dance
    up, 3s cross up to start)
17-24::
    1s+2s dance LH across, 2s+3s dance RH across
25-32::
    2s followed by 1s dance down between 3s, 2s cast up to 1st place &
    1s to 2nd place own sides, 1s followed by 3s dance up, 1s cast to
    3rd place & 3s to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (12464, '2020-01-02 06:59:44.945365+00', '2023-02-04 01:20:02.631844+00', 12832, 3, NULL, 'ace', '1-8::
    1s+2s petronella in tandem & set & repeat. (1) (2) 3 4
9-16::
    1s followed by 2s dance down (LH joined), cross  below 3s, cast up,
    meet & dance up, 1s cast to 2nd place _while_  2s dance up & cast
    into 1st place
17-24::
    1s followed by 3s dance up, cast round 2s, meet, dance down & cast
    up to end 2 1 3
25-32::
    2s+1s+3s dance mirror reels of 3 on sides (1s cross up, 2s out/down,
    3s out/up). Bar 29 1s cross LH (from 3rd place) to continue reel on
    own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5332, '2013-08-21 08:31:04.877481+00', '2023-02-04 01:20:02.658593+00', 13450, 3, NULL, 'ace', '1-8::
    1s set & cross RH, 1s cast 1 place & turn RH to face 1st corners
9-16::
    1s Pass+Turn with corners & end 2nd pl own side (1L facing dn, 1M
    up), 1s dance 1/2 reels of 3 on sides & 1s end turning LH to face
    2nd crnr (pstn)
17-24::
    1s LSh Pass+Turn with 2nd corners & end in 2nd pl own side (1M
    facing dn, 1L up), 1s dance 1/2 LSh reels of 3 on sides & turn RH to
    2nd pl opp side
25-32::
    1s & 3s dance 3/4 double Fig of 8 (1s cast down & 3s cross up to
    start), 1s end turning 2H in 3rd place as 3s stand', 0);
INSERT INTO 'dancecrib' VALUES (5333, '2013-08-21 08:31:04.887673+00', '2023-02-04 01:20:02.686882+00', 13647, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s dance 1/2 Fig of 8 round 2s
9-16::
    1s dance 1/2 reels of 3 across (L with 2s, M with 3s), 1s dance 1/2
    reels on own sides &end facing 1st corners
17-20::
    All set & 1s dance RSh round each other to face 2nd corner (pstns)
    as 2s+3s change places RH on sides
21-24::
    All set & 1s dance RSh round to 2nd place own sides as 2s & 3s cross
    RH.  2 1 3
25-32::
    All dance the Knot to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5336, '2013-08-21 08:31:04.914427+00', '2023-02-04 01:20:02.765497+00', 2289, 3, NULL, 'ace', '1-8::
    1s turn 1/2 RH dancing down middle & set, 1s dance 1/2 Figs of 8
    round 2s/3s (1M round 2s).  2 1 3
9-16::
    All 1/2 turn (2s+3s RH, 1s LH) & retaining hands set, 1s dance RH
    across (1M with 2s & 1L with 3s).  (2)(1)(3)
17-24::
    2s+1s+3s chase clockwise into lines across & set, all chase on to
    places.  (2)(1)(3)
25-32::
    1s dance 1/2 diag R&L (M up) _while_ 2M+3L set & change places RH,
    1s dance 1/2 RSh reels of 3 on sides (1M down & 2M up).  2 1 3
33-40::
    1s dance LSh reels of 3 across (1L with 2s, 1M with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (13150, '2020-09-15 00:19:41.982065+00', '2023-02-04 01:20:02.788564+00', 12228, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance R&L
9-16::
    2s & 4s slip step down middle & back up to place
17-24::
    1s & 3s dance Fig of 8 round couple below them crossing down to
    start
25-32::
    1s+2s dance 1/2 RH across, 1s+3s dance 1/2 LH across, 1s+4s dance
    1/2 RH across. All cross over RH 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5338, '2013-08-21 08:31:04.932737+00', '2023-02-04 01:20:02.829436+00', 2295, 3, NULL, 'ace', '1-8::
    1s set to 2s on the sides both couples moving in, 1s dance under 2s
    arch to set to 3s, 1s dance under 3s arch
9-16::
    1s set to 4s & dance under 4s arch to 4th places facing out, 1s cast
    up to 1st places
17-24::
    2s dance Figs of 8 round 1s _while_ 4s dance Figs of 8 round 3s
25-32::
    1s & 3s dance DoSiDo with partners, 1s cast to 4th places', 0);
INSERT INTO 'dancecrib' VALUES (5339, '2013-08-21 08:31:04.941162+00', '2023-02-04 01:20:02.851881+00', 9105, 3, NULL, 'ace', '1-8::
    1s+2s form arches on the side & set, 1s+2s+3s form arches & set,
    1s+2s+3s+4s form arches & set twice
9-16::
    1s+2s dance RH across 1/2 way, 1s+3s dance LH across 1/2 way, 1s+4s
    dance RH across 1/2 way & all cross to own sides LH
17-24::
    2s+3s+4s+1s set, 1s adv to ptnr & set facing up with 2s+3s+4s
    setting & forming arches, 1s lead up to top (under arches) all end
    on sides
25-32::
    1s cast behind 2s, dance down in front of 3s, cast down behind 4s &
    turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5340, '2013-08-21 08:31:04.949553+00', '2023-02-04 01:20:02.87375+00', 2297, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & turn LH 1.1/2 times
9-16::
    1s dance RH across on own sides (Man with 2M+3M & Lady with 2LM+3L),
    1s 1/2 turn LH to dance RH across on other side & 1s 1/4 turn LSh
    to…
17-24::
    1s dance RH across (Man with 2s & Lady with 3s), 1/2 turn LH to
    dance RH across with other couple & 1s end 2nd place own sides
25-32::
    1L+2L also 1M+3L change places RH, all cross RH, 1L+2M also 1M+3L
    change places LH & all cross LH', 0);
INSERT INTO 'dancecrib' VALUES (15309, '2022-12-19 01:18:16.396538+00', '2023-02-04 01:18:18.169769+00', 21173, 3, NULL, 'ace', '1-8::
    1s+2s set, 1/2 turn partner RH into prom hold; 1s+2s dance down,
    cross LH below 3s and cast up on own sides. 2 1 3
9-16::
    1s+3s set, 1/2 turn partner LH into prom hold; 1s+3s dance up, cross
    RH above 2s and cast down on own sides. 2 3 1
17-18::
    1s dance up _while_ 3s step down
19-24::
    2s+1s+3s dance 6 bar reels own sides 1L+3L & 1M+2M pass RSh, 1s face
    out at end of reel.
25-32::
    Promenade (Chaperoned) Chain progression:
::
    _25-26_   2s & 3s 3/4 turn partner RH into middle _while_ 1s dance
    clockwise 1/4 round the set picking up 2L/3M...
::
    _27-30_   who promenade 1/2 way clockwise _while_ middle people (2M
    + 3L) turn LH 1.1/2.
::
    _31-32_   2s & 3s turn partner RH 3/4 to own sides _while_ 1s dance
    clockwise 1/4 round to end in 2nd place. 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (9717, '2017-04-06 08:39:24.597083+00', '2023-02-04 01:18:18.260015+00', 16183, 3, NULL, 'ace', '1-8::
    All set, 1s+4s set again & 1s dance in towards partner & cast, 1s to
    4th place as 4s lead up curving into 1st place facing out
9-16::
    4s+2s & 3s+1s dance double Fig 8 (4s & 3s cast to start)
17-24::
    4s+2s & 3s+1s dance RH across, dance LH across
25-28::
    4s+2s & 3s+1s »set & mirror link« (end dancers [4s & 1s] cast
    down/up as middles [2s & 3s] dance up/down)
29-32::
    4s+1s circle 4H round to left
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8838, '2015-08-13 20:33:37.782434+00', '2021-06-05 11:45:37.447833+00', 2402, 3, NULL, 'ace', '1-8::

    1s cross RH, cast 1 place, cross LH & cast down 1 place

9-16::

    3s+1s circle 4H round to left, 1s cast up 1place & 1/2 turn RH to

    face 1st corners

17-24::

    1s dance 1/2 diagonal reel of 4 with 1st corners, pass LSh & dance

    1/2 diagonal reel of 4 with 2nd corner

25-32::

    Repeat with 3rd & 4th corners (Mairi''s Wedding type) & 1s end in 2nd

    place on own side

33-40::

    2s+1s+3s dance RH across, turn to right & chase back to place', 0);
INSERT INTO 'dancecrib' VALUES (5341, '2013-08-21 08:31:04.957931+00', '2023-02-04 01:20:02.893082+00', 2298, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 on own sides with 2s+3s (1s in/down
    to start)
9-16::
    1s followed by 2s lead down to bottom & cast up own sides to 2nd
    place, lead up to top & 1s cast to 2nd place as 2s follow but end in
    1st place
17-24::
    1s cross down to dance reflection reels of 3 on opposite sides with
    3s+4s (1s cross down, 3s out/up, 4s in/up to start)
25-32::
    1s turn 3s 1.1/2 times (LH on Ladies'' side & RH on Men''s), turn 4s
    1/2 way (other hand) to 4th place & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (9474, '2016-11-09 08:48:28.586432+00', '2023-02-04 01:20:03.073828+00', 17425, 3, NULL, 'ace', '1-8::
    1s & 3s cross down as 2s & 4s dance up 1 place & 1s & 3s turn 2s/4s
    on sides, 1s & 3s dance down & turn 4s/5s on sides with nearer
    hands. 2 (1) 4 (3) 5
9-16::
    1s & 3s dance 1/2 Figs of 8 round 2s/4s above, 1s & 3s dance 1/2
    Figs of 8 round 4s/5s below & end giving LH to partner & RH to 2nd
    corner
17-24::
    Balance-in-Line with 2nd corners. 1s & 3s turn LH to give RH to 1st
    corners, Balance-in-Line with 1st corners & turn partner LH to…
25-32::
    1s & 3s dance RH across (1L with 2s, 1M+3L with 4s, 3M with 5s), 1s
    & 3s turn LH cast 1 place. 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (10334, '2017-12-22 15:44:21.355433+00', '2023-02-04 01:20:03.10697+00', 17121, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up) & turn 1.1/4 LH to face 1st corners
9-16::
    1s dance Chain Progression for 3 couples on the diagonal:
::
    _9-10_    1s change places RH with 1st corners _while_ 2nd corners
    chase 1 place clockwise
::
    _11-14_  1st corners turn 1.1/2 LH in centre _while_ 1s & 2nd
    corners promenade 1/2 round (corners on outside)
::
    _15-16_  2nd corners chase 1 place back to place _while_ 1s change
    places RH with 1st corners.  1s end facing 4th corners
17-24::
    1s dance "Hello-Goodbye" setting ending facing 2nd corners
25-32::
    1s repeat Chain Progression for 3 couples with 2nd corners & end
    facing 1st corner positions
33-40::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh & dance 1/2
    diag reel of 4 with 2nd corners ending in 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (10335, '2017-12-22 15:44:21.364618+00', '2023-02-04 01:20:03.134055+00', 17126, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 double Figs 8 (2s cross up, 1s dance down).  1s+2s
    turn 1.1/2 Ladies'' side LH Men''s side RH
9-16::
    1s+3s dance 1/2 double Figs 8 (1s cross down, 3s dance up).  1s+3s
    turn 1.1/2, Ladies'' side LH, Men''s side RH
17-24::
    3s followed by 2s cross down below 1s (in 3rd place), dance up to
    top.  3s cast to 2nd place facing down _while_ 2s dance to top
    facing out
25-32::
    2s+3s+1s dance reflection reels of 3 on sides (2s out/down, 3s
    in/down, 1s out/up)
33-40::
    All circle 6H round and back  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13893, '2021-04-05 00:19:44.891535+00', '2023-02-04 01:20:03.155087+00', 20254, 3, NULL, 'ace', '1-4::
    1M+2L 1/2 turn RH, twirl & dance out to opposite places _while_
    1L+2M chase clockwise 1/2 way
5-8::
    2M+1L repeat bars 1-4
9-16::
    1s+2s dance RH across & LH back to remain in the middle
17-24::
    1s, followed by 2s (who dance up), lead down, 2s followed by 1s lead
    up & stay in the middle facing up. On bar 24 3s+4s step in ready
    for…
25-32::
    All dance 4 couple Allemande 4 3 1 2
33-40::
    All 1/2 turn & twirl partners, all circle left 1/2 way 2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (3900, '2013-08-21 08:30:38.764636+00', '2023-02-04 01:20:03.174752+00', 13583, 3, NULL, 'ace', '1-8::
    1s dance down to 4th place as 4s cast up to 1st place; 1s cast up to
    3rd place as 4s dance down to 2nd place, 1s+4s set.  2 4 1 3
9-16::
    1M followed by 4M dance Alternating Tandem reel of 3 on sides (RSh
    to 3M) as 4L followed by 1L dance Alternating Tandem reel of 3 (RSh
    to 2L)
17-20::
    1s+4s 1/2 turn RH then dance RH across 1/2 way
21-24::
    2s+1s also 4s+3s repeat 17-20
25-28::
    1s+2M  dance RH across (2M ends in 1st place own side, 2L steps up
    27-28)
29-32::
    1s+3L dance LH across (3L ends in 2nd place own side, 3M steps up
    31-32)
33-36::
    1s+4M dance RH across (4M ends in 3rd place own side, 3L steps up
    35-36), 1s finish in middle, 1M facing down 1L facing up.
37-40::
    1s set & turn RH 3/4 into 4th place own sides (facing out ready to
    repeat).  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (3899, '2013-08-21 08:30:38.760282+00', '2023-02-04 01:18:18.291306+00', 8352, 3, NULL, 'ace', '1-8::
    1L dances down below 2M & casts up on opp side into middle as 1M
    dances across & casts down into middle, 1s turn LH once round into
    line across with 2s (retain LH & join RH with 2s)
9-16::
    1s+2s Bal-in-Line (HS) & dance 1/2 reel of 4 across
17-24::
    1M+2L also 1L+2M turn RH once round, 1s pass RSh. 1M+2M turn LH
    1.3/4 times _while_ 1L+2L turn LH 1.1/4 times 1s & 2s now in
    partners original place
25-32::
    1s+2s set, circle 4H 1/2 round to left, 2s+1s turn partners 2H', 0);
INSERT INTO 'dancecrib' VALUES (4039, '2013-08-21 08:30:42.393996+00', '2023-02-04 01:18:29.30874+00', 192, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s cross RSh & dance down opposite sides, 1s dance
    in & up to dance R/LH across on sides
9-16::
    1s dance 1/2 Fig of 8 round couple above them, 1s dance in & up to
    dance R/LH across on sides, 1s end in prom hold facing 3M
17-24::
    1s dance 1/2 diagonal reels of 3 with 2nd corners & 1/2 diagonal
    reel with 1st corners
25-32::
    1s set to 3s, turn inward & set to 2s, lead up, cross over & cast to
    2nd places own sides', 0);
INSERT INTO 'dancecrib' VALUES (5343, '2013-08-21 08:31:05.004703+00', '2023-02-04 01:20:03.19453+00', 2301, 3, NULL, 'ace', '1-8::
    1s & 4s cast in 1 place, pass partner LSh to BtoB position facing
    2s/3s, set & change places RH with 2s/3s
9-16::
    2s+3s dance LH across & end BtoB facing 1s/4s, all set & 1/2 turn
    1s/4s who end BtoB between 2s/3s
17-24::
    All dance reels of 4 across ending with 1s & 4s in centre facing
    down
25-32::
    4s cross down & cast up to 2nd pl as 1s lead down & cross into 4th
    pl, 1s+3s set on sides & change pl (RH on M side, LH on L) to end 2
    4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11697, '2019-03-18 21:02:09.840714+00', '2023-02-04 01:20:03.212955+00', 17477, 3, NULL, 'ace', '1-8::
    1s turn RH moving down to 2nd places, 1L facing down, 1M facing up
    (2s step up 3-4). 2s+1s+3s chase clockwise 1/2 way
9-12::
    3s+1s+2s set & 1s set adv & turn right about to face out to opposite
    sides _while_ 3M & 2L petronella right into middle (3M in centre at
    top, 2L in centre at bottom) _while_ 3L & 2M cast into 2nd places to
    2M facing 1M & 1L facing 3L in a line across
13-24::
    Dance to Points & Set (similar to Dance to Corners & Set):
::
    _13-14_     2M+1M & 1L+3L pass RSh to change places, 2M+3L pass RSh
    with a 1/4 turn to right in centre to 3M facing 2M & 3L facing 2L
    _while_ 3M+2L set
::
    _15-16_     3M+2M & 3L+2L pass RSh to change places, 3M+2L pass RSh
    with a 1/4 turn to right in centre to 3M facing 1L & 2L facing 1M
    _while_ 1s set
::
    _17-18_     1L+3M & 2L+1M pass RSh to change places, 1s pass RSh
    with a 1/4 turn to right in centre to 1M facing 2M & 1L facing 3L
    _while_ 3L+2M set
::
    _19-20_      2M+1M & 1L+3L pass RSh to change places, 2M+3L pass RSh
    with a 1/4 turn to right in centre to 2M facing 3M & 3L facing 2L
    _while_ 2L+3M set
::
    _21-22_      2M+3M & 3L+2L pass RSh to change places, 2L+3M pass RSh
    with a 1/4 turn to right to centre to 2L facing 1M & 3M facing 1L
    _while_ 1s set
::
    _23-24_      1M+2L & 1L+3M pass RSh to change places, 1s pass RSh
    with 1/4 turn to right in centre to 1M facing 2M & 1L facing 3L
    _while_ 2M+3L set
25-28::
    1s+2M+3L dance 1/2 reel of 4 across the set, 1s pass LSh to face up
    & down the middle of the set
29-32::
    1s+2L+3M dance 1/2 reel of 4 to finish 1s give RH & 3M+2L face
    clockwise
33-40::
    1s turn to dance out 1L between 3L+2L 1M between 2M+3M _while_ 3s+2s
    dance clockwise (6 steps).  All set. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5344, '2013-08-21 08:31:05.01571+00', '2023-02-04 01:20:03.32629+00', 2302, 3, NULL, 'ace', '{{explanation}}
Running step, 2 steps per bar

1-8::
    1s lead down the middle & back
9-24::
    1s turn RH, 1M turns 2L LH as 1L turns 2M LH, turn partner, turn 3s,
    turn partner, turn 4s (as Strip the Willow) & cast up own side to
    top
25-32::
    2s+3s+4s kneel & clap as 1s with nearer hands joined dance down
    Ladies'' side & up Men''s side making arch over the kneeling dancers
33-48::
    All join 2H with partner & 1s dance in & out to bottom as 2s+3s+4s
    in unison shuttle first to Ladies'' side & back to Men''s side moving
    up as 1s pass', 0);
INSERT INTO 'dancecrib' VALUES (5345, '2013-08-21 08:31:05.024327+00', '2023-02-04 01:20:03.340206+00', 8173, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cross RH as 2s cast up; 1s turn opp dancer LH  (1M+ 2L
    & 1L+2M) into line across & Bal-in-Line. Men turn to face down on
    last step
9-16::
    1s+2s dance down the middle in line of 4, 2s turn inwards, & dance
    back to 1st place own sides followed by 1s who end in 2nd place opp
    sides
17-20::
    2M+1M change places RH, 2L+1L change places RH
21-24::
    All set to partner & 1/2 turn partner RH to end 1s facing down & 2s
    up, NHJ with partner.  (1) 2
25-32::
    1s+2 set, 1s+2s change places, 1s dancing under arch made by 2s, 1s
    dance down for another step, Lady turns under partner''s arm to
    change sides & 1s dance up to 2nd place own side. 2 1', 0);
INSERT INTO 'dancecrib' VALUES (5346, '2013-08-21 08:31:05.032879+00', '2023-02-04 01:20:03.356866+00', 11205, 3, NULL, 'ace', '1-8::
    1s & 3s turn RH, cast 1 place (2s & 4s step up 3-4). 1s & 3s turn
    1.1/4 LH to face 1st corners
9-16::
    1s turn corners RH, partner LH, 2nd corner RH & partner LH to end
    facing 3rd corners
17-24::
    1s & 3s dance RSh reels across (reels of 3 with top or bottom couple
    & reel of 4 with middle couple)
25-32::
    1s & 3s dance RSh round 3rd corners, meet & turn partners 3/4 RH &
    cast 1 place own sides (4s & 5s step up 31-32)', 0);
INSERT INTO 'dancecrib' VALUES (5347, '2013-08-21 08:31:05.041302+00', '2023-02-04 01:20:03.368476+00', 2305, 3, NULL, 'ace', '1-4::
    1s cast 1 place _while_ 2s step up, 1s dance up _while_ 2s cast 1
    place
5-8::
    1s cast 1 place & dance up _while_ 2s dance up & cast 1 place
    _while_ 3s cast 1 place & dance up _while_ 4s step up & cast 1 place
9-16::
    1s+2s also 3s+4s dance double Fig of 8  (1s & 3s cast to start)
17-24::
    1s & 3s set, turn LH, cross down & cast back to places _while_ 2s &
    4s continue with 1/2 Figs of 8, set & cross RH.  1 2 3 4
25-28::
    1s turn RH _while_ 3s 1/2 turn RH & lead up to top
29-32::
    1s cast to 4th place _while_ 3s 1/2 turn RH & lead up to top _while_
    2s & 4s 1/2 turn RH & cross up.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5348, '2013-08-21 08:31:05.170201+00', '2023-02-04 01:20:03.580505+00', 2312, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    2s+1s+3s dance RSh reels of 3 on sides & 1s end facing 1st corner
17-24::
    1s dance 1/2 diagonal reel with 1st corners, 1/2 diagonal reel with
    2nd corners & 1s end in 2nd place opposite side
25-32::
    3s+1s+2s Set+Link for 3 twice', 0);
INSERT INTO 'dancecrib' VALUES (12551, '2020-02-02 02:47:52.974875+00', '2023-02-04 01:20:03.600742+00', 13908, 3, NULL, 'ace', '1-8::
    1M+3L dance Fig 8 round 2s _while_ 1L+3M dance Fig 8 round 4s
9-16::
    1s+3s in prom hold with partner dance 3/4 RSh round each other, 1s
    dance LSh round 4s, 3s LSh round 2s to opp sides.  3 2 1 4
17-24::
    2s+4s repeat 1-8 dancing Fig 8 round 3s/1s
25-32::
    2s+4s repeat 9-16 to end all opposite starting positions. 3 4 1 2
33-40::
    All circle 8H round & back & face partner
41-48::
    Interlocking reels of 4 (pass partner LSh to start), all turn
    partner 3/4 LH so Ladies in centre facing clockwise
49-56::
    Ladies dance 1/2 RH across _while_ Men dance anticlockwise 1/4
    round, Ladies turn nearest Man 1/2 LH; Men in centre face clockwise
    & dance 1/2 RH across _while_ Ladies dance anticlockwise 1/4 round &
    all turn partner 1/2 LH (Ladies back in centre)
57-64::
    Repeat 49-56, finish with Ladies BtoB in centre facing partner (all
    Men in original places)
65-72::
    All petronella turn, 1/2 turn partner 2H; all petronella turn, 1/2
    turn partner 2H to finish in prom hold facing anticlockwise
73-80::
    All promenade round', 0);
INSERT INTO 'dancecrib' VALUES (15135, '2022-10-05 00:19:52.354065+00', '2023-02-04 01:20:03.63274+00', 20793, 3, NULL, 'ace', '1-8::
    All face partner & dance 1/2 Grand Chain (2 bars per hand) & face
    partner again.  3 4 1 2
9-16::
    All dance interlocking reels of 4 (pass partner RSh to start). Bars
    15-16: all 1/2 turn partner RH to Men facing in, Ladies facing out
17-24::
    All dance Double Men''s Chain (Men LHA in centre).  Finish NHJ with
    partner.  3 4 1 2
25-32::
    All set & Petronella in Tandem 1 place anticlockwise, set & turn
    partner 2H & remain facing partner.  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (12172, '2019-09-04 22:02:03.926077+00', '2023-02-04 01:20:03.930741+00', 19576, 3, NULL, 'ace', '{{explanation}}
Round the room 2 facing 2

1-8::
    All dance RH across & LH across to places
9-16::
    Ladies'' Chain
17-24::
    All dance back to back (DoSiDo) with person facing and DoSiDo with
    partner
25-32::
    All Adv+Ret. All advance to meet next couple (anticlockwise facing
    couple make arch, other couple pass under)', 0);
INSERT INTO 'dancecrib' VALUES (11189, '2018-09-30 22:19:45.899328+00', '2023-02-04 01:20:03.959374+00', 18619, 3, NULL, 'ace', '1-8::
    _4_ dance up to top (NHJ) 1s+2s+3s join hands & step down bars 3-4,
    4s set & cast to 2nd place (1s step up 7-8)
9-16::
    4s dance RH across (4M with 2s, 4L with 1s), 4s pass RSh & dance LH
    across with other couple & pass LSh to face 1st corners
17-24::
    4s turn 1st corners LH pass partner RSh to face 3rd corners, turn
    3rd corners RH & turn right about to face 2nd corners
25-32::
    4s turn 2nd corners LH pass partner RSh to face 4th corners, turn
    4th corners RH & finish in middle (for Poussette) as 1s step in
33-40::
    4s+1s dance Allepousse: 1s dance normal Allemande as 4s Poussette to
    change places   4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (5351, '2013-08-21 08:31:05.225014+00', '2023-02-04 01:20:04.037871+00', 2317, 3, NULL, 'ace', '{{explanation}}
2 Couples (facing).  Highland setting throughout

{{title}}
Strathspey

1-8::
    All dance reel of 4 across Ladies passing LSh in centre to start &
    end with Men BtoB in the middle facing opposite partners
9-16::
    All set
17-24::
    All dance reel of 4 giving RSh to opposite partner & end with Men in
    middle facing own partners
25-32::
    All set

{{title}}
Reel

1-32::
    Repeat 1-32 above in reel time

{{explanation}}
Dance an even number of times as Strathspey, then same number of times as Reel.  
Often danced as Strathspey and Reel of Tulloch', 0);
INSERT INTO 'dancecrib' VALUES (14830, '2022-05-17 19:55:03.29246+00', '2023-02-04 01:20:04.042323+00', 14713, 3, NULL, 'ace', '{{explanation}}
2 Couples, Men back to back in centre facing partner.  Highland setting throughout

{{title}}
Strathspey

1-8::
    All dance reel of 4 across Ladies pass partner RSh & each other LSh
    in centre to start. End with Men BtoB in the middle facing opposite
    partners
9-16::
    All set
17-24::
    All dance reel of 4 giving RSh to opposite partner & end with Men in
    middle facing own partners
25-32::
    All set
33-48::
    Repeat bars 1-16

{{title}}
Reel

{{explanation}}
(Reel of Tulloch)

1-8::
    All dance round to left (many variations) & end with Men BtoB in
    centre facing own partners
9-16::
    All set
17-24::
    All Tulloch turn own partners & end with Ladies facing each other in
    centre (with backs to own partner)
25-32::
    Ladies set
33-40::
    Ladies Tulloch turn & end in centre facing opposite partners
41-48::
    All set
49-56::
    All Tulloch turn opposite partners & end with Men in centre facing
    each other
57-64::
    Men set
65-72::
    Men Tulloch turn & end facing own partners
73-80::
    All set to own partners
81-88::
    All Tulloch turn own partners & end beside partners on opposite
    sides', 0);
INSERT INTO 'dancecrib' VALUES (5353, '2013-08-21 08:31:05.241064+00', '2023-02-04 01:20:04.061459+00', 2321, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH to face 1st corners
9-20::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s meet again in
    middle & pass RSh to face 3rd corner positions
21-24::
    1s turn 3rd corners 2H to face diagonally in (corners on 1s right) &
    set _while_ 2nd corners set & cross RH
25-32::
    1s+3rd corners Adv+Ret & dance 3/4 RH across to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11655, '2019-03-10 01:29:26.541973+00', '2023-02-04 01:20:04.093262+00', 19238, 3, NULL, 'ace', '1-6::
    All set, 2s & 3s cross RH & cast, 2s above 1s, 3s below 4s
7-8::
    2s & 3s dance in, meet partner & NHJ dance down/up to 2nd / 3rd
    place, remaining in centre, 2s facing 3s.  1 (2) (3) 4
9-12::
    2s+3s dance 1/2 LH across _while_ 1s & 4s set facing in diagonally,
    1s+3s also 2s+4s change places RH. 3 1 4 2
13-16::
    1s+4s dance 1/2 LH across _while_ 2s & 3s set facing in diagonally,
    3s+4s also 1s+2s change places RH. (4) 3 2 (1)
17-24::
    RSh reels of 4 on sides
25-32::
    3s+2s (middle couples) dance 1/2 R&L (no polite turn);  4s+2s (top
    couples) also 3s+1s (bottom couples) dance 1/2 R&L.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12155, '2019-09-03 14:51:43.842948+00', '2023-02-04 01:20:04.105831+00', 19594, 3, NULL, 'ace', '1-4::
    1L+2L dance diagonally across the set pass partner RSh 1L dances 1/2
    Fig of 8 round 2M+3M _while_ 2L dances 1/2 Fig of 8 round 3M+4M
5-8::
    3L+4L step up twice _while_ 1L+2L dance round 3M+4M then cross set
    to 3rd and 4th places on own side
9-16::
    1M+2M repeat bars 1-8 passing 4L+1L RSh (3M+4M step up twice)
17-24::
    3s+4s+1s+2s Adv+Ret, turn partner RH
25-32::
    1s dance 1/2 Fig of 8 down round 2s, cross RH & cast to bottom (2s
    step up bars 31-32). End  3 4 2 1', 0);
INSERT INTO 'dancecrib' VALUES (14488, '2021-12-18 01:44:05.581305+00', '2023-02-04 01:20:04.11565+00', 20556, 3, NULL, 'ace', '1-4::
    1L dances down centre, casts up round 3L _while_ 1M dances behind
    Men''s line, casts up round 3M, 1s end between 2s & 3s, 1M facing out
5-8::
    1M followed by 1L casts up round 2M & crosses to 1st place opp side,
    1M facing out.  (1) 2 3
9-16::
    1s+2s dance reel of 4 across (1L+2L pass LSh, 1M dances down, 2M
    dances up to start)
17-24::
    1s+3s set, 1s cast to 3rd place _while_ 3s cross up to 2nd place, no
    hands (2s step up 19-20); 3s+1s set & dance 1/2 RH across. 2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5356, '2013-08-21 08:31:05.266391+00', '2023-02-04 01:20:04.126466+00', 7738, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s cross RH & cast 1 place, 1s+4s dance RH across & end 1M+4L
    also 4M+1L in prom hold facing out to pass RH corner person RSh
9-16::
    All dance 1/2 reels of 3 on sides, 1s+4s dance LH across & end 1s
    also 4s in prom hold facing out to pass LH corner person LSh
17-24::
    All dance 1/2 reels of 3 on sides, 1s dance up under arch made by 4s
    & cast to 2nd place _while_ 4s dance down & cast up to 3rd place
25-32::
    1s+4s set advancing (form circle) & retire _while_ 2s+3s chase 1/2
    way, all circle left 1/2 way.  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (8837, '2015-08-13 20:33:36.933077+00', '2023-02-04 01:20:04.137386+00', 14285, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up), turn LH 1.1/2 to end 1M between 3s,
    1L between 2s, facing 1st corners
9-16::
    1s dance LSh reels of 3 across (4M follows 3M dancing in tandem).
    1s end in 2nd place own side facing up
17-24::
    1s dance up (NHJ), cast, meet, dance down between 3s & cast up to
    2nd place _while_ 2s+3s dance R&L (start change places RH on side)
25-32::
    2s+1s+3s+4M circle 7H round & back

{{explanation}}
Note:   4M or original 2M join in the dance wherever possible!', 0);
INSERT INTO 'dancecrib' VALUES (11337, '2018-11-10 20:03:39.901926+00', '2023-02-04 01:20:04.147689+00', 19049, 3, NULL, 'ace', '1-8::
    1s+3s dance double Fig 8 (1s cross down, 3s cast up to start)
9-16::
    1s+2s+3s set, cross RH, set, cross back RH
17-24::
    1s+2s+3s dance Set & Rotate for 3 couples. 3 2 1
25-32::
    2s+1s dance the Tourbillon:
::
    _25-28_   2s & 1s 1/2 turn ptnrs 2H, 1M & 2L lead ptnrs by nearer
    hand 1 place cl''wise to end 2s on Ladies side & 1s Men''s side, 1s
    set to 2s
::
    _29-32_   2s & 1s 1/2 turn ptnrs 2H & lead ptnrs on 1 place
    clockwise & 1s+2s cross RH to own sides.  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5357, '2013-08-21 08:31:05.274781+00', '2023-02-04 01:20:04.159143+00', 2329, 3, NULL, 'ace', '1-8::
    1L followed by partner casts behind 2L, dances up between 2s & casts
    behind 2M & across to 2nd place own side _while_ 4s dance similar
    with 4M casting up round 3M to start (2s & 3s step up/down bars
    7-8).  End 2 1 4 3
9-16::
    1s+4s dance RH across 1/2 way, 1M+4M also 1L+4L turn RH on sides, 1s
    face up, 4s face down; All dance 1/2 RSh reels of 4 on sides. 3L &
    2M face out
17-24::
    3L & 2M followed by partners (end couples) chase clockwise 1/2 way
    to end on opposite sides; bottom 3 couples dance 1/2 reels of 3 on
    sides
25-32::
    2s facing 3s & 4s facing 1s Set+Link (with partners) to own sides,
    2s+3s also 4s+1s dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (5358, '2013-08-21 08:31:05.285018+00', '2023-02-04 01:20:04.173334+00', 2332, 3, NULL, 'ace', '1-8::
    1M+2L turn RH, 2M+1L turn LH 1.1/2 times to end facing partners
9-16::
    1s+2s dance diagonal RSh reel of 4 (1s end in 2nd place)
17-24::
    1s set advancing to end BtoB Lady facing up Man down & dance Crown
    Triangles
25-32::
    1s dance RSh reel of 3 on opposite sides giving RSh to 2nd corners &
    cross back to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (14649, '2022-03-07 02:19:43.626624+00', '2023-02-04 01:20:04.308573+00', 20522, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance RSh reels of 3 on the side. 1L finishes facing out.
9-16::
    1L followed by 1M dance behind 2L+3L to finish in 3rd place opposite
    sides facing up (2s+3s step up bars 11-12), 1s+3s set & change
    places RH on sides (1s finish with polite turn)
17-20::
    1L dances 1/2 Fig of 8 round 2s _while_ 1M dances 1/2 Fig of 8 round
    3s, to finish in middle shoulder to shoulder facing opposite sides
21-24::
    1L+2s & 1M+3s dance RH across, 1s finish facing 1st corners
25-32::
    1s dance Hello-Goodbye setting (6 bars), all clap twice on last 2
    bars 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8058, '2013-10-01 08:46:50.735044+00', '2023-02-04 01:20:04.319136+00', 12466, 3, NULL, 'ace', '1-8::
    1s & 4s set & 1/2 turn RH; 1M followed by partner casts down to 3rd
    place (1M to 3L place, 1L to 2L place) _while_ 4L followed by
    partner casts up to 2nd place (4L to 2M place, 4M to 3M place, 2s &
    3s step up/down bars 7-8)
9-16::
    Interlocking Squares:
::
    Couples in 1st & 3rd places (2s+1M+4M) dance round in a square
    clockwise _while_
::
    Couples in 2nd & 4th places (3s+1L+4L) dance round in a square
    clockwise
::
    End - Ladies''s side: 2L 1L 1M 3L,  Men''s side: 2M 4L 4M 3M
17-20::
    1s & 4s (middle couples) dance 1/2 RH across & 1/2 turn RH
21-24::
    1s & 4s dance 1/2 LH across & 1/2 turn LH to face corner person
25-32::
    All set, then 1s & 4s pass corner person RSh & dance clockwise round
    to end in 3rd/2nd place.  Finish  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5361, '2013-08-21 08:31:05.446753+00', '2023-02-04 01:20:04.354083+00', 6966, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s dance 1/2 Fig of 8 round 2s
9-16::
    1s (prom hold) dance 1/2 diag reel of 3 with 3M+2L (RSh to 3M to
    start) & 1/2 reel of 3 with 3L+2M (RSh to 3L)
17-24::
    1M LH across with 3L+2L (Mens side) _while_ 1L dances RH across with
    3M+2M, 1s cross up between 3s & cast to 2nd place opposite sides
25-28::
    All Ladies slip step right & cross at bottom & dance up own sides
    _while_ Men slip step left & cross (below Ladies) at bottom & up own
    side
29-32::
    1s+3s set to each other on sides & change places (Men RH & Ladies
    LH).  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5362, '2013-08-21 08:31:05.455298+00', '2023-02-04 01:20:04.374834+00', 7401, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, cross LH & cast Lady up Man down
9-16::
    1s dance reels of 3 across Lady with 2s & Man with 3s 1s end facing
    1st corners
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH to end
    2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10996, '2018-08-17 07:52:14.565274+00', '2023-02-04 01:20:04.387588+00', 18385, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s lead down (4 bars), lead up (2 bars), separate, dance out between
    2s+3s own sides & up behind 2s to original places
17-24::
    1s+2s+3s dance Mirror reels of 3 on sides (1s in/down, 2s out/up)
25-32::
    1s set & cast (2s step up 27-28); 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (9475, '2016-11-09 08:48:28.958522+00', '2023-02-04 01:20:04.532973+00', 12584, 3, NULL, 'ace', '1-8::
    1s lead down (3 steps), lead back up & cast to 2nd place (2s step up
    3-4)
9-16::
    1s+3s dance RH across & LH across back to place
17-24::
    1s dance Fig 8 up round 2s
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5363, '2013-08-21 08:31:05.46384+00', '2023-02-04 01:20:04.547093+00', 8670, 3, NULL, 'ace', '{{explanation}}
Man+2 Ladies per side

{{title}}
Strathspey

1-8::
    All circle 12H round & back
9-16::
    Men dance reel of 3 with partners, giving RSh to Lady on the right
17-24::
    1s & 3s Adv+Ret, 1M & 3M dance DoSiDo
25-32::
    2s & 4s repeat 17-24

{{title}}
Reel

1-4::
    1s+3s dance a modified Ladies'' Chain - Ladies on the Men''s right
    cross RH as Men dance into that Ladies place & then Men change
    places LH with Lady on side
5-8::
    Repeat with Ladies on left crossing LH as the Men dance into their
    places & then Men 3/4 turn opposite Lady RH (1s & 3s have changed
    partners)
9-16::
    2s+4s repeat bars 1-8
17-24::
    Men set  & dance RH across 1.1/2 times
25-32::
    Men dance LH across with own partners & all circle 12H round 1/2 way
    to right to original places
::
    (Variation - Bars 17-32 - Men set advancing & dance RH across 1/2
    way, Men dance LH across with own ptnrs.  All set, circle 12H round
    to the left & set)', 0);
INSERT INTO 'dancecrib' VALUES (5306, '2013-08-21 08:31:04.556649+00', '2023-02-04 01:20:01.27014+00', 2244, 3, NULL, 'ace', '1-8::
    2s passing LSh dance 1/2 RSh reel of 4 with 1st corners, pass RSh to
    dance RH across (Man with top couple, Lady with bottom couple)
9-16::
    2s passing LSh dance 1/2 RSh reel of 4 with 2nd corners, pass RSh &
    dance RH across 1s+3s on own sides 2s ending in orig places
17-28::
    3s+2s+1s dance 3 Couple R&L
29-32::
    2s turn RH & cast to bottom _while_ 3s set & cross RH & 1s set &
    cross up RH', 0);
INSERT INTO 'dancecrib' VALUES (5364, '2013-08-21 08:31:05.472196+00', '2023-02-04 01:20:04.560437+00', 2344, 3, NULL, 'ace', '1-8::
    1s set & cross down RH dancing out between 2s+3s, cast round 1st
    corner & 3/4 turn RH in middle to face out again on opposite sides
9-16::
    1s dance out casting round 1st crnr place to dance Figs of 8 across,
    end facing 1st corners, _while_ 2s+3s dance full R&L
17-24::
    1s dance 1/2 diag reel of 4 with 1st corners & 1/2 diagonal reel
    with 2nd crnrs ending ready for RH across (Man with 3s at top & Lady
    with 2s)
25-32::
    1M+3s & 1L+2s dance RH across (1s ending in 2nd place opposite
    sides) & 3s+1s+2s chase clockwise 1/2 way back to places', 0);
INSERT INTO 'dancecrib' VALUES (13617, '2021-02-04 01:19:45.759231+00', '2023-02-04 01:20:04.57167+00', 16470, 3, NULL, 'ace', '1-8::
    1L+2M cross RH & turn partner 3/4 RH into line of 4 across; 1s+2s
    dance 1/2 reel of 4 across. End Men''s side: 2L 2M 3M, Ladies'' side:
    1L 1M 3L
9-16::
    Reels of 3 on sides, 1M & 2M (middle ''couple'') LSh to 3s to start.
    1L & 2M face out
17-24::
    1s+2s dance RH across 1.1/4 round to end on own sides 2 1 3.
    2s+1s+3s turn partner RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9916, '2017-06-05 11:31:06.333536+00', '2023-02-04 01:20:04.582571+00', 16068, 3, NULL, 'ace', '1-8::
    1s, followed by 2s, dance down below 3s, cast up, meet & dance up.
    1s cast to 2nd place own sides, 2s end in 1st place facing out
9-16::
    1s cross down RH through 3rd place to dance mirror reels of 3 on opp
    sides (3s out/up, 2s out/down).  All give hands in reels.  2s & 3s
    curve into place at end of reel
17-24::
    1s dance 1/2 Figs 8 (1L round 2s, 1M round 3s).  2s+1s+3s turn
    partners RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12633, '2020-03-02 01:52:28.472915+00', '2023-02-04 01:20:04.596268+00', 13909, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up); 1s cross RH, cast to right around 1st
    corners into centre 2nd place BtoB facing opp sides
9-16::
    "Saltire Triangles":
::
    _9-10_    2s+1s+3s set (as Double Triangles), on 2nd PdeB release
    hands, 1s turn 1/4 Left 1M facing up, 1L down (as Crown Triangles)
::
    _11-16_  Repeat 9-10 3 more times (set, 1s rotate 1/4 Left) to end
    with 1s facing 4th corners
17-32::
    "Square Reel of 6":
::
    _17-20_   2s+1s+3s dance 1/2 reels of 3 on sides (1s RSh to 4th
    corner to start) 1s end in centre facing 1st corners
::
    _21-24_   1L+3s (at top) & 1M+2s at bottom dance 1/2 reels of 3
    across (1s LSh to 1st corners to start) 1s end facing 2nd corners
::
    _25-32_   1/2 reels of 3 on sides (1s RSh to 2nd corners) 1s face
    3rd corners (pstn); 1/2 reels of 3 across (1s LSh to 3rd corner
    pstn). 1s end 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5365, '2013-08-21 08:31:05.663342+00', '2023-02-04 01:20:04.845419+00', 2348, 3, NULL, 'ace', '1-8::
    All set twice to partner & dance RSh round partner to face corners
9-16::
    All set twice to corners & dance LSh round corner back to places
17-24::
    1s+3s advance (2 steps) & set, 2s+4s advance (2 steps) & set
25-32::
    All circle 8H round to left, gradually increasing size of circle
    until all in original places

{{explanation}}
Repeat with 2s+4s advancing at bar 17', 0);
INSERT INTO 'dancecrib' VALUES (5366, '2013-08-21 08:31:05.673734+00', '2023-02-04 01:20:04.882997+00', 13685, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s turn RH
9-16::
    1s dance reels of 3 across (1L with 2s, 1M with 3s) & 1s end in line
    with 1st corners (LH to corner & RH to partner)
17-24::
    1s dance clockwise Spoke:
::
    _17-18_   Bal-in-Line, Drop LH & dancing couple move clockwise to
    next corner
::
    _19-24_   Repeat with 4th, 3rd & 2nd corners & 1s end 2nd place
    opposite sides
25-32::
    1M crosses down between 3s & casts up 2nd place _while_ 1L crosses
    up between 2s & casts down to 2nd place, 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (15062, '2022-09-05 00:19:47.463783+00', '2023-02-04 01:20:04.901218+00', 21095, 3, NULL, 'ace', '1-8::
    1M+2s+3L dance diag reel of 4 (1M+3L pass LSh, 2s cast to enter reel
    from corners). At end 2s approach each other in centre
9-16::
    1L+2s+3M dance diag reel of 4 (1L+3M pass LSh, 2s cast to enter reel
    from corners). Bar 16: 2s dance in from 2nd place, pull back RSh  to
    face opp sides
17-20::
    2L+1M+3M also 2M+1L+3L circle 3H round to left. Bar 20: 2s pull back
    RSh to face one another
21-24::
    2s set, turn 2H once round & open out to face down
25-28::
    2s LHJ cross down between 3s, cast up & meet in centre facing up
29-32::
    2s NHJ followed by 3s dance up between 1s & cast to 3rd place own
    side.  1 3 2
33-40::
    All dance 3 couple Knot flowing into …
41-48::
    All circle 6H to right (2 steps), retain hands & set, drop hands,
    pull back RSh & cast to sides. End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5368, '2013-08-21 08:31:05.692072+00', '2023-02-04 01:20:05.033367+00', 2350, 3, NULL, 'ace', '1-8::
    1s cast & dance down behind own lines & turning outwards dance back
    to top
9-16::
    1s turn RH, cast & turn LH 1.1/4 times to end 1L between 2s in line
    across facing 1M between 3s
17-24::
    1L+2s & 1M+3s set twice (1s turn left to own sides in 2nd set),
    2s+1s+3s set twice on sides (1s turning to double triangle position
    in 2nd set)
25-32::
    1s dance Double Triangles with 2s+3s & cross to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8579, '2015-02-13 12:47:45.141163+00', '2023-02-04 01:20:05.05219+00', 15582, 3, NULL, 'ace', '1-8::
    1s set & pass LSh to dance round the outside of the set (1M
    anticlockwise & 1L clockwise) to meet behind 3s & dance in between
    them
9-16::
    1M+4s dance LH across _while_ 1L+2s dance RH across, 1s turn LH
    1.1/2 times to end in original places
17-24::
    1s+3s Adv+Ret & dance 1/2 Ladies'' Chain
25-32::
    1s+3s Adv+Ret & dance 1/2 Men''s Chain
33-40::
    1s & 3s chase clockwise (Men leading) 1/2 way round set to original
    places, all couples turn RH

{{explanation}}
2s repeat (dancing with 4s), then 3s repeat (dancing with 1s) & 4s repeat (dancing with 2s)', 0);
INSERT INTO 'dancecrib' VALUES (5369, '2013-08-21 08:31:05.727826+00', '2023-02-04 01:20:05.062968+00', 12401, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s dance 1/2 Figs of 8 (1L round 2s, 1M
    round 3s) _while_ 2s+3s dance 1/2 R&L (RH on sides to start)
9-16::
    1s dance LH across (1M with 2s, 1L with 3s), 1s 1/2 turn RH & twirl
    to own sides
17-24::
    1s cast round 3rd corners into middle BtoB (1M facing up, 1L down) &
    set as Crown Triangles, rotate 1/4 clockwise & set ending facing 1st
    corners
25-32::
    1s dance 1/2 reel of 4 with 1st corners & pass RSh to face 2nd
    corners, 1s dance 1/2 reel of 4 with 2nd corner & pass RSh to2nd
    place own sides
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14904, '2022-06-27 00:19:53.770026+00', '2023-02-25 17:59:34.569072+00', 20882, 3, NULL, 'ace', '{{explanation}}

2 chords - 2nd chord 3s & 4s cross to opposite sides



1-8::

    1s & 4s cross RH, cast (2s/3s step up/down); 1s+4s dance 1/2 R&L. 1L

    & 4L face out

9-16::

    2s+4s also 1s+3s dance Men''s Chain

17-24::

    4s+1s dance LH across; 2s+3s turn RH (4 bars), _while_ 4s+1s 1/2

    turn RH, face each other, pull back RSh & dance out to sides

25-32::

    All circle 8H round & back. 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (4043, '2013-08-21 08:30:42.42978+00', '2023-02-04 01:18:29.52604+00', 13303, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    1s set & dance 1/2 Fig of 8 (1M round 2s, 1L round 3s) then turn LH
    to face 1st corners
17-24::
    1s dance 1/2 reel of 4 with 1st corners & pass RSh to face 2nd
    corners, 1s dance 1/2 reel of 4 with 2nd corners & end 2nd place
    opposite sides
25-32::
    All chase clockwise 1/2 way & turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (5310, '2013-08-21 08:31:04.670526+00', '2023-02-04 01:20:01.559026+00', 2250, 3, NULL, 'ace', '1-8::
    1L followed by partner casts below 3s, 1L crosses & dances up behind
    Men as 1M dances up centre to 1st places on opposite side & 1s set
9-16::
    1M followed by partner repeat above Fig & set in own places
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5370, '2013-08-21 08:31:05.736109+00', '2023-02-04 01:20:05.077906+00', 2352, 3, NULL, 'ace', '1-8::
    All Men set, all Ladies set; Ladies  dance RSh round partner back to
    place
9-16::
    All dance the Knot to end 3 2 1
17-24::
    All Men dance LSh round partner back to place; 1s lead down middle
    followed by 2s+3s, 3s divide & dance to bottom as 2s+1s turn in
    ready for…
25-32::
    2s+1s+3s lead up & 2s stand in top place _while_ 1s+3s dance 1/2
    Diamond Poussette. End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (9362, '2016-10-06 07:18:25.228237+00', '2023-02-04 01:20:05.094364+00', 17230, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up), dance towards each, dance down (NHJ)
    below 3s, cast up into 2nd place own side
9-16::
    2s+1s+3s set, 3/4 turn partners 2H to finish in line in centre
    facing own sides, dance out (1 step) and circle 6H round to left to
    opp. sides (3) (1) (2)
17-24::
    3s+2s turn 3/4 RH into line in middle (M face down, L face up) & set
    _while_ 1s stand (2 bars), Adv+Ret (1 bar each). 3s+2s dance 1/2
    reel of 4 finishing on own sides.  2 (1) 3
25-32::
    2s+1s+3s dance back to back (DoSiDo).  1s dance 1/2 Fig. 8 (1L up
    round 2s, 1M down round 3s) to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (5371, '2013-08-21 08:31:05.744547+00', '2023-02-04 01:20:05.111098+00', 2353, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, 3/4 turn RH, 1L dances up & casts round 2L
    as 1M dances down to 3rd place & casts up round 3M to 2nd place
9-16::
    1s turn 1st corners RH pass partner RSh, turn 2nd corners RH & pass
    partner RSh to 2nd place own sides
17-24::
    1s dance reflection reels of 3 on own sides (1s dancing out & up to
    start), 1s & 2s continue reel with extra loop to end 1 2 3
25-32::
    1s+2s dance Tournee :
::
    1s+2s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 2s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (2s RH, 1s LH) & dance
    out to places', 0);
INSERT INTO 'dancecrib' VALUES (5372, '2013-08-21 08:31:05.752736+00', '2023-02-04 01:20:05.128473+00', 14796, 3, NULL, 'ace', '1-8::
    1s dance »Inveran« reels with 2s+3s (1s cross down bar 1 to reel on
    opp side, cross up bar 5 to reel on own side)
9-16::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of 8 round 2s
17-24::
    1s dance Diag R&L (1s omit polite turn & end 1M facing up & 1L
    facing down on own sides)
25-32::
    1s dance 1/2 RSh reels of 3 on sides, all set then 2s & 3s cross RH.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5373, '2013-08-21 08:31:05.760987+00', '2023-02-04 01:20:05.147532+00', 10893, 3, NULL, 'ace', '1-8::
    1M & 2L change places by crossing & casting RSh round partner, 1s+2s
    dance RH across 1.1/4 times round to end 2 1 on own sides
9-16::
    2s+1s+3s dance RSh reels of 3 on sides (2s+1s pass RSh to start)
17-24::
    1M casts up & crosses down to 2nd place _while_ 1L casts down &
    crosses up to 2nd place opposite sides, 1M casts down & crosses up
    to 2nd place _while_ 1L casts up & crosses down to 2nd place own
    side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5374, '2013-08-21 08:31:05.76938+00', '2023-02-04 01:20:05.164765+00', 2354, 3, NULL, 'ace', '1-8::
    1L+2M also 3L+4M change places RH, cast back to place passing behind
    partner, 1s+2s also 3s+4s circle 4H round to left
9-16::
    1M+2L also 3M+4L repeat but change places LH & circle round to round
    to right
17-24::
    1s lead down the middle for 4 steps, 1s followed by 4s+3s+2s dance
    up to top
25-32::
    1s+4s+3s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5375, '2013-08-21 08:31:05.779663+00', '2023-02-04 01:20:05.18428+00', 2356, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance RSh reels of 3 on own sides
9-16::
    1s dance down the middle & back
17-24::
    1s set, cast 1 place (2s step up); 1s dance RH across (1L+2s &
    1M+3s),  1s end facing 1st corners
25-32::
    1s turn 1st corner RH, partner LH, 2nd corner RH & cross LH to end
    in 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (14489, '2021-12-18 01:44:06.48706+00', '2023-02-04 01:20:05.203261+00', 15532, 3, NULL, 'ace', '1-8::
    1s & 3s set, cast (2s & 4s step up); 1s & 3s dance LSh round 1st
    corners to end in 2nd/4th places opp sides (1M+3L pass RSh in
    middle)
9-16::
    1s+3s dance LSh reel of 4 up/down middle (LSh to partner to start).
    1s & 3s end joining LH with partner, RH with 1st corners
17-24::
    1s & 3s dance the Spoke (4s dance in both Spokes)
25-32::
    1L+2s, 1M+4s+3L, 3M+5s dance RH across; 1s & 3s turn partner 3/4  LH
    & cast 1 place (4s & 5s step up 31-32). 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (5376, '2013-08-21 08:31:05.793718+00', '2023-02-04 01:20:05.363919+00', 2357, 3, NULL, 'ace', '1-8::
    1s turn RH, cast to 2nd place, turn LH & cast back to original
    places
9-16::
    1s+2s advance for 2 steps & retire, 1s & 2s cross RH
17-24::
    1M+2L set & cross RH to change places, 1L+2M repeat
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (14905, '2022-06-27 00:19:54.285757+00', '2023-02-04 01:20:05.373883+00', 16578, 3, NULL, 'ace', '1-8::
    1s+3s turn partner RH into Bal-in-Line position (Men above
    partners); 1s+3s set (HS setting changing hands as required)
9-12::
    1s & 3s turn partner RH to opp sides _while_ 2M casts up to between
    1s facing down & 2L casts down to between 3s facing up
13-16::
    All set & change places RH with person opposite
17-24::
    All set & 2s Petronella turn to opp sides (3) (2) (1);  2s turn to
    right & dance 1/2 RSh reels of 3 on sides
25-32::
    All set & cross RH with partner, 1s face out; 1s+2s change places
    (Men LH, Ladies RH), 1s+3s change places (Men RH, Ladies LH)  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13892, '2021-04-05 00:19:43.988579+00', '2023-02-04 01:20:02.249396+00', 20253, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L+4L chase anticlockwise behind Men''s line back
    to places
9-16::
    1M followed by 2M+3M+4M chase clockwise behind Ladies'' line back to
    places
17-24::
    1s slip step down the centre & back
25-32::
    All couples, both hands joined (4s leading) slip step down, 2s+3s+4s
    slip step up under arch made by 1s. End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (15415, '2023-02-04 01:20:05.384033+00', '2023-02-04 01:20:05.384573+00', 20302, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All dance interlocking RSh reels of 4 (RSh to partner to start).
    Ladies face out
9-16::
    All dance Schiehallion reels to end in opposite place.  3 4 1 2
17-24::
    Men turn partner RH into centre, Men dance 1 place clockwise round
    _while_ Ladies dance LH across 1/2 way; Ladies turn new partner into
    centre, Ladies dance 1 place clockwise round _while_ Men dance LH
    across 1/2 way.  4 1 2 3
25-32::
    All set to partner, turn RH into allemande hold facing anticlockwise
    & all dance 2 places round anticlockwise.  2 3 4 1

{{explanation}}
Repeat once in Strathspey time then twice in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (5377, '2013-08-21 08:31:05.802141+00', '2023-02-04 01:20:05.394882+00', 9350, 3, NULL, 'ace', '1-8::
    2s dance RH across with 1s/3s (Lady up, Man down), 1s+3s chase
    clockwise 1/2 way to change places
9-16::
    2s dance LH across with 3s/1s (Man up, Lady down), 3s+1s chase
    anticlockwise 1/2 way back to places
17-24::
    1s turn 2s on sides LH 1.1/2 times, turn 3s RH (once when in 2nd
    place & 1.1/2 times when in 3rd place
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5378, '2013-08-21 08:31:05.810662+00', '2023-02-04 01:20:05.406744+00', 2360, 3, NULL, 'ace', '{{explanation}}
Fugue dance - Men copy Ladies 8 bars later

1-8::
    1L followed by 2L+3L dance anticlockwise round 1+2+3M & back up to
    places (Men stand)
9-16::
    1L+2L+3L set & cross, set & cross back (Men repeat Ladies Figs but 8
    bars behind)
17-24::
    1L+2L+3L set & cross RH, turn to right & 1L followed by 2L+3L dance
    clockwise & down own side (Men Ditto)
25-32::
    1L+2L+3L dance reel of 3 on own side (1L RSh to 2L to start)  (Men
    Ditto)
33-40::
    1L+2L+3L dance 1/2 reel of 3 on own side, 1L+2L turn LH 1.1/2 times
    on side to change places    (Ditto but 1M & 2M pass LSh)
41-48::
    All Ladies stand _while_ Men complete last Fig (Men Ditto & end
    1M+2M turning RH)', 4);
INSERT INTO 'dancecrib' VALUES (8580, '2015-02-13 12:47:45.268156+00', '2023-02-04 01:20:05.417711+00', 12684, 3, NULL, 'ace', '1-8::
    1s+3s cross RH; 1M+3L change places LH; 1L+3M change places RH; 2s
    cross RH to face out/down
9-16::
    Mirror reels of 3 on sides (1s cross up, 2s out/down, 3s in/down to
    start)   3 (2) (1)
17-20::
    1s cross RH, cast up 2 places (3s+2s step down 19-20)  1 3 (2)
21-24::
    2s repeat bars 17-20 (1s+3s step down 23-24)  2 1 3
25-28::
    1L+2s also 1M+3s dance RH across, 1s dance towards each other ready
    for …
29-32::
    1s touch hands, cast 2 places (3s+4s step up 31-32)  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5379, '2013-08-21 08:31:05.81901+00', '2023-02-04 01:20:05.4288+00', 8977, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels on own sides with 1s dancing out to
    start
9-16::
    1s cast 1 place as 2s dance up & 1s turn RH, 1s dance LSh round 4th
    corner & meet in middle holding LH each facing 2nd corners
17-24::
    1s+2nd crnrs set & 1s turn inwards to face 4th corner & set turning
    anticl''wise to face 1st crnrs 1s+1st crnrs set & 1s turn inwards to
    face 3rd crnr & set
25-32::
    1s dance Pass+Turn with 2nd corners & twirl round to face 1st
    corner, 1s dance Pass+Turn with 1st corners & end 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (5380, '2013-08-21 08:31:05.82978+00', '2023-02-04 01:20:05.440952+00', 13610, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 2nd place, 1s dance 1/2 Fig of 8 (L up round
    2s, M down round 3s).  2 1 3
9-16::
    1s dance RSh reels on opposite sides, (1M RSh to 2L, 1L RSh to 3M)
17-24::
    1s dance 1/2 Fig of 8 (1M round 2s, 1L round 3s), 1s RH across (1L
    with 2s, 1M with 3s)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5381, '2013-08-21 08:31:05.975306+00', '2023-02-04 01:20:05.651988+00', 10481, 3, NULL, 'ace', '1-8::
    1s advance for 1 (touch R hands) & Retire, cast to 2nd place, turn
    2H & dance RSh round each other to face 3rd corners
9-16::
    1s dance reels of 3 on sides (RSh to 3rd corners)
17-24::
    1s dance RSh round 3rd corner into lines across (1M between 2s & 1L
    between 3s), all set, 1s cross RSh & dance RSh round 4th corner to
    2nd pl
25-32::
    2s+1s+3s circle 6H round & back', 4);
INSERT INTO 'dancecrib' VALUES (14650, '2022-03-07 02:19:45.096912+00', '2023-02-04 01:20:05.665397+00', 16598, 3, NULL, 'ace', '1-8::
    1s+3s set & cast down 1 place (2s+4s step up bars 3-4). 1s+3s turn
    LH to face 1st corners
9-12::
    1s+3s dance 1/2 diagonal LSh reels of 4 with 1st corners & pass LSh
    to face 4th corners (partner''s 2nd corner)
13-16::
    1s+3s dance 1/2 diagonal LSh reels of 4 with 4th corners & pass LSh
    to face 3rd corners (partner''s 1st corner)
17-20::
    1s+3s dance 1/2 diagonal LSh reels of 4 with 3rd corners & pass LSh
    to finish facing partner in a line up & down the middle of the set
    (Ladies/Men facing down/up, 5s finish in 1st place, 4s in 3rd place,
    2s in 5th place)
21-24::
    1s+3s dance 1/2 LSh reels of 4 up & down middle of set
25-28::
    1L followed by partner dances up behind 2L into 4th place opposite
    sides _while_ 3M followed by partner dances down behind 5M into 2nd
    place opposite sides 5 (3) 4 (1) 2
29-32::
    1L followed by partner dances down behind 2M into 5th place own
    sides _while_ 3M followed by partner dances up behind 5L & into 1st
    place own sides.(5s step down & 2s step up bars 31-32).  3 5 4 2 1', 0);
INSERT INTO 'dancecrib' VALUES (5382, '2013-08-21 08:31:05.984478+00', '2023-02-04 01:20:05.828591+00', 2364, 3, NULL, 'ace', '1-8::
    1s set, cast & dance down between 3s, cast up behind 3s
9-16::
    All dance Allemande
17-24::
    All Advance+ Retire for 1 step, cross RH & circle 6H round to left
    1/2 way.  2 1 3
25-32::
    1s+3s 3/4 turn partners RH, dance 1/2 RSh reel of 4 up/down middle &
    3/4 turn partner to end on own sides.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4044, '2013-08-21 08:30:42.441402+00', '2023-02-04 01:18:29.539759+00', 195, 3, NULL, 'ace', '1-8::
    All dance double reels of 4 passing LSh in centre (Men start) &
    Ladies end in centre facing partners
9-24::
    All set & petronella turn 4 times
25-32::
    All set HS to partners (4 bars) & turn partner RH 2.1/4 times to
    place (Ladies facing out)
33-48::
    All dance full Schiehallion Reel

{{explanation}}
Repeat in Reel time but normal setting in place of HS setting', 0);
INSERT INTO 'dancecrib' VALUES (5337, '2013-08-21 08:31:04.92266+00', '2023-02-04 01:20:02.807553+00', 2294, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & 1s turn LH to 2nd places.  21 3
9-16::
    1s dance anticlockwise round outside of 2s+3s to change places as
    2s+3s dance RH across, 2s+3s chase clockwise 1/2 way as 1s turn LH
    1.1/2 times ending in 2nd place.  (3)1(2)
17-24::
    1s set, 1/2 turn 2H, 3s+1s+2s set & cross RH
25-32::
    3s+1s+2s circle 6H round 1/2 way, set & cross RH', 4);
INSERT INTO 'dancecrib' VALUES (14369, '2021-10-11 22:39:59.782311+00', '2023-02-04 01:20:05.838751+00', 20484, 3, NULL, 'ace', '1-8::
    1s set, cross down (2s step up), dance down behind 3s & dance up NHJ
    between 3s to 2nd place remaining in centre
9-16::
    2s+1s+3s dance mirror reels of 3 (1s out/up, 2s in/ down, 3s in/up).
    1s end BtoB facing opp sides
17-24::
    1s dance 6 bars Double Triangles then Petronella Turn to 2nd place
    own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5383, '2013-08-21 08:31:05.990836+00', '2023-02-04 01:20:05.846358+00', 9859, 3, NULL, 'ace', '1-8::
    1s set & turn RH for 6 bars & end 1M facing 1st corner with partner
    behind him
9-16::
    1s (Man leading) dance an Alternating RSh diag reel of 3 with 1st
    crnrs
17-24::
    1M faces 4th corner & dance an Alternating Tandem diag reel of 3
    passing 3M RSh, 1s turn LH to face own 1st corners
25-32::
    1s turn 1st corner RH, pass RSh, turn 2nd corner RH & pass RSh to
    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5384, '2013-08-21 08:31:06.001351+00', '2023-02-04 01:20:05.85856+00', 2365, 3, NULL, 'ace', '1-8::
    1L & 2L cross down below partner & cast down 1 place, dance up the
    middle & loop round to right to original places
9-16::
    1M & 2M cross down below partner & cast down 1 place, dance up the
    middle & loop round to left to original places
17-24::
    1s+2s dance RH across; 2s followed by 1s lead down the middle
25-32::
    1s+2s dance RH across; 1s followed by 2s lead up to places
33-40::
    1s+2s dance Espagnole:
::
    _33-34_   1s+2s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _35-36_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _37-40_   2s turn RH as 1s turn LH', 0);
INSERT INTO 'dancecrib' VALUES (5385, '2013-08-21 08:31:06.158761+00', '2023-02-04 01:20:05.952268+00', 2367, 3, NULL, 'ace', '1-8::
    1L+2L dance across between 1M & 2M, cast round partner back to
    places & 1s+2s set
9-16::
    1s+2s+3s all chase round clockwise back to places
17-24::
    1s+2s+3s dance Allemande
25-32::
    3s cast down 2 places _while_ 1s lead up to top & cast 1 place to
    face 1st corners, set to 1st corner & set to 2nd corner
33-40::
    1s dance reel of 3 on opposite sides giving RSh to 2nd corners &
    cross RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (9917, '2017-06-05 11:31:06.912497+00', '2023-02-04 01:20:05.964429+00', 16490, 3, NULL, 'ace', '1-8::
    1s dance down, cast up round 3s (2s step up 3-4).  2s+1s+3s turn
    partners RH. Finish in Allemande hold facing up
9-16::
    2s+1s+3s dance Allemande.  1s end facing 1st corner pstns
17-18::
    1L+3M also 1M+2L pass RSh to change places _while_ 3L+2M set
19-20::
    3M+2L (in centre) turn LH once round _while_ others chase clockwise
    to next corner
21-24::
    Repeat bars 17-20 from new positions
25-28::
    Repeat bars 17-20 from new positions except bars 27-28 when 1s (in
    middle) turn LH to end 1M between 2s (at top) facing 2L, 1L between
    3s facing 3M
29-32::
    _1/2_ LSh reels of 3 across (1M+2s & 1L+3s).  Bar 32 - 1s dance
    towards each other, turn left about to face own sides
33-40::
    2s+1s+3s dance Double Triangles', 0);
INSERT INTO 'dancecrib' VALUES (5387, '2013-08-21 08:31:06.177334+00', '2023-02-04 01:20:05.98864+00', 695, 3, NULL, 'ace', '1-8::
    1s set, cross RH, 1s+2s Set+Link (Ladies face out)
9-16::
    2s+1s Men''s Chain
17-24::
    1s 1/2 Figs of 8 (L round 2s & M round 3s), 2s+1s+3s turn RH & open
    into
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15416, '2023-02-04 01:20:06.00266+00', '2023-02-04 01:20:06.003269+00', 2371, 3, NULL, 'ace', '1-8::
    1s+2s dance the Tournee.  2 1 3
9-12::
    2s+3s chase 1 place clockwise round as 1s Petronella turn finishing
    in lines of 3 across & set (1L between Men at top, 1M between
    Ladies)
13-16::
    2s+3s chase 1 place clockwise round as 1s Petronella turn finishing
    all on opp sides & set. (3)(1)(2)
17-24::
    3s+1s+2s dance 1/2 reels of 3 on the sides  (1s RSh to 2nd crnrs);
    all dance reels of 3 across (1s RSh to 4th crnrs)  2 1 3
25-32::
    All Men cross & dance RSh round partner, Men dance back to own side
    followed by partners who dance RSh round partner and cross back to
    own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9363, '2016-10-06 07:18:26.586059+00', '2023-02-04 01:20:06.014124+00', 17231, 3, NULL, 'ace', '1-8::
    1s cross RH & cast (2s step up 3-4) 1s dance 1/2 fig of 8 down round
    3s
9-16::
    1s followed by 2s lead down the middle (4bars) 2s divide to allow 1s
    to lead back to the top, couples stay in the middle ready for…..
17-24::
    1s+2s dance the Allemande.
25-32::
    2s+1s+3s circle 6H round and back.', 0);
INSERT INTO 'dancecrib' VALUES (15360, '2022-12-19 01:22:37.526286+00', '2023-02-04 01:23:09.639304+00', 21155, 3, NULL, 'ace', '1-8::
    1s turn RH & cast (2s step up 3-4); 1s turn 1.1/2 RH to face 1st
    corners
9-16::
    2s+1s+3s dance reels of 3 across (1s & 1st corners pass RSh to
    begin). 1s end facing 1st corners
17-20::
    1s dance Corner Pass+Turn with 1st corners, pull back RSh, end BtoB
    1L facing up, 1M facing down
21-24::
    1s dance Corner Pass+Turn with 4th corners, 1s ending in 2nd place
    own side
25-32::
    2s+1s+3s circle 6H hands round to left for 6 slip steps (3 bars),
    pivot (pull back LSh) and circle 6H back to right. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5388, '2013-08-21 08:31:06.18559+00', '2023-02-04 01:20:06.024509+00', 2376, 3, NULL, 'ace', '1-8::
    1s set advancing for 2 steps, cast to 2nd place, set advancing for 2
    steps & cast to 3rd place
9-16::
    1s in prom hold dance to top, turn LH to face down on opposite
    sides, 1s+2s set on sides & turn (RH on Men''s side & LH on Ladies)
17-24::
    1s+2s+3s dance reflection reels of 3 on opposite sides (1s in & down
    to start), 1s crossing RH to 2nd place own side
25-32::
    1s change places RH on sides with 3s, cross LH, change places RH on
    sides with 4s & cross LH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (7887, '2013-08-21 08:31:50.572991+00', '2023-02-04 01:23:09.658911+00', 7034, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s turn LH 1.1/4 times to Man facing up
    & lady down
9-16::
    1s dance RH across (1M with 2s & 1L with 3s), 1s turn LH 1.1/2 times
    to Lady facing up & Man down
17-24::
    1s dance RH across (1L with 2s & 1M with 3s), 1s turn LH 1.1/2 times
    to face 2nd corners
25-32::
    1s dance reels of 3 on opposite sides (RSh to 2nd corners to start)
    & cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13894, '2021-04-05 00:19:48.296584+00', '2023-02-04 01:20:06.03501+00', 12252, 3, NULL, 'ace', '1-8::
    1s set, cross RH; cast (2s step up) & cross LH to face 3rd corners
9-16::
    1s dance ''Hello-Goodbye'' setting to end facing 1st corners
17-24::
    Reels of 3 across, 1s pass 1st corners LSh to start.  1s end facing
    1st corners again
25-32::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH to
    finish in middle BtoB, 1M facing down, 1L facing up
33-40::
    1s dance 6 bars of Modified Crown Triangles (start with 1M facing 3s
    & 1L facing 2s & moving to the left)
::
    Bars 39-40: 1M (facing own side) sets 1 PdB then moves out to 2nd
    place own side pulling back LSh to face in _while_ 1L sets 2 PdB
    moving out to own side facing out
41-48::
    1s+2s dance LH across; 1s+3s dance 1/2 RH across & 1/2 turn partner
    RH to own side.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13151, '2020-09-15 00:19:45.588454+00', '2023-02-04 01:20:06.046063+00', 8739, 3, NULL, 'ace', '1-8::
    All set, 1s+2s also 4s+5s dance 1/2 RH across _while_ 3s cross RH;
    all set & cross LH
9-12::
    1s & 5s turn partner RH, 1M & 5L face out;
13-16::
    1M followed by 1L casts up, dances down middle to face 3M, 1L to
    face 2M _while_ 5L followed by 5M casts down, dances up middle to
    face 3L, 5L to face 3L
17-24::
    Reels across: 1L+2s reel of 3 (1L RSh to 2M), 1M+3s+5L RSh reel of
    4, 5M+4s reel of 3 (5M RSh to 4L). 2s+3s+4s end on sides, 1s+5s in
    middle 1L+5L & 1M+5M RSh to RSh (Order:1L 5L 1M 5M)
25-32::
    Middle couples Bal-in-Line, 1L+5L & 1M+5M 1/2 turn LH; Bal-in-Line
    again, 5L & 1M set _while_ 1L+5M 1/2 turn RH. 5s & 1s join LH with
    partner, facing 2nd corners
33-36::
    5s & 1s set to partner _while_ 2nd corners set advancing to join
    them to dance RH across 1/2 way. 1s & 5s face 1st corners
37-40::
    Repeat 33-36 with 1st corners (5s & 1s RH joined, 1/2 LH across with
    corner.  1s end facing 2nd corner (pstn)
41-44::
    Repeat 33-36
45-48::
    5s set RH joined & cross down LH to 3rd place _while_ 1s set RH
    joined & cross down LH to 5th place (3s & 2s step up 47-48).  4 3 5
    2 1', 0);
INSERT INTO 'dancecrib' VALUES (13152, '2020-09-15 00:19:45.666541+00', '2023-02-04 01:20:06.066053+00', 14457, 3, NULL, 'ace', '1-8::
    1s lead down (2s step up 3-4); 1L dances under 1M''s arm to change
    sides (1M dances below 1L) & 1s lead up to 2nd place opp sides
9-16::
    1s NHJ dance up to top & into mirror reels of 3 on sides giving
    hands where possible (2s in/down, 3s out/up). 1s end facing 1st
    corner
17-24::
    1s dance ''Hello-Goodbye'' setting & turn 3/4 RH to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8581, '2015-02-13 12:47:45.630785+00', '2023-02-04 01:20:06.084409+00', 2383, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast (2s step up), cross LH & remain facing out
9-12::
    2s+3s dance RH across _while_ 1s dance anticlockwise around them 1/2
    way to 2nd place opp. sides   2 (1) 3
13-16::
    1s set advancing & turn 2H once round
17-20::
    1M dances down, 1L up, out of ends, cast to Right _while_ 2s+3s set
    to diag. opp. corner & dance to corner on their right
21-24::
    1M dances up, 1L down, all repeat bars 17-20
25-28::
    Repeat bars 17-20 but corners do not set; instead they dance 2
    corner places to Right
29-32::
    1s set advancing, turn RH once round to 2nd place own sides      2 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (5391, '2013-08-21 08:31:06.210435+00', '2023-02-04 01:20:06.096423+00', 2388, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across, 1L also 4M followed by partner
    chase round clockwise to other end of dance
9-16::
    4s+2s also 3s+1s dance RH across, 1L also 4M followed by partner
    chase round clockwise back to places
17-24::
    1s+2s also 3s+4s set facing on sides & change places RH, middle
    couples set facing on sides & change places LH
25-32::
    Middle couples lead up/down between end couples, cast back to place
    & all turn RH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5392, '2013-08-21 08:31:06.218975+00', '2023-02-04 01:20:06.1083+00', 10760, 3, NULL, 'ace', '1-8::
    1s set, cast & dance 1/2 Fig of 8 (Man with 2s & Lady with 3s) & end
    in 2nd place opposite side facing 1st corner
9-24::
    2s+1s+3s dance Fig of 8 Grand Chain: 1s change places RH with 1st
    crnrs on sides as 2nd crnrs cross diag RH, 1s cross diag LH as
    others change pl LH on sides, continue this Fig back to pl (Ladies
    in top pl always cross diag with Man in 3rd pl as others change pl
    on sides) & end with 1s dancing 1/2 Fig of 8 (Man down & Lady up)
25-32::
    2s+1s+3s Adv+Ret & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5393, '2013-08-21 08:31:06.233187+00', '2023-02-04 01:20:06.209878+00', 2389, 3, NULL, 'ace', '1-8::
    1s cast down on own sides, turn out & back to places
9-16::
    1s+2s circle 4H round & back
17-24::
    1s turn RH, cast 1 place & turn LH
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5394, '2013-08-21 08:31:06.241633+00', '2023-02-04 01:20:06.220867+00', 2394, 3, NULL, 'ace', '1-8::
    1s cross RH & cast down to 3rd place, cross RH & cast up to 2nd
    place on own sides
9-16::
    1s set adv to ptnr & turn 1st crnr 2H to face 2nd crnr, 1s dance 1/2
    diag reel of 4 ending M b''tw''n top cpl facing down & L b''tw''n bottom
    cpl facing up
17-24::
    1s set adv to partner & turn 4th corner (pstn) 2H to face own 1st
    corner (pstn), 1s dance 1/2 diag reel with 1st corners ending in 2nd
    place opp sides
25-32::
    3s+1s+2s Set+Link for 3 twice', 0);
INSERT INTO 'dancecrib' VALUES (5395, '2013-08-21 08:31:06.249878+00', '2023-02-04 01:20:06.232137+00', 2396, 3, NULL, 'ace', '1-8::
    All dance RSh reels of 4 on sides
9-16::
    1M & 2L also 3M & 4L pass RSh, dance LSh round partner, pass each
    other RSh back to original places
17-18::
    Top 3 on Men''s side change places RH with bottom 3 on Ladies'' side
19-20::
    Top 3 on Ladies'' side change places LH with bottom 3 on Men''s side
21-24::
    Repeat 17-20 to end (4) (3) (2) (1)
25-32::
    3s+2s Set+Link; 4s+2s also 3s+1s set & dance 1/2 RH across.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8582, '2015-02-13 12:47:45.718258+00', '2023-02-04 01:20:06.382271+00', 2398, 3, NULL, 'ace', '1-8::
    1s turn RH, cast off, dance down between 3s, cast up into 2nd place
9-16::
    1L with 2s & 1M with 3s dance RH across.  1s pass RSh, 1M with 2s &
    1L with 3s dance LH across.
17-24::
    1s dance Corner Pass+Turn.  Finish passing RSh with 1L between 2s
    and 1M between 3s.
25-32::
    Reel of 3 across the dance (6 bars) 1M+3M, 1L+2L passing RSh to
    start.  1s cross RH bars 31-32', 0);
INSERT INTO 'dancecrib' VALUES (9004, '2015-11-30 08:59:46.937625+00', '2023-02-04 01:20:06.394385+00', 2399, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance the Tournée:
::
    1s+2s also 3s+4s dance into prom hold (Men with prtnr on right,
    1s/3s face M''s side & 2s/4s L''s side), couples 1/2 wheel anticl''wise
    & Men turn Ladies into middle, both couples turn 1.1/2 times (2s/4s
    RH, 1s/3s LH) & dance out to places.  2 1 4 3
9-16::
    1s+4s+3s dance the Knot, to end in diagonal lines across the dance,
    3L facing 2L, 4M facing 1M also 3M facing 2M, 4L facing 1L (3M +4L
    pull back LSh on bar 16)
17-24::
    All dance double diagonal reels of 4 (give LSh in centre)
25-32::
    2s+3s also 4s+1s dance RH across & LH back', 0);
INSERT INTO 'dancecrib' VALUES (5349, '2013-08-21 08:31:05.182984+00', '2023-02-04 01:20:03.621782+00', 11810, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back
9-16::
    1s cast on own sides & dance up back to places
17-24::
    1s+2s dance RH across & LH back
25-32::
    1s cast to 4th place as others step up, 2M+1L Adv+Ret', 0);
INSERT INTO 'dancecrib' VALUES (5396, '2013-08-21 08:31:06.260269+00', '2023-02-04 01:20:06.52712+00', 10556, 3, NULL, 'ace', '{{explanation}}
Round the Room 3 facing 3

1-8::
    All circle 6H round & back
9-16::
    All set to opposite person, cross RH & chase clockwise 1/2 way
17-24::
    All set to opposite person, cross RH, centre persons turn RH _while_
    others chase clockwise 1/2 way
25-32::
    All set, slip step to right for 2 bars advancing, all set & slip
    step to left for 2 bars advancing to end facing new trio

{{explanation}}
Repeat with new partners in new set', 0);
INSERT INTO 'dancecrib' VALUES (13153, '2020-09-15 00:19:46.30529+00', '2023-02-04 01:20:06.538912+00', 2401, 3, NULL, 'ace', '1-8::
    1s set, cast behind 2s, down between 3s & cast up to face 1st
    corners
9-12::
    1s turn corner RH _while_ 2nd corners set, 1s turn LH to face 1st
    corner (pstn) again _while_ corners chase clockwise 1 place
13-16::
    Repeat 9-12.  1s end BtoB in centre 1L facing up, 1M facing down
17-24::
    1L+3s (at top) & 1M+2s (at bottom) circle 3H round to left opening
    out to circle 6H 1/2 round to left , 2s+1s+3s set
25-32::
    1M+2s (at top) & 1L+3s (at bottom) dance reels of 3 across (1s LSh
    to 3rd corner), 1s cross RH. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8583, '2015-02-13 12:47:45.770027+00', '2023-02-04 01:20:06.669242+00', 15884, 3, NULL, 'ace', '1-8::
    1s dance Inveran reels with 2s+3s
9-16::
    1s+2s dance double Fig of 8 (1s cross down to start)
17-24::
    3s cross up to dance Inveran Reels
25-32::
    1s lead down the middle & up to 2nd place
33-40::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5398, '2013-08-21 08:31:06.299191+00', '2023-02-04 01:20:06.68628+00', 13585, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, 1s face 2s set & 1s turn inwards cast
    1 place to face 3s
9-16::
    1s+3s dance the Rondel, 1s end in 3rd place & 3s end facing 1st
    corners. 2 (3) 1
17-24::
    3s set to & turn 1st corners; set to & turn 2nd corners.  3s end in
    2nd place opposite sides
25-32::
    2s+1s dance R&L (begin on sides) _while_ 3s dance up between 2s &
    cast to 2nd pl,  lead down LH b''tw''n 3rd pl, cross & cast up to 2nd
    pl.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5399, '2013-08-21 08:31:06.307599+00', '2023-02-04 01:20:06.69618+00', 2408, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across 1/2 way, set & dance LH across 1/2 way
9-16::
    1s+2s set, turn RH to end 1M & 2L BtoB facing partners in diag line
    & dance 1/2 reel of 4 (end on own sides with 1s in 2nd place)
17-24::
    3s set advancing & lead up to top, then 1s set & turn 2H to face 1st
    corners
25-32::
    1s set to 1st corners, set to 2nd corners & dance 1/2 LSh reel of 3
    on own side (Man up Lady down)', 4);
INSERT INTO 'dancecrib' VALUES (5400, '2013-08-21 08:31:06.315903+00', '2023-02-04 01:20:06.709367+00', 2409, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance 1/2 R&L, 1s+4s (middle couples) dance 1/2 R&L
9-16::
    2s+4s & 1s+3s circle 4H left 1/2 way, 2s+3s (middle couples) circle
    4H right 1/2 way; 1s dance up to top (2s+3s+4s step down) & all face
    as for Reel of 4 on sides
17-24::
    All set HS & dance 1/2 Grand Chain.  All end on own side 2 3 4 1
25-32::
    All dance Reel of 4 on sides.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5401, '2013-08-21 08:31:06.326404+00', '2023-02-04 01:20:06.723067+00', 12427, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 Figs of 8 round (1L round
    2s, 1M round 3s) & end facing 1st corners
9-16::
    1s dance 1/2  diag reel of 4 with 1st corners & pass LSh to face 2nd
    corners, 1s dance 1/2 diag reel of 4 with 2nd corners & end turning
    right about into Double triangle position
17-24::
    1s dance Double Triangles & end 2nd place opposite sides  (3)(1)(2)
25-32::
    3s+1s+2s set & turn RH, then chase clockwise 1/2 way to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14906, '2022-06-27 00:19:56.027789+00', '2023-02-04 01:20:06.739491+00', 20883, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s cast off to 3rd place; All set advancing & pass
    LSh to BtoB facing opp sides, pull back RSh & dance round partner to
    own sides
9-16::
    3s+2s+1s dance Reverse Snowball Grand Chain for 3 cpls to end 1 (2)
    3:
::
    1s cross RH & change places LH on side with 2s
::
    1s change places RH with 3s _while_ 2s cross RH
::
    1s cross LH _while_ 3s & 2s change places LH.  1 (2) 3
17-24::
    1s cast, dance down between 3s & cast up & turn LH to face 1st
    corners _while_ bars 17-18: 2s cross up RH to 1st place own side
25-32::
    1s dance corners Pass+Turn with 1st corners (corners turn 2H), pass
    RSh; Repeat with 2nd corners & 1s pass RSh into 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5402, '2013-08-21 08:31:06.334651+00', '2023-02-04 01:20:06.751738+00', 2415, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reels on own sides ending in lines
    across 1L between 2s & 1M between 3s
17-24::
    2s+1s+3s set twice, turn opposite person 2H, 1s end 2nd place on own
    sides
25-32::
    2s+1s+3s set twice & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (13301, '2020-11-02 01:19:54.03031+00', '2023-02-04 01:20:06.765403+00', 20010, 3, NULL, 'ace', '1-8::
    1L+2L dance across, pass partner RSh, chase up behind Men, across
    top & down own side to change places _while_
::
    3M+4M dance across, pass partners RSh, chase down behind Ladies,
    across bottom & up own side to change places
9-16::
    1M+2M dance across, pass opposite dancer LSh, chase up behind
    Ladies, across top & down own side to change places _while_
::
    3L+4L dance across, pass opposite dancer LSh, chase down behind Men,
    across bottom & up own side to change places
17-24::
    1s+3s (Ladies following partners) dance down, Bar 20: pull back RSh
    & dance back up (Ladies leading).  3s dance into 2nd place own sides
    _while_ 1s end in middle, 1L above 1st place, 1M between 2s in 1st
    place, facing up
25-32::
    1s cast round 2s down to 4th place (2s+3s+4s step up 27-28);  1s
    dance RSh round each other. End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (15063, '2022-09-05 00:19:49.904984+00', '2023-02-04 01:20:06.776319+00', 14794, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+3s dance RH across & chase clockwise behind couple on left (1s
    behind 2s, 3s behind 4s) to opposite sides
9-16::
    2s+4s dance LH across & chase anticlockwise (2s behind 3s, 4s behind
    1s) to opposite sides
17-24::
    All set & advance with partners, retire diagonally with corners &
    set
25-32::
    1L+4M & 2M+3L dance 1/2 R&L followed by 1/2 Men''s Chain (Men give RH
    to begin)
33-40::
    1M+2L & 3M+4L dance 1/2 R&L followed by 1/2 Men''s Chain (Men give RH
    to begin)
41-48::
    All set & advance with new corner, retire with new partners & set
    (Men are now in original places, Ladies are opposite their own
    partner)
49-54::
    All Men dance RH across & chase clockwise 1/2 way round to pick up
    partners in promenade hold.
57-64::
    All promenade clockwise to position opposite from original place 3 4
    1 2

{{explanation}}
Repeat in Reel time to finish in original positions', 0);
INSERT INTO 'dancecrib' VALUES (5403, '2013-08-21 08:31:06.342992+00', '2023-02-04 01:20:06.789308+00', 14520, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on opposite sides (1s cross to 2nd place)
9-16::
    1s cross down to dance Figs of 8 round 2s (with 1s 1/2 turning 2s)
17-24::
    1s cross down to 2nd place & set, 1s dance down between 3s & cast up
    to 2nd place own side
25-32::
    1s turn 2s (dancing between them to start), 1s turn 3s with opposite
    hands', 0);
INSERT INTO 'dancecrib' VALUES (7888, '2013-08-21 08:31:50.581009+00', '2023-02-04 01:23:09.684132+00', 7035, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance  2 facing 2

1-8::
    All circle 4H round & back
9-16::
    All dance RH across & LH back
17-24::
    1M+2L also 1L+2M turn RH & turn LH
25-32::
    1s+2s Adv+Ret, 1s also 2s advance & pass RSh to meet the next couple', 0);
INSERT INTO 'dancecrib' VALUES (5354, '2013-08-21 08:31:05.249525+00', '2023-02-04 01:20:04.072411+00', 2323, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s circle 4H round & back
9-16::
    1s+2s dance the Bourrel :
::
    1M+2L set advancing, 3/4 turn 2H & twirl to end BtoB (Lady facing up
    & Man down) _while_ partners chase anticlockwise 3/4 way,
::
    set to partners & turn 2H to own sides having changed places

{{title}}
Reel

1-8::
    1s petronella turn into centre (1L/1M b''tw''n 2s/3s) as 2s+3s set to
    partners, all set lines across, 1s petronella turn to opp side as
    2s+3s set & all set on side lines
9-16::
    1s dance RSh Reels of 3 on opposite sides giving RSh to 2nd corner &
    cross RH to places', 0);
INSERT INTO 'dancecrib' VALUES (5404, '2013-08-21 08:31:06.353126+00', '2023-02-04 01:20:06.843161+00', 2419, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 2s+1s+3s circle 6H round to left back to
    places
9-16::
    2s+1s+3s set, cross RH, set, 2s & 3s cross back _while_ 1s turn RH
    to face 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s dance reels of 3 on opposite sides passing 1st corner LSh to
    start 1s cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5405, '2013-08-21 08:31:06.363537+00', '2023-02-04 01:20:06.855146+00', 8516, 3, NULL, 'ace', '{{explanation}}
Start 2s & 4s with Lady on Mans left

1-4::
    1s+3s change RH with opposite person, 1s & 3s cast (away from
    partner) to sides _while_ 2s & 4s dance to their corners'' pstns
5-8::
    1s+3s dance 1/2 RH across, set across with nearer hands joined with
    ''new'' partner (Everyone has now changed places with their original
    corner)
9-16::
    All dance 1/2 Grand Chain giving RH to corner to start, retaining LH
    at end & 1/2 turn into St Andrews cross formation & set (1M, 2L, 3M
    ,4L in centre)
17-24::
    All dance Double Targe : centre 4 dance 1/4 RH across _while_ others
    chase 1/4 anticl''wise, all turn ptnrs LH & repeat all end on sides
    (as bar 8)
25-32::
    All set to ''new'' ptnr, join hands & set across, dancers in Men''s
    places (2M, 3L, 4M ,1L) chase cl''wise 1/2 round to end 4 1 2 3  with
    1L+3L on partner''s Left', 0);
INSERT INTO 'dancecrib' VALUES (5406, '2013-08-21 08:31:06.442459+00', '2023-02-04 01:20:06.958+00', 2421, 3, NULL, 'ace', '{{explanation}}
5s in centre, 5M facing 2M, 5L facing 4M

1-4::
    5M+2s & 5L+4s dance 1/2 RH across (2 bars). 5s end on sides (2nd/4th
    place) as 2s+4s meet in centre & dance 1/2 LH across (2 bars)
5-8::
    5M+4s & 5L+2s dance 1/2 RH across (2 bars) & 5s turn 3/4 LH in
    centre to end 5M facing 3M & 5L facing 1M
9-16::
    5s turn corner, partner, corner, partner with 1st & 3rd couples
    (turning 1M/3M first)
17-20::
    5M dances 1/2 reel of 3 with Men in 4th+1st place as 5L dances 1/2
    reel with Men in 2nd+3rd place (pass LSh to Men in 2nd & 4th place)
21-24::
    5M dances 1/2 reel of 3 with Ladies 1st+4th place as 5L dances 1/2
    reel with Ladies 3rd+2nd place end facing partner in centre
25-32::
    5s set & 1/2 turn 2H to face 4th place (original 1st couple), 5s+1s
    dance 1/2 R&L to change places', 0);
INSERT INTO 'dancecrib' VALUES (5407, '2013-08-21 08:31:06.450541+00', '2023-02-04 01:20:06.965427+00', 7546, 3, NULL, 'ace', '{{explanation}}
Couples facing anticlockwise around room

1-4::
    All in Allemande hold walk anticlockwise 4 steps & all turn about &
    walk backwards (still anticlockwise) 4 steps
5-8::
    Repeat clockwise
9-16::
    All Men set (moving anticlockwise) as Ladies dance under Mans right
    arm, all polka round the room', 0);
INSERT INTO 'dancecrib' VALUES (13154, '2020-09-15 00:19:46.997522+00', '2023-02-04 01:20:07.059481+00', 18020, 3, NULL, 'ace', '{{explanation}}
Round the Room, Couples facing anticlockwise, Man with partner on Right NH joined.  Start on outside foot

1-8::
    1s travel forward (2 bars, 4 steps), Lady dances under Man''s arm,
    couple now face clockwise; repeat to end facing anticlockwise again
9-16::
    1s turn away from each other (Man pulls back LSh, Lady RSh) & face
    again, set to partner & dance DoSiDo with partner', 0);
INSERT INTO 'dancecrib' VALUES (5408, '2013-08-21 08:31:06.4718+00', '2023-02-04 01:20:07.1145+00', 2423, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L & 2s+1s set, 2s cross LH _while_ 1s turn LH to
    face 1st corner
9-16::
    1s dance 1/2 reel of 4 with 1st corners, pass RSh & dance 1/2 reel
    of 4 with 2nd corners
17-24::
    1s dance RH across 1/2 way (1M+3s, 1L+2s), 1s dance cl''wise 1/2 way
    _while_ 3s+2s dance LH across, 1s dance RH 1/2 way across (1L+3s,
    1M+2s)
25-32::
    All dance the »Snake« (modified):
::
    _25-28_   3M followed by 3L+1L diagonally down _while_ 2L followed
    by 2M+1M cross diagonally up, passing LSh to change ends, 2L & 3M
    looping to left to opposite sides to end (2)(1)(3)
::
    _29-32_   All set & cross RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5411, '2013-08-21 08:31:06.664556+00', '2023-02-04 01:20:07.383619+00', 2428, 3, NULL, 'ace', '1-8::
    1M sets to 2L & casts 1 place, 1L sets to 2M & casts 1 place
9-16::
    1s turn 1st corner RH & pass partner RSh, turn 2nd corner LH pass
    partner RSh to face 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting & end BtoB (1M facing up & 1L
    facing down)
25-32::
    1s give RSh to 2nd corner & dance reels of 3 on sides with 2s+3s &
    cross RH to 2nd place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (15330, '2022-12-19 01:19:55.878696+00', '2023-02-04 01:20:07.400055+00', 21001, 3, NULL, 'ace', '1-4::
    1s cross RH & set to partner.
5-8::
    1s++2s 1/2 turn (RH on Men''s side, LH on Ladies'' side) to finish
    BtoB in Double Triangle positions & All set
9-12::
    1s dance 1/2 diagonal RSh reel of 4 with 1st corners, 1s pass RSh to
    2nd place own sides
13-16::
    1L+2M & 1M+3M Mirror Set+link (1s cast to 3rd place, 3M/2M dance up
    to 2nd place & face out)
17-20::
    3s+2s 1/2 turn on sides (3s RH, 2s LH) _while_ 1s cross LH, All set
    facing in. 2L&3L turn to face out.
21-24::
    1M+2L (Ladies'' side) 1/2 turn RH as 1L+3L (Men''s side) 1/2 turn LH
    to ewnd BtoB in Double Triangle position & All set
25-28::
    1s turn 1st corners RH, pass RSh to finish in lines of 3 across (1M
    between 3M & 2M at top, 1L between 3L &2 L at bottom (corners dance
    for 4 bars).
29-32::
    All chase 3/4 clockwise round to finish 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13155, '2020-09-15 00:19:47.362046+00', '2023-02-04 01:20:07.415494+00', 19687, 3, NULL, 'ace', '1-8::
    1s & 2s dance Chain Progression:
::
    1s+2s 3/4 turn RH, 1M+2L turn LH 1.1/2 times as ptnrs chase cl''wise
    1/2 way, 2s turn RH to end on sides _while_ 1s 1/2 turn RH, pull
    back RSh to face 1st corners
9-16::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh & dance 1/2
    diag reel of 4 with 2nd corners.  1s end in 2nd place opp sides
17-24::
    3s+1s+2s dance Set+Link for 3 twice
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5412, '2013-08-21 08:31:06.672752+00', '2023-02-04 01:20:07.440805+00', 2431, 3, NULL, 'ace', '1-8::
    1s followed by 2s dance down below 3s, cast up round 3s, dance up to
    top & 1s cast to 2nd place
9-16::
    1s+2s dance double Fig of 8, 1s crossing up to start
17-24::
    1s cross RH, cast down 1 place, turn LH twice & end between 3s
    facing opposite partners (1M facing 3l, 1L facing 3M)
25-32::
    1s+3s dance RSh reel of 4 across. 1s & 3s end dancing in to meet
    partner (1s above 3s) facing up NHJ
33-40::
    1s followed by 3s dance up to top, cast down on own sides (1s ending
    in 3rd place & 3s in 2nd place), 1s turn RH & cast to 4th place (4s
    step up)', 0);
INSERT INTO 'dancecrib' VALUES (15208, '2022-11-03 01:18:17.246376+00', '2023-02-04 01:18:18.463451+00', 21115, 3, NULL, 'ace', '1-4::
    1s+3s set, turn RH to face out.
5-8::
    1s+2s+3s+4s dance 1/2 mirror reels of 4 on sides (1s+3s dance
    out/down to start), 3s &1s finish BtoB in middle of set (Men facing
    up, Ladies facing down).  4 3 2 1 5
9-16::
    All dance Double Crown Triangles (4s take hands with 3M, 2s face
    across & take hands with 3L &1M, 5s take hands with 1L
::
    _9-10_          All set, on bar 10 3s &1s move clockwise to face
    opposite sides & take hands with dancers on sides _while_ 4s & 5s
    move to face across.
::
    _11-12_ All set facing across, on bar 12 3s & 1s move clockwise to
    finish BtoB _while_ 4s & 5s move to face down/up
::
    _13-16_ Repeat bars 9-12 to finish 4 3 2 1 5 (same positions as at
    end of bar 8)
17-20::
    3s &1s dance 1/2 diagonal reels of 4 with 2nd corners. On bar 20 3s
    & 1s pass 3/4 LSh to face 1st corners
21-24::
    Repeat bars 17-20 with 1st corners to face 4th corners
25-28::
    3s & 1s dance 1/2 diagonal reels of 4 with 4th corners to finish on
    own sides facing down. 5 3 2 1 4
29-32::
    3s+2s+1s+4s dance 1/2 mirror reels of 4 on own sides (3s & 1s dance
    in/down to begin). On bars 31-32, 4s dance up to 1st place passing
    behind 5s who step down to 2nd place. End 4 5 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (15052, '2022-09-05 00:18:15.942334+00', '2023-02-04 01:18:18.607394+00', 14601, 3, NULL, 'ace', '{{explanation}}
6 dancers arranged in Diamond set: 1s & 3s as in a square set with 2M in 2nd place and 2L in 4th place

{{title}}
···3L··3M

{{title}}
2M·······2L

{{title}}
··1M··1L

{{title}}
····Top

1-8::
    All dance Petronella turn to next side & set; all repeat. All are
    now opposite original place
9-16::
    1s+3s in promenade hold, dance a reel of 4 with 2L & 2M (2L & 2M
    pass LSh to start & give RSh to 3s & 1s) 2s end in original places
    (as at bar 1)
17-24::
    2M+3s (top) & 2L+2s (bottom) dance RH across; 2s pass RSh, 2L+3s &
    2M+2s dance LH across
25-32::
    All set, 3M+2M also 3L+2L turn 1.1/2 2H _while_ 1s turn 2H, all set', 0);
INSERT INTO 'dancecrib' VALUES (15053, '2022-09-05 00:18:15.9767+00', '2023-02-04 01:18:18.646909+00', 20921, 3, NULL, 'ace', '{{explanation}}
Start: 7 dancers arranged in hexagon

::
    _7_······6

{{explanation}}
5 ···4····3

::
    _2_·····1
::
    ··TOP
1-8::
    Dancer 4+1+2 dance RH across; 4+6+7 dance LH across
9-16::
    _4_+3+5 dance RSh reel of 3 across (4 RSh to 3 to start), 4 faces 6
17-24::
    Grand Chain Progession round set (1 bar per hand, centre dancer
    moving anticlockwise round set):
::
    _4_+6 change places RH, 4+7 change places LH, 4+5 change places RH,
    4+2 change places LH;
::
    _4_+1 change places RH, 4+3 change places LH, 4+7 change places RH,
    4+5 change places LH
25-32::
    Outer 6 dancers circle 6H round & back _while_ new centre dancer
    (original 6) sets (Highland setting?)', 0);
INSERT INTO 'dancecrib' VALUES (5413, '2013-08-21 08:31:06.68135+00', '2023-02-04 01:20:07.459243+00', 2432, 3, NULL, 'ace', '{{explanation}}
Note: -	»Change under« means that the Lady holds partners right/left hand in her left/right hand & dances under their raised arms

1-8::
    1s set, »change under« to circle 4H all the way round to left with
    2s
9-16::
    1s+2s+3s dance a special Progressive Chain - 1s+2s start by
    »changing under« on sides then »changing under« on sides with 3s
    _while_ 2s »change under« across etc.  4 changes to end (3) 1 (2) 4
17-18::
    3s & 4s (end couples) dance in to face up/down dance _while_ 1s+2s
    cross (1L+2M dancing under arch made by 1M+2L)
19-20::
    1s & 2s »change under« on sides _while_ 3s+4s change places up/down
    dance (4s dancing under arch made by 3s)
21-22::
    3s & 4s »change under« to other sides _while_ 1s+2s cross (1M+2L
    dancing under arch made by 1L+2M)
23-24::
    1s & 2s »change under« on sides _while_ 3s+4s change places up/down
    dance (3s dancing under arch made by 4s)
25-26::
    3s & 4s »change under« to other sides _while_ 1s & 2s advance
    towards partners
27-28::
    1s+2s dance RH across 1/2 way _while_ 3s & 4s set facing up/down
29-32::
    All dance the following simultaneously:
::
    (a) 1s dance down under arch made by 4s & »change under« to own
    sides
::
    (b) 4s dance to 3rd place & set
::
    (c) 2s dance up under arch made by 3s & »change under« to own sides
::
    (d) 3s dance to 2nd place & set', 0);
INSERT INTO 'dancecrib' VALUES (11222, '2018-09-30 22:20:44.286335+00', '2023-02-04 01:23:08.425021+00', 8385, 3, NULL, 'ace', '1-8::
    1s cast (2s step up), 1s+3s circle 4H round to Left (3 bars), pull
    back RSh, face corners & all set
9-16::
    1s+2s also 3s+4s change places RH, 2s+4s circle 4H round to Left (3
    bars), pull back RSh to face corners & all set.  End 2s & 4s side by
    side with partner, 2s facing up & 4s facing down NHJ
17-24::
    2s dance up / 4s dance down & cast to 2nd / 4th place ; 1s+2s also
    3s+4s dance 1/2 R&L
25-32::
    All set, cross RH, set, 1s cast to 4th place (3s+4s step up 32-32)

{{explanation}}
Note: K.O.S.B. = King''s Own Scottish Borderers (a line infantry regiment of the British Army)', 0);
INSERT INTO 'dancecrib' VALUES (8174, '2014-02-10 10:25:55.406476+00', '2023-02-04 01:18:19.04629+00', 15124, 3, NULL, 'ace', '1-8::
    1s cross & cast then dance 1/2 Fig of 8 round 2s
9-16::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd  corners,
    Pass+Turn with 2nd corners ending in 2nd place own sides
17-24::
    2s+1s+3s dance chase 1/2 way clockwise then turn partners RH 1.1/2
    times
25-32::
    1s+2s Set+Link, 3s+2s Set+Link', 0);
INSERT INTO 'dancecrib' VALUES (12069, '2019-08-30 09:53:41.5056+00', '2023-02-04 01:18:19.359675+00', 19085, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    Ladies dance 1/2 RH across, turn opp Man LH once round, Ladies dance
    1/2 RH across _while_ Men dance 1 place anticlockwise. All turn ''new
    partner'' LH into square set
17-24::
    Men repeat bars 9-16, end turning original partner LH into square
    set.  2 3 4 1
25-32::
    All Adv+Ret, all turn (birl) corner LH
33-40::
    All set to partner & change places RH, change places LH with next
    person, & set to next facing person
41-48::
    All change places RH with facing person, change places LH with next
    person & all turn (birl) partner RH to end 4s (1st place) facing 1s
    (2nd place) & 3s (4th place) facing 2s (3rd place). 4 1 2 3
49-56::
    1s+4s & 2s+3s dance R&L
57-64::
    1s+4s & 2s+3s Adv+Ret, set & change places RH with dancer opposite
    to finish in square set. 1 4 3 2
65-72::
    All dance Set+Link with partner; 2s+4s promenade clockwise inside
    set to original places.  1 2 3 4
73-80::
    All circle 8H round & back.  1 2 3 4', 0);
INSERT INTO 'dancecrib' VALUES (4047, '2013-08-21 08:30:42.473116+00', '2023-02-04 01:18:29.707684+00', 10994, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    Clockwise couples turn RH, Anticlockwise couples turn RH
9-16::
    All circle 4H round & back
17-24::
    All Adv+Ret, all set & advance to meet next couple (clockwise
    couples dance under arches made by other couple)', 0);
INSERT INTO 'dancecrib' VALUES (14421, '2021-11-06 01:11:14.37309+00', '2023-02-04 01:20:07.476218+00', 20541, 3, NULL, 'ace', '1-4::
    1s 1/2 turn RH moving down to 2nd place opp side _while_ 2s step up,
    1s set advancing, pass LSh to finish BtoB facing own side
5-8::
    1s dance out, cast to right _while_ 2s & 3s Petronella turn; 2s+3s
    set _while_ 1s dance between setting couples to 2nd place opp side &
    face clockwise
9-16::
    2s+1s+3s dance Weasel reels:
::
    2s+3s dance part reel of 4 up/down middle but when reaching either
    end they dance clockwise to top/bottom to re-enter reel _while_ 1s
    dance clockwise to replace dancer leaving the reel & all end where
    they started, 1s facing across set
17-24::
    2s+3s Petronella turn to opp sides, 2s+1s+3s join hands on the side
    & set. All cross RH with partner to own side & set again (retain
    hands)
25-32::
    2s+1s+3s circle 6H round to the left for 4 bars; drop hands & dance
    into the centre, pull back RSh & dance out & chase back to own
    sides. 2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (5417, '2013-08-21 08:31:06.720396+00', '2023-02-04 01:20:07.615536+00', 9860, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s set & 1/2 turn into prom hold facing 2M _while_ 4s set & 1/2 turn
    to face 3M in prom hold, 1s & 4s dance 1/2 RSh reels of 3 across set
9-16::
    1s dance 1/2 reel of 3 on Ladies'' side _while_ 4s dance 1/2 reel on
    Men''s side. Still in prom hold 1s+4s dance once round each other RSh
    & to face corner persons (4s face 3s at top & 1s face 2s Man facing
    Man, Lady facing Lady)
17-28::
    1s & 4s set to corners, set facing partner, repeat twice more
29-32::
    1s+4s dance 3/4 LH across to end 3 1 (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (13156, '2020-09-15 00:19:47.642283+00', '2023-02-04 01:20:07.634241+00', 2443, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 2s+1s turn (Ladies'' side RH, Men''s
    side LH)
9-16::
    Mirror reels of 3 on sides (1s in/down, 3s out/up, 2s out/down),
    bars 15-16: 1s cross RH to 2nd place own side
17-24::
    1s petronella turn & set _while_ 2s & 3s set & cross RH up/down; 1s
    petronella turn & set _while_ 2s & 3s set & cross LH with partner
25-32::
    1s dance 1/2 Fig 8 (1L up between 3s, 1M down between 2s) _while_
    3s+2s dance 1/2 R&L up/down; 2s+1s+3s circle 6H round to right.  2 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (5418, '2013-08-21 08:31:06.728418+00', '2023-02-04 01:20:07.645147+00', 9040, 3, NULL, 'ace', '1-8::
    1s cross down to 2nd place (no hands) & change places with 3s (LH
    Men''s side, RH Ladies'' side) into 1/2 reel of 3 (3s out & down)
9-16::
    1s repeat bars 1-8 all ending in original places
17-24::
    1s followed by 2s dance down the middle 4 steps, set to partner &
    dance up 2s leading & 1s end ready for…
25-32::
    1L dances RH across with 2L+3L & 1M LH across with 2M+3M, 1s dance
    up to top & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (5419, '2013-08-21 08:31:06.743043+00', '2023-02-04 01:20:07.771123+00', 7723, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All set to partners & 3/4 turn RH, Ladies dance LH across in centre
    & end in partners place _while_ Men dance 1/2 way round clockwise to
    face opposite Lady
9-16::
    All set & 3/4 turn LH, Ladies dance RH across back to own place
    _while_ Men dance 1/2 way round anticlockwise to meet partner
17-24::
    1s & 3s lead into centre & taking opposite partners nearer hand, set
    to 2s/4s & circle 4H round with 2s/4s
25-32::
    1M+3L & 1L+3M make arches & dance out to sides, cross & cast to
    opposite places, set to partner & change place RH _while_ 2s & 4s
    dance in for 4H round to left, 2s & 4s dance out to opposite places
    (4s making arch) Ladies passing in front of Men to places

{{title}}
Reel

1-8::
    1s+3s advance & turn opp prtnr 2H & retire (PdB) _while_ 2s & 4s
    cast away from prtnr to dance round set passing opp ptnr LH & 1/2
    turn prtnr RH
9-16::
    Repeat with 2s & 4s advancing & 1s & 3s casting
17-32::
    All dance full Schiehallion reel', 0);
INSERT INTO 'dancecrib' VALUES (14303, '2021-09-08 00:22:21.541541+00', '2023-02-04 01:23:09.707221+00', 20432, 3, NULL, 'ace', '{{explanation}}
Round the Room dance, 2 facing 2

1-8::
    1s+2s Adv+Ret NHJ with partner; circle 4H round to left
9-16::
    1s+2s dance R&L (omit polite turn)
17-24::
    1s+2s dance RH across & LH across back to place
25-32::
    1s+2s circle 4H round to right; couples NHJ »Stagger« to right &
    left  to meet new couple (i.e. advance passing opposite couple LSh)', 0);
INSERT INTO 'dancecrib' VALUES (3907, '2013-08-21 08:30:38.958049+00', '2023-02-04 01:18:19.388235+00', 9286, 3, NULL, 'ace', '1-8::
    1s dance down, 1L dances under 1M arm as he dances round below her &
    dance up to 2nd place BtoB in the middle facing opposite sides
9-16::
    1s set (as in Double Triangles), turn 1st corner RH, set again in
    Double Triangles & turn 2nd corners LH
17-24::
    1s reel of 3 on the sides giving RSh to 1st corners & cross to 2nd
    place own sides
25-32::
    All set 1 (PdB on R foot) & circle 6H round to left, all set (PdB on
    L foot) & circle 6H round to right', 0);
INSERT INTO 'dancecrib' VALUES (3908, '2013-08-21 08:30:38.969975+00', '2023-02-04 01:18:19.421525+00', 10820, 3, NULL, 'ace', '1-8::
    1s+3s set & change places RH (up/down), dance clockwise round the
    outside of the set back to places (ending in partner''s place).
9-16::
    2s+4s repeat
17-24::
    1L+2M & 3L+4M (taking nearer hands) Adv+Ret diagonally, 2L+3M &
    4L+1M repeat
25-32::
    All circle 8H round & back ending with Men in original places with
    new partner', 0);
INSERT INTO 'dancecrib' VALUES (3909, '2013-08-21 08:30:38.979715+00', '2023-02-04 01:18:19.484833+00', 9, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s dance 1/2 Fig of 8 round 3s
9-16::
    2s+1s dance Ladies'' Chain
17-24::
    1s lead down for 2 & up, cross up & cast to 2nd place
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (3910, '2013-08-21 08:30:38.987766+00', '2023-02-04 01:18:19.517912+00', 9101, 3, NULL, 'ace', '1-8::
    1M+3L set advancing to join RH with each other & LH with partners in
    diagonal line, Bal-in-Line, 1s+2L also 3s+2M dance LH across
9-16::
    1L+3M set advancing to join LH with each other & RH with partners,
    Bal-in-Line, 1s+2M also 3s+2L dance RH across
17-24::
    1L followed by partner casts behind 2L, cross, casts down behind 3M
    & dances up the middle with partner
25-32::
    1s dancing between 2s turn them with nearer hand, dance in & down
    between 3s & turn them with nearer hand (1.1/2 times 2nd time
    through)', 0);
INSERT INTO 'dancecrib' VALUES (5367, '2013-08-21 08:31:05.682033+00', '2023-02-04 01:20:04.914172+00', 2349, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, turn LH & cast down 1 place
9-16::
    2s+3s+1s circle 6H round & back
17-24::
    1s lead up to top & 1s+2s set twice
25-32::
    1s+2s dance 1/2 R&L, set & cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5420, '2013-08-21 08:31:06.751157+00', '2023-02-04 01:20:07.783388+00', 2445, 3, NULL, 'ace', '1-8::
    1s & 2s dance reel of 4 across (1M & 2L pass LSh)
9-16::
    1s+2s dance RH across, 1L casts below 3L _while_ 1M crosses & casts
    to 2nd place (opp side) 2s step up
17-24::
    1M crosses, casts up above 1st place & into centre _while_ 1L dances
    across set, casts up to 2nd place & into middle, 1s circle 3H round
    to left (Man with 2s & Lady with3s) to end in lines of 3 facing down
25-32::
    1M+2s also 1L+3s dance down for 3 bars, 1s drop hands & turn right
    about as 2s also 3s turn to join hands & dance up (order 1M 2s 1L
    3s), 1M casts to 2nd place as 1L dances to face him on Ladies'' side', 4);
INSERT INTO 'dancecrib' VALUES (8224, '2014-03-31 10:11:40.525011+00', '2023-02-04 01:20:07.796562+00', 15409, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place. 1s dance 1/2 Fig of 8 round 2s
9-16::
    1s+2s dance Men''s Chain
17-24::
    Repeat chain with 1L+3L crossing LH & turning partners RH
25-32::
    1s petronella turn & set, 1s turn RH 1.3/4 times to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5421, '2013-08-21 08:31:06.870727+00', '2023-02-04 01:20:07.81346+00', 7404, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance R&L
9-16::
    1L+2M+3L+4M dance RSh reel of 4 up & down the dance ending in the
    middle Ladies facing down & Men up
17-20::
    1L+2M also 3L+4M 1/2 turn RH to end in each others places on sides
    then 1M+2L also 3M+4L change places RH
21-24::
    All set, 2s cross RH as 1s+4s+3s turn RH to end in middle for
    Allemande
25-32::
    1s+4s+3s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5422, '2013-08-21 08:31:06.879039+00', '2023-02-04 01:20:07.826819+00', 2450, 3, NULL, 'ace', '1-4::
    1s & 3s turn RH, dance behind corner & meet ''opposite partner''
    between 2s/4s & join near hands
5-8::
    1s & 3s set advancing (between 2s/4s) to meet partner, Bar 6: join
    LH with partner & Lady turns to right under partner''s arm to end in
    prom hold, 1s facing 2L & 3s facing 4L
9-16::
    1s dance reel of 3 across with 2L+4M as 3s reel with 4L+2M, 1s & 3s
    drop hands & pass ''opposite partner'' RSh to face 2s/4s
17-24::
    1s+2s also 3s+4s set, dance RH across; 2M leads partner to 3rd place
    as 1M leads partner out to 2nd place _while_ 4M leads partner to 1st
    place as 3M leads partner out to 4th place.  4 1 2 3
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13157, '2020-09-15 00:19:47.955941+00', '2023-02-04 01:20:07.837945+00', 10325, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp side

1-4::
    1s+2s also 3s+4s dance 1/2 reel of 4 across (1L+2M & 3M+4L pass RSh,
    1M & 4M dance across & cast down/up to join end of 1/2 reel), 1s &
    4s 1/2 turn partner LH following into …
5-8::
    1s+4s dance 1/2 LH across, 4s+1s turn LH on sides.  (2) 4 (1) 3
9-16::
    2s+4s+1s+3s dance RSh reels of 4 on sides
17-24::
    4s+1s join RH in centre,  LH with 2s/3s & dance 1/2 RH across, 1s &
    4s face corners; all set, all 1/2 turn corner RH to end 2L followed
    by 2M & 3L followed by 3M in tandem facing corners (on 1st corner
    diagonal)
25-32::
    3s+2s dance alternating tandem reels of 3 on sides (3s pass 1M RSh,
    2s pass 4M RSh to start), 2s & 3s end in middle, 2s towards Ladies''
    side facing down, 3s towards Men''s side facing up, still in tandem
33-36::
    2s & 3s dance up/down to 1st/4th place, separate, (1s & 4s step
    down/up 35-36), 2s+3s turn partner 2H. 3 1 (4) (2)
37-40::
    All circle 8H 1/2 round to left.  End 3 1 (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (15130, '2022-10-05 00:18:23.946487+00', '2023-02-04 01:18:19.589679+00', 20792, 3, NULL, 'ace', '1-8::
    1s set, turn 2H & face down; 1s dance down & cast up round 3s to 2nd
    place own side (2s step up 5-6)
9-16::
    1s pass LSh to dance 1/2 diag reel of 4 with 1st corners, pass LSh
    to dance 1/2 diag reel of 4 with 2nd corners to end in 2nd place opp
    sides (3) (1) (2)
17-24::
    3s+1s+2s dance Set+Link for 3 couples twice.  2 1 3
25-32::
    1s+3s dance The Rosette:
::
    1s+3s join NH & set to partner, 1/2 turn partner RH remaining in
    centre facing partner; 1s+3s pull back RSh & chase clockwise 1/2
    round.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (3949, '2013-08-21 08:30:39.98405+00', '2023-02-04 01:18:23.162079+00', 73, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 3 facing 3

{{title}}
Strathspey

1-8::
    In lines of 3 all set & change places RH with opposite person &
    circle 6H round to left
9-16::
    The 2 Men set (centre dancers), cast to their right & dance a Fig of
    8 round the end Ladies to end BtoB facing other Ladies

{{title}}
Reel

17-24::
    All dance Double Triangles
25-32::
    Men dance reels of 3 with original partners giving RSh to Lady on
    right', 0);
INSERT INTO 'dancecrib' VALUES (3950, '2013-08-21 08:30:39.992077+00', '2023-02-04 01:18:23.190731+00', 74, 3, NULL, 'ace', '1-8::
    1s set & cross RH, 1s+2s Set+Link  2(1)3
9-16::
    2s+1s set & Petronella turn in Tandem to face partner up/down, 2s+1s
    Set+Link ending with Ladies in middle of a line of 4 up/down
17-24::
    2s+1s dance LSh reel of 4 up/down but 2L+1M also 2M+1L end reel
    changing places RH (order 2M+2L+1L+1M)
25-32::
    1M+2M chase clockwise 1/2 way _while_ 2L+1L turn LH, 2s 1.3/4 turn
    RH to 1st place _while_ 1s turn 1.1/4 turn RH into 3rd place  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13524, '2021-01-09 01:19:49.634913+00', '2023-02-04 01:20:08.030207+00', 17701, 3, NULL, 'ace', '1-8::
    All dance Grand Chain
9-10::
    1s+2s+3s set
11-16::
    1s+2s dance La Girandole:
::
    _9-12_    1s+2s join hands & set, 1L+2M 3/4 turn RH _while_ 1M+2L
    pull back LSh & cast down/up to finish 1s on Men''s side & 2s on
    Ladies'' side, Ladies above Men
::
    _13-16_  1s+2s dance RH across 3/4 way & cross RH to own sides 2 1 3
17-24::
    1s dance Corner Pass+Turn with 1st corners, pass RSh & dance Corner
    Pass+Turn with 2nd corners, pass RSh to own sides
25-32::
    1s+3s turn 3/4 2H in line in middle (M face up, L face down). 1s+3s
    dance 1/2 reel of 4, 3s+1s turn 3/4 2H to own sides 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5423, '2013-08-21 08:31:06.887103+00', '2023-02-04 01:20:08.055225+00', 9205, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-8::
    1s+2s also 3s+4s circle 4H round to left; 1s+2 also 3s+4s set to
    each other on sides & 1s+4s dance in  & cast 1 place (2s & 3s dance
    up/down to ends & face out)
9-16::
    1M+4L also 1L+4M in prom hold dance reels of 3 on sides (RSh to
    3L/2L)
17-24::
    1M+4L also 1L+4M in prom dance round each other LSh to change places
    & 1s+4s dance LH across.  2 4(1)(3)
25-28::
    Dancing couples cross LH to give RH to partner, 1s cross up & cast
    to 2nd place _while_ 4s cross down & cast to 3rd place opp side
29-32::
    Dancing couples again cross LH to give RH to partner, 4s cross up &
    cast to 2nd place _while_ 1s cross down & cast to 3rd place opp side
    ending 2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (5424, '2013-08-21 08:31:06.895591+00', '2023-02-04 01:20:08.087785+00', 2453, 3, NULL, 'ace', '1-8::
    1L+2M also 3L+4M set facing diagonally, Ladies cast 1 pl as Men cast
    up & dance into centre (1M & 2L also 3M & 4L step down/up 1/2 pl),
    top 4 dancers also bottom 4 dance RH across
9-16::
    2M+1L+4M+3L dance 1/2 reel of 4 up/down centre, top 4 dancers also
    bottom 4 dance RH across 1.1/4 times to bring other dancers into
    centre
17-24::
    1M+2L+3M+4L dance 1/2 reel of 4 in centre, top 4 dancers also bottom
    4 dancers dance RH across to end with 4s+3s+2s in centre for
    Allemande
25-32::
    4s+3s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (12080, '2019-08-30 09:54:15.870606+00', '2023-02-04 01:20:08.113775+00', 19230, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up), turn LH to face 1st corners
9-16::
    1s turn corner RH, partner LH, 2nd corner RH & cross LH to 2nd place
    own side
17-20::
    2s+3s turn partners 2H to end in middle NHJ, 2s facing down, 3s
    facing up
21-24::
    2s+3s set, 2s dance under arch made by 3s who dance up, 2s+3s remain
    in centre Bar 24: 2s face up, 1s Adv to centre facing up, ready for
    …
25-32::
    3s+1s+2s dance allemande.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5426, '2013-08-21 08:31:06.911671+00', '2023-02-04 01:20:08.189536+00', 10895, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & turn LH 1.1/4 times to end in centre
9-16::
    1s dance RH across (Man with 2s & Lady with 3s), pass LSh & RH
    across on sides (Man with 2M+3M & Lady with 2L+3L) & pass LSh to…
17-24::
    1s dance RH across (1L with 2s & 1M with 3s), pass LSh to dance RH
    across on sides (1L with 2M+3M & 1M with 2L+3L) & end facing 2nd
    crnrs
25-32::
    1s dance Pass+Turn with 2nd corners, turn RH to dance Pass+Turn with
    1st corners ending in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (14525, '2022-01-10 02:19:22.923825+00', '2023-02-04 01:20:08.311282+00', 18772, 3, NULL, 'ace', '{{title}}
Start

::
    ········3M
::
    2L·····2M
::
    1L·····1M
::
    ····Top
1-8::
    1s set, cast (2s step up); 1s set & turn LH to 1M facing 2L with 1L
    following
9-16::
    1s in tandem dance RSh reel of 3 across with 2s (RSh to 2L to
    start). At end of reel 1L takes lead & faces 3M
17-24::
    1s in tandem dance RSh reel of 3 with 2M+3M (RSh to 3M to start). 1s
    end in 2nd place own side
25-32::
    1s turn RH; All set, 1M cast to 3rd place _while_ 3M steps up', 0);
INSERT INTO 'dancecrib' VALUES (5429, '2013-08-21 08:31:06.936072+00', '2023-02-04 01:20:08.338188+00', 9813, 3, NULL, 'ace', '1-8::
    1s lead down the middle & up to 2nd place _while_ 2s (ghosts) follow
    1s to bottom & cast up on own sides to 1st place
9-16::
    1s dance DoSiDo & all turn partners RH (long turn)
17-24::
    1s+3s+4s dance reels of 3 on sides (1s in & down to start) _while_
    2s follow 1s as ghosts
25-32::
    1s dance in passing partner RSh to BtoB position with hands joined,
    turn round to right & dance out own side & cast to 4th place', 0);
INSERT INTO 'dancecrib' VALUES (14718, '2022-04-01 00:18:26.914405+00', '2023-02-04 01:18:23.221755+00', 17410, 3, NULL, 'ace', '1-8::
    1s set, dance in & cast 2 place; 1s cross up to 2nd place opp sides
    & face out (2s step up 5-6)
9-16::
    2s+1s+3s dance reels of 3 on sides giving hands (1s out/up, 2s
    in/down, 3s in/up). 1s finish facing 1st corners
17-24::
    1s set to & turn 1st corner RH, pass LSh, set to & turn 2nd corner
    LH, finish in centre facing partner (Man facing down & Lady facing
    up)
25-32::
    1s 3/4 turn 2H, pull back RSh & dance out to 2nd place own sides.
    2s+1s+3s turn 2H.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14651, '2022-03-07 02:19:48.158405+00', '2023-02-04 01:20:08.374471+00', 20521, 3, NULL, 'ace', '{{explanation}}
6 person hexagonal set, 1st person facing down, 4th person facing up

{{title}}
Start

::
    ·····4
::
    _3_········5
::
    _2_········6
::
    ·····1
::
    ···Top
1-8::
    _1_+4 dance Figs of 8 round 2 dancers on their right (1 & 6+5, 4 &
    3+2)
9-16::
    _3_+6 dance Figs of 8 round 2 dancers on their right (3 & 2+1, 6 &
    4+5). On bar 16, 2+6 dance into middle to face up _while_ 3+5 dance
    into middle to face down.
17-24::
    _2_+6 also 3+5 join hands to form arches. All set, 1 changes place
    with 2+6 by dancing under arch _while_ 4 changes place with 3+5. All
    repeat back to original places facing clockwise
25-32::
    All chase clockwise 1/2 way for 4 bars, cross right foot over &
    chase back to finish 1 place clockwise (1 is now in position 2 etc)', 0);
INSERT INTO 'dancecrib' VALUES (5430, '2013-08-21 08:31:07.060138+00', '2023-02-04 01:20:08.558439+00', 13001, 3, NULL, 'ace', '1-8::
    1L dances RH across with 3s _while_ 1M dances LH across with 2s, all
    set to partner & turn RH
9-16::
    Men dance RSh round partners & dance RH across back to place
17-24::
    Ladies dance LSh round partners & dance LH across back to place &
    face out
25-40::
    All dance full Schiehallion Reel (all end 1 place on round set)
41-48::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5431, '2013-08-21 08:31:07.06838+00', '2023-02-04 01:20:08.592294+00', 2462, 3, NULL, 'ace', '1-8::
    All cross RH & chase clockwise to own sides
9-16::
    4s+3s also 2s+1s dance RH across & LH back
17-24::
    1s dance up to top & cast into 1st place, all turn RH into allemande
    hold
25-32::
    All dance 4 couple Allemande to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5432, '2013-08-21 08:31:07.078217+00', '2023-02-04 01:20:08.628714+00', 2464, 3, NULL, 'ace', '1-8::
    1s & 4s dance in & cast to 2nd/ 3rd place (2s & 3s step up/down);
    1s+4s dance LH across
9-16::
    2s+1s also 4s+3s dance double Figs of 8 (2s cross down & 3s cross
    up, 1s dance up & 4s dance down to start)
17-24::
    All set,  1s+4s dance RH across 1/2 way; all set,  4s & 1s cross RH
25-32::
    2s+4s also 4s+3s dance Diamond Poussette.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5433, '2013-08-21 08:31:07.213707+00', '2023-02-04 01:20:08.654642+00', 13910, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 on own sides (in & down to start)
9-16::
    All petronella turn & set to opposite sides
17-24::
    All chase clockwise back to own sides, all turn RH
25-32::
    3s+2s dance Allemande to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5434, '2013-08-21 08:31:07.222296+00', '2023-02-04 01:20:08.672812+00', 11455, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s cross down to & set to 1st corners _while_
    2s cast up
9-12::
    1s+1st corners change places passing LSh & corners turn RH to face
    2nd corner pstns _while_ all corner persons chase anticlockwise 1
    place
13-16::
    1s+1st corner persons change places passing LSh & 1s 1/2 turn RH to
    face 4th corner pstns _while_ all corner persons chase anticlockwise
    1 place
17-20::
    1s+corner persons change places passing LSh & 2L+3M turn RH to face
    1st corner pstns _while_ all corner persons chase anticlockwise 1
    place
21-24::
    1s+corner persons change places passing LSh & turn RH to face 2nd
    corner pstns _while_ all corner persons chase anticlockwise 1 place
    (orig pls)
25-32::
    1s set to 2nd corners & turn RH to 2nd places own side, 1s+3s dance
    RH across', 0);
INSERT INTO 'dancecrib' VALUES (12552, '2020-02-02 02:47:57.427036+00', '2023-02-04 01:20:08.697332+00', 2465, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across, 1s cast & 2s dance up to top & face out
9-16::
    Reels of 3 on sides, 2s cast, 3s out/up, 1s in/down to start.  1s
    pass LSh to face 1st corners
17-24::
    ''Hello-Goodbye'' setting.  1s end BtoB, 1M facing 2s, 1L facing 3s
25-32::
    1M+2s & 1L+3s dance RH across. 1s end in 2nd place opp side; 1s turn
    RH 1.1/2 to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15065, '2022-09-05 00:19:52.207571+00', '2023-02-04 01:20:08.748719+00', 20914, 3, NULL, 'ace', '1-4::
    1s+2s also 3s+4s dance 1/2 R&L (no polite turns), 2L & 3M face out
5-8::
    2L followed by 2M also 3M followed by 3L chase anticlockwise 1/2
    round to opp end _while_ 1s+4s dance RH across remaining in centre
9-16::
    1s+4s give LH to nearest corner & dance Spoke moving clockwise once
    round & remain in centre
17-24::
    1M followed by 1L also 4L followed by 4M dance RSh Tandem reels on
    sides (1s out/ down Ladies'' side, 4s out/up on Men''s side).  End 1s
    between 3s at top facing down, 4s between 2s at bottom facing up
25-32::
    1s dance down under arch made by 4s who dance up, turn corners with
    free hand & change places RH on  side (polite turns), all 4 couples
    set.  End 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (14206, '2021-08-14 00:19:54.430914+00', '2023-02-04 01:20:08.777184+00', 12256, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, meet NHJ dance down between 3s, cast up into
    2nd place (2s step up bars 3-4)
9-12::
    1s turn LH (4 bars) _while_ 2L/3M followed by partner cast down/up 2
    places & cross to opposite sides (3) 1 (2)
13-16::
    1s dance RH across (1M with 2s & 1L with 3s)
17-24::
    1s turn LH _while_ 2s+3s chase clockwise 1/2 way back to original
    places; 1s dance RH across (1L with 2s, 1M with 3s).  2 1 3
25-32::
    1s cross passing RSh to dance RSh reels on opposite sides (1M RSh to
    3L, 1L RSh to 2M). On bars 31-32 1M crosses down from top to 2nd
    place own side _while_ 1L crosses up from bottom to 2nd place. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5435, '2013-08-21 08:31:07.243663+00', '2023-02-04 01:20:08.808374+00', 11299, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Diamond Poussette
9-16::
    1s+2s also 3s+4s set & petronella-in-tandem 1 place (1s+3s on Men''s
    side & 2s+4s on Ladies), all dance 1/2 reels of 4 on sides
17-24::
    Repeat bars 9-12 but set across the set & petronella-in-tandem to
    end on sides, all dance 1/2 reels of 4 on sides (back to original
    places)
25-32::
    1s+2s cross RH & dance 1/2 RH across, 1s+3s cross RH & dance 1/2 RH
    across
33-40::
    1s+4s dance Espagnole:
::
    _33-34_   1s+4s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _35-36_   1s+4s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _37-40_   4s turn RH as 1s turn LH', 0);
INSERT INTO 'dancecrib' VALUES (5436, '2013-08-21 08:31:07.253653+00', '2023-02-04 01:20:08.88517+00', 2469, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd place)
9-16::
    2s+1s+3s dance reels of 3 on sides (1s pass 3s by LSh to start). At
    end 2L & 1M face out
17-24::
    2s+1s dance RH across, 1s+3s dance LH across
25-28::
    2s+1s+3s set advancing to form circle (no hands), set turning right
    about  on the spot
29-32::
    All dance 1/2 RH across (2 bars), drop hands & chase clockwise round
    to places', 0);
INSERT INTO 'dancecrib' VALUES (3914, '2013-08-21 08:30:39.082984+00', '2023-02-04 01:18:19.935636+00', 18, 3, NULL, 'ace', '{{explanation}}
Longways set in Glasgow Highlanders positions

1-8::
    2L followed by 1M dance also 3L followed by 4M dance Figs of 8 on
    sides round 2M+4L/3M+1L (dancing in front of partners to start)
    ending with 2L+1M at top facing down & 3L+4M at bottom facing up
9-16::
    All set twice (in sq formation), turn ''corners'' (Men RH & Ladies LH)
    to end on sides (Men''s side 2L 1L 3M 4M & Ladies'' side 1M 2M 4L 3L)
17-24::
    1L followed by 3M also 4L with 2M dance Figs of 8 across round
    1M+2L/4M+3L & back to each other''s place (2L 3M 1L 4M & 1M 4L 2M 3L)
25-32::
    Two middle couples set & dance RH across 1/2 way, all set & cross to
    original places
33-40::
    All set & dance "La Baratte" with the opposite person:
::
    Men 1/2 turn Lady RH & retain hands but at arm''s length from each
    other
::
    Men retrace steps with Lady turning right under Man''s arm briefly
    into Allemande hold (Man behind Lady facing Ladies'' original place)
    & releasing Ladies'' RH, she turns under Man''s left arm until almost
    in original places & then they change places LH to opposite places
41-48::
    All In prom hold with partner promenade 1/2 way round clockwise,
    3s+4s (at top) also 1s+2s dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (14490, '2021-12-18 01:44:10.359512+00', '2023-02-04 01:20:08.904752+00', 15528, 3, NULL, 'ace', '1-8::
    1s set, cross down RH, cast behind 3s, meet briefly taking NH &
    dance up behind 2s to 1st place opp sides
9-16::
    1s+3s dances Ladies'' Chain up/down centre finishing 1s full turn, 3s
    1/2 turn to end in centre facing up, 2s step in & all take prom hold
17-24::
    1s+2s+3s dance Promenade, ending with 1s casting to 2nd place to
    face 1st corners, 2s dancing up to 1st place.  2 1 3
25-32::
    1s dance ''Hello-Goodbye'' setting ending with Petronella turn to 2nd
    place own side', 0);
INSERT INTO 'dancecrib' VALUES (5437, '2013-08-21 08:31:07.261733+00', '2023-02-04 01:20:08.922626+00', 2472, 3, NULL, 'ace', '1-8::
    1s cross down RH to 2nd place, dance down to 3rd place & set _while_
    2s cast up, set & cross RH down to 2nd place _while_ 3s set, cross
    LH up to 2nd place & dance up to top, all cross RH to own sides.  3
    2 1
9-16::
    Repeat from new pstns back to original places
17-24::
    1s+2s+3s circle 6H round & back
25-32::
    1s+2s Set+Link, 1s+3s Set+Link', 0);
INSERT INTO 'dancecrib' VALUES (5438, '2013-08-21 08:31:07.271595+00', '2023-02-04 01:20:08.946924+00', 13687, 3, NULL, 'ace', '{{explanation}}
Dance 3 times Strathspey & 3 times Reel

1-8::
    1s+2s dance Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH to face 1st corners
9-16::
    1s turn 1st corner, partner, 2nd corner & partner
17-24::
    1s reels of 3 on opp sides, Lsh to 1st corners to start
25-32::
    1s turn RH, cast, 1/2 fig of 8 through 3s', 0);
INSERT INTO 'dancecrib' VALUES (13895, '2021-04-05 00:19:51.587464+00', '2023-02-04 01:20:08.972179+00', 20080, 3, NULL, 'ace', '1-8::
    All dance Interlocking R&L (1s+3s cross RH, 2s+4s change places RH
    with partner on sides to start)
9-16::
    All chase 1 place clockwise (2 bars), turn partner 2H (2 bars); all
    turn corner RH (4 bars)
17-24::
    All dance Double Ladies'' Chain (Ladies dancing 1/2 RH across in
    centre)
25-32::
    All circle 8H round to left (3 bars), pivot (pull back RSh); all
    chase anticlockwise back to end 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (9731, '2017-04-06 08:39:46.98614+00', '2023-02-04 01:20:08.993214+00', 2475, 3, NULL, 'ace', '{{explanation}}
2s start on opposite sides

1-8::
    All set on sides, dance Do-Si-Do with partners, all set
9-12::
    All Men dance RH Across
13-16::
    All Ladies dance LH Across, finishing facing out
17-24::
    All set, NHJ in ''circle'' (Triple Triangles). All change places RH to
    »invert« (Men facing out, Ladies facing in), Set, change places LH
    to »invert« (Men facing in, Ladies out)
25-32::
    All set, all change places with RH, all set, all change places LH
    into circle, all facing in 3 (1) 2
33-40::
    Circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5439, '2013-08-21 08:31:07.281577+00', '2023-02-04 01:20:09.020765+00', 13309, 3, NULL, 'ace', '1-8::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L
9-16::
    All Men dance RH across finishing in places, all Ladies dance LH
    across finishing in middle facing partners
17-24::
    1s+3s also 2s+4s dance double reels of 4 (all give LH in centre)
25-32::
    All dance Circle Knot:
::
    _25-26_  Couples turn ptnrs RH 1/2 way to end facing anticlockwise
    in Allemande position, the Lady having turned clockwise under her
    ptnrs arm
::
    _27-28_  All promenade anticlockwise 1 place round
::
    _29-30_  Couples drop Right hands, ladies dancing in to middle of
    set
::
    _31-32_  All couples turn partners LH to new position facing in', 0);
INSERT INTO 'dancecrib' VALUES (15331, '2022-12-19 01:19:57.443542+00', '2023-02-04 01:20:09.055658+00', 21126, 3, NULL, 'ace', '{{explanation}}
5 person Sq.Set with 5th person in centre facing top

{{title}}
Start

::
    _3_·····4
::
    ···5
::
    _2_·····1
::
    ··Top
1-2::
    Dancers 1+2+5 join hands in the triangle & set
3-4::
    Dancer 5 1/2 turns right about (2 PdeB) to face 3+4 dancers
5-6::
    Joining hands 5+3+4 set
7-8::
    Dancer 5 1/2 turns right about to face 1+2 dancers
9-16::
    Dancers 5+1+2 dance RH across; 5+3+4 dance LH across (5 retains LH
    with 3 & joins RH with 1)
17-24::
    Dance the Spoke (all 5 dancers dance 8 bars PdeB):
::
    _17-18_  5 balances in line with 1+3, moves on to 4+2
::
    _19-24_  5 balance in line with 4+2, moves on to balance in line
    with 3+1, moves on to balance in line 2+4 to finish facing 1
25-26::
    _5_+1 change places RH
27-28::
    _1_+2 change places LH
29-30::
    _2_+3 change places RH
31-32::
    _3_+4 change places LH. 4th dancer becomes the new 5th dancer', 0);
INSERT INTO 'dancecrib' VALUES (8584, '2015-02-13 12:47:46.483007+00', '2023-02-04 01:20:09.083224+00', 15567, 3, NULL, 'ace', '1-8::
    1s dance down the middle, cast up round 3s back to their places, and
    set to each other.
9-16::
    1s, 2s and 3s dance mirror Reels of 3 on the sidelines, 1s starting
    in.
17-24::
    1s and 3s turn partner RH ; repeat LH.
25-28::
    1M and 2L change places, giving RH, 1L and 2M repeat ;
29-32::
    1s and 2s set and cross over RH', 0);
INSERT INTO 'dancecrib' VALUES (5440, '2013-08-21 08:31:07.375791+00', '2023-02-04 01:20:09.103908+00', 9819, 3, NULL, 'ace', '1-8::
    2s set, 1/2 turn RH, lead up, cross & cast to own places
9-16::
    2s followed by 1s dance Fig of 8 round 3s to end 2 1 3
17-24::
    1s dance RH across (Lady with 2s & Man with 3s) & pass RSh to dance
    LH across with other couple
25-32::
    1s dance reels of 3 across (Lady LSh to 2M & Man LSh to 3L to start)
    & end 2nd place own sides
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12535, '2020-02-02 02:46:38.762018+00', '2023-02-04 01:18:19.967864+00', 20, 3, NULL, 'ace', '1-8::
    1s dance down NHJ & cast up into 4th place (2s+3s+4s step up 3-4);
    1/2 reels of 4 on sides (Men RSh, Ladies LSh)
9-16::
    All set, 1s+2s cast down/up 1 place (3s/4s step down/up 11-12) to
    end 4 1 2 3;  1s+2s circle 4H round to left
17-20::
    1L+4M, 3L+2M set, 3/4 turn 2H to end BtoB up/down centre, Ladies
    pull back RSh to face partner _while_ 1M, 4L, 3M & 2L cross dance &
    cast to face partner in centre
21-24::
    All set, turn RH into promenade hold facing up
25-32::
    _4_ couple Allemande.', 0);
INSERT INTO 'dancecrib' VALUES (3953, '2013-08-21 08:30:40.022916+00', '2023-02-04 01:18:23.309205+00', 9581, 3, NULL, 'ace', '1-8::
    1s+2s set, turn partner 2H & circle 4H round to left
9-16::
    1s+2s+3s RSh reels of 3 on sides
17-24::
    1L followed by partner cast 1 place, cross down between 3s, cast up
    to 2nd place on Men''s side & 1L crosses over to own side
25-32::
    2s+1s+3s dance the Knot to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (13303, '2020-11-02 01:19:56.136498+00', '2023-02-04 01:20:09.123466+00', 17617, 3, NULL, 'ace', '1-8::
    1L+2L, 3L+4L & 2M+3M change places RH on sides & all 4 couples set;
    top 2 couples & bottom 2 couples dance RH across
9-16::
    Top 2 couples & bottom 2 couples dance R&L
17-24::
    Top 2 couples & bottom 2 couples circle 4H round & back, stay in
    middle facing up, ready for …
25-32::
    Top 2 couples & bottom 2 couples dance Allemande

{{explanation}}
Note:	All change partners after bar 2', 0);
INSERT INTO 'dancecrib' VALUES (5441, '2013-08-21 08:31:07.384143+00', '2023-02-04 01:20:09.144365+00', 2491, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, 1s+2s also 3s+4s dance 1/2 double Fig of 8  (1s &
    4s cast to start), 2s & 3s cross RH.  1 2 3 4
9-16::
    1s+2s also 3s+4s dance RH across, all dance 1/2 RSh reels of 4 on
    sides (2s+3s to end passing RSh).  4 3 2 1
17-24::
    3s dance Diag R&L  (2)3(4)1
25-32::
    2s & 4s set & 1/2 turn RH, 2s & 4s dance NHJ down & cast back to
    place  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5442, '2013-08-21 08:31:07.470086+00', '2023-02-04 01:20:09.175862+00', 10151, 3, NULL, 'ace', '1-8::
    1L+2M change places RH, 1M+2L change places RH, 2s & 1s cross RH &
    2s+1s+3s set
9-16::
    1s dance RH across (Lady with 2s & Man with 3s) & 1s turn LH 1.1/2
    times to end facing out
17-24::
    1s dance reels of 3 across (1s pass 2nd corners LSh to start) & 3/4
    turn RH to 2nd places own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5443, '2013-08-21 08:31:07.498211+00', '2023-02-04 01:20:09.401282+00', 2492, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s dance R&L 1/2 way, 1s dance down middle divide & loop round
    into 4th place opp side as 3s & 4s cast up 1 pl & dance in to face
    corners
9-16::
    All set & turn corners RH, 3s+4s dance LH across to end on own sides
    (2)3 4(1)
17-24::
    All dance reels of 4 on sides
25-28::
    2s & 1s petronella turn into middle & end 2L between 3s (facing up)
    as 1M ends between 4s (facing down) & all set
29-32::
    2s & 1s petronella turn to own sides & all set  2 3 4 1

{{explanation}}
Reel:- with new top couple

1-8::
    1s petronella turn & set as 2s cast up, 1s+2s dance RH across with
    1s ending between 2s facing opposite sides
9-16::
    1s+2s dance reel of 4 across & 1s pass RSh to end in middle on
    opposite sides diagonally facing 3s
17-24::
    1L+3M turn LH as 1M+3L turn RH & 1s dance round each other LSh to
    face 4s, 1s repeat bars 17-20 with 4s & end on own sides
25-32::
    2s+3s also 4s+1s dance Figs of 8 across with 2s & 4s crossing down
    as 3s & 1s cross up  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5444, '2013-08-21 08:31:07.506425+00', '2023-02-04 01:20:09.42473+00', 2494, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s 3/4 turn 2H, dance 1/2 reel of 4 in centre of dance, turn 2H
    end in lines across 1M between 2s & 1L between 3s all facing down
9-16::
    All dance down, turn right about & dance back & 1M+2s turn to face
    1L+3s

{{title}}
Reel

1-8::
    All clap & 1s dance 1/2 reels of 3 on opp sides (1M pass 3L RSh & 1L
    passes 2M RSh), 1s turn RH to end 1M between 2s & 1L between 3s
9-16::
    All clap & 1s dance 1/2 reels of 3 on opposite sides [1M passes 3L
    (3s at top) LSh & 1L passes 2M LSh], 1s turn LH to places', 0);
INSERT INTO 'dancecrib' VALUES (5445, '2013-08-21 08:31:07.52507+00', '2023-02-04 01:20:09.523989+00', 2495, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH across back to places
9-16::
    1s+2s+3s dance RH across & LH back to places
17-24::
    1s lead down the middle & back to 2nd place
25-32::
    2s followed by 1s+3s lead down the middle & cast back to places', 0);
INSERT INTO 'dancecrib' VALUES (5446, '2013-08-21 08:31:07.533391+00', '2023-02-04 01:20:09.548018+00', 2497, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH moving down to 2nd place, 1s set, 3/4 turn LH & dance
    LSh round 1st corner to 2nd place on opposite sides
9-16::
    1s+1st corners facing diagonally Adv+Ret, advance passing opposite
    person RSh, 1M followed by 3L dance up to top, divide & cast to end
    1M beside 2nd corner & 3L in 1M place _while_ 1L followed by 2M
    dance between 3s divide & cast 1L to 2nd place opp sides & 2M to 3L
    place
17-24::
    1s+2nd corner Adv+Ret, advance passing opposite person by LSh, 1L
    followed by 3M dance up to top, divide & cast to end 1L 2nd pl opp
    side & 3M in 1L place _while_ 1M followed by 2L dance between 3s
    divide & cast 1M is in 2nd place opp side & 2L in 3M place
25-32::
    3s+1s+2s dance 1/2 reel of 3 on sides (1s give RSh to person on
    their right to start) & 1/2 reels of 3 across (1M with 2s & 1L with
    3s)', 0);
INSERT INTO 'dancecrib' VALUES (5447, '2013-08-21 08:31:07.543405+00', '2023-02-04 01:20:09.574521+00', 12879, 3, NULL, 'ace', '{{explanation}}
2 Ch - Honour Partner & Corner

1-8::
    1L+3L dance 3/4 round each other LSh _while_ 2L & 4L cast round
    partners to face 1L/3L & dance 1/2 reel of 4 across, Ladies 1/2 turn
    corner RH
9-12::
    All Men dance LH across 3/4 way _while_ Ladies dance clockwise 1/4
    way & 1/2 turn corner person RH
13-16::
    All Ladies dance LH across 3/4 way _while_ Men dance clockwise 1/4
    way & 1/2 turn corner person RH
17-24::
    Repeat bars 9-16 but end with 1/4 turn RH with Men in original
    places with corner person on their right
25-28::
    1M+3M 3/4 turn RH & then 1M+4M & 3M+2M 1/2 turn LH (1s & 3s now on
    sides)
29-32::
    2M+4M 3/4 turn RH to all end beside partners (1 place to right of
    original places), all set (Ladies turning to face out)
33-48::
    Ladies dance Schiehallion Reel (casting into partner''s place to
    start) _while_ Men dance full interlocking reels of 4 across twice
    (LH across in centre)

{{explanation}}
Ladies pull back LSh on bars 32 and 80 (into Schiehallion reels in strathspey time), and RSh on bars 128 and 176 (into Schiehallion reels in reel time)', 0);
INSERT INTO 'dancecrib' VALUES (3915, '2013-08-21 08:30:39.093089+00', '2023-02-04 01:18:20.001349+00', 22, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, dance down between 3s & cast to face 1st
    corners
9-16::
    1s dance 1/2 reel of 4 with 1st corners,1s 1/2 turn LH with partner
    giving RH to 3rd corner (pstn) Bal-in-Line & turn LH to face 2nd
    crnrs
17-24::
    Repeat above Fig with 2nd corners
25-28::
    1s dance out own side & cast round 3rd corner to face up/down dance
    as 2s & 3s cross RH, set to partner & to other corner on sides (1
    step each)
29-32::
    1s change places RH (up/dn) & cast round 4th corner to 2nd place own
    sides as 2s+3s change places RH on sides, setting to crnr on sides &
    ptnr', 0);
INSERT INTO 'dancecrib' VALUES (15310, '2022-12-19 01:18:18.063994+00', '2023-02-04 01:18:20.036909+00', 21175, 3, NULL, 'ace', '1-4::
    1s+2s 1/2 turn partner RH and dance 1/2 RH across. 2 1 3
5-8::
    1s+3s 1/2 turn partner RH and dance 1/2 RH across. 2 3 1
9-12::
    1s cross RH & cast up 1 place (3s step down 11-12). 2 (1) 3
13-20::
    2s+1s+3s dance mirror (reflection) reels of 3 on sides (2L+1M pass
    RSh, 2M+1L pass LSh to begin)
21-24::
    1s cross RH & cast up 1 plasce (2s step down 23-24). 1 2 3
25-26::
    1L+2L change places LH _while_ 1M+2M change places RH. 2 1 3
27-28::
    All join hands on sides and set.
29-32::
    All turn partner RH. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3918, '2013-08-21 08:30:39.125808+00', '2023-02-04 01:18:20.381024+00', 14828, 3, NULL, 'ace', '1-8::
    1s+2s set advancing to face up then cast 2 steps behind 3s (2s
    leading) & turn outwards, 1s dance up to 2nd place & 1/2 turn RH
    into promenade hold facing down as 2s dance up to top
9-16::
    1s passing 3M RSh dance a diagonal reel of 3 with 2L
17-24::
    1s set to 3M & set to each other, set to 2L & set to 1st corners
25-32::
    1s dance a diagonal reel of 4 with 1st corners ending in 2nd place
    on own sides', 0);
INSERT INTO 'dancecrib' VALUES (8296, '2014-07-29 12:58:40.314918+00', '2023-02-04 01:18:23.420856+00', 15339, 3, NULL, 'ace', '1-8::
    1s lead down crossing below 3s & cast up to 2nd place opposite
    sides, lead up to top crossing & cast to 2nd place own sides
9-16::
    1s petronella turn into lines across & all set, 1s dance RSh round
    1st corners _while_ 1st corner persons set & change places RH
17-24::
    1s petronella turn to opposite sides & all set, 1s dance RSh round
    2nd corners _while_ 2nd corner persons set & change places RH
25-32::
    3s+1s+2s Set+Link twice', 0);
INSERT INTO 'dancecrib' VALUES (5449, '2013-08-21 08:31:07.561784+00', '2023-02-04 01:20:09.735815+00', 2499, 3, NULL, 'ace', '1-8::
    1s+3s dance RH across 1.1/4 times to end BtoB facing side couples,
    1s facing 2s, 3s facing 4s. 1s+2s also 3s+4s dance RH across
9-16::
    All dance parallel reels of 4 across
17-24::
    1s+2s also 3s+4s dance the Rondel to change places (2s & 4s make
    arch) 1s end in 2nd place, 3s in 4th place, 2s facing 4s in centre
25-32::
    2s+4s circle 4H round to left 3/4 way to end 2s in 1st place & 4s in
    3rd place. All set to partners & turn RH
33-64::
    Repeat bars 1-32 with 1s & 2s also 3s & 4s reversing roles to end
    all back in original places, facing partner
65-72::
    All dance interlocking RSh reels of 4 & end turning partner 1/4 RH
    to bring Men into centre facing partners
73-80::
    All set, Ladies dance in as Men dance out passing LSh & Ladies
    circle 4H round to left, pulling back RSh to face partners
81-88::
    All dance Double Reels of 4 across (1/2 LH across in centre). End
    Men on sides, Ladies in centre facing partner
89-96::
    Men start circle Left with Ladies dancing out to join in circle (2
    bars). All turn partners 2H & then continue circle left to original
    places', 0);
INSERT INTO 'dancecrib' VALUES (5450, '2013-08-21 08:31:07.569827+00', '2023-02-04 01:20:09.763034+00', 2501, 3, NULL, 'ace', '1-8::
    1M sets to 2L & casts to 2nd place _while_ 2L casts up to 1st place
    (2M steps up as 1L steps down), 1M & 2L turn 2H & return to new
    places
9-16::
    2M & 1L repeat above 8 bars
17-24::
    1s+2s set, 1s cross RH & cast round 2s to join hands in line of 4
    with 2s (facing up), dance up to top & 1s end BtoB facing 2s on
    opposite sides
25-32::
    1s+2s set, 1s petronella turn (L face down & M up) as 2s set, 1s
    dance towards each other, lead up to top of set & cast down to 2nd
    place', 0);
INSERT INTO 'dancecrib' VALUES (5451, '2013-08-21 08:31:07.579594+00', '2023-02-04 01:20:09.780305+00', 12880, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Figs of 8 (Lady round2s & Man
    round 3s) & end facing 2nd corners
9-16::
    1s dance 1/2 RSh reel of 3 across & 1/2 reels of 3 on opposite sides
    & end facing 3rd corners (pstn)
17-24::
    1s set to 3rd corners & turn 2H, set to 4th corners (pstn) & turn 2H
    ending 2nd place own sides
25-32::
    1s dance Diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (5452, '2013-08-21 08:31:07.589259+00', '2023-02-04 01:20:09.882833+00', 2504, 3, NULL, 'ace', '1-8::
    1s dance in & with nearer hands joined set to 2M, taking RH lead
    round to right & with nearer hands joined set to 2L
9-16::
    1s turn RH & turn LH
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (5453, '2013-08-21 08:31:07.597257+00', '2023-02-04 01:20:09.915718+00', 12523, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1L+2L set, cross passing partner RSh & chase clockwise to own sides
    to change places similarly 3L+4L dance likewise
9-16::
    1M+2M set, cross passing partner LSh & chase anticlockwise to own
    sides to change places _while_ 3M+4M dance likewise
17-20::
    2s+1s also 4s+3s dance LH across
21-22::
    1M+4M change places RH
23-24::
    1L+4L change places LH
25-32::
    All dance RSh reels of 4 on sides (1s+4s pass RSh at end)', 0);
INSERT INTO 'dancecrib' VALUES (9718, '2017-04-06 08:39:24.884716+00', '2023-02-04 01:18:20.41749+00', 32, 3, NULL, 'ace', '1-8::
    All 4 couples set, 1s+2s & 3s+4s change places RH. All set, cross
    RH.   (2) (1) (4) (3)
9-16::
    2s+1s & 4s+3s face diagonally in, all set then petronella turn 1
    place round.  Repeat to end in original places
17-24::
    1M+2L & 3M+4L change places RH.  Middle couples (1M+3L+2M+4L) dance
    LH across _while_ end couples turn LH. 1M+2L & 3M+4L change places
    RH back to original places
25-32::
    1L followed by 2L+3L+4L dances down middle & back up own side to
    place _while_ 4M followed by 3M+2M+1M dances up middle & down own
    side to place
33-40::
    1L+2M & 3L+4M change places LH. Middle couples (1L+2L+4M+3M) dance
    RH across _while_ end couples turn RH. 1L+2M & 3L+4M change places
    LH back to original places
41-48::
    4s followed by 3s+2s+1s lead down (2 steps), 1s followed by 2s+3s+4s
    lead up (2s steps).  1s cast to 4th place as 2s+3s+4s set & dance up
    1 place. End  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8026, '2013-09-09 06:47:25.894119+00', '2023-02-04 01:20:09.941077+00', 10232, 3, NULL, 'ace', '1-8::
    1s+2s set & dance 1/2 RH across, 1s+3s set & dance 1/2 LH across
9-16::
    1s set & cross RH, 1s cast up 1 place & turn LH turn to face 1st
    corners (pstns)
17-20::
    1s dance 1/2 reel of 4 with 1st crnrs (pstns) & pass left to face
    2nd crnrs (pstns)
21-24::
    1s dance 1/2 reel of 4 with 2nd crnrs (pstns) & curve right to end
    1M between 3s facing down & 1L btwn 2s facing up
25-32::
    1M+3s also 1L +2s Set+Link for 3 once, 1s turn RH 1.1/2 times to 2nd
    place as 2s & 3s dance clockwise 1/2 way to places  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5454, '2013-08-21 08:31:07.6053+00', '2023-02-04 01:20:09.959067+00', 2506, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 double Fig of 8, 1L+2L & 1M+2M turn on sides (Men LH
    Ladies RH)
9-16::
    1s+2s dance 1/2 double Fig of 8, 1L+2L & 1M+2M turn on sides (Men RH
    Ladies LH)
17-24::
    1s+2s dance RH across ending with dancers turning (individually) by
    the right to places & setting
25-32::
    1s+2s dance Espagnole : 1s+2s cross the set, (Ladies dancing RH
    joined, between Men), Ladies change places RH, 1s+2s cross back (Men
    dancing RH joined between Ladies) Men change places RH (1s+2s have
    now changed pstns), 2s turn RH & 1s turn LH', 0);
INSERT INTO 'dancecrib' VALUES (5455, '2013-08-21 08:31:07.613245+00', '2023-02-04 01:20:09.981064+00', 2518, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s+2s turn RH & LH
17-24::
    1s lead down & back to 2nd places
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5456, '2013-08-21 08:31:07.621283+00', '2023-02-04 01:20:09.996491+00', 7567, 3, NULL, 'ace', '1-8::
    1s dance Inveran reels with 2s & 3s, 1s end with nearer hands joined
    facing down
9-16::
    1s dance down to 2nd place, face out & dance Double Triangles (2s &
    3s cross RH when 1s change places), 1s end facing out on opp sides
17-24::
    2s+1s dance 1/2 double Fig of 8 (2s crossing down to start), 1s+3s
    dance 1/2 double Fig of 8 (3s crossing up to start) & 1s face 1st
    crnrs
25-32::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (14422, '2021-11-06 01:11:16.791051+00', '2023-02-04 01:20:10.371953+00', 2526, 3, NULL, 'ace', '1-8::
    1s lead down between 2s, cross, cast behind 3s, lead up, cross, cast
    behind 2s back to place
9-16::
    1s+2s dance Poussette, 1s end BtoB in centre facing own sides as for
    Double Triangles
17-18::
    2s+1s+3s set once, taking hands
19-20::
    1s dance out to sides turning to face in _while_ 2s+3s advance, pass
    LSh to end BtoB with partners in the centre still facing same way
21-22::
    2s+1s+3s set, joining hands in triangle
23-24::
    2s+1s+3s advance, 1s finish in centre facing up, 2s/3s on opposite
    sides facing down/up
25-32::
    All dance 6 bar mirror reels of 3 on the sides, 1s lead up & cross
    to start, 2s dance in & down, 3s dance out & up. All cross RH to own
    sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5459, '2013-08-21 08:31:07.782086+00', '2023-02-04 01:20:10.397052+00', 2510, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to places
9-16::
    1s & 2s Petronella turn & set, turn partners 1.1/4 times RH to end
    with 1s facing down & 2s facing up
17-24::
    1s+2s dance a Half Rondel :
::
    1s dance down under the arch made by 2s who dance up, Ladies cross
    in front of Men & all cast to meet the other Lady or Man on the
    opposite side & join nearer hands, set on opposite sides of the
    dance & cross LH back to own sides
25-32::
    2s+1s R&L', 0);
INSERT INTO 'dancecrib' VALUES (5460, '2013-08-21 08:31:07.79017+00', '2023-02-04 01:20:10.426974+00', 2513, 3, NULL, 'ace', '1-8::
    1s lead down for 3 steps, lead up to top & cast to face 1st corners
9-16::
    1s set & turn 1st corners, set & turn 2nd corners & end 2nd place
    opposite sides
17-24::
    2s+1s+3s Adv+Ret, 1s turn RH 1.1/2 times _while_ 2s & 3s turn RH to
    end in centre (2s facing down & 3s up) to form circle
25-32::
    2s+1s+3s set, dance RH across for 2 steps & chase clockwise to
    places', 0);
INSERT INTO 'dancecrib' VALUES (5461, '2013-08-21 08:31:07.798169+00', '2023-02-04 01:20:10.458306+00', 2514, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place (2s step up 3-4); 1s turn RH & face out
9-16::
    1s dance RSh reels of 3 on sides (1L up, 1M down) & 1s pass LSh (1M
    from top, 1L from bottom) to 2nd place own side, 1M faces down, 1L
    up
17-24::
    1s dance Figs of 8 on own sides (1L out & up, 1M down) & end BtoB in
    centre facing own sides _while_ 2s+3s dance R&L
25-32::
    1s dance Double Triangles', 0);
INSERT INTO 'dancecrib' VALUES (5462, '2013-08-21 08:31:07.806154+00', '2023-02-04 01:20:10.481242+00', 8052, 3, NULL, 'ace', '1-8::
    1s set twice, dance down between 3s & cast up to 2nd places
9-16::
    1s cross down (each couple cross down as they reach top place) to
    dance reflection reels of 3 on sides
17-24::
    1s cross down (each couple cross down as they reach top place) to
    dance reflection reels of 3 on sides
25-32::
    1s turn RH & cast to 2nd places, 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5463, '2013-08-21 08:31:07.815757+00', '2023-02-04 01:20:10.637664+00', 2532, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s followed by 2s lead down & 2s led up 1s crossing at top to end
    between 2s ready for reel of 4
17-24::
    1s+2s dance RSh reel of 4 & 1s end facing 1st corners
25-32::
    1s turn 1st corner RH, partner LH, 2nd corner RH & cross LH to
    places', 0);
INSERT INTO 'dancecrib' VALUES (5464, '2013-08-21 08:31:07.825624+00', '2023-02-04 01:20:10.672068+00', 2540, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All dance RSh reels of 4 on sides
9-16::
    1s+2s dance 1/2 R&L, set & cross RH

{{title}}
Reel

1-8::
    1s petronella turn into middle, set advancing & BtoB face opposite
    sides as for double triangles, set & turn 3s to end 3rd place opp
    sides
9-16::
    1s petronella turn into middle, set advancing & BtoB face own sides
    as for double triangles, set & turn 4s to end 4th place own sides', 0);
INSERT INTO 'dancecrib' VALUES (15054, '2022-09-05 00:18:17.343193+00', '2023-02-04 01:18:20.450718+00', 20800, 3, NULL, 'ace', '1-8::
    All 4 couples Adv+Ret; 1s+3s set advancing & Bal-in-Line (Man above
    Lady)
9-16::
    1s+3s 1/2 turn partner RH & Bal-in-Line; 1s+3s turn partner RH (or
    birl) back to place
17-24::
    1s cross down RH, cast behind 3s; cross RH & cast behind 4s to 4th
    place (2s, 3s & 4s step up 23-24)
25-32::
    2s+3s+4s+1s circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (3919, '2013-08-21 08:30:39.135513+00', '2023-02-04 01:18:20.484208+00', 10844, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 round 2s
9-16::
    1s followed by 2s lead down, 2s followed by 1s lead up to 1st & 2nd
    places
17-24::
    1s+3s Set+Link, 1s+4s Set+Link.  2 3 4 1
25-32::
    1s dance Figs of 8 round 4s', 0);
INSERT INTO 'dancecrib' VALUES (5465, '2013-08-21 08:31:07.874762+00', '2023-02-04 01:20:10.697038+00', 2543, 3, NULL, 'ace', '1-8::
    1s cast 1 place (2s step up) _while_ 3s set, 1s+3s dance 3/4 L&R
    (left hand start).  2 3 1
9-16::
    2s+3s+1s dance Grand Chain (2s across to start). 1s end in 3rd place
    facing out
17-24::
    1s cast up 1 place (3s step down), turn RH 1.1/4 times & dance RSh
    round 2nd corners to face 1st corners
25-32::
    2s+1s+3s dance reels of 3 on sides (1s LSh to 1st corners) & 1s
    cross RH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (5466, '2013-08-21 08:31:07.885494+00', '2023-02-04 01:20:10.726513+00', 9006, 3, NULL, 'ace', '1-8::
    1s cross down to 3rd place opp side (no hands) & 1s+2s dance the
    Capstan :
::
    1M & 2L change places by dancing LSh 1.1/2 times round the standing
    3L _while_ 1L & 2M dance RSh 1.1/2 times round 3M
9-16::
    1s repeat all ending in original places
17-24::
    1s+2s set, cross RH, set & 1s cast to 2nd place _while_ 2s cross up
    (no hands)
25-32::
    1s crossing down dance 1/2 Fig of 8 round 3s & turn 3s 1.1/2 times
    on sides (Ladies LH & Men RH)', 0);
INSERT INTO 'dancecrib' VALUES (5467, '2013-08-21 08:31:07.893536+00', '2023-02-04 01:20:10.760886+00', 2556, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across, 1s+3s set, dance 1/2 LH across
9-16::
    1s set & cast up 1 place as 3s stand & cross back to places, 1s set
    & cast up 1 place as 2s stand & cross back to places
17-24::
    All dance reels of 3 on own sides (2s dancing out round 3s to start)
25-32::
    1s+2s 3/4 turn RH, 1M+2L turn LH 1.1/2 times _while_ 1L & 2M chase
    clockwise to meet partner & 3/4 turn partners RH to places', 0);
INSERT INTO 'dancecrib' VALUES (15224, '2022-11-03 01:19:54.665521+00', '2023-02-04 01:20:10.783188+00', 2516, 3, NULL, 'ace', '1-8::
    1s & 4s Petronella turn & set to finish in a line up/down centre;
    1s+4s dance 1/2 reel of 4 up/down
9-14::
    _6_ bar Reels of 3 across. 1M with 3s (LSh to 3L), 4L with 2s (LSh
    to 2M) [end people stand]
15-16::
    1L+1M, 4L+4M, 2L+3L, & 2M+3M change places with each other RH
17-24::
    1s+4s dance 1/2 reel of 4; 1s+4s Petronella turn & set to finish in
    sidelines.  1 3 2 4
25-30::
    All dance 1/2 »Double Double Figure of 8« (dancing 4 places around
    Figure of 8):
::
    3L followed by 1L cross down, 2L followed by 4L cross up, 1M
    followed by 3M cross to Ladies'' side and follow 1L, 4M followed by
    2M cross to Ladies'' side and follow 4L.
31-32::
    1M+3M also 1L+3L change places LH _while_ others change places RH on
    sides.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5468, '2013-08-21 08:31:07.901768+00', '2023-02-04 01:20:10.809042+00', 10557, 3, NULL, 'ace', '1-8::
    All Ladies RH across & return to places dancing LSh round own
    partners end facing corners
9-16::
    Corner couples turn RH 1.3/4 times into prom hold & dance
    anticlockwise a little more than 1/2 way to form square & face in
    (Men now diametrically opposite original place with ''new'' partner on
    right & all Ladies 1 place on clockwise)
17-24::
    All couples (prom hold) advance to centre, release hands & retire
    with corner, advance again & retire with current partner
25-32::
    All Men LH across & return to place dancing RSh round current
    partner & end giving LH to corner facing in on diagonal
33-40::
    Corner couples Set+Link, Set+Link on sides
41-48::
    All circle 8H round & back

{{explanation}}
NB Ladies are in original place but Men are 1 place anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (12081, '2019-08-30 09:54:16.839013+00', '2023-02-04 01:20:10.887306+00', 19084, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp sides

1-8::
    1s+2s & 3s+4s Set+Link.  2s+1s & 4s+3s dance RH across once round
9-16::
    1s+4s dance 1/2 LH across, 4M+1L & 4L+1M retain hands to change
    places LH on sides;  2s+1s & 4s+3s turn RH once round on sides. 2
    (1) 4 (3)
17-24::
    Reels of 4 on sides.  Bar 24: 1L+4M & 1M+4L 1/2 turn 2H on sides to
    change places
25-32::
    1s+4s dance Bourrel:
::
    _25-28_   1L+4L set advancing, 3/4 turn 2H & twirl to end BtoB (4L
    facing up, 1L facing down) _while_ partners chase anticlockwise to
    face partner
::
    _29-32_   Set to partners & 3/4 turn 2H to own sides having changed
    places. 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (14652, '2022-03-07 02:19:50.255071+00', '2023-02-04 01:20:10.921518+00', 16616, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance mirror reels of 3 on sides (1s in/down, 2s out/up, 3s
    in/up to start). At end of reel 1s continue to dance down to finish
    BtoB in 2nd place facing own sides, 2s dance up to 1st place
9-16::
    1s dance Double Triangles to finish 1L facing 2L & 1M facing 3M
17-24::
    1s dance RSh reels of 3 across (1L+2s, 1M+3s) 1s finish in 2nd place
    opposite sides
25-28::
    1s dance 1/2 Fig of 8 (1L up with 2s, 1M down with 3s) to finish in
    2nd place own sides 2 1 3
29-32::
    2s+1s+3s turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (5470, '2013-08-21 08:31:07.917931+00', '2023-02-04 01:20:10.94308+00', 250, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides with
    1s & 3s ending in centre facing down/up
9-16::
    1s+3s dance Ladies'' Chain ending with 1M facing Ladies'' side & 3M
    facing Men''s side with partners behind them
17-24::
    1M also 3M (followed by ptnrs & cast to start) dance a Fig of 8
    round standing 2s passing firstly LSh in middle & then RSh to end
    back in middle
25-32::
    1s+2s+3s circle 6H round & back
33-40::
    1s+2s set & dance 3/4 double Fig of 8 (1s cast to start) with 1s
    ending in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (10832, '2018-06-11 00:36:23.51749+00', '2023-02-04 01:20:10.973751+00', 18333, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 double Fig of 8 (1s cross down), 1M+2M also 1L+2L
    set advcg (across) to right (pass LSh), Men turn RH as Ladies turn
    LH.  1 2 3
9-16::
    All dance reels of 3 on sides (1s down between 2s to start) with 2s
    crossing down from 1st place.  1 (2) 3
17-20::
    1s+2s set advcg (up/down) & pass LSh _while_ 3s 1/2 turn 2H, 1s+3s
    set advcg & pass LSh _while_ 2s 1/2 turn 2H
21-24::
    2s+3s set advcg & pass LSh _while_ 1s turn 2H, 2s+1s set advcg &
    pass LSh _while_ 3s dance out to 1st place opposite sides.  (3)(1) 2
25-32::
    All dance 1/2 reels of 3 on sides (1s up between 3s to start), 1s+3s
    dance 1/2 double Fig of 8 (1s cross down).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13026, '2020-08-10 00:18:18.966051+00', '2023-02-04 01:18:21.059764+00', 16623, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance 1/2 mirror reels of 3 on sides (1s dance in/down to
    start); 1s+2s 1/2 turn on sides (Men LH, Ladies RH), 1M casts up, 1L
    casts down to end 1M between 3s (at top), 1L between 2s (at bottom)
9-12::
    1s petronella turn to 2nd place own side _while_ 2s+3s advance
    (PdeB) slightly to Left to join hands in line up/down centre, all
    set
13-16::
    1s petronella turn to centre _while_ 2s+3s advance (PdeB) slightly
    to Right to form lines of 3 across, 1L+3s at top facing down, 1M+2s
    at bottom facing up, all set
17-24::
    1s dance RSh round 3rd corner (1M up/out, 1L down/out), pass partner
    RSh & dance RSh round 4th corner to 2nd place own sides. (3) 1 (2)
25-32::
    3s+1s+2s dance diag R&L.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13158, '2020-09-15 00:19:50.366246+00', '2023-02-04 01:20:11.004454+00', 18331, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up), 1s dance 1/2 Fig 8 (1M up round 2s,
    1L down round 3s) & end facing 1st corners
9-12::
    Dance to Corners & Set: (4 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 1 more time to end
    with 2nd corners in the middle facing 1s (in 3rd corner position) as
    1s set.
13-16::
    1s+2nd corners dance 1/2 diag reel of 4, 2nd corners pass RSh to
    face 1st corners (in 2nd corner pstn)
17-20::
    Repeat Dance to Corners & Set: figure (bars 9-12). End 1s facing 2nd
    corners (in 3rd corner pstn)
21-24::
    1s+corners dance 1/2 diag reel of 4. 1s end facing 1st corner (pstn)
25-32::
    1s+corners dance 1/2 diag reel of 4, 1s turn RH to 2nd place own
    side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5471, '2013-08-21 08:31:07.954076+00', '2023-02-04 01:20:11.027188+00', 2521, 3, NULL, 'ace', '1-8::
    All set, cross RH & chase 1/2 way
9-16::
    4s+3s also 2s+1s dance 1/2 R&L, 4s+1s cross RH & turn LH on sides.
    (3) 4 1 (2)
17-24::
    All dance RSh reels of 4 on sides
25-32::
    3s+4s also 1s+2s dance RH across, 4s+1s dance LH across _while_
    3s+2s chase clockwise 1/2 way.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5472, '2013-08-21 08:31:07.962163+00', '2023-02-04 01:20:11.053577+00', 2525, 3, NULL, 'ace', '1-4::
    All set, 1/2 turn partners 2H, 1M & 2L also 3M & 4L drop LH & circle
    left 1 place to end 1s & 3s on Ladies'' side & 2s & 4s on Men''s side
5-8::
    All couples Set+Link
9-16::
    2s & 3s cross passing opposite person RSh & dance to right to change
    places, 1s+3s also 2s+4s dance RH across & end facing partners on
    sides
17-24::
    All dance DoSiDo with partner & dance 1/2 reels of 4 on sides
25-32::
    2s+4s also 3s+1s circle 4H round to left 1.1/4 times & dance 1/2
    diamond Poussette.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13159, '2020-09-15 00:19:50.417702+00', '2023-02-04 01:20:11.082171+00', 18498, 3, NULL, 'ace', '1-8::
    1s set, cross down RH to 2nd place _while_ 2s cast to top place on
    bars 3-4. 1s dance down behind 3s, cross RH & cast up to 2nd place
9-14::
    All set. All 1/2 turn 2H, face partner, pull back RSh & curve out to
    partner''s place
15-16::
    2s+3s cross RH _while_ 1s dance RSh round each other to face 1st
    corners
17-24::
    1s dance Corner Pass+Turn with 1st & 2nd corners
25-32::
    1s+3s dance Set+Link. All turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (5473, '2013-08-21 08:31:07.973567+00', '2023-02-04 01:20:11.09832+00', 2530, 3, NULL, 'ace', '1-8::
    1s set advancing & dance down between 2s, cast down behind 3s & lead
    up to face 1st corner
9-16::
    1s+1st corners set & dance 1/2 diagonal reel of 4, 1s turn LH to
    face 2nd corners as 1st corners set
17-24::
    1s+2nd corners repeat bars 9-16 & 1s end Lady facing down & Man up
25-32::
    1s dance RH across (1L with 3L+2L, 1M with 3M+2M), 1s turn RH to 2nd
    place own sides as corners dance clockwise 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (5474, '2013-08-21 08:31:07.982062+00', '2023-02-04 01:20:11.110494+00', 12524, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s cross RH down/up & cast to partners place, 2s & 3s dance
    up/down & cast back to place
9-16::
    1s & 4s dance Figs of 8 (on own sides) round 2s/3s
17-24::
    1s+2s also 3s+4s dance RH across, 2s+3s dance LH across
25-32::
    1s & 4s set, cross RH, 1s+4s chase anticlockwise to end in 3rd/2nd
    places (2s & 3s step down/up)  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (13990, '2021-05-03 00:19:48.985653+00', '2023-02-04 01:20:11.131085+00', 2534, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH; 1s face 2s on sides & set, 1s+2s change places
    on side (Men RH, Ladies LH).
9-16::
    1s+3s dance 1/2 Double Fig 8 (1s cross down, 3s cast up); 2s+1s+3s
    dance 1/2 reels of 3 on sides (1s cross up, 2s out/down, 3s out/up
    to start) 2s & 3s loop into place
17-24::
    3s+1s+2s Adv+Ret (1 step each), cross RH; Adv+Ret (1 step each) & 1s
    turn LH to face 3rd corners (pstn) _while_ 3s & 2s cross LH  (3) 1
    (2)
25-32::
    1s+corners dance 1/2 diag reel of 4; 1s pass LSh to face 4th corners
    (pstn) & dance 1/2 diag reel of 4.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5475, '2013-08-21 08:31:07.990598+00', '2023-02-04 01:20:11.154737+00', 2536, 3, NULL, 'ace', '{{explanation}}
This reel is danced with 3 Men & 6 Ladies arranged as 3 lines of 3 up & down room, Men in centre with Lady each side. All facing 2M in middle

1-8::
    Centre Man sets with highland steps _while_ others circle 8H round &
    back
9-16::
    Ladies on right (looking up the set) joining hands Adv+Ret _while_
    Men dance RSh round Ladies, repeat with Ladies on left dancing LSh
17-24::
    Top & bottom Men & middle Ladies petronella on 1place & dance
    anticlockwise round centre Man back to places as centre Man sets
    bars 21-24
25-28::
    Top row change places RH with middle row _while_ bottom row sets,
    new middle row changes places LH with bottom row as top row sets
29-32::
    New top row changes places RH with middle row _while_ bottom row
    sets; new middle row changes places LH with bottom row as top row
    sets', 0);
INSERT INTO 'dancecrib' VALUES (5476, '2013-08-21 08:31:07.99926+00', '2023-02-04 01:20:11.17976+00', 13078, 3, NULL, 'ace', '1-8::
    1s+3s dance 1/2 Figs of 8 round 2s/4s, 1s+3s dance down 1 place &
    turn inwards face up as 2s also 4s dance up 1 pl & in to face 1s/3s
    & all set
9-16::
    2s+1s also 4s+3s circle 4H round to left, all dance 1/2 RSh reels of
    4 on sides but end with 1s+4s 3/4 turning LH bringing Ladies into
    centre
17-24::
    1s+4s dance the Targe :
::
    _17-18_  1st & 4th Ladies  3/4 turn RH _while_ Men dance 1/4 way
    round anticlockwise
::
    _19-20_ 1st Man with 4th Lady & 1st Lady with 4th Man full turn LH
::
    _21-22_ 1st & 4th Ladies  3/4 turn RH _while_ Men dance 1/4 way
    round anticlockwise
::
    _23-24_ 1st Man with 4th Lady & 1st Lady with 4th Man turn LH to end
    on sides (3) 1 (4) 2
25-32::
    All dance 1/2 RSh reels of 4 on sides, all set & 3s+4s cross to own
    sides.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15209, '2022-11-03 01:18:19.250331+00', '2023-02-04 01:18:21.300859+00', 19835, 3, NULL, 'ace', '1-8::
    1s+4s cross RH & cast down/up (2s+3s step up/down bars 3-4); 1s+4s
    dance 1/2 Fig of 8 round end couples. 2 1 4 3
9-16::
    1s+4s dance Poussette. On bar 16, 1s+4s turn 2H 3/4 to finish in
    middle of set (Men facing up, Ladies down)
17-24::
    1s+4s dance reel of 4 up/down middle of set
25-32::
    1s+4s turn 2H 1.1/4 to finish 1s facing down, 4s facing up. 1s+4s
    circle 4H 1/2 round to the left; 4s+1s set & cross RH to own sides.
    2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14576, '2022-02-05 02:19:46.825271+00', '2023-02-04 01:20:11.236837+00', 20617, 3, NULL, 'ace', '{{explanation}}
Round the Room, 3 facing 3

1-8::
    Lines of 3 Adv+Ret & circle 6H round to left, back to place
9-16::
    Centre dancers + partner to right + dancer opposite to right dance
    RH across; centre dancers pass RSh to dance LH across with other
    couple
17-24::
    Centre dancers dance Fig 8 round own partners (LSh to partner on
    right to begin)
25-28::
    Dancers on inside of circle change places RH, dancers on outside of
    circle change places RH
29-32::
    Lines of 3 join hands & set, centre dancers pass RSh to rejoin
    partners _while_ partners turn right about so lines of 3 face
    original direction facing a new group of 3 dancers', 0);
INSERT INTO 'dancecrib' VALUES (11447, '2019-01-01 01:56:52.334008+00', '2023-02-04 01:20:11.272204+00', 18968, 3, NULL, 'ace', '1-8::
    All Adv+Ret & dance DoSiDo
9-16::
    1s & 3s set & dance La Baratte with RH _while_ 2s & 4s set & dance
    La Baratte with LH, all ending on opposite sides:
::
    Men 1/2 turn Lady RH/LH & retains hand but at arm''s length from each
    other
::
    Men retrace steps with Lady turning right/left under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies original
    place) & releasing Ladies RH/LH she turns under Mans left arm until
    almost in original places
::
    Couples change places LH/RH to opposite places
17-20::
    1L dances RSh round 2L to face her _while_ 1M dances RSh round 2M to
    face him
21-24::
    1s dance 1/2 reel of 4 with 2s & 1/2 turn partner RH to face 3s
25-32::
    1s dance 1/2 reel of 4 with 3s & 1/2 turn partner RH to face 4s, 1s
    dance 1/2 reel of 4 with 4s & 1/2 turn RH to end in 4th place
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13160, '2020-09-15 00:19:50.63725+00', '2023-02-04 01:20:11.302321+00', 17905, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across ending 2H joined with partner on 1st corner
    diagonal; 1s+2s dance 1/2 Poussette (4 bars). 2 1 3
9-16::
    1s+3s repeat bars 1-8.  2 3 1
17-24::
    1s dance in & cast up to 1st place (2s+3s step down 21-22 & retain
    hands) & all join NH briefly & dance DoSiDo with partner
25-32::
    All dance Progressive Grand Chain:
::
    _25-26_    1s (at top) turn once round RH as 2s+3s change places RH
    on sides,
::
    _27-28_    2s (at bottom) turn once round LH as 1s+3s change places
    LH on sides,
::
    _29-30_    3s (at top) turn once round RH as 1s+2s change places RH
    on sides,
::
    _31-32_    1s (at bottom) turn once round LH as 2s+3s change places
    LH on sides to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5478, '2013-08-21 08:31:08.051755+00', '2023-02-04 01:20:11.327845+00', 11217, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, 1s+3s dance 1/2 R&L
9-16::
    2s set, cast 1 place, 2s+1s dance 1/2 R&L
17-24::
    1s dance down the middle & back to 2nd place facing up in prom hold
    (3s & 2s on opp sides step into prom hold facing down)
25-32::
    3s+1s+2s dance an Interlocking Allemandes:
::
    1s dance normal Allemande ending in 2nd place _while_ 3s+2s
    Allemande (down) & up to 3rd/1st places.  (2)1(3)
33-40::
    1s dance 1/2 Fig of 8 round 2s _while_ 2s set & cross RH, 1s dance
    1/2 Fig of 8 round 3s _while_ 3s set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (5479, '2013-08-21 08:31:08.062314+00', '2023-02-04 01:20:11.367037+00', 12634, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 double Fig of 8, 1s+3s dance 1/2 double Fig of 8 (2s
    dance up to 1st places)
9-16::
    1s+4s dance 1/2 double Fig of 8 (3s dance up to 2nd places), 1s lead
    down & turn RH into 4th places opposite sides.  (2)(3)(4)(1)
17-24::
    4s+1s dance RH across 1/2 way & set, 3s+1s dance LH across 1/2 way &
    set
25-32::
    2s+1s dance RH across 1/2 way & set, 1s cast to 4th places as
    2s+3s+4s step up', 0);
INSERT INTO 'dancecrib' VALUES (5480, '2013-08-21 08:31:08.070436+00', '2023-02-04 01:20:11.394265+00', 2562, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s change places on sides (Ladies LH & Men RH) &
    retaining hands all Bal-in-Line, repeat back to places & Bal-in-Line
9-16::
    All dance reels of 4 on sides (Ladies LSh & Men RSh) with 1s
    crossing at bottom (1s end at top on opposite sides BtoB facing 2s)
17-24::
    1s dance the Spurtle: 1s dance 1/2 reel of 4 with 2s & turn partner
    RH to face 3s, 1s dance 1/2 reel of 4 with 3s & turn partner RH to
    face 4s
25-32::
    1s dance 1/2 reel with 4s & turn RH to 4th place opposite sides, all
    set & cross RH 1s ending in 4th place', 0);
INSERT INTO 'dancecrib' VALUES (5482, '2013-08-21 08:31:08.084776+00', '2023-02-04 01:20:11.590522+00', 11812, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 4 facing 4 (1s+2s face clockwise)

{{title}}
Start

::
    3L···3M··· 4L···4M
::
    2M· ·2L·· 1M··· 1L
1-8::
    All circle 8H round & back
9-16::
    Ladies dance reel of 4 up/down centre (1L+4L also 2L+3L LSh to
    start)
17-24::
    Men dance reel of 4 up/down centre (1M+4M also 2M+3M RSh to start)
25-32::
    1s+4s also 2s+3s dance RH across, set & cross RH to face next two
    couples', 0);
INSERT INTO 'dancecrib' VALUES (5483, '2013-08-21 08:31:08.093105+00', '2023-02-04 01:20:11.613534+00', 2568, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-8::
    All 1/2 turn partners RH, 1s+2s also 3s+4s dance 1/2 RH across, 2s &
    3s chase clockwise 1/2 way _while_ 1s & 4s dance LH across.  3 1 4 2
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1s+4s dance Western DoSiDo (note- opposite partner, not beside
    partner at start)
::
    _17-18_  Men set _while_ Ladies dance in, Ladies pass each other LSh
    & curve to left, then turn right about to face »partner«
::
    _19-20_  All change places with »partner« LH
::
    _21-22_  Men change places with opposite Lady RH, Men pass LSh
    dancing back towards places _while_ Lady dances to »partner''s« place
::
    _23-24_  All turn RH into promenade hold
25-32::
    1L+4M (prom hold) dance reel of 3 across dance with 3s (LSh to 3M to
    start) _while_ 1M+4L reel of 3 across dance with 2s (LSh to 2M).  3
    1 (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (9005, '2015-11-30 08:59:48.379362+00', '2023-02-04 01:20:11.636774+00', 12749, 3, NULL, 'ace', '1-8::
    1s+3s turn prtnr 2H (4 bars), open out to 1s+2s also 3s+4s circle 4H
    once round. All retain partner''s hands, 1s face 2s, 3s face 4s
9-16::
    All set twice, turn facing person Men with RH, Ladies LH
17-24::
    1s+3s cross down RH & dance Fig 8 round 2s / 4s
25-32::
    1s+2s change places (Men RH, Ladies LH), 1s+3s change places other
    hand, 1s+4s change places other hand.  1M pulls back RSh,1L LSh to
    face & turn RH to place', 0);
INSERT INTO 'dancecrib' VALUES (9761, '2017-04-06 08:40:25.047303+00', '2023-02-04 01:23:08.456389+00', 7016, 3, NULL, 'ace', '1-8::
    1s set advancing, turn 2H (2 bars), dance down below 2s & cast up to
    place
9-16::
    1s+2s dance Diamond Poussette
17-24::
    1s+2s dance RH across, dance LH back
25-32::
    1s+2s dance »Tournée«:
::
    _25-28_    1s+2s dance into prom hold (Men with partner on right, 1s
    face Men''s side & 2s face Ladies side), both couples wheel
    anticlockwise 1/2 way & Men turn Ladies into middle
::
    _29-32_   Both couples turn 1.1/2 times (2s RH, 1s LH) & dance out
    to places', 0);
INSERT INTO 'dancecrib' VALUES (14787, '2022-05-05 00:18:18.475324+00', '2023-02-04 01:18:21.338977+00', 17102, 3, NULL, 'ace', '1-8::
    1M+2L also 3M+4L 1/2 turn RH, pull back RSh & dance out to change
    places; all dance 8H 1/2 round to left
9-16::
    4M+3L also 2M+1L 1/2 turn RH, pull back RSh & dance out to change
    places; all dance 8H 1/2 round to left. (2) (1) (4) (3)
17-24::
    All dance reels of 4 on sides
25-32::
    1s+4s (middle couples) Set+Link; all cross RH to own sides & set.  2
    4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3925, '2013-08-21 08:30:39.231007+00', '2023-02-04 01:18:21.538022+00', 46, 3, NULL, 'ace', '1-4::
    All Ladies cast round partner & dance into centre as Men dance to
    right 1/2 way
5-8::
    Ladies dance RH across 3/4 way & turn facing Man 2H & end facing
    partner (on corner)
9-16::
    All set to partners twice, turn partners 1.3/4  & face anticlockwise
17-24::
    All Promenade to original places, all joining hands in circle
    advance to centre & turning inwards dance out to original places
25-48::
    Repeat bars 1-24 with Men casting into LH across & Ladies dancing
    1/2 way round clockwise etc', 0);
INSERT INTO 'dancecrib' VALUES (8839, '2015-08-13 20:33:39.071181+00', '2023-02-04 01:20:11.668066+00', 16192, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round and back (3s+4s 4 bars later - then 5s+6s
    another 4 bars later)
9-12::
    1s+2s dance 1/2 RH across then 1/2 turn 2H ending with nearer hands
    joined facing up. (3s+4s 4 bars later - then 5s+6s another 4 bars
    later)
13-16::
    1s dance up and cast one place as 2s cast and dance up
17-20::
    1s+4s+3s dance 1/2 reels of 3 on the sides (1s in and down to start)
    joining hands where possible
21-24::
    1s+6s+5s dance 1/2 reels of 3 on the sides (1s in and down to start)
    (2s and 3s start the dance from the top on bar 21)

{{explanation}}
Final 4 bars (125-128) all couples turn both hands', 0);
INSERT INTO 'dancecrib' VALUES (12392, '2019-12-05 01:30:04.590322+00', '2023-02-04 01:20:11.695864+00', 17530, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s+4s cross to opp sides

1-8::
    All 4 couples set, cross RH 1s+3s face down & 2s+4s face up, all
    set, change places LH on sides
9-16::
    All set, cross RH 1s+4s face on sides, 1s+4s set, change LH on sides
    to flow into ..
17-24::
    Reel of 4 on sides on bar 24 1s+4s pass RSh 2 (4) 1 (3)
25-32::
    All set, 2s+3s chase clockwise to other end of set _while_ 1s+4s
    dance 3/4 R&L 3 1 (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (5484, '2013-08-21 08:31:08.101343+00', '2023-02-04 01:20:11.724591+00', 12636, 3, NULL, 'ace', '1-8::
    1s & 4s cross & cast in 1 place, 1s+4s dance LH across _while_ 2s+3s
    chase 1/2 way clockwise (2L & 3M cast to start).  (3)(1)(4)(2)
9-12::
    3s facing 1s also 4s facing 2s all set, top 2 Men also bottom 2
    Ladies change places RH _while_ top 2 Ladies also bottom 2 Men
    change places LH
13-16::
    3s & 2s dance 1/2 Figs of 8 round end couples.  (1)3 2(4)
17-20::
    3s+2s dance LH across _while_ 1s+4s chase 1/2 way clockwise (4L & 1M
    cast)
21-24::
    4s facing 3s also 2s facing 1s set, top 2 Men also bottom 2 Ladies
    1/2 turn RH _while_ top 2 Ladies also bottom 2 Men 1/2 turn LH.  3 4
    1 2
25-32::
    2s dance up & out behind 4s to 1st place _while_ 3s dance down & out
    (after 2s pass) behind 1s to 4th place & all turn 2H.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5485, '2013-08-21 08:31:08.109424+00', '2023-02-04 01:20:11.752933+00', 2571, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s set & petronella turn to face partner in middle, turn 3/4
    partners RH & dance RH across 1/2 way
9-16::
    2s+1s+3s circle 6H round & back

{{title}}
Reel

1-4::
    1s set advancing to 1st corner & turn corners RH to end in lines
    across (1L between 2s, 1M between 3s)
5-8::
    1s set advancing to 2nd corners & turn RH to 2nd place opposite side
9-16::
    1s dance reels of 3 on sides (LSh to 1st corner) & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (5486, '2013-08-21 08:31:08.117748+00', '2023-02-04 01:20:11.784209+00', 8674, 3, NULL, 'ace', '1-4::
    1s & 3s 3/4 turn RH & set to partner
5-16::
    1s+2s+3s Dance to each ''Corner'' & Set (diamond shaped square with
    corners on sides & ends):
::
    2s set _while_ 1s & 3s change places with partners passing RSh &
    1L+3M pass RSh face side ''corners'',
::
    1M & 3L set _while_ 1L+2M also 3M+2L change places passing RSh & 2s
    pass RSh to face end ''corners'',
::
    1L & 3M set _while_ 1M+2L also 2M+3L change places passing RSh &
    1L+3M pass RSh to face side corners (partners),
::
    1s & 3s change places with partners passing RSh & 1L+3M pass RSh to
    face end '' corners'',
::
    1M & 3L set on sides _while_ 2L+3M also 1L+2M change places passing
    RSh & 2s pass RSh to face side ''corners'',
::
    2L+1M also 2M+3L change places passing RSh & 1M+3L pass RSh to face
    partners (2s in places opposite sides & 3s+1s in centre)
17-24::
    1s+3s dance 1/2 reel of 4 up/down centre, 1s+2s+3s set & turn
    partners LH to end 1s+2s in centre for Poussette & 3s in own places
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13162, '2020-09-15 00:19:51.158502+00', '2023-02-04 01:20:11.815235+00', 8094, 3, NULL, 'ace', '1-8::
    1L followed by 1M casts & dances across to 2nd place opp side (2s
    step up 3-4); 1s turn 1.3/4 LH
9-12::
    1L+2s dance 1/2 RH across _while_ 1M casts up on Ladies'' side, 1s
    pass LSh at top, 1M+2s dance 1/2 LH across _while_ Ladies casts down
    on Ladies'' side
13-16::
    1L+3s dance 1/2 LH across _while_ 1M casts down on Ladies'' side, 1s
    pass RSh, 1M+3s dance 1/2 RH across _while_ 1L casts up Ladies'' side
17-20::
    1s pass LSh into 1s+1st corners dance 1/2 diag reel of 4, 1s pass
    RSh  & 1M curves round to follow 1L
21-24::
    2nd corners+1L+1M in tandem dance 1/2 diag reel of 3 (RSh to 3M)
25-28::
    1st corners (pstn)+1L+1M in tandem dance 1/2 diag reel of 3 (RSh to
    3L place)
29-32::
    1s separate, 1L curves right to face 2nd corner (pstn) & 1s+2nd
    corners (pstn) dance 1/2 diag reel of 4.  1s end in 2nd place own
    side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5487, '2013-08-21 08:31:08.125805+00', '2023-02-04 01:20:11.85681+00', 10695, 3, NULL, 'ace', '1-8::
    1s lead down for 3 bars, up to top & cast to 2nd place
9-16::
    1s dance 1/2 Fig of 8 round 2s, 1M+2M turn LH
17-24::
    1s+2s dance Ladies'' Chain
25-32::
    1L casts up behind 2M, crosses to 2nd place own side _while_ 1M
    casts up on Ladies'' side, crosses & casts to 2nd place, 2s+1s set', 0);
INSERT INTO 'dancecrib' VALUES (5488, '2013-08-21 08:31:08.133861+00', '2023-02-04 01:20:11.876326+00', 2573, 3, NULL, 'ace', '1-8::
    1M & 3M also 2L & 4L set twice turning to right on fourth step to
    face out & all Bal-in-Line on sides
9-16::
    1L+2M also 3L+4M turn twice _while_ partners dance clockwise round
    them back to place
17-24::
    1M+2L also 3M+4L change places RH, 1M+4L change places LH, 2L+4L
    also 1M+3M change places RH & all set on sides
25-32::
    1L & 4L, 1M & 4M dance towards partner (others step out to ends), 1s
    in prom hold dance out round 3L & cross up to 3rd places own side
    _while_ 4s dance out round 2M & cross down to 2nd places.   2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3958, '2013-08-21 08:30:40.084755+00', '2023-02-04 01:18:23.480794+00', 10599, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s 1.1/4 turn LH
9-16::
    1s dance 1/2 reels of 3 across (1L with 2s, 1M with 3s), 1s turn LH
    1.1/2 times to own sides
17-24::
    1s dance 1/2 reels of 3 on sides (LSh to 4th corner), 1s turn LH
    1.1/2 times to opposite sides
25-32::
    All Set+Link for 3 twice', 0);
INSERT INTO 'dancecrib' VALUES (8324, '2014-07-29 12:59:03.205869+00', '2023-02-04 01:20:11.919749+00', 15061, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across 1.1/4, change places with partners on sides,
    chase 1 place clockwise  2 1 3
9-24::
    Progressive 1/2 reels:
::
    _9-12_    1s dance 1/2 reels of 3 across, RSh to 2nd corner
    position, finish 2nd place opp. Sides
::
    _13-16_  1s dance 1/2 reels on opp. Sides, LSh to 1st corner
    position, finish facing 4th corner positions
::
    _17-20_  1s dance 1/2 reels across, RSh to 4th corner position,
    finish 2nd place own sides
::
    _21-24_  1s dance 1/2 reels on own sides, LSh to 3rd corner
    position, finish BtoB facing 2nd corner positions
25-32::
    1s dance RSh round 2nd corners, pass RSh, dance RSh round 4th
    corners to 2nd place, own sides', 0);
INSERT INTO 'dancecrib' VALUES (5490, '2013-08-21 08:31:08.150066+00', '2023-02-04 01:20:11.947026+00', 10345, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 double Fig of 8 (1s & 4s crossing down/up
    to start), 1L+2L also 3M+4M turn RH _while_ partners turn LH
9-16::
    Repeat but turning with other hand
17-24::
    1s & 4s dance down/up _while_ 2s & 3s cast up/down, 1s+4s set &
    circle 4H round to left
25-32::
    1s+4s Set+Link, 2s+4s also 1s+3s dance RH across to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5491, '2013-08-21 08:31:08.158158+00', '2023-02-04 01:20:11.980375+00', 7406, 3, NULL, 'ace', '1-8::
    1L+2L also 3M+4M cross passing partner by LSh & cast (Ladies down &
    Men up) to change places, repeat passing opposite person by the LSh
9-16::
    1M+2M also 3L+4L repeat bars 1- 8 but passing by RSh
17-24::
    1s slip step down the middle & up
25-32::
    1s cast to 4th place own sides & all turn partners LH', 0);
INSERT INTO 'dancecrib' VALUES (5492, '2013-08-21 08:31:08.166103+00', '2023-02-04 01:20:12.015742+00', 2578, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & turn LH to end in 2nd place on own side
    facing 1st corner
9-16::
    1s dance Diag R&L
17-24::
    3s+1s+2s set, 1s set again _while_ 2s & 3s cross RH, 3s+1s+2s turn
    RH to face up
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (12634, '2020-03-02 01:52:34.989618+00', '2023-02-04 01:20:12.030876+00', 15125, 3, NULL, 'ace', '1-8::
    1L+2M followed by 1M lead down; 1s followed by 2M lead back
    remaining in centre facing up, 2L & 3s step in ready for …
9-16::
    1s+2s+3s dance Allemande, 2s pull back RSh, dance out to own side &
    face out
17-24::
    Promenade (Chaperoned) Chain Progression:
::
    _17-18_    1s & 3s 3/4 turn partner RH into middle _while_ 2s dance
    clockwise 1/4 round the set picking up 3L/1M …
::
    _19-22_    who promenade 1/2 way clockwise _while_ middle people (3M
    + 1L) turn LH 1.1/2.
::
    _23-24_    1s & 3s turn partner RH 3/4 to own sides _while_ 2s dance
    clockwise 1/4 round to end in 2nd place. 1 2 3
25-32::
    1s 1/2 turn RH, pull back RSh & dance out to opp sides, set to each
    other & cross down to 3rd place own side  (2s+3s step up). 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5493, '2013-08-21 08:31:08.297935+00', '2023-02-04 01:20:12.048527+00', 13387, 3, NULL, 'ace', '1-16::
    1s turn RH & cast 1 place, 2s+1s+3s dance 3 couple R&L    2 1 3
17-24::
    1s pass LSh & dance 1/2 reel of 4 with 1st cnrs; 1s pass RSh, dance
    1/2 reel of 4 with 2nd cnrs & end 2nd place opp sides.  (3) (1) (2)
25-32::
    All dance the Serpentine:
::
    _25-28_  1M+2M change places LH as 1L+2L change RH, 3M+2M change
    places RH as 3L+2L change places LH
::
    _29-32_  3M+1M change places LH as 3L+1L change RH, 2s+1s+3s cross
    RH', 0);
INSERT INTO 'dancecrib' VALUES (12724, '2020-04-11 10:51:27.950333+00', '2023-02-04 01:20:12.117072+00', 12083, 3, NULL, 'ace', '1-4::
    1s+4s lead down/up towards each other RHJ, dance 1/2 RH across,
    finishing on sidelines. (2s+3s move up/down). 2  (4) (1) 3
5-8::
    2s+3s repeat. All now on opp  sides (4) (3) (2) (1)
9-16::
    3L+2L dance Alternating Tandem reel of 3 on sides with 4L & 1L, RSh
    to 4L to begin.
::
    _while_ 2M+3M dance Alternating Tandem reel of 3 on sides with 1M
    and 4M, giving RSh to 1M to begin.
::
    At end of reels 4L+1M face out
17-20::
    3s+2s circle 4H round to Left, finishing on side _while_ 4s+1s chase
    anticlockwise 1/2 round set. 1 3 2 4
21-24::
    All set. All turn partners 2H, 2s+3s 1/2 turn, 1s+4s turn once round
    and stay in middle, opening out so that 1s face 3s, 2s face 4s
25-32::
    All dance mirrored Rondels:
::
    (1s+3s dance normal Rondel, with 3s making arch bars 25-31;In other
    Rondel, 2s make arch on bars 25-31) 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (9918, '2017-06-05 11:31:08.95561+00', '2023-02-04 01:20:12.344159+00', 10531, 3, NULL, 'ace', '1-8::
    2s followed by 1s dance full Fig 8 round 3s ending 2s in top place,
    1s in 2nd place
9-16::
    1s dance Petronella turn & set (1L between 2s, 1M between 3s). 1s
    cross RH up/down & cast to 2nd place opp sides
17-20::
    1s Allemande Right: 1s advance 2 steps, give RH to partner, Lady
    turns Right about under Man''s arm & dance out to place as Man
    retires
21-24::
    1s dance LH across (1L+2s & 1M+3s)
25-28::
    1s Allemande Left: 1s advance 2 steps, give LH to partner, Lady turn
    Left about under Man''s arm & dance out to place as Man retires
29-32::
    1s dance RH across (1L+3s &1M+2s).  1s end on sidelines facing 1st
    corners
33-40::
    1s set to 1st corner, turn Right about to face 2nd corner & set.  1s
    turn 1/4  Left about to face parner across dance & 1s turn 1.1/2 RH
    to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (5495, '2013-08-21 08:31:08.314276+00', '2023-02-04 01:20:12.439572+00', 10058, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across 1s/4s end in original places, 2s &
    3s cross out thru ends, cast & change places LH on sides.  1 (3) (2)
    4
9-16::
    All dance RSh reels of 4 on sides
17-24::
    3s & 2s dance 1/2 Figs of 8 round end couples, all turn partners 2H
    opening into…
25-32::
    1s+3s also 2s+4s circle 4H round to left & dance 1/2 Diamond
    Poussette.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (5496, '2013-08-21 08:31:08.322324+00', '2023-02-04 01:20:12.474075+00', 13742, 3, NULL, 'ace', '1-8::
    1s dance down below 3s, cast up to 2nd place own side & turn LH
    1.1/4 times to face 1st corners
9-16::
    1s dance Hello-Goodbye setting & end in centre facing 3rd corners
17-24::
    1s dance diagonal reel of 4 with 1st corners & pass partner LSh to
    face own 2nd corners
25-32::
    1s dance diagonal reel of 4 with 2nd corners & end in 2nd place own
    side
33-40::
    All circle 6H round & back.', 0);
INSERT INTO 'dancecrib' VALUES (8325, '2014-07-29 12:59:03.36153+00', '2023-02-04 01:20:12.504995+00', 15034, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, dance 1/2 Fig 8 round 2s (2s step up on
    bars 3-4)
9-10::
    1s change places RH with 1st corners (quick) and face up/down on
    sides _while_ 1st corners dance diagonally across set (3L up, 2M
    down) finishing outside set in 1st & 3rd places
11-12::
    1s change places LH with 2nd corners _while_ 1st corners dance in to
    join hands in prom hold, with 1s (1L & 2M, 1M & 3L)
13-16::
    1s with 1st corners promenade past each other RSh, curving into 2nd
    place
::

17-24::
    1s repeat 9-16 with 2nd corners (now in 1st corner positions)
25-32::
    1s dance 1/2 Fig 8, 1L round 3M place, 1M round 1L place; 3s+1s+2s
    chase clockwise 1/2 way round.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8528, '2015-02-13 12:47:20.537128+00', '2023-02-04 01:18:21.558894+00', 15593, 3, NULL, 'ace', '1-8::
    1s set & dance down NHJ (2s step up); 1L+3L also 1M+3M join hands
    (Ladies LH, Men RH) & set & 1/2 turn as 2s set & dance down NHJ then
    cast up to 3rd place behind 3s
9-12::
    Ladies dance LH across as Men dance RH across
13-16::
    1s dance up NHJ followed by 3s, 1s cast to 2nd place own sides, 3s
    loop into 1st place _while_  2s NHJ dance down slightly & cast back
    up to 3rd place ready for …
17-24::
    1s dance 1/2 LSh reels of 3 across (1L+3s at top, LSh to 3M, 1M+2s
    in 3rd place, LSh to 2L); 1s dance 1/2 RSh reels of 3 on sides (1M
    RSh to 3M, 1L RSh to 2L).  (2) (1) (3)
25-32::
    All Adv+Ret, all advance & turn 2H 1/2 way & retire to own sides.  2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (5497, '2013-08-21 08:31:08.33046+00', '2023-02-04 01:20:12.520393+00', 2585, 3, NULL, 'ace', '1-8::
    1s+2s 1/2 turn RH, set (retaining hands), turn RH 1.1/2 times to
    original places
9-12::
    1M followed by 2M dance up into centre facing down _while_ 2L
    followed by 1L dance down into centre to face up & 1s+2s set to
    partners
13-16::
    1s+2s change places with partners RH & chase clockwise to own sides
    2 1
17-24::
    1s turn RH 1.1/4 times to dance LH across (Man with 2s & Lady with
    3s) 1s ending 2nd place own side
25-32::
    1s turn LH 1.1/4 times to dance RH across (Lady with 2s & Man with
    3s) 1s ending 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (5498, '2013-08-21 08:31:08.365431+00', '2023-02-04 01:20:12.591774+00', 14339, 3, NULL, 'ace', '1-8::
    1s Slip step down middle, 1s lead up to face 1st corners
9-16::
    1s set twice to 1st corners & set twice to 2nd corners
17-24::
    1s dance reel of 3 on sides (RSh to 2nd corners) & cross RH to end
    2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (11448, '2019-01-01 01:56:52.698817+00', '2023-02-04 01:20:12.626111+00', 18978, 3, NULL, 'ace', '1-8::
    1M followed by partner casts to 3rd place & crosses to opposite
    side; 1s+4s dance RH across
9-16::
    All set & turn partners 2H; 2s+3s also 1s+4s circle 4H round to
    left. 3s & 1s end in middle facing ends
17-24::
    3s & 1s dance out ends & cast in to meet partner in prom hold, 3s+1s
    dance RSh round each other to end 3s b''tw''n 2s, 1s b''tw''n 4s all
    facing down
25-32::
    All dance down for 3 bars, 3s & 1s form arches & turn outer dancers
    in & up under arches (order now 2 3 4 1) & all dance up to new
    places

{{explanation}}
Note:  May be danced as a Reel or Strathspey', 0);
INSERT INTO 'dancecrib' VALUES (5500, '2013-08-21 08:31:08.41077+00', '2023-02-04 01:20:12.733765+00', 14556, 3, NULL, 'ace', '1-8::
    1s+2s also 4s+5s dance RH across to left & back as 3s set & cross RH
    then 3L casts up to top in middle facing down as 3M casts to bottom
    in middle facing up & set
9-16::
    1L+2L & 1M+2M (both couples in Prom hold) dance LSh reel of 3 across
    with 3L _while_ 4M+5M & 4L+5L dances likewise with 3M
17-24::
    3s pass LSh & reels of 3 across with other couples
25-32::
    3s advance & turn 2H _while_ 1s+2s also 4s+5s Set+Link, 3s dance
    down & turn 2H into 4th places _while_ 1s+5s Set+Link.  2 5 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (8585, '2015-02-13 12:47:47.504926+00', '2023-02-04 01:20:12.800276+00', 15641, 3, NULL, 'ace', '1-8::
    1s lead down, cross below 3s, cast up to 2nd place opp. sides (2s
    step up 3-4).  2s+1s+3s Adv+Ret (1 step), turn partners 2H
9-16::
    1s lead up, cross, cast to 2nd place own sides, 2s+1s+3s Adv+Ret (1
    step), turn partners 2H
17-24::
    2s+1s+3s circle 6H round and back
25-32::
    2s+1s dance all-round (diamond) Poussette', 0);
INSERT INTO 'dancecrib' VALUES (9733, '2017-04-06 08:39:48.064101+00', '2023-02-04 01:20:12.829107+00', 17654, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole to finish 1L facing 2L (in 1st place) & 1M
    facing 3M on sides
9-16::
    2s+1s+3s dance RSh reels of 3 on sides
17-24::
    1L+2s & 1M+3s dance RH across, 1s pass RSh to dance LH across with
    other couple
25-32::
    2s+1s+3s circle 6H round and back', 4);
INSERT INTO 'dancecrib' VALUES (14288, '2021-09-08 00:19:54.965957+00', '2023-02-04 01:20:12.850394+00', 20425, 3, NULL, 'ace', '1-4::
    »Flirt & Cast«:
::
    1L+2M also 4L+5M dance towards each other (1 step), pull back RSh,
    dance back to sides & cast right as partners dance 1 place to right,
    pull back RSh to face in
5-8::
    2s+1s also 5s+4s dance RH across.  2 1 3 5 4
9-16::
    1s+5s dance 1/2 R&L (omit polite turn) _while_ bars 11-12 3s Adv+Ret
    (1 step each); 1s+5s  turn partner 1.1/2 RH to end 2 5 3 1 4 (1s
    face out)
17-24::
    3s+1s+4s (bottom 3 couples) dance Promenade (Chaperoned) Chain
    progression:
::
    _17-18_   3s & 4s 3/4 turn partner RH into middle _while_ 1s dance
    clockwise 1/4 round the set picking up 3L/4M …
::
    _19-22_   who promenade 1/2 way clockwise _while_ middle people (3M
    + 2L) turn LH 1.1/2.
::
    _23-24_   3s & 4s turn partner RH 3/4 to own sides _while_ 1s dance
    clockwise 1/4 round to end in 2nd place. 2 5 4 1 3
25-32::
    2s+5s+4L also 4M+1s+3s circle 5H round to left (2 bars), all set;
    all continue 5H round to left to end 2 5 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5502, '2013-08-21 08:31:08.428632+00', '2023-02-04 01:20:12.863469+00', 2587, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place & turn RH to end facing out (Man up & Lady
    down)
9-16::
    1s dance reels of 3 on own sides & all 3 couples end in prom hold
    facing up
17-24::
    2s+1s+3s Promenade to end 1s facing up in middle (2nd place) with 2s
    & 3s facing each other on sides
25-32::
    1s dance up between 2s & dance a full Fig of 8 on sides as 2s+3s
    dance R&L starting by changing places RH on sides', 0);
INSERT INTO 'dancecrib' VALUES (14526, '2022-01-10 02:19:25.604932+00', '2023-02-04 01:20:12.880373+00', 17964, 3, NULL, 'ace', '1-8::
    1s+2s dance Rose Progression:
::
    _1-2_   1M+2L facing in diagonally set _while_ 2M+1L change places
    RH to face out
::
    _3-4_   1M+2L 1/2 turn 2H to face each other as 1L+2M dance into
    partners place
::
    _5-6_   1M+2L cast into each others place as 1L+2M 1/2 turn 2H to
    face each other
::
    _7-8_   1M+2L dance into 2nd/1st place own side _while_ 2M+1L cast
    to right to new places, 1M faces out.  2 1 3
9-16::
    Reels of 3 on sides, 1s RSh to 2s to start, 1s pass LSh to face 1st
    corners (1L through 2nd place, 1M from between 3s)
17-24::
    1s dance ''Hello-Goodbye'' setting & Petronella to 2nd place own side
25-32::
    1s+3s dance Tournee:
::
    1s+3s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 3s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (3s RH, 1s LH) & dance
    out to places.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5501, '2013-08-21 08:31:08.420571+00', '2023-02-21 23:06:52.129775+00', 11635, 3, NULL, 'ace', '1-8::

    1s set advancing, dance down between 2s, behind 3s & lead up to face

    1st corners

9-16::

    1s change places RH with corners, corners pass LH in centre, change

    places RH with 1s & 1s turn LH to face 2nd corners

17-24::

    Repeat above Fig with 2nd corners with 1s ending 2nd place opposite

    sides

25-32::

    3s+1s+2s circle 6H round to right 1/2 way & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (13873, '2021-04-05 00:18:20.839321+00', '2023-02-04 01:18:21.666782+00', 19496, 3, NULL, 'ace', '1-8::
    1s dance down, cast up round 3s (2s step up); all turn partners 2H
    into prom hold facing up
9-16::
    2s+1s+3s promenade
17-24::
    1L+2s & 1M+3s dance RH across, 1s pass RSh to dance LH across with
    other couple
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5503, '2013-08-21 08:31:08.436801+00', '2023-02-04 01:20:12.90754+00', 10672, 3, NULL, 'ace', '1-8::
    1M dance LSh reel of 3 with 2s & 1M ends facing down between 3s
9-16::
    1L dances RSh reel of 3 with 2s _while_ 1M dances RSh reel of 3 with
    3s, 1L ends between 2s (1st place) & 1M between 3s facing down
17-24::
    1s dance RSh round 2M/3M & in to face 1st corners, turn corners RH
    (4 bars) & end facing 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (9364, '2016-10-06 07:18:28.582476+00', '2023-02-04 01:20:12.934638+00', 17091, 3, NULL, 'ace', '1-8::
    All dance Interlocking reels of 4
9-16::
    Men dance RH across & dance out to chase clockwise 1/2 way as Ladies
    dance clockwise 1/2 way & dance RH across to end by partner
17-24::
    1s+3s dance 1/2 Men''s Chain, 2s+4s dance 1/2 Men''s Chain
25-32::
    All set & Men dance anticlockwise to next Ladies'' place _while_
    Ladies cast clockwise to next Man''s place, all turn partners RH
    ready to repeat', 0);
INSERT INTO 'dancecrib' VALUES (5504, '2013-08-21 08:31:08.471166+00', '2023-02-04 01:20:13.0142+00', 2589, 3, NULL, 'ace', '1-8::
    All 1/2 turn 2H to face up & all set, 1s cast to 3rd place & lead up
    to face 1st corner (pstn) _while_ 2s lead to top, cross & cast to
    3rd place _while_ 3s lead up to top, cross & loop round to 1st
    place.  3(1)2
9-16::
    1s dance ''Hello-Goodbye'' setting & 1s end facing own side LSh to LSh
17-24::
    1s dance RH across (1M with top cpl & 1L with cpl in 3rd pl), 1s
    (followed by 3s/2s) dance diagonally down/up passing LSh to change
    ends & loop round to left to end 1s in 2nd place.  2(1)3
25-32::
    1s dance LH across (1M with top cpl & 1L with cpl in 3rd pl), 1s
    (followed by 2s/3s) dance diagonally down/up passing RSh to change
    ends & loop round to right to end 1s in 2nd place all on own sides.
    3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (13163, '2020-09-15 00:19:52.104848+00', '2023-02-04 01:20:13.044812+00', 18500, 3, NULL, 'ace', '1-4::
    1s & 3s dance down between couple below them & cast back to places
5-8::
    All dance back to back with right arm over left (Hornpipe style)
9-12::
    2s & 4s dance up between couple above them & cast back to place.
13-16::
    Repeat bars 5-8
17-20::
    1s slip step down for 2 bars, up for 2 bars, open up hands to face
    out for
21-24::
    1s weave down to 4th place. 2s+3s+4s step up bars 23-24
25-32::
    All set, circle left for 3 bars. Bar 30: All dance into centre with
    left foot, pull back RSh to face out. Bar 31-32:  All spiral out &
    chase clockwise to own sides. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8782, '2015-06-15 11:40:45.878217+00', '2023-02-04 01:20:13.071873+00', 16220, 3, NULL, 'ace', '{{title}}
Chorus

1-16::
    All set, all dance Grand Chain back to places. All turn partners RH
    (4 bars)
17-24::
    1s & 3s join 2H with partner & slip step across (Men pass BtoB) and
    back (Ladies BtoB)
25-32::
    2s & 4s repeat 17-24

{{title}}
Dance

33-40::
    1s & 3s set twice and birl
41-48::
    2s & 4s set twice & birl
49-64::
    Tandem reel of 4 (Man follows Lady) with 1s passing 4s & 2s passing
    3s RSh to start
65-96::
    Chorus
97-104::
    1s+3s dance RH across, LH across
105-112::
    1M+2s+3L also 1L+4s+3M dance RH across, LH across
113-120::
    2s+4s dance RH across, LH across
121-128::
    2L+1s+4M also 2M+3s+4L dance RH across, LH across
129-160::
    Chorus
161-168::
    1s+3s change places (1s between 3s), turn out & dance back to place
    as 3s dance across, meet & dance back to place
169-176::
    All set & turn corner 2H, set & turn partner 2H (all PdeB)
177-184::
    2s+4s repeat bars 161-168
185-192::
    All set to & turn corner 2H, set to & turn partner 2H (all PdeB)', 0);
INSERT INTO 'dancecrib' VALUES (5506, '2013-08-21 08:31:08.48911+00', '2023-02-04 01:20:13.123495+00', 11519, 3, NULL, 'ace', '1-8::
    2s set, petronella turn into centre, set & turn RH to face 1st
    corners
9-16::
    2s dance 1/2 reel of 4 with 1st corners, pass LSh & 1/2 reel with
    2nd corners ending in 2nd place opposite sides. (3) (2) (1)
17-20::
    Top two Men''s side change places RH with bottom two on Ladies'' side,
    top 2 Ladies'' side change place LH with bottom two on Men''s side
21-24::
    Top two Men''s side change places RH with bottom two on Ladies'' side
    & all cross LH.  1 2 3
25-32::
    1s+2s Set+Link, 1s+3s Set+Link.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5507, '2013-08-21 08:31:08.505713+00', '2023-02-04 01:20:13.17461+00', 13736, 3, NULL, 'ace', '1-8::
    1s 1/2 turn 2s as 3s 1/2 turn 4s into double triangle positions
    (Ladies LH, Men RH), 1s 1/2 turn 4s as 3s 1/2 turn 5s into double
    triangle positions & all set.  2 4 1 5 3
9-16::
    2s & 3s cross RH & cast in 1 place, 2s+3s dance RH across.
    4(2)1(3)5
17-24::
    2s+1s+3s circle 6H round & back
25-32::
    All Adv+Ret, 4s & 5s cast in 1 place _while_ 2s & 3s cross to ends.
    2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (5508, '2013-08-21 08:31:08.515546+00', '2023-02-04 01:20:13.32788+00', 2593, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Grand Chain
9-16::
    1s+2s dance Poussette.  2 1 3
17-24::
    2s+1s+3s circle 6H round & back 1s ending facing 1st corners
25-32::
    1s set to & turn 1st corners, set to & turn 2nd corners & end in
    double triangle pstns
33-40::
    1s dance Double Triangles', 0);
INSERT INTO 'dancecrib' VALUES (13991, '2021-05-03 00:19:50.680189+00', '2023-02-04 01:20:13.350971+00', 17979, 3, NULL, 'ace', '1-8::
    All 4 couples Adv+Ret (1 step each), 1s+2s & 3s+4s dance RH across,
    all 4 couples Adv+Ret (1 step each)
9-16::
    RSh reels of 4 on sides
17-20::
    1M+2L also 3M+4L cross RH, middle couples (1M+2M+3L+4L) set
21-24::
    1L+2M also 3L+4M cross LH, middle couples (1s+4s) set.  (2) (1) (4)
    (3)
25-32::
    1s+4s circle 4H round to left; 1L followed by 4L dance out of top &
    cast to 3rd/2nd place own side _while_ 4M followed by 1M dance out
    of bottom, cast up to 2nd/3rd place own side. (2) 4 1 (3
33-40::
    4s+1s turn partner 1.1/2 RH; 2s+4s+1s+3s circle 8H 1/2 round to left', 0);
INSERT INTO 'dancecrib' VALUES (8059, '2013-10-01 08:46:53.953914+00', '2023-02-04 01:20:13.378005+00', 13300, 3, NULL, 'ace', '1-8::
    1s cast to 2nd place & dance 1/2 Fig of 8 round 2s, 1s dance LSh
    round partner to face 1st corner
9-16::
    1s+1st corners dance 1/2 diag Reel of 4 & 1s end passing LSh to face
    2nd corners, 1s dance 1/2 diag Reel of 4 & end facing 3rd corners
    (pstn)
17-20::
    1s dance RSh round 3rd corner (pstn) & turn about to 1M facing up &
    1L down as 2M+3L (in 3rd corner places) pass 1s RSh & 3/4 turn RH &
    dance into 4th corner (pstn) as 2nd corner dancers set & dance on 1
    corner place clockwise
21-24::
    1s dance RSh round 2nd corner position to end in 2nd place opposite
    side _while_ 2M+3L having passed 1s 3/4 turn RH & dance to original
    corner positions _while_ 2L+3M set & dance on 1 place clockwise to
    original corner position  2 (1) 3
25-32::
    1s dance Reels of 3 on opposite sides (LSh to 1st corner) & end
    crossing RH  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8831, '2015-08-13 20:33:16.573304+00', '2023-02-04 01:18:23.688087+00', 13120, 3, NULL, 'ace', '1-8::
    1s cross down (2s step up) to dance Double Triangles (6 bars). 1s
    finish on own sides, 2nd place.  2s face 1s & 3s face 4s
9-16::
    Reels of 4 on sides, Ladies pass LSh, Men RSh
17-24::
    All set, Men make arches & all cross passing prtnr RSh.  Repeat with
    Ladies making arches but 1s+2s remain in centre 2H joined ready for
    ...
25-32::
    1s+2s dance Poussette
33-40::
    1s cross RH, cast to 4th place & turn RH 1.1/2 times (2s+3s+4s step
    up 35-36)
41-48::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5477, '2013-08-21 08:31:08.007491+00', '2023-02-04 01:20:11.208115+00', 2544, 3, NULL, 'ace', '1-8::
    1s set advancing & turn 2H, lead down crossing & cast up to 1st
    place opposite sides
9-16::
    1s+2s dance 3/4 R&L, join hands on sides & Adv (1 step) +Ret (1
    step)
17-24::
    2s+1s set advancing to partner & turn 2H, 1s cast up & dance down to
    2nd place opp sides _while_ 2s cross down & cast up to top opp
    sides. (2) (1)
25-32::
    2s+1s dance 3/4 R&L & circle left 1/2 way. End 2 1', 0);
INSERT INTO 'dancecrib' VALUES (12917, '2020-07-01 00:19:46.428816+00', '2023-02-04 01:20:13.408151+00', 2597, 3, NULL, 'ace', '{{explanation}}
1st figure

1-8::
    All circle 6H round & back
9-16::
    Men dance RH across back to places, men turn partner LH
17-24::
    Ladies dance LH across back to places, turn partner 3/4 RH into
    promenade hold facing clockwise (ladies on partner''s right)
25-32::
    All promenade round, on bar 30 drop RH to face partner. Turn partner
    3/4 LH to places

{{explanation}}
2nd figure

1-12::
    Ladies'' Star Chain:
::
    Ladies pass in front of partners, dance RH across 2 places _while_
    Men dance into their partner''s place (bars1-2). Ladies 1/2 LH turn
    Man on their right. Repeat this movement twice more
13-16::
    All set to partners twice
17-28::
    Men''s Star Chain:
::
    Men pass in front of partners, dance LH across 2 places, RH turn
    Lady on their left. Repeat this movement twice
29-32::
    All set to partners twice

{{explanation}}
3rd Figure

1-6::
    All dance Grand Chain
7-8::
    All set to partners
9-16::
    Men dance reel of 3 (1M passes 3M RSh to start). At end Men pick up
    partner in promenade hold ready for...
17-24::
    All dance reel of 3 (1s pass 3s RSh to start)
25-32::
    Ladies dance reel of 3 (1L passes 2L LSh to start). At end Ladies
    pick up partners in promenade hold ready for...

{{explanation}}
4th Figure

1-6::
    All promenade round clockwise, on bar 6 drop right hands to face
    partners (Ladies with back to centre)
7-8::
    All turn partner 3/4 LH to place
9-16::
    Ladies dance LH across back to places, turn partners RH
17-24::
    Men dance RH across back to places, turn partners LH
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5510, '2013-08-21 08:31:08.534005+00', '2023-02-04 01:20:13.49168+00', 2602, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    1L also 4L cast behind their own lines to other end & cross into
    each others place _while_ other 6 dancers set diagonally to each
    other & change places RH, 2M also 3M cast behind their own lines to
    other end & cross into each others place _while_ other 6 dancers set
    diagonally to each other & change places RH.  3(4)1(2)
9-16::
    All circle 8H round & back
17-24::
    3L followed by 4M+1L+2M cast to other end of set _while_ 2L followed
    1M+4L+3M cast to other end (2) 1 (4) 3, 2s+1s also 4s+3s circle 4H
    to left
25-32::
    2s+1s also 4s+3s dance RH across for 3 bars, LH back & end couples
    (2s & 3s) cast in 1 place _while_ 1s & 4s cross to end places
33-40::
    1s+2s also 3s+4s turn on sides nearer hand (centre cpl between outer
    cpls), 1s+2s also 3+4s dance 1/2 double Fig of 8 (1s & 4s casting to
    start)
41-48::
    All dance interlocking Allemandes-
::
    1s & 2s dance normal Allemande but end in 3rd/1st places _while_
    3s+4s Allemande (down) up to 4th/2nd places to end 2(4)1(3)', 0);
INSERT INTO 'dancecrib' VALUES (5511, '2013-08-21 08:31:08.542145+00', '2023-02-04 01:20:13.511387+00', 11520, 3, NULL, 'ace', '1-8::
    1s+3s dance 1/2 R&L, chase anticlockwise back to places as 2s+4s
    Adv+Ret
9-16::
    2s+4s repeat with 1s+3s Adv+Ret
17-24::
    All set, Petronella-in-tandem to next place to end BtoB with partner
    (facing corner), set to corner & turn 2H.  2 3 4 1
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13408, '2020-12-02 01:19:56.47662+00', '2023-02-04 01:20:13.541807+00', 19155, 3, NULL, 'ace', '1-8::
    1s lead down & back up, remain in centre facing up
9-16::
    1s+2s+3s dance reels of 3 on sides giving hands (1s cast, 2s dance
    in/up, 3s out/up)
17-24::
    1s cast (2s step up), 1s dance RSh round each other 1L faces 2s (at
    top), 1M faces 3s; 1L+2s also 1M+3s dance 3H round to left, flowing
    into …
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8586, '2015-02-13 12:47:47.708993+00', '2023-02-04 01:20:13.577604+00', 15402, 3, NULL, 'ace', '1-8::
    1s cross RH, cast. 1s turn RH once round finishing in Allemande hold
    _while_ 2s+3s set & turn RH 1/2 way into Allemande hold, all couples
    facing down
9-16::
    2s+1s+3s dance Allemande finishing on opposite sides (3) (1) (2)
17-24::
    3s+1s+2s Set+Link finishing in lines across; All turn dancer
    opposite 2H once round
25-32::
    2s+1s+3s Set+Link; 2s+1s+3s turn partners 2H once round', 0);
INSERT INTO 'dancecrib' VALUES (15225, '2022-11-03 01:19:56.905571+00', '2023-02-04 01:20:13.615216+00', 21157, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s cross LH, cast (3s step up).  2 3
    1
9-20::
    2s+3s+1s dance R&L
21-24::
    1s dance 1/2 Fig of 8 up round 3s.  2 3 (1)
25-32::
    All dance reels of 3 on sides (1s cross up, 2s in/down, 3s out/up to
    start).  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (11192, '2018-09-30 22:19:49.515103+00', '2023-02-04 01:20:13.805853+00', 8597, 3, NULL, 'ace', '{{explanation}}
Note:  can also be danced as S2x32 or 3x32 with 2 or 3 couple set

1-8::
    All set, cross RH; all set, cross RH back to place
9-16::
    1s followed by 2s (who dance up to follow) dance down middle & back
    (2s leading). 1s take prom hold _while_ 2s separate & cast out into
    …
17-24::
    1s in prom hold dance reel of 3 across with 2s, passing 2L by RSh to
    start.  1s end in middle facing up
25-32::
    1s dance out of top of set, separate & cast to bottom (others step
    up 27-28) & 1s turn 2H once round', 0);
INSERT INTO 'dancecrib' VALUES (11449, '2019-01-01 01:56:53.167613+00', '2023-02-04 01:20:13.83058+00', 19040, 3, NULL, 'ace', '1-8::
    1s lead down & back to top
9-16::
    1s+2s dance Allemande & 1s end facing 1st corners
17-24::
    1s turn 1st corner RH & pass RSh to face 2nd corners, 1s turn 2nd
    corners RH & pass RSh to 2nd place own sides
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13164, '2020-09-15 00:19:52.946364+00', '2023-02-04 01:20:14.045346+00', 16568, 3, NULL, 'ace', '1-4::
    1s+2s set, facing diagonally in Bar 2, 1M+2L cast into centre, 1M
    above 1st place, 2L below 2nd place _while_ 1L+2M turn 3/4 RH to
    face partner
5-8::
    1s+2s dance 1/2 reel of 4
9-16::
    2s+1s set & petronella turn to  opp sides; 1s+2s dance 1/2 R&L
17-24::
    1M followed by 1L casts & crosses to 2L place (2s step up 19-20); 1s
    pull back LSh, 1L followed by 1M casts & crosses to 3rd place own
    side (3s step up 23-24)
25-32::
    1s followed by 3s dance up, cast round 2s, dance down & cast up to
    2nd/3rd place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5514, '2013-08-21 08:31:08.717196+00', '2023-02-04 01:20:14.3574+00', 15075, 3, NULL, 'ace', '1-8::
    1s+2s dance the Tourbillon:
::
    1s & 2s 1/2 turn ptnrs 2H, 1M & 2L lead ptnrs by nearer hand 1 place
    cl''wise to end 1s on Ladies'' side & 2s Men''s side, 1s set to 2s
::
    1s & 2s 1/2 turn ptnrs 2H & lead ptnrs on 1 place clockwise & 2s+1s
    cross RH (2s to own sides 1s into middle facing down)
9-16::
    1s dance reflection reels on own sides (1s down between 3s to start)
    & end facing 1st corners
17-24::
    1s Pass+Turn with 1st corners & pass RSh to face 2nd corners, dance
    Pass+Turn with 2nd corners & end 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5515, '2013-08-21 08:31:08.725541+00', '2023-02-04 01:20:14.372366+00', 2607, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, set & cross back RH
9-16::
    1s+3s dance Double Fig of 8 round 2s (1s cross down to start)
17-20::
    1s dance down middle, cross over & cast up to 2nd pl _while_ 2s set
    & cross RH to 3rd pl _while_ 3s cast up to 1st pl & cross RH (as
    Muirland W)
21-24::
    3s+1s+2s dance 1/2 reel of 3 on sides (3s out & down & 1s cross up
    to own sides to start).  (2) 1 (3)
25-28::
    1s+3s change places on sides (1s between 3s) & 3s cross down to 3rd
    place own side _while_ 1s cast to 2nd place
29-32::
    2s+1s change places on sides (1s between 2s) & 2s cross up to 1st
    place own side _while_ 1s cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (13082, '2020-08-10 00:19:48.075564+00', '2023-02-04 01:20:14.421131+00', 2608, 3, NULL, 'ace', '1-8::
    1s lead down, cross & cast up round 3s to 2nd place opp sides (2s
    step up 3-4); 1s turn 1.1/4 RH to end in centre facing 4th corner
    (1M+3M, 1L+2L)
9-16::
    1M+3s & 1L+2s dance RSh reels of 3 across. Bars 15-16: 1s turn 1.1/4
    RH to face 4th corner again
17-24::
    1s dance reels of 3 on own side (RSh to 4th corner to start). Bars
    23-24: 1s turn 1.1/4 LH
25-32::
    1M+3s & 1L+2s dance RH across, 1s pass RSH to dance LH across with
    other couple.  (1s remain in middle to start 2nd turn)', 0);
INSERT INTO 'dancecrib' VALUES (5517, '2013-08-21 08:31:08.743323+00', '2023-02-04 01:20:14.472125+00', 11521, 3, NULL, 'ace', '1-8::
    2M followed by partners casts up & dances down in front of Ladies to
    3L place (partner to own place) _while_ 3L followed by partner down
    casts down & dances up in front of Men to 2nd place (partner to own
    place), all turn LH on sides (persons in 1st+2nd pl & 3rd+4th pl)
9-16::
    2s+3s dance RH across, 3L followed by partner dances up & casts down
    behind Ladies to 3rd place & crosses to opp side _while_ 2M followed
    by partner dances down & casts up behind Men to 2nd place & crosses
    to opp side.  1 (2)(3) 4
17-24::
    1s+2s also 3s+4s set & dance RH across 1/2 way, 1s+4s set & dance LH
    across 1/2 way.  2 4 1 3
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5518, '2013-08-21 08:31:08.751811+00', '2023-02-04 01:20:14.486847+00', 2611, 3, NULL, 'ace', '1-8::
    All set to partners & cast 1 place (Men cl''wise & Ladies
    Anticl''wise) & repeat to end facing partner on opposite side of
    dance
9-16::
    1s+4s also 2s+3s dance diagonal reels of 4 & end in diagonal lines
    of 4 (facing)
17-24::
    All Adv+Ret, 1s & 3s dance clockwise to just past their original
    place _while_ 2s & 4s dance in, 2s follow 1s to 4th place _while_ 4s
    follow 3s to 2nd place & all end in 2 diagonal, lines of 4 [1s on
    right of 4s, 3s on right of 2s (2s & 4s dance small circles)]
25-32::
    All Adv+Ret, 2s & 4s dance clockwise to their original places
    _while_ 1s & 3s dance in, 1s follow 2s & 3s follow 4s to original
    places (1s & 3s dance small circles)
33-40::
    1s+3s dance RH across _while_ 2s & 4s chase clockwise 1/2 way, 1s+4s
    dance RH across _while_ 1s & 3s chase clockwise 1/2 way
41-48::
    Repeat to original places
49-56::
    All circle 8H round & back
57-64::
    With both hands joined with partner set HS into centre & out, turn
    partner LH 1.1/4 times to end in double wheel with Ladies in middle
    giving RH
65-72::
    All dance round clockwise for 3 bars then Men cast to right & Ladies
    cast left (L dance under partners arm) to form double wheel facing
    anticlockwise with Men in centre & all dance round to places
73-80::
    All Promenade round anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (5520, '2013-08-21 08:31:08.768169+00', '2023-02-04 01:20:14.515875+00', 11420, 3, NULL, 'ace', '1-4::
    1s+2s 1/2 turn partners 2H & circle 4H round to left 1/2 way  2 1 3
5-8::
    2M followed by 1M+3M dance up, across & down Ladies'' side _while_
    Ladies advance 1 step, set turning right about & retire to Men''s
    side
9-12::
    Top 2 Men & bottom 2 Ladies cross diagonally LH _while_ 2s set, all
    change places LH with opposite person
13-16::
    Same dancers cross diagonally RH _while_ 2s set & all 1/2 turn
    opposite person RH into allemande hold facing down
17-24::
    All dance down 2 steps, turn about & dance backwards 2 steps, dance
    up 2 steps, turn about & dance backwards (as Gay Gordons)
25-32::
    All turn RH (4 bars), top Lady (2L) followed by 1L+3L dance up,
    across & down own side _while_ Men advance 1 step, set turning right
    about & retire to own side', 0);
INSERT INTO 'dancecrib' VALUES (5521, '2013-08-21 08:31:08.776203+00', '2023-02-04 01:20:14.537043+00', 2613, 3, NULL, 'ace', '1-8::
    2s dance RH across (Man with 2s & Lady with 3s) continue RH across &
    2M followed by 1s dances down Ladies'' side to 3rd place _while_ 2L
    followed by 3s dance up Men''s side to top
9-16::
    1s+2s+3s dance 3 couple R&L for 8 bars to end (3) 2 (1)
17-24::
    1s cross RH, cast to top (own sides) _while_ 3s turn RH 1.1/2 times
    to face down, 1s turn RH into 2nd place (2s move up) _while_ 3s
    dance down & loop into original places
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5522, '2013-08-21 08:31:08.784231+00', '2023-02-04 01:20:14.580447+00', 9061, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left & Set+Link
9-16::
    1s dance reels on own sides (LSh to 3rd person
17-24::
    1s set, 3/4 turn 2H & dance RH across (Lady with 2s & Man with 3s)
25-32::
    2s+1s+3s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (14795, '2022-05-05 00:19:53.664651+00', '2023-02-04 01:20:14.597185+00', 17106, 3, NULL, 'ace', '1-8::
    1s set, dance 6 bars of Fig 8 round 2s, ending in 2nd place own side
    (2s step up 7-8)
9-20::
    2s+1s+3s dance R&L for 3 couples
21-24::
    1s set, turn 1/4 LH ready for …
25-32::
    1L+2s & 1M+3s dance RH across, 1s pass RSh to dance LH across with
    other couple. All end in prom hold facing up
33-40::
    2s+1s+3s dance Promenade. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5489, '2013-08-21 08:31:08.141998+00', '2023-02-04 01:20:11.89615+00', 2575, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides 1s
    crossing down to start & end BtoB in 2nd place facing opposite sides
9-16::
    Set twice as in Double Triangles, turn 1st corners RH & end BtoB (in
    crown triangle pstns Man facing 2s)
17-24::
    Set twice, turn 2nd corners RH & 1s end facing down in centre
25-32::
    1s dance down below 3s, cast up to 2nd place & 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5523, '2013-08-21 08:31:08.794956+00', '2023-02-04 01:20:14.626286+00', 2616, 3, NULL, 'ace', '1-4::
    1s cast 1 place & set advancing to 1st corner
5-16::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s in the middle
    facing 3rd corner positions
17-24::
    1s dance 1/2 diagonal Reel of 4 with 3rd corner, pass RSh & dance
    1/2 diagonal Reel with 4th corners
25-32::
    1s dance RH hands across (L with 2s & M with 3s) & 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5524, '2013-08-21 08:31:08.804765+00', '2023-02-04 01:20:14.647246+00', 12633, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, dance down between 3s & cast back to 2nd
    places
9-16::
    1s pass LSh & dance 1/2 reel of 4 with 1st corners, pass RSh & dance
    1/2 reel of with 2nd corners ending in 2nd place opposite sides
17-20::
    1s petronella turn as 3s+2s change places RH on sides into lines
    across & all set down/up
21-24::
    1s petronella turn as 2s+3s cross RH to own sides & all set
25-32::
    1s dance up between 2s & cast to 2nd place, 1s+3s dance 1/2 Diamond
    Poussette.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (12725, '2020-04-11 10:51:29.715145+00', '2023-02-04 01:20:14.678072+00', 17889, 3, NULL, 'ace', '{{explanation}}
2s & 3s start on opp sides

1-4::
    1s cross down RH _while_ 4s cross up (2s/3s step down/up), 1s+4s
    change places LH on sides
5-8::
    4s dance 1/2 Fig 8 up round 2s _while_ 1s dance 1/2 Fig 8 down round
    3s.  (2) 4 1 (3)
9-16::
    4s+1s (middle couple) set & dance 1/2 RH across; 2s+1s (at top) &
    4s+3s (at bottom) set & dance 1/2 LH across.  End 1 2 3 4
17-24::
    All dance reels of 4 on sides (1s+2s & 3s+4s pass LSh to start)
25-28::
    1s & 4s cross RH with partner, 1s+2s & 3s+4s change places LH on
    sides
29-32::
    2s (top) & 3s (bottom) turn partner RH _while_ 1s+4s turn 1.1/2 RH
    on sides.  End 2 (4) (1) 3', 0);
INSERT INTO 'dancecrib' VALUES (14653, '2022-03-07 02:19:53.552511+00', '2023-02-04 01:20:14.711743+00', 16599, 3, NULL, 'ace', '1-8::
    1s set, cast below 3s & lead up to 1st corners.(2s step up bars 5-6)
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh to dance
    1/2 diagonal reel of 4 with 2nd corners & finish in 2nd place
    opposite sides (3) (1) (2)
17-24::
    1s (centre couple) change places RH with person diagonally to Right
    (1M with 3L, 2M with 1L)
::
    New centre couple change LH with person diagonally to Left (2M with
    3M, 2L with 3L)
::
    New centre couple change RH with person diagonally to Right (2L with
    1M, 3M with 1L)
::
    All cross LH to own sides 2 1 3
25-32::
    2s+1s+3s dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5526, '2013-08-21 08:31:08.827364+00', '2023-02-04 01:20:14.783153+00', 2629, 3, NULL, 'ace', '1-8::
    1s+2s 1/2 turn (Men RH, Ladies LH) into Double Triangle position &
    2s+1s+3s set; 1M+3M also 1L+2L turn LH 1.1/2 times to end 1M between
    3s, 1L between 2s facing 1st corner
9-16::
    1s dance RSh reels of 3 across & end in 2nd place opp sides facing
    2nd corners
17-24::
    1s dance LSh reels of 3 on opposite sides & end in centre joining LH
    with partner, RH with 1st corner
25-32::
    1s Bal-in-Line with 1st corners, 1s turn LH 1.1/4 times; 1s
    Bal-in-Line with 2nd corners & 1s turn LH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (5527, '2013-08-21 08:31:08.836979+00', '2023-02-04 01:20:14.88288+00', 2631, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH, set & cross back RH
9-16::
    1s lead down the middle for 3 steps, back to top, cast to 2nd place
    & face 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners ending between 2s
    & 3s on opposite sides
25-32::
    2s+1s+3s Adv+Ret, 1s turn 2H 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (5528, '2013-08-21 08:31:08.845085+00', '2023-02-04 01:20:15.07296+00', 13322, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 double Fig of 8 (1s & 3s cross down to
    start) & dance 1/2 reel of 4 on sides (Ladies RSh & Men LSh).
    (4)(3)(2)(1)
9-16::
    4s+3s also 2s+1s dance 1/2 double Fig of 8 (4s & 2s cross down to
    start) & dance 1/2 reel of 4 on sides (Men RSh & Ladies LSh).  1 2 3
    4
17-24::
    1s+2s also 3s+4s Set+Link, 1s+4s Set+Link
25-32::
    2s+4s also 1s+3s dance R&L but Men end changing places RH at end of
    R&L (not LH), ready to start again.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5529, '2013-08-21 08:31:08.854753+00', '2023-02-04 01:20:15.089188+00', 2636, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 2 places (2s step up); 1s cross LH & cast up to
    2nd place own side Lady facing up & Man facing down
9-24::
    2s & 3s dance 2 full reels of 3 on own sides _while_
::
    _9-12_   1s dance 1/2 RSh reel of 3 on own side (1L up, 1M down)
    back to 2nd place own side
::
    _13-16_ 1L at top & 1M at bottom dance 1/2 LSh reels of 3 across
    (LSh to 1st corner pstn) finishing in 2nd place opp side
::
    _17-20_ 1s dance 1/2 RSh reel of 3 on opp sides (1M up, 1L down)
    back to 2nd place opp side
::
    _21-24_ 1M at top & 1L at bottom dance 1/2 LSh reels of 3 across
    (LSh to 3rd corner pstn) finishing in 2nd place own side.  2 1 3
25-32::
    1s+3s dance 1/2 R&L; 1s+3s turn 2H 1.1/2 times to own sides.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5539, '2013-08-21 08:31:08.933928+00', '2023-02-04 01:20:15.569785+00', 2651, 3, NULL, 'ace', '1-8::
    1M+2L Adv+Ret & turn RH
9-16::
    2M+1L Adv+Ret & turn RH
17-24::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of 8 round 2s (1s cross
    up)
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8697, '2015-03-03 08:47:38.009679+00', '2023-02-04 01:20:15.941633+00', 15279, 3, NULL, 'ace', '1-8::
    1L+2L+3L dance round partners RSh & back to place (6 bars).  All
    cross RH with partners
9-16::
    1M+2M+3M repeat bars 1-8
17-24::
    1s cast 2 places, dance up middle & cast to 2nd place (2s step up
    17-18)
25-32::
    2s+1s+3s Adv+Ret & all turn partners RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5494, '2013-08-21 08:31:08.306248+00', '2023-02-04 01:20:12.374966+00', 2583, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, set & 1/2 turn LH into prom hold facing up
9-16::
    1s+2s+3s Promenade & 1s end casting to 3rd place
17-24::
    2s+1s dance double Fig of 8 round 3s (1s cross up to start)
25-32::
    1s & 4s set, turn 2H, 1s followed by 4s dance up between 3s & cast
    down (1s to 4th place & 4s to 3rd place)', 0);
INSERT INTO 'dancecrib' VALUES (13167, '2020-09-15 00:19:53.849396+00', '2023-02-04 01:20:15.11154+00', 16018, 3, NULL, 'ace', '1-8::
    1s+2s Poussette
9-16::
    1s dance in & cast (2s step up 3-4); meet, dance down between 3s &
    cast up to face 1st corners
17-18::
    1s+1st corners set advancing to change places. 1s pull back RSh to
    face across, corners finish in the centre facing each other.
19-20::
    1L+2L & 3M+1M cross RH to opp _while_ 2M+3L dance round each other
    RSh to face 2nd corner pstns
21-22::
    :       2M+3L set advancing to 2nd corners to change places, 1s
    finish in centre facing each other
23-24::
    1s dance RSh round each other into 2nd place opp sides. (2) (1) (3)
25-32::
    All set, all dance RSh 1/2 round partners & face partner, pull back
    RSh & dance out to own side. All set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8326, '2014-07-29 12:59:03.817924+00', '2023-02-04 01:20:15.267261+00', 15428, 3, NULL, 'ace', '{{explanation}}
Round the Room 3 facing 3

1-8::
    All Adv+Ret, All Advance, end persons Retire, centre persons
    stand/set
9-16::
    Centres dance own choice/style _while_ ends dance R&L around them
    (RH to person opposite to start)
17-24::
    Centres turn person on Right (RH) and person on Left (LH)
::
    OR
::
    Reels of 3, centre person passes person on Right by RSh to start
25-32::
    All turn opp. person RH 1.1/2 times to face new line 0f 3, all set,
    cross RH with person opposite to face new line of 3 dancers', 0);
INSERT INTO 'dancecrib' VALUES (13168, '2020-09-15 00:19:54.001645+00', '2023-02-04 01:20:15.285163+00', 18492, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link; 1s+3s Set+Link.  3s face down, 1s face up
9-16::
    2s+3s+1s dance RSh reels of 3 on sides (1s+3s pass RSh to start) 1M
    faces out
17-24::
    1M followed by 1L casts up, dances across to 2nd place opp side (3s
    step down); 1M+2s also 1L+3s dance RH across.  1s end in centre
    facing each other
25-32::
    1s set, petronella turn to own side; 2s+1s+3s turn partner 2H', 0);
INSERT INTO 'dancecrib' VALUES (5530, '2013-08-21 08:31:08.862787+00', '2023-02-04 01:20:15.314331+00', 2642, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, set & cross back LH
9-16::
    2s followed by 1s lead down for 3, 1s followed by 2s lead up & 1s
    (prom hold) cast to 2nd place Men''s side _while_ 2s end at top
17-24::
    1s, in prom hold, dance 1/2 reel of 3 across with 3s (LSh to 3L) to
    end 2nd pl Ladies'' side. 1L dances 1/2 reel of 3 across with 2s (LSh
    to 2M) _while_ 1M dances 1/2 reel of 3 with 3s (RSh to 3L in 3M''s
    place)
25-32::
    1s (prom hold) dance 1/2 RSh reel of 3 across with 2s; 1s in centre
    turn RH to 2nd place own side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5531, '2013-08-21 08:31:08.87106+00', '2023-02-04 01:20:15.345355+00', 10072, 3, NULL, 'ace', '1-8::
    1s set, 1M casts 1 place, 1M+2L dance 1/2 Fig of 8 round 1L+2M to
    end beside partner (Lady on partners right)
9-16::
    1s+2s+3s set & circle 6H round to left for 2 bars, turn partner 2H &
    circle 6H round to left back to place (in circle formation)
17-24::
    _1_+2+3 Ladies set advancing, dance RH across & dance round partners
    (LSh) to place (in circle formation)
25-32::
    _1_+2+3 Men set advancing, dance RH across & turn partners LH to
    face anticl''wise with partner on right in prom hold
33-40::
    1s+2s+3s Promenade once round, 2s followed by 1s+3s dance down &
    drop LH to face up
41-46::
    3s followed by 1s+2s lead up & cast down on opp sides to (2) (1) (3)
47-48::
    2s cross RH _while_ 1s+3s dance 1/2 RH across      2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5533, '2013-08-21 08:31:08.885438+00', '2023-02-04 01:20:15.369394+00', 2644, 3, NULL, 'ace', '1-8::
    1s lead out on Men''s side, cast behind 2M, cross (2s step up) & lead
    out on Ladies'' side, cast down behind 3L, lead up to 2nd places on
    own sides
9-16::
    2s repeat 1- 8 commencing by dancing behind 1M & end in 2nd places
17-24::
    1s cross RH & cast (2s step up), dance down between 3s & cast up to
    2nd place on opposite sides
25-32::
    2s+1s+3s circle 6H round & back
33-40::
    1s set & dance 1/2 Fig of 8 round 2s to end in 2nd place on own
    sides
41-48::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5534, '2013-08-21 08:31:08.893503+00', '2023-02-04 01:20:15.391+00', 2645, 3, NULL, 'ace', '1-8::
    1M+2L set & turn 2H, 1L+2M repeat
9-16::
    1s lead down the middle & back to top
17-24::
    1s set & cast to 2nd place (2s step up) & 1s dance DoSiDo with
    partner
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5535, '2013-08-21 08:31:08.901566+00', '2023-02-04 01:20:15.411803+00', 9007, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across, 1s+3s set & dance 1/2 LH across
9-16::
    2s+1s dance Ladies Chain (up/down)
17-24::
    1L followed by partner casts up to 1st place & crosses to opposite
    side, 1s+2s+3s set & 1/2 turn RH ready for…
25-32::
    1s+2s+3s Promenade & 1s end casting to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (5537, '2013-08-21 08:31:08.917721+00', '2023-02-04 01:20:15.484676+00', 13580, 3, NULL, 'ace', '{{explanation}}
Round the Room, 3 facing 3

1-8::
    All circle 6H round & back
9-16::
    Centre persons dance RH across with dancers on the right, LH across
    with dancers on left
17-24::
    Corner dancers Adv+Ret on diagonal, centre dancers dance DoSiDo
25-32::
    All pass facing dancer RH & pass next dancer LH, all turn facing
    dancer RH once round', 0);
INSERT INTO 'dancecrib' VALUES (15332, '2022-12-19 01:20:02.772452+00', '2023-02-04 01:20:15.516524+00', 19665, 3, NULL, 'ace', '1-4::
    1s set, 1M casts to 2nd place as 1L dances Petronella turn to centre
    top (2s step up 3-4)
5-8::
    LIGO (L-shape) Set+Link:
::
    1L between 2s facing down & 1M between 2M & 3M on sides all join
    hands & set (in »L« shape), 2L dances to 3M''s place _while_
    1L+2M+1M+3M pull back RSh & chase clockwise 2 places round to new
    »L« shape, 1M between 2M+3M at top, 1L between 2M+3L on Ladies'' side
9-12::
    Repeat LIGO Set+Link: 3L dances to 1M''s place, others pull back RSh
    & chase clockwise 2 places to end 3M, 1M, 2M on Ladies'' side & 1L
    between 2s in 3rd place facing up
13-16::
    1s dance RSh 1/2 round each other then birl (or turn 1.1/2 RH) to
    face 1st corners (pstn)
17-24::
    1s dance 1/2 diag reel of 4 with 1st corners, pass LSh to face 2nd
    corners (pstn) & dance 1/2 diag reel of 4 with 2nd corners, 1s pass
    RSh to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5538, '2013-08-21 08:31:08.925875+00', '2023-02-04 01:20:15.549008+00', 12610, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig of 8 (1s cross down)
9-16::
    1s+2s+3s dance reels of 3 on sides (1s down between 2s to start)
17-24::
    1s cross RH & cast 1 place, 1s+3s turn RH on sides, 1s+2s turn LH on
    sides
25-32::
    1s+3s dance RH across 1/2 way, 2s+3s dance LH across 1/2 way, 2s+1s
    dance RH across 1/2 way & all set.  3(1)2
33-40::
    3s+1s+2s dance Snowball Grand Chain for 3 cpls to end 2 1 3 :
::
    3s cross RH & change places LH on side with 1s
::
    3s change places RH with 2s _while_ 1s cross RH
::
    3s cross LH _while_ 1s & 2s change places LH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3926, '2013-08-21 08:30:39.346476+00', '2023-02-04 01:18:21.700662+00', 9542, 3, NULL, 'ace', '1-8::
    All Ladies dance Fig of 8 passing in front of corner & behind
    opposite man
9-16::
    All dance Ladies'' Chain with Ladies dancing 1/2 RH across in centre
    & all end facing corners
17-24::
    All dance a reel all round the set giving RSh to corners to start
    (ie Grand Chain without hands)
25-32::
    All set to corners & turn 2H, repeat with partner
33-40::
    1s+3s set & cross RH, dance out & cast to right (L leading) into
    centre (L dancing round side couple but M thru side couple) & turn
    to face side cpl
41-48::
    All dance 6 bars of reel of 4 across & 1s also 3s dancing out &
    clockwise to opposite places as 2s & 4s dance out to own places
49-64::
    2s+4s repeat bars 33-48 ending 3 4 1 2
65-72::
    All Men dance Fig of 8 passing in front of corner & behind opposite
    Lady
73-80::
    All dance Men''s Chain with Men giving LH in centre
81-88::
    All set & 3/4 turn RH into prom hold, all Promenade 1/2 way round
    (to original places)
89-96::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14907, '2022-06-27 00:20:03.715997+00', '2023-02-04 01:20:15.589181+00', 16575, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate
9-16::
    1s Petronella turn to 1M between 3s facing up, 1L between 2s facing
    down, 1s set pulling back RSh to face 1st corner; 1s dance 1/2 reels
    of 3 across (RSh to 1st corner)
17-24::
    1s Petronella turn to 2nd place opp sides, set pulling back RSh to
    face 2nd corner; 1s dance 1/2 reels of 3 across (RSh to 2nd corner).
    (3) (1) (2)
25-32::
    3s+1s+2s Petronella turn into centre, all set with Men pulling back
    RSh to face up; all dance up & cast to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14908, '2022-06-27 00:20:03.734211+00', '2023-02-04 01:20:15.612587+00', 16577, 3, NULL, 'ace', '1-4::
    1s+3s Adv (2 step) & set turning inwards to face out of set
5-8::
    1s cast out to join side couples forming longways set - Men''s side:
    1L 4M 4L 3M, Ladies'' side: 1M 2L 2M 3L
9-12::
    All dance 1/2 RSh reels of 4 on sides
13-16::
    3L+2M, 2L+1M, 3M+4L & 4M+1L turn RH once round & face in
17-20::
    All cross RH with person opposite & chase clockwise to re-form
    square set.  2 3 4 1
21-24::
    All turn partner RH
25-32::
    All circle 8H round & back
33-36::
    2s+4s dance »Pass & Turn«:
::
    Men dance straight across set & curve into opposite Man''s place
    _while_ Ladies dance in, turn RH & dance back to place
37-40::
    1s+3s repeat 33-36
41-48::
    2s+4s dance 1/2 Ladies'' Chain; 1s+3s dance 1/2 Ladies'' Chain.  4 1 2
    3
49-52::
    All Men set _while_ Ladies Adv (2 steps) & clap, Ladies Ret _while_
    Men Adv (2 steps) & clap
53-56::
    Men face out & turn partner RH into promenade hold (Lady on Man''s
    right) all facing anticlockwise
57-64::
    All Promenade once round.  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (13169, '2020-09-15 00:19:54.312948+00', '2023-02-04 01:20:15.744183+00', 9431, 3, NULL, 'ace', '1-8::
    1s followed by 2s (who cast up) dance down between 3s, cast up, meet
    & dance up to top. 1s cast to 2nd place, 2s at top face out
9-16::
    Mirror reels of 3 on sides giving hands (1s in down, 3s out/up, 2s
    out/down). 2s & 3s dance loops at end
17-24::
    1s followed by 2s lead down, 2s divide then 1s followed by 2s lead
    up, remaining in middle ready for …
25-32::
    1s+2s dance Allemande.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5540, '2013-08-21 08:31:08.942143+00', '2023-02-04 01:20:15.781749+00', 12881, 3, NULL, 'ace', '1-8::
    All circle 8H round to left, slowing down as though to dance back
    but then accelerating to keep dancing same direction to place
9-16::
    Double Ladies'' Chain ending holding partner at arms length facing
    anticlockwise
17-24::
    All set inwards & outwards, Men pass partner in front to other hand.
    all set inwards & outwards, Ladies turn under arm to meet new Man
    who has advanced to meet her.
25-32::
    All Promenade with new partner to Mans original place
33-40::
    Repeat bars 17-24
41-48::
    Repeat bars 25-32 but end facing new partner
49-56::
    All dance Grand 1/2 way but clapping alternate hands instead of
    holding hands, then set.
57-64::
    Continue ''clapping'' Chain to place & turn new partner

{{explanation}}
Repeat with new partner', 0);
INSERT INTO 'dancecrib' VALUES (5542, '2013-08-21 08:31:08.958241+00', '2023-02-04 01:20:15.836178+00', 10059, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reel of 3 on sides (1s dance in & down to start)
9-16::
    1s cross down RH to double triangle position, set, cast down behind
    3s & dance up to 2nd place
17-24::
    1L dances LH across with 2M+3M _while_ 1M dances RH across with
    2L+3L, 1s cross to other side to continue the wheels
25-32::
    1s+2s dance double Fig of 8 (1s crossing up to start)', 0);
INSERT INTO 'dancecrib' VALUES (15226, '2022-11-03 01:19:58.764481+00', '2023-02-04 01:20:15.86489+00', 2667, 3, NULL, 'ace', '1-4::
    1M+2L set advancing and turn RH, 1M finishing in 2nd place (2M step
    up on 3-4)
5-8::
    1L+2M set advancing and turn LH, 1L finishing in 2nd place (2L step
    up on 7-8)
9-16::
    1M+2s dance reel of 3 across (begins 1M RSh to 2L and 2M casting)
17-24::
    1L and 2s dance a reel of 3 across (begins 1L LSh to 2M and 2L
    casting)
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (14796, '2022-05-05 00:19:54.746162+00', '2023-02-04 01:20:15.916832+00', 2673, 3, NULL, 'ace', '1-8::
    1M+2L+3M+4L advance into centre on diagonal (2 PdeB), join hands &
    set; 1M+2L also 3M+4L turn RH to finish facing partners on diagonal
9-16::
    1s+2s also 3s+4s dance diagonal reels of 4 ending in original places
17-24::
    1L+2M+3L+4M advance into centre on diagonal (2 PdeB), join hands &
    set; 1L+2M also 3L+4M Tulloch turn to right (or turn RH)
25-32::
    1L+2M also 3L+4M Tulloch turn to left (or turn LH); 1L+2M also 3L+4M
    set to each other & retire (2 PdeB) to place
33-40::
    1s+2s also 3s+4s circle 4H round & back
41-48::
    2L+3L+4L also 2M+3M+4M make arches, 1s cross down, dance out between
    2s/3s & beween 3s/4s & cross to 4th place own side (2s+3s+4s step up
    47-48).  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5541, '2013-08-21 08:31:08.950261+00', '2023-02-04 01:20:41.188104+00', 2661, 3, NULL, 'ace', '1-8::
    1s dance parallel RSh reels of 3 on own sides
9-16::
    1s set, turn 2H, 1s facing 2s on sides set & turn 2s with 2H 1.1/2
    times
17-24::
    1M+3s circle 3H round to L end 3s on opp sides & 1M casts to 2nd pl,
    1L+3s circle 3H round to right & end 3s own sides & 1L casts to 2nd
    pl
25-32::
    1s set dance up to top, cast to 2nd place & turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (3929, '2013-08-21 08:30:39.375234+00', '2023-02-04 01:18:21.772452+00', 51, 3, NULL, 'ace', '1-8::
    All dance full petronella but without setting
9-16::
    1s set & turn partner 2H, 1s set to 2s on sides & 1/2 turn 2H
17-24::
    1s set to 3s on side & 1/2 turn 2H, 1s cast back to top
25-32::
    All dance Reversing Grand Chain: 1s turn once round RH as 2s+3s
    change places RH on sides, 2s (at bottom) turn once round LH as
    1s+3s change places LH on sides, 3s (at top) turn once round RH as
    1s+2s change places RH on sides, 1s (at bottom) turn once round LH
    as 2s+3s change places LH on sides to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5544, '2013-08-21 08:31:08.974934+00', '2023-02-04 01:20:15.970043+00', 2674, 3, NULL, 'ace', '1-8::
    1s cross down & dance reflection reels of 3 on sides, 2s end facing
    out. (1) 2 3
9-16::
    1s 1/2 turn RH, lead down _while_ 2s cast to top; 1L, closely
    followed by partner, casts up behind 3M & crosses towards 2nd place
    Ladies'' side
17-24::
    1s+3L dance RH across, 1s about turn & with 1M leading dance RH
    across with 3M, ending with 1s in prom hold facing 3M
25-32::
    1s+3M+2L dance diagonal LSh reel of 3 (LSh to 3M). 1L completes reel
    to end 2nd place own side _while_ 1M dances 3/4 reel & casts round
    2M to 2nd place own side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5546, '2013-08-21 08:31:08.989029+00', '2023-02-04 01:20:16.003609+00', 10107, 3, NULL, 'ace', '1-8::
    2s+3s dance into centre & dance out ends, turn RH _while_ 1s & 4s
    cast in 1 place & turn RH
9-16::
    1s & 4s repeat
17-24::
    1s cast & face 3s, set & turn with nearer hand & lead to bottom
25-32::
    All dance Promenade
33-40::
    1s followed by 4s+3s+2s lead up to top & cast back to places
41-48::
    2s+3s also 4s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (5547, '2013-08-21 08:31:08.99737+00', '2023-02-04 01:20:16.02396+00', 11985, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast 1 place & turn LH to face 1st corners
9-12::
    1s+1st corner (prom hold) dance round anticlockwise 1/2 way _while_
    2nd corners dance in, turn LH & dance back to place
13-16::
    1s+1st corners set (facing diagonally) & 1s+1st corner persons cross
    diagonally LH, 1s dance round to face 2nd crnrs as 1st crnrs dance
    into places
17-20::
    1s+2nd corner (prom hold) dance round anticlockwise 1/2 way _while_
    1st corners dance in, turn LH & dance back to place
21-24::
    1s+2nd corners set (facing diagonally) & 1s+2nd corner persons cross
    diagonally LH, 1s dance out 2nd place own side as 2nd crnrs dance
    into places
25-32::
    1s dance LSh reels of 3 on own sides (LSh to 4th corner), 1s dancing
    out 1/2 turn 3s to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5548, '2013-08-21 08:31:09.005442+00', '2023-02-04 01:20:16.038771+00', 2675, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 on own sides (in & down to start)
9-16::
    1s dance reels of 3 on own sides (in & down to start)
17-24::
    1s cross down & cast down behind 3s, lead up to top crossing & cast
    to 2nd place.  2 1 3
25-32::
    Top couple (2s) cast to 2nd place & cross RH, cast to 3rd place &
    lead up to top crossing to own side
::
    _while_ middle couple (1s) cross, cast to 3rd place, lead up to top
    crossing to own side & cast to 2nd place
::
    _while_ bottom couple (3s) lead up to top crossing to opposite side
    & cast to 2nd place, cross & cast to 3rd place', 4);
INSERT INTO 'dancecrib' VALUES (9365, '2016-10-06 07:18:29.204868+00', '2023-02-04 01:20:16.054676+00', 17270, 3, NULL, 'ace', '1-8::
    1s set & cross RH, 1s set to 2s & change places (RH Mens side, LH
    Ladies)
9-12::
    1s set to 3s & change places with other hand (LH Mens side, RH
    Ladies)
13-20::
    1s dance Fig of 8 round 3s
21-24::
    1s lead up to top crossing & cast to 2nd place own sides
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5549, '2013-08-21 08:31:09.13022+00', '2023-02-04 01:20:16.075118+00', 12882, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cast to 2nd place _while_ 2s cross up, 1s+3s set, 1s
    cast to 3rd place _while_ 3s cross up to 2nd place.  2 3 1
9-16::
    3s+1s dance R&L 1/2 way, 2s+1s dance R&L 1/2 way.  1 2 3
17-24::
    1M followed by partner casts to 2nd place & crosses into 1s+3s
    dancing RH across
25-32::
    2s+1s dance LH across, 1M followed by partner casts up to 1st place
    & crosses to own side
33-40::
    1s set to 2s & 1/2 turn on sides (Men RH & Ladies LH) into double
    triangle position, set & 1/2 turn 3s by nearer hand.  2 3 1
41-48::
    2s+3s+1s dance reels of 3 on sides with 2s dance down between 3s to
    start', 0);
INSERT INTO 'dancecrib' VALUES (5550, '2013-08-21 08:31:09.138523+00', '2023-02-04 01:20:16.094588+00', 8517, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set on sides & dance 1/2 RH across, 1s+4s set on
    sides & dance 1/2 LH across
9-16::
    2s+4s also 1s+3s set & dance 1/2 RH across, all dance 1/2 RSh reel
    of 4 on sides
17-24::
    1s+3s dance LSh diagonal reel of 4 across _while_ 2s+4s dance RSh
    diagonal reel of 4 ending in lines across
25-32::
    All turn facing dancer 1.1/2 times (1s+3s RH & 2s+4s LH) to end on
    sides, 1s & 4s dance 1/2 Figs of 8 round end couples.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (4526, '2013-08-21 08:30:50.106502+00', '2023-02-04 01:20:16.243576+00', 2682, 3, NULL, 'ace', '1-8::
    1s 3/4 turn RH, full turn LH to end L between 2s & M between 3s,
    2s+1s+3s set twice
9-16::
    1s turn 2H 1.3/4 times to end 2nd place on opposite sides, 2s+1s+3s
    set twice on sides 1s end facing 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners &
    cross to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (12635, '2020-03-02 01:52:37.4771+00', '2023-02-04 01:20:16.270711+00', 13912, 3, NULL, 'ace', '1-8::
    1M+2s & 1L+3s dance mirror reels of 3 (1M RSh to 2M, 1L LSh to 3L to
    start)
9-16::
    1s dance "La Baratte":
::
    _9-10_    1s 1/2 turn RH & retain hand but at arm''s length from each
    other
::
    _11-12_  1M retraces steps with 1L turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Lady''s original
    place) & releasing Lady''s RH she turns under Man''s left arm until
    almost in original places
::
    _13-16_  1s turn RH once round.. End 1 2 3
17-24::
    1s+2s+3s Set+Link; Ladies dance RH across to place & face out
    _while_ Men set & cast to Right to place & face in
25-32::
    1s+2s+3s dance 8 bars Schiehallion Reels to end 1 place to the left.
    End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (14577, '2022-02-05 02:19:51.059439+00', '2023-02-04 01:20:16.295074+00', 18511, 3, NULL, 'ace', '1-8::
    1s dance in & cast (2s step up); 1s turn RH
9-16::
    2s+1s+3s dance Set+Link for 3 couples twice.  (3) (1) (2)
17-24::
    1s pass LSh to dance 1/2 diag reel of 4 with 1st corner person; pass
    RSh to dance 1/2 diag reel of 4 with 4th corner person. 2 1 3
25-32::
    All Petronella Turn 4 times (no setting) back to place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3932, '2013-08-21 08:30:39.521776+00', '2023-02-04 01:18:22.004561+00', 54, 3, NULL, 'ace', '1-8::
    All Men dance across passing partner RSh & cast down to the bottom
    of set (4th Man leading), cross the bottom of the set & up Men''s
    side
9-16::
    All circle 8H round & back (retaining the circle formation to bar
    40)
17-20::
    1s with dancers on their left (1M+2M & 1L+2L) NHJ cross diagonally
    (Men''s arch) & both pairs turn away from each other to face in
21-24::
    1s with dancers on their left (1M+3L & 1L+3M) NHJ cross over (1M+3L
    make arch) both pairs turning away from each other to face in
25-32::
    1s continue this Fig 2 more times to end with top 2 dancers facing
    each other also bottom dancers facing each other for a Snowball
    Grand Chain
33-40::
    All dance Snowball Grand Chain for 4 cpls:
::
    End couples cross RH & change places LH on side with side persons
::
    Original side persons cross RH _while_ original end couples change
    places RH on sides & all change places LH on sides
41-48::
    All Ladies dance across passing opposite Man RSh & cast up to top,
    cross & down on the Ladies'' side to end opposite partner.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5551, '2013-08-21 08:31:09.156426+00', '2023-02-04 01:20:16.323462+00', 8241, 3, NULL, 'ace', '1-8::
    1s & 3s set & dance La Barratte:
::
    Man 1/2 turns Lady RH & retains hand but at arm''s length from each
    other
::
    Man retraces steps with Lady turning right under Man''s arm briefly
    into Allemande hold (Man behind Lady facing Ladies original place) &
    releasing Ladies RH she turns under Mans left arm until almost in
    original places
::
    Couples change places LH to opposite places  (1)2(3)
9-16::
    1s dance reflection reels of 3 on sides (1s out & down as 2s dance
    up between 1s) & 1s+2s continue reel to change places.  2(1)(3)
17-24::
    1s+3s dance 1/2 double Fig of 8 (1s cross down), 1s dance up between
    2s & cast back to 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5552, '2013-08-21 08:31:09.164399+00', '2023-02-04 01:20:16.354776+00', 2686, 3, NULL, 'ace', '1-8::
    1L followed by 1M casts & crosses to opposite sides, 2s+1s circle
    left
9-16::
    2s+1s crcle right, 1M followed by 1L casts to 1st place & crosses to
    original place
17-24::
    1s lead down middle & back
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5553, '2013-08-21 08:31:09.172666+00', '2023-02-04 01:20:16.384182+00', 2687, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opposite sides   1 (2) 3 (4)

1-8::
    1s+2s also 3s+4s Set+Link, 2s+1s also 4s+3s Set+Link with Men ending
    in centre in line up/down in order 1 2 3 4
9-16::
    All Men dance RSh reel of 4 in middle
17-24::
    1M+2M also 3M+4M turn RH _while_ Ladies set, 1s+2s also 3s+4s dance
    1/2 RH across (2 bars); pull back LSh curving left & dance 1/2 LH
    across back to original places
25-32::
    1s+4s chase anticlockwise 1/2 way _while_ 2s+3s dance RH across,
    4s+2s also 3s+1s turn LH on sides
33-40::
    4s+2s also 3s+1s dance the Bourrel :
::
    4M+2M also 3M+1M set advancing, 3/4 turn 2H & twirl to end BtoB
    (2M/1M facing up & 4M/3M down) _while_ partners chase anticl'' 1/2
    way,
::
    set to partners & turn 2H to end (2) 4 (1) 3
41-48::
    All circle 8H round & back

{{explanation}}
Repeat from new positions with Ladies dancing reel of 4 & Ladies setting in the Bourrel', 0);
INSERT INTO 'dancecrib' VALUES (5554, '2013-08-21 08:31:09.180778+00', '2023-02-04 01:20:16.413303+00', 2688, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & turn LH
9-16::
    1s dance reels of 3 on opposite sides giving LSh to 1st corner, 1s
    1/2 turn RH as 2s & 3s loop round into middle
17-24::
    2s+1s+3s dance Allemande & end crossing LH to opposite sides
25-28::
    3s+1s+2s chase anticlockwise for 2 bars & cast back to form lines
    across (Men at top & Ladies at bottom)
29-32::
    All change places with partner RH & chase clockwise to own sides.  3
    1 2', 0);
INSERT INTO 'dancecrib' VALUES (9476, '2016-11-09 08:48:31.858819+00', '2023-02-04 01:20:16.428113+00', 17435, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+2s also 3s+4s dance R&L
17-24::
    1M&2L change places RH, 1M&3M also 1L&2M change places LH, 1M&4L
    also 1L&3L change places RH, 1L&4M change places LH
25-32::
    All set & cross RH, 2s+3s also 4s+1s circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (12151, '2019-09-02 22:56:50.532954+00', '2023-02-04 01:20:16.446129+00', 19611, 3, NULL, 'ace', '1-8::
    All set HS, 1s+2s also 3s+4s circle 4H round to right
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1s+2s also 3s+4s dance Diamond Poussette
25-32::
    1s set advancing & cast to 2nd place, dance down between 3s & cast
    to 4th place', 0);
INSERT INTO 'dancecrib' VALUES (9477, '2016-11-09 08:48:31.9094+00', '2023-02-04 01:20:16.466467+00', 14043, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection (mirror) reels of 3 on sides giving hands
    (1s in/down, 2s out/up, 3s in/up)
9-16::
    1s followed by 2s (who dance up to top) dance down, cast round 3s,
    meet, dance up & cast to 2nd place, 2s into 1st place
17-24::
    1s+1st corners turn RH, 1s pass RSh, 1s+2nd corners turn RH, 1s pass
    RSh to 2nd place own side, 1M facing up, 1L facing down
25-32::
    1M+2s & 1L+3s dance LH across, 1s pass LSh and dance RH across with
    other couple', 0);
INSERT INTO 'dancecrib' VALUES (5556, '2013-08-21 08:31:09.238284+00', '2023-02-04 01:20:16.531255+00', 10180, 3, NULL, 'ace', '1-8::
    Top 3 Ladies dance round partner RSh, dance down & round next Man
    LSh & back to places
9-16::
    Men repeat passing partner LSh
17-24::
    1s & 3s petronella turn (2s * 4s step up), all 4 couples set; 1s/3s
    dance down to face 2s/4s & all set
25-32::
    1s+2s also 3s+4s dance reels of 4 across
33-40::
    1s & 3s cast to right round the facing person into centre & dance
    1/2 reel of 4 (up/down set) end passing partner LSh to own side.  2
    3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13525, '2021-01-09 01:19:55.374845+00', '2023-02-04 01:20:16.561848+00', 14989, 3, NULL, 'ace', '1-8::
    1s+2s set & cross RH, set & turn 3/4 2H into line up/down middle
    (Ladies face up, Men down)
9-16::
    1s+2s dance reel of 4 in the middle, remaining in middle facing
    partner
17-24::
    1s+2s set, turn RH to own side; 1s+2s set & turn partner 2H, remain
    in the middle facing up ready for …
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (8587, '2015-02-13 12:47:48.461972+00', '2023-02-04 01:20:17.213719+00', 8482, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round and back
9-16::
    1s cross down, giving RH, between 2s, cast round 3s, cross RH up
    between 3s, and cast up behind 2s, meet in middle,1st place facing
    down, 2s step in to face 1s
17-24::
    1s+2s dance the Rondel with 1s finishing in 2nd place facing down
25-32::
    2s+1s+3s dance Grand Chain', 0);
INSERT INTO 'dancecrib' VALUES (3933, '2013-08-21 08:30:39.540655+00', '2023-02-04 01:18:22.118204+00', 55, 3, NULL, 'ace', '1-8::
    All Adv+Ret, cross over passing partners RSh, Men making the arches
9-16::
    Repeat bars 1- 8
17-20::
    1s & 4s turn R elbow grip ending in middle 1s facing down & 4s up
    (Lady on Man''s right)
21-28::
    1s+4s dance R&L up/down dance
29-32::
    1s+4s turn partners L elbow grip (end Lady on Man''s Right)
33-40::
    1s+4s dance Ladies'' Chain & end in original places
41-48::
    1s followed by 2s+3s+4s cast & 1s make an arch at bottom of set
    _while_ others dance under arch to top', 0);
INSERT INTO 'dancecrib' VALUES (3935, '2013-08-21 08:30:39.557116+00', '2023-02-04 01:18:22.1773+00', 10103, 3, NULL, 'ace', '1-8::
    1s cross RH, cast & turn LH to face out on opposite sides
9-16::
    1s dance RH across with corners & pass RSh to dance LH across with
    ptnrs crnrs (1M ends between 3s facing up & 1L with 2s facing down)
17-24::
    2s+1s+3s Set+Link for 3 twice (starting & ending in lines across)
25-32::
    1s dance 1/2 RSh reels of 3 across (1s face opposite sides to
    start), 1s dance 1/2 reel on own side (1M+3M also 1L+2L pass RSh to
    start)', 0);
INSERT INTO 'dancecrib' VALUES (14638, '2022-03-07 02:18:18.879654+00', '2023-02-04 01:18:22.728664+00', 16596, 3, NULL, 'ace', '1-8::
    1s set, 1L followed by partner, casts 2 places, 1L crosses (below
    3s) & casts up Men'' side to 2nd place facing down _while_ 1M dances
    round 3L & up the middle to 2nd place Ladies'' side facing down 2 (1)
    3
9-16::
    2s+1s+3s dance reels of 3 on the sides (1s & 3s pass RSh, 2s
    out/down to begin, 1M finishes facing out)
17-20::
    1s turn 3s RH on sides to finish 1M facing out
21-24::
    1M followed by partner, casts down 1 place & dances across the set
    to finish in 3rd place own sides, 3s step up bars 23-24.  2 3 1
25-32::
    2s+3s+1s Adv+Ret, all turn partner RH.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13409, '2020-12-02 01:19:59.06593+00', '2023-02-04 01:20:16.580349+00', 19930, 3, NULL, 'ace', '{{explanation}}
No hands are given throughout the dance

1-8::
    3s followed by 2s+1s dance down for 2 bars, set & dance up backwards
    & Petronella turn to original place (Ladies pull back RSh, Men LSh)
9-16::
    1s dance 1/2 Fig of 8 down round 2s, 1s cast 1 place (2s step up bar
    13-14) & cross up to their original place (2s step down 15-16)
17-24::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RSh
    on sides & dance on 1 place to own sides (1s in 2nd pl)
25-32::
    2s+1s+3s circle left for 6 steps, pivot left & chase back to places
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5557, '2013-08-21 08:31:09.246422+00', '2023-02-04 01:20:16.601847+00', 12802, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    1s dance LSh round 3s & dance 1/2 reel of 3 on sides (RSh to 2s to
    start) & end facing 1st corners (pstn)
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh & dance
    1/2 diagonal reel with 2nd corners (pstn) to end 2nd place opposite
    sides. (2) (1) (3)
25-32::
    All set twice & 1/2 turn partner, pull back RSh (twirl) & dance out
    to places', 0);
INSERT INTO 'dancecrib' VALUES (9199, '2016-06-16 22:41:52.14318+00', '2023-02-04 01:20:16.629573+00', 12951, 3, NULL, 'ace', '1-8::
    1L sets to 1M (who does not set) casts to 4th place (2L+3L+4L step
    up 5-6) 1L sets to 4M (who does set)
9-16::
    Diagonal reels of 4 across (1M+3L also 3M+1L pass LSh as 2M & 4M
    dance up, 2L & 4L dance down)
17-24::
    1M casts to 4th place (2M+3M+4M step up 19-20) & 1M set to 1L & they
    turn RH to face 4L (1L following partner)
25-36::
    _1/2_ RSh alternating tandem reels of 3 across:  1s with 4s, 1s with
    3s, 1s with 2s
37-40::
    1L followed by 1M casts behind Men, cross at 4th place to own side
    as 2s, 3s, & 4s cross up (Lady in front of Man)
41-48::
    2s+3s dance RH across as 4s+1s dance LH across, 2s+3s dance LH
    across as 4s+1s dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (5558, '2013-08-21 08:31:09.256268+00', '2023-02-04 01:20:16.655597+00', 14200, 3, NULL, 'ace', '1-8::
    1s also 3s turn RH & cast 1 place, turn LH to face 1st corners
9-16::
    1s also 3s dance 1/2 Diagonal reel of 4 with 1st corners, 1/2
    Diagonal reel with 2nd corners
17-24::
    1s also 3s dance 1/2 Diagonal reel with 3rd corner (pstns), 1/2
    Diagonal reel with 4th corner (pstns)
25-32::
    1s also 3s dance Diag R&L (M down).  2 1 4 3 5
33-40::
    1s dance down to 5th place _while_ 3s dance in & cast up to 2nd
    place as 5s step up, all turn RH.  2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (9763, '2017-04-06 09:57:25.068209+00', '2023-02-04 01:20:16.671835+00', 2695, 3, NULL, 'ace', '1-8::
    1s lead down and back to 1st place facing out
9-16::
    1s+2s+3s dance reflection reels of 3 on sides taking hands (1s
    out/down, 2s in/up, 3s out/up) 1s end casting into place to face
    down, 3s casting to face up
17-24::
    Passing RSh throughout, 1s dance behind 2s, cross in 3rd place, cast
    up behind 2s, cross to place as 3s dance up behind 2s, cross in 1st
    place, cast behind 2s, cross to place
25-32::
    1s+2s dance »Le Carré«
::
    _25-26_    1s+2s set, 1M & 2L turning 1/4 to right
::
    _27-28_    All dance 1 place round anticlockwise
::
    _29-32_    1M+2L turn LH as 1L+2M continue to dance round 1/2 way
    End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11193, '2018-09-30 22:19:50.227903+00', '2023-02-04 01:20:16.689895+00', 18104, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    Partners join NH & set, pass opp person RH, set, pass next dancer LH
9-16::
    Facing couples dance RH across & LH back
17-24::
    Gypsy turn with opp person (dance RSh round person & back to place,
    no hands); RSh Gypsy turn with partner
25-32::
    Ladies change places RH, Men change places LH; face partner & set,
    1/2 turn partner RH to face new couple', 0);
INSERT INTO 'dancecrib' VALUES (13992, '2021-05-03 00:19:53.358442+00', '2023-02-04 01:20:16.733313+00', 2698, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All set to opp dancer & change places RH to face new couple; all set
    to opp dancer & change places LH to face another new couple
9-16::
    All dance RH across & LH across
17-24::
    Ladies Adv+Ret; Men Adv+Ret
25-32::
    Ladies change places RH, Men change places LH; All turn partners
    1.1/2 RH to face new couple', 0);
INSERT INTO 'dancecrib' VALUES (5559, '2013-08-21 08:31:09.26633+00', '2023-02-04 01:20:16.770668+00', 2700, 3, NULL, 'ace', '1-8::
    1s dance down between 2s & cast back to places, 1M+2M nearer hands
    joined dance across between 1L & 2L, divide & dance back to places
9-16::
    1L+2L nearer hands joined dance across between 1M & 2M, divide &
    dance back to places, 2s dance up & cast back to places
17-24::
    1M+2L set advancing, twirl & dance back to places, 1L+2M repeat this
    Fig
25-32::
    1s+2s dance 4H (skip change) round 1/2 way, set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (5560, '2013-08-21 08:31:09.275994+00', '2023-02-04 01:20:16.78907+00', 2702, 3, NULL, 'ace', '1-8::
    1s set, lead down middle, cross & cast up behind 3s to 2nd place (2s
    step up bars 5-6), 2s+1s set
9-16::
    1s+2s dance Ladies'' Chain (Ladies cross RH)
17-24::
    1s+3s dance Ladies'' Chain (Ladies cross LH)
25-32::
    1s set, cross RH, change places LH with 3s on sides & change places
    RH with 4s on sides.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13170, '2020-09-15 00:19:55.292465+00', '2023-02-04 01:20:16.964696+00', 16904, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+3s dance 1/2 R&L & set, face in _while_ 2s+4s set, dance 1/2 R&L,
    2L+4L pull back LSh to face out. All 1/2 turn corner NH (all now
    opposite partner)
9-16::
    2s+4s dance in to meet partner, dance out between side couples,
    separate & cast to form "longways set"  (Ladies'' side: 4L 3M 1L 4M;
    Men''s side: 2M 3L 1M 2L), all set

{{title}}
Reel

1-8::
    Reels of 4 on sides.  1s & 3s pass RSh, 2s & 4s dance in slightly to
    form square set, all facing clockwise
9-16::
    Men chase 1/2 round clockwise, Ladies pull back RSh, loop round to
    follow Men.  End in square & all set (All with new partner)

{{explanation}}
Each repeat Men move 1 place clockwise, Ladies 1 place anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (5563, '2013-08-21 08:31:09.302574+00', '2023-02-04 01:20:16.993769+00', 9862, 3, NULL, 'ace', '1-8::
    1s cross RH & 1/2 turn 2s LH on sides, 2s+1s chase anticl''wise 1 pl
    & 3/4 turn ptnrs LH into centre to a line of 4 across (Ladies BtoB
    facing ptnrs)
9-16::
    All dance Gypsy Poussette :
::
    Box setting:
::
    _9_  All set to the right turning 1/4 turn to right
::
    _10_  All set to the left (facing away from partner) & 1/4 turn to
    right
::
    _11_  All set to the right (facing partner, Men pass BtoB) & 1/4
    turn to right
::
    _12_  All set to the left (facing away from partner & passing BtoB)
    & no turn, partners now facing away from each other (but not lined
    up back to back)
::
    Gypsy turn:
::
    _13-14_  All cast to right & dance around partners 1/2 way to face
    partners
::
    _15-16_  All 3/4 turn partners 2H into a line across, Men back to
    back in middle
17-24::
    1s+2s dance reel of 4 across ending in prom hold, 2s facing down &
    1s facing up (Men with partner on their right)
25-32::
    1s+2s wheel round anticlockwise 1/4 way &  dance last 7 bars of
    Tournée (couples 1/2 wheel anticl''wise & Men turn Ladies into
    middle, both couples turn 1.1/2 times (2s RH, 1s LH) & dance out to
    places)', 0);
INSERT INTO 'dancecrib' VALUES (5564, '2013-08-21 08:31:09.321472+00', '2023-02-04 01:20:17.024518+00', 2709, 3, NULL, 'ace', '1-8::
    All set, 1s cross RH _while_ 2s+3s dance RH across 1/2 way, all set
    & 2s cross RH _while_ 1s+3s dance RH across 1/2 way
9-16::
    1s petronella turn into centre, set, petronella turn & set & end
    facing 2nd corner pstns
17-24::
    1s dance Pass+Turn with 2nd corners ending with 1s advancing towards
    each other & turning right about to face 1st corner pstns, Pass+Turn
    with 1st corners ending with 1s advancing towards each other &
    turning right about to BtoB position (Lady facing up, Man down)
25-32::
    1s dance reels of 3 across (Lady RSh to 3L & Man RSh to 2M to start)
    & 1s end passing LSh to 2nd places.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5565, '2013-08-21 08:31:09.33129+00', '2023-02-04 01:20:17.056903+00', 9165, 3, NULL, 'ace', '1-8::
    1s+3s dance RSh 3/4 round partner to end in line of four in middle
    (Ladies face down, Men up), 1/2 reel of 4, 1s+3s RSh 3/4 round prtnr
    to own sides
9-16::
    2s+1s Set+Link, 3s+1s Set+Link
17-24::
    1s+3s+2s 1/2 RSh reel of 3 on own sides, 1L followed by partner
    casts up 1 pl crossing to opp sides & turning left turns prtnr LH to
    face 1st crnrs
25-32::
    1s Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    Pass+Turn with 2nd corners, 1s ending 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8327, '2014-07-29 12:59:04.244649+00', '2023-02-04 01:20:17.094501+00', 15063, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 1s turn 2H 1.3/4 to face 1st corners
9-12::
    1s dance 1/2 RSh reel of 4 with 1st corners _while_ 2nd corners
    dance track of 1/2 reel of 4 (2s+3s dance LH across 1/2 way when
    passing in middle). 1s pass LSh to face 2nd corner positions
13-16::
    Repeat bars 9-12 with 2nd corners, 1s pass RSh to own side 2nd place
17-24::
    2s+1s+3s circle 1/2 way round, set and cross RH to own side   3 1 2
25-32::
    1s cross down between 2s, cast up, cross up between 3s casting to
    2nd place own side. End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5567, '2013-08-21 08:31:09.34786+00', '2023-02-04 01:20:17.197657+00', 2713, 3, NULL, 'ace', '1-8::
    1L+2L advance towards partners & set, retire & set
9-16::
    1M+2M repeat bars 1- 8
17-24::
    1s lead down & back
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (5568, '2013-08-21 08:31:09.357747+00', '2023-02-04 01:20:17.23316+00', 2714, 3, NULL, 'ace', '1-8::
    1s cross down, dance out round 3s, meet & dance up middle to end
    BtoB facing out on opp sides, join hands with corners & set
9-16::
    1s change places with 1st corners RH, 1st corners change places with
    2nd corners LH, 2nd corners change places with 1s RH & 1s face out
    again & set with corners
17-24::
    1s dance RSh round 1st corner (position) to meet in centre &
    2s+1s+3s turn partners RH, remaining in centre facing up ready for …
25-32::
    2s+1s+3s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5571, '2013-08-21 08:31:09.387348+00', '2023-02-04 01:20:17.288239+00', 2718, 3, NULL, 'ace', '1-8::
    1s+4s dance RH across in centre (2s & 3s step up/down), 1L & 4M wait
    on own sides as 1M+4L retaining hands continue for another full turn
    to end beside partner on sides (1L on partners left & 4L on partners
    right) in prom hold facing out
9-16::
    1s dance RSh reel of 3 on Ladies side _while_ 4s RSh reel of 3 on
    Men''s side & end 1s+4s in circle (1s in 2nd pl & 4s in 3rd pl all on
    own sides)
17-24::
    1s+4s set & turn right about, set to nearest corner, turn corners
    with nearer hand (dancing out thru ends) to end 2 1 4 3 & all set
25-32::
    1s+4s dance 1/2 R&L & dance Figs of 8 round end couples to end 2 4 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (5545, '2013-08-21 08:31:08.982858+00', '2023-02-04 01:20:15.988911+00', 11522, 3, NULL, 'ace', '1-8::
    All dance RSh reels of 3 on sides
9-16::
    1s+2s dance RH across & LH back
17-24::
    All dance Poussette to end 2 3 1
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13171, '2020-09-15 00:19:55.66255+00', '2023-02-04 01:20:17.300558+00', 2719, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s & end
    facing 1st corners
9-16::
    1s dance diag reel of 4 with 1st corners, 1s end in 2nd place opp
    sides
17-24::
    1s set, cast to 3rd place (3s step up); 1s dance 1/2 Fig 8 up round
    3s 2 3 1
25-32::
    1s cross up to dance mirror reels of 3 on opp sides (3s out/down, 2s
    in/down to start)
33-40::
    1s cross up to dance mirror reels of 3 on own sides (3s out/down, 2s
    in/down to start).  End 2 3 1

{{explanation}}
Note: Another version exists: R8x40 - Bars 33-40 mirror reels with 1s ending in 2nd place own side 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9366, '2016-10-06 07:18:29.48076+00', '2023-02-04 01:20:17.315738+00', 17205, 3, NULL, 'ace', '1-8::
    1s+2L & 3s+2M dance diagonal reels of 3 (1L & 3M give RSh to partner
    to start) 2s end in original places, 1L+3M turn LH as 1M & 3L dance
    in to face partner up/down middle (Men facing down)
9-16::
    1s+3s dance 1/2 reel of 4, 1s/3s 1.1/4 turn partners RH to face down
    1s crossing & casting up to 2nd place as 3s dance to 3rd place.  2
    (1) 3
17-24::
    2s+3s dance 1/2 R&L but setting back & forward at each corner
    _while_ 1s dance ''Goodbye-Hello'' setting (PdB rotating across
    passing BtoB to own side & set), 1s set adv rotating (Lsh back) &
    loop round 4th corner (pstn) into middle to face partner
25-32::
    3s+2s dance 1/2 R&L but set rotating at each corner _while_ 1s
    ''Goodbye-Hello'' setting (PdB rotating up/down passing BtoB to change
    places & set), set adv & 1M turns 1L under R arm into Allemande hold
    (Lady on left) & dance down to 4th place.  2 3 4 1

{{explanation}}
The dance repeats from the top a further 7 times', 0);
INSERT INTO 'dancecrib' VALUES (8698, '2015-03-03 08:47:38.331601+00', '2023-02-04 01:20:17.333166+00', 10458, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Progressive Fig 8:  1s (+3s) cross RH as 2s
    (+4s) set, 1s+2s also (3s+4s) dance 3/4 double Fig of 8 with 1s
    (+3s) casting & 2s (+4s) crossing up to start. Finish  2 1 4 3
9-16::
    Mirror (»Reflection«) reels of 4 on sides (Ladies pass RSh, Men LSh
    to start)
17-24::
    2s+1s also 4s+3s Set+Link.  2s+3s (middle couples) Set+Link    1 3 2
    4
25-32::
    All set, all turn 2H twice round, finish in centre facing down.
    1s+2s dance down 1 place _while_ 3s+4s cast up 1 place.  End 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (5574, '2013-08-21 08:31:09.43631+00', '2023-02-04 01:20:17.394587+00', 2723, 3, NULL, 'ace', '1-8::
    1s set & cross RH, 1s+2s set & 1L+2L cross to other sides _while_ 1M
    casts down as 2M casts up (to right of other Lady)
9-16::
    1s+2s set & dance La Baratte :
::
    Men 1/2 turn Lady RH & retains hand but at arm''s length from each
    other
::
    Men retrace steps with Lady turning right under Man''s arm briefly
    into Allemande hold (Man behind Lady facing Ladies original place) &
    releasing Ladies RH she turns under Mans left arm until almost in
    original places
::
    Couples change places LH to opposite places
17-24::
    1s+2s set, dance RH across 1.1/4 times round (4 bars), 1s dance out
    thru orig place & cast to 2nd place _while_ 2s 1/2 turn RH to end
    1st pl own side
25-32::
    2s+1s set, circle 4H round to left 1/2 way, turn partners 2H,
    opening out into circle 4H round to left to finish on own sides', 0);
INSERT INTO 'dancecrib' VALUES (5690, '2013-08-21 08:31:11.850542+00', '2023-02-04 01:20:17.425203+00', 9863, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 3 facing 3

1-8::
    All dance LH across & RH back to places Men faces Lady on his left
9-16::
    Man & Left Lady set twice & turn 2H, Man faces Lady on his right
17-24::
    Man & Right Lady set twice, turn 2H & all return to lines of 3
25-32::
    All Adv+Ret, advance to meet next group of 3 dancers (1 group
    passing under arches made by opposite group)', 0);
INSERT INTO 'dancecrib' VALUES (5576, '2013-08-21 08:31:09.452545+00', '2023-02-04 01:20:17.443248+00', 7409, 3, NULL, 'ace', '1-8::
    1s set, lead down below 3s, cast up 1 place & face 1st corners
9-16::
    1s dance a full »Relay« reel of 4 thru 1st corner pstns as 1st
    corners dance 1/2 reel & dance on clockwise to next corner & set
    _while_ 2nd corners set, dance on to next corner & dance remaining
    1/2 reel with 1s (2nd corners let 1s corners out before entering
    reel) 1s end facing 2nd corners
17-24::
    1s dance similar »Relay« reel thru 2nd corner pstns _while_ corners
    repeat above the moves, 1s end in 2nd places own sides
25-32::
    1s dance Diag R&L (1M crossing diagonally down & 1L crossing
    diagonally up to start)', 0);
INSERT INTO 'dancecrib' VALUES (5577, '2013-08-21 08:31:09.462505+00', '2023-02-04 01:20:17.470425+00', 5100, 3, NULL, 'ace', '1-8::
    1s & 3s set, cast 1place, dance 1/2 Fig of 8 round couples above
    them & pass LSh to dance into centre ready for Double Triangles
9-16::
    »Petronella Quadruple Triangles« :
::
    All set as for Double Triangles, 1s & 3s continue as in Double
    Triangles _while_ standing couples all petronella turn one place to
    the right & repeat, 1s & 3s end in the middle BtoB with partners
    facing 3rd corner (pstns)
17-24::
    1s & 3s dance 1/2 diagonal reel of 4 with 3rd corners & turn LH
    1.1/2 times to face 1st corner (pstns)  5 1 4 3 2
25-32::
    1s & 3s turn 1st corners RH, partner LH, 2nd corner RH & partner LH
    to end on own sides
33-40::
    5s cast to bottom as 2s dance up to top, 1s+3s set & cast 1 place.
    2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (5578, '2013-08-21 08:31:09.470797+00', '2023-02-04 01:20:17.518023+00', 9079, 3, NULL, 'ace', '1-4::
    All set, 1M & 5L petronella into centre _while_ 1L casts to below
    2nd place (3L steps down slightly) & 5M casts above 4th place (3M
    steps up slightly) (3M+5M now face 1L+3L) _while_ 2s & 4s dance to
    ends & face down/up
5-8::
    Centre couples circle 4H round to left _while_ end trios set in
    double triangle formation & advance to invert triangle
9-12::
    Centre couples circle 4H round to right _while_ end trios set ending
    with 2s & 4s dancing to top/bottom places as 1s & 5s end in 2nd/4th
    place & 3s in own place.  2 1 3 5 4
13-16::
    1s turn RH to face 1st corners _while_ 3s turn RH moving down to
    face 1st corners as 4s cast to 3rd place & 5s step down
17-24::
    1s & 3s turn 1st corners RH, partners LH, 2nd corners RH & partners
    LH to end in 2nd/4th places
25-32::
    1s & 3s dance 1/2 Figs of 8 round end couples, cross RH & cast to
    3rd/5th places.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (5579, '2013-08-21 08:31:09.480842+00', '2023-02-04 01:20:17.556475+00', 10539, 3, NULL, 'ace', '{{title}}
Start

::
    _3_······4
::
    ····8
::
    _2_·····5
::
    ····7
::
    _1_·····6
::
    ··Top
1-8::
    Middle 4 dancers (2 8 5 7) dance RH across, end dancers (1+7+6 &
    3+8+4) dance LH across
9-16::
    _2_+7+6 & 3+8+5 dance diagonal reels of 3 (7 giving RSh to 2 & 8
    giving RSh to 5 to start)
17-24::
    _1_+7+5 & 2+8+4 dance diagonal reels of 3 (7 giving LSh to 1 & 8
    giving LSh to 4 to start)
25-32::
    _7_+8 turn RH, 7+1 & 8+4 pass RSh to change places (no hands), 1+6 &
    4+3 pass RSh & change place, 6+5 & 3+2 pass RSh & change place to:
::
    _4_······8
::
    ····2
::
    _3_······6
::
    ····5
::
    _7_······1

{{explanation}}
Repeat 3 more times to end in original places', 0);
INSERT INTO 'dancecrib' VALUES (3941, '2013-08-21 08:30:39.842437+00', '2023-02-04 01:18:22.7822+00', 7336, 3, NULL, 'ace', '1-8::
    1s & 4s set, cast 1 place, set & dance LH across 1/2 way
9-16::
    1s & 4s change places RH with corners, 2s+3s dance LH across 1/2
    way, change places RH with crnrs & 1s+4s dance LH across 1/2 way.
    (3) 1 4 (2)
17-24::
    All dance Snowball Grand Chain for 4 cpls to end 2(1)(4)3:
::
    2s & 3s cross RH & change places LH on side with 1s/4s
::
    1s & 4s cross RH _while_ 3s+2s change places RH
::
    1s+2s & 3s+4s change places LH on sides.  2(1)(4)3
25-32::
    1s+4s dance 1/2 Diagonal Poussette to change places:
::
    1s+4s 3/8 turn partners RH into diagonal lines (Poussette hold),
    dance out diagonally & 1/4 turn        & dance down/up diagonally,
    1/4 turn & turn partner RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (10015, '2017-07-23 15:57:51.150277+00', '2023-02-04 01:18:32.492881+00', 10199, 3, NULL, 'ace', '1-8::
    1s+3s+5s cross RH, cast 1 place (2s+4s+6s step up), cross LH & cast
    to Left around 4th corner, pass partner LSh to face 2nd corner
9-16::
    1s+3s+5s turn 2nd corner RH, partner LH, 1st corner RH & partner LH
    to end BtoB in middle facing own side ready for ...
17-24::
    1s+3s+5s dance Double Triangles, ending BtoB in middle facing own
    sides
25-28::
    1s+3s+5s dance out of sides, cast down 1 place, meet partner & begin
    to dance up NHJ
29-32::
    1s+4s, 3s+6s & 5s+7s turn 3/4 on sides (Men LH, Ladies RH) & all
    set.  End 2 4 1 6 3 7 5', 0);
INSERT INTO 'dancecrib' VALUES (12636, '2020-03-02 01:52:38.576107+00', '2023-02-04 01:20:17.574182+00', 17046, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Grand Chain
9-16::
    1L+2M cross RH, 1M+2L cross RH, 1L+3L cross RH, 1M+3M cross RH.  End
    (2) (3) (1)
17-24::
    1L followed by 1M cast up round 3s & cast to 2nd place (3s step
    down); 1s cast up round 2s & cross to 1st place own side (2s step
    down)
25-32::
    1s+2s+3s circle 6H round & back
33-40::
    1s+2s dance 1/2 RH across & set; 1s+3s dance 1/2 LH across & set.
    End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5580, '2013-08-21 08:31:09.498104+00', '2023-02-04 01:20:17.611629+00', 2732, 3, NULL, 'ace', '1-8::
    1s dance down the middle & back
9-16::
    1s followed by 2s+3s+4s cast on own sides to bottom, cross (Ladies
    inside Men) & dance up opposite sides
17-24::
    1L+2M change places RH, 1M+2L change places RH, 1L+3L change places
    RH, 1M+3M change places RH
25-32::
    1L+4M change places RH, 1M+4L change places RH, all Adv+Ret', 0);
INSERT INTO 'dancecrib' VALUES (5581, '2013-08-21 08:31:09.508292+00', '2023-02-04 01:20:17.62377+00', 10790, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s cast 1 place (2s up) & 1s+3s dance LH
    across 1/2 way.  2 (3)(1) 4
9-16::
    1L+3L dance Alternating Tandem reel of 3 on side giving RSh to 4M
    _while_ 3M+1M dance similarly giving RSh to 2L, 3s+1s end in circle
17-24::
    3s+1s change places by setting twice moving to left, 1s followed by
    3s dance up between 2s & cast 1s to 3rd place.  2 3 1 4
25-32::
    All set, 1s turn RH & cast to 4th place _while_ 2s+3s+4s turn RH (4s
    moving up to 3rd place) & all set', 0);
INSERT INTO 'dancecrib' VALUES (5582, '2013-08-21 08:31:09.516248+00', '2023-02-04 01:20:17.634362+00', 2734, 3, NULL, 'ace', '1-8::
    1M+2L change places RH, 2L+2M change places LH, 1s+2s circle 4H
    round to left
9-16::
    1s+2s dance Ladies Chain
17-24::
    1s+2s set, 2s followed by 1s lead down, 1/2 turn & dance back
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5583, '2013-08-21 08:31:09.660779+00', '2023-02-04 01:20:17.806097+00', 11032, 3, NULL, 'ace', '{{explanation}}
Circle, partner on Man''s right

1-8::
    All dance Grand Chain passing partner & 3 persons
9-16::
    All turn new partner RH & 3/4 turn LH to face anticlockwise
17-24::
    All dance anticlockwise 4 steps & back 4 steps & end facing in
    (Partner on Man''s right)
25-32::
    All Slip-Step to right & back again', 0);
INSERT INTO 'dancecrib' VALUES (5585, '2013-08-21 08:31:09.680466+00', '2023-02-04 01:20:17.86464+00', 2737, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance RH across (Lady with 2s & Man with 3s)
9-16::
    1s dance LH across with other couple, 1s turn RH 1.1/2 times to face
    1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting ending between 2s/3s
25-32::
    1s Adv+Ret down/up, change places RH & cast to right to 2nd places
    _while_ 2s+3s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (12918, '2020-07-01 00:19:49.682+00', '2023-02-04 01:20:17.886527+00', 17592, 3, NULL, 'ace', '1-8::
    1s set, 1M followed by 1L dances down & casts behind 3M; 1M crosses
    set & casts up round 3L _while_ 1L casts up round 3M. 1s end facing
    1st corners
9-12::
    1s dance "Corner Pass Left + Turn Left" with 1st corners (as Corner
    Pass+Turn but passing corner LSh, corners turning LH in centre);
13-16::
    1s pass LSh to face 4th corner & repeat Corner Pass Left + Turn Left
    with 4th corners.  1s end approaching each other in centre
17-20::
    1s turn LH to end 1L, with 1M following, facing 2M, 1L followed by
    1M dances up round 2M passing by RSh
21-24::
    1s dance down NHJ, divide , 1L dances behind 3L _while_ 1M dances
    behind 3M (3s step up 23-24). 2 3 1
25-32::
    All circle 6H round to the right & back to the left.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5587, '2013-08-21 08:31:09.696599+00', '2023-02-04 01:20:17.947359+00', 2742, 3, NULL, 'ace', '1-8::
    1s+2s set twice & dance 1/2 R&L
9-16::
    2s set twice on sides to 1s, change places RH & LH with partner
    ready for Promenade
17-24::
    1s+2s+3s Promenade & end with 1s casting to 2nd place
25-32::
    1s+3s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (5588, '2013-08-21 08:31:09.708371+00', '2023-02-04 01:20:17.975109+00', 2743, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s dance down below 2s & cast back to place _while_ 3s dance down
    below 4s & cast back to place, all dance DoSiDo
9-16::
    2s dance up to top & cast down to places _while_ 4s dance up above
    3s & cast back to places, all dance DoSiDo
17-24::
    All set, cross RH & circle 1/2 way to left
25-32::
    All set, cross LH & circle 1/2 way to right

{{title}}
Reel

1-4::
    All set twice
5-12::
    2s & 4s dance Figs of 8 round couple above
13-16::
    1L+2L also 3L+4L turn RH on sides _while_ 1M+2M also 3M+4M turn LH
    on sides
17-24::
    1s & 3s cast 1 place & lead down the middle, lead up & cast up
    behind 2s/4s to places
25-32::
    1s & 3s advance setting into a line up/down & set, 1s & 3s turn RH &
    cast down 1 place.  2 1 4 3', 0);
INSERT INTO 'dancecrib' VALUES (8060, '2013-10-01 08:46:55.176746+00', '2023-02-04 01:20:17.992412+00', 12699, 3, NULL, 'ace', '1-8::
    1M+3L & 1L+3M turn 1/2 way RH & turn about into opposite places, 1L
    & 3L followed by partners dance clockwise around set to original
    sides
9-16::
    2s & 4s repeat bars 1-8
17-20::
    All Set+Link with partner & end Ladies facing out
21-32::
    All dance Schiehallion reel 3/4 way round
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12070, '2019-08-30 09:53:42.365249+00', '2023-02-04 01:18:22.816257+00', 64, 3, NULL, 'ace', '1-8::
    1s+2s (also 3s+4s) dance R&L
9-12::
    1M+2s dance 1/2 reel of 3 across (1M LSh to 2L) 1M ends on left of
    1L _while_ 3L+4s dances 1/2 reel of 3 across (3L RSh to 4M), 3L ends
    on right of 3M
13-16::
    1s in prom hold dance 1/2 reel of 3 across with 2s to end facing 2M
    _while_ 3s dance similar to end facing 4L
17-20::
    1s+2M dance RH across, end facing 2L (1L on 1M''s left) _while_ 3s+4L
    dance RH across, end facing 4M (3L on 3M''s right)
21-24::
    1s+2L dance LH across ending in centre facing down _while_ 3s+4M
    dance LH across to end in 3rd place own side
25-32::
    1s followed by 2s+3s+4s lead down; 1s make arch & 2s+3s+4s dance
    under & cast up to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5589, '2013-08-21 08:31:09.716538+00', '2023-02-04 01:20:18.012427+00', 9564, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 2 places, 1s dance 1/2 reflection reels of 3 on
    own sides with 4s+5s (1s cross down to start).  2 3 5 4 1
9-16::
    1s cross LH, cast up 2 places, 1s dance 1/2 reflection reels of 3 on
    own sides with 3s+2s (1s cross up to start).  1 3 2 5 4
17-24::
    1s+2s set, 1/2 turn partner RH & chase clockwise round 3s to change
    places.  2 3 1 5 4
25-32::
    1s+4s set, 1/2 turn partner LH & chase anticlockwise round 5s to
    change places.  2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (5590, '2013-08-21 08:31:09.724587+00', '2023-02-04 01:20:18.045491+00', 2745, 3, NULL, 'ace', '1-8::
    1L sets to 2M & turns 3M (2H) & stands b''tw''n them, 1M sets to 2L &
    turns 3L (2H) 1M ends b''tw''n 3s facing up as 1L up between 2s facing
    down
9-16::
    2s+1s+3s set twice & 1s 3/4 turn 2H on to opposite sides
17-24::
    2s+1s+3s set twice on sides & 1s 1/2 turn 2H to own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5591, '2013-08-21 08:31:09.732678+00', '2023-02-04 01:20:18.07228+00', 2747, 3, NULL, 'ace', '1-8::
    1M+2L change places RH, 1L+2M change places, 1M+3M change places &
    1L+3L change places
9-16::
    3s+1s dance 1/2 R&L, 2s+1s dance 1/2 R&L
17-24::
    1s cross RH & cast 1 place, 1s turn 1.3/4 LH to face 1st corners
25-32::
    1s set & turn corners 2H & twirl to face partners, set to partners &
    turn 2H & twirl to face 2nd corners
33-40::
    1s set & turn 2nd corners & twirl to face partners, set to partners
    & turn 2H & twirl to face 2nd corners again
41-48::
    1s dance reel of 3 on opposite sides passing 2nd corner RSh & cross
    to own sides 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (5592, '2013-08-21 08:31:09.74077+00', '2023-02-04 01:20:18.091065+00', 9565, 3, NULL, 'ace', '1-8::
    1s cross down also 3s+5s (each couple cross down from top place) to
    dance reflection reels of 3 on sides _while_ 2s & 4s stand to end
    (1)2(3)4(5)
9-16::
    Repeat from new pstns to end in original places
17-24::
    1s+2s dance RH across, 1s cross RH & cast down 2 places
25-32::
    1s+4s dance LH across, 1s cross LH & cast to bottom to end 2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (5593, '2013-08-21 08:31:09.74893+00', '2023-02-04 01:20:18.110487+00', 2749, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s dance double Fig of 8 (1s crossing down & 4s up to
    start)
9-16::
    1L & 4L turn RH 1.1/2 times to change places facing out _while_
    partners cross & cast down/up to change places, repeat from new
    pstns with 1M & 4M turning 1.1/2 times & partners crossing & casting
17-24::
    1s & 4s cast in 1 place & dance RH across, dance up/down to original
    places _while_ 2s+3s dance 1/2 RH across, dance out ends, cast
    up/down & dance 1/2 RH across back to places
25-32::
    1s & 4s cast in 1 place, Men give LH to approaching Lady to pass her
    in front & meet partner in centre 2 (4) 1 (3), dance out ends
    crossing RH & cast into top & bottom places to order 4 2 (3)(1),
    4s+2s also 3s+1s Set+Link to end 2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (5594, '2013-08-21 08:31:09.75694+00', '2023-02-04 01:20:18.132919+00', 9547, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    1s cast to bottom & dance up between 3s & out behind 2s to places
9-16::
    All Adv+Ret & 2s+3s dance 1/2 R&L
17-24::
    All set as Men advance to partner, turn RH to end all facing
    clockwise (Men in front of partner) & chase 1/2 way
25-32::
    All set as Ladies advance to opposite Man, turn LH to end facing
    anticlockwise (Ladies in front of Men) & chase 1/2 way.  3(1)4(2)', 0);
INSERT INTO 'dancecrib' VALUES (14116, '2021-07-07 00:19:36.89756+00', '2023-02-04 01:20:18.150792+00', 2752, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s cross RH & cast (1M down, 1L up) to 1M
    between 3s facing up, 1L between 2s facing down
9-16::
    1s turn LH twice round to face 1st corners; 1s dance 1/2 diag reel
    of 4 with 1st corners
17-24::
    1s turn LH twice round to face 2nd corners; 1s dance 1/2 diag reel
    of 4 with 2nd corners, 1s end in 2nd place opp sides  (3) (1) (2)
25-32::
    Reels of 3 on sides, 1s LSh to dancer on left
33-40::
    1s dance diag R&L (1M up, 1L down). 1s omit polite turn & finish
    facing out. 2 (1) 3
41-48::
    1s cast (1M down, 1L up), 1s cross RH up/down centre & cast to 2nd
    place opp side, 1s cross RH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (5595, '2013-08-21 08:31:09.765062+00', '2023-02-04 01:20:18.174676+00', 2753, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig of 8 (1s cross down to start)
9-16::
    1s+3s advance setting & dance 1/2 RH across _while_ 2s chase
    clockwise to opposite places, 3s+2s+1s set & dance 1/2 LH across
    back to places
17-24::
    1s cast, dance 1/2 Fig of 8 round 1st pstns & cross RH to own side
    _while_ 2s dance 1/2 Fig of 8 round 1st pstns & turn RH moving up to
    1st pl
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5596, '2013-08-21 08:31:09.773145+00', '2023-02-04 01:20:18.192668+00', 14695, 3, NULL, 'ace', '1-8::
    1s cross down to dance reels of 3 on opposite sides
9-16::
    1scross down to dance reels of 3 on own sides
17-24::
    1s lead down middle & back
25-32::
    All turn partner RH, 1s cast to 3rd place.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5597, '2013-08-21 08:31:09.781171+00', '2023-02-04 01:20:18.214605+00', 13576, 3, NULL, 'ace', '1-8::
    1s cross down & cast behind 3s to meet below 3s, 1s lead up crossing
    & cast up behind 2s to original places
9-16::
    1s+2s+3s turn partners RH & LH
17-24::
    1s+2s set passing partner LSh to dance the Helix:
::
    Cast right to own sides, 1/2 turn partners RH & dance 1/2 RH across
25-32::
    All circle 6H round & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5598, '2013-08-21 08:31:09.877495+00', '2023-02-04 01:20:18.234463+00', 11770, 3, NULL, 'ace', '1-8::
    1s dance in (touch nearer hands) & cast 1 place, dance down between
    3s & cast up to 2nd places own sides (2s step up 3-4)
9-16::
    1s turn 1st corners RH & pass RSh to face 2nd corners, turn 2nd
    corners RH & pass RSh to 2nd place own side facing out
17-20::
    1M casts up into middle _while_ 1L casts down into middle facing
    partner & set _while_ 2s+3s adv on diag to form circle & set pulling
    back RSh to face out
21-24::
    2s+3s dance out to 1st/3rd places, face in & set _while_ 1s dance
    RSh round each other to end 1M between 2s & 1L between 3s facing
    opposite sides
25-32::
    1s dance 1/2 RSh reels of 3 across (1M+2s, 1L+3s). Bar 27-28 1s turn
    RH & dance 1/2 RSh reel of 3 with other couple ending in 2nd places
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (3942, '2013-08-21 08:30:39.850536+00', '2023-02-04 01:18:22.845717+00', 9001, 3, NULL, 'ace', '1-8::
    1s+2s+3s chase clockwise 1/2 way, 1s dance up to top & cast on
    opposite sides 1 place & face 3rd corner pstns (own 1st corner
    persons)
9-16::
    1s dance 1/2 reel of 4 with 3rd corners, join LH with partner to
    Bal-in-Line with 4th corner pstns (RH to corner), 1s set to 4th
    corner
17-24::
    1s 1/2 reel of 4 with 4th corners, join LH with partner to
    Bal-in-Line with 1st corner pstns (RH to corner), 1s set to 1st
    corner
25-32::
    1L with 2s & 1M with 3s circle 3H round to left, 1s finish BtoB in
    centre, 1s dance out through ends (1L up & 1M down) & cast to right
    to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (3943, '2013-08-21 08:30:39.928151+00', '2023-02-04 01:18:22.879407+00', 11688, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, 1s set to 2s, 1s cast to 2nd place
    _while_ 2s dance up casting to 1st place
9-16::
    1s+3s repeat bars 1-8.  2 3 1
17-24::
    3s set to 1s & change places on sides (Ladies RH & Men LH), 2s set
    to 1s & change places on sides (other hand)
25-32::
    1s+2s dance the Bourrel:
::
    1M+2L set advancing, 3/4 turn 2H & twirl to end BtoB (Lady facing up
    & Man down) _while_ partners chase anticlockwise 1/2 way,
::
    set to partners & turn 2H to own sides having changed places', 0);
INSERT INTO 'dancecrib' VALUES (13172, '2020-09-15 00:19:56.58001+00', '2023-02-04 01:20:18.258753+00', 19900, 3, NULL, 'ace', '{{explanation}}
Note: no hands are given throughout dance

1-8::
    1s+2s chase clockwise 1/2 round; 1s+3s chase anticlockwise 1/2
    round.  (2) (3) 1
9-16::
    1s cast up (3s step down) & set advancing to 1st corners; 1s+1st
    corners dance 1/2 diag reel of 4. 1s pass LSh to face 2nd corners
17-24::
    1s+2nd corners dance 1/2 diag reel of 4; 1s dance RSh round each
    other 1.1/2 times to 2nd place own side. 3 1 2
25-32::
    1s+2s (bottom couples) dance Poussette (no hands).  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5599, '2013-08-21 08:31:09.885706+00', '2023-02-04 01:20:18.4653+00', 8861, 3, NULL, 'ace', '1-8::
    1s dance down, cast up round 3L (1L followed by 1M) & dance into the
    middle, 1L+2s dance RH across _while_ 1M+3s dance LH across
9-16::
    Hand-in-hand Tandem reel of 3, 1s giving RSh to 2s
::
    (2s & 3s dance NHJ, changing hands at top or bottom, 1s dance with M
    following 1L to start & changing leader at top or bottom)
17-24::
    1L+2s dance RH across _while_ 1M+3s dance LH across, 1L casts up &
    2M casts down (both on M-side) & end BtoB facing own sides
25-32::
    1s dance Double Triangles & end in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5600, '2013-08-21 08:31:09.893767+00', '2023-02-04 01:20:18.490475+00', 2760, 3, NULL, 'ace', '1-8::
    All clap & cross (passing RSh), set & dance 1/2 reel of 4 on sides
9-16::
    Repeat & at end of reel 2s+3s turn LH on sides
17-24::
    1s+2s+3s dance Grand Chain
25-32::
    1s+2s turn 2H (end 1s facing 2s), 1s dance under arch made by 2s,
    1s+3s+4s turn partners 2H (end 1s facing 3s with 4s behind them) &
    1s dance under arches made by 3s & 4s to bottom', 0);
INSERT INTO 'dancecrib' VALUES (12919, '2020-07-01 00:19:50.237772+00', '2023-02-04 01:20:18.518675+00', 19988, 3, NULL, 'ace', '1-4::
    1s+2s+3s dance 1/2 reels of 3 on sides, 1s then 2s crossing down
    from 1st place
5-8::
    1s+3s turn partners RH, cast (3s down, 1s up). 1M+3L meet behind 2M,
    1L+3M meet behind 2L
9-12::
    1M+3L also 1L+3M turn once round RH & face each other
13-16::
    1s+3s pass RSh, 1s dance through 1st place, pass partner RSh to own
    sides _while_ 3s dance similar through 3rd place, dancing RSh round
    each other to own side (1s facing out, 3s facing in). 1 (2) 3
17-20::
    1s+2s turn on sides 1.1/2 (LH on Men''s side, RH on Ladies'' side)
21-24::
    1L+2s also 1M+3s dance 1/2 reels of 3 across (1L LSh to 2L in 1M''s
    place, 1M LSh to 3M in 3L''s place)
25-32::
    1s dance down, cast up round 3s, cross up RH at top & casy to 2nd
    place.  2 1 3

{{explanation}}
Note:	2nd time through Bars 31-32: 1s cast to 4th place, 4s step up', 0);
INSERT INTO 'dancecrib' VALUES (5601, '2013-08-21 08:31:09.901751+00', '2023-02-04 01:20:18.541143+00', 13553, 3, NULL, 'ace', '1-8::
    1L+2L turn LH _while_ 1M+2M turn RH, 1s followed by 2s dance down
    between 3s & cast to orig places.
9-16::
    1s+2s set & 1s cross down RH to 2nd place to face out _while_ 2c
    cast up to top. 1s cast right to end between 3s/2s facing opposite
    sides
17-24::
    1s dance RSh reels of 3 across
25-32::
    1s set & petronella turn to 2nd place opposite sides, 1s dance 1/2
    Figs of 8 eight round 3s', 0);
INSERT INTO 'dancecrib' VALUES (5602, '2013-08-21 08:31:09.907997+00', '2023-02-04 01:20:18.557781+00', 12883, 3, NULL, 'ace', '1-8::
    _1- 8_  1s dance Fig 8 on own sides, dancing in/down to start (in
    front of 2s, behind 3s). 1s end in middle at top, 2s step in bar 8
9-16::
    1s+2s dance Poussette.  2 1 3
17-24::
    1s cross RH, cast 1 place (3s step up 19-20), 1s cross RH & set
25-32::
    1s+3s dance LH across 1/2 way & set; 1L+3M cross RH _while_ partners
    set, 1M+3L cross RH _while_ partners set', 0);
INSERT INTO 'dancecrib' VALUES (11326, '2018-11-03 18:44:58.705224+00', '2023-02-04 01:20:18.818474+00', 11282, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up), dance down between 3s & cast up to end
    LSh to LSh in centre ready for …
9-12::
    1L+2s & 1M+3s dance RH across, 1s end facing 1st corners
13-16::
    1s turn 1/2  RH with corners _while_ 2s set, 1st corners (in centre)
    1/2 turn LH _while_ others dance clockwise 1 place round
17-24::
    Repeat 13-16 twice from new positions. 1s end facing 1st corners
25-32::
    Interrupted Hello-Goodbye setting:
::
    _25-28_   1s set to 1st corner and set to partner, turn 3/4 RH to
    face 2nd corners;
::
    _29-32_   Repeat with 2nd corner; 1s end on own side in 2nd place.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5566, '2013-08-21 08:31:09.338018+00', '2023-02-04 01:20:19.007934+00', 2711, 3, NULL, 'ace', '1-8::
    1s turn RH (moving down) to end BtoB Lady facing up (2s step up),
    2s+1s+3s set (Double Triangle formation), 1L+2L also 1M+3M turn RH &
    1s pass RSh to end facing 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting ending by set advancing to partner
17-24::
    1s turn RH to end BtoB Man facing up, 2s+1s+3s set (Double
    Triangle), 1M+2L also 1L+3M turn RH & 1s pass RSh to 2nd place own
    sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13746, '2021-03-02 01:20:07.404021+00', '2023-02-04 01:20:19.040183+00', 12264, 3, NULL, 'ace', '1-8::
    1s dance down the middle & back up to top
9-16::
    1s+2s+3s Adv+Ret for 1 step twice; 1s set & turn RH into promenade
    hold
17-24::
    1s dance 1/2 LSh reel of 3 across with 2s (1s give LSh to 2L to
    begin & 2s finish in 1st place); 1s dance 1/2 reel with 3s (1s give
    RSh to 3M)
25-28::
    1s NHJ dance down & cast up round 3s _while_ 3s set & cross RH to
    own side
29-32::
    1s NHJ dance up between 2s & cast to 2nd place _while_ 2s set &
    cross RH to own side 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5573, '2013-08-21 08:31:09.42813+00', '2023-02-04 01:20:17.37103+00', 9466, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s
9-16::
    1s+2s Adv+Ret for 2 steps each & turn partners 2H (skip change)
17-24::
    1s+2s dance RH across & LH back. 2M & 1L end on own sides, 1M & 2L
    end BtoB  in centre, 1M facing 2M, 2L facing 1L
25-32::
    1s+2s dance reel of 4 across. At end 1M & 2L do not pass LSh but
    dance out to own sides, 2s ending 1st place & 1s in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (5603, '2013-08-21 08:31:09.933262+00', '2023-02-04 01:20:19.076422+00', 10777, 3, NULL, 'ace', '1-8::
    1s cross down & cast down behind 3s, 1s+4s dance RH across
9-16::
    1s cross & cast up 1 place, 2s+1s dance LH across
17-24::
    1s & 3s set & cross RH to face 2s/4s on sides, set & change places
    with 2s/4s (RH on Ladies side & LH Men''s side)
25-32::
    1s cast to bottom, cross RH, 3s lead up to top, cross, cast to 2nd
    place & all set.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (11736, '2019-03-26 02:05:25.628931+00', '2023-02-04 01:20:19.103882+00', 11178, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-4::
    1s+2s & 3s+4s circle 4H round to left to end with 1s+3s facing down,
    2s+4s facing up NHJ with partner
5-8::
    All set, 1s & 4s turning inwards to face up/down, 1s cast to 2nd
    place, 2s dance up & cast into 1st place, 4s cast up to 3rd place,
    3s dance down & cast into 4th place
9-16::
    1s+4s dance 1/2 Ladies'' Chain & face partners; 1s+4s dance 1/2 Men''s
    Chain
17-24::
    All set on sides, 2s+4s & 1s+3s dance RH across, all set on sides
25-32::
    2s+4s+1s+3s dance RSh reels of 4 on sides.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (13747, '2021-03-02 01:20:07.495226+00', '2023-02-04 01:20:19.149423+00', 12265, 3, NULL, 'ace', '1-8::
    1s+2s set & cross RH with partner; 1s+2s chase clockwise 1/2 way
    round.  2 1
9-16::
    2s+1s set facing on sides & change places (1s in & up, 2M+1M LH,
    2L+1L RH); 1s cast, meet below 2s & take promenade hold
17-24::
    1s dance reel of 3 across the dance giving RSh to 2L to begin &
    finish in 1st place facing up with 2nd couple behind ready for …
25-32::
    1s+2s dance Allemande.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (5605, '2013-08-21 08:31:09.952883+00', '2023-02-04 01:20:19.235048+00', 10177, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L dance across, down behind top 3 Men, cross &
    dance back to places
9-16::
    1M followed by 2M+3M repeat round top 3 Ladies
17-24::
    1s followed by 2s+3s+4s lead down & cast back to places
25-32::
    All turn 2H, 2s+3s+4s make arches & 1s dance under arches to 4th
    place
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12726, '2020-04-11 10:51:33.016973+00', '2023-02-04 01:20:19.275802+00', 9656, 3, NULL, 'ace', '1-8::
    1s cross RH & cast (2s step up), 1s dance 1/2 Fig of 8 up round 2s,
    finishing in prom hold facing 2L
9-16::
    1s+2s dance reel of 3 across (1s pass 2L RSh). 1s finish facing 3L
17-24::
    1s+3s dance reel of 3 across (1s pass 3L LSh), 1s finish in centre
    facing Ladies'' side, drop RH
25-32::
    1s dance out between 2L & 3L, cross LH, cast back into centre & turn
    RH 1.1/4 to finish facing up NHJ _while_ 2s+3s set twice and turn
    partner RH, finishing 2HJ in centre making two arches
33-40::
    1s dance up between 2s, cast, dance down between 3s and cast up to
    2nd place. 2s and 3s step back to sidelines end bar 40.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5606, '2013-08-21 08:31:09.960976+00', '2023-02-04 01:20:19.310408+00', 2770, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 2nd place, into 1/2 LSh reels of 3 across (1L
    with 2s & 1M with 3s) & end facing 1st corner persons (on opposite
    sides)
9-16::
    1s turn crnrs RH (M ends facing 3s & L facing 2s in double triangle
    position), all set & 1s LH turn 1st crnr (pstn) to end facing 2nd
    crnr (pstn)
17-24::
    1s turn 2nd corner RH (M ends facing 2s & L facing 3s in double
    triangle position), all set & turn 2nd corner persons LH
25-32::
    1s dance 1/2 RSh reels of 3 across (1M with 2s & 1L with 3s) & 1s
    turn 1.1/2 times to end on own sides 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (14910, '2022-06-27 00:20:05.946106+00', '2023-02-04 01:20:19.342942+00', 20877, 3, NULL, 'ace', '1-4::
    All clap, 1s cross passing RSh & cast (2s step up)
5-8::
    1s pass RSh, pull back RSh and dance out to 2nd place own side, 1M
    facing up, 1L facing down 2 1 3
9-16::
    2s+1s+3s dance reels of 3 on own sides (1s RSh to 3rd corners)
17-24::
    1s dance out round 3rd corners, pass RSh & curve into 2nd place own
    sides, _while_ 2s+3s Adv+Ret diagonally & set twice
25-32::
    2s+1s+3s circle 6H round to the left for 6 steps, pivot & chase back
    to places', 0);
INSERT INTO 'dancecrib' VALUES (5607, '2013-08-21 08:31:09.969349+00', '2023-02-04 01:20:19.375885+00', 8504, 3, NULL, 'ace', '1-8::
    1s & 3s cast down behind own sides, turn outwards & dance back to
    places
9-16::
    All dance reflection reels on own sides (1s & 3s in & down to start)
17-20::
    1s & 3s cross down 1 place & face out _while_ 2s & 4s dance up 1
    place & face in & all Bal-in-Line on sides
21-24::
    1s & 3s dance out & about turn to face in _while_ 2s & 4s passing
    partner RSh face out on opposite sides & all Bal-in-Line
25-28::
    2s+1s also 4s+3s 1/2 turn on sides meet ptnr in middle (1 2 3 4), 1s
    followed by 2s+3s+4s dance up, 1s cast, 2s to 1st pl, 3s to 2nd pl &
    4s to 3rd pl
29-32::
    1s continue to cast to bottom & cross over _while_ 2s & 4s cross RH
    & loop round in to 1st & 3rd pl _while_ 3s stand for 2 bars & cross
    to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13898, '2021-04-05 00:20:00.39037+00', '2023-02-04 01:20:19.414118+00', 19498, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s set, cast to 3rd place (3s step up)
9-16::
    1s cross, cast up (3s step down); 1s cross & cast up to 1st place
    (2s step down)
17-20::
    1s+2s change places LH on side, 1s cross RH with partner;
21-24::
    1s+3s change places LH on sides, 3s dance down to 3rd place _while_
    1s lead up, retain RH & join LH with 1st corners (1M swivels to face
    down)
25-32::
    1s+1st corner Bal-in-Line, 1s 3/4 turn RH to join LH with 2nd
    corners & Bal-in-Line, 1s 1/2 turn RH to end BtoB facing own side
33-40::
    2s+1s+3s dance Double Triangles', 0);
INSERT INTO 'dancecrib' VALUES (5608, '2013-08-21 08:31:09.979043+00', '2023-02-04 01:20:19.534792+00', 2777, 3, NULL, 'ace', '1-8::
    1M+2L cross passing RSh, dance LSh round partner, pass RSh up/down &
    dance RSh round standing Man/Lady (1M round 2M, 2L round 1L)
9-16::
    1L+2M cross passing LSh, dance RSh round partner, pass LSh up/down &
    dance LSh round standing Man/Lady (2M round 1M, 1L round 2L)
17-24::
    1s dance 4 slip step down middle, set to each other, slip step up to
    top & cast to 2nd place
25-32::
    2s+1s Adv+Ret clapping on bar 28 & turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (5609, '2013-08-21 08:31:09.987165+00', '2023-02-04 01:20:19.566374+00', 2780, 3, NULL, 'ace', '1-8::
    1s lead down & turn RH & out to 2nd place, cast up & set _while_ 2s
    cast up, set, lead down & turn RH & dance out to places
9-16::
    1s lead down for 4 steps, up for 2 & cast up behind 2s back to
    places
17-24::
    1s+2s dance RH across, LH across for 2 steps & 1M & 2L keep turning
    to end in centre to end facing partners in line across
25-32::
    1s+2s dance 1/2 reel of 4 across, 1s & 2s turn RH on side to end 2 1', 0);
INSERT INTO 'dancecrib' VALUES (5584, '2013-08-21 08:31:09.668828+00', '2023-02-04 01:20:17.833657+00', 2736, 3, NULL, 'ace', '1-8::
    1s+2s set twice & dance RH across
9-16::
    1s+2s set twice & dance LH across
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (5610, '2013-08-21 08:31:09.996803+00', '2023-02-04 01:20:19.651506+00', 2781, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reel of 3 on own sides
17-24::
    1s lead down the middle for 3 steps & back, cast to 2nd place
25-32::
    1s dance RH across with 3s & LH across with 2s', 0);
INSERT INTO 'dancecrib' VALUES (9367, '2016-10-06 07:18:29.843696+00', '2023-02-04 01:20:19.889248+00', 14814, 3, NULL, 'ace', '1-4::
    1L+2M dance small clockwise loops in own place (left & forward to
    start) passing LSh in middle & 1L dances down to 2nd place, 2M up to
    1st place _while_ 1M+2L set, turn 3/4 RH & retain hands
5-8::
    2s+1s dance RH across, 2s end in 1st place as 1s pull back RSh to
    end BtoB in middle facing own sides
9-16::
    2s+1s+3s dance Double Triangles but bars 15-16 1M+2L & 1L+3M turn LH
    into lines of 3 across
17-24::
    Reels of 3 across (1M+2M & 1L+3L pass RSh) ending in lines of 3
    across again, facing down/up
25-32::
    Set+Link for 3. 2s+1s+3s set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (8180, '2014-02-10 10:26:28.754278+00', '2023-02-04 01:20:19.937973+00', 15265, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, all set & 2s also 3s petronella into middle
    _while_ 1s cross RH end facing clockwise
9-16::
    2s+1s+3s dance Weasel reels:
::
    2s+3s dance part reel of 4 up/down middle but when reaching either
    end they dance clockwise to top/bottom to re-enter reel _while_ 1s
    dance clockwise to replace dancer leaving the reel & all end where
    they started
17-24::
    All set & 1set again _while_ 2s & 3s petronella (all on opposite
    sides) chase 1/2 way to own sides   3 1 2
25-32::
    All dance 3 couple Allemande.', 0);
INSERT INTO 'dancecrib' VALUES (5612, '2013-08-21 08:31:10.207914+00', '2023-02-04 01:20:19.948261+00', 11636, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L (no polite turn), 1M casts up _while_ 2L casts
    down _while_ 2M+1L cross RH & 1/2 turn partner LH (like 1/2 Ladies''
    Chain but with 2M+1L crossing)
9-16::
    1M dances reel of 3 on Ladies side passing 3L RSh _while_ 2M dances
    reel of 3 on Men''s side passing 3M RSh
17-24::
    1M dances down _while_ 3M dances up _while_ 2M+3L cross LH & 1/2
    turn partner RH (like 1/2 Men''s Chain but with 2M+3L crossing),
    persons in 2nd & 3rd places dance 1/2 R&L
25-32::
    1L+2M also 3M+1M cross diagonally (to left) to change places (2) (1)
    3; 2s+1s set, cross RH & 2s+1s+3s set. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5613, '2013-08-21 08:31:10.218063+00', '2023-02-04 01:20:19.961129+00', 2789, 3, NULL, 'ace', '1-4::
    1s & 3s petronella into centre & set with centre pair (1M&3L)
    rotating 1/2 turn clockwise BtoB to change pstns
5-8::
    1s & 3s petronella onto sides & set. Order: Ladies''s side 3L 2L 3M
    4L :  Men''s side 1L 2M 1M 4M
9-12::
    Dancers in 1st & 3rd pstns petronella into centre & set with centre
    pair (1L&3M) rotating 1/2 turn clockwise BtoB to change pstns
13-16::
    These persons now petronella onto sides & set    Order: Ladies'' side
    3M 2L 1M 4L  :   Men''s side 3L 2M 1L 4M
17-24::
    3s+2s also 1s+4s dance Left Hand Ladies'' Chain (Ladies cross LH &
    turn Men RH)
25-32::
    1s & 3s set to partners, cross RH cast down 1 place & turn RH
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5614, '2013-08-21 08:31:10.228628+00', '2023-02-04 01:20:19.993909+00', 15079, 3, NULL, 'ace', '1-8::
    1s cross down RH & cast down behind 3s, lead up crossing to top &
    cast to 2nd place own sides
9-16::
    1M+3L also 1L+2M set & change places RH, set & change back LH
17-24::
    1M+2L also 1L+3M set & change places RH, set & change back LH
25-32::
    1s dance RH across (Lady with 2s & Man with 3s), pass RSh & dance LH
    across with other couple', 0);
INSERT INTO 'dancecrib' VALUES (5615, '2013-08-21 08:31:10.236748+00', '2023-02-04 01:20:20.024007+00', 13747, 3, NULL, 'ace', '1-8::
    1M+2M turn RH 1.1/2 times _while_ 1L+2L turn LH 1.1/2 times, 1M+3M
    turn LH 1.1/2 times _while_ 1L+3L turn RH 1.1/2 times
9-16::
    1s dance up to top & cast to 2nd place _while_ 3s cast to 3rd place,
    1s turn RH twice to face 3rd corners
17-24::
    1s dance reel of 4 with 3rd corners & pass LSh to face 2nd corners
25-32::
    1s dance reel of 4 with 2nd corners & end 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8061, '2013-10-01 08:46:55.716591+00', '2023-02-04 01:20:20.045009+00', 15137, 3, NULL, 'ace', '1-4::
    1s+2s set facing each other up/down dance & change places (Men LH,
    Ladies RH) _while_ 3s facing partner set & cross RH
5-8::
    1s+3s set facing each other up/down dance & full turn (Men RH,
    Ladies LH) _while_ 2s facing partner set & cross RH.  (2)1(3)
9-16::
    1s dance reflection reels of 3 on sides (1s dancing in & up)
17-24::
    1s dance 1/2 Fig of 8 up around 2s ending in 2nd place, all set &
    cross RH
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12639, '2020-03-02 01:52:40.405682+00', '2023-02-04 01:20:20.066459+00', 2794, 3, NULL, 'ace', '1-12::
    1s+2s+3s dance R&L for 3 couples
13-16::
    1s+2s+3s circle 6H 1/2 round to left.  (3) (2) (1)
17-24::
    2s+1s dance 1/2 R&L; 3s+1s dance 1/2 R&L
25-32::
    3s+2s dance 1/2 R&L; 1s+2s dance 1/2 R&L.  2 1 (3)
33-40::
    2s+1s+3s dance mirror reels of 3 on sides (3s cross up, 1s out/down,
    2s in down).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5616, '2013-08-21 08:31:10.267094+00', '2023-02-04 01:20:20.084932+00', 12611, 3, NULL, 'ace', '1-8::
    1s+2s set & petronella turn into middle, set & 1/2 turn partner RH
9-16::
    1s+2 dance reel of 4 up/down middle
17-24::
    1s+2s set & petronella turn to places, set facing on sides & change
    places (Men LH & Ladies RH)
25-32::
    2s+1s dance double Fig of 8 (1s cross up)', 0);
INSERT INTO 'dancecrib' VALUES (5617, '2013-08-21 08:31:10.275194+00', '2023-02-04 01:20:20.101983+00', 9233, 3, NULL, 'ace', '1-8::
    1s lead down below 2s & cast back to places, 2s dance 1/2 Fig of 8
    round 1s
9-16::
    1s+2s set, Petronella-in-tandem, set & Petronella-in-tandem
17-24::
    2s+1s+3s set, circle 6H round left (2 bars), Men turn Lady on their
    right 2H & circle left to places
25-32::
    1s reel of 3 on sides (Man down LSh to 3L & Lady up LSh to 2M) 1s
    crossing RH to places', 0);
INSERT INTO 'dancecrib' VALUES (5618, '2013-08-21 08:31:10.285495+00', '2023-02-04 01:20:20.15242+00', 2801, 3, NULL, 'ace', '{{explanation}}
1 Man +3 Ladies in Sq.Set

{{title}}
Start

::
    1L······2L
::
    1M·····3L
::
    ····Top
1-8::
    1M+1L dance down the middle & back
9-16::
    All dance RH across, turn right about, dance out & chase clockwise 1
    place
17-24::
    1M+3L in prom hold dance reel of 3 across (LSh to 1L), 1M leaves 3L
    in his original place & dances to 2L place as 1L returns to orig pl
25-32::
    All dance 1/2 R&L & turn opposite person RH

{{title}}
End

::
    2L······3L
::
    1M·····1L
::
    ····Top', 0);
INSERT INTO 'dancecrib' VALUES (5619, '2013-08-21 08:31:10.293532+00', '2023-02-04 01:20:20.175917+00', 2805, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place (2s step up); 1s dance 1/2 Fig of 8 (1M
    round 2s & 1L round 3s) _while_ 2s & 3s set & cross RH to opp sides
9-16::
    1s cross RH, cast round 1st corner (pstn) & cross between 2s/3s to
    2nd pl, dance in & take allemande hold facing up _while_ 2s & 3s
    set, petronella turn into centre (skip change) & set, 2s+3s turn 3/4
    RH ready for …
17-24::
    2s+1s+3s dance Allemande
25-32::
    3s+1s+2s set, cross RH & chase 1/2 way clockwise.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12640, '2020-03-02 01:52:40.502159+00', '2023-02-04 01:20:20.20281+00', 17042, 3, NULL, 'ace', '1-8::
    1L+4s & 3L+2s dance RH across; 1s+3s dance LH across
9-12::
    2L+3L(followed by 3M)+1L(followed by 1M)+4L dance 1/2 RSh Tandem
    reel of 4
13-16::
    2M+1L(followed by1M)+3L(followed by 3M)+4M dance 1/2 RSh Tandem reel
    of 4.  End 1 4 3 2
17-24::
    1s+3s set, 1s+3s dance 1/2 R&L, 1s+3s set
25-32::
    All Ladies petronella one place anticlockwise & set; All Men repeat.
    End 4 3 2 1

{{explanation}}
Repeat Strathspey then twice in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (5620, '2013-08-21 08:31:10.301707+00', '2023-02-04 01:20:20.221625+00', 10181, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to top _while_ 4s cross RH, cast to
    top, cross RH & cast back to place
9-16::
    All dance reels of 4 on sides (1s & 3s dancing down & out to start)
17-24::
    1s+2s also 3s+4s dance RH across & all chase clockwise 1/2 way
25-32::
    All turn partner RH 1.1/2 times, 4s+3s+2s dance 1/2 RSh reels of 3
    on sides.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14654, '2022-03-07 02:19:58.279545+00', '2023-02-04 01:20:20.247741+00', 18349, 3, NULL, 'ace', '1-8::
    1s+3s 1/2 turn partners RH, lead down for 2 steps (2s+4s step up
    bars 3-4), 1/2 turn RH, lead up to finish 1s in 2nd place & 3s in
    4th place 2 1 4 3
9-16::
    2s+4s repeat bars 1-8 but finish in 1st & 3rd places 2 1 4 3
17-24::
    1s+4s dance Set & Rotate:
::
    Set, Rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides. 2 4 1 3
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5621, '2013-08-21 08:31:10.311466+00', '2023-02-04 01:20:20.35792+00', 2807, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH, lead down for 2 steps, 1/2 turn RH & lead up to
    places
9-16::
    2s 1/2 turn RH, lead down for 2 steps, 1/2 turn RH & lead up to
    places
17-24::
    1s+2s set, dance 1/2 RH across, set, dance 1/2 LH across
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (5622, '2013-08-21 08:31:10.319917+00', '2023-02-04 01:20:20.373981+00', 2809, 3, NULL, 'ace', '1-8::
    1s+3s circle 4H round to left, set to partners & dance out to places
    ending BtoB
9-16::
    All dance RSh reels of 3 with 2s & 4s (in prom hold) dancing to
    right
17-24::
    2s+4s dance RH across & LH back ending in place facing anticlockwise
25-32::
    2s & 4s chase anticlockwise (lady followed by partner) round to next
    couple & L dances round L as M dances round M to continue chase to
    opp sides
33-40::
    2s+4s circle 4H round to right, set to partners & dance out to (new)
    places ending BtoB
41-48::
    All dance crescent RSh reels of 3 with 1s & 3s (in prom hold)
    dancing to right
49-56::
    1s & 3s repeat bars 17-24 ie dance RH across & LH back ending in
    place facing anticlockwise
57-64::
    1s & 3s repeat bars 25-32 ie chase anticlockwise round to next
    couple & L dances round L as M dances round M to continue chase to
    opp sides
65-72::
    1L & 3L cross & pass opposite Man LSh to original place, 1M & 3M
    cross passing partner RSh to original place
73-80::
    2s & 4s repeat bars 65-72 ie Ladies cross passing opposite Man LSh
    to original places & Men cross passing partner RSh to original
    places
81-88::
    All turn partners RH & LH back to places (slow turns)', 0);
INSERT INTO 'dancecrib' VALUES (10336, '2017-12-22 15:44:26.873934+00', '2023-02-04 01:20:20.400722+00', 2811, 3, NULL, 'ace', '1-4::
    1s+4s dance 3/4 RH across in centre to end 1s on Men''s side, 4s on
    Ladies'' side in 2nd+3rd places _while_ 2s+3s set & cast (2s to top,
    3s to bottom)
5-8::
    2s+3s dance 3/4 RH across in centre to end 2s on Men''s side, 3s on
    Ladies'' side in 2nd+3rd places _while_ 1s+4s set & cast (1L+4L to
    top,  1M+4M to bottom)
9-12::
    1L+2L NHJ dance through opp couple & cast down to face partners
    _while_ 3M+4M do same, casting up to face partners
13-16::
    All turn partners 2H to end on own sides, 4s & 2s facing down, 3s &
    1s facing up
17-20::
    _1/2_ reels of 4 on sides (Ladies pass LSh, Men pass RSh to start)
21-24::
    1s+2s dance 1/2 RH across (2 bars), 1s+3s change places LH on sides
25-28::
    1s+3s cross RH with partner (2 bars), 1s+4s dance 1/2 LH across
29-32::
    All set & cross RH with partner', 0);
INSERT INTO 'dancecrib' VALUES (5623, '2013-08-21 08:31:10.329761+00', '2023-02-04 01:20:20.426812+00', 12884, 3, NULL, 'ace', '1-8::
    1s cross RH & cast to 2nd place as 2s step up, 1s dance 1/2 Fig of 8
    round 2s
9-16::
    1s cross RH & cast to 3rd place as 3s step up, 1s dance 1/2 Fig of 8
    round 3s
17-24::
    2s+3s+1s Adv+Ret & turn RH
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5624, '2013-08-21 08:31:10.412429+00', '2023-02-04 01:20:20.591846+00', 8103, 3, NULL, 'ace', '1-8::
    1L+2L+3L set advancing to 2M+3M+4M (who also set), Ladies dance
    round Men RSh back to places & all cross RH with partner
9-16::
    1M+2M+3M set advancing to 2L+3L+4L (who also set), Men dance round
    Ladies RSh back to places & all 1/2 turn RH to face up in centre
17-24::
    1s+2s+3s dance Allemande
25-32::
    3s+2s also 1s+4s set to partners, dance RH across 1/2 way, set &
    cross RH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14655, '2022-03-07 02:19:58.639253+00', '2023-02-04 01:20:20.611665+00', 20404, 3, NULL, 'ace', '1-8::
    1s+3s NHJ with partner, set advancing and dance RH across back to
    places and set
9-16::
    2s+4s NHJ with partner, set advancing and dance RH across back to
    places and set
17-20::
    All NHJ with partner Adv for 2,  all retire with Lady turning under
    partner''s arm to end facing out
21-24::
    All dance 4 bars of Schiehallion reels (move 1 place round
    anticlockwise).  2 3 4 1
25-32::
    All circle 8H round and back. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5625, '2013-08-21 08:31:10.422785+00', '2023-02-04 01:20:20.716721+00', 2812, 3, NULL, 'ace', '1-8::
    1M+2L turn RH 1/2 way & 1L+2M join in to dance RH across 1/2 way,
    1s+2s dance LH across to end Men in 1st pls & Ladies in 2nd pls
9-16::
    1s+2s HS to other side & back (1s pass below 2s to cross & above 2s
    to return) into a 1/2 Diamond Poussette to change places', 0);
INSERT INTO 'dancecrib' VALUES (5626, '2013-08-21 08:31:10.431181+00', '2023-02-04 01:20:20.73021+00', 2813, 3, NULL, 'ace', '1-8::
    All Men circle 4H round, face partners, turn RH & set
9-16::
    1s+3s dance thru next couple (M to right & L to left) to opposite
    pstns, 1s+3s in prom hold dance round each other (Men passing LSh)
17-24::
    1s dance reel of 3 across with 4M+2L (giving LSh to 4M) _while_ 3s
    dance reel of 3 with 2M+4L (giving LSh to 2M) ending in longways set
25-32::
    2s & 4s in prom hold dance reels of 3 on sides (2s gives LSh to 3M &
    4s LSh to 1M)
33-40::
    2L+4M dance 1/2 double Fig of 8 with 1s as 2M+4L dance similarly
    with 3s, all turn on sides by nearer hands (1s+3s to dancing
    outwards)
41-48::
    All repeat (Bars 33-40) from new places
49-56::
    1s+2L+4M also 3s+2M+4L dance RH across, then dance 1/2 reels of 4 on
    sides
57-64::
    All repeat (Bars 49-56) from new places
::
    Repeat with 2s & 4s leading', 0);
INSERT INTO 'dancecrib' VALUES (3944, '2013-08-21 08:30:39.937996+00', '2023-02-04 01:18:22.919237+00', 10141, 3, NULL, 'ace', '1-8::
    All set, 1s & 3s cast down 1 place _while_ 2s & 4s cross up 1 place,
    all dance 1/2 reel of 4 on sides (RSh Ladies'' side & LSh Men''s side)
9-16::
    3s+4s also 1s+2s dance 1/2 R&L. 4L+3L also 2L+1L cross diagonally
    RH, 4M+3M also 2M+1M cross RH
17-24::
    1s+2s (bottom couples) dance 1/2 RH across, 4s+2s dance 1/2 LH
    across. 3s+2s dance 1/2 RH across, 3s & 1s cross RH
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9170, '2016-06-16 22:41:25.955872+00', '2023-02-04 01:18:23.008169+00', 11195, 3, NULL, 'ace', '1-8::
    1s promenade anticlockwise inside set, 1M leaves 1L in 4L place,
    prom with 4L to 3L place, prom with 3L to 2L place, prom with 2L to
    top place.  All face corners.
9-16::
    All set advancing, turn corners 2H to form cross (Ladies RH in
    centre) all facing clockwise.  All dance RH across 1/2 round, Ladies
    cross in front of Men who finish BtoB facing Ladies
17-20::
    All pivot turn to face again
21-32::
    Double Diag reels of 4 (LH across in centre)
33-40::
    Men set to corners & to each other (»Hello-Goodbye«) 1/2 round.  End
    beside original partner facing out.
41-48::
    Double Ladies'' Chain (1/2 RH across in centre) & finish in square
    set   4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (3966, '2013-08-21 08:30:40.247614+00', '2023-02-04 01:18:24.101483+00', 12620, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across 1/2 way, 1s+3s set & dance LH across 1/2
    way
9-16::
    2s+3s set, dance RH across 1/2 way, 3s+2s turn 2H ready for…
17-24::
    3s+2s dance 1/2 Diamond Poussette & dance 4H round to left into…
25-32::
    2s+3s+1s dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5627, '2013-08-21 08:31:10.439368+00', '2023-02-04 01:20:20.750587+00', 9207, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-4::
    1s & 4s petronella turn into centre, change places with partners RH
    _while_ 2s & 3s step up/down
5-8::
    1L & 4L followed by partner pass LSh to face corner (1L faces 3M, 1M
    - 3L, 4L - 2M & 4M - 2L) & change places RH into St Andrews cross
9-16::
    All Balance in cross formation, change place with corner RH & 4s+1s
    dance LH across 1/2 way all end on sides  2(1)4(3)
17-24::
    All dance RSh reels of 4 on sides 1s & 4s do not end passing LSh but
    turn about to face other corner  2 4(1)(3)
25-32::
    4s & 1s turn corner RH & 2s+4s also 1s+3s circle 4H round to right', 0);
INSERT INTO 'dancecrib' VALUES (5628, '2013-08-21 08:31:10.447443+00', '2023-02-04 01:20:20.762516+00', 9043, 3, NULL, 'ace', '1-8::
    1s set & dance Fig of 8 on own sides (between 2s to start)
9-16::
    1s+2s also 3s+4s dance Chain Progression :
::
    1s+2s also 3s+4s 3/4 turn RH, 1M+2L also 3L+4L turn LH 1.1/2 times
    as ptnrs chase cl''wise 1/2 way, 2s+1s also 4s+3s turn RH to …
17-24::
    1s+4s+3s dance Allemande
25-32::
    All dance ''Banana Reels'': Interlocking reels around set (end dancers
    pass RSh across set)', 0);
INSERT INTO 'dancecrib' VALUES (4108, '2013-08-21 08:30:43.602716+00', '2023-02-04 01:20:20.775943+00', 313, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s Set+Link;  2s+1s & 4s+3s Set+Link   1 2 3 4
9-16::
    1s & 3s 1/2 Fig of 8 round couple below; 2s & 4s 1/2 Fig of 8 round
    couple above [all now on opp sides (1) (2) (3) (4)]
17-24::
    All set, turning left on second step (Men face down, Ladies up),
    dance 2 slip steps to right passing partner (BtoB) & turn right
    about (1PdB) (Men face up, Ladies down) & repeat back to places on
    opp sides
25-32::
    1s cross RH & cast to 4th place _while_ 2s+3s+4s 1/2 turn RH, lead
    up & out to next place [4 bars]. All couples turn LH  2 3 4 1', 1);
INSERT INTO 'dancecrib' VALUES (5629, '2013-08-21 08:31:10.457305+00', '2023-02-04 01:20:20.885119+00', 2820, 3, NULL, 'ace', '1-8::
    1L+4M turn RH & back to place, 1M+4L turn RH & back to place
9-16::
    Repeat with LH turns
17-24::
    Repeat with 2 hand turns
25-32::
    Repeat with DoSiDo
33-40::
    Repeat with a bow & courtesy
41-48::
    1s cast to bottom on own sides followed by 2s+3s+4s, form an arch &
    2s+3s+4s dance under to new places', 0);
INSERT INTO 'dancecrib' VALUES (5630, '2013-08-21 08:31:10.609707+00', '2023-02-04 01:20:21.05855+00', 2821, 3, NULL, 'ace', '1-8::
    1s+2L circle 3H round to left, 1M+2s circle 3H round to left 2s
    ending BtoB between 1s facing other partner
9-16::
    1s+2s dance RSh reel of 4 across
17-24::
    1s cast 2 places, lead up to top, cast to 2nd place & cross RH
25-32::
    1s cast down 1 place on opposite sides & lead up to face 1st
    corners, set to 1st corners & set to 2nd corners
33-40::
    1s dance reels of 3 on opposite sides passing 2nd corners RSh &
    cross RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (8588, '2015-02-13 12:47:49.594731+00', '2023-02-04 01:20:21.09085+00', 16031, 3, NULL, 'ace', '1-8::
    1s lead down for 2 steps & turn 3/4 RH to face each other, set
    (retaining RH) & 1L turns under partners arm to dance up to face 2L
    (1M behind 1L) 2s step up
9-16::
    1s dance RSh diagonal Alternating Tandem reel with 2nd corners & end
    facing 2M
17-24::
    1s dance LSh diagonal Alternating Tandem reel with 1st corners & end
    in middle facing up NHJ on own sides
25-32::
    1s dance up & cast to 2nd place, all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (9200, '2016-06-16 22:41:53.273173+00', '2023-02-04 01:20:21.123155+00', 16836, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate
9-16::
    1s+3s dance all-round (diamond) Poussette
17-24::
    1s set advancing to 1st corners, turn corner 2H to finish 1L between
    2s 1M between 3s.  Repeat with 2nd corners finish 2nd place opp.
    sides
25-32::
    1s+3M dance RH across.  3M finish in 2nd place.  1s+3L dance LH
    across.  3L finish in 2nd place.    2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5631, '2013-08-21 08:31:10.640694+00', '2023-02-04 01:20:21.139151+00', 2822, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH to face 1st corners
9-16::
    1s turn 1st corners RH, pass RSh, turn 3rd corner LH & pass LSh to
    face 2nd corner
17-24::
    1s turn 2nd corners RH, pass RSh, turn 4th corner LH, 1s pass LSh to
    face down in middle (opposite sides) left hands joined
25-32::
    1s lead down below 3s, cross, cast up to 2nd place own sides,
    2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (3951, '2013-08-21 08:30:40.001905+00', '2023-02-04 01:18:23.250914+00', 76, 3, NULL, 'ace', '1-8::
    1s cast 1 place & turn RH, cast up to places & turn LH
9-16::
    1s+2s set & RH across 1/2 way, set & dance LH across 1/2 way to
    places
17-24::
    1M+2L set adv & turn RH ending in 2nd places (2M step up), 2M+1L set
    adv & turn LH & 1L ends in 2nd place (2L steps up)
25-32::
    1M changes places RH with 2L, 2M changes places RH with 1L, 1s+2s
    1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (12638, '2020-03-02 01:52:39.775181+00', '2023-02-04 01:20:19.124431+00', 13914, 3, NULL, 'ace', '1-8::
    1M+2L pass RSh & dance 3/4 LSh round partner, 1M+2L pass LSh up/down
    & cast Right round standing Man/Lady back to place
9-16::
    1L+2M pass LSh & dance 3/4 RSh round partner, 1L+2M pass RSh up/down
    & cast Left round standing Man/Lady back to place
17-24::
    1M followed by 1L casts off, dances across to 2nd place opp side,
    turns to Left to face up (2s step up 19-20);  2s+1s dance LH across,
    2s face down, 1s face up
25-32::
    2s+1s set, 2s turn 1s (LH on Ladies'' side, RH on Men''s side) & 1s
    cross LH to end 2 1', 0);
INSERT INTO 'dancecrib' VALUES (9734, '2017-04-06 08:39:49.713597+00', '2023-02-04 01:20:21.194683+00', 16804, 3, NULL, 'ace', '1-8::
    1s set, cross RH.  1s+2s circle 4H round to Left
9-16::
    1s set, cast (2s step up 11-12); 1s dance 1/2 Fig 8 down round 3s
17-24::
    1s lead down & back to 2nd place in centre, 2s & 3s stepping in, 2s
    in front of 1s & 3s behind 1s, on bar 24
25-32::
    2s+1s+3s dance promenade', 0);
INSERT INTO 'dancecrib' VALUES (5632, '2013-08-21 08:31:10.648814+00', '2023-02-04 01:20:21.230473+00', 2823, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH, 1s+2s also 3s+4s change places LH on sides & dance
    1/2 R&L
9-16::
    1s+2s also 3s+4s dance reels of 4 across (Ladies pass LSh to start,
    Men stand for 2 bars) to end (2) 1 (4) 3 with 2s & 4s on opposite
    sides
17-24::
    1s+4s dance Ladies'' Chain
25-32::
    All dance RSh reels of 4 on sides
33-40::
    1s set, 1/2 turn RH moving down to 4th place opposite side _while_
    3s cross & cast up to 2nd place on opposite side & all turn partners
    1.1/2 times 2H', 0);
INSERT INTO 'dancecrib' VALUES (5633, '2013-08-21 08:31:10.658596+00', '2023-02-04 01:20:21.264179+00', 2825, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance 1/2 Fig of 8 round 3s
9-16::
    3s set, cast up 1 place & dance 1/2 Fig of 8 round 2s.  2(3)(1)
17-24::
    2s cross down below 3s, cast down to 3rd place, lead up crossing &
    cast up to 1st place
25-32::
    2s cross down (each couple cross down as they reach top place) to
    dance reflaction reels but with 2s also crossing at the bottom.  2 3
    1', 0);
INSERT INTO 'dancecrib' VALUES (5634, '2013-08-21 08:31:10.668408+00', '2023-02-04 01:20:21.322026+00', 2828, 3, NULL, 'ace', '1-8::
    1s & 3s set, cross RH; 1s & 3s set & 3/4 turn RH to end in line
    up/down centre with 1L+3M joining LH
9-16::
    1s & 3s Bal-in-Line _while_ 2s set on sides, 1L+3M 1/2 turn LH
    _while_ 1M followed by 2M+3L+2L chase clockwise 1 place
13-16::
    All set (2M+3M+1L+2L in Line & 3L+1M facing in on sides), 1L+3M 1/2
    turn LH _while_ 1M followed by 2M+3L+2L chase clockwise 1 place
17-24::
    1M followed by 2M+3M dance clockwise up Men''s side _while_ 3L
    followed by 2L+1L dance down Ladies side to original places & all
    turn partners RH
25-32::
    1s cross RH, cast 1 place, dance 1/2 Fig of 8 across (1M round 2s &
    1L round 3s)', 0);
INSERT INTO 'dancecrib' VALUES (5636, '2013-08-21 08:31:10.684405+00', '2023-02-04 01:20:21.370996+00', 10152, 3, NULL, 'ace', '1-8::
    1s+2s turn RH into Allemande hold & dance Allemande
9-16::
    2s+1s+3s dance reflection reels of 3 on sides (3s in & up, 1s out &
    down to start)
17-24::
    1s+3s dance double Fig of 8 (in 6 bars) & 1/2 turn on sides (Men LH
    & Ladies RH)
25-32::
    All chase clockwise for 2 bars, circle left for 2 bars & circle
    right back to own sides.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5637, '2013-08-21 08:31:10.696941+00', '2023-02-04 01:20:21.411069+00', 12885, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 round 2s+3s on own sides (RSh to 2s to start)
9-12::
    1M+2M also 1L+2L 1/2 turn RH, 2M+1L lead other Man/Lady 1 place
    clockwise (in middle), 1s set to 2s
13-16::
    1M+2M also 1L+2L 1/2 turn RH, 2M+1L lead other Man/Lady 1 place
    clockwise (in middle), 1s+2s cross RH to own sides.  2 1 3
17-24::
    1s+3s dance reels of 4 across
25-32::
    2s+1s+3s dance Grand Chain', 0);
INSERT INTO 'dancecrib' VALUES (9919, '2017-06-05 11:31:11.287783+00', '2023-02-04 01:20:21.438431+00', 2580, 3, NULL, 'ace', '1-4::
    1s+2s set advancing & face up NHJ.  1s cast to 2nd place, 2s dance
    up to top & face out
5-8::
    2s+1s+3s dance 1/2 mirror reels of 3 on sides (1s in/down) in 3
    bars, then all dance in ready for …
9-16::
    3s+1s+2s dance Allemande, 1s end BtoB facing 1st corners
17-24::
    1s dance ''Hello-Goodbye setting, advancing on bar 24, pull back RSh
    to end BtoB, 1M facing up, 1L facing down
25-32::
    LH across, 1L+3s & 1M+2s.  1s pass LSh to dance RH across with other
    couple.  End 2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (5638, '2013-08-21 08:31:10.705174+00', '2023-02-04 01:20:21.465053+00', 9948, 3, NULL, 'ace', '1-8::
    1s & 4s set & 1s cross down RH & cast up round 2s _while_ 4s cross
    up LH & cast down round 3s to meet partners & lead into centre (1s
    facing 4s)
9-16::
    1s+4s dance RH across, 1s+4s retaining RH give LH to corners & dance
    RH across 1/2 way & end facing corners
17-20::
    1s & 4s set & turn corners LH 1/2 way to end with 2s & 3s in centre
    (2s facing Mens side, 3s facing Ladies side)
21-24::
    2s+3s chase - 2L followed by partner dance out Mens side, up behind
    4th man & across set to end in 1st place own side _while_ 3M
    followed by partner dance out Ladies side, behind 1st lady & across
    set to end 4th place own side
25-32::
    All circle 4H round & back.', 0);
INSERT INTO 'dancecrib' VALUES (5639, '2013-08-21 08:31:10.713233+00', '2023-02-04 01:20:21.493601+00', 8947, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate
9-16::
    All 4 couples Adv(2)+Ret(2), middle couples (1s & 3s) cross RH &
    cast round corners (1s cast up, 3s cast down) to form lines of 4
    across
17-24::
    All 4 Adv(2)+Ret(2); 1s & 3s cross RH (down/up), dance out of ends &
    cast round corners to 2nd/3rd places opp sides. 2 (3) (1) 4
25-32::
    3s &1s dance 1/2 Figs of 8 round end couples; bottom 2 couples (1s &
    4s) dance up to 2nd place & cast, 1s to bottom & 4s to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (3954, '2013-08-21 08:30:40.03134+00', '2023-02-04 01:18:23.34055+00', 9774, 3, NULL, 'ace', '1-8::
    1s & 4s set, cast in 1 place, advance diagonally in & turn right
    about setting to face corners
9-16::
    1s & 4s turn corners RH, 1s+4s dance LH across in middle to end
    facing same corner
17-24::
    1s & 4s 1/2 turn corners RH into middle, corners dance LH across in
    middle & end facing same corner (pstn) _while_ 1s+4s chase clockwise
    1/2 way, all 1/2 turn RH (4s & 1s now in middle facing new corner
    person)
25-32::
    4s & 1s dance ''Hello-Goodbye'' setting (corners set for 8 bars) & end
    facing corners
33-40::
    1s & 4s dance out thru ends turning corners with nearer hand to
    2nd/3rd places & dance 1/2 Figs of 8 round end couples
41-48::
    1s+4s dance 1/2 R&L & all turn partners RH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3956, '2013-08-21 08:30:40.045224+00', '2023-02-04 01:18:23.376366+00', 83, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp. sides

1-8::
    1M dances full reel of 3 with 2s (LSh to 2L) picking up partner on
    bar 5 _while_ 4M reels with 3s & picks up partner on bar 5
9-16::
    1s+4s lead into middle, RH across 1/2 way & LH across once round to
    face new corner
17-24::
    1s+4s set twice & turn corners (1s+4s dancing out through sides)
    ending in middle to take prom hold (facing sides) with other partner
25-32::
    1s+4s dance 1/2 RSh reel of 3 on sides, 1s+4s change partners & 1/2
    LSh reel on other side ending in middle (as in Bees of
    Maggieknockater)
33-40::
    1s+4s (in middle) set & change places RH, circle 4H round to left,
    drop ptnrs hand & open out to pick up 2s & 3s (1s picks up 3s)
41-48::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5640, '2013-08-21 08:31:10.723006+00', '2023-02-04 01:20:21.526838+00', 2840, 3, NULL, 'ace', '1-8::
    1L+2L+3L dance RSh round partners back to places; 1M+2M+3M repeat
9-16::
    1s+3s dance 1/2 Double Figs of 8 round 2s (1s cross down to start);
    1L+2L cross RH diagonally, 1L+3L cross LH
17-20::
    All circle 6H round to left
21-24::
    Men dance round to right as Ladies pull back RSh, cast round Man on
    left & all circle 6H round to right to end (1) 2 (3)
25-32::
    1s cross down to 2nd place _while_ 2s cast up, 1s cast to 3rd places
    as 3s cross up; all turn partners 2H twice', 0);
INSERT INTO 'dancecrib' VALUES (15227, '2022-11-03 01:20:03.404731+00', '2023-02-04 01:20:21.555295+00', 20430, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link; 2s+1s chase clockwise 1/2 round.  (1) (2)
9-16::
    1s+2s dance RH across; all set & cross RH with partner.  1s face out
17-24::
    1s dance down behind own sidelines, turn outwards & dance back up to
    2nd place (2s step up 19-20)
25-32::
    2s+1s dance Poussette. 2 1', 0);
INSERT INTO 'dancecrib' VALUES (5641, '2013-08-21 08:31:10.731261+00', '2023-02-04 01:20:21.587267+00', 12769, 3, NULL, 'ace', '1-8::
    1s+3s dance 1/2 R&L, turn corner RH & all set to partners
9-16::
    1s+3s repeat back to places
17-24::
    All dance interlocking reels of 4 (RSh to partner) & end facing
    corner person
25-32::
    All dance interlocking reels of 4 (LSh to corner) & end in original
    places
33-48::
    2s+4s repeat bars 1-16
49-56::
    All Ladies dance RH across once round & pass partner LSh & dance
    round to place
57-64::
    1s+3s dance 1/2 Ladies Chain, 2s+4s dance 1/2 Ladies Chain
65-72::
    All Men dance RH across, pick up new partner & RH wheel a further
    1/2 way
73-80::
    Men face new partner set, turning to left Men dance LH across 1/2
    way to face own partner, set & 3/4 turn RH to place
81-88::
    All dance 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5642, '2013-08-21 08:31:10.740089+00', '2023-02-04 01:20:21.615263+00', 14988, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
    ending 1st place opposite sides
9-12::
    1s cross down to 2nd place own sides & dance out 1/2 turning 3s with
    nearer hand.  2 3 1 4
13-16::
    1L dances up b''tw''n 3s & casts round 3M into middle facing 4s
    _while_ 1M dances down b''tw''n 4s round 4L into middle facing 3s
    (BtoB with prtnr)
17-20::
    All dance 3H round to left (1L with 4s,1M with 3s)
21-24::
    1s change places to dance 3H round to right (1M with 4s,1L with 3s)
    & end in 3rd place opp sides 1L facing 4M & 1M facing 3L
25-32::
    1s dance reels of 3 on opposite sides giving RSh to 4M/3L & 1s cross
    down to 4th place own sides.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14730, '2022-04-01 00:20:05.800124+00', '2023-02-04 01:20:21.674999+00', 12271, 3, NULL, 'ace', '1-8::
    1M+2L cross RH, 1L+2M cross RH; 1M+3M cross RH, 1L+3L cross RH.  (2)
    (3) 1
9-16::
    1s+3s dance 1/2 R&L; 2s+1s dance 1/2 R&L.  1 2 3
17-24::
    Mirror reels of 3 on sides (1s in/down, 2s out/up, 3s in/up)
25-32::
    1s+2s dance Rondel
33-40::
    1s+3s dance Rondel
41-48::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13993, '2021-05-03 00:19:56.960999+00', '2023-02-04 01:20:21.706469+00', 13776, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH _while_ 2s+3s dance 1/2 RH across, all set to
    partners; (1) (3) (2) (4) All turn 1.1/2 RH, retain partner''s RH
    (backs to own sides)
9-16::
    »Spiral Exchange«:
::
    1s+3s & 2s+4s dance RH across once round (3 bars only), then 3M
    leads 3L, 1L, 1M in chase down Men''s side and anticlockwise round
    bottom to end in »U« shape at bottom in 3L/4L/4M/3M places, _while_
::
    2L leads 2M, 4M, 4L up Ladies'' side and anticlockwise round top to
    end in »U« shape at top (2M/1M/1L/2L places).
::
    2s &1s on Men''s side, 4s & 3s on Ladies'' side, all facing partners,
    Men facing down, Ladies facing up
17-24::
    Reels of 4 on sides, all ending on sidelines
25-32::
    2s+4s & 1s+3s circle 4H round to left 1.1/4 times (4 bars) to end
    (2) (4) (1) (3); opening out to circle 8H 1/2 round to own sides.
    End 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (5644, '2013-08-21 08:31:10.759631+00', '2023-02-04 01:20:21.739713+00', 12886, 3, NULL, 'ace', '1-8::
    1s & 4s 1/2 turn partner RH, twirl & 1M & 4L dance out to opposite
    side followed by partner & chase clockwise 1/2 way _while_ 2s+3s
    set, set advancing & turn to face other couple, set & 2s dance under
    arch made by 3s
9-16::
    All dance RSh reels of 4 on sides.  4 3 2 1
17-24::
    3s+2s dance RH across & LH back _while_ 4s & 1s 1/2 turn partner RH,
    twirl & 4L & 1M dance out to opposite side followed by partner &
    chase clockwise 1/2 way.  1 3 2 4
25-32::
    1s dance Allemande _while_ 3s dance Poussette (to change places)
    also 2s Allemande as 4s Poussette.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (3957, '2013-08-21 08:30:40.076721+00', '2023-02-04 01:18:23.454074+00', 12866, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place. 1s set to 2s _while_ 4s set to
    3s, 1s & 4s turn inwards & set to each other _while_ 2s & 3s set to
    partners
9-16::
    1s+4s dance LH across, 1M followed by 4M dance up to top & cast on
    Men''s side _while_ 4L followed by 1L dance down & cast up on Ladies''
    side
17-24::
    1M+4M also 4L+1L dance Tandem RSh reels of 3 on sides
25-32::
    4s+1s dance LH across, Men dance out Men''s side _while_ Ladies dance
    out Ladies'' side turning corner with nearer hand to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5646, '2013-08-21 08:31:10.776083+00', '2023-02-04 01:20:21.801766+00', 7414, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All dance Grand Chain
9-16::
    1s cast to 4th place & dance RH across with 4s
17-24::
    4s+1s dance LH across & 1s lead up to top
25-32::
    All set twice & turn partners 2H twice

{{title}}
Reel

33-40::
    1s+2s also 3s+4s dance 1/2 R&L, 1s+4s dance 1/2 R&L
41-48::
    2s+4s also 1s+3s dance 1/2 R&L, 2s+3s dance 1/2 R&L.  (4 3 2 1 all
    on opposite sides)
49-56::
    4s+3s also 2s+1s turn RH 1.1/2 times on sides & all turn partners LH
    1.1/2 times.  3 4 1 2
57-64::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13304, '2020-11-02 01:20:07.179622+00', '2023-02-04 01:20:21.822968+00', 20091, 3, NULL, 'ace', '1-8::
    1s cast behind lines (2s step up 3-4) & cast back up to 2nd place &
    pass LSh to face 1st corners. 2 1 3
9-16::
    1s dance RSh reels of 3 on opposite sides (1L up, 1M down), finish
    facing 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    place own sides
25-32::
    1s dance Fig of 8 round 2s', 0);
INSERT INTO 'dancecrib' VALUES (10074, '2017-09-03 23:44:44.595748+00', '2023-02-04 01:20:21.860413+00', 17899, 3, NULL, 'ace', '1-8::
    1s set cross RH, cast & turn 3/4 RH to face opp sides (2s step up
    5-6)
9-16::
    1M+2s also 1L+3s dance LH across, 1s pass LSh to dance RH across
    with other couple.  1s end BtoB in middle facing 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting, clap & petronella turn to 2nd
    place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5647, '2013-08-21 08:31:10.781686+00', '2023-02-04 01:20:21.882849+00', 3785, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels of 3 all crossing down when at top ending on
    opposite sides facing up
9-16::
    1s followed by 2s+3s lead down, cross in 3rd place, cast on own
    sides & lead up to top & cast to face 1st corners _while_ 2s end at
    top & 3s in 3rd pl
17-24::
    1s dance ''Hello-Goodbye'' ending with petronella turn to 2nd places
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5648, '2013-08-21 08:31:10.789726+00', '2023-02-04 01:20:21.910069+00', 2859, 3, NULL, 'ace', '1-8::
    1s+2s+3s chase clockwise 1/2 way, set & cross RH to own sides
9-16::
    3s+1s+2s set, cross RH & chase clockwise 1/2 way to original places
17-24::
    1M set as 1L dances towards him, 1L turns to right & followed by
    partner casts behind 2L & 1L crosses to Men''s side, 1s set as 1L
    turns in
25-32::
    2s+1s+3s Adv+Ret for 2 steps & 1s turn RH 1.1/2 times to own side', 0);
INSERT INTO 'dancecrib' VALUES (5649, '2013-08-21 08:31:10.797763+00', '2023-02-04 01:20:21.945647+00', 2861, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides & end
    in middle BtoB in 2nd place facing opposite sides
9-16::
    1s dance Crown Triangles (Man sets with 2L+3L, 3L+3M, 2M+3L & Lady
    with 2M+3M, 2M+3L, 2L+3L, 3L+3M)
17-24::
    1s Figs of 8 (Man round 2s giving RSh to 2L & 1L round 3s) _while_
    corners dance into centre & touch hands twice, 1s end in 2nd place
    own side
25-32::
    1s reel of 3 across (Lady with 2s & Man with 3s', 0);
INSERT INTO 'dancecrib' VALUES (5650, '2013-08-21 08:31:10.807697+00', '2023-02-04 01:20:21.983747+00', 11929, 3, NULL, 'ace', '{{explanation}}
A set of 7 dancers, 2 lines of 3 on the sides & with number 1 in the middle facing up

{{title}}
Start

::
    _4_······5
::
    _3_··1··6
::
    _2_······7
::
    ···Top
1-8::
    _1_+2+3 dance RH across; 1+6+7 dance LH across
9-16::
    _1_+3+4 dance RH across; 1+6+5 dance LH across
17-24::
    _1_+3+6 reel of 3 across (1+3 pass RSh to start)
25-28::
    _1_+2 turn RH 1.1/2 times to change places, ending with dancer 2 in
    centre facing down
29-32::
    Dancer 2 sets, pulling back RSh to set again facing up _while_
    1+3+4+5+6+7 set, turn to left & chase 1 place clockwise to end:
::
    _3_······4
::
    _1_··2··5
::
    _7_······6

{{explanation}}
Repeat 6 more times', 0);
INSERT INTO 'dancecrib' VALUES (5651, '2013-08-21 08:31:10.81762+00', '2023-02-04 01:20:22.015482+00', 2868, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All Adv+Ret 1 step twice, 1s cross & cast 1 pl as 2s turn 1/2 way RH
    & lead up 1 pl & cross RH as 3s+4s 1/2 turn RH & 1/2 turn LH
9-16::
    All dance Grand Chain
17-24::
    1s+3s dance RH across & LH back
25-32::
    2s+1s dance R&L 1s end facing 1st corners

{{title}}
Reel

1-8::
    1s dance ''Hello-Goodbye'' setting, set to each other ending BtoB (1M
    facing up & 1L down)
9-16::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corner &
    cross back to own sides
17-24::
    1s+3s Adv+Ret, 1s+3s Adv+Ret up & down & 1s dance between 3s to 3rd
    place _while_ 3s dance up to 2nd place
25-32::
    1s+4s repeat bars 17-24', 0);
INSERT INTO 'dancecrib' VALUES (15333, '2022-12-19 01:20:07.325982+00', '2023-02-04 01:20:22.034675+00', 21127, 3, NULL, 'ace', '1-4::
    1s Petronella turn into middle _while_ 2s cast up to 1st place,
    1s+2s set
5-8::
    1s+2s Adv+Ret (1 step each) & set
9-12::
    1s Petronella turn to 1st place opp sides _while_ 2s cast to 2nd
    place, 1s+2s set
13-16::
    1s cross RH, cast to 2nd place on own sides (2s step up 15-16)
17-20::
    1s pass dance 1/2 diagonal R&L with 1st corners (Man down, Lady up)
21-24::
    1s dance 1/2 diagonal R&L with 4th corners (Man down, Lady up).  (3)
    1 (2)
25-32::
    1s cross for 1/2 LSh reels of 3 on opposite sides (1M+3M & 1L+2L
    pass LSH);  All cross RSh & All set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12465, '2020-01-02 07:00:00.379562+00', '2023-02-04 01:20:22.226593+00', 13812, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to 1st place facing out
9-16::
    1s+2s+3s dance mirror reels of 3 on sides (1s out/down, 2s in/up, 3s
    out/up to start)
17-24::
    1s cast to 2nd place as 2s dance up & curve into 1st place, all set;
    2s+1s+3s turn partner RH
25-32::
    2s+1s+3s circle 6H round & back.  2 1 3

{{explanation}}
Note:  last time through all 4 couples set, turn partners RH (19-24) & all circle 8H round and back (25-32)', 0);
INSERT INTO 'dancecrib' VALUES (13173, '2020-09-15 00:19:59.78426+00', '2023-02-04 01:20:22.242894+00', 19996, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance allemande.  Bars 7-8: 1s remain in middle, dancing up
    in prom hold to between 3s at top
9-16::
    1s, in prom hold, dance reel of 3 across with 3s, RSh to 3L to start
17-24::
    1s, in prom hold, dance reel of 3 across with 2s, RSh to 2L to
    start.  1s end in 2nd place in middle facing own side
25-32::
    Promenade (Chaperoned) Chain progression:
::
    _25-26_    3s & 2s 3/4 turn partner RH into middle _while_ 1s dance
    clockwise 1/4 round the set picking up 3L/2M …
::
    _27-30_    who promenade 1/2 way clockwise _while_ middle people (2L
    + 3M) turn LH 1.1/2.
::
    _31-32_    2s & 3s turn partner RH 3/4 to own sides _while_ 1s dance
    clockwise 1/4 round to end in 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5653, '2013-08-21 08:31:10.921986+00', '2023-02-04 01:20:22.276331+00', 3020, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s+2s+3s circle 6H round & back
17-24::
    All set, dance DoSiDo & set
25-32::
    1s cast to 4th place (2s+3s+4s step up) & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (13384, '2020-12-02 01:18:25.054096+00', '2023-02-04 01:18:23.526204+00', 19145, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up), dance in front of 3s, behind 4s (4s
    step up) to 4th place
9-16::
    4s+1s dance 1/2 R&L; 3s+1s dance 1/2 R&L
17-20::
    2s+1s dance 1/2 R&L. 1 (2) (3) (4)
21-24::
    All advance (2 bars), 2s+3s+4s 1/2 turn partner 2H & all retire (2
    bars) to end facing up/down.  1 2 3 4
25-28::
    _1/2_ mirror reels of 4 on sides (Men RSh, Ladies LSh). 4 3 2 1
29-32::
    1s stand, 4s+3s+2s dance 1/2 mirror reels of 3 on sides (4M+3M pass
    RSh, 4L+3L pass LSh).  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (3960, '2013-08-21 08:30:40.102476+00', '2023-02-04 01:18:23.715243+00', 7337, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s Fig of 8 round 2s
17-24::
    1L+2M turn RH, 1M+2L turn RH
25-32::
    1s lead down the middle & up to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (3961, '2013-08-21 08:30:40.112531+00', '2023-02-04 01:18:23.751849+00', 9726, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance 1/2 Fig of 8 round 2s
9-12::
    All set, 1s turn RH to face 2nd corners
13-24::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s meet again in
    middle to face their 4th corner positions
25-32::
    1s turn 4th corners RH to end in 2nd place own sides, all chase
    clockwise 1/2 way & 1s cross RH', 0);
INSERT INTO 'dancecrib' VALUES (5654, '2013-08-21 08:31:10.930032+00', '2023-02-04 01:20:22.434892+00', 8866, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH & cast in 1 place; 2s+1s also 4s+3s dance RH across
    & 1s & 4s (nearer hands joined with partner) end 1s facing 2M & 4s
    facing 3L on 1st corner diagonal
9-24::
    1s & 4s dance diagonal 1/2 ''Hand-in-Hand'' reels of 4 with each
    corner in turn (1s & 4s dance NHJ with partner, turning about in
    each corner to change hands & pass other couple RSh in centre).
    Bars 23-24: 1M+4M pass RSh (followed by partner) to end on opp sides
    2 (4) (1) 3
25-32::
    4s+1s dance RH across; 1s & 4s cross RH with partner & set. End 2 4
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (5655, '2013-08-21 08:31:10.938008+00', '2023-02-04 01:20:22.45495+00', 2873, 3, NULL, 'ace', '1-8::
    1st turn RH, 1L followed by partner casts below 3s, 1L crosses to
    opposite side & both cast/dance up to 2nd place
9-16::
    1s dance reels of 3 on opposite sides giving LSh to 2s
17-24::
    1s+3s dance RH across, 1s cross up between 2s & cast to 2nd place
    own sides
25-32::
    1L dances Fig of 8 round 2s _while_ 1M dances Fig of 8 round 3s
    _while_ 2s+3s set, cross RH set & cross back RH', 0);
INSERT INTO 'dancecrib' VALUES (5656, '2013-08-21 08:31:10.946053+00', '2023-02-04 01:20:22.474574+00', 2878, 3, NULL, 'ace', '1-8::
    1s cross to 2nd place opposite sides, 1s+3s set, 1s cross to 1st
    place own sides & cast 1 place
9-16::
    1s dance reels of 3 across 1L with 2s & 1M with 3s
17-24::
    1s cross down & cast up round 3s on opposite sides to meet in centre
    facing 2s, turn 2s by nearer hand end facing 3s
25-32::
    1s turn 3s by nearer hand, cross up & cast down to 2nd place on own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (5657, '2013-08-21 08:31:10.954038+00', '2023-02-04 01:20:22.619717+00', 2883, 3, NULL, 'ace', '{{explanation}}
2 couple set with an additional Lady in centre & 2nd cpl on opp sides  
On opening chord all bow or curtsey toward the centre Lady (»Herself«) who curtsies toward top of the set.

1-16::
    Herself dances 4x1/2 diagonal reels of 3 giving RSh to 1L to start
17-24::
    Herself dances RH across with 1s & then LH across with 2s & end
    joining nearer hand with 1M facing down & 2M on her left (no hands)
25-32::
    Herself with 1M & 2M dance down for 2 bars & return in ''Triumph'',
    Men dance back to places _while_ Herself changes place RH with 1L
    who changes places LH with 2L who becomes the new Herself', 0);
INSERT INTO 'dancecrib' VALUES (5658, '2013-08-21 08:31:10.963828+00', '2023-02-04 01:20:22.649806+00', 9583, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, 1s facing 2s set, 1s facing up cast 1
    place as 2s dance up
9-16::
    1s+3s repeat above Fig
17-24::
    2s+3s+1s dance reflection reels of 3 on sides 1s dancing in & up to
    start end with 1s (at bottom) facing up & 3s down
25-32::
    All set, 1s+2s face partners & turn 2H to face up/down _while_ 3s
    form an arch, 2s dance under arch & cast back to top as 1s cast to
    top & dance under arch to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (14731, '2022-04-01 00:20:06.27347+00', '2023-02-04 01:20:22.669159+00', 18301, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+2s also 3s+4s dance 1/2 RH across, 1s+4s circle 4H round to left
    (4 bars), 2s+1s also 4s+3s dance 1/2 RH across.  1 2 3 4
17-24::
    1s & 3s dance Fig 8 round 2s/4s
25-28::
    2s & 4s set, 4s lead up to 2nd place _while_ 2s cast to 4th place
29-32::
    2s make arch & dance up to top as 1s followed by 4s & 3s dance down
    under arch to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14732, '2022-04-01 00:20:06.292474+00', '2023-02-04 01:20:22.699292+00', 18303, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across; 2s+3s dance LH across
9-16::
    Reels of 3 on sides, 1s+2s pass RSh
17-24::
    All dance "The Exchange":
::
    _17-18_   All cross RH with partner
::
    _19-20_   Centre dancers change places LH with dancer in 2nd corner
    pstn (2M+1M, 2L+3L) _while_ dancers in 1st corner pstn (3M & 1L) set
::
    _21-22_   All cross RH with dancer opposite
::
    _23-24_   Centre dancers change places LH with dancer in 2nd corner
    pstn (3L+1L, 1M+3M) _while_ dancers in 1st corner pstn (2L & 2M)
    set.  3 2 1
25-32::
    All circle 6H round & back.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5659, '2013-08-21 08:31:10.972138+00', '2023-02-04 01:20:22.7307+00', 10176, 3, NULL, 'ace', '1-8::
    1s+3s cross RH, 1/2 turn new corner LH to Bal-in-Line on sides
    (3L+2L+2M+1M & 3M+4M+4L+1L) & all 1/2 turn LH into square
9-16::
    1s+3s turn 3/4 partner into prom hold & dance 1/2 reel of 3 across
    (1s RSh to 2M & 3s RSh to 4M to start), all continue in same
    direction to end with 4M+2L in 1st place & 4L+2M in 3rd place, 1M in
    4th place & 3M in 2nd place with 1L & 3L in centre BtoB facing 2L &
    4L
17-24::
    Ladies dance LSh reel of 4 to end with 1L & 3L on their partner''s
    right
25-32::
    4s+2s dance in & dance LH across, 4L & 2L followed by partners dance
    to 3rd & 1st places', 0);
INSERT INTO 'dancecrib' VALUES (14509, '2022-01-10 02:18:17.518816+00', '2023-02-04 01:18:24.136216+00', 17950, 3, NULL, 'ace', '1-8::
    1s+2s+3s turn partner RH (4 bars); all chase clockwise 1/2 round to
    opp sides (3) (2) (1)
9-16::
    Mirror reels of 3 on sides (3s in/down, 2s out/up, 1s in/up) giving
    hands where possible
17-24::
    3s followed by 2s+1s (who dance up to start) dance down middle; Bar
    21: Ladies dance under Men''s right arm to change sides & all dance
    up, 1s+2s remain in centre facing partner, 3s end in 3rd place
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8589, '2015-02-13 12:47:49.941579+00', '2023-02-04 01:20:22.759457+00', 2887, 3, NULL, 'ace', '1-8::
    1s set, turn 2H, lead down, cross below 3s, cast up to face 1st
    corners
9-16::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn
    (pas-de-bas) to 2nd places own sides _while_ 2s+3s cross RH (bars
    15-16)
17-20::
    1s cast (1M down/1L up) to meet in centre _while_ 2M+3M and 2L+3L
    set, change places RH
21-24::
    1s turn LH _while_ 2s+3s chase 1/2 way round them clockwise.  1s
    finish facing 1st corners
25-32::
    1s turn corner, partner, corner and cross LH to 2nd place own sides
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12161, '2019-09-04 08:37:23.133321+00', '2023-02-04 01:20:22.772795+00', 19626, 3, NULL, 'ace', '1-8::
    1L+2M also 3L+4M Adv+Ret for 2 steps, dance DoSiDo
9-16::
    1M+2L also, 3M+4L repeat
17-24::
    1s turn RH, cast to 2nd place, turn LH to face 1st corners
25-32::
    1s dance RSh reel with 1st crns, pass LSh to face 2nd corners
33-40::
    1s dance RSh reel with 2nd crns, following into…
41-48::
    1s dance 1/2 Fig. 8 up around 2s, cross down between 3s + 4s (who
    step up), to end in 4th place', 0);
INSERT INTO 'dancecrib' VALUES (13749, '2021-03-02 01:20:10.393169+00', '2023-02-04 01:20:23.061786+00', 13424, 3, NULL, 'ace', '1-4::
    1s+4s turn partners RH (3 bars),1s facing down & 4s facing up with
    NHJ with partner dance down/up to meet in the centre (2s/3s step
    up/down)
5-8::
    1L&4L turn LH _while_ 1M&4M turn 1.1/2 LH, 1s+4s finish BtoB in the
    centre facing corners.
9-24::
    Rotating four-leaf clover:
::
    _9-12_    1s+4s turn corner RH, pull back RSh, finish facing next
    corner clockwise round
::
    _13-24_  All repeat bars 9-12 3 more times.
::
    _24_       1s+4s end in line of 4 across, 4s on own side, 1s BtoB in
    middle (from Ladies'' side to Men''s side, 4L, 1M, 1L, 4M)
25-32::
    1s+4s dance reel of 4 across the set. 1s do not pass LSh at end but
    finish facing each other on 1st corner diagonal
33-40::
    1s dance Tulloch turn to right & 2 spring points, repeat to left,
    _while_ 2s+3s+4s form a large circle (no hands), 4 slip steps left,
    set & 4 slip steps to right & set.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5662, '2013-08-21 08:31:10.998809+00', '2023-02-04 01:20:23.076082+00', 2896, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, 1s dance down middle & loop round to 4th place
    opp sides _while_ 3s+4s cast up 1 place & dance in to face corner
    persons
9-16::
    All set & 3s+4s turn corners RH, 3s+4s dance LH across & end on
    sides
17-24::
    All dance RSh reels of 4 on sides
25-32::
    2s & 1s petronella turn into middle & all set, 2s & 1s petronella
    turn to own sides & all set', 0);
INSERT INTO 'dancecrib' VALUES (5663, '2013-08-21 08:31:11.006961+00', '2023-02-04 01:20:23.092374+00', 2897, 3, NULL, 'ace', '1-8::
    All four Men dance across & pass RSh round partners, dance down to
    bottom & up on own sides to new places (reverse order)
9-16::
    4M+1L 1/2 turn RH, lead down to bottom & cast on opp sides to top,
    cross RH to pl as 1M+4L cross, cast to top, lead down & cross to pl
17-24::
    All circle 8H round & back
25-32::
    1L+2L, 3L+4L, 4M+3M, 2M+1M set & 1/2 turn 2H, centre dancers (1s+4s)
    turn right about to face each other on sides, set & 1/2 turn 2H
33-40::
    All four Ladies dance across & pass RSh round opposite Man, cast up,
    cross & dance down own sides to end 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (5664, '2013-08-21 08:31:11.082362+00', '2023-02-04 01:20:23.209709+00', 2900, 3, NULL, 'ace', '1-8::
    1s set advancing & dancing down turn out to face 2s who set twice,
    1M+2M turn RH as 1L+2L turn LH to end 1s facing down & 2s in 1st
    place
9-16::
    1s circle 4H round to left with 3s, 1s turn to face up & circle 4H
    round to right with 2s
17-24::
    1s dance up, cast to 3rd place & 2s+3s+1s turn RH
25-32::
    3s+1s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5665, '2013-08-21 08:31:11.092386+00', '2023-02-04 01:20:23.314241+00', 2903, 3, NULL, 'ace', '1-8::
    1s+2s cross Men dancing between Ladies, cross back Ladies dance
    between Men
9-16::
    1s+2s dance RH across & dance LH back
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (5666, '2013-08-21 08:31:11.101782+00', '2023-02-04 01:20:23.333616+00', 13587, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    All dance reels of 4 on sides but middle couples do not pass LSh &
    end turning about to face corners.  1 3(2)(4)
9-16::
    1s+3s also 2s+4s dance R&L starting RH on sides.  At end 3s & 2s
    remain in centre facing partners joining 2H ready for …
17-24::
    3s+2s dance poussette
25-32::
    2s & 3s dance 1/2 Figs of 8 round end couples, all turn partners RH
    & end in middle 1s+2s facing up 3s+4s down.  1 2(3)(4)
33-40::
    All dance interlocking Allemandes:
::
    1s & 2s dance normal Allemande but end in 3rd/1st places _while_
    3s+4s Allemande (down) & up to 4th/2nd places to end 2(4)1(3)', 0);
INSERT INTO 'dancecrib' VALUES (5667, '2013-08-21 08:31:11.109899+00', '2023-02-04 01:20:23.352833+00', 2905, 3, NULL, 'ace', '1-8::
    1s & 4s set, cross RH, cast in 1 place & turn LH on sides (2s & 3s
    step up/down bars 5-6)
9-16::
    2s+1s also 4s+3s dance RH across; 1s+4s dance 1/2 R&L
17-24::
    2M+4L also 1M+3L join RH & set to partners, turning right about set
    to other''s partner; 2s+4s also 1s+3s dance LH across
25-32::
    2L+4M also 1L+3M retain LH & repeat setting to partner & other''s
    partner; 2s+4s also 1s+3s dance RH across. End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5668, '2013-08-21 08:31:11.202064+00', '2023-02-04 01:20:23.534399+00', 2906, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 on own side round 2s+3s (dance between 2s to
    start) & end facing 1st corners
9-16::
    1s turn 1st corners RH, pass partner RSh & turn 2nd corners RH, pass
    partner LSh to face own sides for Double Triangles
17-24::
    1s dance Double Triangles
25-32::
    2s+1s+3s dance Grand Chain (2s cross RH to start)', 0);
INSERT INTO 'dancecrib' VALUES (5669, '2013-08-21 08:31:11.216176+00', '2023-02-04 01:20:23.679392+00', 2910, 3, NULL, 'ace', '1-8::
    1s cast, dance down behind own lines, turn outwards & dance back to
    place
9-16::
    1s+2s turn partners RH back to place & then turn LH
17-24::
    1s followed by 2s, lead down the middle & 2s lead back to the top
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (13776, '2021-03-02 01:22:24.107173+00', '2023-02-04 01:23:08.482061+00', 12971, 3, NULL, 'ace', '1-8::
    1s+2s also 4s+3s change places LH on sides (2 bars),  2s+1s+3s dance
    RSh reel of 3 on own sides, 1s pass 3s RSh to start
9-16::
    1s+3s dance RH across; 2s+1s dance LH across. End 2 1 3 with 1L
    facing out
17-24::
    1L followed by 1M dance Tandem reel of 3 across passing 3L RSh to
    start
25-28::
    1s in tandem dance up middle, 1L pulls back RSh to face 1M (1L
    facing down & 1M facing up), 1s turn 1.1/4 RH face up (1L on 1M''s
    right)
29-32::
    2s+1s circle 4H round to the left to finish 1s in 2nd place own side
    facing down.  2 1 3

{{explanation}}
On bar 1-2 of 2nd turn for each dancing couple, only 1s+2s change places LH on own sides. 2nd turn ends 2 3 1 4', 0);
INSERT INTO 'dancecrib' VALUES (3962, '2013-08-21 08:30:40.122614+00', '2023-02-04 01:18:23.780539+00', 88, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, 1s+2s cross RH & 1s 1/2 turn LH to face 1st
    corners
9-12::
    1s change places with corners RH, corners 3/4 turn LH in middle to
    face 2nd corner pstns _while_ 1s change places LH with opposite
    persons
13-16::
    Centre dancers change places with corners (1s) RH who turn LH 1.1/4
    times in middle to face 1st crnrs _while_ 2s+3s change places with
    opp person
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners & 1/2 diagonal reel
    with 2nd corners
25-32::
    1s dance full Figs of 8 across 1L with 2s & 1M with 3s
33-40::
    2s+1s+3s dance RSh reels of 3 on sides (Man up & Lady down) 1s end
    crossing RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (11194, '2018-09-30 22:19:52.26952+00', '2023-02-04 01:20:21.838567+00', 18592, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance - 2 facing 2

1-8::
    All set, dance 1/2 RH across; all set, dance 1/2 LH across
9-16::
    Ladies'' Chain
17-24::
    All dance R&L
25-32::
    All Adv+Ret with partner; pass person opposite RSh to meet new
    couple', 0);
INSERT INTO 'dancecrib' VALUES (13750, '2021-03-02 01:20:11.133807+00', '2023-02-04 01:20:23.835211+00', 13377, 3, NULL, 'ace', '{{explanation}}
Special set: 1s+4s on Men''s side & 2s+3s on Ladies'' side,  
`	1M with 4M & 2M with 3M BtoB in centre on Mens/Ladies'' side, all Ladies facing partners. Order: 1L 1M 4M 4L on Men''s side, 2L 2M 3M 3L on Ladies'' side

{{title}}
Part A - Strathspey:

1-8::
    All set to partners with suitable Highland Strathspey steps
9-16::
    All dance halfway *Axum Reel*
::
    _9-10_ All couples pass LSh, Men to partner''s »outer« positions,
    1L/3L veering left to 2M/4M positions, 2L/4L straight ahead to 3M/1M
    positions.
::
    _11-16_ Repeat 3 times from new positions all ending diagonally
    opposite starting positions.
17-24::
    All set to partners with suitable Highland Strathspey steps
25-32::
    Repeat bars 9-16 to dance back to original positions

{{title}}
Part B - Reel:

1-2::
    1M+2L also 4L+3M set advancing _while_ 1L+2M also 4M+3L step back
    diagonally right. 1s+2s also 3s+4s finish in lines of 4 across the
    dance
3-4::
    1M+2L also 4L+3M set turning on spot (pulling back RSh)
5-8::
    1M+2L also 4L+3M set & 4 spring points to finish facing each other
    across the dance.
9-11::
    1M+2L also 4L+3M Tulloch turn 1.1/2 times with right arms linked

{{explanation}}
12	1M+2L also 3M+4L do assemble (jump on the spot landing with right foot in front, 3rd position) & change (jump on the spot landing with left foot in front)

13-16::
    1M+2L also 4L+3M Tulloch turn 2 times with left arms linked to
    finish facing outside person
17-24::
    All set to person facing with suitable Highland reel steps (2M+1M,
    2L+1L, 3L+4L, 3M+4M)
25-32::
    1L+2L+3M+4M also 1M+2M+3L+4L dance RH across & LH back
33-40::
    Centre dancers 1L+2M also 4M+3L set with suitable Highland reel
    steps
41-48::
    1L+2M also 4M+3L repeat Part B bars 9-16
49-56::
    All set to partners with suitable Highland reel steps
57-64::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14656, '2022-03-07 02:20:01.297504+00', '2023-02-04 01:20:23.854319+00', 20643, 3, NULL, 'ace', '1-8::
    1s clap & cross passing RSh, cast (2s step up);  1s dance 1/2 Fig 8
    down round 3s
9-16::
    2s+1s+3s dance mirror reels of 3 on sides (1s in/up, 2s out/down, 3s
    out/up) 2s & 3s curve into place
17-24::
    1s dance DoSiDo; 2s+1s+3s dance RSh round partners & back to place
25-28::
    All chase clockwise into lines of 3 across, all change places RH
    with partner
29-32::
    All chase clockwise to own sides, 2L followed by 1L & 3L cast up
    _while_ 3M followed by 1M & 2M cast off to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5670, '2013-08-21 08:31:11.230436+00', '2023-02-04 01:20:23.892282+00', 2911, 3, NULL, 'ace', '1-8::
    All set HS, 1s+3s advance & 1/2 turn opposite person 2H to face side
    couples (M facing M)
9-16::
    All set HS, 1s & 3s dance out between side couple & face in _while_
    2s & 4s dance in & 1/2 turn opp person 2H to face side couples (M
    facing L)
17-24::
    All dance RSh reels of 4 across ending with 4M+2L & 2M+4L passing LH
    joined to dance out to 1st & 3rd places
25-32::
    1s+3s dance 1/2 Ladies Chain, 2s+4s dance 1/2 Ladies Chain (all now
    with own partners 1 place clockwise)', 0);
INSERT INTO 'dancecrib' VALUES (5671, '2013-08-21 08:31:11.238692+00', '2023-02-04 01:20:23.91985+00', 2914, 3, NULL, 'ace', '1-8::
    All set to partner & turn RH to face corner, set to corner & turn LH
9-16::
    1s+3s dance RH across & end facing 2s/4s, all set HS
17-24::
    2s+1s+3s+4s dance reels of 4 across & at end 1s & 3s do not pass
    each other but turn right about
25-32::
    1L+3M & 1M+3L lead out between 2s/4s cross & dance round to opposite
    sides, All dance Grand Chain 1/2 way
33-56::
    2s+4s repeat bars 9-32 but up/down set
57-64::
    All circle 8H round & back

{{explanation}}
Repeat in reel time but the HS is replaced by any Highland Step', 0);
INSERT INTO 'dancecrib' VALUES (5672, '2013-08-21 08:31:11.248656+00', '2023-02-04 01:20:24.054494+00', 2916, 3, NULL, 'ace', '1-8::
    1s set, cast to 3rd place (3s step up), 2s+3s cross RH
9-16::
    1s lead up to top (2s+3s step down), set, cast down 1 place to face
    3rd corner pstns (2s step up)
17-24::
    1s set & turn 3rd corners, set & turn 4th corners 1s end facing out
    in 2nd place on own sides
25-32::
    2s+1s+3s Bal-in-Line twice & turn RH back to places (2s & 3s turn
    1.1/2 times)', 0);
INSERT INTO 'dancecrib' VALUES (5673, '2013-08-21 08:31:11.331645+00', '2023-02-04 01:20:24.09084+00', 8833, 3, NULL, 'ace', '1-8::
    1s+2s set twice, circle 4H round to left & end in centre facing up,
    ready for …
9-16::
    1s+2s dance Allemande, 1s pass partner with setting step to end
    facing 1st corners
17-24::
    1s turn 1st corners RH, dance round each other passing LSh to turn
    4th corners RH & dance round each other LSh to…
25-32::
    1s turn 3rd corners RH, dance round each other LSh to turn 2nd
    corners RH & 1s cross LH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5674, '2013-08-21 08:31:11.347939+00', '2023-02-04 01:20:24.230114+00', 2918, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place, 1s dance 1/2 reels of 3 across (Lady
    with 2s & Man with 3s)
9-16::
    1s dance down between 3s, cast up to 2nd place opposite sides &
    dance 1/2 reels of 3 across (Man with 2s & Lady with 3s)
17-24::
    2s+1s dance R&L
25-32::
    1s dance down between 3s, cast up to 2nd place & 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5675, '2013-08-21 08:31:11.356097+00', '2023-02-04 01:20:24.254327+00', 8056, 3, NULL, 'ace', '1-8::
    1s+2s set twice, 1s+2s dance RH across
9-16::
    1s cast below 3s & dance up to top, 1s cast 1 place & face 1st
    corners
17-24::
    1s turn 1st corner RH & turn partner LH, turn 2nd corner RH &
    partner LH to end 2nd place own sides
25-32::
    1s+3s dance R&L

{{explanation}}
Note: May be danced as a Strathspey or Jig', 0);
INSERT INTO 'dancecrib' VALUES (3964, '2013-08-21 08:30:40.229745+00', '2023-02-04 01:18:24.036928+00', 89, 3, NULL, 'ace', '1-8::
    1s lead down to bottom, all set & circle 8H round to left 2 places
    (end with Men at top of dance & Ladies at bottom)
9-16::
    Men dance LH across & Ladies RH across once round, continue but
    change places with partner when passing thru middle in order 1 4 3 2
17-24::
    As 1s (+4s+3s+2s) meet again (Men drop RH) & leads his prtnr round
    to end 1s (followed by 4s+3s+2s) leading up to top, all 1/2 turning
    RH into…
25-32::
    All dance Allemande ending 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5676, '2013-08-21 08:31:11.36431+00', '2023-02-04 01:20:24.281303+00', 8850, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    All clap as 1s & 4s cross RH & cast in 1 place, 1s+4s set & dance RH
    across 1/2 way
9-16::
    All clap as 4s & 1s cross RH & cast to ends, 4s+2s also 3s+1s set &
    dance RH across 1/2 way to end 2s facing 4s & 1s facing 3s
17-24::
    All set & petronella turn into lines of 4 across (Man facing Man
    etc) & dance 1/2 reel of 4 across
25-32::
    All set & 3/4 turn RH facing person all onto sides & chase clockwise
    1/2 way to end 3 1 (4)(2)', 0);
INSERT INTO 'dancecrib' VALUES (5678, '2013-08-21 08:31:11.383433+00', '2023-02-04 01:20:24.349781+00', 2924, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 2nd place, dance RH across with 3s
9-16::
    2s+1s dance LH across, 1L followed by partner cast up round 2L &
    dance down middle to 1L between 3s & 1M between 2s
17-24::
    1s+2s+3s dance down the middle & back
25-32::
    1M followed by partner dance up, cast down round 2L to 2nd places on
    own side & turn RH
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5679, '2013-08-21 08:31:11.393134+00', '2023-02-04 01:20:24.468268+00', 2925, 3, NULL, 'ace', '{{explanation}}
Round the Room 3 facing 3

1-8::
    All Adv+Ret twice
9-16::
    Men reel of 3 across with Lady on right & opposite Lady starting by
    passing opposite Lady LSh
17-24::
    Men with same Ladies 3H round & back
25-32::
    All Adv+Ret & lead thru passing opposite person RSh', 0);
INSERT INTO 'dancecrib' VALUES (8591, '2015-02-13 12:47:50.415925+00', '2023-02-04 01:20:24.494349+00', 2926, 3, NULL, 'ace', '1-8::
    1s set, cross (no hands) to 2nd place opp sides (2s step up 3-4), 1s
    3/4 turn 1st corners 2H into lines across (1L between 2s facing
    down, 1M between 3s facing up) and all set
9-10::
    All turn person opposite 2H to end with 2s & 3s facing across, 1L
    facing up and 1M facing down, ready for…
11-16::
    1s dance reels of 3 across passing 4th corners RSh to end 1s in 2nd
    place on opposite sides 2 (1) 3
17-24::
    1s set, dance RSh round each other to 3/4 turn 2nd corners 2H. 1s
    end between their corners and all set
25-26::
    All turn partners 2H to end with 2s facing down, 3s facing up and 1s
    facing out, ready for …
27-32::
    1s dance reels of 3 on opposite sides passing 1st corners RSh &
    cross diagonally (1M from 1st place ladies'' side, 1L from 3rd place
    man''s side) to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5680, '2013-08-21 08:31:11.505384+00', '2023-02-04 01:20:24.800698+00', 2931, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    Both couples circle to left & back again
9-16::
    Both couples dance RH across & LH back to places
17-24::
    All turn opposite partner LH & face own partner, turn partner RH &
    end facing other couple
25-32::
    All Adv+Ret, all couples advance (couples facing clockwise round the
    room make arches) & pass to meet new couple', 0);
INSERT INTO 'dancecrib' VALUES (8592, '2015-02-13 12:47:50.521533+00', '2023-02-04 01:20:24.831129+00', 15312, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opposite sides

1-8::
    2s+3s dance 1/2 R&L, 1s+3s also 2s+4s dance 1/2 R&L
9-16::
    All set, all turn ptnrs 2H once round. 3s+1s also 4s+2s circle 4H
    round to Left finish on sides with 1s+2s facing up, 3s+4s facing
    down
17-24::
    All set (Glasgow Highlanders) to facing person.  All dance 1/2 LSh
    reels of 4 on sides
25-32::
    All dance modified »Chain Progression«
::
    _25-26_   Facing couples (2M+4L, 1M+3L, 2L+4M, 1L+3M) 3/4 turn LH
::
    _27-30_   1L+3L also 2L+4L turn RH 1.1/2 times _while_ ptnrs dance
    antioclockwise 1/2 way round them
::
    _31-32_   Facing couples (2M+4L, 1M+3L, 2L+4M, 1L+3M) 3/4 turn LH
    to sides  2 (4) 1 (3)', 0);
INSERT INTO 'dancecrib' VALUES (5681, '2013-08-21 08:31:11.515549+00', '2023-02-04 01:20:24.860044+00', 12603, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s cross passing LSh & cast round 1st corner
    to end 1L between 2s & 1M between 3s
9-16::
    1s set advancing (arms raised Highland style) & Tulloch turn (left
    arm raised) for 6 bars & end turning about to face opposite ends
17-24::
    1M+3s & 1L+2s dance RH across, pass RSh to dance LH across & pass
    LSh to face 1st corners
25-32::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners & pass RSh to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5682, '2013-08-21 08:31:11.523571+00', '2023-02-04 01:20:24.885815+00', 2933, 3, NULL, 'ace', '1-8::
    1s & 3s, passing partner RSh (similar to turn 3/4 RH), dance 1/2
    reel of 4 up/down middle; 3s+1s  turn partners RH 1.1/4 times to own
    sides
9-16::
    3s+2s+1s set, cross RH & chase clockwise to original places
17-24::
    1s+2s dance RH across 1/2 way & set, 1s+3s dance LH across 1/2 way &
    set
25-32::
    1s lead up to top, cross & cast to 2nd place opposite sides (3s step
    down 27-28), 2s+1s+3s set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (5683, '2013-08-21 08:31:11.602619+00', '2023-02-04 01:20:25.081975+00', 2934, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place & turn LH 1.1/2 times to end facing 1st
    corners
9-16::
    1s set & turn 1st corners 2H, set & turn 2nd corners 2H ending
    facing 1st corners
17-24::
    1s dance reels of 3 on opposite sides giving LSh to 1st corner &
    cross RH to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5684, '2013-08-21 08:31:11.612555+00', '2023-02-04 01:20:25.208899+00', 8087, 3, NULL, 'ace', '1-8::
    1s set twice, cross RH & cast down to 3rd place
9-16::
    3s+1s circle 4H round to left, 1s lead up to top & cast to 2nd place
    to face 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corner &
    cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5685, '2013-08-21 08:31:11.620558+00', '2023-02-04 01:20:25.228141+00', 2935, 3, NULL, 'ace', '1-8::
    All 4 couples in prom hold advance 2 steps to centre & retire, all
    Ladies cast 1 place clockwise
9-16::
    All with new partners Adv+Ret, all Men cast 1 place anticlockwise
17-24::
    All set to new partners, 1M+3M change places LH, 2M+4M change places
    LH & all set to own partners
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5686, '2013-08-21 08:31:11.628633+00', '2023-02-04 01:20:25.247743+00', 13931, 3, NULL, 'ace', '1-8::
    1s+2L also 3s+2M dance RSh reels of 3 across  (1L & 3M pass prtnr by
    R to start).  2s end 2nd place, 1L & 3M dance into middle BtoB to
    face prtnr
9-16::
    1s+3s dance diagonal reel of 4 (pass prtnr RSh), 3M & 1L cast (1L
    from 3L place, 3M from top) back to place on bars 15/16.  1 2 3 4
17-22::
    1s+2s dance 3/4 double Fig of 8 (1s cross down, 3s dance up to
    start). 1s end facing out  (2)1 3 4
23-24::
    2s cross RH _while_ 1s cast 1 place as 3s step up.  2 3 1 4
25-32::
    1s followed by 4s dance up & cast round 3s to 4th & 3rd places,
    4s+1s dance RH across.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (3965, '2013-08-21 08:30:40.237857+00', '2023-02-04 01:18:24.070016+00', 7338, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance - 3 dancers in triangular formation - 1st dancer facing clockwise to 2nd & 3rd (numbered clockwise)

1-8::
    All dance RH across & LH back
9-16::
    _1_ turns 3 RH & turns 2 LH
17-24::
    All dance reel of 3 (1 gives RSh to 3 to start)
25-32::
    _1_ sets to 2+3 (as Double Triangles), all advance & turn right
    about & set again, 1 turns right about & 2+3 turn inwards to face
    new partners', 0);
INSERT INTO 'dancecrib' VALUES (8770, '2015-06-15 11:40:22.563338+00', '2023-02-04 01:18:24.173426+00', 16124, 3, NULL, 'ace', '{{explanation}}
2 chords - on 2nd chord 3s & 4s cross to opp sides

1-8::
    All circle 8H 1/2 way round to Left.  All set & cross RH
9-16::
    Repeat Bars 1-8 finishing in allemande hold, 1s+2s face up, 3s+4s
    face down
17-24::
    Interlocking allemandes: Bars 19-20 1s & 4s pass on sides then
    complete allemandes to finish 2 (4) 1 (3)
25-32::
    4s+1s dance RH across.  4s & 1s dance 1/2 Figs 8 (4s up round 2s, 1s
    down round 3s). End  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (12904, '2020-07-01 00:18:22.009895+00', '2023-02-04 01:18:24.647676+00', 17586, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Poussette
9-16::
    4s followed by 3s+2s+1s lead down; 1s lead up 2 steps & cast to 4th
    place _while_ 2s+3s+4s contine to lead up.  2 3 4 1
17-24::
    RSh reels of 4 on sides
25-32::
    All circle 8H round & back.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14657, '2022-03-07 02:20:02.253698+00', '2023-02-04 01:20:25.273367+00', 16600, 3, NULL, 'ace', '1-8::
    All dance reels of 3 on sides (1s in/down, 2s out/up, 3s in/up)
9-12::
    1s dance 1/2 Fig of 8 round 2s
13-16::
    1s turn 2s 1.1/4 on sides (1M LH, 1L RH) to face 2s BtoB in middle
    of 2nd place (1M facing 2L, 1L facing 2M)
17-24::
    1s dance the Spurtle: 1s dance 1/2 RSh reel of 4 with 2s & turn RH
    to face 3s, 1s dance 1/2 RSh reel of 4 with 3s & turn RH to 3rd
    place opposite sides (2) (3) (1)
25-32::
    2s+3s+1s set, turn 2H 1.1/2 times to finish on own sides. All set.
    2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13174, '2020-09-15 00:20:02.149714+00', '2023-02-04 01:20:25.30206+00', 16842, 3, NULL, 'ace', '1-8::
    All 1/2 turn corner RH, turn next LH once round, 1/2 turn corner RH
    & turn partner LH.  Men face out
9-16::
    Interlocking Ladies'' Chain (Ladies 1/2 RH across in centre)
17-24::
    Set, Link & Progress:
::
    _17-20_   All Set+Link with partner, Men moving in & to right to
    BtoB in centre facing next place anticlockwise, Ladies outside
    original place facing in
::
    _21-24_   All set to ''new partner'' & turn 1.1/4 2H (Ladies now in
    partner''s place, ''new partner'' on right)
25-32::
    Set, Link & Progress:
::
    _25-28_   All Set+Link with partner, Ladies moving in & to right to
    BtoB in centre facing next place anticlockwise (original partner),
    Men outside place facing in
::
    _29-32_   All set to partner & turn 1.1/4 2H.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13175, '2020-09-15 00:20:02.168165+00', '2023-02-04 01:20:25.322383+00', 18330, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp side

1-4::
    1s+2s also 3s+4s dance 1/2 Double Fig 8 (1s/4s cross down/up, 2s/3s
    dance up/down)
5-8::
    1s & 4s turn partner 1.1/2 RH _while_ 2s+3s change places on side
    turning 1.1/2 LH
9-12::
    1s+3s also 2s+4s dance 1/2 Double Fig 8(1s/4s cross down/up, 2s/3s
    dance up/down)
13-16::
    1s & 4s turn partner 1.1/2 RH _while_ 3s+2s change places on side
    turning 1.1/2 LH
17-24::
    All dance Grand Chain, 1s & 4s cross, 2s+3s change places on side to
    start.  Omit polite turns
25-28::
    All 1/2 turn partner RH flowing into 2s+1s also 4s+3s dance 1/2 RH
    across;
29-32::
    2s+1s also 4s+3s dance 1/2 LH across, all chase 2 places round
    anticlockwise
33-40::
    1s+4s set, petronella in tandem; 1s+4s Set+Link across to end 2 4
    (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (5687, '2013-08-21 08:31:11.636823+00', '2023-02-04 01:20:25.343633+00', 11523, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s set & cross RH, cast in 1 place & 1M+4M petronella turn into
    centre _while_ partners turn LH to end BtoB facing partners
9-16::
    1s+4s dance reel of 4 in centre
17-24::
    1M followed by partner dance reel of 3 with 2s (RSh to 2L) _while_
    4M followed by partner reel of 3 with 3s (RSh to 3L) & end 2(1)4(3)
25-32::
    1s+4s dance RH across, 1s+4s set facing & change places RH on sides
    to end 2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (9735, '2017-04-06 08:39:50.742522+00', '2023-02-04 01:20:25.829122+00', 17662, 3, NULL, 'ace', '1-8::
    1s dance in, cast (2s step up).  1s turn LH to face 1st corners
9-16::
    1s dance 1/2 diag reel of 4, pass RSh to face 2nd corners.  1s+2nd
    corners turn RH, 1s pass RSh to face 3rd corners
17-24::
    1s dance 1/2 diag reel of 4, pass RSh to face 4th corners.  1s+4th
    corners turn RH.  1s end in 2nd place own sides
25-32::
    _1/2_ Figs 8, 1M round 2s & 1L round 3s, then 1M round 3s & 1L round
    2s', 0);
INSERT INTO 'dancecrib' VALUES (5691, '2013-08-21 08:31:11.865696+00', '2023-02-04 01:20:25.859626+00', 11225, 3, NULL, 'ace', '1-8::
    1s+2s+3s 1/2 turn RH, twirl & dance out to partner''s place & chase
    clockwise 1/2 way ending with 2s facing 1st corner pstns
9-16::
    2s dance Fig of 8 round 1st & 2nd corner pstns ending 2nd place
    opposite sides
17-24::
    2s change places RH with person diag to right, new centre couple LH
    with person diag left, new centre cpl RH diag to right, all cross LH
    (as »Cashmere Shawl«)
25-32::
    1s+2s turn 1.1/2 times on sides (LH Men''s side & RH Ladies side),
    1s+3s dance 1/2 double Fig of 8 (1s in & down to start)', 0);
INSERT INTO 'dancecrib' VALUES (8328, '2014-07-29 12:59:06.384061+00', '2023-02-04 01:20:25.879828+00', 15223, 3, NULL, 'ace', '{{explanation}}
1s start on opposite sides

1-8::
    1M followed by 2L+3L dances across top of set, behind Men''s side and
    back up to places
9-16::
    1s cross down to dance reflection reels of 3 on own sides; finish 2s
    in 1st place, 1s in centre facing down
17-24::
    1L+2L+3L dance LH across as 1M+2M+3M dance RH across, 1s cross to
    dance 1L+2M+3M RH across as 1M+2L+3L dance LH across
25-32::
    1s dance in, meet & dance down to 3rd place (2s+3s step up 27-28);
    2s+1s dance 1/2 double Fig 8 round 3s (2s cross down, 1s cast up to
    start) (2) 3 1', 0);
INSERT INTO 'dancecrib' VALUES (3978, '2013-08-21 08:30:40.757106+00', '2023-02-04 01:18:24.996268+00', 11027, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 2s+1s circle 4H round to left
9-16::
    1s+3s Set+Link, 3s+1s circle 4H round to left
17-24::
    1s dance up to top, cast to 2nd places & turn LH to face 1st corners
25-32::
    1s turn 1st corners RH, turn partner LH, turn 2nd corners RH &
    partner LH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (15334, '2022-12-19 01:20:10.782123+00', '2023-02-04 01:20:25.897754+00', 19975, 3, NULL, 'ace', '1-4::
    1s set, dance »Tom Bombadil« turn:
::
    1s 1/2 turn RH (1M dances above 1L _while_ lady dances under arch
    made by the joined hands, 1M curves clockwise _while_ 1L curves
    anticlockwise to finish next to each other in middle in 1st place
    facing up
5-8::
    1s cast & turn 3/4 LH to face 1st corners (2s step up 5-6)
9-16::
    1s dance »Hello-Goodbye« setting. Bar 15-16: 1s 3/4 turn RH to
    finish RHJ in middle in 2nd place facing down
17-24::
    1s cross down between 3s, cast up to 2nd place in centre RHJ facing
    up. 1s cross up between 2s, cast to 2nd place in centre 2H joined.
    3s step in on bar 24
25-32::
    1s+3s dance Poussette 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5692, '2013-08-21 08:31:11.874088+00', '2023-02-04 01:20:25.914024+00', 10060, 3, NULL, 'ace', '1-8::
    1s cross, cast & dance RH across (1M with 2s & 1L with 3s)
9-16::
    1s dance RSh reels of 3 across (1L with 2s & 1M with 3s) 1s end with
    1/2 RH turn to BtoB Man facing up & Lady down
17-24::
    2s+3s dance R&L (starting on sides) _while_ 1s dance RSh round 2nd
    corner (pstn), turn LH & dance LSh round 1st corner to 2nd place opp
    side
25-32::
    2s+1s+3s set, 1s petronella turn into lines across, set & 1s
    petronella turn to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5693, '2013-08-21 08:31:11.882733+00', '2023-02-04 01:20:25.933229+00', 2947, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, all chase clockwise to own sides
9-16::
    1s+2s+3s set, cross LH, all chase anticlockwise to own sides
17-24::
    1M+3L change places RH, 1L+3M change places RH, 2s cross RH &
    3s+2s+1s set.  (3)(2)(1)
25-32::
    3s+2s+1s dance "Horse-shoe Chain" for 3 couples:
::
    _25_   1s cross LH
::
    _26_   1s+2s change places RH on side
::
    _27-28_  1s change places LH with 3s _while_ 2s cross LH
::
    _29-32_  1s turn RH into 2nd place (4 bars) as 2s+3s change places
    RH on side (2 bars), 2s dance up to 1st place (2 bars) _while_ 3s
    cross LH to 3rd place own side. 2 1 3

{{explanation}}
Note: Deviser states all 3 couples dance 8 bars (25-32), 2s & 3s dancing small skip change steps down sides at start of chain.', 0);
INSERT INTO 'dancecrib' VALUES (10075, '2017-09-03 23:44:45.699974+00', '2023-02-04 01:20:25.959287+00', 16211, 3, NULL, 'ace', '{{explanation}}
Round the Room, 2 facing 2

1-8::
    All Adv (2) Ret (2) Couples facing clockwise dance between facing
    couple, turning them with NH back to place
9-16::
    Couples facing clockwise join 2H & slip step between facing couple
    (4 bars) & slip step back to place
17-32::
    Repeat bars 1-16 with anticlockwise couples as dancing couple
33-40::
    All set, pass opp person LSh to meet new couples & all circle 4H
    round to Left', 0);
INSERT INTO 'dancecrib' VALUES (13899, '2021-04-05 00:20:05.708363+00', '2023-02-04 01:20:25.987792+00', 12274, 3, NULL, 'ace', '1-4::
    1s turn 3/4 2H, dance out through own place & cast (2s step up (3-4)
5-8::
    1s join hands briefly (1L RH+1M LH) & 1L dances under 1M''s arm as 1s
    cross up & cast to 2nd place opp sides
9-16::
    1s Petronella turn (touch hands briefly) into lines of 3 across &
    all set; 1s repeat to 2nd place own side & all set
17-24::
    1s 1/2 turn 2H (1 step), open out & dance down NHJ (2 steps), 1s 1/2
    turn 2H (1 step), open out & dance up NHJ (2s step down) & 1s turn
    2H remaining in centre, 2s step in ready for …
25-32::
    1s+2s dance 1/2 Poussette, 1s remain in centre, 2s retire to 1st
    place; 1s+3s dance 1/2 Poussette.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5694, '2013-08-21 08:31:11.891057+00', '2023-02-04 01:20:26.008564+00', 2951, 3, NULL, 'ace', '1-8::
    1s cross down below 2s, cast down round 3s, 1/2 turn RH & lead up to
    BtoB position for double triangles
9-16::
    1s dance Double Triangles ending 2nd place own sides
17-24::
    1M followed by partner casts up round 2M & dances down centre, 1M
    between 3s & 1L between 2s all dance down in lines of 3 & turn right
    about
25-32::
    All dance up 1L turning to face down to partner, 1s turn RH 1.1/4
    times to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5696, '2013-08-21 08:31:11.909317+00', '2023-02-04 01:20:26.104875+00', 2952, 3, NULL, 'ace', '1-8::
    1s cast 1 place, cross RH, cast to right into centre, dance towards
    each other & turn right about to face up/down
9-16::
    2s+1s+3s set & petronella twice (in diamond formation with ''a hole
    in the wa'') to end 1L facing down, 1M facing up & 2s+3s on opp sides
17-24::
    2s+1s+3s set, dance RH across 1/2 way (1L+2s & 1M+3s), 1s turn LH
    1.1/2 times to face 2nd corner
25-32::
    1s dance reels of 3 on sides (RSh to 2nd corner) & 1s cross RH to
    2nd place (second time to 4th place)', 0);
INSERT INTO 'dancecrib' VALUES (10076, '2017-09-03 23:44:45.727918+00', '2023-02-04 01:20:26.136008+00', 2955, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round and back
9-16::
    1s+2s dance RH across & LH across
17-24::
    1s lead down (2s step up 3-4) & lead back up to end 1L between 2s
    facing 2M, 1M between 3s facing 3L
25-32::
    LSh reels of 3 across (LSh to 1st corner).  1s end in 2nd place own
    side', 0);
INSERT INTO 'dancecrib' VALUES (5698, '2013-08-21 08:31:11.929674+00', '2023-02-04 01:20:26.406338+00', 2957, 3, NULL, 'ace', '1-8::
    1s facing 2s set &1s cross RH to opposite sides, facing 2s again set
    & 1s cross back to own sides RH
9-16::
    1s cross RH & cast to 2nd place, dance 1/2 Figs of 8 round 2s
17-24::
    1s dance down below 3s & cast up 1 place, dance up between 2s & cast
    back to 2nd place
25-32::
    2s+1s dance R&L
33-40::
    1s dance reels of 3 across (Lady with 2s & Man with 3s)
41-48::
    1s dance reels of 3 across (Lady with 3s & Man with 2s)', 0);
INSERT INTO 'dancecrib' VALUES (13900, '2021-04-05 00:20:06.090697+00', '2023-02-04 01:20:26.418394+00', 19491, 3, NULL, 'ace', '1-4::
    1s & 4s cross RH, cast in (2s & 3s step up/down)
5-8::
    2L+1M+4L+3M dance 1/2 diag RSh reel of 4 on 1st corner diagonal (top
    2 Ladies'' side & bottom 2 Men''s side ) _while_ 2M+1L & 4M+3L set &
    turn 2H
9-12::
    2M+1L+4M+3L dance 1/2 diag RSh reel of 4 on other diagonal (top 2
    Men''s side, bottom 2 Ladies'' side), _while_ 3M+4L & 1M+2L set & turn
    2H
13-16::
    1s lead down below 2s (in 4th place) cross & cast up to 3rd place
    opp sides _while_ 4s lead up, cross & cast to 2nd place opp sides.
    (3) (4) (1) (2)
17-24::
    1s lead down (2 steps), lead up to top (4 steps) & cast into 2nd
    place opp sides (4s step down 19-20).  (3) (1) (4) (2)
25-32::
    All circle 8H 1/2 round to left to own side; 4s+1s circle 4H round
    to right.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5699, '2013-08-21 08:31:11.93794+00', '2023-02-04 01:20:26.431034+00', 10896, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1M+2L 3/4 turn RH & dance out own side RSh
    round 2M/1L back to places
9-16::
    1s+2s dance LH across, 1L+2M 3/4 turn LH & dance out own side LSh
    round 2L/1M back to places
17-24::
    1s+2s set, 1M+2L change places RH, 1L+2M change places LH, 2s+1s 1/2
    turn partners 2H to end facing down/up
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5700, '2013-08-21 08:31:11.957607+00', '2023-02-04 01:20:26.53357+00', 2962, 3, NULL, 'ace', '1-8::
    1L casts to bottom as 4M casts up to top to meet in centre of dance,
    1M+4L do the same _while_ 1L+4M turn 3/4 RH
9-16::
    1s+4s dance LH across in centre 1s end in 4th place as 4s end at
    top, all 4 couples turn RH
17-32::
    Repeat bars 1-16 with 4L+1M starting
33-40::
    All in prom hold dance 1/2 RSh reel of 4 in centre of set & end with
    4s/1s casting into top/bottom places as 3s & 2s cross LH to own
    sides.  4 3 2 1
41-48::
    4s+3s+2s dance 1/2 RSh reels of 3 on sides 4s (4s RSh to 3s), all
    turn RH', 0);
INSERT INTO 'dancecrib' VALUES (10077, '2017-09-03 23:44:45.902532+00', '2023-02-04 01:20:26.555246+00', 17897, 3, NULL, 'ace', '1-8::
    1s set, turn RH to face out & cast (2s step up 5-6), 1s turn RH to
    face out in 2nd place
9-16::
    Reels of 3 on sides (Man up, RSh to 2M, Lady down, RSh to 3L).  1s
    end BtoB in centre facing 1st corners
17-24::
    1s+1st corners dance Corner Pass+Turn, 1s pass RSh & dance Corner
    Pass+Turn with 2nd corners ending in 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13083, '2020-08-10 00:19:54.3215+00', '2023-02-04 01:20:26.58022+00', 20035, 3, NULL, 'ace', '1-8::
    1s set & cross down RH to 2nd place opp side; 1s set & turn RH into
    prom hold in the centre facing 2L
9-16::
    1s dance 1/2 RSh diag reel of 3 with 2L+3M, 1s finish in centre
    facing the Men''s side; 1L+2M+3M (at top) dance RH across & 1M+2L+3L
    (at bottom) dance LH across. 1s finish in prom hold facing 2M.
17-24::
    1s dance 1/2 RSh diag reel of 3 with 2M+3L and 1s finish in centre
    facing down; 1L+2L+3L (on sides) dance RH across & 1M+2M+3M dance LH
    across. 1s finish in prom hold facing down.
25-28::
    1s dance down & cast up round 3rd place to 2nd place opp sides
    _while_ 2s & 3s set facing on sidelines and change places RH
29-32::
    2s+1s+3s set and cross RH. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12145, '2019-09-02 21:56:04.926315+00', '2023-02-04 01:20:26.609229+00', 19596, 3, NULL, 'ace', '1-4::
    1s+2s dance 1/2 double Fig of 8 (1s cast, 2s cross up)
5-8::
    1s cast, dance in to centre, set pulling back RSh to end BtoB facing
    opp sides _while_ 2s cross up & set pulling back RSh to face in
9-12::
    2s+1s+3s set (as in Double Triangles) 1s PdB out & turn right about
    to face in _while_ 2s & 3s PdB in & turn right about to face out
13-16::
    2s+1s+3s set (Inverted Double Triangle formation), 1s PdB in & face
    down _while_ 2s & 3s PdB out to places
17-24::
    1s lead down (4 bars) & back up to 2nd place opp side
25-32::
    Mirror reels of 3 on sides (2s down/in, 1s up/out, 3s up/in to
    start), 1s end crossing to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (5701, '2013-08-21 08:31:12.057512+00', '2023-02-04 01:20:26.641531+00', 10061, 3, NULL, 'ace', '1-8::
    1s cast 1 place, cross down between 3s, cast up 1 place & turn RH to
    face 2L in prom hold
9-16::
    1s dance RSh reel of 3 with 2s & end facing 1st corners
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh &repeat
    with 2nd corners
25-32::
    1s dance RH across (Lady with 2s & Man with 3s) opening out into
    circle & chase clockwise back to own sides', 0);
INSERT INTO 'dancecrib' VALUES (15067, '2022-09-05 00:20:07.723067+00', '2023-02-04 01:20:26.673019+00', 14793, 3, NULL, 'ace', '1-8::
    1s set, cast to 2nd place (2s step up 3-4); 1s cross RH & cast to
    3rd place (3s step up 7-8)
9-16::
    1s & 3s dance Ladies'' Chain to finish middle couples facing ends 2 3
    (1) 4
17-24::
    All dance RSh reels of 4 on the sides
25-32::
    1s turn 4s 1.1/2 RH on the sides 2 3 4 (1); 1s set & cross RH 2 3 4
    1
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5702, '2013-08-21 08:31:12.072074+00', '2023-02-04 01:20:26.700671+00', 13429, 3, NULL, 'ace', '1-8::
    1s dance down to 4th place, all turn partners LH
9-16::
    2s+3s also 4s+1s dance LH across & back RH
17-24::
    2s+3s also 4s+1s dance double Fig of 8  (2s & 4s cross down)
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5703, '2013-08-21 08:31:12.080435+00', '2023-02-04 01:20:26.729252+00', 13579, 3, NULL, 'ace', '1-8::
    1s set & cast to meet below 4s & dance up between 4s+3s
9-16::
    1M dances LH across with 2M+3M as 1L dances RH across with 2L+3L, 1s
    dance up between 2s & cast to meet in middle & dance down b''tw''n 3s
17-24::
    1M dances RH across with 3M+4M as 1L dances LH across with 3L+4L &
    1s end 2nd place, 1s set & cast to 4th place
25-32::
    All circle 8H round & back.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (11698, '2019-03-18 21:02:17.250377+00', '2023-02-04 01:20:26.753173+00', 17918, 3, NULL, 'ace', '{{explanation}}
1s & 2s start on opposite sides

1-8::
    1s+2s also 3s+4s Set & Rotate, 1L & 4L end facing out
9-16::
    1s+4s dance LH across, finish 1M+4L (facing up/out Ladies'' side) &
    4M+1L (facing down/out Men''s side) in prom hold; All dance 1/2 LSh
    reels of 3 on the sides
17-20::
    1s+4s dance RH across, finish in prom hold with partner, 1s facing
    down/out on Ladies'' side, 4s up/out Men''s side _while_ 3s & 2s cross
    RH and set
21-24::
    All dance 1/2 RSh Reels of 3 on sides, 4s & 1s separate and face
    down/up
25-32::
    4s+1s turn 2H on sides _while_ 2s & 3s cross RH, all set on sides;
    All circle 8H left 1/2 way (3)(1) 4 2', 0);
INSERT INTO 'dancecrib' VALUES (5704, '2013-08-21 08:31:12.519592+00', '2023-02-04 01:20:27.917897+00', 2965, 3, NULL, 'ace', '1-8::
    1s+2s+3s all dance »Inveran« reels (all cross down at top & cross up
    at bottom) 3s ending on opposite sides
9-16::
    1s lead down under 2s arch & both couples cross to opposite sides,
    2s+1s+3s set & cross to own sides
17-24::
    2s+1s+3s circle 6H round & back
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5705, '2013-08-21 08:31:12.528583+00', '2023-02-04 01:20:27.946653+00', 2966, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast below 3s & dance up middle (1L followed by
    1M) to face 2L (2s step up 5-6)
9-16::
    1s dance RSh Semi-Alternating Tandem reel with 2nd corners, passing
    2L RSh (alternate once at bar 10) & end facing 2M (1M followed by
    1L)
17-24::
    1s dance LSh Semi-Alternating Tandem reel with 1st corners, passing
    2M LSh (alternate once at bar 18) & end facing up (1L followed by
    1M)
25-32::
    1s dance RH across with 2L & LH across with 2M ending 2nd place own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (5706, '2013-08-21 08:31:12.536736+00', '2023-02-04 01:20:27.967134+00', 7569, 3, NULL, 'ace', '1-8::
    1s+2s set, 1M+2L dance DoSiDo 1M ends in 2nd place & 2L in 1st place
    as 1L+2M cast, 2s+1s+3s set
9-16::
    1L+2s also 1M+3s dance RH across, 1s turn LH & cast on own sides (L
    up & M down) to end L between 2s & between 3s facing 1st corners
17-24::
    1s dance reels of 3 across giving RSh to 1st corners, 1s end side by
    side facing 2nd corners holding LH
25-32::
    1s set to 2nd corners, turn to right (BtoB with partner) & set to
    1st corners, turn to right & turn RH with partner to 2nd place own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (5707, '2013-08-21 08:31:12.544823+00', '2023-02-04 01:20:27.986363+00', 2968, 3, NULL, 'ace', '1-8::
    Each trio dance reels of 3 (Man RSh to Lady on right)
9-16::
    All Men dance RH across & LH back _while_ corner Ladies turn RH & LH
17-24::
    All set, Men petronella turn left into centre to face out between
    Partner & her corner Lady, all set, Men petronella turn into next
    Mans pl to left
25-32::
    All LH Ladies followed by RH Lady (who first casts) dance across
    (touching RH) & out opposite corner, round Man on right back into
    centre & out opposite corner, LH Lady dancing round Man on right
    (own partner) to new places All 1 place on clockwise', 0);
INSERT INTO 'dancecrib' VALUES (14897, '2022-06-27 00:18:28.667095+00', '2023-02-04 01:18:25.503277+00', 20537, 3, NULL, 'ace', '1-8::
    1s set, cross passing RSh & cast 2 places, dance up round 3s to face
    1st corners (2s step up 5-6)
9-16::
    1s dance ''Hello-Goodbye'' setting & Petronella turn to 2nd place own
    sides
17-24::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh & dance 1/2
    diag reel of 4 with 2nd corners to end in 2nd place on opp sides.
    (3) (1) (2)
25-32::
    3s+1s+2s chase clockwise 1/2 round; 1s turn partner (birl).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5708, '2013-08-21 08:31:12.554499+00', '2023-02-04 01:20:28.068102+00', 2970, 3, NULL, 'ace', '1-8::
    1L+2L+3L circle 3H round to left, 1M+2M+3M circle 3H round to left
9-16::
    1s lead down the middle & back
17-24::
    1s+2s dance Poussette.  2 1 3
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5709, '2013-08-21 08:31:12.637686+00', '2023-02-04 01:20:28.252706+00', 14678, 3, NULL, 'ace', '1-8::
    1s set & dance down below 2s, cast back to place & cross RH
9-16::
    1L+2M set to each other & dance out between 1M+2L, cast away from
    each other back to Men''s side & change places LH
17-24::
    1s cross diagonally RH & chase clockwise once round
25-32::
    1L+2L set to each other & dance out between 2M+1M, cast away from
    each other back to Ladies side & change places LH', 0);
INSERT INTO 'dancecrib' VALUES (5710, '2013-08-21 08:31:12.646077+00', '2023-02-04 01:20:28.285709+00', 9234, 3, NULL, 'ace', '1-4::
    1s set, cast 1 place, _while_ 2s step up
5-8::
    1s turn LH 1.1/2 times to face 1st corners & on bars 7/8 2L+4M
    petronella turn into centre _while_ 2M steps down & 3L+4L step up
    (to hexagon shape with 1s facing 2M & 4L)
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh & dance
    1/2 diagonal reel with 2nd corners 1s end facing end persons (2L &
    4M)
17-24::
    1s dance 1/2 reel of 4 up/down (1s end in centre Lady facing down &
    Man up), 1s set twice as 2s+3s+4s chase clockwise 1/2 way (pstns as
    at bar 8)
25-32::
    2s+3s+4s circle 6H round & back to end on sides in original places
    _while_ 1s turn RH & LH to end facing up (Lady on Mans right)
33-40::
    1s dance up to top, cast (on own sides) behind 2s, in front of 3s &
    behind 4s to 4th place (others step up on bars 39/40)', 0);
INSERT INTO 'dancecrib' VALUES (5711, '2013-08-21 08:31:12.659827+00', '2023-02-04 01:20:28.469493+00', 2972, 3, NULL, 'ace', '1-8::
    1s cast to bottom, turning outwards dance back to places
9-16::
    1s+2s dance RH across & LH back
17-24::
    1s cross RH, cast 1 place, cross LH & cast down round 3s & lead up
    to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13751, '2021-03-02 01:20:15.067226+00', '2023-02-04 01:20:28.492038+00', 13701, 3, NULL, 'ace', '{{title}}
Strathspey

1-4::
    1s dance towards each other, cast off to below 3s _while_ 4s+2s
    dance RH across & 3s set twice
5-8::
    4s+2s circle 4H round to left _while_ 3s turn 2H & 1s turn 1.1/2 2H
    (now in ''longways set''  shape, 2L+4M at top, 2M+4L in 2nd place, 3s
    in 3rd place, 1s at bottom facing up)
9-10::
    1s lead  up to top
11-12::
    1s turn 1/2 RH, _while_ 2s dance towards each other, separate, cast
    to the side of square, 4s & 3s dance similar.  All now in original
    places
13-16::
    All set to partner, all joined NH with partner & set facing in

{{title}}
Reel

17-18::
    All set advancing to form a St Andrews cross, Men form corners
    facing clockwise, Ladies in centre facing anticlockwise
19-20::
    Ladies join LH in centre & RH to corner & all set in St Andrews
    cross
21-24::
    All Men chase clockwise 1/2 round _while_ Ladies dance LH across
25-28::
    All turn partner RH 1.1/2
29-32::
    All circle 8H 1/2 round to left.  End 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (5712, '2013-08-21 08:31:12.669706+00', '2023-02-04 01:20:28.523397+00', 2973, 3, NULL, 'ace', '1-8::
    1s & 3s 3/4 turn 2H, dance 1/2 reel of 4 up/down middle & turn 2H to
    own sides
9-16::
    All dance 1/2 double Fig of 8 (couples in 2nd & 4th places start by
    crossing up) into 1/2 reflection reels of 4 on sides
17-24::
    All dance 1/2 double Fig of 8 (couples in 2nd & 4th places start by
    crossing up) into 1/2 reflection reels of 4 on sides
25-32::
    3s+2s also 1s+4s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (5713, '2013-08-21 08:31:12.677859+00', '2023-02-04 01:20:28.552413+00', 2974, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-4::
    1s cross down _while_ 4s cross up, 1M+4L also 1L+4M in prom hold
    dance out to right & into centre facing own partner
5-8::
    1s & 4s change places RH with partner & chase round inside clockwise
    to end 1s in 2nd place opposite sides & 4s in 3rd place own sides
9-12::
    2s cross down _while_ 3s cross up, 2M+3L also 2L+3M in prom hold
    dance out to left & into centre facing own partner
13-16::
    2s & 3s change places LH with partner & chase round inside
    anticlockwise to end 2s in 2nd place opp sides & 3s in 3rd place own
    sides.  (1)(2) 3 4
17-24::
    1s+2s Set+Link, 1s+3s set & dance RH across 1/2 way
25-32::
    1s+4s Set+Link, all set & cross RH.  2 3(4)(1)', 0);
INSERT INTO 'dancecrib' VALUES (13176, '2020-09-15 00:20:05.095365+00', '2023-02-04 01:20:28.658048+00', 16827, 3, NULL, 'ace', '1-8::
    1L & 4M followed by partners cast down/up (2s & 3s step up/down),
    across set to 2nd/3rd place opp sides; 1s+4s dance LH across
9-12::
    1s & 4s dance out (1M & 4L out of end, 1L & 4M out of sides) & cast
    right (round 1 person), pull back RSh to face out _while_ 2s+3s
    Adv+Ret diagonally
13-16::
    Repeat 9-16 from new places.  1s+4s end towards centre, Men face
    down, Ladies face up. 2 4 1 3
17-24::
    Alternating tandem reels of 3 on sides (4L+1L RSh to 2L, 1M+4M RSh
    to 3M to start)
25-32::
    4s+1s dance Slip Knot (as usual Knot but end by passing Lady in
    front & dancing 1/2 LH across back to same places). 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5716, '2013-08-21 08:31:12.709416+00', '2023-02-04 01:20:28.684352+00', 8931, 3, NULL, 'ace', '{{explanation}}
2 chords: 2nd chord 3s & 4s cross to opp sides

1-8::
    1s+2s also 3s+4s set facing up/down on sides & Petronella turn into
    lines of 4 across; all dance 1/2 reels of 4 across
9-16::
    1s+2s also 3s+4s set facing across & Petronella turn to other sides
    (1) (2) 3 4; all dance 1/2 reels of 4 on sides.  4 3 (2) (1)
17-24::
    4s+1s (end couples) chase clockwise 1/2 way to opposite ends; 1s &
    4s birl giving RH (elbow grip).  1 3 (2) (4)
25-32::
    All set, 1s+3s (at top) also 2s+4s (at bottom) dance 1/2 RH across;
    all set & cross RH with partner.  3 1 (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (5717, '2013-08-21 08:31:12.719099+00', '2023-02-04 01:20:28.806015+00', 2978, 3, NULL, 'ace', '1-8::
    1s set, turn RH, lead down below 2s, 1L casts up & 1M casts down on
    own sides to end 1L between 2s & 1M between 3s
9-16::
    1s dance reels of 3 across (giving RSh to 1st corner) & end facing
    1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners & 1s end between
    2s+3s on opposite sides
25-32::
    2s+1s+3s Adv+Ret, 1s cross back to places', 0);
INSERT INTO 'dancecrib' VALUES (5718, '2013-08-21 08:31:12.914062+00', '2023-02-04 01:20:28.839333+00', 11538, 3, NULL, 'ace', '1-8::
    All clap as 1s & 4s cross passing RSh & cast in, 1s+4s dance RH
    across
9-16::
    All clap as 1s & 4s cross passing RSh & cast back to original
    places, 1s+2s also 3s+4s dance LH across.  1 2 3 4
17-20::
    1M+3L also 2M+4L change places RH & 1L+3M also 2L+4M change places
    RH
21-24::
    1M+3L also 2M+4L change places RH & 1L+4M change places LH _while_
    others dance anticlockwise to next vacant place (ignoring 2L & 3M
    pls)
25-32::
    3s+1s also 4s+2s dance R&L.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (5719, '2013-08-21 08:31:12.926503+00', '2023-02-04 01:20:28.916611+00', 2979, 3, NULL, 'ace', '1-8::
    All clap & 1s cross passing RSh, cast to 2nd place & dance RH across
    with 3s
9-16::
    All clap & 1s cross passing RSh, cast to 1st place & dance LH across
    with 2s
17-24::
    1M+3L change places RH & 1L+3M change places RH (as 1M+3L loop
    round), 1M+3L change places RH (as 1L+3M loop round) & 1L+3M cross
    LH 1L ending in 2nd place (as 1M casts to 2nd pl), 2s step up on
    bars 23 - 24
25-32::
    2s+1s dance R&L.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5720, '2013-08-21 08:31:12.934593+00', '2023-02-04 01:20:28.949592+00', 7420, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across back to places but 1L faces out & casts 2
    places followed by partner, 1L crossing to 3rd place opposite side
9-16::
    All dance Grand Chain
17-24::
    1s set, turn 2H 1/2 way & dance up to top & cast to 3rd place own
    sides
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9920, '2017-06-05 11:31:13.481503+00', '2023-02-04 01:20:28.973204+00', 16491, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, Adv+Ret, set
9-16::
    1s cast (2s step up), dance down between 3s, cast up to 2nd place
    own sides.  All set
17-24::
    1s+3s dance double Fig 8 (1s cross down, 3s dance up)
25-32::
    2s+1s+3s dance mirror reels of 3 on sides (1s in/up to start). End
    with 2s+3s curving into place
33-40::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (5721, '2013-08-21 08:31:12.942656+00', '2023-02-04 01:20:28.999133+00', 2983, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s turn RH, cast (2s step up 11-12) & 1/2 turn 2H (PdeB), pull back
    RSh to end BtoB facing opposite sides
17-24::
    1s dance RSh reels of 3 across (Lady with 2s & Man with 3s), 1s pass
    LSh to face 2nd corners on sides
25-32::
    1s dance LSh reels of 3 on sides ending with 1s BtoB facing opposite
    sides
33-36::
    1s set (as Double Triangles) & dance round each other (PdeB) to end
    1M facing up & 1L facing down _while_ 2s+3s continue setting, ending
    facing down/up
37-40::
    Repeat bars 33-36, 1s end in 2nd place own side _while_ 2s+3s
    continue setting, ending facing partners', 0);
INSERT INTO 'dancecrib' VALUES (5722, '2013-08-21 08:31:12.950642+00', '2023-02-04 01:20:29.016284+00', 2984, 3, NULL, 'ace', '1-8::
    1s lead down below 3s & cast up round 3s, lead up to top & cast to
    2nd place
9-16::
    1s dance RH across (Lady with 2s & Man with 3s), pass RSh & dance LH
    across with other couple
17-24::
    2s+1s dance 1/2 R&L, 1s+2s turn RH
25-32::
    1s+2s circle 4H round 1/2 way, 2s+1s+3s circle 6H round to left', 0);
INSERT INTO 'dancecrib' VALUES (5723, '2013-08-21 08:31:12.960006+00', '2023-02-04 01:20:29.033906+00', 14686, 3, NULL, 'ace', '1-8::
    1s lead down the middle, back to top & cast to 2nd place
9-16::
    1s dance 1/2 reels of 3 across (1L with 2s & 1M with 3s) giving LSh
    to 1st crnr (pstn), 1s dance LH across with same cpls & end 2nd pl
    opp side
17-24::
    1s dance down between 3s & cast back to 2nd place _while_ 3s set &
    cross RH, 1s cross up & cast to 2nd pl own side _while_ 2s set &
    cross RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12393, '2019-12-05 01:30:19.451903+00', '2023-02-04 01:20:29.052101+00', 19421, 3, NULL, 'ace', '1-4::
    2s pass LSh to dance 1/2 diag RSh reel of 4 with 1M+3L (1st corner
    pstns), 2s end in middle (2L at top, 2M in 3rd place)
5-8::
    2s pass LSh to dance 1/2 diag RSh reel of 4 with 2nd corner pstns,
    2s end in 2nd place opp sides  (3) (2) (1)
9-16::
    All set, all triple petronella into lines across, set & triple
    petronella back to original places
17-24::
    1s+2L & 2M+3s circle 3H once round to left opening out to circle 6H
    1/2 round to left, ending (3) (2) (1)
25-32::
    All turn partners 2H 1.1/2 times; 2s followed by 1s dance up & cast
    round 3s to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5724, '2013-08-21 08:31:12.968454+00', '2023-02-04 01:20:29.072814+00', 7274, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s+3s dance 1/2 R&L
9-16::
    2s set & cast 1 place, 2s+1s dance 1/2 R&L
17-24::
    1s cross RH cast round 1st corners (pstn) into lines of 3 across (1L
    between 3s at top & 1M between 2s), all Adv+Ret (up/down)
25-28::
    1s change places RH & cast round 2nd corners (pstn) to 2nd place
    opposite sides _while_ 3s+2s set facing diagonally & dance 1/2 RH
    across
29-32::
    All set & 1s cross RH', 0);
INSERT INTO 'dancecrib' VALUES (5725, '2013-08-21 08:31:12.976797+00', '2023-02-04 01:20:29.098889+00', 7576, 3, NULL, 'ace', '1-8::
    All set, 1s & 4s cross RH & cast in 1 place, 1L+4L also 1M+4M turn
    LH on sides
9-16::
    All dance RSh reels of 4 on sides, 1L+4L & 1M+4M end by turning LH
    to join with corners RH
17-24::
    All Bal-in-Line on sides, 1s & 4s 1/2 turn corners RH & Bal-in-Line
    again, 1s & 4s 1/2 turn corners RH
25-26::
    1s+4s dance LH across 1/2 way as 2s & 3s set
27-36::
    All dance intersecting diagonal reels of 4 giving RSh in corner & LH
    in centre
37-40::
    1s+4s circle 4H round to left, end with 4s (facing up to 1s) making
    an arch
41-48::
    4s dance up & turn corners RH as 1s dance down to turn corners RH
    onto side lines, 4s & 1s dance 1/2 Figs of 8 to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13618, '2021-02-04 01:20:07.430854+00', '2023-02-04 01:20:29.130146+00', 15244, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s turn 3/4 LH to face 1st corners
9-16::
    1s set to 1st corners & change places with corners RH (corners end
    BtoB facing 1s); 1s+1st corners dance 1/2 diag reel of 4. Corners
    pass RSh to face 2nd corners (3L facing 2L, 2M facing 3M)
17-20::
    _1/2_ diag reel of 4. 1st corners pass LSH to face 1s again (in 3rd
    corner pstns, 3L facing 1M, 2M facing 1L)
21-24::
    1st corners set to 1s & change places RH
25-32::
    1s turn 3/4 LH to 2nd place opp side;  3s+1s+2s set & cross RH with
    partner.  End 3 1 2

{{explanation}}
Note:	If preferred, LH turns Bars 5-8 & 25-28 can be 1.3/4 turn.  May also be dance as R8x32 (4C set)', 0);
INSERT INTO 'dancecrib' VALUES (13526, '2021-01-09 01:20:05.889045+00', '2023-02-04 01:20:29.282916+00', 17698, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All set, Adv+Ret (1 step), turn 2H & circle 8H round for 2 bars
9-16::
    All set to corners & dance La Baratte to form new couples
::
    Men 1/2 turn corner RH & retain hand but at arm''s length from each
    other, Men retrace steps with corner turning right under his arm
    briefly into Allemande hold (Men behind corner facing Men''s original
    place) & releasing corner''s RH she turns under Man''s left arm & all
    change places LH to opposite places`
17-24::
    Couples in 1st & 3rd positions dance a variation of the Swirl:
::
    Turn partner RH into Allemande hold & dance LSh round other couple
    1/4 way, on bar 20 release right hands & dance LH across & swirl to
    face side couples to form 2 lines of 4: 3L faces 4M & 3M faces 4L
    _while_ 1L faces 2M & 1M faces 2L`
25-32::
    All dance reels of 4. On bars 31-32 1s+3s loop into square set
    formation (Ladies on partner''s right)
33-48::
    New couples in 2nd & 4th positions repeat bars 17-32 3 4 1 2

{{title}}
Reel

49-64::
    All dance full Schiehallion Reel
65-80::
    All dance Grand Chain (2 bars per hand)
81-88::
    All turn partner RH, turn corner LH to finish passing partner RSh
89-92::
    All Men dance LH across _while_ all Ladies chase clockwise 1/2 way
    round (Ladies pass Men LSh)
93-96::
    All Ladies dance RH across _while_ all Men chase anticlockwise 1/2
    way round to meet own partner', 0);
INSERT INTO 'dancecrib' VALUES (5727, '2013-08-21 08:31:13.038522+00', '2023-02-04 01:20:29.313335+00', 9163, 3, NULL, 'ace', '1-8::
    1s set, cast 2 places, cross up through 3s & dance up behind 2s to
    partner''s place
9-16::
    1s dance Fig of 8 round 2s _while_ 2s set, cross RH, set & cross
    back
17-24::
    1s+2s Set+Link, 2s+1s+3s Set+Link for 3 once to end in lines of 3
    across set
25-32::
    2s+1s+3s set twice, cast as in Set+Link for 3, 1s meet in prom hold
    _while_ 2s & 3s 1/2 turn RH into prom hold - all facing up
33-40::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5728, '2013-08-21 08:31:13.047024+00', '2023-02-04 01:20:29.34039+00', 2990, 3, NULL, 'ace', '1-8::
    1s+2s set & circle left 1.1/2 times round. (2) (1) 3
9-16::
    2s+1s set & cross RH to own sides, 1s set & turn RH to face 1st
    corners (1s may set 9-10 then turn by right arm - elbow grip - to
    face 1st corners)
17-24::
    1s turn 1st corners LH, partner RH, 2nd corner LH & partner RH
25-32::
    2s+1s+3s dance "reels of 3 on sides with crossing":
::
    1s continue turn moving down, cross out through 3rd place opp sides,
    cast up to 2nd place & cross up RH to 1st place own side & cast to
    2nd place _while_
::
    3s dance out/up to 2nd place, cross up RH to 1st place opp sides,
    cast to 2nd place & cross down RH to original places _while_
::
    2s dance out/down to 2nd place (3s pass in front), cross down RH to
    3rd place opposite sides, cast up to 2nd place (3s pass in front) &
    cross up to 1st place own sides.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15068, '2022-09-05 00:20:10.102234+00', '2023-02-04 01:20:29.37419+00', 2991, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp side

1-8::
    All set,  1s & 4s cast in 1 place (2s & 3s step up/down); 1s & 4s
    cross RH & cast up/down into lines across (1s between 2s, 4s between
    3s)
9-16::
    All Adv+Ret up/down set; 1s+4s dance 1/2 R&L (4s now between 2s, 1s
    between 3s, Man facing Lady)
17-24::
    4s+2s also 1s+3s dance reels of 4 across.  At end 4s & 1s start
    turning partner LH
25-32::
    4s & 1s continue turning LH moving up/down (4s to top on opp sides
    facing out, 1s to 4th place own sides facing out); 4s & 1s cast to
    2nd/3rd place & dance 1/2 Fig 8 up/down round 2s/3s.  End 2 4 (1)
    (3)', 0);
INSERT INTO 'dancecrib' VALUES (5729, '2013-08-21 08:31:13.057121+00', '2023-02-04 01:20:29.401374+00', 2992, 3, NULL, 'ace', '1-8::
    1s cross RH & cast down 1 place, 1s dance 1/2 RSh reels of 3 across
    (1L with 2s & 1M with 3s)
9-16::
    1s cross RH & cast right (1M down 1L up), 1s dance into centre &
    turn about to BtoB with partner & set _while_ 2s+3s set & dance in,
    retire & set
17-24::
    1s dance RH across (1L with 2s & 1M with 3s) 1s ending 2nd place own
    sides, 1s dance 1/2 reel of 3 across (1M with 2s & 1L with 3s)
25-32::
    1s cross RH & 2s+1s+3s set, all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (12147, '2019-09-02 22:09:10.337559+00', '2023-02-04 01:20:29.56053+00', 19607, 3, NULL, 'ace', '1-8::
    2s+3s dance 1/2 R&L, 3s+2s dance RH across _while_ 1s & 4s chase
    clockwise 1/2 way.  (4)(3)(2)(1)
9-12::
    4M followed by prtnr casts 1 place & crosses to face 3M (3s step up)
    _while_ 1L followed by prtnr casts & crosses to face 2M (2s step
    down)
13-16::
    4s+1s dance Alternating Tandem 1/2 reel of 4 with 1st corners
17-24::
    Repeat Alternating Tandem 1/2 reels with next 2nd & 3rd corners
25-32::
    Repeat with 4th corner ending with 4s in 2nd place & 1s in 3rd
    place, 4s+1s spin turn _while_ 3s+2s chase clockwise 1/2 way.  2 4 1
    3
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5730, '2013-08-21 08:31:13.087319+00', '2023-02-04 01:20:29.623625+00', 2999, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, dance 1/2 Fig of 8 round 2s & end in 2nd
    place opposite sides facing down
9-16::
    1s turn 3s (with nearer hand -1s dancing in) into 1/2 Fig of 8 round
    3s & end facing 1st corners
17-24::
    1s dance Hello-Goodbye setting ending BtoB (Man facing up)
25-32::
    1s dance reels of 3 across (Man with 2s & Lady with 3s) giving RSh
    to 2nd corner', 0);
INSERT INTO 'dancecrib' VALUES (9736, '2017-04-06 08:39:51.620938+00', '2023-02-04 01:20:29.690367+00', 13871, 3, NULL, 'ace', '1-8::
    1s+3s dance double Fig 8 round 2s (1s cross down, 3s cast up to
    start)
9-16::
    2L+1s & 2M+3s dance RH across. 2s pass RSh to dance LH across with
    other couple
17-24::
    1s+2s set facing on sides, 1s cross down as 2s dance up.  1s+3s set
    facing on sides, 1s cross down as 3s dance up
25-32::
    2s+3s+1s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (9006, '2015-11-30 08:59:52.649466+00', '2023-02-04 01:20:29.71484+00', 10906, 3, NULL, 'ace', '1-8::
    All join hands on side, set twice & turn partner RH 1.1/2 times to
    finish on opp sides
9-16::
    Repeat bars 1-8 back to places
17-24::
    1s+2s also 3s+4s dance RH across, LH across
25-32::
    1L, followed by 1M, casts, crosses below 4s into 4M place (2s+3s+4s
    step up bars 27-28). 1s turn 1.1/2 times to own side in 4th place', 0);
INSERT INTO 'dancecrib' VALUES (11450, '2019-01-01 01:57:00.75519+00', '2023-02-04 01:20:29.74504+00', 18949, 3, NULL, 'ace', '1-8::
    1s cross down RH & cast down behind 3s, lead up to top cross & cast
    to 2nd place own sides
9-12::
    1M+2L also 1L+3M turn LH 1.1/2 times to change places _while_ 2M &
    3L chase anticlockwise to each others place
13-16::
    3L+3M also 2L+2M turn RH 1.1/2 times to change places _while_ 1M &
    1L chase anticlockwise to each others place
17-24::
    1s set & cast to 2nd places, 1s dance 1/2 reels of 3 on sides giving
    LSh to 3rd corner (pstn)
25-32::
    2s+1s+3s circle left & back', 0);
INSERT INTO 'dancecrib' VALUES (11195, '2018-09-30 22:19:54.91248+00', '2023-02-04 01:20:29.775481+00', 18669, 3, NULL, 'ace', '1-8::
    1s & 3s lead down (2s & 4s step up on 3 & 4) and lead back up,
    finish in promenade hold, 1s facing 2L, 3s facing 4L
9-16::
    1s & 3s dance RSh reels of 3 across, dropping RH at end and turn 1/4
    LH to face 1st corners
17-24::
    1s & 3s turn 1st corner RH, pass RSh, turn 2nd corner RH, pass RSh
    to finish in 2nd/4th places own sides
25-32::
    1s & 3s set, cast 1 place (4s & 5s step up).  All 5 couples turn RH
    (birl)   2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (10337, '2017-12-22 15:44:29.743205+00', '2023-02-04 01:20:29.809324+00', 16903, 3, NULL, 'ace', '{{explanation}}
Square set - 5s in centre facing 1s

1-8::
    1s+5s+3s dance parallel RSh reels of 3 up/down set (1s+5s pass RSh
    to start)
9-16::
    5s dance up between 1s, divide & cast round 1s to meet in centre &
    turn 1.1/4 RH (or birl) to face 2s
17-24::
    2s+5s+4s dance parallel RSh reels across (2s+5s pass RSh to start)
25-32::
    5s dance out between 2s, divide & cast round 2s to meet in centre &
    turn 1.3/4 RH (or birl) to face 1s
33-40::
    5s+1s dance 1/2 RH across, 1s+4s repeat, 4s+3s repeat, 3s+2s repeat.
    2s now in centre facing new 1s ready to repeat', 0);
INSERT INTO 'dancecrib' VALUES (10078, '2017-09-03 23:44:46.997026+00', '2023-02-04 01:20:29.832725+00', 16198, 3, NULL, 'ace', '{{explanation}}
Round the Room, 2 facing 2

1-8::
    All Adv+Ret, pass opp person RSh & chase 1 place clockwise (now
    facing partner)
9-16::
    All Adv+Ret, pass partner LSh & chase 1 place anticlockwise (now
    back with partner on »opposite« side)
17-24::
    All dance LH across & RH across
25-32::
    All circle 4H round to Left & back but bar 32 Man dances in front of
    partner & Lady turns under his Right arm to finish facing new couple', 0);
INSERT INTO 'dancecrib' VALUES (5731, '2013-08-21 08:31:13.242281+00', '2023-02-04 01:20:29.854587+00', 13768, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 Figs of 8 (1M with 2s, 1L
    with 3s)
9-12::
    1s turn LH to face 3rd corners (pstn) _while_ corners dance 1 place
    clockwise, 1s turn 3rd corners RH _while_ 2nd corners (pstn) set
13-16::
    1s turn LH to face 2nd corner (pstns) _while_ corners dance 1 place
    cl''wise, 1s turn 2nd crnrs RH to end 2nd pl opp sides _while_ 1st
    corners set
17-24::
    1s dance 1/2 LSh reels of 3 on sides (1L up, 1M down), 1s dance 1/2
    reels of 3 across (1L with 2s, 1M with 3s) ending 2nd place own
    sides
25-32::
    All dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12857, '2020-06-03 16:25:02.206497+00', '2023-02-04 01:18:32.598844+00', 251, 3, NULL, 'ace', '1-8::
    1L+4M set, cast in 1 place (2L & 3M step up/down), top 2 couples
    also bottom 2 couples dance 1/2 R&L (1L+2M, 1M+2L, 4M+3L, 3M+4L
    cross RH). All finish on opposite sides
9-16::
    1L+4M set, cast in 1 place (2L & 3M step up/down). All turn partners
    RH (2) (1) (4) (3)
17-24::
    2s+1s also 4s+3s circle 4H round & back
25-32::
    All set & cross RH to own sides to finish 1s facing down & 4s facing
    up, 1s+4s set on sides & change places LH with a polite turn. 2 4 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (8840, '2015-08-13 20:33:43.400147+00', '2023-02-04 01:20:29.907188+00', 3006, 3, NULL, 'ace', '1-8::
    1s turn RH, cast, dance down between 3s & cast up into 2nd place own
    side
9-16::
    1s dance 1/2 Diag R&L with 1st corners,  1/2 Diag R&L with 4th
    corners. Finish 1M facing 3L, 1L facing 2M on sidelines
17-24::
    1M+3L+2L also 1L+2M+3M dance RSh reel of 3 on sides (6 bars) & 1s
    turn 3/4 RH into 2nd place opp sides
25-28::
    3s+1s+2s cross RH with partner & chase clockwise into lines across
    (1M between 3L+2L facing up, 1L between 3M+2M facing down)
29-32::
    All cross RH up/down with partner & chase clockwise to own sides  2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (12727, '2020-04-11 10:51:40.568154+00', '2023-02-04 01:20:29.927692+00', 10352, 3, NULL, 'ace', '1-8::
    1s set & cross down RH  into 2nd place opp side (2s step up 3-4);
    2s+1s+3s set & cross RH. 1s face out
9-16::
    _1/2_ reels of 3 sides (1s RSh to 3rd corner), 1s turn LH to join
    1/2 reel on other side (1s LSh to 2nd corner). 1s finish BtoB in
    middle in 2nd pstn facing opp sides
17-20::
    All set. 1s dance out to 2nd place opp side & face in _while_ 2s+3s
    1/2 turn 2H staying in middle facing prtnrs
21-24::
    All set. 1s cross RH to own sides _while_ 2s+3s pull back RSh and
    dance out to own sides. 2 1 3
25-32::
    2s+1s+3s circle 6H round and back. End 2 1 3

{{explanation}}
Repeat from 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (5732, '2013-08-21 08:31:13.251225+00', '2023-02-04 01:20:29.955582+00', 3009, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place (2s & 3s step up/down) & 1s+4s
    dance LH across to face corner (person they cast round)
9-16::
    "Double turn Corner, Partner, Corner, Partner":
::
    _9-10_     1s+4s turn corner RH,
::
    _11-12_   1s+4s dance LH across 1/2 way to face diagonally opposite
    corners,
::
    _13-14_   1s+4s turn corner RH,
::
    _15-16_   1s+4s dance LH across 1/2 way to face original corner
17-24::
    All dance RSh reels of 4 on sides
25-32::
    All join hands on sides & set (HS); 1s+4s dance 1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (11196, '2018-09-30 22:19:54.970375+00', '2023-02-04 01:20:30.044453+00', 17537, 3, NULL, 'ace', '1-8::
    1s set, cast 2 places, dance up between 3s, divide & dance out & up
    behind 2s to original place
9-16::
    "Reel/Jig Poussette like figure":
::
    _9-10_   1s+2s turn 3/4 2H to line up/down middle (Ladies face down,
    Men up)
::
    _11_      1s set out to Men''s side, pull back RSh on hop to 1/4
    turn, 2s set out to Ladies'' side & 1/4 turn
::
    _12_      1s set moving down & pull back RSh on hop to 1/4 turn, 2s
    set moving up & 1/4 turn
::
    _13-14_ 1s+2s set moving towards centre & turn 3/4 2H, finishing in
    middle retaining hands
::
    _15-16_ 1s+2s retire to sides
17-20::
    1s cross RH, cast round 1st corners to end 1M facing 3M at bottom,
    1L facing 2L at top _while_ 1st corners stand (2 bars) then change
    places RH
21-24::
    _1/2_ LSh reels of 3 across (1M with couple in 3rd place, 1L with
    couple in top place)
25-28::
    1s cross up/down LH, cast round 3rd corner position to finish 1M
    facing down, 1L facing up on own sides _while_ 3rd corner (pstn)
    dancers stand (2 bars) then change places LH
29-32::
    _1/2_ RSh reels of 3 on own sides (1M down, 1L up). 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5734, '2013-08-21 08:31:13.337877+00', '2023-02-04 01:20:30.069264+00', 11481, 3, NULL, 'ace', '1-4::
    1s cross RH & cast to 2nd places
5-16::
    2s+1s+3s dance 3 couple R&L  2(1)3
17-24::
    1s dance reel of 3 on sides, (1L RSh to 3M, 1M RSh to 2L)
25-32::
    All set & 1s cross down to 3rd place _while_ 3s dance up to 2nd
    place. All turn partners RH  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5735, '2013-08-21 08:31:13.346951+00', '2023-02-04 01:20:30.115948+00', 7745, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s & 3s cast, dance down behind own side, turn out & dance back to
    places
9-16::
    All dance reflection reels of 4 on sides (1s & 3s in & down to
    start)
17-24::
    1s also 3s dance 1/2 Fig of 8 round couples below them & all turn
    partners RH
25-32::
    1s+2s also 3s+4s dance RH across, 1M & 4M (others in wheel follow)
    chase clockwise 1/2 way to form square set with 4s at top & 1s at
    bottom

{{title}}
Reel

1-8::
    All circle 8H round & back
9-16::
    All turn partner RH 1.1/2 times, dance 1/2 reel of 4 (pass partner
    RSh & 2 others & turn about to face person just passed)
17-24::
    All turn person just passed RH 1.1/2 times, dance 1/2 RSh reel of 4
    (end by passing partner to face original corners)
25-32::
    Turn corner RH, partner LH, corner RH & partner LH', 0);
INSERT INTO 'dancecrib' VALUES (5736, '2013-08-21 08:31:13.355923+00', '2023-02-04 01:20:30.147823+00', 3021, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    2s+3s set & dance »La Baratte« with partners :
::
    Men 1/2 turn opposite Lady RH & retains hand but at arms length from
    each other, Men retrace steps with Lady turning right under Man''s
    arm briefly `into Allemande hold (Man behind Lady facing Ladies
    original place) & releasing Ladies RH she turns under Man''s left arm
    until almost in original `places & couples change place LH to
    opposite positions to end facing out in prom hold Men with person on
    right (not with partner)
9-16::
    2M+3L (prom hold) dance LSh reel of 3 on Ladies side _while_ their
    partners dance (prom hold) LSh reel of 3 on Men''s side, meet in
    middle, change partners & continue reel (prom hold) with own partner
    (2s on Ladies side & 3s on Mens)
17-24::
    3s+2s dance RH across, 3s lead up crossing & cast 1 place as 2s lead
    down crossing & cast 1 place.  1 3 2 4
25-32::
    1s+3s also 2s+4s Set+Link & all chase 1/2 way to end 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (14118, '2021-07-07 00:19:46.663226+00', '2023-02-04 01:20:30.169474+00', 3025, 3, NULL, 'ace', '1-8::
    1L followed by 1M & 4M followed by 4L chase clockwise round set back
    to place _while_ 2s+3s circle 4H round & back
9-12::
    4M cast up to top (1M+2M+3M step down 9-10) _while_ 1L casts to 4th
    place (2L+3L+4L step up 9-10)
13-16::
    4M+2L & 3M+1L (end couples) set & turn 2H
17-20::
    2L (at top) & 3M (at bottom) repeat 9-12.  3 4 1 2
21-24::
    3s & 1s set & turn partner RH
25-28::
    3s lead down to 4th place _while_ 4s+1s+2s clap 3 times (2 bars) &
    step up 27-28
29-32::
    3s turn (Right Elbow grip) _while_ 4s+1s+2s Adv+Ret.  End 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (5737, '2013-08-21 08:31:13.364963+00', '2023-02-04 01:20:30.189172+00', 10516, 3, NULL, 'ace', '1-8::
    1s (Lady on left) & 4s (Lady on right) in prom hold dance reel of 3
    across with 2s/3s (RSh to 2M/3L) 1s & 4s end passing LSh to…
9-16::
    1s & 4s dance reels of 3 with other couples ending with 1s+4s
    passing LSh to face out between 2s+3s (1s on Men''s side & 4s on
    Ladies side)
17-24::
    1s & 4s divide & cast into full Figs of 8 across (Men round 2nd
    places, Ladies round 3rd places with Ladies'' side dancers crossing
    down/up first) _while_ 2s+3s dance R&L ending 1M+4M between 2s
    facing down & 1L+4L between 3s facing up
25-32::
    All set twice, 1s+4s chase clockwise 3/4 way to own sides & end 2 1
    4 3', 0);
INSERT INTO 'dancecrib' VALUES (8593, '2015-02-13 12:47:51.745063+00', '2023-02-04 01:20:29.656246+00', 15699, 3, NULL, 'ace', '1-8::
    1s cross RH & cast to 2nd place, 2s+1s Set+Link
9-16::
    1s dance RSh reels of 3 on opposite sides
17-24::
    1M followed by partner cast to 2nd place & crosses to own sides to
    dance LH across with 3s
25-32::
    1s dance reels of 3 on own sides (RSh to 2s to start)
33-40::
    1s set & 1L followed by partner casts to 3rd place & crosses to
    opposite sides, 1L casts up to 2nd place as 1M dances up to 2nd
    place opposite sides
41-64::
    1s repeat bars 9-32 with 3s+4s', 0);
INSERT INTO 'dancecrib' VALUES (5739, '2013-08-21 08:31:13.461079+00', '2023-02-04 01:20:30.406038+00', 3031, 3, NULL, 'ace', '1-8::
    1s+2s set, circle 4H round to the left & set
9-16::
    1s+2s dance the Rondel
17-24::
    1s dance reflection reels of 3 on sides (1s start by dancing out
    round 3s) to end with 2s facing down 3s facing up the set
25-32::
    2s+1s+3s set (in circle), circle 6H round to the left, dance in,
    turn singly to right & chase clockwise to places', 0);
INSERT INTO 'dancecrib' VALUES (8699, '2015-03-03 08:47:41.607321+00', '2023-02-04 01:20:30.454079+00', 16070, 3, NULL, 'ace', '1-8::
    All dance Grand Chain 1/2 way, set to & turn partners 2H
9-16::
    1s+3s dance RH across, 1s+3s, with Men, leading chase clockwise back
    to places
17-24::
    2s+4s repeat bars 9-16
25-32::
    All dance interlocking reels (Ladies leading) of 4 across giving LH
    in middle, Men end BtoB in centre facing opposite partner
33-40::
    All set & turn 3/4 RH into prom hold & all promenade anticlockwise
    1/2 way (Men end in original places beside opp partner)
41-48::
    All dance interlocking reels (Ladies leading) of 4 across giving LH
    in middle, Men end BtoB in centre facing own partner
49-56::
    All set & turn 3/4 RH into prom hold, & all promenade anticlockwise
    1/2 way to original places
57-64::
    All circle 8H round & back

{{explanation}}
Repeat 1-64 in reel time  
Note:   Interlocking reels start with Ladies dancing 1/2 LH across while Men set (2 bars). Then Men dance 1/2 LH across while Ladies continue reel', 0);
INSERT INTO 'dancecrib' VALUES (5741, '2013-08-21 08:31:13.509848+00', '2023-02-04 01:20:30.484334+00', 9930, 3, NULL, 'ace', '1-8::
    1s & 4s turn RH, cast in 1 place & turn partner LH 1.1/2 to end in
    lines of 4 across (1s between 2s & 4s between 3s)
9-16::
    All dance reels of 4 across ending with 1s & 4s passing partners RH
    & all facing down/up to other line of 4
17-24::
    All set & change place RH with opposite person, 2s & 3s set _while_
    4s & 1s cast in to 2nd/3rd place on opp side, all cross LH with ptnr
25-32::
    All chase anticlockwise 1/2 way, 1s+4s dance 1/2 LH across & all
    set.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9369, '2016-10-06 07:18:32.5696+00', '2023-02-04 01:20:30.664677+00', 17223, 3, NULL, 'ace', '1-8::
    1s+2s dance DoSiDo with partners,1s+2s dance RH across
9-16::
    1s+2s dance 1/2 double Fig. 8 (1s cast to start, 2s cross up); all
    dance DoSiDo on the sides
17-24::
    All petronella into center in succession (2 bars each): 1M then 1L,
    2M, 2L
25-32::
    1s+2s dance 1/2 reel of four; turn partner RH 1.1/4 to own sides', 0);
INSERT INTO 'dancecrib' VALUES (14423, '2021-11-06 01:11:34.966636+00', '2023-02-04 01:20:30.726742+00', 3036, 3, NULL, 'ace', '1-8::
    3s followed by 2s & 1s slip step 2H joined down centre, 1s+2s+3s
    slip step back up & out to original places
9-12::
    1s+2s set, 1s cross down to 2nd place opp sides facing out _while_
    2s cast up to 1st place own side
13-16::
    1s turn 3s (1L+3M LH, 1M+3L RH) to end 1M+3L also 1L+3M in prom hold
    facing out
17-24::
    Reels of 3 on sides (2s in/down, 1L+3M also 1M+3L out/up, 4s in/up).
    1s leave 3s in 3rd place facing in & 1s finish in 2nd place opp
    sides facing out
25-28::
    1s 1/2 turn 2s (1M+2L LH, 1L+2M RH), 1s cross down (1L in front of
    1M) to just above 3s _while_ 2s dance out/up to 1st place own side
29-32::
    1L+3L+4L dance LH across  _while_ 1M+3M+4M dance RH across, 3s
    dancing up to end in 2nd place, 4s in 3rd place, 1s in 4th place. 2
    3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14207, '2021-08-14 00:20:12.336512+00', '2023-02-04 01:20:30.749158+00', 12276, 3, NULL, 'ace', '1-4::
    1s dance 1/2 Fig of 8 round 2s.
5-8::
    1s & 2s turn 1.1/2 RH to finish in centre, 1s facing up, 2s facing
    down
9-16::
    1s & 2s dance mirror Allemande (1s dance normal Allemande, 2s dance
    an inverted Allemande) (2) 1
17-24::
    2s+1s dance Ladies'' Chain with Men crossing RH to start (2) 1
25-32::
    2s dance 1/2 Fig of 8 round 1s. 2s & 1s turn 2H.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (5742, '2013-08-21 08:31:13.518476+00', '2023-02-04 01:20:30.782551+00', 9635, 3, NULL, 'ace', '1-8::
    1s & 3s cross down to dance reflection reels of 4 on sides
9-16::
    1s & 3s (crossing down to start) dance 1/2 Fig of 8 round 2s/4s, 2s
    & 4s (crossing up to start) dance 1/2 Fig of 8 round 1s/3s
17-24::
    1s & 3s set to partners, cross RH, 1M+3L change places LH & 1L+3M
    change RH
25-32::
    3s+2s also 1s+4s set & dance RH across 1/2 way, 3s & 1s turn 2H
    1.1/2 times to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (15229, '2022-11-03 01:20:09.553223+00', '2023-02-04 01:20:30.804252+00', 21150, 3, NULL, 'ace', '{{explanation}}
2 chords: 2nd chord 3L & 4M change places to be beside partner

1-8::
    1s cross RH & cast (2s step up); 1s dance down between 3M+4M (who
    step up), cast behind 3L+4L (who step up) to 4th place opp side
    _while_ 2s cross RH & cast to 2nd place as 3M+4M step up.  [Men''s
    side: 3M,2L,3L,1L; Ladies'' side: 4M,2M,4L,1M]
9-16::
    1s followed by 2s dance down (3L+4L step up 11-12); 2s followed by
    1s dance up to 3rd/4th place
17-20::
    3s+4s also 2s+1s circle 4H 1/2 round to left (2 bars), turn partner
    2H [Men''s side: 4L,4M,1M,2M; Ladies'' side: 3L,3M,1L,2L]
21-24::
    3s+4s also 2s+1s circle 4H 3/4 round to right, retain hands with
    neighbour & face partner, 4s+3s at top, 1s+2s Men facing down Ladies
    facing up
25-28::
    4s cross passing RSh, cast & face up NHJ _while_
::
    3s Adv+Ret (1 bar each), cross up passing LSh & face down NHJ
    _while_
::
    1s+2s Adv+Ret up/down (1 bar each) & 1/2 turn partner 2H, retain NH
    facing in
29-32::
    3s+4s Set+Link across back to own sides _while_ 1s+2s Set+Link on
    sides [Men''s side: 3M,4M,2M,2L; Ladies'' side: 3L,4L,1M,1L]', 0);
INSERT INTO 'dancecrib' VALUES (5743, '2013-08-21 08:31:13.531716+00', '2023-02-04 01:20:30.854631+00', 8932, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back
9-16::
    1s+2s dance Poussette with 1s ending BtoB ready for double triangles
17-24::
    All dance Double Triangles & 1s end facing out on own sides
25-32::
    1s cast to right & dance Figs of 8 across _while_ 2s+3s dance reels
    of 3 on sides (1s interacting with 2s+3s in reel)', 0);
INSERT INTO 'dancecrib' VALUES (13527, '2021-01-09 01:20:06.951908+00', '2023-02-04 01:20:30.883704+00', 3037, 3, NULL, 'ace', '1-8::
    1s cast (2s step up) & dance 1/2 Fig 8 up round 2s, 1s dance LSh
    round each other to face 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting. 1s finish BtoB facing 2nd corners
17-24::
    1s dance 1/2 RSh reel of 3 on opp sides (RSh to 2nd corner); _while_
    2s+3s continue reel, 1M crosses down,1L crosses up & dance RSh round
    4th corner into 2nd place own side
25-32::
    1s dance DoSiDo _while_ 2s+3s set twice; 1s set twice _while_ 2s+3s
    dance DoSiDo.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14117, '2021-07-07 00:19:46.56702+00', '2023-02-04 01:20:30.089866+00', 3019, 3, NULL, 'ace', '1-4::
    1s lead down, cross below 2s & cast up into partner''s place
5-8::
    1M+2L lead across between partners, cross, 2L casts up _while_ 1M
    casts down & they dance across to Ladies'' side & face partner
9-12::
    1s+2s set to partners (diagonally) & Petronella turn 1 place to
    right
13-16::
    1s+2s set to partners (diagonally) & dance 1/2 RH across. End facing
    down, 1M+2L RHJ followed by 2M+1L
17-24::
    All dance down (4 bars); Men pass LSh to meet partner & all dance up
    finishing ready for …
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5745, '2013-08-21 08:31:13.552655+00', '2023-02-04 01:20:31.015196+00', 10295, 3, NULL, 'ace', '1-8::
    4s set, cross LH to face 3s who step down, 3s+4s dance 1/2 reel of 4
    across 4s end in middle facing up
9-16::
    4s dance up & turn 2s with nearer hand into 3rd place own sides,
    2s+4s dance 1/2 R&L  1 (4)(2)(3)
17-24::
    1s+4s+2s dance 1/2 reel of 3 on sides (4s in & up between 1s), 4s
    cross dn between 1s (3rd pl) & dance 1/2 reel other side to end 2nd
    pl own side
25-32::
    1s+4s set & dance 1/2 RH across, all set & cross RH.  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (5746, '2013-08-21 08:31:13.562117+00', '2023-02-04 01:20:31.025959+00', 7748, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & cross RH, set & cross back RH
9-16::
    1s cross RH, cast 1 place, cross LH & cast (Lady up to end between
    2s facing down & Man down to end between 3s facing up)
17-24::
    1s change places RH & cast to 2nd place opposite sides, cross RH &
    cast (Man up to end between 2s facing down & Lady down to end
    between 3s facing up) _while_ 2s & 3s set & cross RH
25-32::
    1s change places RH & cast to 2nd place own sides _while_ 2s & 3s
    set to partners & cross RH, 1s turn RH twice _while_ 2s+3s set to
    each other on sides & change places RH on sides  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (14658, '2022-03-07 02:20:07.14202+00', '2023-02-04 01:20:32.344652+00', 16601, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L
9-16::
    1s+3s set, advance into centre. 3M+1L NHJ retire to 2nd place also
    3L+1M NHJ retire to 4th place. 1s+3s set. At the same time 4s+2s
    face partner, set, retire 2 steps. 4s+2s advance, 2M advances to 4L
    in 1st place _while_ 4M advances to 2L in 3rd place, 4s+2s set.
    Finish with Men on Ladies'' right
17-20::
    All Ladies dance 1/2 Ladies'' Chain (Ladies dance LH across in middle
    & turn partner RH into promenade hold facing clockwise, Ladies on
    partner''s right)
21-24::
    All promenade clockwise 1/2 way round 4 1 2 3
25-32::
    All dance 8H round & back
33-64::
    Repeat bars 1-32

{{explanation}}
Repeat bars 1-64 in Reel time to finish in original places', 0);
INSERT INTO 'dancecrib' VALUES (15069, '2022-09-05 00:20:11.525861+00', '2023-02-04 01:20:31.035893+00', 14792, 3, NULL, 'ace', '1-8::
    1M sets to 1L & casts to 2nd place (2M steps up on bars 3-4), 1M+3s
    dance RH across
9-12::
    1M sets to 2L & casts to 3rd place (3M steps up on bars 11-12)
    _while_ 1L sets to 2M & casts to 2nd place (2L steps up on bars
    11-12)
13-16::
    1M+4s also 1L+2s dance RH across
17-20::
    1L sets to 3M & casts to 3rd place (3L steps up bars 19-20)
21-24::
    1s+4s Set+Link 2 3 4 1
25-32::
    All dance RSh reels of 4 on the sides.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5747, '2013-08-21 08:31:13.573162+00', '2023-02-04 01:20:31.122879+00', 3045, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH across back to places
9-16::
    1s lead down for 3 steps, back to top & turn RH
17-24::
    1s+2s+3s dance the Grand Chain
25-32::
    1s+2s+3s set, cross RH, set & cross back RH
33-40::
    1s+2s set twice & dance 1/2 Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (5748, '2013-08-21 08:31:13.582771+00', '2023-02-04 01:20:31.148755+00', 3046, 3, NULL, 'ace', '1-8::
    1L followed by 1M cast to 3rd place opposite sides, 1M followed by
    1L dance back to places
9-16::
    1s cross RH, cast 1 place, cross LH, cast down round 3s & lead up to
    face 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s dance reels of 3 on sides giving LSh to 1st corners & cross to
    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5749, '2013-08-21 08:31:13.594471+00', '2023-02-04 01:20:31.205963+00', 3047, 3, NULL, 'ace', '1-8::
    1s lead down between 2s, cross & cast behind 3s (2s+3s step up 3-4).
    2s+3s+1s turn partners RH
9-16::
    1s lead up between 3s, cross & cast up behind 2s (2s+3s step down
    11-12). 1s+2s+3s turn partners RH
17-24::
    1s+2s circle 4H round to left, 1s cross RH & change places on sides
    with 2s giving LH
25-32::
    2s+1s+3s Adv, 2s+3s Ret _while_ 1s release hands & turn to left (1L
    between 2s, 1M between 3s).  Lines of 3 Adv (up/down), 2s+3s Ret
    _while_ 1s release hands to turn to left to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (11197, '2018-09-30 22:19:55.343788+00', '2023-02-04 01:20:31.241303+00', 18580, 3, NULL, 'ace', '1-8::
    1L+3M also 1M+3L turn RH & face out; 1s & 3s chase 1/2 round
    clockwise, Men leading _while_ 2M+4L & 2L+4M turn RH & face out. 3 2
    1 4
9-12::
    2s & 4s chase 1/2 round clockwise, Men leading _while_ 3s & 1s NHJ
    with partner Adv+Ret up/down set;
13-16::
    1s & 3s stand (4 bars) _while_ 2s & 4s NHJ with partner Adv+Ret
    across set. 3 4 1 2
17-24::
    3s+1s dance 1/2 Ladies'' Chain (up/down); 4s+2s dance 1/2 Ladies''
    Chain across set.  All with new partners, Ladies in original places
25-32::
    All face new partner, set & turn RH (4 bars) into prom hold facing
    clockwise (Lady on Man''s right). All promenade 1 place & face in

{{explanation}}
2nd time, all back with original partner opposite starting position.  Repeat 2 more times when all will be back in original places', 0);
INSERT INTO 'dancecrib' VALUES (13084, '2020-08-10 00:19:56.915226+00', '2023-02-04 01:20:31.267913+00', 3051, 3, NULL, 'ace', '1-8::
    1s+3s dance R&L (across to start) _while_ 2s+4s dance R&L up/down
    (start facing up/down)
9-16::
    1s & 3s cross RH, cast 1 place (2s & 4s step up); 1s & 3s turn
    partner LH to face 1st corners)
17-24::
    RSh reels across:  1L+2s, 1M+4s+3L (reel of 4) & 3M+5s. End 1L
    between 2s facing down, 1M between 4s facing up, 3L between 4s
    facing down, 3M between 5s facing up
25-32::
    1s & 3s petronella turn to opp side & set; 1s & 3s cross down 1
    place to own side & set (4s & 5s step up 31-32).  End 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (3996, '2013-08-21 08:30:40.991171+00', '2023-02-04 01:18:26.567316+00', 11404, 3, NULL, 'ace', '1-8::
    1s cross down under 3s arch & cast up to 2nd place opposite side, 1s
    turn LH & face 1st corners _while_ 3s (making arch) dance up to 2nd
    place & turning inwards dance down to places as 2s dance up & face
    diagonally in & set twice
9-16::
    1s+1st corners change places RH then 1st corners turn 1.1/4 LH to
    face 2nd corners, 1st+2nd corners change places RH & 2nd corners
    turn 11/4 LH to face 1s in 3rd corner positions
17-24::
    2nd corners change places RH with 1s who turn LH to end 1L between
    2L+3L (facing down) & 1M between 2M+3M (facing up) & all set twice
25-32::
    1s+2s+3s dance 1/2 RH across & 1s complete the wheel as 2s+3s &
    dance to their places, 2L+3L also 2M+3M dance 1 place clockwise to
    end 2s in 1st place & 3s in 3rd place _while_ 1s turn once round to
    face down (1L on 1M left) ready to start again.', 0);
INSERT INTO 'dancecrib' VALUES (5751, '2013-08-21 08:31:13.613377+00', '2023-02-04 01:20:31.541468+00', 9528, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, turn LH to face 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting & end 1L facing Mans 1st corner
    with partner behind
17-24::
    1s dance Alternating Tandem 1/2 reel of 3 with 1st corners &
    Alternating Tandem 1/2 reel with 2nd corners
25-32::
    1s similarly dance 1/2 reel of 3 with 3rd corner (pstn) & 1/2 reel
    with 4th corner (pstn) & end in 2nd place own sides
33-40::
    1s dance Figs of 8 on own sides dancing up between 2s to start
    (giving hands where possible) _while_ 2s+3s dance R&L changing
    places RH on sides to start', 0);
INSERT INTO 'dancecrib' VALUES (5752, '2013-08-21 08:31:13.622116+00', '2023-02-04 01:20:31.69335+00', 10822, 3, NULL, 'ace', '1-8::
    2s cross passing RSh & cast round 1st corner & dance 1/2 LSh reels
    of 3 across (Lady with 1s & Man with 3s)
9-16::
    2s dance 1/2 reels of 3 on opposite sides giving LSh to 2nd corner
    (pstn) & end turning LH 1.1/4 times to face 3rd corner (pstn)
17-28::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 2s in the middle
    facing up, lady on man''s right
29-32::
    2s dance up & cast to 2nd place own sides.  1 2 3
33-40::
    All circle left 1/2 way, 3s+2s dance RH across 1/2 way _while_ 1s
    cross RH & all set.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (11451, '2019-01-01 01:57:01.282706+00', '2023-02-04 01:20:31.745984+00', 18955, 3, NULL, 'ace', '1-8::
    1s set, cast, 1s followed by 3s lead to top, cross and cast, ending
    with 1s in 3rd place and 3s in 2nd place on opposite sides
9-16::
    All set. 1s+3s dance 1/2 RH across _while_ 2s & 4s cross LH
::
    1M followed by 3M dance 1/2 tandem reel of 3 on Men''s side (up LSh
    to 2L), _while_ 3L followed by 1L dance 1/2 tandem reel of 3 on
    Ladies'' side (down LSh to 4M)
17-24::
    All set. 1s+3s dance 1/2 RH across _while_ 2s & 4s cross LH
::
    3M followed by 1M dance 1/2 tandem reel of 3 on Ladies'' side (down
    LSh to 2L), _while_ 1L followed by 3L dance 1/2 tandem reel of 3 on
    Men''s side (up LSh to 4M).  End 2 (3) (1) 4
25-32::
    All set. 1s+3s dance 1/2 RH across, ending with 1L facing out on
    Ladies'' side
::
    1L followed by 1M dance out and down to end in 4th place on opposite
    sides (3s+4s step up)
33-40::
    1s dance 6 bar mirror reels of three with 4s and 3s on sides (1s
    dance in and up to begin) & 1s cross RH', 0);
INSERT INTO 'dancecrib' VALUES (5753, '2013-08-21 08:31:13.722526+00', '2023-02-04 01:20:31.807157+00', 3057, 3, NULL, 'ace', '1-8::
    All circle 8H round to the left & back (popular variation - 8 hands
    all the way round to left)
9-24::
    Ladies dance in front of ptnr & behind next Man, into RH across, in
    front of Man opp own ptnr & behind next Man, into RH across & back
    to place
25-32::
    All Promenade clockwise
33-40::
    1s & 3s dance cl''wise behind next couple & Men dance past cpl as
    Ladies dance in between cpl & both turn R to face cpl, all set &
    turn RH
41-48::
    All dance parallel reels of 4
49-56::
    1s & 3s dance a full Fig of 8 round the standing 2s/4s
57-64::
    1s & 3s dance LH across, 1s & 3s dance back to places (Men round &
    Ladies through the standing 2s & 4s)
65-96::
    2s & 4s repeat 33-64
97-104::
    All Promenade anticlockwise
105-120::
    Men dance in front of ptnr & behind next Lady, into LH across, dance
    in front of Lady opp own partner & behind next L into LH across &
    back to pl
121-128::
    All circle 8H round to the right & back (popular variation - 8 hands
    all the way round to right)', 0);
INSERT INTO 'dancecrib' VALUES (5754, '2013-08-21 08:31:13.811638+00', '2023-02-04 01:20:31.838268+00', 3058, 3, NULL, 'ace', '1-8::
    1s & 4s turn RH & cast in 1 place (2s & 3s step up/down), 1s+2s
    circle 4H to left
9-16::
    _9-10_    1M turns 4L LH so 4L in centre facing 3M
::
    _11-12_  1M turns 1L RH so 1L in centre facing 2M
::
    _13-16_  1M turns 4M LH (4 bars) so 4M in centre facing 3L & 1M ends
    in centre facing  2L
17-24::
    All set (HS) to ''corners'' & turn facing person 2H into St Andrews
    Cross with Ladies giving RH in centre & retaining LH with Men
25-32::
    All dance once round clockwise to end in longwise set with Man at
    each corner (Man''s side: 2M 1L 4L 3M : Ladies'' side: 1M 2L 3L 4M)
33-40::
    All circle 8H round to right
41-48::
    All dance Grand Chain (Men cross to start, Ladies change places on
    sides)
49-56::
    1s+2s also 3s+4s Adv+Ret (Diagonally) & turn own partner RH to end
    in original places
57-64::
    1s dance down to bottom (2 steps) & make an arch, 2s+3s+4s dance
    through arch & lead off (1M waving farewell)', 0);
INSERT INTO 'dancecrib' VALUES (5755, '2013-08-21 08:31:13.820539+00', '2023-02-04 01:20:31.850605+00', 11186, 3, NULL, 'ace', '1-8::
    1s+3s cross RH _while_ 2s & 4s 1/2 turn partners RH & all chase 1
    place cl''wise, 2s+4s cross RH as 1s & 3s 1/2 turn prtnr RH & all
    chase back to pl
9-16::
    Ladies dance RH across 1/2 way, dance out through opposite Ladies
    place to dance clockwise 1 place & repeat (Ladies now in opp places)
17-24::
    Repeat bars 1-8 but using LH & chase anticlockwise 1 place
25-32::
    Men dance LH across 1/2 way, dance out through opposite Mans place
    to dance anticlockwise 1 place & repeat to meet partner.  3 4 1 2
33-40::
    1s & 3s 1/2 turn partner RH into reel of 4 ending with Men BtoB
    facing partner.
41-48::
    1s+3s set advancing, taking prom hold dance all round each other by
    LSh to end 1s in 3rd place, 3s in 1st place
49-64::
    2s+4s repeat bars 33-48.  1 2 3 4
65-72::
    1s+3s RH across, turning right about couples dance RSh round each
    other & out between 2s/4s (Men leading) & cast to original places
73-80::
    2s+4s repeat bars 65-72
81-88::
    All dance Grand Chain BUT no hands
89-96::
    All turn partners 1.1/4 times RH, set & turn RH to Ladies in centre
    for bow/curtsey', 0);
INSERT INTO 'dancecrib' VALUES (4079, '2013-08-21 08:30:43.202528+00', '2023-02-04 01:18:32.664534+00', 3791, 3, NULL, 'ace', '1-8::
    1s+3s dance double Fig of 8 around 2s, 1s crossing down, 3s cast up
    to start
9-16::
    1s+2s dance Poussette
17-24::
    1s dance in & down between 2s (2s step up), set to each other &
    dance RSh round 4th corner to face own 1st corner
25-32::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places. 2 1 3

{{explanation}}
Note: End of 2nd turn it may help if 1s step in & down to 4th place as 3s cast up into double Fig 8', 0);
INSERT INTO 'dancecrib' VALUES (5757, '2013-08-21 08:31:13.837107+00', '2023-02-04 01:20:31.890895+00', 7423, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-12::
    1s dance down under an arch made by 2s, 1s dance down & make an arch
    for 3s (who dance up to 2nd place)
13-16::
    1s dance up under arch made by 3s, 1s dance up & make an arch for 2s
    (who dance down to 2nd place)
17-24::
    1M+2L change places diagonally RH, 1M+3M change places diagonally
    LH, 1L repeats with 2M & 3L
25-32::
    1L followed by partner casts to 2nd place (1L crosses to Men''s
    side), 2s+1s+3s set & cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (13305, '2020-11-02 01:20:15.099782+00', '2023-02-04 01:20:31.914408+00', 20098, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides, 1s
    end facing 1st corners
9-20::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s in the middle
21-24::
    1s dance 3/4 RSh turn (no hands) to 2nd place facing out _while_
    3s+2s chase clockwise 1/2 way 2 1 3
25-32::
    1s chase clockwise 1/2 round to 2nd place _while_ 2s+3s Adv+Ret
    diagonally. 1s dance 1/2 Fig of 8 (lady up, man down round 4th
    corner)', 0);
INSERT INTO 'dancecrib' VALUES (5758, '2013-08-21 08:31:13.847249+00', '2023-02-04 01:20:31.938557+00', 11478, 3, NULL, 'ace', '1-8::
    1s+2s dance Poussette
9-16::
    1s dance down & cast up round 3s to 2nd place in middle, 1s dance up
    & cast round 2s to face 1st corners
17-24::
    1s dance 1/2 reel of with corners & pass LSh to face 2nd corners, 1s
    dance 1/2 reel of 4 with corners& end 2nd place opposite sides
25-32::
    All set HS, all cross RH & 1s cast to 3rd place _while_ 2s+3s change
    places on sides (Ladies RH, Men LH) 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (15136, '2022-10-05 00:20:15.85052+00', '2023-02-04 01:20:31.972422+00', 20786, 3, NULL, 'ace', '1-8::
    1s+2s dance 6 bars Double Fig 8 (1s dance down, 2s cross up); 1s 1/2
    turn LH remaining in centre _while_ 2s & 3s set
9-16::
    1L+2L+3L also 1M+2M+3M dance RH across; 1s pass RSh to dance LH
    across, 1L+2M+3M, 1M+2L+3L. 1s end BtoB in centre facing opp sides
17-24::
    2s+1s+3s set as Double Triangles, all set advancing & pull back RSh
    to invert triangle
::
    2s+1s+3s set in inverted Double Triangles, 2s & 3s pull back RSh &
    dance out to own side (PdeB) _while_ 1s cross RH to own side.  2 1 3
25-32::
    _25_   2s  Allemande Right: advance to take partner''s RH,  Lady
    dances under Man''s arm. Lady curves out to place as Man retires
::
    _27_   1s repeat
::
    _29_   3s repeat', 0);
INSERT INTO 'dancecrib' VALUES (5759, '2013-08-21 08:31:13.855726+00', '2023-02-04 01:20:31.999973+00', 10587, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s set & turn RH, cast in 1 place & dance LH across 1/2 way
9-16::
    1s+4s retain LH give RH to corner & Bal-in-Line, 1/2 turn corner,
    Bal-in-Line & 1/2 turn corner to end on sides.  2 4(1)(3)
17-24::
    All dance 1/2 4 Couple Rights & Lefts:
::
    _17-18_     All cross RH
::
    _19-20_    Dancers in 1M & 2M pstns also 3L & 4L pstns change places
    LH on sides _while_ dancers in 1L place & 3M place cross diagonally
    LH as dancers in 2L & 4M pstns cross diagonally LH,
::
    _21-24_    Repeat Bars 17-20 to end facing own partner.  3 1 (4)(2)
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5760, '2013-08-21 08:31:13.864093+00', '2023-02-04 01:20:32.031248+00', 13932, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & 2s+3s dance up as 1s dance down between 2s+3s to 3rd
    pl, 3s+1s turn on sides 1.1/2 times (Men RH, Ladies LH) to change
    pl.  2 1 3
9-16::
    1s followed by 3s dance double Fig of 8 s round 2s with 1s ending in
    3rd place
17-24::
    2s+3s+1s set & 2s+3s dance down as 1s dance up between 2s+3s to 1st
    place, 1s+2s turn on sides 1.1/2 times (Men LH, Ladies RH) to change
    pl
25-32::
    2s+1s+3s dance reels of 3 on sides with 1s crossing up to begin &
    crossing down through 3rd place (own sides) & cast up to 2nd place.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13235, '2020-10-16 00:20:22.719757+00', '2023-02-04 01:20:32.061626+00', 3065, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+3s join 2H with partner & slip step past each other (Men pass
    BtoB); slip step back (Ladies BtoB)
17-24::
    2s+4s repeat 9-16
25-32::
    All Ladies dance RH across & LH across back to place facing corner
33-40::
    Ladies turn corner RH, turn partner LH
41-48::
    All Men dance RH across & LH across back to place facing partner
49-64::
    Change places RH with partner (2 bars) & set (or clap); change
    places with next person LH & set (clap); repeat twice more to end in
    opposite place from start place. 3 4 1 2

{{explanation}}
Repeat from new place', 0);
INSERT INTO 'dancecrib' VALUES (12642, '2020-03-02 01:52:48.959703+00', '2023-02-04 01:20:32.094381+00', 13915, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place, dance down between 3s & cast up to face
    1st corners (2s step up 7-8)
9-16::
    1s dance 1/2 diag reel of 4 with 1st corners; 1s pass RSh & dance
    1/2 diag reel of 4 with 2nd corners. 1s pass RSh into …
17-24::
    1L+3s (at top) & 1M+2s (at bottom) dance LH across; 1s pass LSh &
    dance RH across with other couple
25-32::
    1s dance out of ends (1M at top, 1L at bottom) & cast Right to 2nd
    place opp sides (3) (1) (2); All chase clockwise 1/2 round to end 2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (8594, '2015-02-13 12:47:52.455206+00', '2023-02-04 01:20:32.192468+00', 12685, 3, NULL, 'ace', '1-8::
    1s cross RH, cast, join RH to ptnr & LH to 1st cnrs, balance in
    line. 1s+1st cnrs change places LH, 1st cnrs meet in centre joining
    RH as 1L faces down, 1M faces up
9-12::
    1s pass 2nd cnrs by Left, curve in to join RH to ptnr & LH to 2nd
    cnrs _while_ 1st cnrs set, pass by Right & dance out to opp. corner
    place
13-16::
    1s+2nd cnrs balance in line, 1s+2nd cnrs change place LH, 2nd cnrs
    meet in centre joining RH, 1s face across dance
17-20::
    1s pass 1st cnrs person (3rd cnr pstn) LSh, cast into centre to join
    LH facing opp sides _while_ 2nd cnrs set & dance to opp corner place
21-28::
    All set, 1s turn 1/2 LH, 1M+3s (at top) &1L+2s (3rd place) dance RH
    across.  1s finish on opp sides facing clockwise
29-32::
    1M followed by 3M+3L & 1L followed by 2L+2M chase clockwise 1/2 way
    round to end all on own sides   2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9371, '2016-10-06 07:18:32.850297+00', '2023-02-04 01:20:31.864134+00', 12279, 3, NULL, 'ace', '1-8::
    1L dances in & casts to 2nd place (2L steps up).  1L dances down,
    cast up round 3M to 2nd place opp side _while_ 1M casts & crosses to
    2nd place opp side (2M step up 5-6)
9-16::
    1s dance reels of 3 on opp sides, 1L+2M pass LSh & 1M+3L pass RSh.
    1s end in middle, opp sides, facing down
17-24::
    1s lead down (3 steps), 1L dances under 1M''s Right arm to change
    sides & 1s dance up, divide & dance up behind 3s, cross passing LSh
    to face 1st corners
25-32::
    1s dancer ''Corner Pass+Turn'' with 1st then 2nd corners to end in 2nd
    place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5762, '2013-08-21 08:31:13.912477+00', '2023-02-04 01:20:32.224999+00', 11395, 3, NULL, 'ace', '1-8::
    1s+2s+3s set advancing & 1s followed by 2s+3s cast to 3rd place,
    meet & dance up to top (2s end in 2pl middle)
9-16::
    1L+2L 1.1/2 turn RH as 1M+2M 1.1/2 turn LH, 1s dance 1/2 Fig of 8
    (1L up, 1M down) ending 2nd place opposite sides
17-24::
    1s set to 2nd corner then partner, set to 1st corner & Petronella
    turn to end 1M between 2s & 1L between 3s
25-32::
    2s+1M also 1L+3s dance reels of 3 across & end with 1s dancing down
    to 4th place  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8595, '2015-02-13 12:47:52.470588+00', '2023-02-04 01:20:32.254021+00', 3080, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up), dance 1/2 Fig. 8 round 2s
9-16::
    1s turn 2H, dance down, cast up round 3s, lead up to 1st place opp.
    sides (2s step down 15-16)
17-20::
    1s turn RH, cast _while_ 2s set, turn RH moving up to 1st place
21-24::
    1s+2s dance 1/2 double Fig. 8 (1s cross up, 2s cast to start)
25-28::
    1s turn 2H moving up to 1st place, opening out to cast to 2nd place
    own sides _while_ 2s cast to 3rd place & cross RH also 3s (NHJ)
    dance up to 2nd place (bars 25-26) and turn 2H moving up to 1st
    place  3 1 2
29-32::
    3s+1s+2s dance 1/2 reels of 3 on sides (3s cast, 1s down & in, 2s
    out & up to start)   2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15230, '2022-11-03 01:20:10.807783+00', '2023-02-04 01:20:32.282142+00', 20447, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance mirror reels of 3 on sides (1s in/down, 2s out/up, 3s
    in/up to start)
9-16::
    1s set, cast (2s step up); 1s turn RH & face out
17-24::
    Promenade (Chaperoned) Chain progression:
::
    _17-18_    2s & 3s 3/4 turn partner RH into middle _while_ 1s dance
    clockwise 1/4 round the set picking up 2L/3M …
::
    _19-22_   who promenade 1/2 way clockwise _while_ middle people
    (2M+3L) turn LH 1.1/2
::
    _23-24_   3s & 2s turn partner RH 3/4 to own sides _while_ 1s dance
    clockwise 1/4 round to end in 2nd place. 3 1 2
25-32::
    3s+1s+2s dance the Knot.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13994, '2021-05-03 00:20:04.958566+00', '2023-02-04 01:20:32.317923+00', 17247, 3, NULL, 'ace', '1-8::
    1s+3s set, Petronella turn to middle; 1s+3s set to partner &
    Petronella turn to opp side
9-16::
    3s followed by 1s dance down NHJ (3 bars), 2s step up 11-12 as 1s+3s
    change sides (Lady turning under Man''s arm) & dance back up. 1s end
    between 2s, 1L leading, followed by 1M. 3s end in 3rd place
17-24::
    1s dance Alternating Tandem reel of 3 across with 2s (RSh to 2L to
    start). 1s end facing 1st corners
25-32::
    1s turn 1st corner RH, pass RSh, turn 2nd corner RH & pass RSh to
    2nd place own side
::
    2nd time through, Bars 31-32: 1s cross LH to 4th place (4s step up)', 0);
INSERT INTO 'dancecrib' VALUES (9203, '2016-06-16 22:41:56.18497+00', '2023-02-04 01:20:32.332366+00', 16848, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret, pass partner RSh & curve round them, 1s into 1st
    place facing down, 2s facing up, all on own sides
9-16::
    1s+2s Adv+Ret.  1s+2s turn 1.1/2 (Men LH, Ladies RH) and face down
17-24::
    2s+1s+3s dance mirror (reflection) reels on sides, 1s in/down, 2s
    out/down to start
25-32::
    2s+1s+3s Advance setting (2 bars).  2s cast up to 1st place, 1s cast
    to 3rd place _while_ 3s NHJ dance up into 2nd place.  1s+4s turn
    1.1/2 (Men RH, Ladies LH)  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5763, '2013-08-21 08:31:13.921022+00', '2023-02-04 01:20:32.364339+00', 13461, 3, NULL, 'ace', '1-8::
    1s dance down & turn 2H to face up, dance up & cast 1 place
9-16::
    2s+1s+3s circle 6H round & back, 1s end facing 1st corners.
17-24::
    1s dance Hello-Goodbye setting,1s end BtoB in centre (1M facing up,
    1L down)
25-30::
    1s reels of  3 on opposite sides passing 2nd corner RSh
31-32::
    1s cross RH to own sides.', 0);
INSERT INTO 'dancecrib' VALUES (5764, '2013-08-21 08:31:13.929192+00', '2023-02-04 01:20:32.392798+00', 3084, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back to places
9-16::
    1s lead down to 3rd place, 3s+1s circle 4H round to left
17-24::
    1s set, cast up 1 place to face 1st corners, 1s set to 1st corners &
    then to 2nd corners
25-32::
    1s dance reels of 3 on sides giving RSh to 2nd corners & cross to
    places', 0);
INSERT INTO 'dancecrib' VALUES (5765, '2013-08-21 08:31:13.93746+00', '2023-02-04 01:20:32.416036+00', 9636, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, 1s dance in & cast to 3rd place
9-16::
    1s dance RH across (1L with 3s & 1M with 4s), pass RSh & dance LH
    across with other couple 2 3 1 4 5
17-24::
    1L+2M (at top) also 1M+5L (at bottom) turn RH, 1s pass RSh & 1L+5M
    (at bottom)  also 1M+2L (at top) turn LH (1s end 3rd place own side)
25-32::
    1s dance in & cast to 5th place, 5s+1s circle 4H round to right.  2
    3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (5766, '2013-08-21 08:31:13.947561+00', '2023-02-04 01:20:32.477697+00', 7560, 3, NULL, 'ace', '1-8::
    1s+2s+3s in prom hold dance a reel of 3 across the set, 1s passing
    3s RSh to start
9-16::
    1s (with Lady leading) dance RH across with 3s & dance LH across
    with 2s
17-24::
    2s+3s dance Ladies Chain across the set _while_ 1s set (2 bars) &
    then dance between 2s+3s & cast individually back to places
25-32::
    1s+3s dance 1/2 R&L, 1s+2s dance 1/2 R&L to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5767, '2013-08-21 08:31:13.95738+00', '2023-02-04 01:20:32.613457+00', 3091, 3, NULL, 'ace', '1-8::
    1M sets to 2L, 1s turn 2H (crossed), 1L sets to 2M & 1s turn again
9-16::
    1s cast 1 place, turn 2H (crossed), dance down between 3s & cast up
    to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5768, '2013-08-21 08:31:13.963921+00', '2023-02-04 01:20:32.626988+00', 8933, 3, NULL, 'ace', '1-8::
    All dance RSh reels of 4 on sides
9-16::
    All set HS & turn partners 2H
17-24::
    1M+2L set, 1M casts down as 2L casts up (partners step down/up),
    2L+1M turn 2H
25-32::
    2M+1L set, 2M casts down as 1L casts up & turn 2H
33-40::
    1s lead down for 2 steps, set, lead up to top, cross & cast to 2nd
    place
41-48::
    1s change places RH with 3s on sides, change places with 4s LH &
    turn RH 1.1/2 times to 4th place', 0);
INSERT INTO 'dancecrib' VALUES (5769, '2013-08-21 08:31:13.972302+00', '2023-02-04 01:20:32.644631+00', 12281, 3, NULL, 'ace', '1-8::
    1s followed by 2s dance down below 3s, cast up & dance up to top 1s
    casting to face 1st corners
9-16::
    1s dance Pass+Turn with 1st corners, turn partner RH 1.3/4 times to
    face 2nd corners
17-24::
    1s dance LSh Pass+Turn with 2nd corners, turn partners LH to face
    1st corners
25-32::
    1s dance 1/2 LSh reels of 3 across (Lady with 2s & Man with 3s) &
    1/2 LSh reels with other couple', 0);
INSERT INTO 'dancecrib' VALUES (5770, '2013-08-21 08:31:13.980714+00', '2023-02-04 01:20:32.667028+00', 9836, 3, NULL, 'ace', '1-8::
    1s+2s turn 1.1/4 times on sides (Ladies LH, Men RH) to end in line
    across 1s BtoB, 1s+2s set, Ladies  3/4 turn RH _while_ Men turn 3/4
    LH.  2 1 3
9-16::
    1s dance 1/2 reels of 3 on sides (1L in & up, 1M in & down), 2s+3s
    continue reel _while_ 1s cross to join other reel (1L crosses down
    to 3rd place Men''s side _while_ 1M crosses up to 1st place Ladies
    side) & 1s turn 3M/2L RH to end in a diagonal line between 2nd
    corners
17-24::
    1s Bal-in-Line with 2nd corners, 1s turn LH & Bal-in-Line with 1st
    corners, 1s turn LH to…
25-32::
    1s dance RH across on sides (1L with 2L+3L, 1M with 2M+3M), 1L
    dances up & casts to 2nd pl own side _while_ 1M dances down & casts
    up to 2nd pl', 0);
INSERT INTO 'dancecrib' VALUES (5771, '2013-08-21 08:31:13.988912+00', '2023-02-04 01:20:32.68916+00', 3093, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    2s turn 1st corner LH, then turn 4th corner RH to end facing up in
    centre (1L & 3M face out)
17-24::
    1s+2s+3s dance reels of 3 on sides, 2s dancing up to top & casting
    to start.
::
    End 1s casting into 2nd place, 2s dancing up to top & 3s in 3rd
    place, all in centre facing up ready for …
25-32::
    2s+1s+3s dance Allemande. End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (14289, '2021-09-08 00:20:11.136385+00', '2023-02-04 01:20:32.908487+00', 20437, 3, NULL, 'ace', '1-8::
    1s dance in, cast to 3rd place (2s+3s step up 3-4); 2s+3s+1s set &
    cross RH
9-12::
    All dance 4 bars of Bourrel:
::
    2L+3M also 3L+1M set advancing, 3/4 turn 2H to line up/down middle,
    pull back RSh to BtoB in centre _while_
::
    2M+1L chase clockwise 1/2 round to end 1L 3M 2L 1M 3L 2M (Ladies
    facing down, Men facing up)
13-16::
    All set & turn opp person RH once round. 1L, 3M & 2L face up, 2M, 3L
    & 1M facing down
17-20::
    1L followed by 3M+2L dance down Ladies'' side _while_ 2M followed by
    3L+1M dance up Men''s side.  2 (3) 1
21-24::
    3s dance 1/2 Fig 8 (3L up round 2s, 3M down round 1s).  2 3 1
25-32::
    All Adv+Ret (1 step each), dance DoSiDo with partner & set.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (8596, '2015-02-13 12:47:52.546918+00', '2023-02-04 01:20:32.944044+00', 12686, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across (1L face out). 1L casts 2 places, dances up
    middle to 2nd place _while_ 1M dances down middle, casts up to 2nd
    place (2s step up 7-8)
9-16::
    2s+1s dance LH across.  1L casts up to 1st place, dances down middle
    to 3rd place (1L face out) _while_ 1M dances up middle to 1st place
    & casts to 3rd place facing in/down (3s step up 15-16)
17-24::
    3s+1s+4s dance reels of 3 on sides (1s+4s pass RSh). Finish 1L
    facing out/down, 1M in/down
25-28::
    1L+4L also 1M+4M turn RH 1.1/4 into line of 4 across
29-32::
    1L+4L also 1M+4M set to each other, turn 3/4 LH to finish 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (10444, '2018-02-24 07:52:41.950135+00', '2023-02-04 01:20:33.118317+00', 11365, 3, NULL, 'ace', '1-8::
    1s & 3s lead down & back to face 1st corners (2s & 4s step up 3-4)
9-12::
    1s & 3s dance Corner Pass+Turn with 1st corners; on approaching
    partners pull back RSh to face 4th corners
13-16::
    Repeat 9-12 with 4th corners, pulling back RSh to face out on own
    side
17-24::
    2s, 4s & 5s dance Petronella turn & set twice _while_ 1s & 3s dance
    out, cast Right, cross between setting couples, out & cast Right to
    end 1s in 2nd place, 3s in 4th place (End with all couples on opp
    sides, so all set bars 23-24)  (2)(1)(4)(3)(5)
25-28::
    2s 1/2 turn RH _while_ 1s+4s also 3s+5s dance 1/2 RH across; All set
29-32::
    All turn RH (or birl) to end 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (13236, '2020-10-16 00:20:23.480023+00', '2023-02-04 01:20:33.141426+00', 18211, 3, NULL, 'ace', '1-8::
    1s set, dance down below 3s (2s step up 3-4); 1s cast up & turn 3/4
    LH, remaining in centre for …
9-16::
    1M+2s also 1L+3s dance RH across, 1s end 2nd place opp side;
    2s+1s+3s chase clockwise 1/2 round
17-24::
    1s dance 1/2 Fig 8 (1M up round 2s, 1L down round 3s); all set & 1/2
    turn partner RH remaining in centre for …
25-32::
    3s+1s+2s dance allemande.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15137, '2022-10-05 00:20:16.858219+00', '2023-02-04 01:20:33.195318+00', 20785, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate
9-12::
    2s+1s+3s join hands on sides, set advancing, turn to right to Ladies
    facing up, Men facing down
13-16::
    2L followed by 1L+3L dance up & cast down Ladies''s side _while_ Men
    dance down & cast up Men''s side. 3s & 2s end in 1s/3rd place, 1s
    pass LSh to face 1st corners (pstn)
17-20::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh to face 2nd
    corners (pstn)
21-24::
    1s dance 1/2 diag reel of 4 with 2nd corners, 1s end in centre, LHJ
    with partner RHJ with 2nd corner (pstn)
25-28::
    1s+corners Bal-in-Line, retain LH & rotate 1/4 anticloclwise to join
    RH with 3rd corners (pstn) & Bal-in-Line
29-32::
    1s turn LH 1.1/4 to end in 2nd place own side _while_ 2s+3s set &
    cross RH to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12395, '2019-12-05 01:30:22.438612+00', '2023-02-04 01:20:33.216016+00', 18603, 3, NULL, 'ace', '1-8::
    1s & 3s set, cast 1 place (2s & 4s step  up); 1s & 3s turn partner
    1.1/4 LH to face up/down in centre ready for ..
9-16::
    1s & 3s dance Double Triangles (1L+2s, 1M+3L+4s, 3M+5s to start), 1s
    & 3s finish in centre facing partner (Men face up, Ladies face down)
17-24::
    1s+3s dance RSh reel of 4 finishing on sides in 2nd/4th place
25-32::
    1s & 3s cross RH, cast to 3rd/5th place (4s & 5s step up); 1s & 3s
    1/2 Fig 8 (1s up round 4s, 3s up round 5s). End 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (13995, '2021-05-03 00:20:05.575883+00', '2023-02-04 01:20:33.248045+00', 19959, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All pass partner RSh to dance interlocking reels of 4
9-16::
    1s & 3s change places passing opposite dancer RSh, cast away from
    partner & dance behind sides back to place (pass other dancer RSh
    behind sides) _while_ 2s & 4s set, Adv (2), set, Ret (2)
17-24::
    2s & 4s repeat 9-16
25-32::
    1s+2s also 3s+4s change places passing opp dancer RSh & chase
    clockwise 1 place;  1s+2s also 3s+4s change places passing opp
    dancer RSh, face in & set. 4 1 2 3
33-64::
    Repeat 1-32 from new places.  3 4 1 2

{{title}}
Reel

1-64::
    Repeat in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (5772, '2013-08-21 08:31:13.998916+00', '2023-02-04 01:20:33.374133+00', 3104, 3, NULL, 'ace', '1-8::
    1s+3s dance double Fig of 8 round 2s (1s cross down to start)
9-16::
    1s turn RH, cast 1 place, turn LH to form lines across 1L between 2s
    & 1M between 3s
17-24::
    2s+1s+3s Adv+Ret 1 step twice, turn opposite person 2H & 1s+2s end
    in centre for Allemande
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5773, '2013-08-21 08:31:14.007086+00', '2023-02-04 01:20:33.393852+00', 3105, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place (2s step up 3-4) & dance 1/2 Fig 8 down round
    3s
9-16::
    2s+1s dance R&L, 1s end facing 1st corners
17-24::
    1s set to & turn 1st corners, set to & turn 2nd corners finishing on
    sides between corners
25-32::
    1s dance 6 bar reels of 3 on sides giving LSh to 1st corners & cross
    to 2nd place own side bars 31-32', 0);
INSERT INTO 'dancecrib' VALUES (15337, '2022-12-19 01:20:17.178797+00', '2023-02-04 01:20:33.428375+00', 21180, 3, NULL, 'ace', '1-4::
    1s cross RH and cast (2s step up 3-4)
5-8::
    1s cross LH and cast down 2 places (3s+4s step up 7-8). 2 3 4 1
9-12::
    3s+4s dance RH across
13-16::
    2s+3s & 4s+1s dance LH across
17-20::
    3s+4s dance 1/2 R&L.  2 (4) (3) 1
21-24::
    2s+4s & 3s+1s dance 1/2 R&L. 4 (2) (1) 3
25-28::
    2s+1s dance 1/2 R&L. 4 1 2 3
29-32::
    All turn partner RH (or birl). 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (5774, '2013-08-21 08:31:14.015423+00', '2023-02-04 01:20:33.451587+00', 3108, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 double Fig of 8 (1s cross down), 1s dance down
    between 3s as 2s dance out & up then 1s cast up to 2nd place opp
    sides
9-16::
    1s+3s dance 1/2 double Fig of 8 (1s cross down), 1s dance up between
    2s & cast to 2nd place own sides
17-24::
    1s Petronella to opposite sides
25-32::
    2s & 3s Petronella to own sides _while_ 1s cast RSh round 1st corner
    & cross between 2s/3s, 1s cast to 2nd place own sides & all set', 0);
INSERT INTO 'dancecrib' VALUES (8303, '2014-07-29 12:58:42.905847+00', '2023-02-04 01:18:32.934755+00', 15362, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    1s dance RH across (Lady with 2s & Man with 3s), 1s pass RSh and
    dance LH across with other couple
17-24::
    2s+1s+3s Adv+Ret for 1 step, cross RH; all Adv+Ret for 1 step, 2s
    cross RH to place, 1s turn LH to face down in centre, 3s turn RH to
    face up in centre 2 (1) (3)
25-32::
    1s + 3s dance »Scissor Progression«:
::
    _25-26_   1s+3s set advancing & pass RSh
::
    _27-28_   All chase clockwise 1 place
::
    _29-32_   Repeat 25-28 to end 2 3 1
33-40::
    2s+3s+1s circle 6H round & back.', 0);
INSERT INTO 'dancecrib' VALUES (5775, '2013-08-21 08:31:14.024032+00', '2023-02-04 01:20:33.501949+00', 3110, 3, NULL, 'ace', '1-8::
    All set, Men turn Lady on right RH & Lady on left LH
9-16::
    All dance reels of 3 (RSh to Lady on right to start)
17-32::
    Men dance Quadruple Triangles: dancing to left to face out & join
    hands with Lady on left+opposite Lady (who face each other) & set,
    Men set turning 1/4 round to join hands with opposite Ladies (who
    face each other) & set, Men repeat with RH Ladies then own partners
    & turn to own place
33-48::
    Repeat bars 1-16
49-64::
    Men dance ''Hello-Goodbye'' setting all round ending in original
    places
65-80::
    Repeat bars 1-16
81-88::
    Both Men dance 1/2 reel of 4 with 1st corners (pass opposite Lady
    RSh), Men dance 1/2 reel of 4 with 2nd corners (pass opposite Lady
    RSh)
89-96::
    Repeat with 3rd & 4th corners back to places
97-112::
    repeat bars 1-16
113-128::
    Men petronella turn to right to join hands with Lady+opposite Lady &
    set in lines across, repeat 3 more times back to places', 0);
INSERT INTO 'dancecrib' VALUES (5779, '2013-08-21 08:31:14.06092+00', '2023-02-04 01:20:33.744104+00', 3113, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    All set, 1s+2s also 3s+4s dance 1/2 double Fig of 8 (1s & 4s
    crossing down/up to start), 1s & 4s turn 2H
9-16::
    1s & 4s dance 1/2 Figs of 8 on sides (out between 2s+3s) & loop
    round to face 2s/3s in lines across, all set & turn 2H
17-24::
    1s & 4s dance 1/2 reel of 4 across with 2s/3s, all set, 1s & 4s
    petronella turn into centre _while_ 2s & 3s set
25-32::
    1s+2s also 3s+4s circle 4H round to left, 1s & 4s advance towards
    partner & dance out ends & cast to 2nd/3rd places to end 2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (5780, '2013-08-21 08:31:14.069191+00', '2023-02-04 01:20:33.772477+00', 3115, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 on own sides dancing between 2s to start
9-16::
    1s (dancing between 2s giving nearer hand) into double triangle
    position & dance Double Triangles
17-24::
    1s dance 1/2 diagonal reel of 4 giving RSh to 1st corners & pass RSh
    to dance 1/2 diagonal reel with 2nd corners & pass LSh to face 1st
    corners
25-32::
    1s dance 1/2 LSh reel of 3 across (Man with 3s & Lady with 2s) into
    a 1/2 reel 3 on own sides giving RSh to 4th corner', 0);
INSERT INTO 'dancecrib' VALUES (5781, '2013-08-21 08:31:14.077491+00', '2023-02-04 01:20:33.801329+00', 14465, 3, NULL, 'ace', '1-4::
    1M crosses (passing partner RSh) & casts 1 place as 1L dances in &
    follows partner to end side by side in 2nd place
5-8::
    1L dances RH across with 2s _while_ 1M dances LH across with 3s
9-16::
    1s in prom hold dance diagonal reel of 3 with 1st corners (start RSh
    to 2M)
17-24::
    1s in prom hold dance diagonal reel of 3 with 2nd corners (start LSh
    to 3M) ending in middle dancing down
25-32::
    1s lead down & cross below 3s & cast up to 2nd places, 2s+1s+3s turn
    partners RH', 0);
INSERT INTO 'dancecrib' VALUES (5782, '2013-08-21 08:31:14.085958+00', '2023-02-04 01:20:33.826723+00', 3119, 3, NULL, 'ace', '{{explanation}}
Square set 5s face 1s & 6s face 3s.  Dance 3 times Strathspey & 3 times Reel

1-8::
    1s+5s+6s+3s dance parallel RSh reels of 4 up/down set
9-16::
    1s+5s & 6s+3s dance DoSiDo as 2s & 4s Adv+Ret, 1s+5s & 6s+3s dance
    1/2 R&L (1s & 3s end facing side couples)
17-24::
    2s & facing couple (1L+3M) with 4s & facing couple (1M+3L) dance
    parallel RSh reels of 4 across set
25-32::
    Each centre dancer (1s & 3s) dances RH across with nearest 2 corner
    dancers, centre dancers dance LH across once round in centre as
    outside couples (5s+2s+6s+4s) circle 8H round (or chase) to left 3/4
    way (quickly) to new pstns with 2s at top, 6s in 2nd place, 4s in
    3rd place & 5s in 4th pl', 0);
INSERT INTO 'dancecrib' VALUES (5783, '2013-08-21 08:31:14.096083+00', '2023-02-04 01:20:33.855632+00', 3122, 3, NULL, 'ace', '1-8::
    1s+2s set & dance 1/2 RH across, 1s+3s set & dance 1/2 LH across
    (2)(3) 1
9-16::
    1s dance Fig 8 round 3s
17-24::
    1s lead up between 3s & behind 2s to top, 1s+2s+3s set, 1s cast to
    2nd place _while_ 2s cross up & 3s cross RH
25-32::
    2s+1s+3s dance reels of 3 on sides (1s in & down to start)', 0);
INSERT INTO 'dancecrib' VALUES (5784, '2013-08-21 08:31:14.106374+00', '2023-02-04 01:20:33.88001+00', 8567, 3, NULL, 'ace', '1-8::
    1s set, cross RH, 1s+2s set, 1L casts to 2nd place opposite side
    _while_ 2L cast up to top own side _while_ 1M+2M cross to ptnrs pl
    facing out
9-16::
    1s+2s dance Ladies Chain & end facing diagonally in
17-24::
    1s+2s petronella turn to 1 place to right & join hands with partner
    set facing up/down, 2s dance 1/2 Fig of 8 round 1s
25-32::
    2s+1s Adv+Ret 1 step twice & turn partners 2H', 0);
INSERT INTO 'dancecrib' VALUES (5785, '2013-08-21 08:31:14.114641+00', '2023-02-04 01:20:33.90456+00', 14419, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s cross LH & cast left into lines
    across (1L between 2s & 1M between 3s)
9-16::
    2s+1s+3s Adv+Ret (up/down) & circle 6H round to left 1/2 way
17-20::
    1s dance 1/2 diag R&L (up/down)  with 3M & 2L
21-24::
    1s dance 1/2 diag R&L (up/down)  with 3L & 2M & end omitting polite
    turn
25-32::
    1s dance reels of 3 across giving RSh to 2nd corner end in 2nd place
    own sides & all set', 0);
INSERT INTO 'dancecrib' VALUES (5786, '2013-08-21 08:31:14.122961+00', '2023-02-04 01:20:33.934839+00', 9025, 3, NULL, 'ace', '1-8::
    1s set, cross RH & turn 2s LH on sides 1.1/2 times
9-16::
    1s+2s dance Ladies Chain
17-24::
    1s+2s+3s dance reels of 3 on sides (1s cross down LH to dance reels
    on own sides & end 2nd place own sides)
25-32::
    1s+3s dance RH across, 1s set advancing & cast to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (4010, '2013-08-21 08:30:41.433576+00', '2023-02-04 01:18:27.221919+00', 153, 3, NULL, 'ace', '1-8::
    2s+3s dance into middle & face diagonally in & all set, turn R about
    to face corners, change pl passing RSh with corners & set turning R
    about
9-16::
    Corners dance out as 2s+3s dance into middle passing RSh & all set,
    2s+3s turn R about & turn corners RH once back to middle
17-32::
    2s+3s LH across once round to face corners, all dance double
    diagonal reels of 4 giving LH in middle, corners end in original
    places
33-40::
    2s+3s change places with partners LH to face ptnrs crnr & set, all
    turn crnr with nearer hand (2s+3s dance out ends & cast back to
    middle)
41-48::
    2s+3s face diagonally in, Set & Points twice
49-56::
    2s+3s dance out own ends & cast (individually) back into middle
    again to Set & Points
57-64::
    2s+3s dance out opp ends (3s making an arch), couples cast round
    left corner & dance out other end _while_ corners step up/down.  2 1
    4 3', 0);
INSERT INTO 'dancecrib' VALUES (13237, '2020-10-16 00:20:24.214844+00', '2023-02-04 01:20:33.976185+00', 12924, 3, NULL, 'ace', '1-8::
    1s set cross down (no hands, 2s step up 3-4); dance LSh round 2nd
    corner (1M up, 1L down) to 2nd place opp sides facing out
9-16::
    1s+1st corners turn 3/4 RH, retain RH with corner & join LH with
    partner, 1s dance 4 bars of "Spoke" (balance with 1st corner & 2nd
    corner) & 1s turn 3rd corners 3/4 RH
17-24::
    1M+2s also 1L+3s dance LSh reels of 3 across (LSh to 2nd corner to
    start), 1s end facing 2nd corners
25-32::
    1s+2nd corners turn 3/4 RH, retain RH with corner & join LH with
    partner, 1s dance 4 bars of "Spoke" (balance with 3rd & 4th corner)
    & 1s turn 4th corners 3/4 RH to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5787, '2013-08-21 08:31:14.131186+00', '2023-02-04 01:20:34.00514+00', 12606, 3, NULL, 'ace', '1-8::
    1s cross down to dance Fig of 8 on opposite sides & end 1st pl
    opposite sides
9-16::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L.  (2)(3)(1)
17-24::
    All dance 1/2 reel of 3 on sides (2s give RSh to 3s), all set & 1/2
    turn partner into…
25-32::
    All dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (12466, '2020-01-02 07:00:08.793414+00', '2023-02-04 01:20:34.036282+00', 19475, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up), turn LH to 2nd place opp sides
9-16::
    1M+2s & 1L+3s dance RH across; 1s pass RSh to dance LH across with
    other couple
17-24::
    _1/2_ LSh reels of 3 across, 1M at top, 1L at bottom (1M+2M & 1L+3L
    pass LSh); 1s pass LSh & dance 1/2 LSh reels of 3s across with other
    couple
25-32::
    1s dance diag R&L (1M up/ 1L down)
33-40::
    3s+1s+2s turn RH (4 bars) & all chase clockwise 1/2 round to own
    side
41-48::
    2s+1s+3s circle 6H round & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13238, '2020-10-16 00:20:24.309448+00', '2023-02-04 01:20:34.086568+00', 19693, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s dance RH across; 1s & 4s chase clockwise 1/2 round
    _while_ 2s+3s dance LH across. 4 (2) 3 (1)
9-12::
    4s+2s also 3s+1s pass each other RSh on sides (2 bars), 2s & 3s
    chase clockwise 1/2 round (2 bars) _while_ 4s+1s dance LH across (2
    bars) & cross LH with partner to form 2 lines of 4 across set
13-16::
    Repeat 9-12 from new positions to form lines up/down
17-20::
    Repeat 9-12 from new positions to form lines across
21-24::
    Repeat 9-12 from new positions to form lines up/down. 4 (2) 3 (1)
25-32::
    4s+2s also 3s+1s turn 1.1/2 RH to change places; 2s+4s+1s+3s dance
    1/2 RSh reels of 3 on sides.  3 (1) 4 (2)', 0);
INSERT INTO 'dancecrib' VALUES (11241, '2018-10-03 22:46:40.593523+00', '2023-02-04 01:20:34.12294+00', 18721, 3, NULL, 'ace', '1-8::
    All set, cross RH   All set & 1/2 turn RH, remaining in centre
    facing up taking promenade hold ready for …
9-16::
    _3_ couple allemande, 2s end facing 1st corners (pstn)
17-24::
    2s+1st corners dance 1/2 diag reel of 4, pass RSh, 2s+2nd corners
    dance 1/2 diag reel of 4. 2s pass RSh to 2nd place own side (1) 2
    (3)
25-28::
    All set, 1s+2s dance 1/2 RH across _while_ 3s cross RH
29-32::
    All set, 1s+3s Link _while_ 2s cross RH.  2 3 1', 3);
INSERT INTO 'dancecrib' VALUES (13528, '2021-01-09 01:20:08.951868+00', '2023-02-04 01:20:34.295188+00', 17702, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-10::
    1s dance into promenade hold (Man with partner on right) to face
    Men''s side.
11-12::
    1s dance to 2nd place on Men''s side (2M steps up 11-12). On bar 12
    Man turns partner to his left into 2M''s place
13-14::
    1M dances over to 1st place on Ladies'' side
15-16::
    1M & 2L change places RH on the side.  2 (1)
17-24::
    2s+1s dance Men''s chain
25-28::
    1s dance 1/2 Fig of 8 round 2s.  2 1
29-32::
    2s+1s dance Allemande Turn to the Right:
::
    2s+1s advance one step, join RH with partner, dance one step forward
    Lady turns under Man''s right arm, Man retires as Lady dances back to
    place', 0);
INSERT INTO 'dancecrib' VALUES (8330, '2014-07-29 12:59:08.263953+00', '2023-02-04 01:20:34.32315+00', 15065, 3, NULL, 'ace', '1-8::
    1s+2s dance the Knot
9-16::
    3s followed by 1s+2s lead down middle, 2s+1+3s lead back up. 1s
    finish facing 1st corners
17-32::
    Corner Chain
::
    _17-24_   1s change pl RH with 1st crnrs, 1st crnrs turn LH in
    centre & return to places giving RH to 1s who turn LH in centre to
    face 2nd crnrs
::
    _25-32_   1s change places RH with 2nd crnrs, 2nd crnrs turn LH in
    centre & return to places giving RH to 1s who turn LH in centre', 0);
INSERT INTO 'dancecrib' VALUES (5790, '2013-08-21 08:31:14.16205+00', '2023-02-04 01:20:34.525229+00', 9864, 3, NULL, 'ace', '1-8::
    All circle 10H round & back
9-16::
    1s+2s also 4s+5s dance LH across & RH back to end NHJ 1s+2s & 4s+5s
    facing each other _while_ 3s set & cross RH, set & cross RH to own
    side & face out
17-24::
    1s+2s also 4s+5s dance "Mirror" Rondels (1s/5s make arches to start)
    as 3s dance round clockwise round set to prtnrs place (6 bars) &
    cross over LH to face out on own side
25-32::
    1s+3s+5s (centre 3 couples) dance Reels of 3 on own sides (3s pass
    person on left by LSh), end 1s & 5s facing in, 3s facing out
::
    _while_ 2s & 4s set, turn partner RH (4 bars), set
33-40::
    1s progression to 5th place:
::
    1s+3s also 5s+4s change places on sides (Men RH, Ladies LH)
::
    1s+4s change places (Men LH, Ladies RH)
::
    1s+5s turn 1.1/2 (Men RH, Ladies LH) to change places.  End 2 3 4 5
    1

{{explanation}}
Note: Dance originally published 1992.  This revised version published 2017', 0);
INSERT INTO 'dancecrib' VALUES (5791, '2013-08-21 08:31:14.17214+00', '2023-02-04 01:20:34.544458+00', 3144, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1s+2s also 3s+4s dance Poussette
25-32::
    1s+3s dance RH across (between 4s), 1s cast to bottom _while_ 3s
    lead up to 2nd place.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5792, '2013-08-21 08:31:14.187328+00', '2023-02-04 01:20:34.685078+00', 3145, 3, NULL, 'ace', '1-8::
    1s dance down the middle & back
9-16::
    1s+2s dance Allemande, 1s end in middle facing 1st corners
17-24::
    1s turn 1st corners RH, partner LH, 2nd corner RH & cross LH to 2nd
    place own sides
25-32::
    2s+1s+3s Adv+Ret 1 step, Adv+Ret 1 step & all turn 2H.', 0);
INSERT INTO 'dancecrib' VALUES (5788, '2013-08-21 08:31:14.139421+00', '2023-02-04 01:20:34.060964+00', 3129, 3, NULL, 'ace', '1-8::
    1s dance down below 3s & cast up to 2nd place own sides, 1L dances
    RH across with 2s _while_ 1M dances RH across with 3s
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners, 1/2 reel with 2nd
    corners & 1/2 turn LH in centre to face 1st corners
17-24::
    1s dance reels of 3 across giving LSh to 1st corners ending in 2nd
    place own sides
25-32::
    1s dance Diag R&L (1M crossing down & 1L crossing up to start)', 0);
INSERT INTO 'dancecrib' VALUES (5793, '2013-08-21 08:31:14.201414+00', '2023-02-04 01:20:34.843041+00', 3154, 3, NULL, 'ace', '1-8::
    1s dance RSh reels of 3 on own sides
9-16::
    1s cast behind 2s dance down between 3s,  cast round 3s to face 1st
    corners
17-24::
    1s set to 1st corners, set to 2nd corners & end between corners, 1s
    turn RH 1.1/2 times to end 2nd place own sides
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5794, '2013-08-21 08:31:14.212482+00', '2023-02-04 01:20:34.871444+00', 3147, 3, NULL, 'ace', '1-8::
    2s+3s set, dance in 2s face up & 3s down, dance between end couples
    & cast back to places
9-16::
    All Adv+Ret, 1s+2s also 3s+4s dance RH across
17-24::
    All circle 8H round to left 1/2 way Adv+Ret
25-32::
    1s+2s also 3s+4s dance LH across & circle 8H round to right 1/2 way
33-40::
    2s+3s cross RH, cast round corners, cross back to places & 2s cast
    up & 3s down', 0);
INSERT INTO 'dancecrib' VALUES (10833, '2018-06-11 00:36:30.774449+00', '2023-02-04 01:20:34.899238+00', 12726, 3, NULL, 'ace', '1-8::
    All set facing partner & petronella turn (Ladies BtoB in centre, Men
    outside facing in); all set, change places with partner RH retain
    hands & men join LH in centre
9-16::
    LH across ("double wheel") 2 places round ending Men BtoB  in centre
    facing partner; All set, petronella turn to face partner
17-24::
    Interlocking RSh reels of 3, at end Ladies face out
25-32::
    Schiehallion reels to end 2 places round anticlockwise from start,
    facing partner', 0);
INSERT INTO 'dancecrib' VALUES (5795, '2013-08-21 08:31:14.220866+00', '2023-02-04 01:20:34.926433+00', 3152, 3, NULL, 'ace', '1-8::
    1s+2s+3s set twice & cross (Ladies under Men''s arches passing
    partner RSh)
9-16::
    1s+2s+3s repeat to places
17-24::
    1s lead down the middle, up to top & turn to face 2s
25-32::
    1s set twice to 2s & turn opposite dancer with 2H 1.1/2 times to end
    in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (15070, '2022-09-05 00:20:14.872819+00', '2023-02-04 01:20:34.959059+00', 14791, 3, NULL, 'ace', '1-8::
    2s followed by 1s slip step down for 4 steps, set (starting on foot
    nearest top) & back to top, 1s cast to 2nd place 2 1 3
9-12::
    1s turn 3s on sides (Men RH, Ladies LH)
13-16::
    1s turn 2s (Ladies RH, Men LH), 1s finish facing 1st corner
17-20::
    1s dance 1/2 RSh reel of 4 with 1st corners, 1s pass RSh to face 2nd
    corners
21-24::
    1s dance 1/2 RSh reel of 4 with 2nd corners to finish in 2nd place
    on opposite sides
25-32::
    3s+1s+2s dance Set+Link for 3. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9204, '2016-06-16 22:41:56.526972+00', '2023-02-04 01:20:34.997686+00', 16881, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast, turn LH to face 1st corners
9-16::
    1s set to & turn 1st corners RH, set to & turn 2nd corners LH
    finishing in middle facing down/up
17-24::
    1s change places RH, cast to Right (M down round 3M, L up round 2L)
    into 2nd place own sides,1s dance 1/2 Fig 8 round 2nd corners to 2nd
    place opp. sides
25-32::
    2s+1s+3s set twice, 1s turn RH 1.1/2 times to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (12083, '2019-08-30 09:54:23.886795+00', '2023-02-04 01:20:35.025617+00', 19423, 3, NULL, 'ace', '{{explanation}}
2 chords, 2nd chord 3s & 4s cross to opp sides

1-8::
    1s & 4s dance in, cast down/up 1 place (2s & 3s step down/up 3-4);
    1s+4s dance RH across
9-12::
    2s+1s & 4s+3s dance LH across, 1L & 4L face out ready for …
13-16::
    1L followed by 1M casts up round 2L & dances down to 3rd/2nd place
    Men''s side _while_ 4L followed by 4M, casts down round 3L to 2nd
    /3rd place Ladies'' side
17-24::
    1s+3L+2M dance tandem reel of 3 (LSh to 3L in 4th place) _while_
    4s+2L+3M dance tandem reel of 3 (LSh to 2L in top place). 1s finish
    on the man''s side, 4s finish on the ladies'' side in 2nd & 3rd places
25-28::
    1s & 4s face diagonally in, set advancing & petronella 1 place
29-32::
    1s & 4s 1/2 turn partner RH, pull back right shoulder & dance out to
    sides.  End 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (9921, '2017-06-05 11:31:15.152057+00', '2023-02-04 01:20:35.073468+00', 17739, 3, NULL, 'ace', '1-4::
    1s dance down NHJ, 1M raises Left arm, dances behind 1L As she
    dances under his arm to change sides
5-8::
    1s repeat bars 1-4 as they dance back to top and face down
9-16::
    1s dance down followed by 2s (who dance up to start), cast up round
    3s, dance up to top & cast to 2nd place, 2s ending in 1st place
17-24::
    1s turn 1st corner RH, pass RSh, turn 3rd corner LH, pass partner
    LSh
25-32::
    1s turn 2nd corner RH, pass RSh, turn 4th corner LH & dance LSh
    round partner to face down, NHJ ready to repeat', 0);
INSERT INTO 'dancecrib' VALUES (13086, '2020-08-10 00:19:58.467943+00', '2023-02-04 01:20:35.094817+00', 20050, 3, NULL, 'ace', '1-8::
    1s set, cross down RH to 2nd place (2s step up); 1s turn RH to
    sidelines facing clockwise _while_ 2s+3s set & turn 3/4 RH to line
    up/down centre
9-16::
    2s+1s+3s dance a ''Weasel Reel'':
::
    2s+3s dance part reel of 4 up/down middle but when reaching either
    end they dance clockwise to top/bottom to re-enter reel _while_ 1s
    start by dancing clockwise to ends to replace dancer leaving the
    reel. All end where they started
17-20::
    1L+2s & 1M+3s dance RH across, 1s drop hands after 2 steps to meet
    in centre & 1/2 turn LH _while_ 2s+3s continue to turn RH ending on
    sides
21-24::
    1s dance out of end casting Left to 2nd place own side facing down
25-32::
    1s cross down RH, cast up round 3s, cross up RH & cast round 2s to
    2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8182, '2014-02-10 10:26:33.013163+00', '2023-02-04 01:20:35.114831+00', 14074, 3, NULL, 'ace', '1-8::
    1s & 2s dance Set & Rotate
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    1M with 2s, 1L with 3s dance reels of 3 across (RSh to 2nd corner to
    start); 1s end facing 1st corners
17-24::
    1s dance Pass+Turn with 1st crnrs, 1s pass RSh to face 2nd crnrs, 1s
    dance Pass+Turn with 2nd crns, end in 2nd place opp sides
25-32::
    2s, 1s & 3s dance Reel of 3 on sides (LSh to 1st corner to start),
    1s cross RH to own sides 31-32', 0);
INSERT INTO 'dancecrib' VALUES (5796, '2013-08-21 08:31:14.229062+00', '2023-02-04 01:20:35.131613+00', 13465, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret, 1s+2s+3s turn RH ending in middle for…
9-16::
    1s+2s+3s promenade round back to places
17-24::
    1s lead down & back to places facing out
25-32::
    1s cast round 2s & dance between 3s, behind 4s as 2s+3s+4s step up &
    1s turn RH to 4th place', 0);
INSERT INTO 'dancecrib' VALUES (5820, '2013-08-21 08:31:14.81371+00', '2023-02-04 01:20:36.945892+00', 8059, 3, NULL, 'ace', '1-8::
    1L+2M Adv+Ret, 1.1/2 turn RH
9-16::
    1M+2L Adv+Ret, 1.1/2 turn RH
17-24::
    2s+1s Adv+Ret, 1.1/2  turn RH
25-32::
    All circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8984, '2015-11-30 08:59:27.373122+00', '2023-02-04 01:18:33.311071+00', 14393, 3, NULL, 'ace', '1-8::
    1s turn 2H, face up, cast (2s step up), cross RH & cast round 1st
    corners to finish facing 1st corners
9-12::
    1s + 1st corners set, 1s cast round each other (RSh) to 3rd corner
    places as corners dance in, pull back RSh to face their original
    places
13-16::
    1s + 1st corners repeat bars 9-12, corners end in opp corner places
    _while_ 1s dance in, pull back RSh to face 2nd corners
17-24::
    1s + 2nd corners repeat bars 9-16, with 1s passing RSh into 2nd
    place opp sides.  All now on opp sides (3) (1) (2)
25-32::
    3s+1s+2s Set+Link for 3 twice to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5797, '2013-08-21 08:31:14.237433+00', '2023-02-04 01:20:35.15072+00', 14685, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s cross RH & cast in 1 place, 1s dance 1/2 Fig of 8 round 2s
    as 4s dance 1/2 Fig of 8 round 3s  2 1 4 3
9-12::
    All dance 1/2 Grand Chain (across at ends to start) but turning
    1.1/2 times when giving RH then all passing LH alternatively
13-16::
    4s & 1s  turn RH 1.1/2 times as 2s+3s turn RH 1.1/2 times on sides
    then 4s+3s & 1s 2s+1s change places LH on sides  3 4(1)(2)
17-24::
    All dance reels of 4 on sides.  3 4(1)(2)
25-32::
    End (3s & 2s) couples chase clockwise to change places _while_
    middle couples (4s+1s) dance LH across then top & bottom couples
    (2s+4s & 1s+3s) dance RH across  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (8331, '2014-07-29 12:59:08.51309+00', '2023-02-04 01:20:35.330909+00', 14654, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-16::
    1s+2s Set+Link & dance 4H  round to the Left
17-24::
    1s set to partner, pull RSh back, set to 4th corner, pull RSh back,
    set to partner, turn 2H to face 1st  corners
25-32::
    1s dance Pass+Turn with 1st corners (corners turn 2H) 1s passing
    RSh to face 2nd corners, dance Pass+Turn with 2nd corners finishing
    in 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (5798, '2013-08-21 08:31:14.245859+00', '2023-02-04 01:20:35.35456+00', 12428, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & cross RH, all chase clockwise 1/2 way
9-16::
    3s+2s+1s repeat back to places
17-24::
    1s lead down the middle & back
25-32::
    1s set & cross RH, 1s cast 1 place & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (5799, '2013-08-21 08:31:14.254096+00', '2023-02-04 01:20:35.381592+00', 8461, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s slip step down & back to 2nd place
17-24::
    1s dance 1/2 Fig of 8 round 2s, 1s dance 1/2 Fig of 8 round 3s
25-32::
    2s+1s dance R&L
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5800, '2013-08-21 08:31:14.264283+00', '2023-02-04 01:20:35.417843+00', 3165, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1M dances 1/2 Fig of 8 round 2s _while_
    1L dances round 3s 1s end facing 1st corners
9-16::
    1s dance 1/2 reel of 4 with 1st crnrs, pass LSh & dance RH across
    (1M with couple in 1st pl & 1L with cpl in 3rd pl) 1s end facing 2nd
    crnrs
17-24::
    1s dance 1/2 Reel of 4 with 2nd corners, pass partner LSh to dance
    RH across (1M with 2L+3L on Men''s side & 1L with 2M+3M)
25-32::
    1s 1/2 turn LH _while_ 2s+3s change places RH on sides, 1M dances up
    & 1L down, cast on own sides _while_ corners set & cross RH & all
    set', 0);
INSERT INTO 'dancecrib' VALUES (5801, '2013-08-21 08:31:14.272632+00', '2023-02-04 01:20:35.454609+00', 9087, 3, NULL, 'ace', '1-8::
    1s+2s set, Ladies cross, passing partners RSh chase clockwise to own
    side (having changed places)
9-16::
    1s+2s dance RH across & LH back
17-24::
    1s+2s set, Men cross, passing opposite Lady RSh chase clockwise to
    own sides
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5802, '2013-08-21 08:31:14.359589+00', '2023-02-04 01:20:35.594205+00', 8334, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH, set & petronella turn into centre
9-16::
    1s+2s dance 1/2 reel of 4 & turn partners 1.1/4 times to own sides
17-24::
    1s+3s dance R&L
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10080, '2017-09-03 23:44:49.098966+00', '2023-02-04 01:20:35.607169+00', 14719, 3, NULL, 'ace', '1-8::
    1s+2s dance "Chain Progression":
::
    _1- 2_   1s & 2s 3/4 turn RH
::
    _3- 6_   1M+2L turn LH 1.1/2 times _while_ partners chase clockwise
    1/2 way
::
    _7- 8_   2s & 1s 3/4 turn RH to end on sides in order 2 1
9-16::
    1s dance 1/2 Fig 8 (1M up round 2L, 1L down round 3M) finishing in
    2nd place opp sides facing 1st corners.  1s turn corner LH 1.1/4 to
    end BtoB in centre facing 1st corners
17-20::
    1s set pulling back RSh, cast round each other to 3rd corner place
    _while_ 2M+3L set, chase clockwise to next corner & 2L+3M set, dance
    in, pull back RSh to dance out to same place
21-24::
    1s set, dance in, pull back RSh to face place just left _while_
    2M+3L set, chase clockwise to next corner & 2L+3M set, pull back RSh
    & cast round each other to change places
25-32::
    1s dance 1/2 diag reel of 4 with 1st corner pstns, pass RSh in
    middle, dance 1/2 diag reel of 4 with 2nd corner pstns, finishing in
    centre BtoB facing own side
33-36::
    2s+3s chase clockwise 1/2 round _while_ 1s set, pull back RSh & cast
    round each other to 2nd place opp sides
37-40::
    3s+1s+2s set & cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (9373, '2016-10-06 07:18:33.431939+00', '2023-02-04 01:20:35.618761+00', 17206, 3, NULL, 'ace', '1-4::
    1s dance down between 2s & cast back to places
5-8::
    2s cross down between 3s & cast up to 1st place opp side as 1s dance
    down b''tw''n 3s & cast to 2nd pls own side as 3s stand & change pl LH
9-16::
    2s & 3s petronella turn into middle & set, 1s petronella turn into
    middle (1L between 2s & 1M between 3s) & all set
17-24::
    2M+1L & 1M+3L (both couples dancing in tandem) dance an Alternating
    Tandem reel of 4 with 2L & 3M up/down middle & Tandem couples end on
    own sides as 2L+3M turn 1.1/4 LH to own sides. (Men end 2 3 1 :
    Ladies 1 2 3)
25-32::
    1L+2L 1/2 turn RH, 2L to top, 1L+3L 1/2 LH turn, 3L into 2nd place
    _while_ Men stand [Strathspey] or Set/Coupe [jig],   All turn
    partner 2H [Strathspey] or Clap & birl partner [Jig].  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5803, '2013-08-21 08:31:14.391043+00', '2023-02-04 01:20:35.660519+00', 3172, 3, NULL, 'ace', '1-8::
    1M+2L set advancing & turn RH, 1L+2M set advancing & turn RH
9-16::
    1s set advancing to each other & turn 2H, cast to 2nd place &
    Petronella turn to Lady between 2s & Man between 3s
17-24::
    1s set & 3/4 turn RH _while_ 2s+3s change places RH on sides & set,
    1s repeat but 2s & 3s cross RH & set
25-32::
    1s set & change places RH _while_ 2s+3s change places RH on sides &
    set, 1s cast round corner to 2nd pl own sides as 2s+3s cross RH &
    all set', 4);
INSERT INTO 'dancecrib' VALUES (14137, '2021-07-07 00:21:58.497633+00', '2023-02-04 01:23:13.713794+00', 7174, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret; all turn partner 2H (PdeB) to end 1s in 1st place
    facing diag down, 2s in 2nd place, 3s in 3rd place facing diag up
9-16::
    1s+3s set & dance 1/2 RH across _while_ 2s dance clockwise round set
    to partner''s place; All dance clockwise round set to original places
17-24::
    1s turn RH, cast (2s step up); 1s turn LH to end in centre facing up
    NHJ
25-32::
    1s dance 6 bar reels of 3 on opp sides, 1s cross up to 1st place, 2s
    dance in/down, 3s out/up to start, 1s cross RH to own side 2nd
    place. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4082, '2013-08-21 08:30:43.232388+00', '2023-02-04 01:18:33.341581+00', 9769, 3, NULL, 'ace', '1-8::
    1s set to 2s & change places on sides (1M+2M LH, 1L+2L RH), 1s cross
    down RH to dance 1/2 reels of 3 on opp side ending in 2nd place opp
    side
9-16::
    1s petronella turn, set, change places RH, 1L dancing up between 3s,
    1M down between 2s & cast round to right to 2nd place own side
17-24::
    1s pass LSh to dance Diag 1/2 reel of 4 with 1st corners (pstns), 1s
    ending in centre 1L in 1st place facing down & 1M in 3rd place
    facing up, all circle 6H round 3/4 way to left (all on opposite
    sides)
25-32::
    1s pass LSh to dance Diag 1/2 reel of 4 with 1st corners (pstns), 1s
    ending in centre 1L in 3rd place facing up & 1M in 1st place facing
    down, all circle 6H round 3/4 way to left to end on own sides    3 1
    2', 0);
INSERT INTO 'dancecrib' VALUES (15138, '2022-10-05 00:20:19.008222+00', '2023-02-04 01:20:35.671441+00', 20790, 3, NULL, 'ace', '1-8::
    1s turn RH & cast (2s step up); 1s turn 1.1/4 LH to end 1L between
    2s facing down, 1M between 3s facing up
9-16::
    1s dance 1/2 diag R&L (1s cross diagonally with person to right);
    Lines of 3 Adv+Ret, 2s+3s Adv+Ret again _while_ 1s turn 3/4 RH to
    face up (1L on 1M''s right) NHJ
17-24::
    1s dance up, cast on own side, dance down through 3rd place & cast
    up to 2nd place _while_ 2s+3s set facing in diagonally, chase 1
    place clockwise, set & cross RH with partner.  2 1 3
25-32::
    1s set to 3s on sides, 1s+3s change places RH, retain RH; 3s+1s
    dance RH across.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (11198, '2018-09-30 22:19:56.556409+00', '2023-02-04 01:20:35.682108+00', 18552, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s cross LH & cast, 1L up & 1M down, to
    end 1L between 2s facing down & 1M between 3s facing up
9-16::
    1s dance Diag R&L (up & down set) & 1s end facing person on Left
17-24::
    1s pass person on their Left by RSh to dance Fig of 8 on own sides,
    ending in 2nd place
25-32::
    1s dance Diag R&L (across set) to end 2 1 3
33-40::
    All Adv+Ret & turn partners RH
41-48::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5804, '2013-08-21 08:31:14.5902+00', '2023-02-04 01:20:35.827657+00', 3176, 3, NULL, 'ace', '1-8::
    All dance Grand Chain 1/2 way
9-16::
    1s followed by 2s+3s+4s lead up 1s & 3s crossing to own sides as 2s
    & 4s end on opp sides, 1s cast 1 place & 1/2 turn RH to face 3s
17-24::
    1s+3s set, 1s set turning 3/4 round to left into BtoB (L facing up
    to 2s, M down) & circle 3H round to right 1/2 way (L with 2s, M with
    4s) to end in lines of 3 across & all set facing dn/up
25-32::
    1s dance 1/2 RSh reels of 3 (with same couples - RSh to person on
    right) & pass RSh to dance a 1/2 LSh reel of 4 with 3s
33-40::
    1s passing by RSh dance 1/2 RSh reels of 3 with other end couple
    pass LSh to dance a 1/2 RSh reel of 4 with 3s & end facing 3s
41-48::
    1s+3s set, 1s turn to face up to 2s & set, turn inwards to face 4s &
    set, 1s lead down & cross to 4th place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5805, '2013-08-21 08:31:14.600381+00', '2023-02-04 01:20:35.973418+00', 3177, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 2nd place, 1s cast again & lead up between 3s
    to face 2s
9-16::
    2s+1s set facing each other, set to partners, 1s+3s set facing each
    other, set to partners & 1s passing LSh face 1st corners
17-24::
    1s turn 1st corners RH, turn Partner LH, turn 2nd corners RH &
    partner LH to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14527, '2022-01-10 02:19:40.011074+00', '2023-02-04 01:20:35.999767+00', 18797, 3, NULL, 'ace', '1-8::
    1s dance down & cast up round 2s back to place; 1s set advancing,
    1/2 turn 2H & pull back RSh to finish BtoB in centre facing opp
    sides _while_ 2s set & cast up to 1st place facing in
9-16::
    1s+2s dance reel of 4 across (1s pass 2s RSh). 2s finish in 1st
    place, 1s do not complete reel but join NH in centre on own sides
    facing down
17-24::
    1s cross down between 3s, cast up to 2nd place opp side; 1L+3s (at
    bottom) & 1M+2s dance RH across. 1s end facing 1st corners
25-32::
    2s+1s+3s dance 6 bar reels of 3 on sides (1s LSh to 1st corner to
    start), 1s cross RH to 2nd place own side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5806, '2013-08-21 08:31:14.608901+00', '2023-02-04 01:20:36.03247+00', 3180, 3, NULL, 'ace', '1-8::
    All circle 8H round & back.
9-16::
    1s+3s dance LH across for 3 bars & pivot left, cast to own places &
    all 4 couples set
17-24::
    2s+4s dance RH across for 3 bars & pivot right, cast to own places &
    all 4 couples set
25-32::
    All turn corners RH & partner LH, turn corners RH & partner 3/4 LH
    to end Men BtoB in middle facing partner on the outside
33-40::
    All set (4 bars), all dance interlocking 1/2 reels4 across (Ladies
    giving LH in middle) & Men end BtoB facing facing their corner pstn
41-48::
    Repeat bars 33-40 to end with Ladies in own places & Men facing
    opposite lady
49-56::
    All 1/2 turn RH & Ladies dance 1/2 LH across in middle to face
    partner _while_ Men set, all turn RH 1.1/4 times to end Men facing
    in & Ladies out
57-64::
    All dance 1/2 Schiehallion reel to original places
1-64::
    Repeat in reel time', 0);
INSERT INTO 'dancecrib' VALUES (5807, '2013-08-21 08:31:14.617318+00', '2023-02-04 01:20:36.049219+00', 9803, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reels of 3 on own sides
17-24::
    1s petronella turn into centre, 2s petronella turn into centre,
    1s+2s set _while_ 3s petronella turn into centre, all set 1/4
    turning 2H ready for…
25-32::
    All dance 3 couple Poussette', 0);
INSERT INTO 'dancecrib' VALUES (5808, '2013-08-21 08:31:14.623718+00', '2023-02-04 01:20:36.073741+00', 10560, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s dance double Fig of 8  (2s & 3s cast to start)
9-16::
    1s+4s dance in (2s & 3s step to ends), turning other partner RH to
    face out in prom hold, dance out & round to right to face 2L/3L
17-24::
    1M & 4M with ''new'' partners dance LSh reel of 3 across & end in
    centre facing own partner
25-32::
    1s+4s join partner in prom hold, dance out round to left, dance in
    ends to meet in centre & dance 1/2 RH across, 1s & 4s cross RH to
    end 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (5840, '2013-08-21 08:31:15.088395+00', '2023-02-04 01:20:38.382268+00', 12525, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on sides (1s in & down to
    start)
9-16::
    1s lead down the middle & up to 2nd place ((2s up)
17-24::
    2s+1s+3s circle 6H round & back
25-32::
    1s pass LSh & turn 1st corners RH, passing RSh turn 2nd corners LH &
    pass LSh to places', 0);
INSERT INTO 'dancecrib' VALUES (4083, '2013-08-21 08:30:43.242249+00', '2023-02-04 01:18:33.359603+00', 265, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s & 4s set, cast in 1 place & dance 1/2 Fig of 8 round end couples,
    Ending in centre facing corners
9-16::
    All dance double diagonal reels of 4 passing LSh in centre & ending
    in original places

{{title}}
Reel

17-24::
    Set to & change places with corners RH, couples now in centre dance
    LH across once round
25-32::
    Set & change places with corners again RH, centre couples dance 1/2
    RH across & retire to sidelines & set.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10381, '2018-01-17 20:30:52.422584+00', '2023-02-04 01:20:36.186362+00', 18102, 3, NULL, 'ace', '1-8::
    1s+3s Petronella turn in centre & set.  1s+3s change place RH with
    partner, 1L+3M change places LH
9-16::
    1s+2s+3s dance ''Reel of 4 and Chase'':
::
    1M+3L dance 1/2 reel of 4 then dance clockwise through own sidelines
    to position as bar 9
::
    _While_ 1L+3M pass facing person RSh then dance clockwise round to
    rejoin reel at opposite end.  1L+3M do not pass on bar 16 but pull
    back RSh to end 1L facing up, 3M facing down
::
    _While_ 2s dance clockwise (2 bars), join at ends to dance 1/2 reel
    of 4, then dance clockwise back to original places
17-24::
    1s+3s dance Petronella turn to original places.  1s+2s+3s set & turn
    partners RH, all finishing in centre joining both hands, ready for …
25-32::
    1s+2s+3s dance 3 couple Poussette (1s move 2 places down _while_
    2s+3s move up 1 place)', 0);
INSERT INTO 'dancecrib' VALUES (5812, '2013-08-21 08:31:14.660928+00', '2023-02-04 01:20:36.213328+00', 9467, 3, NULL, 'ace', '1-8::
    1L & 3M followed by partners cast & chase clockwise 1/2 way, turn
    partners RH 1.3/4 times to end in centre Men facing down & Ladies up
9-16::
    1s+3s dance 1/2 reel of 4 up/down centre, turn partners RH 1.3/4
    times into original places
17-24::
    2s followed by 1s dance Fig of 8 round 3s & end 2 1 3
25-32::
    1s dance RH across (1L with 2s & 1M with 3s), 1s dance up & cast to
    2nd place', 0);
INSERT INTO 'dancecrib' VALUES (5814, '2013-08-21 08:31:14.683348+00', '2023-02-04 01:20:36.246559+00', 10794, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s cross RH, cast 1 place, 1s dance 1/2 Fig of 8 round 2s
    _while_ 4s dance 1/2 Fig of 8 round 3s
9-16::
    1s+4s dance R&L & end 1s facing up & 4s down
17-24::
    All dance RSh reel of 4 on sides & end 1s+4s in line across (Men in
    centre RSh to RSh & 1M LSh to 4L & 4M LSh to 1L)
25-28::
    1M+4M 3/4 turn RH _while_ Ladies dance anticlockwise 1/4 way round,
    Men 1/2 turn other partner LH to bring Ladies into centre
29-32::
    1L+4L 3/4 turn RH _while_ Men dance anticlockwise 1/4 way round,
    Ladies  3/4 turn Men LH to end 1s in 3rd place opp sides & 4s in 2nd
    place', 0);
INSERT INTO 'dancecrib' VALUES (5815, '2013-08-21 08:31:14.691882+00', '2023-02-04 01:20:36.274841+00', 10792, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s turn RH & cast 1 place, 1s dance 1/2 Fig of 8 round 2s
    _while_ 4s dance 1/2 Fig of 8 round 3s.  2 (1) 4 (3)
9-16::
    1L+4M (prom hold) dance 1/2 reel of 3 across with 3s & 1/2 reel with
    2s _while_ 1M+4L dance 1/2 reel across with 2s then 3s
17-20::
    2L+1L also 4L+3L 1/2 turn RH, twirl & dance out to others place
    _while_ 2M+1M also 4M+3M dance clockwise to change places
21-24::
    Repeat with Men turning RH & Ladies dancing clockwise.  2 (1) 4 (3)
25-32::
    1M+4L also 1L+4M Set+Link & circle 4H round to left.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (5816, '2013-08-21 08:31:14.701891+00', '2023-02-04 01:20:36.289828+00', 9094, 3, NULL, 'ace', '1-8::
    1M+2M also 1L+2L set on sides & change places on sides (Ladies RH
    Men LH), set & change back with other hand
9-16::
    1s cross down to dance reflection reels of 3 on opposite sides
    ending BtoB in 2nd place facing own sides
17-24::
    1s dance Double Triangles ending in centre facing down (Lady on left
    of partner)
25-32::
    1s dance down between 3s, cast up on own sides, dance up between 2s
    & cast to 2nd place
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5817, '2013-08-21 08:31:14.710057+00', '2023-02-04 01:20:36.31472+00', 7429, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH & chase clockwise 1/2 way
9-16::
    1s+2s+3s set, cross LH & chase anticlockwise 1/2 way
17-24::
    1s lead down middle & back
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5818, '2013-08-21 08:31:14.718623+00', '2023-02-04 01:20:36.342974+00', 3197, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cast 1 place _while_ 2s dance up, 1s+3s set, 1st cast
    1 place _while_ 3s dance up
9-16::
    1s turn RH, lead up to top & cast to face 1st corners
17-28::
    1s Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s meet again in the
    middle facing each other, 1L facing up, 1M facing down
29-32::
    1s pass RSh & 1L dances up between 2s & casts to 2nd place as 1M
    dances down between 3s & casts up to 2nd place _while_ 2s+3s set
    advancing & dance RH across 1/2 way.  2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (9737, '2017-04-06 08:39:53.083949+00', '2023-02-04 01:20:36.576329+00', 8058, 3, NULL, 'ace', '1-8::
    All 4 couples Adv&Ret; 1s+2s also 3s+4s dance RH across
9-16::
    All 4 couples Adv&Ret; 1s+2s also 3s+4s dance LH across
17-24::
    1s lead down and back, finishing in 1st place facing out
25-32::
    1s cast to 4th place (2s+3s+4s step up 27-28) All 4 couples turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5819, '2013-08-21 08:31:14.726965+00', '2023-02-04 01:20:36.602164+00', 12120, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L
9-16::
    2s & 3s cross RH _while_ 1s 1/2 turn RH, 1s lead up to top & cast to
    2nd place opposite sides
17-24::
    1s turn RH, 2L+1L turn LH, 1L+3L turn LH 1.1/4 times _while_ 1M+2M
    turn RH, 1M+3M turn LH 1.1/4 times (1s end facing 1st corners)
25-32::
    1s dance ''Hello-Goodbye'' setting & pass RSh to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (9478, '2016-11-09 08:48:36.033595+00', '2023-02-04 01:20:36.629649+00', 17407, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s dance down (4 bars) & cast up to original
    places
9-16::
    1s+2s dance 1/2 R&L. 1s+3s dance 1/2 R&L.  (2) (3) 1
17-24::
    1s turn 1/2 RH, face each other, pull back RSh and dance out to opp
    sides (»Gypsy Turn«).  All Set, cross RH to own sides.  2 3 1
25-32::
    All circle 6H round and back.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13410, '2020-12-02 01:20:14.950685+00', '2023-02-04 01:20:36.65111+00', 17340, 3, NULL, 'ace', '1-8::
    1s lead down (2s step up 3-4) & back up to 2nd place in centre, in
    prom hold facing 2L
9-16::
    1s+2nd corners dance diag reel of 3 (RSh to 2L). 1s end facing 2M
17-24::
    1s+1st corners dance diag reel of 3 (LSh to 2M). 1s end in centre
    facing up
25-32::
    1s dance up, separate & cast to 3rd place own side (3s step up
    27-28); 2s+3s+1s Adv+Ret (1 step each) & set', 0);
INSERT INTO 'dancecrib' VALUES (5847, '2013-08-21 08:31:15.403093+00', '2023-02-04 01:20:39.081966+00', 3246, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 round 2s+3s on own sides giving RSh to 2s to
    start
9-16::
    1s lead down to bottom & back to top
17-24::
    1s dance down under arch made by 2s, 1s form arch & 2s dance under
    back to places, 1s+2s repeat
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3967, '2013-08-21 08:30:40.435377+00', '2023-02-04 01:18:24.357385+00', 91, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s set & cross up _while_ 2s turn RH &
    cast to 2nd place.  (1)2 3
9-16::
    1s+2s set & dance RH across 1/2 way. 1s+2s set & cross down 1 place
    _while_ 3s turn LH & cast up to top.  3 2(1)
17-20::
    1s set & 1/2 turn LH _while_ 3s turn RH
21-24::
    1s lead up to top crossing & cast to 2nd place opposite sides
    _while_ 2s step down & set as 3s cast & lead up to top.  3(1)2
25-28::
    1s set & 3/4 turn LH in middle to face opposite sides
::
    _while_ 2s facing down promenade round up behind Men''s side & 3/4
    turn RH in middle to face opposite sides
::
    _while_ 3s facing up promenade down behind Ladies'' side & 3/4 turn
    RH in middle to face opposite sides
29-32::
    All turn 1.3/4 times (1s LH, 2s & 3s RH to own sides).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15071, '2022-09-05 00:20:16.683319+00', '2023-02-04 01:20:36.766364+00', 21097, 3, NULL, 'ace', '1-8::
    1s set, cross RH & cast, cross RH to 2nd place own side (2s step up
    5-6)
9-12::
    1s Petronella turn _while_ 2s+3s change places RH on sides to lines
    of 3 across (1L between 3s at top, 1M between 2s at bottom), join
    hands & all set
13-16::
    1s Petronella turn to 2nd place opp side _while_ 2s & 3s cross RH
    with partner, all join hands on sides & set.  (3) (1) (2)
17-24::
    Reels of 3 on sides (1s RSh to person on right to start)
25-32::
    3s+1s+2s circle 6H 1/2 round to left to own sides; 2s+1s+3s turn
    partner RH twice round (birls allowed).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10081, '2017-09-03 23:44:50.021801+00', '2023-02-04 01:20:36.786822+00', 3200, 3, NULL, 'ace', '1-8::
    1s cross down RH (2s step up) to face 3s, 1L sets to 3M & turns LH
    _while_ 1M sets to 3L & turns RH, 1s dance up to face 2s
9-16::
    1L sets to 2M & turns LH _while_ 1M sets to 2L & turns R; 1s dance
    1/2 Fig of 8 round 2s to face 1st corners.
17-24::
    1s dance RSh diagonal reel of 4 with 1st corners, pass LSh to face
    2nd corners.
25-32::
    1s dance RSh diagonal reel of 4 with 2nd corners to finish on own
    sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8597, '2015-02-13 12:47:53.578074+00', '2023-02-04 01:20:36.970015+00', 15023, 3, NULL, 'ace', '{{explanation}}
2 chords - 3s+4s cross to opp. sides on 2nd chord

1-4::
    2s+3s dance 1/2 Tourbillion (turn partners 2H 1/2 way round & dance
    clockwise 1 place and set)
5-8::
    2s+3s turn 2H 1.1/4 to finish 2s on Ladies'' side facing up, 3s on
    Man''s side facing down in promenade hold (Lady on Man''s right)
9-16::
    2s+1L+4M dance reels of 3 on side (2s+1L pass RSh) also 3s+1M+4L
    dance reels of 3 on sides (3s+4M pass RSh)
17-24::
    2s+3s dance 1/4 RH across, 2s dance down, cast up round 4s _while_
    3s dance up, cast round 1s.  2s+3s cross LH
25-32::
    1s+3s also 2s+4s dance the Bourrel:
::
    1M+3L (4M+2L) set advancing, 3/4 turn 2H & twirl to end BtoB (Lady
    facing up, Man down) _while_ prtnrs chase anticl''wise 3/4 way,
::
    set to partners & turn 2H to own sides having changed places', 0);
INSERT INTO 'dancecrib' VALUES (5821, '2013-08-21 08:31:14.822168+00', '2023-02-04 01:20:36.998394+00', 13323, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set+Link, all dance Grand Chain for 3 changes
    commencing with RH on sides.  3(1)(4)2
9-16::
    3s+1s also 4s+2s Set+Link, all dance Grand Chain for 3 changes
    commencing with RH on sides.  (4)(3)(2)(1)
17-24::
    All circle 8H round to left 1/2 way, 1s+2s also 3s+4s circle 4H
    round to left.  1 2 3 4
25-32::
    1s+2s also 3s+4s dance 1/2 Diamond Poussette; 1s+4s dance 1/2
    Diamond Poussette.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5822, '2013-08-21 08:31:14.830389+00', '2023-02-04 01:20:37.026627+00', 3207, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, set, 2s cross RH _while_ 1s turn right to face
    1st corner
9-16::
    1s dance RSh reels of 3 on opposite sides, 1s turn RH to face 3rd
    corner
17-24::
    1s dance RSh reels of 3 on own side, 1s turn RH to 2nd places
    opposite sides
25-32::
    2s+1s+3s set, 1s petronella turn into lines across & set, 1s
    petronella turn to own sides', 0);
INSERT INTO 'dancecrib' VALUES (12396, '2019-12-05 01:30:26.02088+00', '2023-02-04 01:20:37.048112+00', 19696, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Inveran Reels
9-16::
    1s+2s dance the Knot; 1s finish facing 1st corners
17-24::
    1s set to 1st corners, set to 2nd corners, pull back RSh, face
    partner across dance and turn 1.1/2 RH to finish in 2nd place on own
    side of the dance
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13411, '2020-12-02 01:20:15.18456+00', '2023-02-04 01:20:37.074438+00', 19156, 3, NULL, 'ace', '1-8::
    1L sets in centre (own choice of steps) _while_ others circle 7H
    round & back
9-16::
    1L+4s dance RH across; 1L+3s dance LH across
17-24::
    1L+2s dance RH across; 1L+1M turn LH into prom hold facing down (i.e
    backs to original place)
25-32::
    1s dance Fig 8, RSh to 4s then LSh to 2s & back to place
33-40::
    All 4 couples promenade anticlockwise back to original places
::
    Repeat 3 times with 2L, 3L & 4L in middle', 0);
INSERT INTO 'dancecrib' VALUES (5823, '2013-08-21 08:31:14.923362+00', '2023-02-04 01:20:37.283211+00', 11485, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cast to 2nd place as 2s dance up to top & face out;
    2s+1s dance 1/2 double Fig of 8 (1s cross up to start)
9-16::
    1s+3s set, 1s cast to 3rd place as 3s dance up to 2nd place & face
    out; 3s+1s dance a 1/2 double Fig of 8 (1s cross up to start)
17-20::
    All set, 1s dance up middle to 2nd place _while_ 2L+3L change places
    LH & 2M+3M change places RH on sides  3 1 2
21-24::
    1L dances RH across with 2M+3M as 1M dances LH across with 3L+2L. 1s
    end facing 1st corner (pstn)
25-32::
    1s dance 1/2 diag reel of 4 with crnrs & pass LSh to face 2nd corner
    (pstn), 1s dance 1/2 diag reel of 4 with crnrs & pass RSh to end in
    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5825, '2013-08-21 08:31:14.939862+00', '2023-02-04 01:20:37.332582+00', 9946, 3, NULL, 'ace', '1-8::
    1s cross down (no hands) to face 3s & set, 1s dance RSh round 3M/3L
    into 2nd place opposite sides
9-16::
    2s+1s chase anticlockwise 1 place & change places LH with other
    partner, repeat to end 2(1)
17-24::
    1M sets to 2L then turning right about sets to 3L then partner
    _while_ 1L sets to 3M then 2M then partner & end crossing RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9891, '2017-05-29 09:07:56.803591+00', '2023-02-23 12:21:34.107663+00', 17769, 3, NULL, 'ace', '1-8::

    1s+2s Set & Rotate with 1s turning RH to end facing 1st corners

9-12::

    1s set to 1st corners & dance RSh round each other into 3rd corner

    (pstn) _while_ 1st corners dance in & turn right about to face their

    original position

13-16::

    1s+1st corners dance 1/2 diag reel of 4 (corners end passing RSh to

    join next figure, 3L between Ladies at top, 2M between Men)

17-24::

    All chase clockwise to end in lines of 3 across, 1M between 2s at

    top, 1L between 3s at bottom. All set facing down/up, 1s change

    places RH

25-32::

    All Set+Link for 3, all turn partners RH (4 bars)

33-40::

    2s+1s+3s circle 6H round & back', 5);
INSERT INTO 'dancecrib' VALUES (3968, '2013-08-21 08:30:40.445589+00', '2023-02-04 01:18:24.387708+00', 7272, 3, NULL, 'ace', '1-8::
    1s lead down below 3s, turn RH & cast up on own sides to end in the
    middle (2nd place)
9-16::
    1s cross & dance reel of 3 on opposite sides, (1L RSh to 2M & 1M LSh
    to 2L)
17-24::
    1s dance reel of 3 on own sides (1L LSh to 2L & 1M RSh to 2M) & end
    in middle of dance
25-32::
    1s dance up & cast to 2nd place, 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (14719, '2022-04-01 00:18:27.918825+00', '2023-02-04 01:18:24.457232+00', 20650, 3, NULL, 'ace', '1-8::
    1s cross RH & cast; 1L dances down between 3s & casts up _while_ 1M
    dances up between 2s & casts down to end 1s in 2nd place own side
    (2s step up 7-8)
9-16::
    2s+1s+3s Adv+Ret; all 3 couples turn partner RH
17-24::
    1L+2s & 1M+3s dance RH across, 1s pass RSh to dance LH across with
    other couple. 2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13027, '2020-08-10 00:18:21.542302+00', '2023-02-04 01:18:24.475393+00', 92, 3, NULL, 'ace', '1-8::
    1s set & cross RH; 1s+2s set, 1s cross down RH to own side 2nd place
    facing 3s _while_ 2s cast up to top place
9-16::
    2s+1s+3s dance mirror reels of 3 on sides (1s out/down to start).
    1s end in centre, 2nd place, facing down
17-20::
    1s lead down followed by 2s, 1s cast up into 3rd place facing up (3s
    step up), 2s remain in centre in 2nd place facing down; 1s+2s join
    hands across & set
21-24::
    1s+2s 1/2 turn NH (Ladies LH, Men RH), 2s dance up to top, 1s follow
    to end in 2nd place (3s step down). 2 1 3
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (12902, '2020-07-01 00:18:21.811969+00', '2023-02-04 01:18:24.487863+00', 17585, 3, NULL, 'ace', '1-8::
    2s+3s set advancing, turn 2H to end on sides facing end couples;
    1L+2L & 3L+4L set, change places RH _while_ 1M+2M & 3M+4M set,
    change places LH. 4s face out. 2 1 4 3
9-16::
    1s+4s+3s dance Promenade (Chaperoned) Chain progression:
::
    _9-10_    1s & 3s 3/4 turn partner RH into middle _while_ 4s dance
    clockwise 1/4 round the set picking up 1L/3M …
::
    _11-14_   who promenade 1/2 way clockwise _while_ middle people (1M
    + 3L) turn LH 1.1/2.
::
    _15-16_   1s & 3s turn partner RH 3/4 to own sides _while_ 4s dance
    clockwise 1/4 round to end in 3rd place. 2 3 4 1
17-24::
    2s+3s & 4s+1s dance diag reels of 4 across (2L+3M also 1M+4L pass
    LSh to start then RSh to partner)
25-32::
    All circle 8H round & back.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (3969, '2013-08-21 08:30:40.453753+00', '2023-02-04 01:18:24.506323+00', 93, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, petronella turn to 1M between 2s facing
    down & 1L between 3s facing up, all set
9-16::
    2s+1s+3s Adv+Ret up/ down for 2 steps, 1s petronella turn to 2nd
    place own sides & all set
17-24::
    1s dance reels of 3 on sides giving RSh to 4th corner, 1s end Lady
    between 2s & Man between 3s
25-32::
    1s dance reels of 3 across again giving RSh to 4th corner, 1s cross
    RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (3970, '2013-08-21 08:30:40.463916+00', '2023-02-04 01:18:24.541424+00', 8499, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance 1/2 Fig of 8 round 2s (2s step up 3-4)
9-16::
    2s+1s+3s set twice, 2s & 3s cross RH & set to partner as 1s turn RH
    1.1/4 times to end in lines of 3 across (1M between 3s, 1L between
    2s)
17-24::
    2s+1s+3s set twice, 2s & 3s change places RH on sides & set to
    person they changed with _while_ 1s turn RH 1.1/4 times to 2nd place
    own sides
25-32::
    1s dance Diag R&L (1M crossing diagonally down & 1L crossing
    diagonally up to start)', 0);
INSERT INTO 'dancecrib' VALUES (5827, '2013-08-21 08:31:14.956671+00', '2023-02-04 01:20:37.639661+00', 10755, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    1s dance reels of 3 on sides (1s give LSh to person on left to
    start) & end facing 1st corners
17-32::
    1s dance Corner Chain with 1st & 2nd corners :
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end turning LH to 2nd places
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (10998, '2018-08-17 07:52:25.483189+00', '2023-02-04 01:20:37.659346+00', 3216, 3, NULL, 'ace', '1-8::
    1s lead down (3 bars), turn 1.1/2 RH (3 bars) & dance up to 2nd
    place opp sides facing out (2s step up 3-4)
9-16::
    2s+1s dance 1/2 Double Fig 8 (2s cross down, 1s dance out/up); 2s+1s
    turn on sides (2L+1M RH, 2M+1L LH)
17-24::
    1L+2M NHJ dance across  between partners, separate & cast back to
    Ladies'' side; 1s NHJ dance up & cast to 2nd place own side
25-32::
    1M+2L NHJ dance across  between partners, separate & cast back to
    Men''s side; 2s join LH, dance down between 1s, cross & cast up to
    1st place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5828, '2013-08-21 08:31:14.975597+00', '2023-02-04 01:20:37.718778+00', 13763, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH
9-16::
    All dance RSh reels of 4 on sides
17-24::
    All 1/2 turn partner RH & twirl out to opposite sides; all chase
    clockwise 1/2 way.  3 4 1 2
25-32::
    2s dance up passing 1s RSh & pass 4s LSh, pass 3s RSh into 1st place
    (3s+4s+1s step down 29-30);  All turn partner 2H.  End  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5829, '2013-08-21 08:31:14.984005+00', '2023-02-04 01:20:37.741014+00', 3218, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 2s
9-16::
    1s dance 1/2 Diag R&L with 1st corners; 1M dances up between top
    couple & casts to 2nd place own side _while_ 1L dances down & casts
    up to 2nd place
17-24::
    1s dance 1/2 Diag R&L with 2nd crnr (pstns); 1L dances up & casts to
    2nd pl own side as 1M dances down & casts up to 2nd place.  (3) 1
    (2)
25-32::
    1s dance RH across (1L with 3s at top & 1M with 2s), 1s turn LH
    1.3/4 times to 2nd places _while_ 3s+2s chase clockwise to places. 2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (5830, '2013-08-21 08:31:14.992257+00', '2023-02-04 01:20:37.760638+00', 9091, 3, NULL, 'ace', '1-8::
    1s dance down between 2s, cast back to places & turn RH
9-16::
    1s dance Fig of 8 round 2s casting to start
17-24::
    1s+2s turn on sides (Ladies RH & Men LH), set on sides & change
    places RH on sides
25-32::
    2s+1s dance RH across & LH back', 0);
INSERT INTO 'dancecrib' VALUES (5831, '2013-08-21 08:31:15.000453+00', '2023-02-04 01:20:37.776737+00', 3219, 3, NULL, 'ace', '1-8::
    1s & 4s turn RH moving into centre & dance RH across & turn partner
    RH into line of 4 up/down set (Men BtoB)
9-16::
    1s+4s dance reel of 4 up/down & into…
17-24::
    1s also 4s dance reels of 4 across (1s with 2s & 4s with 3s) & end
    in original places
25-32::
    All set & advance, 1s cast to bottom _while_ others dance up & all
    set', 0);
INSERT INTO 'dancecrib' VALUES (5832, '2013-08-21 08:31:15.008602+00', '2023-02-04 01:20:37.8008+00', 11603, 3, NULL, 'ace', '1-8::
    1s lead down & back up again to end BtoB facing 1st corners
9-16::
    1s set to 1st corners & turn 2H & PdB face 2nd corners, 1s set to
    2nd corners & turn 2H & end in 2nd place opposite sides
17-24::
    2s+1s+3s Adv+Ret; 1s turn RH 1.1/2 times
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12920, '2020-07-01 00:20:05.257665+00', '2023-02-04 01:20:37.822943+00', 19989, 3, NULL, 'ace', '{{explanation}}
5 person square set, 5th person in centre facing person 1 at top

{{title}}
Start

{{title}}
····3

{{title}}
2··5··4

{{title}}
····1

{{title}}
··Top

1-8::
    _5_+1 turn RH; 5+3 turn LH
9-16::
    _5_+4 turn LH; 5+2 turn RH
17-24::
    _5_+4+1 dance RH across; 5+3+2 dance LH across
25-32::
    _5_+4+2 dance reel of 3 across, 5 passes 4 RSh to start. 5 ends
    facing 3 at bottom
33-40::
    _5_+3+1 dance reel of 3 up/down, 5 passes 3 LSh to start. 5 end in
    centre facing 3 & 4
41-44::
    _5_+4+3 set as Double Triangles, 5 turns right about (2 PdeB)
    _while_ 1+2+3+4 chase one place round clockwise. 4 1 2 3 [5 in
    centre]
45-48::
    _5_+1+4 (in new places) set as Double Triangles; 5+1 change places
    RH', 0);
INSERT INTO 'dancecrib' VALUES (5833, '2013-08-21 08:31:15.018574+00', '2023-02-04 01:20:37.987339+00', 3225, 3, NULL, 'ace', '1-8::
    1L advances & sets to partner, casts LSh round 2M & sets to 2M
9-16::
    1L in triangle formation with 1M+2M sets twice, 1s turn into
    Allemande hold facing out on Ladies side
17-24::
    1s in Allemande hold dance out round 2L, up & round 2M to form line
    across for reel of 4
25-32::
    1s+2s dance reel of 4 across
33-40::
    1s set twice & turn RH 1.1/2 times to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (12146, '2019-09-02 22:01:38.332816+00', '2023-02-04 01:20:37.998905+00', 19577, 3, NULL, 'ace', '1-8::
    1s NHJ dance down middle, cast round 5s & dance back up to original
    places
9-16::
    All 5 couple set, cross, set & cross back
17-24::
    1s+2s also 3s+4s dance double Figs 8 (1s & 3s cross down, 2s & 4s
    dance out & up). 2s & 4s end facing out  & up ready for ...
25-34::
    Reflection reels of 5 (10 bars):
::
    Start 1s in/down; 2s out/up; 3s in/down; 4s out/up; 5s in/up (give
    way to 3s)  End 1s face 2s, 3s face 4s on side _while_ 5s face
    partner across set
35-40::
    1M+2M, 3+4M turn RH _while_ 1L+2L, 3L+4L turn LH, _while_ 5s turn RH
    (4 bars).  All set on sides (2 bars)
41-48::
    1s+2s change places (Men RH, Ladies LH), 1s+3s change places other
    hand,  continue progression until 1s reach 5th place.  Order 2 3 4 5
    1', 0);
INSERT INTO 'dancecrib' VALUES (5837, '2013-08-21 08:31:15.053742+00', '2023-02-04 01:20:38.133912+00', 3233, 3, NULL, 'ace', '1-12::
    1s set, cast 1 place into centre & dance reflection reels of on own
    sides (1s down between 3s to start)
13-16::
    1s set (2nd place), Lady casts up & Man down 1 place (2L steps down
    & 3M up)
17-24::
    1s cross RH with opposite person, change LH on side with 2L/3M &
    dance 1/2 Diag R&L
25-32::
    1s dance LSh round 1st corner positions to 2nd place opposite sides,
    2s+1s+3s set & cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5839, '2013-08-21 08:31:15.080108+00', '2023-02-04 01:20:38.346832+00', 11605, 3, NULL, 'ace', '1-8::
    1L followed by partner cast round 2L cross & cast up round 2M back
    to places & 1s turn 2s RH
9-16::
    1s+2s dance reel of 4 across (1M+2L pass LSH to start) all end in
    original places
17-24::
    1s+2s turn RH on sides & set, 1s+2s circle 4H once round to Left,
    drop hands bar 24 to dance into original places
25-32::
    1s+2s dance The Rose:
::
    _25-28_  1M+2L set as 1L+2M change places RH, 1M+2L 1/2 turn 2H &
    remain in middle as 1L & 2M dance into partners place
::
    _29-32_  1M+2L cast into each others place as 1L+2M 1/2 turn 2H, 1M
    & 2L dance into 2nd/1st places own side as 1L & 2M cast to right to
    new places', 0);
INSERT INTO 'dancecrib' VALUES (5841, '2013-08-21 08:31:15.096607+00', '2023-02-04 01:20:38.40524+00', 3236, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 R&L (1 bar per hand), set & dance 1/2 R&L (1
    bar per hand) back to places
9-16::
    1s lead down the middle & back to top
17-24::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5842, '2013-08-21 08:31:15.192906+00', '2023-02-04 01:20:38.634153+00', 13508, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance 6 bar mirror reels of 3 on own sides (2s in &
    down),1s end in 1st place. Bars 7-8:  2s+3s continue reel to end 1 3
    2
9-20::
    1s+3s+2s dance 3 couple R&L
21-24::
    All turn RH to face up for…
25-32::
    1s+3s+2s dance Allemande.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5836, '2013-08-21 08:31:15.04534+00', '2023-02-04 01:20:38.108502+00', 3231, 3, NULL, 'ace', '1-8::
    1s+2s+3s set cross RH, set & cross back RH
9-16::
    1s+2s dance double Fig of 8 (1s cross down to start)
17-24::
    1s dance Inveran reels with 2s+3s
25-32::
    1s followed by 2s lead down 3 steps, turn RH (3 bars) & 2s lead up
    followed by 1s to new places', 0);
INSERT INTO 'dancecrib' VALUES (5660, '2013-08-21 08:31:10.982017+00', '2023-02-04 01:20:38.284571+00', 3237, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret & circle 4H round 1/2 way to left
9-16::
    1M turns 2L RH back to places, 1L turns 2M repeat
17-24::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (14659, '2022-03-07 02:20:11.911041+00', '2023-02-04 01:20:38.647436+00', 20519, 3, NULL, 'ace', '1-8::
    1s+2s+3s cross LH & set, cross back RH & set (1s+2s advance & take
    promenade hold)
9-16::
    1s+2s promenade ending with 1s casting to face 1st corners, 2s dance
    to top
17-22::
    1s & 1st corners dance La Baratte (6 bars):
::
    _17-18_    1s 1/2 turn corners RH & retain hands but at arm''s length
    from each other
::
    _19-20_    Men retrace steps with Lady turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies original
    place) & releasing Ladies RH she turns under Mans left arm until
    almost in original places
::
    _21-22_    1s+1st corners change places LH to opposite places
23-24::
    1st corners dance to original places _while_ 1s dance on
    anticlockwise to face 2nd corners
25-32::
    1s & 2nd corners dance La Baratte (6 bars), 1s dance on
    anticlockwise to finish in lines of 3 across the dance (1L between3s
    facing up, 1M between 2s facing down)
33-40::
    All set, 1s pull back RSh, cast round 2nd corners & pass RSh to 2nd
    place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5843, '2013-08-21 08:31:15.201261+00', '2023-02-04 01:20:38.658271+00', 12624, 3, NULL, 'ace', '1-8::
    1s cross, cast 1 place & dance 1/2 Fig of 8 round 2s
9-16::
    1s dance 1/2 reels of 3 across (1L with 2s & 1M with 3s), 1s dance
    diagonal 1/2 reel of 4 with 2nd corners (pstn)
17-24::
    1s dance 1/2 reels of 3 across (1M with 2L+3L & 1L with 2M+3M), 1s
    dance diagonal 1/2 reel of 4 with 4th corners ending (3) 1 (2)
25-32::
    1s dance Diag R&L to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15072, '2022-09-05 00:20:18.313467+00', '2023-02-04 01:20:38.668303+00', 20915, 3, NULL, 'ace', '1-8::
    1s set, 1/2 turn 2H; 1s dance down NHJ (2 steps) _while_ 2s step up,
    1s turn LH to face 1st corners
9-16::
    1s set to 1st corner moving to between corners, turn RH to face 2nd
    corners; repeat to end facing 3rd corners
17-24::
    1s dance 1/2 diag reel of 4 with 3rd corners, pass RSh; dance 1/2
    diag reel of 4 with 4th corners & end in 2nd place own side
25-32::
    1s dance diag R&L (Lady up / Man down).  End 2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (5844, '2013-08-21 08:31:15.211554+00', '2023-02-04 01:20:38.680764+00', 14235, 3, NULL, 'ace', '1-4::
    1M+2L change places RH & 1M dances RSh round 1st corner to end in
    middle just below 3rd place
5-8::
    1L+2M change places RH & 1L dances RSh round 1st corner to end in
    middle just above 1st place
9-16::
    1s dance reels of 3 on sides giving LSh to 2nd corner ending in
    middle above/below 2s/3s
17-20::
    1s dance RH across 1/2 way (1L with 2s & 1M with 3s) & 1s pass each
    other RSh & turn to face partner then twirl to dance down/up as
    crnrs set
21-24::
    1s dance LH across 1/2 way (1M with 2s & 1L with 3s) & dance round
    3rd corner to 2nd place own sides.  (2)1 3
25-32::
    2s+1s dance 1/2 R&L, 1s dance 1/2 Fig of 8 round 2s.  1 2 3
33-40::
    1s turn 2s on sides 1.1/2 times (Ladies LH & Men RH) & turn 3s with
    other hand once round in 4 Couple set (1.1/2 times in 3 Couple set)', 0);
INSERT INTO 'dancecrib' VALUES (13412, '2020-12-02 01:20:16.441436+00', '2023-02-04 01:20:38.69396+00', 19157, 3, NULL, 'ace', '1-8::
    1s+2s turn partner RH; 1s+2s dance RH across
9-16::
    1s+2s circle 4H round & back
17-24::
    1s+2s dance LH across; 1s+2s turn partner LH
25-28::
    1s+2s Adv+Ret (1 step each) twice
29-32::
    Ladies lead across between partners & cross RH _while_ Men dance
    across & curve into partner''s place; Repeat to end 2 1

{{explanation}}
Note:	May also be danced in 3 couple set (S6x32)', 0);
INSERT INTO 'dancecrib' VALUES (5845, '2013-08-21 08:31:15.297115+00', '2023-02-04 01:20:38.704448+00', 8840, 3, NULL, 'ace', '1-8::
    1s dance down below 3s (2 steps), set, cast up 1 place (behind 3s),
    1/2 turn RH & face up
9-16::
    1s lead up to top, set, cast 1 place & turn LH to face 1st corners
17-24::
    Set to corner & petronella turn to face up/down _while_ corners set
    twice, 1s set & advance setting to face 2nd corners _while_ 1st
    corners change places RH & set
25-32::
    1s repeat with 2nd corners & 1s end turning RH to face up (Lady on
    Mans right)
33-40::
    1s dance 1/2 Fig of 8 round 2s dance 1/2 Fig of 8 round 3s
41-48::
    1s turn RH (4 bars) _while_ 2s & 3s chase clockwise 1/2 way &
    2s+1s+3s turn partners RH (4 bars)', 0);
INSERT INTO 'dancecrib' VALUES (12863, '2020-06-03 16:26:35.207968+00', '2023-02-04 01:20:38.964894+00', 3245, 3, NULL, 'ace', '1-8::
    1s set, cross & cast to 2nd place (2s step up bars 5-6), 1s cross RH
    to opp sides & face out
9-16::
    2s+1s+3s dance RSh reels of 3 on sides (1L down, RSh to 3L, 1M up,
    RSh to 2M ), to finish 1s end passing LSh to centre facing own sides
17-20::
    1s dance RH across (Man with 2s & Lady with 3s), 1s finish in 2nd
    place on opp sides (1M/1L facing down/up, 2L/3M facing down/up)
21-24::
    1M followed by 2L+2M & 1L followed by 3M+3L chase clockwise to
    finish 2s/3s in 3rd/1st place opp sides (3) 1 (2)
25-32::
    1s set, 1M casts up above 1st place, across the top, casts off to
    2nd place opp side _while_ 1L casts down below 3rd place, across the
    bottom, casts up to 2nd place opp side
33-36::
    1s dance LH across (Lady with 3s & Man with 2s), 1s finish 2nd place
    opp sides (1M/1L facing up/down, 2M/3L face up/down)
37-40::
    1M followed by 2M+2L also 1L followed by 3L+3M chase clockwise to
    finish 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14660, '2022-03-07 02:20:12.171232+00', '2023-02-04 01:20:39.0996+00', 20518, 3, NULL, 'ace', '{{explanation}}
2 chords - Men move into middle to finish back to back facing partners

1-8::
    All dance double reels of 4, passing partner RSh to begin & giving
    LH briefly in centre & end in original places
9-16::
    All dance Grand Chain giving RH to partner to begin, one step to
    each hand. (Chain is danced around perimeter, Men dance
    anticlockwise & finish beside partners)
17-20::
    All set & Petronella in Tandem one place anticlockwise.
21-24::
    All set & Petronella in Tandem, Men finish in middle beside partner,
    facing anticlockwise
25-30::
    All promenade 3/4 round set, finishing one place to right of their
    original place
31-32::
    All turn partner RH to finish Men back to back in the middle', 0);
INSERT INTO 'dancecrib' VALUES (9374, '2016-10-06 07:18:34.292837+00', '2023-02-04 01:20:39.267053+00', 17272, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH across
9-16::
    1s lead down middle & back to top crossing to opposite sides
17-24::
    1s cast below 3s & lead up middle crossing to own sides
25-32::
    1s cast to 4th place as 2s+3s+4s step up, all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (5849, '2013-08-21 08:31:15.544859+00', '2023-02-04 01:20:39.507696+00', 10299, 3, NULL, 'ace', '1-8::
    2s & 4s dance anticlockwise 1/2 way round set making arches as 1s &
    3s (prom hold) dance clockwise 1/2 way, all dance 1/2 double Ladies
    Chain
9-16::
    1M & 3M with ''new'' partner dance RSh reel of 3 with 4s _while_ 1L &
    3L dance RSh reel of 3 with 2s
17-24::
    All set to corners & change places RH, set to & 1/2 turn own partner
    2H
25-32::
    All circle 8H round & back All are now 1 place on anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (14119, '2021-07-07 00:19:53.985572+00', '2023-02-04 01:20:39.546591+00', 3266, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s cross LH & cast (1L up, 1M down)
    to 1L betwwen 2s facing down, 1M between 3s facing up
9-12::
    1L+2M & 1M+3L join NH, 1s dance clockwise round 2M/3L _while_ 2M/3L
    set turning about on the spot
13-16::
    1L+2L  & 1M+3M join NH, 1s dance anticlockwise round 2L/3M set
    turning about on the spot
17-24::
    1s cross passing LSh & repeat figure of 9-16 (1L dancing with 3M
    then 3L, 1M with 2L then 2M) 1s end in 2nd place own side
25-28::
    1s set advancing & 1/2 turn 2H (2 steps) & dance 4 slip steps to 3rd
    place remaining in center 2H joined _while_
::
    2s+3s dance 1/2 R&L (no polite turn)
29-32::
    1s 1/2 turn 2H & retire to 3rd place own side _while_
::
    3s+2s continue R&L.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5850, '2013-08-21 08:31:15.553177+00', '2023-02-04 01:20:39.574564+00', 10495, 3, NULL, 'ace', '1-6::
    1s dance down in front of 2s, behind 3s, in front of 4s & face out
    on own sides (2s, 3s & 4s step up as 1s pass in front/behind)
7-12::
    1s dance up behind 4s, in front of 3s, behind 2s & face in at 1st
    place (2s, 3s & 4s step down as 1s pass in front/behind)
13-16::
    All 4 couples turn partner RH
17-24::
    1s+2s 1/2 RH across, 1s+3s 1/2 LH across; 1s+4s 1/2 RH across, all
    cross RH
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5851, '2013-08-21 08:31:15.561396+00', '2023-02-04 01:20:39.604493+00', 13131, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 on own sides (between 2s to start)
    ending 1s & 3s in middle 1s facing down & 3s facing up
9-16::
    1s+3s dance R&L up/down ending in own places
17-24::
    1s cast 1 place to dance 1/2 Fig of 8 up round 2s & cross RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14556, '2022-01-17 17:00:16.459607+00', '2022-01-17 17:00:16.459607+00', 20632, 2, 1645, 'ace', '1-8::
  1W, 3M half turn and twirl. 1M, 3W repeat
9-16::
  2s repeat. All chase clockwise half way
17-24::
  Pickup chain (1s start)
25-32::
  3s, 2s chase clockwise half way. All turn partner BH (3s turn 1 ½  while 2s, 1s turn once round)
', 2);
INSERT INTO 'dancecrib' VALUES (8332, '2014-07-29 12:59:09.582643+00', '2023-02-04 01:20:39.640984+00', 15367, 3, NULL, 'ace', '1-8::
    1s cast & dance down behind own lines, turn outwards and dance back
    up to place
9-16::
    1s+2s+3s dance Reflection reels on own sides (1s in & down to start)
17-24::
    1s, followed by 2s, lead down the middle; 2s, followed by 1s, lead
    up    2 1 3
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5852, '2013-08-21 08:31:15.569613+00', '2023-02-04 01:20:39.677512+00', 9580, 3, NULL, 'ace', '1-8::
    1s lead down the middle followed by 2s; 2s lead to top followed by
    1s.  2 1
9-16::
    1s dance Fig of 8 up round 2s
17-24::
    2s dance Fig of 8 down round 1s
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5853, '2013-08-21 08:31:15.577849+00', '2023-02-04 01:20:39.700299+00', 14102, 3, NULL, 'ace', '1-8::
    1s cross RH & cast to 2nd place, cross LH & cast below 3s
9-16::
    1s lead up to top crossing & cast to 2nd place, 1s turn RH to end in
    Prom hold facing 3L.
17-24::
    1s dance 1/2 RSh reel of 3 with 1st corners & face 2nd corners; 1s
    dance 1/2 RSh reel of 3 with 2nd corners & end in 2nd place own side
25-32::
    1s set twice & turn RH _while_ 2s+3s cross RH & set, 2s+3s change
    places RH on sides & set. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5854, '2013-08-21 08:31:15.58637+00', '2023-02-04 01:20:39.732417+00', 13511, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s cross RH & 1M casts up to end between
    2s as 1L casts down to end between 3s
9-16::
    1s dance reels of 3 across giving LSh to 2nd corner & end LH joined
    facing 1st corners
17-20::
    1s set to 1st corners turning in to face 3rd corners & set turning
    clockwise to face 2nd corners
21-24::
    1s set to 2nd corners turning in to face 4th corners & set turning
    anticlockwise to face 1st corners
25-32::
    1s dance RH across (1L with 2s, 1M with 3s), pass RSh & dance LH
    across with other couple', 0);
INSERT INTO 'dancecrib' VALUES (12728, '2020-04-11 10:51:47.208116+00', '2023-02-04 01:20:39.764699+00', 9650, 3, NULL, 'ace', '1-8::
    All join hands on sides & set, all circle 8H 1/2 round to opp sides,
    & all set
9-12::
    1s+4s dance RH across to finish RHJ in centre, 1s facing down, 4s
    facing up
13-16::
    1s cross below 2s and cast up to 3rd place _while_ 4s cross above 3s
    and cast down to 2nd place own sides (2s & 3s step down/up 15-16)
17-24::
    2s+3s repeat bars 9-16 (1s & 4s step down/up 23-24)
25-32::
    1s NHJ dance up and cast to 4th place _while_ 4s+3s+2s set twice &
    turn partner RH
33-40::
    4s+3s+2s Allemande. End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12864, '2020-06-03 16:26:35.799018+00', '2023-02-04 01:20:39.797171+00', 3253, 3, NULL, 'ace', '1-4::
    1M+3L set, turning left about on bar 2, 1M+3L cast 2 places down/up
    (2M+3M also 1L+2L step up/down)
5-6::
    2M+2L set, turning left about on bar 6 to face out, _while_ 1M+3L
    cross the set to below/above 2L/2M & finish facing out
7-8::
    1M+2L take promenade hold & dance up Ladies'' side to finish 1M/2L in
    1st/2nd places _while_ 3L+2M take promenade hold dance down Men''s
    side to finish 3L/2M in 3rd/2nd places (1L/3M step down/up)
9-10::
    1M+2L drop RH, 1/2 turn LH to finish 2L/1M in 1st/2nd places facing
    in _while_ 3L+2M drop RH, 1/2 turn LH to finish 2M/3L in 3rd/2nd
    places facing out also 1L+3M set, turn left about to cast on bar 10
11-14::
    1s/3s take promenade hold dance up/down Ladies''/Men''s side to finish
    in centre in 1st/3rd places facing down/up NHJ _while_ 2s dance in
    on bar 11 & turn 3/4 LH to 2nd place own side (1) 2 (3)
15-16::
    1s+2s+3s set advancing to form circle
17-24::
    1s+2s+3s circle 6H round to right & back
25-32::
    1s+3s cross RH, 1s cast to 2nd place & turn LH to own sides (2s step
    up 27-28). End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5855, '2013-08-21 08:31:15.602126+00', '2023-02-04 01:20:39.853166+00', 9865, 3, NULL, 'ace', '1-8::
    1L+2s dances RH across & back _while_ 1M travels clockwise round
    2s+3s back to place
9-16::
    1L followed by partner casts down 2 places, crosses, casts up behind
    3M & in to face 2L _while_ 1M dances up between 3s to face 3L
17-24::
    1s dance RSh reels of 3 across set (Lady with 2s & Man with 3s)
25-32::
    1s dance out between 2L+3L, cast (Lady up & Man down), meet & turn
    to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (15073, '2022-09-05 00:20:19.271071+00', '2023-02-04 01:20:39.883591+00', 20911, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s dance 1/2 Figs 8, 1M up between
    2s, 1L down between 3s. 1M faces down, 1L faces up.  2 1 3
9-16::
    2s+3s dance full RSh reels of 3 on sides _while_ 1s dance 1/2 reel
    (1M RSh to 3M, 1L RSh to 2L); Bar 5: 1s cross diagonally passing
    RSh, 1M up to 2L place / 1L down to 3M place, 1M+2L & 1L+3M turn RH.
    1s end BtoB in centre 1M facing 2L, 1L facing 3M
17-24::
    1s dance 6 bars »Hello-Goodbye« setting finishing in 2nd place own
    side & all 3 couples set
25-32::
    All 1/2 turn partner RH, pull back RSh & dance out to opp sides; all
    set & cross RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15417, '2023-02-04 01:20:39.950389+00', '2023-02-04 01:20:39.952354+00', 18248, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back up to top. 2s & 3s step in ready for
    …
9-16::
    1s+2s+3s dance promenade
17-24::
    1s set, cast (2s step up); 1s turn LH to finish facing 1st corners
25-32::
    1s dance a 1/2 diag reel of 4 with 1st corners, pass RSh & dance 1/2
    diag reel of 4 with 2nd corners. 1s finish in 2nd place on opp
    sides. (3) (1) (2)
33-40::
    3s+1s+2s chase clockwise 1/2 round; all turn partner RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13619, '2021-02-04 01:20:15.81865+00', '2023-02-04 01:20:39.975444+00', 15246, 3, NULL, 'ace', '1-4::
    1s & 3s turn partner RH & cast (2s & 4s step up);
5-8::
    1M+4M+2L+1L also 3M+5M+4L+3L dance 1/2 diag R&L (no polite turns)
    _while_ 2M+5L set to each other
9-16::
    2M+4M+1L (at top) & 1M+5M+2L+3L (in middle) & 3M+5L+4L (at bottom)
    circle round to left & back
17-20::
    All repeat 5-8
21-24::
    All turn partner RH, 1s & 3s cast 1 place _while_ 4s & 5s dance up 1
    place _while_ 2s turn partner RH.  2 4 1 5 3
25-32::
    All circle 10H round & back.  End 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (11737, '2019-03-26 02:05:31.77693+00', '2023-02-04 01:20:39.997431+00', 19202, 3, NULL, 'ace', '1-8::
    1s & 3s set, cast 1 place & dance 1/2 figure of 8 round the couple
    below (1s round 4s & 3s round 5s).  2s & 4s step up on bars 3-4
9-16::
    1M+3L pass LSh into reel of 4 across with 4s to finish in the
    middle, 1M facing up, 3L facing down, _while_ 1L/3M dance across to
    turn 2L/5M LH, turn 2M/5L RH to finish facing partners in a line up
    & down the middle of the set, ready for …
17-24::
    Reel of 4, finish 1L facing up between 2s, partner following & 3M
    facing down between 5s, partner following.
25-32::
    1s & 3s dance up/down, cast to opposite sides, (2nd/4th place),
    cross RH & cast down another place (1s to 3rd place. 3s to 5th
    place).  4s & 5s step up on bars 31-32
33-40::
    All circle 10 hands round & back', 0);
INSERT INTO 'dancecrib' VALUES (5856, '2013-08-21 08:31:15.610421+00', '2023-02-04 01:20:40.036796+00', 8556, 3, NULL, 'ace', '1-8::
    1s set, cast to 2nd place & 2s+1s+3s dance 1/2 Grand Chain to end on
    opposite sides 3 1 2
9-16::
    3s+1s+2s set, 1s dance reels of 3 across (1M with 2s & 1L with 3s)
17-24::
    3s+1s+2s Set+Link for 3 twice
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12084, '2019-08-30 09:54:25.553297+00', '2023-02-04 01:20:40.070428+00', 19064, 3, NULL, 'ace', '1-8::
    2s+4s set advancing into middle BtoB facing own side & dance 6 bars
    of Double Triangles
9-16::
    2s+4s dance Corner Pass+Turn with 1st corners, pass RSh & dance
    Corner Pass+Turn with 2nd corners.  2s+4s end in 2nd/4th place opp
    sides
17-24::
    2s+4s cross up RH & cast 1 place; dance down 1 place & cast up to
    original places. 2s+4s face up, 1s+3s face down
25-32::
    1s+2s & 3s+4s set & 1/2 turn 2H on sides;  1s+4s & 3s+5s set & 1/2
    turn 2H on sides.  2 4 1 5 3
33-40::
    All circle 10H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9738, '2017-04-06 08:39:53.647536+00', '2023-02-04 01:20:40.092728+00', 3256, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up), 1s cross LSh, cast (1L up, 1M down) to
    face 4th corner
9-16::
    Reels of 3 across, 1L+2L & 1M+3M pass LSh.  Finish 1L between 2s
    facing down, 1M between 3s facing up
17-24::
    1s change places passing LSh, cast round corner to Right, cross
    passing RSh to BtoB facing 1st corners.  1s set to 1st corner, set
    to 2nd corner
25-32::
    Reels of 3 on sides (6 bars), 1s pass 2nd corner RSh to start.  1s
    cross RH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (13996, '2021-05-03 00:20:10.411619+00', '2023-02-04 01:20:40.120905+00', 20324, 3, NULL, 'ace', '{{explanation}}
Sets scattered around the room, 2 facing 2

1-8::
    All turn opposite person RH, finishing with polite turn to face
    partner on side; All turn partner LH, Men finish facing out
9-16::
    All dance Ladies'' Chain finishing facing partner
17-24::
    All dance DoSiDo with partner; all dance RH across, retain RH of opp
    person & take prom hold
25-32::
    Couples, with a new partner, promenade around the room and join
    another couple on bars 31-32 to start again', 0);
INSERT INTO 'dancecrib' VALUES (5857, '2013-08-21 08:31:15.618645+00', '2023-02-04 01:20:40.151403+00', 3257, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 2s
9-16::
    1s set (1 step) & petronella turn to left into centre (2 steps) to
    face each other,set (1 step) & turn RH to own sides in 2nd place
17-24::
    2s+1s+3s circle 6H round & back but remain in circle
25-32::
    2s+1s+3s PdB turning to left 1 place & dance RH across back to place', 1);
INSERT INTO 'dancecrib' VALUES (5858, '2013-08-21 08:31:15.628736+00', '2023-02-04 01:20:40.181122+00', 3267, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s
9-16::
    1s lead down the middle & back
17-24::
    1s+2s Promenade & 1s cast to 2nd place
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9070, '2016-01-13 11:33:25.564495+00', '2023-02-04 01:20:40.206607+00', 15828, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across & LH back
9-16::
    All circle 8H round & back
17-24::
    1s dance Fig of 8 round 2s as 4s dance Fig of 8 round 3s
25-32::
    1s lead down to bottom, all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (5859, '2013-08-21 08:31:15.63691+00', '2023-02-04 01:20:40.235969+00', 3261, 3, NULL, 'ace', '1-8::
    1s lead down for 3 bars & back to top, cross RH & cast to 2nd place
9-16::
    2s+1s dance Ladies Chain
17-24::
    1s dance 1/2 Fig of 8 round 2s, 2s+1s turn LH to face up in middle
25-32::
    2s & 1s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (5861, '2013-08-21 08:31:15.697608+00', '2023-02-04 01:20:40.282188+00', 13317, 3, NULL, 'ace', '1-8::
    1s slip-step down 4 steps & set, slip-step to top & set _while_ 2s &
    3s set turning left & slip-step across passing BtoB with partner &
    set turning left, slip-step back to own side.
9-16::
    1L followed by her partner casts 1 place & crosses, casts down round
    3M & dances up middle to end between 2s facing up as 1M ends between
    3s
17-24::
    All facing up slip-step to right & back with 2s+1L turning to right
    & 1s turn RH to 2nd place own side.
25-32::
    2s+1s+3s circle 6H round to left for 3 bars then pivot & circle back
    to places', 0);
INSERT INTO 'dancecrib' VALUES (13752, '2021-03-02 01:20:24.460182+00', '2023-02-04 01:20:40.309742+00', 13378, 3, NULL, 'ace', '1-8::
    1s set and 1/2 turn 2H (skip change); 1s dance down NHJ below 3s &
    cast up into centre 2nd place facing 1st corners (2s step up 5-6)
9-16::
    1s set and turn 1st corner 2H (skip change); set & turn 2nd corner
    2H (skip change)
17-18::
    1s 1/2 turn 2H (skip change) to face Men''s side (1L on 1M''s right),
    _while_ 2s & 3s set facing diagonally in
19-24::
    2s+1L also 1M+3s dance mirror reels of 3 across the set, 1L+2M pass
    RSh, 1M+3M pass LSh to start.  End 1L between 2s facing down, 1M
    between 3s facing up
25-32::
    Lines of 3 across set twice; 1s 1/2 turn RH & turn 3/4 LH to face
    Men''s side (1L in front of 1M)
33-40::
    1L followed by 1M dances out of Men''s side, casts down behind 3M,
    dances across the set & 1s end in 3rd place own side;  all 3 couples
    turn partner RH.  End 2 3 1

{{explanation}}
If danced as 4 couple set (J4x40) Bars 33-36: 1s cast to 4th place (3s+4s step up)', 0);
INSERT INTO 'dancecrib' VALUES (12397, '2019-12-05 01:30:28.684555+00', '2023-02-04 01:20:40.326574+00', 19411, 3, NULL, 'ace', '1-8::
    1s+2s dance the Knot
9-16::
    2s+1s Allemande Turn Right & chase clockwise 1/2 round. (1) (2) 3
17-28::
    1s+2s+3s dance R&L for 3 couples, 1s face out
29-32::
    1s cast (2s step up), 2s+1s cross RH wth partner. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5862, '2013-08-21 08:31:15.705927+00', '2023-02-04 01:20:40.34371+00', 13618, 3, NULL, 'ace', '1-8::
    All Adv+Ret, all dance DoSiDo
9-16::
    All turn RH, all turn LH
17-24::
    1s slip step down for 4 & back to top, 1s cast to bottom & 2s+3s
    step up
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5863, '2013-08-21 08:31:15.714262+00', '2023-02-04 01:20:40.358695+00', 3268, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across; 1s cast 1 place (2s dance up to top)  & 1s
    3/4 turn RH to end Lady between 2s & Man between 3s
9-16::
    1s dance 1/2 reels of 3 across giving RSh to 4th corner into 1/2
    reels of 3 on sides to end facing 1st corners
17-24::
    1s dance 1/2 RSh reels of 4 with 1st corners & 1/2 reel of 4 with
    2nd corners to end 2nd place own sides
25-32::
    2s+1s+3s dance Grand Chain', 0);
INSERT INTO 'dancecrib' VALUES (8529, '2015-02-13 12:47:21.91211+00', '2023-02-04 01:18:24.629628+00', 15601, 3, NULL, 'ace', '1-8::
    1s dance down middle. 1M dances below his partner & turns her under
    his L arm & 1s dance up to 2nd pl opp sides
9-16::
    2s+1s dance double Figs of 8 (2s cross down, 1s out & up)
17-24::
    1s dance reels of 3 on sides. (1s dance out & down to start) but 1s
    cross up from 3rd place to complete reels on own sides
25-32::
    1s+3s dance double Figs of 8. (1s dance & down, 3s cross up)', 0);
INSERT INTO 'dancecrib' VALUES (8376, '2014-07-31 07:48:39.33209+00', '2023-02-04 01:18:29.225021+00', 11196, 3, NULL, 'ace', '{{title}}
Strathspey

1-4::
    All Men dance RH across _while_ Ladies chase anticlockwise to
    opposite side
5-8::
    All Ladies dance LH across, _while_ Men chase clockwise to face
    partner on opposite side
9-12::
    All dance 1/2 Grand Chain to places (Men clockwise, Ladies
    anticlockwise)
13-16::
    All 1.1/2 turn RH to face in, with Lady on RHS of partner in
    original places
17-20::
    1s+3s dance 1/2 R&L _while_ 2s & 4s, facing across, set (HS)
21-24::
    2s+4s dance 1/2 R&L _while_ 1s & 3s, facing across, set (HS)
25-28::
    All Ladies petronella 1/4 turn to next place on their right, all set
29-32::
    All Men petronella 1/4 turn to next place on their right & with
    partner, all set
33-40::
    Repeat bars 25-32 to original places
41-48::
    All dance 1/2 Schiehallion Reel (2 places)
49-56::
    All promenade anticlockwise 1/2 round set, on bar 52 all release RH
    & Men lead partners to original places to face each other.  All set
    and turn BH into
57-64::
    All circle 8H round and back

{{explanation}}
Reel:	Repeat bars 1-64 above, except

17-24::
    HS step is replaced with pas de basque and balance
57-64::
    All circle 8H round to the left for 6 steps, pivot & chase back to
    places', 0);
INSERT INTO 'dancecrib' VALUES (4036, '2013-08-21 08:30:42.367328+00', '2023-02-04 01:18:29.242675+00', 183, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of 8 round 2s
9-16::
    1L dances full reel of 3 with 2s _while_ 1M dances 1/2 reel with 3s
    & 1/2 reel with 4s
17-24::
    1s dance LH across with 3s, 1s dance RH across (1L with 2s & 1M with
    4s)
25-32::
    1s pass LSh to dance 1/2 reel of 4 with 3s, turn RH to opposite
    sides _while_ 4s set advancing & 1s+4s dance RH across 1/2 way round
    to new places', 0);
INSERT INTO 'dancecrib' VALUES (13517, '2021-01-09 01:18:28.012033+00', '2023-02-04 01:18:29.768922+00', 17697, 3, NULL, 'ace', '1-8::
    1s+2s+3s Set & Rotate for 3 couples:
::
    Set & rotate singly & chase clockwise to form lines of 3 across (Men
    facing down & Ladies up)  all change places RH with partner & chase
    clockwise to own sides. 3 2 1
9-16::
    2s+1s dance Chain & Turn:
::
    _9-10_    2M+1L turn 3/4 RH to face 1M & 2L on diagonal
::
    _11-12_  1L+2L also 1M+2M change places LH, 2L+1M face each other in
    the centre
::
    _13-16_  2L+1M turn 1.1/4 RH to finish on own sides 3 1 2
17-24::
    1s dance 1/2 Fig of 8 round 2s, 3s+1s+2s turn RH into promenade hold
    (3s+2s facing up, 1s facing down)
25-32::
    3s+1s+2s dance Circulating Allemande:
::
    3s & 2s dance normal Allemande but end in 3rd/1st place as 1s
    Allemande (down) & up to 2nd place opposite sides
33-40::
    1s dance 1/2 Fig of 8 round 2s; All turn LH. End 2 1 3

{{explanation}}
Note: At end of 2nd time, on bars 35-36 1s dance down to 4th place while 4s step up', 0);
INSERT INTO 'dancecrib' VALUES (11199, '2018-09-30 22:19:58.097555+00', '2023-02-04 01:20:40.37737+00', 18573, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1M dances a 1/2 RSh reel of 3 across with 2s
    as 1L dances a 1/2 reel of 3 with 3s
9-16::
    1s dance 1/2 reel of 3 with 2s+3s on opp sides (LSh to 1st corner
    pstn), 1s dance 1/2 reel of 3 across (RSh to 4th corner pstn)  3 1 2
17-24::
    1M dances RH across with 2s _while_ 1L dances RH across with 3s, 1s
    change places & dance LH across with other couple
25-32::
    All turn partners 1/2 way RH, face partner & then  pull back RSh to
    dance out to opp sides & all chase clockwise 1/2 way to own sides', 0);
INSERT INTO 'dancecrib' VALUES (14690, '2022-03-07 02:22:17.13784+00', '2023-02-04 01:23:08.517731+00', 16609, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 3 facing 3

1-8::
    All set. Two outside dancers change places RH with person opposite
    then change places LH with oncoming person to finish one set in
    front of centre dancer. All set
9-12::
    Centre dancers dance RH across with 2 dancers on the right
13-16::
    Middle dancers pass RSh to dance an Interlocking 1/2 reel of 4 with
    opposite dancer & other 2 centre dancers in the set in front. Centre
    dancers finish beside original partners
17-24::
    All Adv+Ret & turn dancer opposite RH
25-32::
    All dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9349, '2016-10-06 07:18:04.08779+00', '2023-02-04 01:18:29.258041+00', 186, 3, NULL, 'ace', '1-4::
    1s, 3s & 5s cross RH, 1s cast 1 place(2s step up) as 5s cast up (4s
    step down)
5-8::
    1s+3s+5s dance 1/2 reels of 3 on opp sides (1s in/down, 3s up/out,
    5s up/in)
9-12::
    2s+4s cross RH, 2s cast down 1 place (5s step up) as 4s cast up (1s
    step down)
13-16::
    2s+3s+4s dance 1/2 reels of 3 on opp sides (2s in/down, 3s down/out,
    4s up/in)  (5) (4) (3) (2) (1)
17-24::
    All set twice, all turn partner 1.1/2 RH, 1s (in 5th place) retain
    hands, 5s+4s+3s+2s finish on own sidelines
25-28::
    1s lead up to top _while_ 2s+3s+4s+5s dance down sidelines to meet
    partners & dance up/out one place on own side
29-32::
    1s cast to 5th place _while_ 2s+3s+4s+5s set twice. End 2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (5864, '2013-08-21 08:31:15.810288+00', '2023-02-04 01:20:40.398243+00', 12402, 3, NULL, 'ace', '1-8::
    1s+2s+3s Promenade & end 1s cast to 2nd place as 2s dance up to top
9-16::
    2s+1s dance 1/2 double Fig of 8 (1s cross up to start, 2s cast),
    1s+3s 1/2 double Fig of 8 (1s cross down to start, 3s cast up) 1s
    end facing 3rd corners
17-24::
    1L+2s & 1M+3s dance 1/2 reel of 3 across, 1s face 3rd corner pstn.
    3s face out.  1s dance 1s 1/2 diagonal reel of 4 with 3rd corners &
    pass LSh to face 4th corners
25-32::
    1s dance 1/2 diagonal reel of 4 with 4th corners, pass RSh to 2nd
    place opp side & all chase clockwise to own side
33-40::
    1s+3s dance the Tournee :
::
    1s+3s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 3s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (3s RH, 1s LH) & dance
    out to places.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5865, '2013-08-21 08:31:15.818734+00', '2023-02-04 01:20:40.430877+00', 9574, 3, NULL, 'ace', '1-8::
    1s set, cross RH & face 2s on sides, 1s+2s set & change places with
    nearer hand (1s dancing out)
9-16::
    2s+1s+3s dance reflection reels (1s dancing in & down between 3s) &
    1s end facing 1st corners
17-24::
    1s dance 1/2 diagonal Reel of 4 with 1st corners then with 2nd
    corners
25-32::
    1s dance 1/2 diagonal Reel with 3rd corners then with 4th corners', 0);
INSERT INTO 'dancecrib' VALUES (5866, '2013-08-21 08:31:15.827139+00', '2023-02-04 01:20:40.46006+00', 12944, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s dance RH across (1M with 3s, 1L with
    2s) & end facing 1st corners
9-16::
    1s dance diag reel of 4 with 1st corners & pass RSh to face 2nd
    corners
17-24::
    1s dance diag reel of 4 with 2nd corners end 2nd place own sides
25-32::
    1s+3s Set+Link, 3s+1s dance RH across
33-40::
    1s+4s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 4th pl)
41-48::
    All circle 8H round & back  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13240, '2020-10-16 00:20:29.524814+00', '2023-02-04 01:20:40.480113+00', 13975, 3, NULL, 'ace', '1-8::
    1s+2s dance DoSiDo with partner; 1s+2s dance in & face up, join NH
    with partner, 1s cast to 2nd place, 2s dance up & loop into 1st
    place
9-16::
    1s+1st corners Adv+Ret; 1s+2nd corners Adv+Ret
17-24::
    1s pass LSh, dance RSh round 1st corner, pass LSh & dance RSh round
    2nd corner & 1s pass LSh to 2nd place own side facing out
25-32::
    Reels of 3 on sides, 1s pass 4th corner LSh to start (1M down, 1L
    up). End of reel 1s pull back RSh to dance into 2nd place.  End 2 1
    3
::
    Bars 31-32: 1s pass partner RSh, pull back RSh & into 2nd place own
    side (Optional)', 0);
INSERT INTO 'dancecrib' VALUES (15164, '2022-10-07 21:43:21.134099+00', '2023-02-04 01:20:40.503777+00', 21147, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Inveran reels (1s cross down to start, cross up to
    reel on own side from 3rd place). 1s+3s finish in middle NHJ with
    partner, 1s facing down, 3s facing up)
9-16::
    1s & 3s Set+Link; 1s+2s+3s chase clockwise 1/2 round. 3 (2) 1
17-24::
    2s+1s (bottom couples) Set+Link; 3s+1s+2s chase clockwise 1/2 round.
    2 (1) (3)
25-32::
    1s dance 1/2 Fig 8 (1L up, 1M down) to 2nd place own side _while_ 3s
    set & cross RH; 2s+1s+3s turn partner RH (or birl)', 0);
INSERT INTO 'dancecrib' VALUES (5867, '2013-08-21 08:31:15.835867+00', '2023-02-04 01:20:40.524781+00', 13601, 3, NULL, 'ace', '1-8::
    1s in prom hold dance reel of 3 with 2s giving RSh to 2M to start
9-16::
    1s followed by 2s dance down in prom hold for 4 bars, 2s+1s turn
    inwards & dance up 2s to top places
17-24::
    1s cross up LH to dance 1/2 double Fig of 8 with 2s, 1s cross down
    LH to dance 1/2 double Fig of 8 with 3s.  (2)(1)(3)
25-32::
    1s in prom hold dance reel of 3 across with 3s (RSh to 3L in 3M
    place) 1s ending BtoB in middle (1M facing up) in double triangle
    position
33-40::
    1s dance Double Triangles & 1s end dancing RSh round each other to
    face 1st corners (pstn)
41-48::
    1s dance 1/2 reel of 4 with 1st corners & pass RSh to face 2nd
    corners, 1s dance 1/2 reel of 4 with 2nd corners & cross RH to 2nd
    places.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5870, '2013-08-21 08:31:15.861038+00', '2023-02-04 01:20:40.591828+00', 3277, 3, NULL, 'ace', '1-8::
    1M+2L also 3M+4L set, pass RSh & turn to join LH, 1/2 turn & 1M & 3M
    dance RSh round 2M/3M to places as 2L & 4L RSh round 1L/3L to pls
9-16::
    1L+2M also 3L+4M repeat passing LSh at end to return to place
17-24::
    2s & 3s set & turn partner 2H to end in centre, 2s facing up & 3s
    down; 2s & 3s turn corners 1.1/2  to end on sides (2s & 3s dancing
    out through ends).  2 1 4 3
25-32::
    1s+4s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl). End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5871, '2013-08-21 08:31:15.86944+00', '2023-02-04 01:20:40.611912+00', 8355, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s RH across, 2s+3s 1/2 R&L
9-16::
    All RSh reels of 4 on sides
17-20::
    3M+2L & 3L+2M dance in Men passing Lady LH to change places, 2s & 3s
    lead out of ends, cross & cast in 1 place back to original places
21-24::
    2M+3L & 2L+3M dance in Men passing Lady LH to change places, 3s & 2s
    lead out of ends, cross & cast in 1 pl.  1 3(2)(4)
25-28::
    1L+3L cross passing partner LSh & cast to 3rd & 4th places _while_
    2L+4L cross passing partners LSh & dance up to 1st & 2nd places
29-32::
    1M+3M cross passing partner RSh & cast to 3rd & 4th places _while_
    2M+4M cross passing partners RSh & dance up to 1st & 2nd places.  2
    4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (7875, '2013-08-21 08:31:50.186657+00', '2023-02-04 01:23:08.544909+00', 7018, 3, NULL, 'ace', '{{explanation}}
Round the Room, 2 facing 2

1-8::
    All circle 4H round & back
9-16::
    Ladies dance DoSiDo & turn RH
17-24::
    Men dance DoSiDo & turn RH
25-32::
    All turn partners LH into prom hold & Promenade (Men passing LSh) to
    meet next couple', 0);
INSERT INTO 'dancecrib' VALUES (8533, '2015-02-13 12:47:24.069291+00', '2023-02-04 01:18:29.823349+00', 15604, 3, NULL, 'ace', '1-8::
    1s dance under arch made by 3s to change places, 1s & 3s turn corner
    persons with nearer hand
9-16::
    2s & 4s repeat bars 1-8
17-32::
    All repeat bars 1-16 back to places
33-40::
    All turn RH into Prom hold & dance 3/4 round anticlockwise, all turn
    partner RH.  End 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (13087, '2020-08-10 00:20:02.803313+00', '2023-02-04 01:20:40.629585+00', 17593, 3, NULL, 'ace', '{{explanation}}
2 chords: 2nd chord 3s & 4s cross to opp sides

1-8::
    1s+2s also 3s+4s Set & Rotate anticlockwise (set, cast Left 1 place
    anticlockwise, change places LH with partner & dance one place
    round)
9-16::
    2s+1s also 4s+3s dance LH across; 1s+4s dance RH across, 1M+4L on
    Men''s side & 1L+4M on Ladies'' side take prom hold
17-20::
    1M+4L+2s also 1L+4M+3s dance 1/2 RSh reels of 3 across. End 1M+4L in
    2nd place Ladies'' side facing down, 1L+4M in 2nd place Men''s side
    facing up
21-24::
    _1/2_ LSh reels of 3 on sides (2s & 3s dance loop into place at end
    to face clockwise).  3 4 (1) (2)
25-28::
    2s+3s chase clockwise 1/2 round _while_ 4s+1s circle 4H round to
    Right.  2 4 (1) (3)
29-32::
    All set, all cross RH. (2) (4) 1 3

{{explanation}}
Repeat from new places (top couples on opp sides) Promenade is with Lady on Man''s Left', 0);
INSERT INTO 'dancecrib' VALUES (5872, '2013-08-21 08:31:15.879613+00', '2023-02-04 01:20:40.657777+00', 14949, 3, NULL, 'ace', '1-8::
    1s+3s dance RH across & chase clockwise 1/2 way round the set
    _while_ 2s cast (2M up, 2L down), both cross & cast to each other''s
    places &  turn RH  (3) (2) (1)
9-16::
    2s dance down to bottom & cast up,  dance up (no hands) between top
    couple & cast to 2nd place opp sides (3) (2) (1)
17-24::
    All turn partners RH, 3s+2s cross RH with partner, 2s+3s change
    places passing LSh on sides
25-32::
    3s+1s dance Transverse Rondel:
::
    _25-27_   Couple on Ladies'' side make arch & change places with
    couple opposite, dancers cast away from each other & turn inwards to
    face up/down.
::
    _28-30_   1s (couple facing up) make arch & change places with 3s
    (couple facing down) 3s cross LH as they dance down
::
    _31-32_   3s cast up to 2nd place, 1s lead down & loop into 3rd
    place.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5873, '2013-08-21 08:31:15.887926+00', '2023-02-04 01:20:40.686621+00', 10298, 3, NULL, 'ace', '1-8::
    1s+2s dance Double Fig of 8 (1s crossing down)
9-16::
    1M+2M turn RH & 1L+2L turn LH 1.1/2 times (4 bars), 1s dance out own
    side, down behind 3s & cross up to 2nd place opposite sides
17-24::
    1s dance reels of 3 on opposite sides (1s out & up/2s in & down to
    start), 1s end crossing up to 2nd place own sides
25-32::
    1s dance reels of 3 on own sides (1s out & up to start), 1s end in
    centre facing up
33-40::
    1s dance up to top, cast to 2nd place & 2s+1s+3s turn RH

{{explanation}}
Original version: - 33-40  1s turn 2s with nearer hand (4 bars) & turn 3s with other hand (4 bars)', 0);
INSERT INTO 'dancecrib' VALUES (13241, '2020-10-16 00:20:29.756603+00', '2023-02-04 01:20:40.712964+00', 19517, 3, NULL, 'ace', '1-8::
    1s cast (2s step up) & set advancing to partner, 1s pull back LSh &
    1s+3rd corner turn 3/4 LH
9-16::
    1s+3s dance 3/4 R&L & set. 2 3 1
17-24::
    1s cast up to 2nd place (3s step down) & set advancing to partner;
    1s pull back RSh & 1s+4th corner turn 3/4 RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13753, '2021-03-02 01:20:24.886074+00', '2023-02-04 01:20:40.740643+00', 12286, 3, NULL, 'ace', '1-8::
    1s cast behind lines to bottom & turn outwards to dance back to top
9-16::
    1s turn RH & cast 1 place (2s step up 11-12); 1s turn 1.1/4 LH to
    face 1st corners
17-24::
    1s turn 1st corners RH, partner LH to finish facing 4th corners (1L
    facing 2L & 1M facing 3M); 1s turn 4th corners RH to finish in 2nd
    place, 1s cross LH to opposite sides & face out
25-32::
    1s dance 6 bar LSh reels of 3 on the sides (1M out/up, LSh to 2L, 1L
    out/down,  LSh to 3M), 1s cross to 2nd place own side (1M from 3L
    place & 1L from 1M place)', 0);
INSERT INTO 'dancecrib' VALUES (5874, '2013-08-21 08:31:15.894287+00', '2023-02-04 01:20:40.757662+00', 9866, 3, NULL, 'ace', '1-16::
    1s+2s+3s dance 3 couple R&L, all 4 couples turn RH to end in centre
    for Allemande (1s+2s facing up & 3s+4s on opp sides facing down)
17-24::
    1s+2s dancing up & 3s+4s dancing down dance Allemande with 1s & 4s
    passing each other to end 2 4 1 3
25-32::
    2s+4s also 1s+3s circle 4H round to left, all set on sides 3s+4s
    cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5875, '2013-08-21 08:31:15.902715+00', '2023-02-04 01:20:40.78607+00', 3281, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, LH back to end with 1s casting to 2nd place
9-16::
    1s dance 3H round & back (1L with 2s & 1M with 3s) 1s end facing 1st
    corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s lead down below 3s, cross to own sides, cast up, lead up between
    2s & cast to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5877, '2013-08-21 08:31:15.922731+00', '2023-02-04 01:20:40.905681+00', 3284, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 1s cross to 2nd place opp sides, 2s step up to top place own sides

1-8::
    _1-2_   1M+2L & 1L+2M in Allemande hold cross the dance, Men passing
    LSh, face down on Men''s side, up on Ladies'' side
::
    _3-4_   Lady turns under Man''s right arm, Man turns under own right
    arm, Lady turns left  under own left arm to face across set
::
    _5-8_   Repeat 1-4 back to places
9-16::
    2s+1s dance R&L
17-24::
    1s set HS, turn 2H & cast down to 3rd place (3s step up 23-24)
25-32::
    2s+3s+1s circle 6H round & back
::
    Repeat, 1s dancing with 3s.  Bar 23-24 1s cast 2 places to 4th
    place, return to own sides at start of new repeat.  New top couple
    cross to 2nd place opp sides bars 31-32', 0);
INSERT INTO 'dancecrib' VALUES (5878, '2013-08-21 08:31:15.930932+00', '2023-02-04 01:20:40.917076+00', 3285, 3, NULL, 'ace', '1-8::
    1s+2s turn RH, turn LH & end in centre in prom hold
9-16::
    1s+2s Promenade
17-24::
    1s dance down the middle & back up to 2nd place (2s step up 19-20)
25-32::
    2s+1s dance 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5879, '2013-08-21 08:31:15.939055+00', '2023-02-04 01:20:40.930507+00', 9577, 3, NULL, 'ace', '1-8::
    1s cross RH, cast to bottom & turn RH 1.1/2 times to own sides
9-16::
    All dance RSh reels of 4 on sides
17-24::
    2s+3s also 4s+1s circle 4H round & back
25-32::
    All set, cross RH, set & cross back LH
33-40::
    2s+3s also 4s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5880, '2013-08-21 08:31:15.949093+00', '2023-02-04 01:20:40.945245+00', 12887, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left & chase clockwise 1/2 way
9-16::
    1s+3s circle 4H round to left & chase clockwise 1/2 way
17-20::
    2s+3s cross RH, change places on sides LH with 2s dancing down to
    3rd place _while_ 1s set & cross up to 2nd place facing out opp
    sides
21-24::
    2s+1s+3s Bal-in-Line twice
25-32::
    1s dance 1/2 reel of 3 on opposite sides (RSh to 1st corner) ending
    between 2s/3s       & turn RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5882, '2013-08-21 08:31:15.971229+00', '2023-02-04 01:20:40.970567+00', 13419, 3, NULL, 'ace', '1-8::
    1L followed by partner casts 1 place & crosses up between 2s then 1L
    casts 1 place & crosses to end on own sides
9-16::
    1s+3s dance RH across, 1s+2s dance LH across
17-24::
    1L followed by partner casts 1 place & crosses up between 3s then 1L
    casts to 3rd place & crosses to end on own sides
25-32::
    1s dance reels of 3 on own sides (LSh to 3s)', 0);
INSERT INTO 'dancecrib' VALUES (4037, '2013-08-21 08:30:42.377733+00', '2023-02-04 01:18:29.27059+00', 188, 3, NULL, 'ace', '{{explanation}}
5s in centre, 5L facing down & 5M facing up

1-8::
    1s+2s+3s+4s circle 8H left 1/2 way & pivot left, chase back 1/4 way
    & set as 5s set & 1/2 turn RH, set & 3/4 turn LH to end 5M facing up
    to 4M (1st pl) & 5L faces down to 2M (3rd pl)
9-16::
    5s dance LSh reels of 3 with 4M+2L/2M+4L & 5s pass RSh to end 5M
    facing 1L (2nd pl) & 5L facing 3L (4th pl)
17-24::
    5s dance RSh reels of 3 with 1L+3M/3L+1M & 5s 1/2 turn LH to end Man
    facing up & Lady facing down
25-32::
    5M dances RH across with top cpl as 5L RH across with bottom cpl, 5s
    1/2 turn LH to face 1s (2nd pl) & change places RH (M with M etc)

{{explanation}}
Repeat from new positions', 0);
INSERT INTO 'dancecrib' VALUES (8535, '2015-02-13 12:47:24.72092+00', '2023-02-04 01:18:33.379824+00', 15643, 3, NULL, 'ace', '1-8::
    2s followed by 1s dance down (2 steps), turn partners 2H.  1s
    followed by 2s dance up, 1s+2s 1/2 turn (M Left hand, L Right hand)
    2 1 3
9-16::
    2s+1s+3s dance Diag R&L.  1s finish facing out in 2nd place  (3) 1
    (2)
17-24::
    3s+1s+2s dance RSh reels of 3 on sides (1M+3L & 1L+2M pass RSh to
    start)
25-32::
    3s+1s+2s dance clockwise 1/2 way round & turn partners 2H (1s turn
    1.1/2 times) Order:  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14661, '2022-03-07 02:20:13.582026+00', '2023-02-04 01:20:40.982326+00', 16876, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance, 2 facing 2, Lady on Man''s right, 1s face anticlockwise, 2s clockwise

1-8::
    1s+2s dance RH across & LH across
9-16::
    1s dance Fig 8 round the 2s
17-24::
    2s dance Fig 8 round the 1s
25-32::
    1s & 2s Adv+Ret, Advance again, 2s dancing under arch made by 1s to
    face next couple, 1L and 2L change places RH to join new partner

{{explanation}}
Repeat with new partner.', 0);
INSERT INTO 'dancecrib' VALUES (5883, '2013-08-21 08:31:15.98526+00', '2023-02-04 01:20:41.016623+00', 13393, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s turn LH 1.1/4 times to end facing 1st
    corners
9-16::
    1s dance LSh reels of 3 across (1L with 2s, 1M with 3s) & end BtoB
    in middle 1L facing up
17-20::
    2s+1s+3s set (Double Triangles) & 1s PdB to ends turning right about
    to face in _while_ 2s+3s PdB in turning right about to face up/down
21-24::
    2s+1s+3s set (Inverted Triangle formation) & 1s PdB in to face each
    other _while_ 2s+3s PdB to places
25-32::
    1s set turning 2H clockwise (1/4 turn each set) & dance out to own
    sides passing RSh', 0);
INSERT INTO 'dancecrib' VALUES (13413, '2020-12-02 01:20:18.223514+00', '2023-02-04 01:20:41.039656+00', 20145, 3, NULL, 'ace', '1-8::
    1s set, turn RH & cast (2s step up 7-8)
9-16::
    1s+2s+3s set, cross RH; set, cross LH
17-24::
    1L+2s & 1M+3s dance RH across; 1s pass RSh to dance LH across with
    other couple. 1s end in centre in 2nd place facing up NHJ
25-32::
    1s dance up, cast, dance down NHJ between 3s & cast up into 2nd
    place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5884, '2013-08-21 08:31:15.993486+00', '2023-02-04 01:20:41.057497+00', 3309, 3, NULL, 'ace', '1-8::
    2s petronella turn & set in lines of 3 across, petronella turn & set
    on opposite sides
9-16::
    2s dance reels of 3 on sides giving RSh to 2nd corner to start & 2s
    cross RH to own sides
17-24::
    1s lead down & back remaining in centre (bars 23-24: 2s step down to
    3rd place as 3s dance to 2nd place behind 1s)
25-32::
    1s+3s dance Allemande.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5885, '2013-08-21 08:31:16.001674+00', '2023-02-04 01:20:41.083067+00', 3310, 3, NULL, 'ace', '1-8::
    All Adv+Ret, turn partners RH with 1s & 4s end facing up & down set
9-16::
    1s & 4s advance (up/down set) & retire, turn corner person with
    nearer hand
17-24::
    1s lead down crossing RH below 3s& cast to bottom, 1s dance 1/2 Fig
    of 8 round 4s
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5886, '2013-08-21 08:31:16.00997+00', '2023-02-04 01:20:41.102039+00', 9867, 3, NULL, 'ace', '1-8::
    1s & 3s turn RH, cast to 2nd / 4th place, dance down between 4s / 5s
    & cast up 1 place to face 1st corners  2 1 4 3 5
9-24::
    1s & 3s dance Corner Chain with 1st & 2nd corners:
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end turning LH back to places
25-32::
    1s+4s & 3s+5s (bottom 4 couples) dance 1/2 R&L, set & cross RH to
    own sides  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (12398, '2019-12-05 01:30:29.14567+00', '2023-02-04 01:20:41.122526+00', 18606, 3, NULL, 'ace', '1-8::
    All dance Grand Chain
9-16::
    1s+3s in prom hold dance round each other (Men pass LSh) to opp
    sides; 1s+3s dance 1/2 R&L
17-24::
    2s+4s repeat 9-16
25-32::
    "Crescent Reels" across:
::
    1s+2L+4M also 3s+2M+4L dance reels of 4 across (1s+3s pass LSh to
    start)
33-40::
    "Crescent Reels" up/down:
::
    2s+1M+3L also 4s+1L+3M dance reels of 4 up/down set (2s+4s pass LSh
    to start)
41-48::
    All Set+Link; all turn corner 1.1/2 2H
49-56::
    All Advance with new corner (2 bars), Retire with person originally
    opposite (1M+3L, 2L+4M, etc); Ladies petronella turn into centre
    facing out & all set
57-64::
    All dance intersecting reels of 4 (LH across in centre)
65-72::
    Ladies continue 1/2 LH across to face partner _while_ Men set (2
    bars), all turn partner RH into prom hold facing clockwise (4 bars)
    & all promenade back to original places
73-80::
    All circle 8H round & back. Finish with Ladies in centre facing
    partner for bow/curtsey', 0);
INSERT INTO 'dancecrib' VALUES (5887, '2013-08-21 08:31:16.018358+00', '2023-02-04 01:20:41.169306+00', 3314, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, cross LH & cast (Man down, Lady up) &
    dance in to face 1st corners
9-16::
    1s change places RH with 1st corners & corner persons turn LH 1.1/2
    times to face diagonally opposite 1s, change places RH with 1s & 1s
    turn LH 1.1/4 times to face 2nd corners
17-24::
    Repeat bars 9-16 with 2nd corners but end 2nd place opposite sides
25-32::
    1s dance 1/2 reels of 3 on sides (LSh to 2nd corner pstn to start),
    2s+1s+3s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (3973, '2013-08-21 08:30:40.638282+00', '2023-02-04 01:18:24.674336+00', 14690, 3, NULL, 'ace', '1-8::
    All dance 6H round & back
9-16::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of 8 round 2s
17-24::
    1s dance Diag R&L (M down)
25-32::
    All Adv+Ret, 1s turn RH _while_ 3s & 2s turn RH 1.1/2 times to own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (13387, '2020-12-02 01:18:30.12123+00', '2023-02-04 01:18:29.283389+00', 19926, 3, NULL, 'ace', '1-8::
    1s dance LSh reel of 4 with corners (1L LSh to 4M & 1M LSh to 2L)
9-16::
    All chase clockwise round set back to places
17-24::
    All Men dance 2 steps into centre & dance out to next place on their
    right to face in; All Ladies repeat but stay facing out
25-32::
    All set turning right about to face partner, all dance DoSiDo with
    partner, all set turning left about (Ladies facing out, Men facing
    in)
33-48::
    All dance full Schiehallion Reel', 0);
INSERT INTO 'dancecrib' VALUES (4038, '2013-08-21 08:30:42.385921+00', '2023-02-04 01:18:29.295388+00', 190, 3, NULL, 'ace', '1-8::
    1s dance Inveran Reels with 2s+3s
9-16::
    1M+3L change places RH & cast to left to stand next to partner (1M
    with Lady on right & 3M with Lady on Left), 1s dance into centre
    facing down _while_ 3s into centre facing up, 1s dance down below
    arch made by 3s
17-24::
    1s+2s+3s circle 6H round & back
25-32::
    1s & 3s set facing down/up & dance RH across to original places, 1s
    & 2s set, turn 2H & end for the Rondel
33-40::
    1s+2s dance the Rondel', 4);
INSERT INTO 'dancecrib' VALUES (9007, '2015-11-30 08:59:55.229207+00', '2023-02-04 01:20:41.21992+00', 16535, 3, NULL, 'ace', '1-8::
    1s lead down (2s+3s step up 3-4), lead up to 3rd place & turn RH to
    face 3M with 1L following 1M
9-16::
    1s, 3M+2M, 4L+5L all in tandem, dance alternating tandem reel on
    diagonal (1s pass 3M+2M RSh).  1s end facing 4M, 1L following 1M
17-24::
    1s, 4M+5M, 2L+3L all in tandem, repeat 9-16 (1s pass 4M+5M LSh) 1s
    end in middle, 3rd place facing down NHJ (1L on Left of 1M)
25-32::
    1s dance down between 4s, cast behind 5s (4s+5s step up 27-28), 1s
    pivot turn (R elbow grip) & finish in 5th place    2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (5888, '2013-08-21 08:31:16.034559+00', '2023-02-04 01:20:41.250057+00', 3317, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, set turning to left to face own side & cast to
    left to form lines of 3 across
9-16::
    Lines advance for 1 step & retire, turn opposite person 2H & open
    out to circle 6H round to left
17-24::
    1s 3/4 turn RH, lead down, lead up crossing & cast to 2nd place own
    side
25-32::
    2s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (5889, '2013-08-21 08:31:16.042984+00', '2023-02-04 01:20:41.293307+00', 10229, 3, NULL, 'ace', '1-8::
    2s dance RH across (Lady with 1s & Man with 3s), pass RSh to dance
    LH across with other couple & end facing 1st corners
9-16::
    2s dance 1/2 diagonal reel of 4 with 1st corners, 3/4 turn LH to
    face 4th corners & dance 1/2 diagonal reel & 3/4 turn LH to face 3rd
    corners (pstn)
17-24::
    2s repeat bars 9-16 with 3rd & 2nd corners & end in middle on own
    sides facing down
25-32::
    2s followed by 1s dance down between 3s, 2s cast to 1st place & 1s
    followed by 3s dance up between 2s, 1s cast to 3rd place & 3s to 2nd
    place', 0);
INSERT INTO 'dancecrib' VALUES (7418, '2013-08-21 08:31:40.536649+00', '2022-01-17 12:01:12.894581+00', 5812, 2, NULL, 'ace', '*Note there is some doubt about the accuracy of the original instructions (for strathspey bars 13-16).*



{{title}}

Reel



1-8::

    Ladies dance RH across, Men dance LH across back to places

9-16::

    All pass partners LSh Men into centre LH across _while_ Ladies take

    RH of next Man (St Andrews Cross), all set, 1/2 turn ''new'' partners

    & dance back to places passing own partner RSh

17-24::

    All pass partners RSh Ladies into RH across _while_ Men take LH of

    next Lady, all set, 3/4 turn ''new'' partner & turn own partner RH

    into prom hold facing anticlockwise

25-32::

    All Promenade round anticlockwise



{{title}}

Strathspey



1-8::

    All set to partners & holding RH Men set again as Ladies dance under

    Mens arm, 1s+3s dance LH across ending in prom hold facing

    anticlockwise

9-12::

    1s+3s promenade 1/2 way _while_ 2s+4s dance RH across to end in prom

    hold facing clockwise

13-16::

    1s+3s set to partners & holding RH Men set again as Ladies dance

    under Mens arm _while_ 2s+4s promenade clockwise 1/2 way

17-20::

    1s+3s promenade anticlockwise 1/2 way & end facing in _while_ 2s+4s

    dance RH across ending in prom hold facing clockwise

21-24::

    1s+3s in prom hold advance & retire _while_ 2s+4s promenade

    clockwise 1/2 way

25-32::

    1s+4s also 3s+2s promenade round each other RSh, 1s+2s also 3s+4s

    promenade round each other LSh



{{title}}

Jig



1-8::

    Ladies dance a Figs of 8 round partner & corner (pass LSh round

    partner)

9-16::

    Men dance Figs of 8 round partner (pass RSh round partner) & all

    turn corners LH to face them holding RH

17-24::

    All set to corners & Men set again _while_ Ladies turn under Mens

    arms, all advance & retire

25-32::

    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9739, '2017-04-06 08:39:53.973518+00', '2023-02-04 01:20:41.32252+00', 16709, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up) & 1s dance 1/2 Fig 8 round 2s
9-16::
    2s+1s+3s dance mirror reels of 3 on sides taking hands (1s in/down,
    2s dance in & cast, 3s cast up)
17-24::
    1s lead down (2 steps), turn RH & lead up to top staying in centre,
    2s step down bars 19-20 & in behind 1s bar 24 ready for ...
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (12399, '2019-12-05 01:30:29.236965+00', '2023-02-04 01:20:41.351708+00', 19418, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up) & turn RH
9-16::
    1s+3s dance "Espagnole".  2 3 1
17-24::
    2s+3s+1s Set & Rotate for 3 couples
::
    Set & rotate singly & chase clockwise to form lines of 3 across (Men
    facing down & Ladies up) , all change places RH with partner & chase
    clockwise to own sides.`
25-32::
    3s+2s 1/2 turn partner RH, 3s+2s dance 1/2 RH across; 1s+2s 1/2 turn
    partner RH, 1s+2s dance 1/2 RH across.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5890, '2013-08-21 08:31:16.051664+00', '2023-02-04 01:20:41.375411+00', 3323, 3, NULL, 'ace', '1-8::
    1s Adv+Ret 1 step (touch RH) & cross LH, lead down RH 1 place & 3/4
    turn LH to face 1st corners
9-16::
    1s turn RH 1st corner & turn partner LH, turn RH 2nd corner then
    cross LH to 2nd place own sides
17-24::
    2L+1L+3L set, Adv+Ret & set _while_ 2M+1M+3M stand for 2 bars, set,
    Adv+Ret
25-32::
    2s+1s+3s cross RH, circle 6H round to left 1/2 way, cross LH &
    circle 6H round to right 1/2 way', 4);
INSERT INTO 'dancecrib' VALUES (12812, '2020-05-14 23:13:11.607196+00', '2023-02-04 01:18:24.695382+00', 19960, 3, NULL, 'ace', '1-8::
    1s dance in, cast to 2nd place (2s step up); 1s dance 1/2 reel of 3
    across (LSh to 1st corner to start). 2 (1) 3
9-16::
    All dance 1/2 RSh reel of 3 on sides (1M up, 1L down, RSh to 2nd
    corner pstn); 1s DoSiDo across _while_ corners DoSiDo on sides (pass
    LSh to start) (3) (1) (2)
17-24::
    1s petronella turn, set advancing passing LSh & dance 1.1/4 LSh
    round each other to 2nd place opp sides
::
    _while_ corners chase clockwise 1/2 round, pull back LSh & chase
    anticlockwise back to opp sides (3) (1) (2)
25-32::
    All Adv+Ret (1 step each), 3/4 turn partner 2H to line up/down in
    centre; all set to partner & 3/4 turn 2H to own side.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (8297, '2014-07-29 12:58:40.797977+00', '2023-02-04 01:18:24.715818+00', 15038, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides (6
    bars), 1s dance down the middle to face to face 3M in prom hold as
    2s dance up to 1st place
9-16::
    1s dance a diagonal RSh reel of 3 with 2nd corners to end facing
    Man''s 1st corner
17-24::
    1s dance a diagonal LSh reel of 3 with 1st corners
25-32::
    1s lead down, cross over below 3s, cast up to 2nd place, dance up
    between 2s & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (13385, '2020-12-02 01:18:26.23249+00', '2023-02-04 01:18:24.730607+00', 98, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    1L+2L cross LH, chase clockwise round standing Men back to place &
    set
9-16::
    1M+2M cross RH, chase anticlockwise round standing Ladies back to
    place & set
17-24::
    All circle 4H round & back
25-32::
    All dance DoSiDo with dancer opposite; all Adv+Ret (1 step each),
    drop hands, pass opposite dancer RSh & dance on to meet new couple', 0);
INSERT INTO 'dancecrib' VALUES (4040, '2013-08-21 08:30:42.403717+00', '2023-02-04 01:18:29.481849+00', 13620, 3, NULL, 'ace', '1-8::
    1s+2s set twice, 1s+2s dance RH across
9-16::
    1s+2s set twice, 1s+2s circle 4H round to left
17-24::
    1s cross RH & cast 1 place, 1s cross LH & cast down to 4th place
25-32::
    All turn RH, all turn LH', 0);
INSERT INTO 'dancecrib' VALUES (14662, '2022-03-07 02:20:14.002968+00', '2023-02-04 01:20:41.395019+00', 20396, 3, NULL, 'ace', '1-8::
    1s & 4s set & cross RH ; 1s & 4s cast in 1 place (2s & 3s step
    down/up) & Petronella turn into the middle
9-16::
    2s+1s also 4s+3s dance RH across; 1s & 4s finish in middle, Men
    facing down, Ladies up & dance 1/2 reel of 4 up/down the dance
17-24::
    2s+4s also 1s+3s dance RH across; 4s & 1s finish in middle, Men
    facing up, Ladies down & dance 1/2 reel of 4 up/down the dance.
    Finish 1s facing up, 4s facing down
25-32::
    1M followed by 1L dance RSh round 2L to 3rd place _while_ 4L
    followed by 4M dance RSh round 3M to 2nd place , all turn partners
    RH  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5891, '2013-08-21 08:31:16.060012+00', '2023-02-04 01:20:41.41824+00', 3326, 3, NULL, 'ace', '1-16::
    1s dance 4 progressive 1/2 reels of 2 across
::
    _1-8_   1s pass RSh to dance 1/2 reel with 2L then 1s pass LSh &
    dance 1/2 reel with 2M
::
    _9-16_ 1s pass RSh to dance 1/2 reel with 3L then 1s pass LSh to
    dance 1/2 reel with 3M.  (2) (3) 1
::
    (Supporting dancer in each 1/2 reel dances up sideline to begin
    reel)
17-24::
    1s turn RH & cast up to 2nd place on own sides, dance 1/2 Fig of 8
    around the 2s to 2nd place opposite sides
25-32::
    2s+1s+3s turn 3/4 RH to end in line in centre of dance facing
    partners (M facing down & L up) & set, 3/4 turn RH to end on own
    sides & set', 0);
INSERT INTO 'dancecrib' VALUES (8183, '2014-02-10 10:26:35.138026+00', '2023-02-04 01:20:41.440976+00', 15219, 3, NULL, 'ace', '1-8::
    1L+2L Set+Link as 1M+2M reverse Set+Link, 1s dance 1/2 figs of 8
    (Lady round 2s, Man round 3s) & end facing 1st corners
9-10::
    1s set to corners
11-12::
    1s dance RSh round each other into 3rd corner positions _while_ 1st
    crnr persons turn right about dancing into centre & twirl to face
    own orig positions
13-14::
    1s+3rd corner persons set
15-16::
    1s dance into centre & twirl to face 2nd corners _while_ original
    1st corners persons dance RSh round each other into each others
    original position
17-20::
    1s+2nd corners repeat bars 9-12
21-22::
    1s+2nd corner persons set
23-24::
    1s cast to 2nd place own sides _while_ original 2nd corners persons
    dance RSh round each other into each others original position.  (3)
    1 (2)
25-28::
    3s (at top) cross RH _while_ 1s+2s dance RH across 1/2 way, 3s+2s
    change places LH on sides _while_ 1s cross RH
29-32::
    All turn 2H.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5892, '2013-08-21 08:31:16.086586+00', '2023-02-04 01:20:41.474832+00', 3329, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast 1 place, cross LH to 2nd place own sides
    facing out
9-24::
    2s & 3s petronella turn into centre & set, _while_ 1M casts down as
    1L casts up & cross (M between 3s & L between 2s)
::
    2s & 3s petronella & set _while_ 1M casts up & 1L casts down & cross
    RH hand (to 2nd place own sides)
::
    2s & 3s petronella & set _while_ 1M casts up & 1L casts down & cross
    between 2s/3s
::
    2s & 3s petronella & set _while_ 1M casts down & 1L casts up & 1s
    turn LH to face 1st corners
25-32::
    1s turn 1st corner RH, partner LH, 2nd corner RH & cross LH to 2nd
    places own sides', 0);
INSERT INTO 'dancecrib' VALUES (9205, '2016-06-16 22:41:58.080179+00', '2023-02-04 01:20:41.627365+00', 11201, 3, NULL, 'ace', '1-8::
    1s+2s set, petronella-in-tandem 1/2 way round  (2) (1) 3
9-16::
    2s+1s+3s circle 6H round and back
17-24::
    Reels of 3 on sides, 1s pass 2s (at top) RSh
25-32::
    2s+1s dance 1/2 RH across, set & 1s cast to 2nd place & turn RH (2s
    step up (29-30))', 0);
INSERT INTO 'dancecrib' VALUES (9375, '2016-10-06 07:18:34.74093+00', '2023-02-04 01:20:41.654444+00', 17273, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s turn RH to face up in middle
9-16::
    1s dance reflection reels of 3 on opposite sides dancing up between
    2s to start
17-20::
    1s lead up between 2s crossing to own sides & cast to 2nd place
21-32::
    2s+1s+3s dance R&L for 3 couples', 0);
INSERT INTO 'dancecrib' VALUES (3974, '2013-08-21 08:30:40.648323+00', '2023-02-04 01:18:24.749611+00', 7421, 3, NULL, 'ace', '{{explanation}}
Note: 1st Lady has no partner

1-8::
    1L+2M set & turn RH, 1L+3M set & turn RH ending with 1L in middle
    between 3s
9-16::
    2s+3s+4s circle 6H round & back _while_ 1L sets (similar to
    Eightsome Reel) & ends facing 3M
17-24::
    1L dances 1/2 reel of 3 with 3s (RSh to 3M) & 1/2 reel with 4s (RSh
    to 4M)
25-32::
    1L dances down below 4s & casts up behind Ladies'' side to 1st place,
    sets & casts to 2nd place (2L steps up) _while_ 3s+4s set & cross RH
33-40::
    1L+2M dance down the middle & back to 2nd places
41-48::
    1L+2M cast to 4th places & 1L+2M also 3s & 4s turn RH

{{explanation}}
Repeat with 2L as dancing 1st Lady', 0);
INSERT INTO 'dancecrib' VALUES (3975, '2013-08-21 08:30:40.656464+00', '2023-02-04 01:18:24.777511+00', 100, 3, NULL, 'ace', '1-8::
    1s dance 1/2 reels of 3 on sides (1s in & down to start), 1M
    continues reel with partner behind him (dancing as one) _while_
    2L+3L set & 1/2 turn RH
9-16::
    1s dance RH across on own sides (1M with 2M+3M & 1L with 2L+3L) 1s
    changing sides for LH back but end with 1s in 2nd place own side
17-24::
    1s cast (1M down, 1L up) & turn LH to face 1st corner (pstn) _while_
    2s & 3s set, change places RH on sides, set to partner & cross RH
25-32::
    1s dance 1/2 diagonal reel of 4 on 1st corners & 1/2 diagonal reel
    with 2nd corners, 1s crossing RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5894, '2013-08-21 08:31:16.230885+00', '2023-02-04 01:20:41.678781+00', 3336, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All set to corners & turn RH, set to partners & turn LH
17-24::
    1s & 3s advance to centre & lead out through sides with opposite
    partner, cross & dance to opposite sides & turn partner RH 1.1/2
    times
25-32::
    2s & 4s repeat 17-24
33-40::
    All Ladies petronella one place to right & all set, Ladies
    petronella on to next place to right & set
41-48::
    All Men petronella one place to right & all set, Men petronella on
    to next place to right & set
49-64::
    All dance Grand Chain once round & dance Allemande anticlockwise
65-128::
    Repeat in Jig time', 0);
INSERT INTO 'dancecrib' VALUES (5895, '2013-08-21 08:31:16.239115+00', '2023-02-04 01:20:41.701655+00', 3337, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    All dance RH across & LH back to place
9-16::
    1s (dancers facing clockwise) cross between 2s to dance Fig of 8
    round 2s
17-24::
    2s cross between 1s to dance Fig of 8 round 1s
25-32::
    1s+2s Adv+Ret (raise arms and hooch), turn opp person 1.1/2 times to
    change places', 0);
INSERT INTO 'dancecrib' VALUES (5896, '2013-08-21 08:31:16.249261+00', '2023-02-04 01:20:41.736377+00', 3338, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, set & cross back RH
9-20::
    1s+2s+3s dance 3 couple R&L
21-24::
    1s cast 1 place on own side to end in diagonal line (RH with 1st
    corners & LH to partner)
25-32::
    2s+1s+3s dance the Spoke : Bal-in-Line with 1st corners, then with
    2nd corners, then with 3rd corners & 4th crnrs
33-40::
    1s dance 1/2 Fig of 8 round 1st corners LSh to meet in the centre &
    turn 1.1/2 times LH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5898, '2013-08-21 08:31:16.265653+00', '2023-02-04 01:20:41.781951+00', 3340, 3, NULL, 'ace', '1-8::
    1s+2s dance 4H round to left, 1s+2s+3s set & 1s cast to 2nd place,
    2s lead up & 3s dance small loop round to place (3M to right & 3L to
    left)
9-16::
    1s dance reels of 3 on sides dancing down between 3s to start
17-24::
    2s+1s dance double Fig of 8, 1s crossing up to start & end facing
    1st corners
25-32::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partner LH to
    end in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5899, '2013-08-21 08:31:16.273785+00', '2023-02-04 01:20:41.800125+00', 3342, 3, NULL, 'ace', '1-8::
    1L followed by partner casts to 2nd place opposite side & set
9-16::
    1M followed by partner casts up to original pstns & set
17-24::
    1s+2s dance RH across & LH back to places
25-32::
    1s+2s set, cross RH, set & cross back RH
33-40::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (5900, '2013-08-21 08:31:16.282034+00', '2023-02-04 01:20:41.830698+00', 3343, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back to places
9-16::
    1s lead down for 3 steps, back to top & cast to 2nd places
17-24::
    1s full Fig of 8 round 2s
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5901, '2013-08-21 08:31:16.290376+00', '2023-02-04 01:20:41.859599+00', 3345, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast & turn LH to face 2nd corner with LH joined
9-16::
    1s set to 2nd corner, turn inwards & set to 4th corner, set to 1st
    corner & set to 3rd corner
17-24::
    1s dance RSh reels of 3 across (Lady with 3s & Man with 2s) & turn
    RH to face 1st corner
25-32::
    1s dance LSh reels of 3 on sides & cross to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (5902, '2013-08-21 08:31:16.428308+00', '2023-02-04 01:20:41.891038+00', 7283, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, 1s dance down between 3s & cast back to 2nd
    place on own sides
9-16::
    2s+1s+3s turn RH & chase 1/2 way round clockwise
17-24::
    3s+1s+2s dance DoSiDo, set & 1/2 turn partners RH for Allemande
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (12643, '2020-03-02 01:52:56.141143+00', '2023-02-04 01:20:41.955115+00', 10832, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up), 1L+2s & 1M+3s dance RH across. 1s finish
    BtoB in middle, 1L facing up, 1M facing down.
9-16::
    1s set (as Double Triangles),1s cast to Right round 4th corner pstn
    into middle, 1L facing down, 1M facing up. 1s set as in Double
    Triangles.
17-20::
    1s cast to Right round 2nd corner pstn into 2nd place opp sides
    _while_ 2s+3s dance 1/2 R&L starting dancing up/down sides
21-24::
    1s dance 1/2 LSh reel of 3 on opp sides, LSh to 1st corner pstn (1M
    down, 1L up)
25-28::
    1s turn 3/4 LH, 1s cast to Right (1M down, 1L up) round 4th corner
    into 2nd place own side _while_ 2s+3s dance 1/2 R&L starting dancing
    up/down sides
29-32::
    1s dance 1/2 LSh reel of 3 on own sides (1M up, 1L down).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5903, '2013-08-21 08:31:16.436756+00', '2023-02-04 01:20:41.999616+00', 3351, 3, NULL, 'ace', '1-8::
    3s followed by 1s dance down the middle for 2 steps & turn partner
    2H, 1s followed by 3s dance up, 1s cast to 3rd place & 3s end at top
9-16::
    1s cross up to 2nd pl opp side, 1L+3M turn RH as 1M+3L turn LH end
    between 3s (at top), 1s dance down, 1L+2M turn RH as 1M+2L turn LH
17-24::
    3s+1s+2s set, 1s turn 2H 1.1/2 times & all set
25-32::
    3s+1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (13875, '2021-04-05 00:18:27.943059+00', '2023-02-04 01:18:29.512851+00', 20215, 3, NULL, 'ace', '1-8::
    _6_ bars Mirror reels of 3 on sides (2s in/up, 1s & 3s cast to
    start), 1s+2s pass to change places as 3s loop into place
9-16::
    1L+2s & 1M+3s dance RH across; all chase clockwise 1/2 round. 1s end
    in 2nd place own side facing down.  (3) 1 (2)
17-24::
    3s+1s+2s dance Grand Chain (3s cross RH, 1s+2s change places RH on
    sides to start)
25-32::
    All Adv+Ret; 3s & 2s set & cross RH _while_ 1s dance down below 3s &
    cast up to 2nd place.  3s & 2s face out', 0);
INSERT INTO 'dancecrib' VALUES (5904, '2013-08-21 08:31:16.446843+00', '2023-02-04 01:20:42.037618+00', 3352, 3, NULL, 'ace', '1-8::
    1s & 3s set & cross RH, 1s & 3s set & cross down to 2nd/4th places
    _while_ 2s & 4s cross RH & cast up 1 place.  (2) 1 (4) 3
9-16::
    2s+1s also 4s+3s dance double Fig of 8 (giving hands when crossing)
17-24::
    All dance reels of 4 on sides (RSh on Men''s side & LSh on Ladies)
    with 2s & 4s crossing down to start.  2 1 4 3
25-32::
    1s+4s+3s dance 1/2 reel of 3 on sides (RSh on Men''s side & LSh on
    Ladies) & all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (9206, '2016-06-16 22:41:58.325846+00', '2023-02-04 01:20:42.064455+00', 16849, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast & cross LH to 2nd place own sides facing out
    (2s step up 5-6)
9-16::
    1s cast, meet below 3s, dance up to top & cast to 2nd place
17-24::
    2s+1s+3s Adv+Ret.  1L+2s also 1M+3s dance RH across
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (8842, '2015-08-13 20:33:45.979434+00', '2023-02-04 01:20:42.090713+00', 13122, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to Left, turn partner 1/2 RH, pull back RSh
    dance out to partner''s place
9-16::
    1s face 2s on sides, Set & Rotate 1 2 3
17-24::
    1s cross down (no hands) & dance Fig 8 round 3s (2s step up 17-18)
    1s+3s turn on sides (Men''s side RH, Ladies'' side LH)
25-32::
    1s+3s dance Espagnole:
::
    _25-26_   1s+2s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _27-28_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _29-32_   2s turn RH as 1s turn LH', 0);
INSERT INTO 'dancecrib' VALUES (14290, '2021-09-08 00:20:19.067876+00', '2023-02-04 01:20:42.120961+00', 20357, 3, NULL, 'ace', '1-8::
    All chase 1/2 round clockwise to opposite side; 4s+3s & 2s+1s dance
    1/2 RH across & 1/2 turn partner RH.  (3) (4) (1) (2)
9-16::
    All repeat bars 1-8 back to original places
17-24::
    Ladies Adv+Ret & set twice _while_ Men set, Adv+Ret, set
25-32::
    1s cross RH below 2s (2s dance up to 1st place), cast behind 3s (3s
    step up), cross LH below 4s (4s dance up), all 4 couples set.  2 3 4
    1', 0);
INSERT INTO 'dancecrib' VALUES (5905, '2013-08-21 08:31:16.455269+00', '2023-02-04 01:20:42.159584+00', 9947, 3, NULL, 'ace', '1-8::
    2s & 4s set then turn 1/2 way RH & 2s end facing up & 4s face down,
    2s lead between 1s & cast to 2nd place opposite sides _while_ 4s
    lead down through 5s & cast to 4th place opposite side
9-16::
    All dance Double Tandem reels of 3 on sides: 1L+2M, 1M+2L, 4M+5L &
    4L+5M dance in Tandem
::
    3L passes 1L+2M LSh as 3M passes 4L+5L LSh to start & all end back
    where they started at bar 8
17-20::
    1L+2L+3L+4L+5L advance towards middle, join hands briefly & retire
21-24::
    Men repeat bars 17-20
25-32::
    All circle 10 hands left & back to place
33-40::
    1s+3s+5s Petronella to opposite side [All now on opposite sides (1)
    (2) (3) (4) (5)]
41-48::
    1s cast off to 5th place _while_ 2s+3s+4s+5s set on sides joining
    hands & cross up 1 place, all turn RH as 1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (8333, '2014-07-29 12:59:10.312088+00', '2023-02-04 01:20:42.177851+00', 15043, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on sides (1s in & down to
    start)
9-16::
    1s lead down for 3 bars, lead up to top (3 bars) and 1s cast to 2nd
    place & face down
17-20::
    1s+3s set, 1M+3M turn RH _while_ 1L+3L turn LH, 1s end facing up
21-24::
    1M+2M turn LH _while_ 1L+2L turn RH, 2s+1s+3s set
25-32::
    2s+1s+3s circle round & back', 0);
INSERT INTO 'dancecrib' VALUES (5906, '2013-08-21 08:31:16.463524+00', '2023-02-04 01:20:42.204247+00', 3358, 3, NULL, 'ace', '1-8::
    1s & 3s turn RH, cast 1 place, turn LH to give RH to 1st corner
9-16::
    1s & 3s Bal-in-Line with 1st corners, 3/4 turn LH to Bal-in-Line
    with 4th corners & turn LH to face own sides for…
17-24::
    1s & 3s dance Double Triangles ending in middle for…
25-32::
    1s+4s also 3s+5s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (5907, '2013-08-21 08:31:16.472321+00', '2023-02-04 01:20:42.223578+00', 7433, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH
9-16::
    3s+1s dance ''reverse'' Espagnole:
::
    3s+1s cross (Men between Ladies) with Men changing places LH, all
    cross back (Ladies between Men) with Ladies changing places LH, 3s
    turn LH as 1s turn
17-24::
    1s cross RH, cast up 1 place & turn LH 1.1/4 times
25-32::
    2s+1s+3s dance reels of 3 on own sides (1s give LSh to person on
    their Left)', 0);
INSERT INTO 'dancecrib' VALUES (13620, '2021-02-04 01:20:17.876776+00', '2023-02-04 01:20:42.278547+00', 16471, 3, NULL, 'ace', '1-8::
    1M+2L 1/2 turn RH, pull back RSh & dance out to change places &
    chase clockwise back to original places _while_
::
    1L+2M chase anticlockwise 1/2 round, 1/2 turn RH, pull back RSh &
    dance out to original places
9-16::
    1s+3s dance Double Fig 8 round 2s (1s cross down, 3s dance up to
    start)
17-24::
    1s lead down, cross below 3s & cast up to 2nd place opp sides (2s
    step up19-20); 1s lead up to top, cross & cast to 2nd place own side
25-32::
    2s+1s dance »Slip Knot«: As the Knot, but on last 2 bars couples
    dance LH across 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (11452, '2019-01-01 01:57:05.307579+00', '2023-02-04 01:20:42.482118+00', 18956, 3, NULL, 'ace', '1-8::
    2s+3s+4s turn partners RH, remain in middle, Ladies facing down, Men
    facing up.  4L followed by 3L & 2L dance down, cast up round 5M to
    end in order (4) (3) (2) on men''s side _while_ 1M followed by 2M &
    3M dance up, cast round 1L to end in order (4) (3) (2) on ladies''
    side
9-16::
    3s dance diag R&L with 4s+2s (3M up, 3L down).  3s finish facing out
    on opp sides
17-24::
    3s dance to Left to dance reel of 3 on sides (3L+4M+5M, 3M+2L+1L).
    Bars 23-24 3s cross LH to own sides _while_ supporting dancers
    complete the  reel.  1L finishes facing out.
25-32::
    1L casts 2 places _while_ 1M dances down middle 2 places (2s+3s step
    up 27-28).  1M casts down behind 4M+5M _while_ 1L dances down
    middle. 1s end in 5th place (4s+5s step up 29-30).  All set', 0);
INSERT INTO 'dancecrib' VALUES (5908, '2013-08-21 08:31:16.482418+00', '2023-02-04 01:20:42.507484+00', 14684, 3, NULL, 'ace', '1-8::
    1s dance down below 3s & cast up to 2nd place, 2s cast to 3rd place
    _while_ 1s+3s dance up to top & 1s cast to face 1st corners
9-16::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners ending in 2nd place opposite sides
17-24::
    3s+1s+2s chase clockwise 1/2 way & 1s dance 1/2 reels of 3 across
    (1M with 2s at top & 1L with 3s)
25-32::
    1s dance reels of 3 on sides (LSh to 1st corner) & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (9171, '2016-06-16 22:41:26.601457+00', '2023-02-04 01:18:24.80898+00', 16844, 3, NULL, 'ace', '1-8::
    1s+2s turn partners RH (4 bars) into RH across finishing 1s & 2s
    facing down
9-16::
    2s followed by 1s lead down, 1s followed by 2s lead back up staying
    in middle for ...
17-24::
    1s+2s dance allemande
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (4045, '2013-08-21 08:30:42.449448+00', '2023-02-04 01:18:29.549908+00', 10012, 3, NULL, 'ace', '1-8::
    All set & circle 6H to left (3 bars), dance in turning right about
    spiral out to chase on to places
9-16::
    All set & 2s petronella turn into centre, set & turn RH 1.1/4 times
    _while_ 1s+3s dance 3/4 R&L & all end facing down beside partners
17-24::
    1s followed by 2s+3s lead down & 3s lead back up.  3 2 1
25-32::
    3s+2s Allemande', 0);
INSERT INTO 'dancecrib' VALUES (12644, '2020-03-02 01:52:56.543819+00', '2023-02-04 01:20:42.535334+00', 13916, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s turn 1.1/2 LH
9-16::
    1M+2s at top & 1L+3s (at bottom) dance RH across, 1s in centre face
    own side & join LH; 1s set & dance out to 2nd place own side facing
    out
17-24::
    Reels of 3 on sides, 1s pass 4th corner LSh to start, at end 1s, 3M
    & 2L pull back RSh to flow into …
25-32::
    2s+1s+3s circle 6H round & back.  2 1 3

{{explanation}}
Note:  End of reel (bars 23-24) is "challenging" - if too difficult dancers should end reel as normal', 0);
INSERT INTO 'dancecrib' VALUES (5909, '2013-08-21 08:31:16.490737+00', '2023-02-04 01:20:42.558129+00', 3364, 3, NULL, 'ace', '1-8::
    1s 1/2 turn 2H, set to each other in centre, cross RH & cast 1 place
    to face 1st corners
9-12::
    1s 3/4 turn 1st corners 2H to face in diagonally (with corners on
    right of 1s) & 1s with corners set;
13-16::
    1s+corners drop hands, advance passing opposite person LSh, pull
    back LSh & dance LH across in centre. Corners dance back to place &
    1s face 2nd corners
17-24::
    Repeat with 2nd corners ending facing 3rd corners
25-32::
    1s dance reels of 3 across giving RSh to 3rd corners & end in 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (5910, '2013-08-21 08:31:16.504861+00', '2023-02-04 01:20:42.73671+00', 3365, 3, NULL, 'ace', '1-8::
    1M casts to 2nd place (2M step up), sets to 3L, turns RH & dances
    back to 2nd place on own side
9-16::
    1L casts to 2nd place (2L step up), sets to 3M, turns LH & dances
    back to 2nd place
17-24::
    1L with 2s & 1M with 3s dance RH across, 1s end in centre LH joined,
    1s set in centre & dance out to 2nd place on opposite sides
25-32::
    1M with 2s & 1L with 3s dance RH across, 1s end in centre LH joined,
    1s set in centre & dance out to 2nd place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (5911, '2013-08-21 08:31:16.513327+00', '2023-02-04 01:20:42.759575+00', 3366, 3, NULL, 'ace', '1-8::
    1s dance reflection reels on own sides (in & down to start)
9-16::
    1s cross down to 2nd place opposite sides as 2s dance out & up to
    1st pl, 1s turn 2nd corners LH & 1/2 turn partner RH to face 3L (L
    on Ms left)
17-24::
    1s dance RH across with 3L & LH across with 2M with 1s ending in
    BtoB in middle facing 4th corner
25-32::
    1s dance 1/2 diagonal reel of 4 with 4th corners & 1/2 diagonal reel
    with 1st corners with 1s 1/2 turning LH to face 2L (3M place)
33-40::
    1s dance RH across with 2L & LH across with 3M (1L place) with 1s
    ending in BtoB in middle facing 3rd corners (pstn)
41-48::
    1s dance 1/2 diagonal reel of 4 with 3rd corners & 1/2 diagonal reel
    with 4th corner (pstns), 1s end 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5912, '2013-08-21 08:31:16.521878+00', '2023-02-04 01:20:42.780912+00', 9869, 3, NULL, 'ace', '1-16::
    1M & 3M petronella turn into centre to face partners, set, dance
    reel of 4 up & down set & turn partners RH back to places
17-32::
    2M & 4M petronella turn into centre to face partners, set, dance
    reel of 4 across set & turn partners RH back to places
33-40::
    1L+4M also 3L+2M set adv towards each other & lead into centre, lead
    opp person out & dance round partner into diag lines (1s+4s facing
    2s+3s)
41-48::
    1s+4s also 3s+2s in diagonal line Adv+Ret, all turn partners LH back
    to places
49-56::
    Repeat bars 33-40 with 2L+1M & 4L+3M advancing
57-64::
    Repeat bars 41-48 on other diagonal with 1s+2s also 4s+3s advancing
    & turning partner LH back to places
65-80::
    Ladies dance RH across 1/2 way _while_ Men dance anticl''wise 1/4
    round, join LH with new Lady & set, repeat 3 times & meet partner
    turn LH to pls
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5913, '2013-08-21 08:31:16.531992+00', '2023-02-04 01:20:42.808436+00', 3368, 3, NULL, 'ace', '1-8::
    1L+2M also 4L+3M change places RH & set _while_ 2L+1M also 3L+4M set
    & change places RH, 2s+1s also 4s+3s dance RH across
9-16::
    All dance RSh reels of 4 on sides
17-24::
    All set advancing, turn partner 2H to own sides & 1s+4s+3s dance 1/2
    reel of 3 on sides (1s in & down to start)
25-32::
    2s+3s also 4s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5914, '2013-08-21 08:31:16.540199+00', '2023-02-04 01:20:42.875335+00', 3367, 3, NULL, 'ace', '1-8::
    1s set, cross down below 2s, cast down round 3s & dance up to 2nd
    places
9-16::
    1s dance reels of 3 on sides with each top couple crossing down to
    end (2) 1 (3)
17-24::
    2s+1s dance 1/2 double Fig of 8 (1s cast up to start), 1s+3s dance
    1/2 double Fig of 8 (1s casting)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8334, '2014-07-29 12:59:10.396661+00', '2023-02-04 01:20:42.891837+00', 14466, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L (starting RH on sides)
9-16::
    1s+3s dance double Fig of 8 round 2s (1s cast to start)
17-24::
    1s+2s turn 1.1/2 times on sides (out round 2s to start), 1s dance
    1/2 Fig of 8 round 2s
25-32::
    1s dance reels of 3 on opposite sides (1s in & down to start) &
    cross LH to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (9376, '2016-10-06 07:18:35.064436+00', '2023-02-04 01:20:42.912046+00', 17266, 3, NULL, 'ace', '1-8::
    1s set, cast, dance LSh round 1st corners to finish BtoB in centre
    facing opposite sides
9-12::
    2s+1s+3s set (as in Double Triangles), 1s PdB out & turn about to
    face in _while_ 2s+3s PdB in & turn about to face out
13-16::
    2s+1s+3s set (Inverted Double Triangle). 1s set rotating in place to
    face clockwise _while_ 2s+3s dance round partners to 1st/3rd place
    opp sides facing clockwise  (2) (1) (3)
17-24::
    2s+1s+3s chase 1/2 way round to own sides & turn partners RH into
    promenade hold facing up
25-32::
    3s+1s+2s dance Allemande   2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13997, '2021-05-03 00:20:13.148011+00', '2023-02-04 01:20:43.433591+00', 17383, 3, NULL, 'ace', '1-8::
    1L sets & casts (2L steps up); 1L dances LSh round 3L back to 2nd
    place _while_ 1M sets & casts (2M steps up)
9-16::
    2s+1s+3s dance reels of 3 on sides (1M down, RSh to 3M, 1L up, RSh
    to 2L). 2L faces out
17-24::
    1L+2s dance RH across _while_ 1M dances RSh round 3M; 1L+3s & 1M+2s
    dance LH across
25-32::
    2s+1s+3s Adv+Ret; all turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (5915, '2013-08-21 08:31:16.56235+00', '2023-02-04 01:20:43.149336+00', 12121, 3, NULL, 'ace', '1-8::
    1L sets to 2M as 4L sets to 3M & 1L & 4L cast in 1 place as 2M & 3M
    cast to ends, all cross & set with partners, turning Ladies in to
    face partners on diagonal on 2nd setting step (Men at corners)
9-16::
    All dance two interlocking diagonal reels of 4 giving LH briefly in
    centre.
17-24::
    All Ladies (in middle) dance1/2 R&L, top & bottom couples dance1/2
    R&L.
25-32::
    All Men (in middle) dance1/2 LH across, all Men take promenade hold
    with partners & dance anticlockwise round the set for 3 places
33-40::
    The 2 dancers at end of Men''s line set to 2 dancers in middle of
    Ladies'' line & all cast & cross then set in pairs
41-48::
    Top & bottom 2 couples dance "Transverse Rondel":
::
    Couples on Ladies'' side make arch & change places with couples
    opposite, cast up/down (do not cross) & turn to face up/down
::
    Couples facing up (1s+3s) make an arch & change places with couples
    facing down, those dancing under the arch cross & cast up, those
    making the arch lead down  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (5916, '2013-08-21 08:31:16.74399+00', '2023-02-04 01:20:43.374635+00', 3373, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, 2s+1s+3s set & cross RH
9-16::
    1s cross RH, 1L casts up to end between 2s facing down _while_ 1M
    casts down to end between 3s facing up, all set, 1s turn RH to face
    1st corners (pstn) _while_ 2s+3s change places RH on sides
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass LSh to face
    2nd corners (pstn) & dance 1/2 reel of 4 with 2nd corners 1s ending
    2nd pl opp sides
25-32::
    1s advance passing RSh, about turn to face partner & retire to own
    side _while_ 2s & 3s dance DoSiDo, 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5917, '2013-08-21 08:31:16.75252+00', '2023-02-04 01:20:43.401194+00', 13765, 3, NULL, 'ace', '1-8::
    1s & 3s dance down to 2nd/4th place & face out (own side) & dance
    double triangles to end facing out opposite sides
9-16::
    1s & 3s 1/2 diagonal reels of 4 with 1st corners & pass RSh to face
    2nd corners, 1s dance 1/2 diag reel with 2nd corners & end 2nd/4th
    places opp side
17-24::
    1s & 3s dance diag R&L (1M/3M crossing down & Ladies up to start).
    2(1)4(3)5
25-32::
    1s & 3s cross LH & cast 1 place, 1s & 3s turn RH.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (13242, '2020-10-16 00:20:32.068786+00', '2023-02-04 01:20:43.472787+00', 19204, 3, NULL, 'ace', '1-8::
    1s lead down (2s step up 3-4); 1L dances under 1M''s arm to change
    sides & 1s lead back to 2nd place opp sides. 2 (1) 3
9-16::
    _1/2_ mirror reels of 3 on sides (1s out/up to start); 3s+2s 1/2
    turn RH remaining in centre, 3s facing down, 2s facing up & all 3
    couples set
17-22::
    1s Petronella turn & set; Petronella turn to 2nd place own side
    _while_
::
    3L & 2M pull back RSh & chase clockwise 1/2 round to opposite end
    _while_
::
    3M & 2L Petronella turn to 2nd place, set; Petronella turn to join
    NH with partner (Lady on Man''s left)
23-24::
    All 3 couples set
25-32::
    All repeat 17-24 from new places to end as bar 16 (All on opp sides,
    3s in centre 1st place, 1s in 2nd place on sides, 2s in 3rd place in
    centre)
33-36::
    1s dance out/up to top, cross & dance down to 2nd place own side
    _while_
::
    2s cross & cast up to 1st place _while_
::
    3s cross down (in front of 2s) & cast down to 3rd place
37-40::
    2s+1s+3s turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (5918, '2013-08-21 08:31:16.762418+00', '2023-02-04 01:20:43.500082+00', 3377, 3, NULL, 'ace', '1-16::
    1s+2s+3s dance 3 couple R&L, all 4 couples turn RH, 1s+2s end facing
    up in the middle & 3s+4s end facing down
17-24::
    1s+2s dance an Allemande as 3s+4s dance an Allemande (down) but
    leading couple (1s & 4s) pass LSh to end 2 4 1 3
25-32::
    2s+4s also 1s+3s circle 4H round to left, all set on sides & 3s+4s
    cross to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5919, '2013-08-21 08:31:16.772563+00', '2023-02-04 01:20:43.536255+00', 3378, 3, NULL, 'ace', '1-8::
    1s & 4s set, 1M+4L advance, turn RH & dance back to place
9-16::
    1s & 4s set, 1L+4M advance, turn RH & dance back to place
17-24::
    2s+3s dance RH across 1/2 way, set, dance LH across 1/2 way & set
25-32::
    All dance reels of 4 on sides
33-40::
    1s lead down middle & back
41-48::
    1s cast 2 places _while_ 2s+3s dance up, 1s cross RH, cast to bottom
    & cross LH', 0);
INSERT INTO 'dancecrib' VALUES (5920, '2013-08-21 08:31:16.780953+00', '2023-02-04 01:20:43.571445+00', 7774, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place to face 3rd corners, 1s dance 1/2
    diagonal reel of 4 with 3rd corners
9-16::
    1s dance 1/2 diagonal reels of 4 with 4th corners (1s end own
    sides), 1s cross RH & cast 1 place
::
    (1s now repeat 1/2 diagonal reels with couples in 3rd & 4th place
    acting as corners):-
17-24::
    1s dance 1/2 diagonal reel of 4 with ''new'' 3rd corners, 1s dance 1/2
    diagonal reel of 4 with ''new'' 4th corners (3)(4) 1 2
25-32::
    1s+2s dance 1/2 R&L, 4s+2s dance 1/2 R&L (3) 2 4 (1)
33-38::
    3s+2s dance 1/2 R&L, 2s & 1s cross RH', 0);
INSERT INTO 'dancecrib' VALUES (5921, '2013-08-21 08:31:16.789243+00', '2023-02-04 01:20:43.598582+00', 3381, 3, NULL, 'ace', '1-8::
    1L+2M set, change places RH & dance behind partners back to places
9-16::
    1M+2L set, change places LH & dance behind partners back to places
17-24::
    1s+2s dance double Fig of 8 (1s cross down to start) ending in
    middle
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (5922, '2013-08-21 08:31:16.79753+00', '2023-02-04 01:20:43.630259+00', 13725, 3, NULL, 'ace', '1-8::
    1s cast off 1 place & dance 1/2 Fig of 8 through 2s & turn LH to
    face 1st corners
9-16::
    1s turn 1st corners RH, change places in middle LH, turn 3rd corner
    RH & turn each other 3/4 LH to face 2nd corners
17-24::
    Repeat 9-16 with 2nd corners & end facing 2nd corners
25-32::
    1s dance RSh Reels of 3 on opp sides (RSh to 2nd corners) 1s cross
    to own sides in 2nd place facing out ready to start again (or cast
    to bottom)', 0);
INSERT INTO 'dancecrib' VALUES (5923, '2013-08-21 08:31:16.814055+00', '2023-02-04 01:20:43.657656+00', 11750, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, chase anticlockwise 1/2 way & 1/2 turn partners into
    prom hold
9-16::
    3s+2s+1s Promenade ending with 3s casting to original places _while_
    2s dance up to 1st place & 1s remain in centre
17-24::
    1s lead up (LH), cross & cast to 2nd place opposite sides, cross
    down between 3s & cast up to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12143, '2019-09-02 21:08:41.389165+00', '2023-02-04 01:20:44.282561+00', 19605, 3, NULL, 'ace', '1-8::
    1s & 4s set then cast in 1 place, 1s & 4s dance RH across
9-16::
    1s+2s & 4s+3s dance LH across, 1s & 4s set then cross RH
17-24::
    All dance reels of 4 on the sides
25-32::
    1s+4s dance 1/2 R&L, all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4977, '2013-08-21 08:30:58.409282+00', '2023-02-12 16:02:56.931088+00', 1624, 3, NULL, 'ace', '1-8::

    1s cast 1 place & cross RH, cast up on opposite side & cross back LH

9-16::

    2s cast up & cross RH, cast down 1 place & cross back LH

17-24::

    1M in prom hold with partner (Lady on Man''s right) dance down behind

    2M (who steps up) & 1M leaves 1L in 2nd place (opposite side), 1M

    1/2 turns 2L RH to end on Ladies'' side with 2L on his right

25-32::

    1M+2L lead across between 1L+2M & cast round own partner & return to

    Ladies'' side, 1M+2L turn RH to face partners

33-40::

    1s dance 1/2 Fig of 8 round 2s & turn RH to end in 2nd place own

    sides', 0);
INSERT INTO 'dancecrib' VALUES (4046, '2013-08-21 08:30:42.457596+00', '2023-02-04 01:18:29.560401+00', 197, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp. sides

1-8::
    1L dances in & followed by partner casts 1 place, crosses down to
    4th place Men''s side, up behind 3L, crosses up to own place & 1M to
    his place _while_ 4L dances in & followed by partner casts up behind
    3L, crosses up to 1L place, down behind 2L, crosses to original
    place & 4M to his place
9-16::
    All dance reels of 4 on sides, at end 2s & 3s do not pass but curve
    round so that 3s face up in 2nd place & 2s face down in 3rd place
17-24::
    1s+3s also 2s+4s set twice on sides, all turn twice round to right
    in Tulloch hold
25-32::
    1s+3s also 2s+4s set on sides & dance 3/4 double Fig of 8 (1s
    crossing down & 4s crossing up to start).  3 1 (4)(2)', 0);
INSERT INTO 'dancecrib' VALUES (5924, '2013-08-21 08:31:16.822429+00', '2023-02-04 01:20:43.671615+00', 3387, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance 1/2 Fig of 8 round 2s
9-16::
    1s dance reflection reels of 3 on sides (1s in & down between 3s to
    start)
17-24::
    1s dance RH across (Man with 2s & Lady with 3s) & LH across with
    other couple & end facing 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (8598, '2015-02-13 12:47:55.137049+00', '2023-02-04 01:20:43.702058+00', 15690, 3, NULL, 'ace', '1-8::
    1M+2L 3/4 turn RH & turn about into BtoB (2L facing up) _while_
    partners dance anticlockwise to face own partner, 1s+2s set & 3/4
    turn partner RH
9-16::
    1s pass RSh & turn 1st corner RH, passing RSh turn 2nd corner RH to
    end 2nd place opposite sides.  2 (1) 3
17-24::
    2s+1s+3s Set+Link for 3 twice.  (3) 1 (2)
25-32::
    1s dance diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (5925, '2013-08-21 08:31:16.854489+00', '2023-02-04 01:20:43.730242+00', 10897, 3, NULL, 'ace', '1-8::
    1M+3L 3/4 turn RH & cast behind 2s to orig place _while_ 1L+3M cast
    & 3/4 turn RH back to place, 1s+2s dance RH across _while_ 3s+4s LH
    across
9-16::
    1M+3L again turn RH & cast to place _while_ 1L+3M cast & turn RH to
    place, 1M+2L also 3L+4M change pl RH, 1L+2M also 3M+4L change pl RH
17-24::
    2s+1s also 4s+3s circle 4H round & back
25-32::
    All set, 2s & 3s cross RH _while_ 1s+4s dance 1/2 RH across & all
    turn partners RH.   2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13621, '2021-02-04 01:20:19.120851+00', '2023-02-04 01:20:43.765208+00', 16472, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp side

1-8::
    1s & 4s turn partner RH, cast down/up 1 place (2s & 3s step
    up/down); 1s+4s dance LH across, end 1s facing up, 4s facing down
    LHJ
9-16::
    1s/4s lead up/down, cross & cast out of ends to 2nd/3rd place. 2 (1)
    4 (3); 1L+4M & 1M+4L turn RH into prom hold facing out
17-24::
    Reels of 3 on sides (as »Bees of Maggieknockater«):
::
    Couples in prom hold dance 1/2 RSh reel of 3 (RSh to dancer on
    right); couples meet partners, take prom hold & dance 1/2 LSh reel
    of 3 on sides (LSh to dancer on left).  End 4s BtoB in 2nd place, 1s
    BtoB in 3rd place
25-32::
    4s & 1s turn corner NH & end NHJ with partner, 4s facing down, 1s
    facing up; 4s+1s Set+Link to end on sides 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (5926, '2013-08-21 08:31:16.862868+00', '2023-02-04 01:20:43.789423+00', 3389, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across 1/2 way, 1s+4s dance LH across 1/2
    way, 2+4s also 1s+3s dance RH across right round
9-16::
    All set & cross RH, 1s+4s dance 1/2 R&L.  2 1 4 3
17-24::
    2s+4s petronella turn into middle _while_ 1s & 3s step up, all set,
    all petronella turn & set
25-32::
    1s+3s dance 1/2 reel of 4 in middle into 1/2 reel of 4 across (3s
    with 2s & 1s with 4s) all giving RSh to same sex ending 2 3 4 1
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5927, '2013-08-21 08:31:16.897873+00', '2023-02-04 01:20:44.003012+00', 3390, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across 1/2 way, set & cross back RH
9-16::
    2s+1s+3s set, cross RH, 1s cast down below 3s & dance up to 2nd pl
    (in centre) _while_ 2s+3s set & change places on sides (Men RH &
    Ladies LH)
17-24::
    3M+1M+2M dance RH across _while_ 3L+1L+2L dance LH across, wheels
    continue as 1s followed by 2s & 3s change places to dance round on
    own sides & end with 1s followed by 2s & 3s facing up into prom hold
25-32::
    1s+2s+3s Promenade ending with 1s casting down to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (13243, '2020-10-16 00:20:32.610193+00', '2023-02-04 01:20:44.180052+00', 8335, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up); 2s+1s+3s set, 2s+3s set again as 1s
    Petronella turn to 1L between 2s facing down, 1M between 3s facing
    up
9-16::
    All set in lines of 3 across, 2s+3s set again as 1s Petronella turn
    to face 1st corners; 1s+1st corners dance 1/2 diag reel of 4, 1s
    pass RSh to face 2nd corners
17-24::
    1s+2nd corners dance 1/2 diag reel of 4; 1s dance RSh round partner
    to 2nd place own side.  (3) 1 (2)
25-32::
    3s+1s+2s chase clockwise 1/2 round; all turn partners RH (1s turn
    1.1/2 RH).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5928, '2013-08-21 08:31:16.906252+00', '2023-02-04 01:20:44.208935+00', 13743, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set+Link & end facing link person, all turn RH into
    St Andrews cross (1s+4s in Middle LH across)
9-16::
    All dance the Spoke:
::
    1s+4s Bal-in-Line with corners & dropping RH move anticlockwise to
    repeat with 2nd, 3rd & 4th crnrs & end between 2s/3s
17-24::
    1s & 4s dance Tandem reels of 3 across (Men leading) with 2s/3s &
    pass RSh to end 4s facing up between 2s & 1s facing down between 3s
25-32::
    4s & 1s turn 2s/3s with nearer hands into 2nd/3rd places, 4s & 1s
    turn partners RH 1.1/2 times to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13306, '2020-11-02 01:20:24.689146+00', '2023-02-04 01:20:44.240409+00', 20009, 3, NULL, 'ace', '1-8::
    1s dance RSh round partner back to place & face out; 1s cast (2s
    step up) to face 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting ending with Petronella turn to 2nd
    place own side
17-24::
    1L+2s & 1M+3s dance reels of 3 across (LSh to 1st corner to start).
    1s end in 2nd place, 2s & 3s loop into place & all face clockwise
25-32::
    2s+1s+3s chase clockwise round.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5930, '2013-08-21 08:31:16.94791+00', '2023-02-04 01:20:44.350887+00', 3396, 3, NULL, 'ace', '1-8::
    2s & 4s cast up 1pl _while_ 1s & 3s petronella turn into middle &
    all set, all petronella turn (1s & 3s onto sides & 2s & 4s into
    middle M)
9-16::
    1s+2s also 3s+4s dance reels of 4 across (2s & 4s pass partner LSh
    to give RSh to sides)
17-24::
    2M+4L turn LH 1.1/2 times _while_ others chase anticlockwise 1/2
    way, 4s+3s also 2s+1s dance LH across
25-32::
    All set & 3s+1s set _while_ 4L+2L turn left about to face down as
    partners dance down to join NH & 4s+2s dance down, 2s cast up to top
    & 4s to 3rd place.  2 3 4 1

{{explanation}}
Repeat in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (5931, '2013-08-21 08:31:16.95618+00', '2023-02-04 01:20:44.387555+00', 12669, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 Figs of 8 (1L round 2s, 1M
    round 3s) _while_ 2s+3s set & cross LH.  (2)1(3)
9-16::
    1s dance Diag R&L.  3 1 2
17-24::
    3s+1s+2s Set & Rotate for 3 couples:
::
    All set & chase clockwise into lines across facing partner, all
    change places with partner & chase clockwise to own sides.  2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8298, '2014-07-29 12:58:40.821907+00', '2023-02-04 01:18:24.84501+00', 15361, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp. sides

1-8::
    1s & 3s set & turn RH, 1s cast to 3rd place & cross LH to face down
    to as 3s lead up crossing & cast into 1st place.  3 2(1)(4)
9-16::
    All dance reels of 4 on sides
17-24::
    3s followed by 2s lead down & cast to places as 4s followed by 1s
    cast to top & lead down to places
25-32::
    3s+2s Allepousse (3s dance normal Allemande as 2s Poussette) also
    1s+4s dance »inverted« Allepousse down set (1s dance Allemande down
    as 4s Poussette up).  Finish 2 3(4)(1)', 0);
INSERT INTO 'dancecrib' VALUES (13876, '2021-04-05 00:18:28.259729+00', '2023-02-04 01:18:29.719818+00', 20235, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s turn RH to end in 2nd place opp
    sides
9-16::
    1s dance reels of 3 across, RSh to 4th corners (1M+3M, 1L+2L pass
    RSh)
17-24::
    1s cross up between 2s & cast; meet & dance down between 3s & cast
    up to 2nd place own side
25-32::
    1s+3s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (4048, '2013-08-21 08:30:42.481326+00', '2023-02-04 01:18:29.730101+00', 10092, 3, NULL, 'ace', '1-8::
    1s & 4s set, cross RH, cast 1 place & 1/2 turn partners 2H
9-16::
    1s+4s slip step down & back
17-24::
    1s followed by 4s dance up, 1s cast to 3rd place as 4s cast to 2nd
    place & dance 1/2 Figs of 8 round end couples
25-32::
    4s+1s 1/2 turn partner RH, twirl & dance out to own sides, 2s+4s
    also 1s+3s circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (11733, '2019-03-26 02:04:52.744725+00', '2023-02-04 01:18:29.745218+00', 11444, 3, NULL, 'ace', '1-8::
    1s cross down to face out between 2s & 3s & set as in Double
    Triangles (2s step up bars 1-2); 1s dance out, cast round 1st
    corners into centre & pull back RSh to end BtoB, 1L facing up, 1M
    facing down
9-12::
    1L+2s & 1M+3s set as in Double Triangles, 1s PdB out & pull back RSh
    to face down/up _while_ 2s & 3s PdB in & pull back RSh to face out
13-16::
    1s cross RH up/down centre & cast to right into 2nd place opp sides
    _while_ 2s & 3s set turning cl''wise & chase 1 place (2L to 3L, 3M to
    2M place)
17-20::
    1s cross RH, cast to right to end 1L between 3rd pstns facing up &
    1M between 2nd pstns facing down _while_ 2s+3s set & chase cl''wise 1
    place to end 3s in 1st place & 2s in 3rd place both on opp sides.
21-24::
    1s pass LSh to dance 1/2 diagonal reel with 4th corners (pstns) to
    end facing 3rd corner (pstns).
25-28::
    1s dance 1/2 diagonal reel with 3rd corners (pstn) ending BtoB
    facing own sides in 2nd place
29-32::
    2s+1s+3s set as in Double Triangles, 1s set advancing into 2nd place
    own sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5932, '2013-08-21 08:31:16.96218+00', '2023-02-04 01:20:44.415818+00', 14241, 3, NULL, 'ace', '1-8::
    1s set & 1/2 turn 2H, 1s set & turn 2s RH, 1s finishing in partner''s
    place  (1) 2 3 4 5
9-16::
    1s dance a modified Snowball Grand Chain for 4 couples:
::
    _9_    1s change places with 2s RH on sides
::
    _10_   1s change places with 3s LH as 2s cross LH
::
    _11_   1s change places with 4s RH as 2s+3s change places RH on
    sides 3 (2) 4 (1 )5
::
    _12_   2s & 1s dance in to take Tulloch turn holds (LSh to LSh & RH
    behind backs)
::
    _13-16_   2s & 1s dance anticlockwise Tulloch turns finishing facing
    up on opposite sides   3 (2) 4 (1) 5
17-24::
    3s+2s also 4s+1s dance RH across 1.1/2 times, 3s+1s dance LH across
    1.1/2 times   2 (1) 3 (4) 5
25-32::
    2s+1s also 3s+4s dance RH across 1.1/2 times, 1s+2s+4s+3s set then
    2s & 3s cross up RH as 1s & 4s cast 1 place.  2 1 3 4 5
::
    1s dance down to bottom as new 1st couple start (5s step up)', 0);
INSERT INTO 'dancecrib' VALUES (5933, '2013-08-21 08:31:16.9705+00', '2023-02-04 01:20:44.444474+00', 13070, 3, NULL, 'ace', '1-8::
    1s set advancing & dance down the middle, Lady dances under Man''s
    left arm to change pls & 1s dance up to end BtoB in 2nd pl facing
    opp sides
9-16::
    1s dance Double Triangles & end facing 2nd corner
17-24::
    1s turn 2nd corner RH, turn partner LH, turn 1st corner RH & partner
    LH to face out 2nd place own side
25-32::
    1s dance reels of 3 on own sides (LSh to 4th corner to start)', 0);
INSERT INTO 'dancecrib' VALUES (12400, '2019-12-05 01:30:31.336478+00', '2023-02-04 01:20:44.478993+00', 19416, 3, NULL, 'ace', '1-8::
    1s+2s dance "Tournee":
::
    1s+2s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 2s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (2s RH, 1s LH) 2s dance
    out to place, 1s to face 1st corners
9-16::
    1s+1st corners dance 1/2 diag reel of 4, 1s pass RSh & dance 1/2
    diag reel of 4 with 2nd corners, 1s pass RSh to 2nd place own side
    (3) 1 (2)
17-24::
    "Reverse Snowball grand Chain":
::
    _17-20_   2s cross RH, 1s+2s change places LH on side
::
    _21-22_   2s+3s change places RH _while_ 1s cross LH
::
    _23-24_   2s cross LH _while_ 3s+1s change place LH on sides.  (2)
    (1) (3)
25-32::
    2s+1s+3s Set+Link; 3s+2s chase clockwise 1/2 round _while_ 1s turn
    2H 1.1/4 round to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5934, '2013-08-21 08:31:16.978783+00', '2023-02-04 01:20:44.495055+00', 3397, 3, NULL, 'ace', '1-8::
    1s+2s dance The Knot
9-16::
    1s set advancing to 1st corners, turn 2H & circle 4H round to left &
    end Lady between 2s facing down & Man between 3s facing up
17-24::
    1s set advancing to 2nd corners, turn 2H & circle 4H round to left &
    end on opposite sides facing 1st corners
25-32::
    1s dance reels of 3 on opposite sides (1s give LSh to 1st corners) &
    cross to own 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (14208, '2021-08-14 00:20:23.846191+00', '2023-02-04 01:20:44.570532+00', 12292, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig of 8 (1s cross down to start)
9-16::
    1s lead down middle & up to end in middle at top facing down NHJ. 2s
    step in NHJ to face 1s
17-20::
    1s+2s set advancing to change places (1L & 2M pass LSh), 1s & 2s
    turn partners 2H to 2s facing down, 1s facing up
21-24::
    2s+1s repeat bars 17-20 returning to places.  1 2
25-28::
    1M & 2L set & cross into their partner''s place _while_ 1L & 2M set
    advancing & turn 2H to face partners
29-32::
    1L passes partner RSh to dance to 2L''s place _while_ 2M passes
    partner RSh to dance to 1M''s place _while_ 1M & 2L give RSh to their
    partners to start 1/2 diagonal reel of 4 to change places. 2 1', 0);
INSERT INTO 'dancecrib' VALUES (5936, '2013-08-21 08:31:17.010955+00', '2023-02-04 01:20:44.735949+00', 3402, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, set & cast down behind 3s
9-16::
    1s lead up to top & cast to face 1st corners, set to 1st corners &
    set to 2nd corners
17-24::
    1s+2nd corners circle 4H round & back
25-32::
    1s dance R&L with 1st corners (normal Rights & Lefts but on a
    diagonal)', 0);
INSERT INTO 'dancecrib' VALUES (15232, '2022-11-03 01:20:21.365383+00', '2023-02-04 01:20:44.762171+00', 20431, 3, NULL, 'ace', '1-8::
    1L+2M cross RH & cast RSh round partner; cross LH & cast LSh back to
    original places
9-16::
    1M+2L cross LH & cast LSh round partner; cross RH & cast RSh back to
    original places
17-24::
    1s+2s set & Petronella in tandem; facing up/down all set & change
    places with partner
25-32::
    1s+2s set & Petronella in tandem; all turn partner 2H.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (5937, '2013-08-21 08:31:17.020374+00', '2023-02-04 01:20:44.781835+00', 13596, 3, NULL, 'ace', '1-8::
    1s cross RH & cast to 2nd place, 1s dance RH across (1M with 2s, 1L
    with 3s)
9-12::
    1L dances up between 2s & casts round 2L to 2nd place own side
    _while_ 1M casts round 3M to 2nd place
13-16::
    1s dance 1/2 reels of 3 on own sides (1L giving LSh to 3L, 1M giving
    LSh to 2M)
17-20::
    1L dances up between 3s & casts round 3M to 2nd place opp side
    _while_ 1M casts round 2L to 2nd place opp side
21-24::
    1s dance 1/2 reel of 3 on opp sides (1L giving RSh to 2M, 1M giving
    LSh to 3L) & 1s end facing 1st corners
25-32::
    1s set to 1st corner & set to 2nd corner & turn right about to face
    partner, 1s turn RH 1.1/2 times to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13088, '2020-08-10 00:20:05.636992+00', '2023-02-04 01:20:44.807641+00', 20049, 3, NULL, 'ace', '1-8::
    1s+2s dance Set & Rotate. 1M & 2L face out
9-16::
    2s+1s dance RH across; 1s+3s dance LH across.  1s face up
17-24::
    2s+1s+3s dance RSh reels of 3 on sides (1s pass 2s RSh to start)
25-32::
    1s+3s dance the Knot.  End 2 3 1', 5);
INSERT INTO 'dancecrib' VALUES (8599, '2015-02-13 12:47:55.34019+00', '2023-02-04 01:20:44.828826+00', 15988, 3, NULL, 'ace', '1-8::
    1s cast down behind own lines, turn outwards & cast up to 2nd place
    own side (2s step up bars 3-4)
9-16::
    1s & 1st crnrs change places RH & set _while_ 2nd crnrs set change
    places RH, all repeat back to places.  2(1)3
17-24::
    1s lead down & cross below 3s, cast up to 2nd place on opposite
    sides, then lead up, cross over & cast down to 2nd place on own
    sides.
25-32::
    All 1/2 turn 2H & 2s facing down _while_ 3s facing up (square
    formation) & all set, all circle 6H round 1/2 way to left.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5938, '2013-08-21 08:31:17.063085+00', '2023-02-04 01:20:44.84701+00', 3407, 3, NULL, 'ace', '1-8::
    All dance RSh round partner chase clockwise 1/2 way.  (3)(2)(1)
9-16::
    All set & turn 2H 1.1/2 times & set
17-24::
    All dance reflection reels of 3 on sides (3s in & down)
25-32::
    3s & 1s set, 1s dance up to top as 3s cast to 3rd place, 1s cast to
    3rd place as 2s+3s step up. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (14529, '2022-01-10 02:19:45.098893+00', '2023-02-04 01:20:44.86334+00', 17965, 3, NULL, 'ace', '1-8::
    1s+3s dance down middle & back, 1s face out
9-16::
    1s+5s dance Fig 8 on sides (1s down/out, 5s in/up to start)
17-24::
    1s cast to 5th place (2s+3s+4s+5s step up 19-20); All 5 couples turn
    partner RH
25-32::
    All circle 10H round & back.  2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (5939, '2013-08-21 08:31:17.071628+00', '2023-02-04 01:20:44.91074+00', 8936, 3, NULL, 'ace', '1-8::
    1s set, cross down RH & dance RSh round 1st corners to meet in
    centre LSh to LSh, 1L facing down, 1M facing up (2s step up 3-4)
9-16::
    1s dance RH across (1L with 2M+3M & 1M with 2L+3L), 1s turn left
    elbow grip (birl) 1.3/4 to face 3rd corner position _while_ corners
    chase 1/2 way clockwise
17-24::
    1s turn 3rd corners RH, pass RSh to turn 4th corners LH & pass LSh
    to…
25-32::
    1s dance RH across,1L+2s (in 3rd place) 1M+3s (at top) , turn left
    elbow grip 1.1/4 to end in 2nd place own side _while_ corners chase
    1/2 way clockwise', 0);
INSERT INTO 'dancecrib' VALUES (5940, '2013-08-21 08:31:17.080142+00', '2023-02-04 01:20:44.945066+00', 3408, 3, NULL, 'ace', '1-8::
    1s dance Chain Progression :
::
    1s+2s 3/4 turn RH, 1M+2L turn LH 1.1/2 times _while_ partners chase
    cl''wise 1/2 way, 2s+1s turn prtnrs RH, 2s end 1st place & 1s facing
    3rd corners
9-16::
    3rd corners dance full diagonal reel of 4
::
    _while_ 2nd corners chase clockwise to next corner, dance 1/2 reel
    of 4 with 3rd corner persons & chase clockwise to own corner
::
    _while_ 1s pass 3rd corners RSh & chase clockwise 1/2 way to 1st
    corner (pstn), pass 1st crnr person RSh & partner RSh to face 2nd
    corner
17-24::
    Repeat with 2nd corners
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5941, '2013-08-21 08:31:17.088364+00', '2023-02-04 01:20:44.975355+00', 3409, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 on own sides (1s dancing in to start)
    with 1s ending in middle facing 2s
9-16::
    1s+2s dance the Rondel & end on sides with 1s facing down in 2nd
    place
17-24::
    2s+1s+3s dance Grand Chain & 1s end facing 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting & turn RH to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (13244, '2020-10-16 00:20:33.173039+00', '2023-02-04 01:20:45.00692+00', 15677, 3, NULL, 'ace', '1-8::
    1L followed by 1M casts off & crosses to opp side (2s step up 3-4);
    1s+3s dance LH across
9-16::
    1L followed by 1M casts up & cross to own side; 1s+2s dance RH
    across
17-24::
    Reels of 3 on sides, 1s RSh to 2s.  1s end facing down, 2s facing up
25-32::
    1s+2s set & change places RH; 2s+1s circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (5942, '2013-08-21 08:31:17.097001+00', '2023-02-04 01:20:45.033401+00', 10766, 3, NULL, 'ace', '1-8::
    All set to partner, 1/2 turn 2H & 1s+2s also 3s+4s circle 4H round
    to left opening into 2 diagonal lines (1M+1L+2M+2L facing
    4L+4M+3L+3M)
9-16::
    All turn opposite person RH, twirl & dance to opposite place, all
    circle 8H round to left ending in square 2 1 4 3
17-24::
    All set to partner, 1/2 turn 2H & 1s+4s also 3s+2s circle 4H round
    to left opening into 2 diagonal lines (1M+1L+4M+4L facing
    2L+2M+3L+3M)
25-32::
    All turn opposite person RH, twirl & dance to opposite place, all
    circle 8H round to left ending in square 3 4 1 2
33-40::
    1s+3s dance R&L
41-48::
    1s+3s dance Ladies Chain
49-56::
    2s+4s dance R&L
57-64::
    2s+4s dance Ladies Chain
65-96::
    Repeat bars 1- 32 back in original places', 0);
INSERT INTO 'dancecrib' VALUES (8532, '2015-02-13 12:47:24.055833+00', '2023-02-04 01:18:29.756867+00', 15603, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp. sides

1-8::
    1s & 4s cross RH & cast in 1 place, 1s & 4s turn LH to end with
    Ladies facing 2M/3M with partners behind them
9-12::
    1s+4s dance an alternating tandem Pass+Turn with corners pass RSh to
    Men with partners behind them facing 3L/2L
13-16::
    Repeat with corners & end 1s on Men''s side & 4s on Ladies'' side.
17-24::
    1s & 4s dance tandem LSh reels of 3 on sides (Ladies leading)
25-32::
    1s+4s set & 1L+4L change places LH, 4s+1s set & cross RH.  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (4049, '2013-08-21 08:30:42.532877+00', '2023-02-04 01:18:29.782384+00', 202, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cross down RH to 2nd place _while_ 2s cast up, 1s turn
    2nd corner LH, pass partner LSh to face 1st & 2nd corners
9-16::
    1s dance 3H round to left with corners 1/2 way & lead corners round
    to top/bottom & dance 6H round to end 1L between 2s & 1M between 3s
17-24::
    All set in line across, change places RH with opposite person, set &
    change places with opposite person
25-32::
    1s dance reels of 3 across giving RSh to 4th corner & end turning
    4th corner RH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (15211, '2022-11-03 01:18:31.422369+00', '2023-02-04 01:18:29.964092+00', 21116, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance all round Poussette
9-14::
    1s+2s also 3s+4s set, 1/2 turn partner RH & chase clockwise 1/2
    round.  2 1 4 3
15-16::
    All turn partners 2H, 2s+3s finish on sides _while_ 1s+4s finish in
    middle, NHJ, facing down/up
17-24::
    1s+4s dance a Rondel.  2 4 1 3
25-28::
    All set, Men make arches, all dance into partners'' places passing
    RSh.
29-32::
    Repeat bars 25-28 with Ladies making arches.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11699, '2019-03-18 21:02:23.50723+00', '2023-02-04 01:20:45.229729+00', 18356, 3, NULL, 'ace', '1-4::
    All set, 1s & 2s rotating by right on bar 2 & 1s+2s chase clockwise
    1 place _while_ 3s cast & 4s step up
5-8::
    1s+2s chase clockwise 1 place to face partners, 2s cross RH as 1s
    dance in, touch RH & turn about to BtoB facing 1st corners _while_
::
    4s+3L & 3M+5s RH across.  3s finish facing 1st corners.  2 1 4 3 5
9-16::
    1s & 3s dance 1/2 diag reel of 4 with 1st corners, pass partner RSh,
    turn 2nd corner RH, pass RSh to face 3rd corner
17-20::
    1s & 3s dance 1/2 diag reel of 4 with 3rd corners, end in centre
    facing partner (Men face down, Ladies face up).  2 1 4 3 5
21-24::
    1s & 3s 3/4 turn partner RH & cast to 3rd/5th place (4s+5s step up
    23-24).  2 4 1 5 3
25-32::
    2s+4s also 5s+3s circle 4H round & back _while_ 1s (middle couple)
    turn RH & turn LH (alternatively 1s birl)', 3);
INSERT INTO 'dancecrib' VALUES (13307, '2020-11-02 01:20:25.494897+00', '2023-02-04 01:20:45.253509+00', 20093, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place (2s step up 3-4), 1s dance 1/2 Fig of 8 up
    round 2s 2 (1) 3
9-16::
    1s set & cast 1 place (3s step up 11-12), 1s+3s dance 1/2 double Fig
    of 8 (1s cross up, 3s cast to start).  2 (3) 1
17-24::
    3s+1s set, petronella in tandem, set & petronella in tandem again  2
    (1) 3
25-32::
    1s dance 1/2 reels of 3 on sides, RSh to 1st corners; bar 28 1s pass
    RSh to 2nd place own side to dance 1/2 reel of 3 on sides (RSh to
    3rd corner to start)', 0);
INSERT INTO 'dancecrib' VALUES (10082, '2017-09-03 23:44:52.5211+00', '2023-02-04 01:20:45.275148+00', 17771, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L, 1M & 2L end facing out
9-16::
    Reels of 3 on sides, 1L+2L also 1M+2M pass LSh to start
17-24::
    1L+2L also 1M+2M turn 1.1/2 LH to change places.  1s+3s dance RH
    across
25-32::
    1s+3s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9010, '2015-11-30 08:59:56.18906+00', '2023-02-04 01:20:45.295373+00', 16101, 3, NULL, 'ace', '1-8::
    1s lead down middle & back finishing in middle at top facing each
    other & joining 2H, 2s step in ready for ...
9-16::
    1s+2s Poussette
17-24::
    2s+1s+3s Set+Link twice.  All on opp sides  (3) (1) (2)
25-32::
    All dance clockwise 1/2 way round & turn partners RH   End  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5943, '2013-08-21 08:31:17.105276+00', '2023-02-04 01:20:45.320626+00', 12001, 3, NULL, 'ace', '1-8::
    1s followed by 2s lead down for 3 steps, 1s lead up to top & cast to
    2nd place
9-16::
    1s cross down to dance reels of 3 on opposite sides & end in middle
    1L facing up & 1M down for…
17-24::
    1s dance Double Triangles (up/down) & end in 2nd place on opposite
    sides
25-32::
    1s dance 1/2 Figs of 8 (1M round 2s & 1L round 3s); 1L+2s also 1M+3s
    dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (12085, '2019-08-30 09:54:26.97211+00', '2023-02-04 01:20:45.34727+00', 19278, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up), cross down LH beween 3s & cast up
    passing LSh to face 1st corners
9-20::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s in 2nd place own
    side facing out
21-24::
    1s cast up 1 place (3s step down), 1s set _while_ 3s+2s dance 1/2 RH
    across
25-32::
    Progressive Grand Chain:
::
    _25-26_    1s (at top) turn once round RH as 2s+3s change places RH
    on sides,
::
    _27-28_    2s (at bottom) turn once round LH as 1s+3s change places
    LH on sides,
::
    _29-30_    3s (at top) turn once round RH as 1s+2s change places RH
    on sides,
::
    _31-32_    1s (at bottom) turn once round LH as 2s+3s change places
    LH on sides
33-40::
    All set, pull back RSh & dance into lines of 3 across flowing into
    circle 6H round to left to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (12921, '2020-07-01 00:20:11.130033+00', '2023-02-04 01:20:45.54762+00', 19990, 3, NULL, 'ace', '1-8::
    1s set, cast, cross up to partner''s place facing out; 1s+2s turn on
    side (1M+2L RH, 1L+2M LH), 1s end BtoB in centre 2nd place facing
    opp sides
9-16::
    RSh reels of 4 across.  Bar16: 1s do not pass LSh but 1/2 turn LH to
    face each other between 2s
17-24::
    1s set, petronella turn to face up/down, set advancing & 3/4 turn RH
    to 2nd place own sides (2s step up 23-24)
25-32::
    2s+1s dance R&L.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (12816, '2020-05-14 23:14:58.331322+00', '2023-02-04 01:20:45.583153+00', 19723, 3, NULL, 'ace', '1-8::
    1s set, cast & dance 1/2 Fig 8 up round 2s (2s step up 3-4). 2 (1) 3
9-16::
    1s lead down (3 bars), lead up (3 bars) & turn 3/4 RH, pull back RSh
    to end BtoB in mddle (Lady facing down / Man up)
17-24::
    1s dance 6 bars of Double Triangles (up/down), 1s turn 4th corner RH
    to end in 2nd place own sides, 1M facing up / 1L down. 2 1 3
25-32::
    2s+1s+3s dance LSh reels of 3 on sides (1M in/ up, 1L in down).  End
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5950, '2013-08-21 08:31:17.168448+00', '2023-02-04 01:20:45.740035+00', 3424, 3, NULL, 'ace', '1-8::
    1M+2L Adv+Ret 2 steps & dance DoSiDo
9-16::
    1L+2M Adv+Ret 2 steps & dance DoSiDo
17-24::
    1s cast behind 2s, lead down between 3s & cast back to 2nd places
25-32::
    2s+1s+3s (in circle formation) Adv+Ret & turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (5951, '2013-08-21 08:31:17.178961+00', '2023-02-04 01:20:45.752312+00', 2372, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 1L+2L+3L dance round partners RSh & chase clockwise to
    own sides.
9-16::
    1s+2s+3s dance Grand Chain (1L+3M at bottom cross RH to start &
    others change places RH on sides) & end with new partners
17-24::
    All dance Allemande, Ladies to original places & Men to order 3 2 1
25-32::
    All set, 3M+2M+1M dance round new partner RSh & chase clockwise to
    original places.
33-40::
    1s+2s+3s 3/4 turn partner RH & join up to Bal-in-Line up/down
    middle, 1M+2L turn LH 1.1/4 times as partners chase clockwise 1/2
    way to end 1s in 2nd place _while_ 3s turn RH 1.1/4 times to own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (5952, '2013-08-21 08:31:17.187309+00', '2023-02-04 01:20:45.762836+00', 9870, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across, 2s+3s dance LH across _while_ end
    couples chase clockwise to opposite ends
9-16::
    4s+2s also 3s+1s repeat
17-24::
    1s+2s also 3s+4s set & cross RH, set & change places LH on sides
25-32::
    2s+1s also 4s+3s set & cross RH Centre couples (1s+4s) set & change
    L on sides
33-40::
    All dance RSh reels of 4 on sides
41-48::
    4s dance Fig of 8 round 2s _while_ 1s dance round 3s to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5953, '2013-08-21 08:31:17.195835+00', '2023-02-04 01:20:45.779296+00', 3433, 3, NULL, 'ace', '{{explanation}}
1s start on opp sides

1-8::
    1s set, 1/2 turn RH & dance RH across with 2L end with 1L in 1st
    Mans pl & 1M+2L turn into prom hold (Lady on Mans right) facing
    Ladies side
9-16::
    1M+2L dance diagonal reel of 3 with 1L & 3L (RSh to 3L to start)
    ending with 2L dancing to own place & 1M to 1st Ladies place
17-24::
    1s set, 1/2 turn LH & dance LH across with 2M ending with 1M in 1st
    Ladies place & 1L+2M turn into prom hold (Lady on Mans R) facing
    Men''s side
25-32::
    1L+2M dance diag reel of 3 with 1M & 3M (LSh to 3M to start) ending
    with 2M dancing to own place & 1L to 1st Mans place _while_ 3s 1/2
    turn RH
33-40::
    1M+2L, 1L+2M & 3M+3L set to each other, continue setting as Man give
    RH to Lady as she turns under his arm & turn 1.1/2 times to change
    pl
41-48::
    2s+1s+3s circle 6H round & back

{{explanation}}
NB On bars 95-96 new top couple cross & the ''retiring 1s'' cross down to 4th place as new 1s start turning', 0);
INSERT INTO 'dancecrib' VALUES (5954, '2013-08-21 08:31:17.210021+00', '2023-02-04 01:20:45.941918+00', 3435, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s lead down for 3, up for 3, cross over & cast down to 2nd place
17-24::
    2s+1s dance Ladies Chain
25-32::
    2s+1s Adv+Ret, 1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (5955, '2013-08-21 08:31:17.218426+00', '2023-02-04 01:20:45.96431+00', 3436, 3, NULL, 'ace', '1-8::
    1s+2s set advancing, 1s cast to 2nd place _while_ 2s turn 2H, 2s+1s
    circle 4H round to left
9-16::
    1s+3s set advancing, 1s cast to 3rd place _while_ 3s turn 2H, 3s+1s
    lead up to top & 3s cast to 3rd place
17-24::
    1s+2s+3s dance 1/2 Grand Chain, 2s+1s set advancing, 2s cast to 3rd
    place _while_ 1s turn 2H
25-32::
    1s+2s circle 4H round to left, 3s+1s+2s circle 6H round to left 1/2
    way', 4);
INSERT INTO 'dancecrib' VALUES (5956, '2013-08-21 08:31:17.229111+00', '2023-02-04 01:20:46.062657+00', 3437, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across 1/2 way & 1s followed by 2s lead down the
    middle
9-16::
    1s+2s dance LH across 1/2 way & 1s followed by 2s dance back to
    original places remaining in middle ready for …
17-24::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (5957, '2013-08-21 08:31:17.23743+00', '2023-02-04 01:20:46.080957+00', 3441, 3, NULL, 'ace', '1-8::
    1s cross down & dance reflection reels of 3 on opposite sides, all
    giving nearer hands where possible. 1s+3s end in the middle (1s face
    down & 3s up)
9-16::
    1s+3s dance Ladies Chain up/down middle of set, ending 1s facing
    down, 3s facing up, NHJ with partners
17-24::
    1s+3s set & Petronella-in-tandem (skip change) to side as 2s cross
    RH & cast round to right; 1s+3s set & petronella to ends as 2s cross
    RH (up/down) & cast to right
25-32::
    1s+2s+3s chase clockwise 1/2 way, 1s cross RH & cast 1 place', 0);
INSERT INTO 'dancecrib' VALUES (5958, '2013-08-21 08:31:17.245661+00', '2023-02-04 01:20:46.092812+00', 3444, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left for 3 steps, 1s cast to 2nd place as
    2s dance up, 1s+3s repeat this Fig circling to right
9-16::
    3s+1s set, dance 1/2 R&L & cross RH
17-24::
    2s+1s+3s circle 6H round & back
25-32::
    2s+1s+3s turn partners RH & turn LH', 0);
INSERT INTO 'dancecrib' VALUES (13755, '2021-03-02 01:20:29.657574+00', '2023-02-04 01:20:46.104297+00', 20234, 3, NULL, 'ace', '1-8::
    1s lead down, cross & cast (1M behind 3s, 1L behind 2s) back to
    place (bar 6) & turn RH to bring 1M into centre ready for …
9-16::
    Men dance LH across & RH across back to place _while_ Ladies chase
    clockwise round back to place
17-24::
    Ladies dance RH across & LH across back to place _while_ Men chase
    clockwise round back to place
25-32::
    All couples set, rotate & dance in tandem to next place to left (Men
    lead); all couples turn RH to face in
33-40::
    All join hands in circle, dance in 2 steps, raise arms & »Hooch« &
    retire; all turn partner RH (4 bars).  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5959, '2013-08-21 08:31:17.253865+00', '2023-02-04 01:20:46.138099+00', 9941, 3, NULL, 'ace', '1-8::
    All set then 1s+2s dance RH across 1/2 way _while_ 3s cross RH, all
    set then 2s & 3s cross RH _while_ 1s 3/4 turn RH into prom hold
    facing 3L
9-16::
    1s dance 1/2 reel of 3 with 1st corners, 1/2 reel of 3 with 2nd
    corners ending each facing own 1st corner position
17-24::
    1s dance 1/2 reel of 4 with 1st corners, 1/2 reel with 2nd corners
    ending 2nd place own sides
25-32::
    2s+1s+3s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (10382, '2018-01-17 20:30:56.118538+00', '2023-02-04 01:20:46.160481+00', 18136, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up), 1s set again & Petronella turn to end 1M
    between 3s facing up, 1L between 2s facing down
9-16::
    1s turn LH 4 times round _while_ 2s+3s turn RH 4 times round
17-24::
    1s+2s+3s set, 1s Petronella turn to 2nd place opp sides _while_
    2s+3s cross RH with partners.  (2)(1)(3).  All set & cross RH to own
    sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5960, '2013-08-21 08:31:17.262021+00', '2023-02-04 01:20:46.194193+00', 3446, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH & dance DoSiDo
9-16::
    Repeat bars 1- 8
17-24::
    2s followed by 1s dance down 2 steps, set turning right about, 1s
    followed by 2s dance up & 1s cast to 2nd place
25-32::
    1s+3s dance RH across, 2s+1s dance LH across', 0);
INSERT INTO 'dancecrib' VALUES (5963, '2013-08-21 08:31:17.393072+00', '2023-02-04 01:20:46.495482+00', 7438, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place & dance 1/2 Fig of 8 round new end
    couples
9-16::
    2s+1s also 4s+3s dance R&L
17-24::
    1s+4s dance RH across for 3 steps & back, 1s cast down 1 place
    _while_ 4s dance up 1 place
25-32::
    2s+4s+1s+3s dance reels of 4 on side (RSh Men''s side & LSh Ladies
    side)', 0);
INSERT INTO 'dancecrib' VALUES (13730, '2021-03-02 01:18:31.897131+00', '2023-02-04 01:18:24.88394+00', 12131, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s NHJ dance down & cast up round 2s to 1st place, on bar 12 1s+2s
    dance into centre ready for 1/2 Diamond Poussette. 1s finish in
    centre facing down, 2s finish in 1st place
17-24::
    1s repeat bars 9-16 with 3s, 1s end in centre, 3s finish in 2nd
    place. 2 3 1
25-32::
    1s turn RH, cast up 1 place (3s step down bars 27-28), 1s NHJ dance
    up between 2s & cast to 2nd place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3976, '2013-08-21 08:30:40.739165+00', '2023-02-04 01:18:24.921984+00', 103, 3, NULL, 'ace', '1-8::
    1s lead down for 4 bars, Lady passes under Mans arm & lead up to 2nd
    place
9-16::
    2s+1s+3s set, cross RH, set, 2s & 3s cross LH _while_ 1s pass LSh to
    face 1st corner
17-24::
    Set to & turn 1st corner; set to & turn 2nd corner
25-32::
    1s dance 1/2 Fig of 8 round standing 2s & 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (8981, '2015-11-30 08:59:26.780435+00', '2023-02-04 01:18:30.143256+00', 16097, 3, NULL, 'ace', '1-4::
    1s+2s Set+Link
5-12::
    2s+1s+3s dance reel of 3 on sides, 1s+3s passing LSh.  1s end BtoB
    in middle, 1L facing up, 1M down
13-16::
    1M+3s & 1L+2s circle 3H round to Left.  1s end in 2nd place own
    sides
17-24::
    1s+4s set, petronella turn into middle, Men face up, Ladies down.
    1s+4s dance 1/2 reel of 4
25-32::
    1s+4s set, petronella turn to own sides.  4s+3s (middle couples)
    Set+Link    Finish 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5961, '2013-08-21 08:31:17.374558+00', '2023-02-04 01:20:46.437964+00', 4819, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & turn 2H1.3/4 times to face 1st corners
9-16::
    1s set, turn 1st corners 2H, 1s set & turn 2nd corners 2H into…
17-24::
    1s circle 3H round to left with 1st+2nd corners, 1s pull back RSh to
    face & turn 2H once round, 1s set passing each other LSh to end BtoB
    facing own sides
25-32::
    1s circle 3H round to left with 3rd+4th corners, 1s pull back RSh to
    face & turn 2H, turn right about & dance out to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (15338, '2022-12-19 01:20:29.069955+00', '2023-02-04 01:20:46.475644+00', 21130, 3, NULL, 'ace', '1-8::
    1s+2s Mirror Set+Link.(1s cast, 2s dance up); 1s dance down below 3s
    & cast up to 2nd place own sides.  2 1 3
9-16::
    1s turn 1.1/4 LH; 1s dance 1/2 RH across (1L with 2s, 1M with 3s).
    1s cast round 4th corners to 2nd place own sides
17-24::
    1s dance 1/2 diagonal R&L with 1st corners (Man down, Lady up). 1s
    dance 1/2 diagonal R&L with 2nd corners (Man down, Lady up)
25-32::
    1s dance LH across (1M with 3s, 1L with 2s) flowing into »Snake
    Pass«:
::
    1M followed by 3s also 1L followed by 2s pass RSh diagonally across
    through 2nd place to change ends, loop round to right to end 2nd
    place 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8335, '2014-07-29 12:59:11.111905+00', '2023-02-04 01:20:46.518651+00', 15368, 3, NULL, 'ace', '1-4::
    All dance 1/2 Grand Chain
5-8::
    Ladies dance RH across _while_ men dance anticlockwise back to
    original places around outside of set
9-12::
    Ladies pass Men LSh & men dance LH across in the middle _while_
    ladies dance clockwise around outside of set to original places;
13-16::
    All turn partners RH for 4 bars, twirl (pivot) to face corners
17-24::
    Set to & turn corners; set to & turn partners, ladies end facing out
25-40::
    All dance full Schiehallion reels, end back in original places
41-48::
    All Circle 8H 1/2 way round, set, pull RSh back, dance on 1 place
    clockwise, men curving around to end facing partners', 0);
INSERT INTO 'dancecrib' VALUES (5964, '2013-08-21 08:31:17.40142+00', '2023-02-04 01:20:46.540026+00', 3454, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    Men change places RH, Ladies change places LH & all dance 1/2 R&L
    ending with Men turning partners LH into centre to form a line
9-16::
    All Bal-in-Line, 1/2 turn partner LH, Bal-in-Line, 1/2 turn partner
    LH into prom hold
17-24::
    All dance clockwise promenade passing both opposite couple & next
    couple RSh back to original places facing partner
25-32::
    All 1/2 turn partner RH & dance 1/2 RH across with opposite couple,
    all turn partners RH to face next couple', 0);
INSERT INTO 'dancecrib' VALUES (10999, '2018-08-17 07:52:28.552072+00', '2023-02-04 01:20:46.565724+00', 18391, 3, NULL, 'ace', '1-4::
    1s+2s circle 4H round to left 7/8 way, all adv to prtnr turning
    right about to end BtoB in middle (1L facing up, 2L Ls side, 2M down
    & 1M Ms side)
5-8::
    1s+2s advance turning right about & set
9-16::
    1s+2s dance LH across back to places, 1s+2s+3s set & cross RH.
    (1)(2)(3)
17-20::
    1s followed by 2s+3s dance down middle
21-24::
    All cross Ladies dancing under Mens right arm to own side & all
    dance up & turn 2H to order 3 2 1
25-28::
    3s cross RH _while_ 2s+1s dance 1/2 RH across & 3s+1s dance 1/2 RH
    across _while_ 2s cross RH.  1 3 2
29-32::
    1s cross RH _while_ 3s+2s dance 1/2 RH across & 1s+2s dance 1/2 RH
    across _while_ 3s cross RH.  2 1 3
33-40::
    2s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (8600, '2015-02-13 12:47:55.735291+00', '2023-02-04 01:20:46.585698+00', 12687, 3, NULL, 'ace', '1-4::
    »Progressive Wheels«:  Ladies LH across, Men RH across on sides, 1s
    dancing down middle followed by 2s+3s to begin.  Finish 1s in centre
    2nd place, 2s in 1st place, 3rd in 3rd place
5-8::
    1s dance down between 3s, 1M followed by 1L casts up round 3M into
    centre, 1s NHJ (brief) face Ladies'' side
9-12::
    1M+2s dance LH across _while_ 1L+3s dance RH across
13-16::
    1s dance out of Ladies'' side, cast (1M up, 1L down) and dance into
    2nd place opp. sides.  1L faces up, 1M down
17-24::
    1s set to 1st cnrs, set to ptnrs, set to 2nd cnrs, 1s turn LH 3/4 to
    end 1M between 3s, 1L between 2s, facing 1st cnrs
25-32::
    LSh Reels of 3 across.  1s finish in centre, own side, facing down.
    3s dance up sides to 2nd place (face up) _while_ 1s dance down &
    curve into 3rd place facing up', 0);
INSERT INTO 'dancecrib' VALUES (5965, '2013-08-21 08:31:17.441495+00', '2023-02-04 01:20:46.614018+00', 3461, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All turn Partners RH 1.1/4 times, turn Partners LH 1.1/4 times
17-24::
    All Ladies dance RH across, then LH across
25-32::
    All Ladies chase once round set anticlockwise to face corner
33-40::
    All Ladies turn corners RH 1.1/4 times, the turn LH 1.1/4 times
41-48::
    All Men dance RH across, then LH across
49-56::
    All Men chase once round set anticlockwise to place
57-64::
    All in prom hold dance anticlockwise round set Ladies ending BtoB in
    centre.', 0);
INSERT INTO 'dancecrib' VALUES (5966, '2013-08-21 08:31:17.449831+00', '2023-02-04 01:20:46.640865+00', 3463, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cross RH & cast 1 place (2s step up), 1s dance in to
    meet partner & face down, 1s turn 3s with nearer hand to face up
9-16::
    1s dance reflection reels of 3 on sides (1s dancing in & up between
    2s to start)
17-24::
    1s Petronella turn to middle as 2L+3L & 2M+3M change pl RH, set in
    lines across, 1s petronella turn to sides as 2s+3s cross RH & set on
    sides
25-32::
    1s dance Diag R&L (1M crossing down & 1L crossing up)', 0);
INSERT INTO 'dancecrib' VALUES (5967, '2013-08-21 08:31:17.458165+00', '2023-02-04 01:20:46.676649+00', 3470, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 4H round to left & end facing other cpl, all
    set & 1L+2L turn LH as 1M+2M turn RH as 3L+4L turn RH & 3M+4M turn
    LH
9-12::
    1s followed by 2s dance down to 3rd/4th pl as 4s followed by 3s
    dance up (pass RSh, M with M & L with L)
13-16::
    All set (joining hands) to partner & casting to right dance out to
    new places.
17-24::
    All cross RH, circle 8H round to left (2 bars); set (in circle) &
    continue 8H round (2 bars) to end on own sides 1 2 3 4
25-28::
    All dance 1/2 RSh reel of 4 on sides;
29-32::
    4s+3s+2s dance 1/2 reel of 3 _while_ 1s (at bottom) stand.  End 2 3
    4 1', 0);
INSERT INTO 'dancecrib' VALUES (13414, '2020-12-02 01:20:22.792446+00', '2023-02-04 01:20:46.827527+00', 19158, 3, NULL, 'ace', '1-8::
    1s turn 1.1/2 2H, remaining in centre facing down NHJ. 2s step in
    bar 4 to face 1s NHJ; 1s+2s Set+Link ending on sides (2s face up1s
    face down)
9-16::
    1s+2s+3s dance RSh reels of 3 on sides (2s RSh to 1s to start)
17-24::
    Men dance RH across; Ladies dance LH across
25-28::
    2s followed by 1s dance down, 2s cross below 3s (1s do not cross) &
    1s+2s cast up on own sides. 2 1
29-32::
    1s followed by 3s dance up & cast round 2s to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5968, '2013-08-21 08:31:17.466449+00', '2023-02-04 01:20:46.877064+00', 3472, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross up & cast to 2nd places _while_ 2s
    set, cross up, cast 1 place & cross up to 1st place
9-16::
    1s dance down below 3s, cast up to 2nd place, lead up between 2s
    crossing LH & cast to face 1st corners
17-24::
    1s set to 1st corners, turn right to turn partners RH to face 2nd
    corners, set to 2nd corners & turn right to turn partners RH to face
    1st corners
25-32::
    1s turn 1st corners 2H, pass RSh, turn 2nd corners 2H & cross to 2nd
    place passing RSh. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5969, '2013-08-21 08:31:17.474716+00', '2023-02-04 01:20:46.907764+00', 3474, 3, NULL, 'ace', '1-8::
    1M+2L & 3M+4L cross diagonally RH, 1M+4L cross LH, 1L+2M & 3L+4M
    cross RH & 1L+4M cross LH
9-16::
    2s+4s & 1s+3s set & dance 1/2 RH across then middle couple (2s+3s)
    set & dance 1/2 LH across
17-24::
    1s lead up to the top then 4s facing 3s set & turn LH
25-32::
    All dance 1/2 reel of 4 on sides & all cross RH with partner (slow)
    to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5970, '2013-08-21 08:31:17.483048+00', '2023-02-04 01:20:46.934425+00', 3475, 3, NULL, 'ace', '1-8::
    1L followed by 1M dances Fig of 8 round 2M & 3M passing out between
    them to start & end in centre at top of set
9-16::
    1s quickly slip step to bottom & set _while_ 2s+3s+4s set & cross
    RH, 1s slip step back to top & set _while_ 2s+3s+4s set & cross RH
17-24::
    1M+2L DoSiDo _while_ 1L+2M set & cast (1s in 2nd place), 1s repeat
    with 3s ending in 3rd place
25-32::
    1s repeat above with 4s to end in 4th place & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (13246, '2020-10-16 00:20:34.830685+00', '2023-02-04 01:20:46.96926+00', 15459, 3, NULL, 'ace', '1-8::
    All 4 couples set, Adv (touch hands) +Ret & all set
9-16::
    1s+3s change places turning 1/2 RH, pull back RSh & dance out to opp
    place; 2s+4s repeat _while_ 1s+3s turn partner 2H, pull back RSh to
    face side couples (lines of 4 across)
17-24::
    All dance RSh reel of 4 across
25-32::
    All turn corner RH, 1/2 turn partner LH; all set & circle 8H round 1
    place to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5971, '2013-08-21 08:31:17.491281+00', '2023-02-04 01:20:46.983979+00', 3482, 3, NULL, 'ace', '1-8::
    All set, cross (Ladies under arches made by Men), set & cross back
    (Ladies under arches made by Men)
9-16::
    1M+2L & 3M+4L cross RH, centre couples dance RH across, 1M+2L &
    3M+4L cross back RH
17-24::
    1L+2M & 3L+4M cross LH, centre couples dance LH across, 1L+2M &
    3L+4M cross back LH
25-28::
    All dance 1/2 reels of 4 on sides (Men RSh, Ladies LSh) finish 1s
    polite turn into 4th place
29-32::
    2s+3s+4s (top 3 couples) continue dancing a 1/2 reel of 3 on sides
    3s finish with polite turn into 2nd place.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12086, '2019-08-30 09:54:27.470127+00', '2023-02-04 01:20:47.004689+00', 19425, 3, NULL, 'ace', '{{explanation}}
Round the room - 1 Man (facing clockwise) opposite 2 Ladies (facing anticlockwise)

1-8::
    All circle 3H round to left & dance LH across back to place
9-16::
    RSh reel of 3, Man passes Lady on his right to start
17-24::
    Man + Lady on right dance DoSiDo (pass RSh); Man + Lady on Left
    dance DoSiDo (pass LSh)
25-28::
    Man+2 Ladies join hands (as Double Triangles) & set, Ladies 1/2 turn
    2H (PdeB) to change places _while_ Man continues setting
29-32::
    All Adv (1 step) & Ret (1 step), Ladies make arch & Man dances under
    to meet 2 new Ladies', 0);
INSERT INTO 'dancecrib' VALUES (9740, '2017-04-06 08:39:55.442886+00', '2023-02-04 01:20:47.155837+00', 17439, 3, NULL, 'ace', '1-8::
    1s cross down to dance reels of 3 on opp sides (2s out/up, 3s in/up)
9-16::
    1s cross RH, cast (2 step up).  1s set advancing, turn RH to finish
    1M between 3s, 1L between 2s, all facing down
17-24::
    All dance down, turn right about bar 20, dance up.  1L turns right
    about to face down
25-32::
    1s petronella turn to 2nd place opp sides, set & turn 1.1/2 2H to
    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5972, '2013-08-21 08:31:17.499648+00', '2023-02-04 01:20:47.189283+00', 3483, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Figs of 8 round 2s, 1s+2s dance RH across ending with
    1M between 1L & 2L at top facing down & 2M facing down in front of
    1M
9-16::
    2M followed by 1M+Ladies dance down for 4 bars, turn to right & 1M
    followed by 2M+Ladies dance up to top, 1M turns to face 2M in centre
    (both with partners on their right)
17-24::
    1s+2s set in diamond formation, circle 4H round to left, turn
    partners 2H & open out to circle 4H round into diamond formation
25-32::
    1s+2s set in diamond formation, Ladies set again on sides _while_
    Men pass RSh to face partner, turn partner to end on own sides (1s
    in 2nd place)', 0);
INSERT INTO 'dancecrib' VALUES (13756, '2021-03-02 01:20:30.682438+00', '2023-02-04 01:20:47.224328+00', 9261, 3, NULL, 'ace', '1-4::
    1M casts off one place and dances into the middle between 1st and
    2nd place (2M steps up 1-2), 1M sets to 1L+2L (who join hands & set)
5-8::
    1M+1L+2L dance RH across. 1M ends in 2nd place own side facing out &
    1L in 1st place own side facing out
9-12::
    1L+1M cast one place and dance into the middle (2L steps up 9-10),
    1L sets to 2M+3M _while_ 1M set to 3L+4L
13-16::
    1L+2M+3M also 1M+3L+4L RH across. 1L ends in 2nd place own side
    facing out. 1M ends in 3rd place own side.
17-20::
    1L casts down one place and into the middle to face 1M+4M (3rd/4th
    place), 1L sets to 1M+4M
21-24::
    1L+1M+4M dance RH across. 1L ends in 3rd place own side. 2 3 1 4
25-32::
    All 4 couples turn partner RH, 2s face 3s, 1s face 4s on sides;
    2s+3s turn LH and 1s+4s slow turn LH 1/2 way to change places.  End
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (3977, '2013-08-21 08:30:40.747252+00', '2023-02-04 01:18:24.957548+00', 9762, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, dance down & dance round 3s into 2nd place
9-16::
    1s+1st corners set twice, corners turn RH _while_ 1s cast & chase
    clockwise (outside 2s) to 2nd place opp sides
17-24::
    1s+2nd corners set twice, corners turn LH _while_ 1s cast & chase
    anticlockwise to 2nd place own sides
25-32::
    1s dance 1/2 LSh reels of 3 across (Lady with 2s & Man with 3s) &
    1/2 LSh reels of 3 across with other couple', 0);
INSERT INTO 'dancecrib' VALUES (5973, '2013-08-21 08:31:17.507899+00', '2023-02-04 01:20:47.248857+00', 3485, 3, NULL, 'ace', '1-8::
    2s & 4s dance full diagonal RSh reels of 4 with 1st corners (passing
    partner LSh to start)
9-16::
    2s & 4s dance full reel of 4 with 2nd corners (dancing LSh round
    partner to face 2nd corners)
17-24::
    2s & 4s dance Figs of 8 on sides dancing in front of dancer on left
    (Ladies down & Men up) & meet ready for a Poussette
25-32::
    1s+2s also 3s+4s dance 1/2 Diamond Poussette, 1s+4s also 3s+5s dance
    1/2 Diamond Poussette to end 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (13177, '2020-09-15 00:20:19.220537+00', '2023-02-04 01:20:47.293344+00', 18501, 3, NULL, 'ace', '1-8::
    1L followed by 1M also 4M followed by 4L cast in 1 place, 1L & 4M
    cross to  opposite sides, cast up/down back to place.
9-16::
    2s+3s dance RH across & LH back
17-24::
    All dance RSh reels of 4 on the sides
25-32::
    1s+2s dance 1/2 RH across, 1s+3s dance 1/2 LH across, 1s+4s dance
    1/2 RH across. All cross giving RH to own sides with new 1L & 4M
    facing out', 0);
INSERT INTO 'dancecrib' VALUES (5975, '2013-08-21 08:31:17.524603+00', '2023-02-04 01:20:47.310902+00', 3492, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & turn RH
9-16::
    1s dance reels of 3 on opposite sides (RSh to 2nd corner to start)
17-24::
    1s dance 1/2 Figs of 8 (Man round 2s & Lady round 3s) & turn LH
    _while_ 2s+3s dance R&L starting on sides
25-32::
    1s dance reels of 3 on own sides (LSh to 3rd corner to start) & end
    BtoB (Lady facing up to 2s & Man facing 3s)
33-40::
    All set (as Double Triangles), 1s dance round each other 3/4 way to
    face opposite sides, set (as DT) & dance round to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (5976, '2013-08-21 08:31:17.53296+00', '2023-02-04 01:20:47.327006+00', 3493, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 3/4 turn LH & dance LSh round 1st corner
    to end beside corner facing in diagonally
9-16::
    1s+1st corners Set+Link & end 1L between 2s facing down & 1M between
    3s facing up, 1s dance 1/2 reel of 3 on own sides (RSh to 3rd
    corner) ending beside 2nd corner (1st corner person) facing in
    diagonally
17-24::
    1s+2nd corner Set+Link & end 2nd place opp sides, 1s dance 1/2 reel
    of 3 across (Lady up/Man down - RSh to 4th crnr pstn) & end 2nd pl
    own side
25-32::
    1s dance 1/2 Fig of 8 (Man up/Lady down) _while_ 3s+2s set & change
    places on sides, 2s+1s+3s set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (5977, '2013-08-21 08:31:17.544041+00', '2023-02-04 01:20:47.360171+00', 9779, 3, NULL, 'ace', '1-8::
    1s turn 2H, dance below 3s (2s step up 3-4); 1s cast up & in through
    2nd place, 1/2 turn 2H, pull back RSh to face 1st corners
9-24::
    1s dance "Turning Triangles":
::
    _9-12_    1s turn corner RH ending BtoB in centre (1M facing down,
    1L facing up). 1s & corners set as in Crown Triangles (1s start
    setting on Left foot)
::
    _13-16_  1s turn corner to Right by RH (4th corner) ending BtoB in
    centre facing own sides. 1s set as in Double Triangles
::
    _17-24_  Repeat 9-16, 1s turning & setting with 3rd then 2nd
    corners.  Bars 23-24 1s 1/2 turn 2H to face up
::
    Supporting corners set diagonally whilst others turn RH
25-32::
    1s dance up to top, cast to 3rd place (3s step up 27-28) & all turn
    2H once round, pull back RSh & cast to own sides', 0);
INSERT INTO 'dancecrib' VALUES (9011, '2015-11-30 08:59:56.575119+00', '2023-02-04 01:20:47.382275+00', 11746, 3, NULL, 'ace', '{{explanation}}
2 chords - 3s+4s cross to opp sides on 2nd chord

1-8::
    1s+4s set, cast in to 2nd & 3rd place (2s+3s step up/down bars 3-4).
    1s+4s turn prtnr RH 1/2 way,  1M dances to 3L place, 4M to 2M place,
    1L (pull back RSh) to 2L place & 4L to 3M place. Ladies face out
9-12::
    2s+4M+1L also 3s+1M+4L dance LH across 1/2 way.  2s+3s dance RH
    across 1/2 way
13-16::
    2s+1M+4L also 3s+4M+1L dance LH across 1/2 way.  1s+4s dance RH
    across 1/2 way.  End 1M+4L face up, 4M+1L face down in prom hold
17-20::
    _1/2_ RSh reels of 3 across - 1M+4L pass 3L RSh, 4M+1L pass 2L RSh
    to start
21-24::
    _1/2_ LSh reels of 3 on sides - 1M+4L on Ladies'' sides (pass 2L
    LSh), 4M+1L on Men''s side (pass 3L LSh)
25-28::
    1s+4s dance RH across, Ladies pull back RSh to 1L face down, 4L face
    up
29-32::
    1s dance down between 3s & cast up to 3rd place, 4s dance up between
    2s & cast to 2nd place   2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (5978, '2013-08-21 08:31:17.554035+00', '2023-02-04 01:20:47.450558+00', 3502, 3, NULL, 'ace', '1-8::
    1s+2s set & dance RH across 1/2 way, set & dance LH across 1/2 way
9-16::
    1s cross & cast to bottom, lead up & turn to face 2s (Lady facing
    Man)
17-24::
    1s dance 1/2 RSh reel of 4 with 2s & turn partner RH to face 3s, 1s
    dance 1/2 RSh reel with 3s & turn partner RH to 3rd place (facing
    out)
25-32::
    All dance reel of 3 on sides (2s out & 3s in & up to start) but as
    each cpl dance down thru 2nd pl they cross to their own side to
    complete the reel', 0);
INSERT INTO 'dancecrib' VALUES (5979, '2013-08-21 08:31:17.562288+00', '2023-02-04 01:20:47.597455+00', 3504, 3, NULL, 'ace', '1-8::
    1M followed by 2M+3M dance across, down behind Ladies & back to
    places
9-16::
    1L followed by 2L+3L repeat
17-24::
    1s slip step to bottom & back
25-32::
    1s cast to 4th place (2s+3s+4s step up 27-28) & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5980, '2013-08-21 08:31:17.572223+00', '2023-02-04 01:20:47.737775+00', 3506, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to top
9-16::
    1L+2M set & turn RH; 1M+2L set & turn RH into a line of 4 across
    (Bar 16 1L steps in to be BtoB with partner, 1M facing 2L, 1L facing
    2M)
17-24::
    1s+2s dance reel of 4 across
25-32::
    1s+2s Promenade
33-40::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (11200, '2018-09-30 22:20:00.078852+00', '2023-02-04 01:20:47.764204+00', 18575, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    All circle 4H round & back
9-16::
    All dance RH across & LH back
17-24::
    All dance DoSiDo & turn partners LH
25-32::
    All in prom hold Adv+Ret, couples facing clockwise make arches &
    dance on 2 places as others dance under', 0);
INSERT INTO 'dancecrib' VALUES (12922, '2020-07-01 00:20:12.981298+00', '2023-02-04 01:20:47.788161+00', 16065, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s cross LH, cast (3s step up)
9-16::
    1s dance reels of 3 on opp sides:
::
    1M crosses set to pass 3L LSh, 1L crosses diagonally to pass 3M LSh
    to start, 1s pass 2s RSh (3s down/right, 2s down/left to start).
    End: 1L crosses back to 3rd place own side _while_ 1M crosses down
    from 2nd place to 3rd place own side. 1M pulls back LSh to face up
17-24::
    1s dance LSh reels of 3 on own side. 2 3 1
25-32::
    1s set, cast up to 2nd place (3s step down); 2s+1s+3s turn partners
    RH
33-40::
    2s+1s+3s circle 6H round & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4050, '2013-08-21 08:30:42.720681+00', '2023-02-04 01:18:29.994205+00', 14431, 3, NULL, 'ace', '1-8::
    All circle 8H round to left, pivot & chase back to places
9-16::
    1L & 3L followed by partners pass RSh & dance to opposite Mans place
    & curve round left to opposite places & turn partner LH _while_ 2L &
    4L turn partner LH & followed by partners pass RSh & dance to
    opposite Mans place & curve round left to opposite places
17-24::
    All repeat bars 9-16
25-32::
    All Ladies advance setting into centre, circle 4H round to left &
    retire (PdB)
33-40::
    1M+3L also 1L+3M 1/2 turn RH, twirl & dance out to opposite places,
    2M+4L also 2L+4M 1/2 turn RH, twirl & dance out to opposite places
41-48::
    All repeat bars 33-48 back to places
49-56::
    All Men advance setting into centre, circle 4H round to right &
    retire (PdB)
57-64::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4051, '2013-08-21 08:30:42.73297+00', '2023-02-04 01:18:30.025671+00', 12243, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1M+3L also 1L+3M dance 1/2 Fig of 8 round 2s/4s, 1/2 turn & twirl
    back to place, finishing facing out
17-24::
    1M & 3M turn corner RH _while_ partners turn corner LH, all set to
    partner & turn 2H (skip change of step)
25-40::
    2s & 4s repeat bars 9-24
41-48::
    All Ladies dance RH across 1/2 way, dance round opp Man LSh & dance
    RH across 1/2 way back to place
49-56::
    All Men dance LH across 1/2 way, dance round opp Lady RSh & dance LH
    across 1/2 way back to place
57-64::
    All promenade round anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (9172, '2016-06-16 22:41:27.938323+00', '2023-02-04 01:18:30.059117+00', 11197, 3, NULL, 'ace', '1-8::
    1M+2L set advancing, change places RH.  1L+2M set advancing, change
    places LH.
9-16::
    2s+1s set, cross RH.  1L casts down, 1M cast up, pass RSh in middle
    to face 1st corners.
17-24::
    1s set to & turn 1st corners RH, pass partner LSh, set to & turn 2nd
    corner RH.  Finish facing 1st corners.
25-32::
    2s+1s+3s dance 6 bar reels of 3 on sides (LSh to 1st corner).  1s
    cross RH to 2nd place own sides.', 0);
INSERT INTO 'dancecrib' VALUES (5981, '2013-08-21 08:31:17.612806+00', '2023-02-04 01:20:47.816362+00', 3509, 3, NULL, 'ace', '1-8::
    All dance reels of 4 on sides
9-16::
    1s cross RH, cast down 1 place & dance 1/2 Fig of 8 (Man round 2s &
    Lady round 3s) to 2nd place on own side
17-24::
    2s+3s set facing diagonally _while_ 1s 3/4 turn RH, 1L dances up,
    casts behind 2L+3L & into the centre to face 4s & sets _while_ 4s
    1/2 turn RH _while_ 2s+3s advance with 2 pas de Basque & circle left
    round 1M (as he sets) & out to places
25-32::
    2s+3s dance R&L (round 1M who sets) _while_ 1L+4s circle for 2 steps
    & 1L leads 4s up Men''s side & down Ladies side with 1M (last 2 bars)
    dancing up to join on end of line
33-40::
    1L leads line across bottom, up to 3rd place, across & down to 4th
    place (to 2 3 4 1), 1s & 4s set diagonally
41-48::
    1s & 4s advance for 2 steps, join hands raised & retire, 2s+3s also
    4s+1s dance RH across', 4);
INSERT INTO 'dancecrib' VALUES (5982, '2013-08-21 08:31:17.621531+00', '2023-02-04 01:20:48.083187+00', 9051, 3, NULL, 'ace', '1-8::
    1s cross down RH, cast to right, dance down/up to meet partner &
    turn RH 1.1/2 times
9-16::
    1s dance RSh reels of 3 across (1M with 2s & 1L with 3s) & end
    facing 1st corners
17-24::
    1s dance 1/2 Corner Chain with 1st corners:
::
    1s+1st corners change pl RH, 1st crnrs turn LH in centre & return to
    places giving RH to 1s who turn LH in centre to 1L facing 2s & 1M
    facing 3s
25-32::
    1s dance RH across (1L with 2s & 1M with 3s) & changing places dance
    LH across with other couple 1s end facing 2nd corners
33-40::
    1s dance 1/2 Corner Chain with 2nd corners:
::
    1s+2nd corners change pl RH, 2nd crnrs turn LH in centre & return to
    places giving RH to 1s who turn LH in centre to end 2nd place own
    sides
41-48::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (11700, '2019-03-18 21:02:24.221443+00', '2023-02-04 01:20:48.105848+00', 3516, 3, NULL, 'ace', '1-8::
    1s cross down to dance reel of 3 on opp sides, all giving hands
    where possible. End 1s NHJ dance to 2nd place & face 3s, 2s dance
    out/up to 1st place, 3s in original place
9-12::
    1s make arch, dance to 3rd place on men''s side facing out, set
    inwards & join NH to face 3L _while_
::
    3M dances up under arch, LSh round 2L to just above her & they join
    NH
13-16::
    3M+2L also 1M+1L make arches, dance across set, turn inwards to face
    partners _while_
::
    2M & 3L dance under arches, meet in centre in 2nd place & 1/2 LH
17-20::
    3s+2L (at top) & 1s+2M (3rd place) dance RH across, all finishing on
    sides 3 2 1
21-24::
    All turn partners RH, 3s finishing at top on own sides, 2s+1s
    finishing in middle facing up in promenade hold
25-32::
    3s cast to 3rd place & stand for 6 bars _while_ 2s+1s dance up &
    into a 2 couple promenade.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5983, '2013-08-21 08:31:17.629896+00', '2023-02-04 01:20:48.122152+00', 7782, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Figs of 8 (Man up & Lady down)
9-16::
    2s+1s+3s dance Diag R&L, 1s ending in middle LSh to LSh each facing
    own sides
17-24::
    1L+2s also 1M+3s dance RH across 1/2 way, 2s & 3s continue to turn
    as 1s dance 1/2 way round outside clockwise & dance RH across with
    other couple, 1s end facing 1st corner pstns
25-32::
    1s dance 1/2 diagonal reel of 4 with 1st corners then 1/2 reel with
    2nd corners, 1s end in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (3980, '2013-08-21 08:30:40.775399+00', '2023-02-04 01:18:25.063515+00', 108, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s+3s dance 1/2 reels of 3 on opposite sides, 1s (in 3rd pl)
    dance in to change pl on sides with 2s & turn 3s with other hand
    once round
9-16::
    3M+2L change places RH (diag), 3L+2M change places RH, 2s+1s+3s
    cross to own sides & set with 1s advancing to face 1st corners

{{title}}
Reel

17-24::
    1s change places with corners RH, 2s+3s dance LH across once round
    in middle, 1s change pl with crnr persons & pass RSh to face 2nd
    crnrs
25-32::
    1s repeat with 2nd corners LH (RH in middle) & 1s dance into 2nd
    place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4052, '2013-08-21 08:30:42.742966+00', '2023-02-04 01:18:30.080884+00', 209, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance, in 3s, all facing anticlockwise  
2 Chords  1 - Men step forward & turn to face partners, 2 - Bow & curtsy

1-8::
    All dance RH across & LH across
9-16::
    Man sets & turns RH Lady on right, sets & turns RH Lady on left
17-24::
    Man dances reel of 3 with his partners giving LSh to Lady on right
25-32::
    All facing anticlockwise Adv+Ret, Men dance between next 2 Ladies &
    turn right about to face them', 0);
INSERT INTO 'dancecrib' VALUES (5984, '2013-08-21 08:31:17.638389+00', '2023-02-04 01:20:48.1438+00', 8557, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All Petronella-in-tandem 1 place to right, set, Petronella-in-tandem
    1 place to right & set
17-24::
    Ladies dance RH across once round & face partners, set & turn
    partners LH
25-32::
    1s+3s dance Ladies Chain
33-40::
    1s+3s dance reel of 4 up/down with Ladies passing LSh to start
    Ladies end facing in with corners holding nearer hands
41-48::
    All Adv+Ret with corners, Adv+Ret with partners
49-56::
    2s+4s dance reel of 4 across with Ladies passing LSh to start
57-64::
    2s+4s dance Men''s Chain
65-72::
    Men dance LH across once round & face Partners, set & turn partner
    RH back to place
73-80::
    All petronella on 1 place to right, set, petronella on 1 place to
    right & set
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5985, '2013-08-21 08:31:17.648853+00', '2023-02-04 01:20:48.174063+00', 10936, 3, NULL, 'ace', '1-8::
    All Men dance anticlockwise round set _while_ Ladies dance RH across
    & circle 4H round to left to face partner (Ladies BtoB)
9-16::
    All set, turn prtnr (1s/3s LH, 2s/4s RH), 1L+2L also 3L+4L dance out
    between prtnrs, divide & dance round prtnr into 2 diag lines (Ladies
    in middle)
17-24::
    All couples rotate 1.1/2 times into diag lines (Men in middle &
    Ladies facing in) & all set
25-32::
    All Adv+Ret 2 steps, turn partners 2H into Sq.Set & all set
33-40::
    All dance interlocking reels of 4 (pass partner RSh to start) & turn
    partner RH to Men in centre with partner facing anticlockwise
41-48::
    Men with partner on right wheel 1/2 way anticlockwise, all dance out
    HS & back to centre
49-56::
    All wheel 1/2 way anticlockwise, all dance out HS but Men only dance
    back to centre
57-64::
    Men dance LH across 1/2 way, turn opposite Lady 2H,dance LH across
    1/2 way & turn partner 2H into Sq.Set
65-72::
    1M followed by 2L+2M+3L also 1L followed by 4M+4L+3M dance down &
    out through 3rd place, divide casting back to places & all set
73-80::
    All circle 8H round to left for 3 bars, 1st Man leads all into
    straight line & all Bow/Curtsey to honoured guest (or circle 8H
    round & back)', 0);
INSERT INTO 'dancecrib' VALUES (5986, '2013-08-21 08:31:17.657365+00', '2023-02-04 01:20:48.198292+00', 9868, 3, NULL, 'ace', '{{explanation}}
 Easier version of »The Kirrie Lads«

1-8::
    All set & cross RH, 1s+2s also 3s+4s dance RH across once round
9-16::
    All dance 1/2 4 Couple Rights & Lefts:
::
    _9-10_     All cross Right Hands
::
    _11-12_    Dancers in 1M & 2M places also 3L & 4L places change
    places Left Hands on sides _while_ dancers in 1L place & 3M place
    cross diagonally LH as dancers in 2L place & 4M place cross
    diagonally LH
::
    _13-16_   Repeat Bars 9-12 to end facing own partner.  4 3 2 1
17-24::
    Bottom 3 couples (3s+2s+1s) set, cross RH & chase clockwise 1/2 way
    round to end 4 1 2 3
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5987, '2013-08-21 08:31:17.665834+00', '2023-02-04 01:20:48.218799+00', 9365, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s set, dance 1/2 RH across, couples in 2nd & 4th places
    (1s & 3s) dance 1/2 Figs of 8 round couples above them
9-16::
    All dance 1/2 4 Couple Rights & Lefts:
::
    _9-10_     All cross RH
::
    _11-12_    Dancers in 1M & 2M places also 3L & 4L places change
    places LH on sides _while_ dancers in 1L & 3M places cross
    diagonally LH as dancers in 2L & 4M place cross diagonally LH
::
    _13-16_    Repeat Bars 9-12 to end facing own partner.  (3) 4 (1) 2
17-24::
    Bottom 3 couples (4s+1s+2s) set, cross RH & chase clockwise 1/2 way
    round
25-32::
    Couples in 2nd & 4th places (2s & 4s) dance 1/2 Figs of 8 round
    couples above them, all dance 1/2 R&L to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13089, '2020-08-10 00:20:08.092489+00', '2023-02-04 01:20:48.257077+00', 17921, 3, NULL, 'ace', '1-8::
    _1- 8_  1s+2s dance the Bourrel:
::
    1M+2L set advancing, 3/4 turn RH & twirl to end BtoB (Lady facing up
    & Man down) _while_ partners chase anticlockwise 1/2 way
::
    Set to partners & turn 3/4 RH 2s to own sides 1s to face 1st corners
9-16::
    _9-12_    1s pass corners RSh, pass RSh to face 2nd corners _while_
    corners Advance, slap thighs, Bar 10: clap own hands & clap other
    opp corner 2H, corners Retire
::
    _13-16_  1s+2nd corners repeat 9-12.  1s end joing RH facing up in
    middle
17-24::
    Mirror reels of 3 on sides giving hands, 1s dance up & cross to own
    side,  2s out/down, 3s out/up to start.  End 2s at top facing out,
    1s in 2nd place in middle facing up
25-32::
    Non-progressive Allemande:
::
    _25-26_   1s dance up middle in prom hold before changing to
    allemande hold _while_ 2s  cast off, meet in 2nd place & take prom
    hold
::
    _27-28_   1s dance bars 3-4 of a standard allemande for two couples
    _while_ 2s dance up the middle & into allemande hold & follow 1s
::
    _29-32_   2s + 1s dance bars 5-8 of a standard allemande for two
    couples.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5989, '2013-08-21 08:31:17.683895+00', '2023-02-04 01:20:48.272184+00', 10912, 3, NULL, 'ace', '{{explanation}}
Round the Room 3 facing 3

1-8::
    All circle 6H round & back
9-16::
    All turn opposite person RH, all turn opposite person LH
17-24::
    Middle person dances RH across with partner & opposite person on
    right & LH back
25-32::
    All Adv+Ret for 2 steps & pass RH to meet next trio', 0);
INSERT INTO 'dancecrib' VALUES (3981, '2013-08-21 08:30:40.785234+00', '2023-02-04 01:18:25.094497+00', 109, 3, NULL, 'ace', '1-8::
    1s+2s set to partners, turn 2H & dance 1/2 Diamond Poussette
9-16::
    1s followed by 2s lead down & back to original places (2s dividing &
    turn in behind 1s)
17-24::
    1s+2s dance reel of 4 across (1L & 2M passing LSh to start)
25-32::
    1s+2s dance Tournee:
::
    1s+2s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 2s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (2s RH, 1s LH) & dance
    out to places', 0);
INSERT INTO 'dancecrib' VALUES (4085, '2013-08-21 08:30:43.258929+00', '2023-02-04 01:18:33.425704+00', 268, 3, NULL, 'ace', '{{explanation}}
 3s & 4s start on opp. sides

1-8::
    1s+2s also 3s+4s dance 1/2 double Fig of 8 (2s & 3s cross up/down to
    start), 1M+2M also 3M+4M turn RH on sides _while_ partners turn LH
9-16::
    Repeat using other hand to turn on sides
17-24::
    _17-18_  2L+3M cross to Men''s side (2L passing in front of 3M to 3rd
    place, 3M to 2nd place) _while_ partners cross to Ladies'' side opp
    partners
::
    _19-20_  2M+3L cross back to Men''s side (3L passing in front of 2M,
    3L to 2nd place, 2M to 3rd place) _while_   partners cross to
    Ladies'' side opp partners
::
    _21-24_  3s (in 2nd place) turn partner RH _while_ 2s turn LH
25-32::
    2s & 3s repeat 17-20 back to original place; 2s turn RH _while_ 3s
    turn LH
33-40::
    All Petronella turn into centre, set & 3/4 turn RH, 1s+2s also 3s+4s
    dance 1/2 RH across.  2 1 (4) (3)
41-48::
    1s+4s dance LH across, 2s+1s also 4s+3s dance RH across
49-56::
    All dance reels of 4 on sides ending 1M & 4L also 1L & 4M passing
    RSh giving RH into prom hold to face each other across set
57-64::
    1M+4L & 4M+1L promenade 1/2 way round each other (Ladies passing
    RSh. On 4th bar they dance in to join nearer hands with partner with
    4s in 2nd place facing up & 1s in 3rd place facing down; 4s & 1s
    dance up/down & cast to 2nd/3rd place.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (5990, '2013-08-21 08:31:17.692125+00', '2023-02-04 01:20:48.294834+00', 3526, 3, NULL, 'ace', '1-4::
    1M+2M set advancing to partners, set to opp woman, then set to own
    partner
5-8::
    1M+2M retire then set to each other as partners set to each other
    then to 1M+2M, then set to partners
9-16::
    1L+2L repeat above Fig
17-24::
    1s lead down the middle & back to top
25-32::
    1s+2s set, cross RH & circle 4H round 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (5991, '2013-08-21 08:31:17.703537+00', '2023-02-04 01:20:48.323906+00', 10562, 3, NULL, 'ace', '1-8::
    1s cross RH, 1M followed by 1L dances behind Ladies crosses below 3s
    up to 2nd pl (1L up centre, 1M behind 3M) & pass RSh to face 1st
    crnrs
9-16::
    1s turn corner RH, partner LH, 2nd corner RH & partner LH to end in
    middle LSh to LSh facing own sides
17-24::
    1s dance Figs of 8 on own sides (1s out & down to start) & turn RH
    at top _while_ 2s+3s dance R&L & 1s+2s end in centre for…
25-32::
    1s+2s dance Allemande (with a kiss on bar 30?)', 0);
INSERT INTO 'dancecrib' VALUES (5992, '2013-08-21 08:31:17.72156+00', '2023-02-04 01:20:48.443751+00', 3529, 3, NULL, 'ace', '1-8::
    1s set, cast down 1 place & circle 4H round to left with 3s
9-16::
    1s set, cast up & circle 4H round to left with 2s
17-24::
    1s lead down for 2 steps & back up to top, cast 1 place & turn RH to
    face down
25-32::
    1s lead down below 3s, cast up to 2nd place & 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (8027, '2013-09-09 06:47:35.813514+00', '2023-02-04 01:20:48.460948+00', 14977, 3, NULL, 'ace', '1-8::
    1s cast  & dance behind lines to bottom & turn outwards to dance
    back to top
9-16::
    1s cross down to dance reels of 3 on opposite sides to end in
    partners place
17-24::
    1s lead down middle & cross to own sides (Lady under Mans arm), 1s
    lead up to top & end facing partner with 2H joined
25-32::
    1s+2s dance Poussette  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5993, '2013-08-21 08:31:17.729714+00', '2023-02-04 01:20:48.482615+00', 8492, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, 1M & 2L set _while_ 1L+2M change places RH,
    1s+2s chase clockwise 1 place
9-16::
    2s+1s dance RH across, 1s+3s dance LH across
17-24::
    1s+3s repeat bars 1- 8
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5994, '2013-08-21 08:31:17.737929+00', '2023-02-04 01:20:48.519417+00', 3536, 3, NULL, 'ace', '1-8::
    1s & 3s dance 1/2 Figs of 8 round couple below, 1s+2s also 3s+4s
    dance 1/2 Ladies'' Chain
9-16::
    1L+2L also 3L+4L dance LSh round partners (on sides) to end facing
    ptnr in diagonal lines & dance 1/2 reel of 4 ending (2) 1 (4) 3 in
    prom hold
17-24::
    All in prom hold dance 6 bars of reel of 4 (2s+1s also 2s+4s pass
    RSh to start) ending 4s+3s+2s in middle facing up & 1s in 4th place
    own side
25-32::
    4s+3s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5995, '2013-08-21 08:31:17.752093+00', '2023-02-04 01:20:48.684081+00', 3537, 3, NULL, 'ace', '1-8::
    1s set twice, turn RH & cast below 2nd place
9-16::
    1s lead down the middle for 3 steps, back to top & cast 1 place to
    face 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s lead down between 3s, cross & cast up round 3s, dance up between
    2s & cast back to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5996, '2013-08-21 08:31:17.760332+00', '2023-02-04 01:20:48.711609+00', 3538, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place & dance RH across in centre
9-16::
    2s & 3s repeat
17-24::
    All set, 1s+2s also 3s+4s dance 1/2 R&L, all set
25-32::
    2s+1s also 4s+3s dance double Fig of 8 (1s & 4s cast to start)
33-40::
    1s+4s dance the Rondel', 0);
INSERT INTO 'dancecrib' VALUES (5997, '2013-08-21 08:31:17.766582+00', '2023-02-04 01:20:48.729731+00', 12122, 3, NULL, 'ace', '1-8::
    Ladies set Advg, set turning about once round & dance RH across to
    end facing partner
9-16::
    All dance DoSiDo with partner, turn partner RH (4 bars) to end in
    original places Ladies facing out
17-24::
    All dance 1/4 Schiehallion Reel (1 place) & turn partners RH (4
    bars)
25-32::
    All circle 8H round to left for 6 steps, pivot left & chase back to
    ''new'' places', 0);
INSERT INTO 'dancecrib' VALUES (4086, '2013-08-21 08:30:43.284785+00', '2023-02-04 01:18:33.548599+00', 273, 3, NULL, 'ace', '1-8::
    1s & 5s dance a Fig of 8 round next couple casting to start _while_
    3s petronella to opposite sides
9-16::
    1s & 5s cast in 1 place & set _while_ 3s turn RH 1.1/2 times back to
    places, 1s & 5s turn partners RH 1.1/2 times & end facing 1st
    corners
17-24::
    1s & 5s dance ''Hello-Goodbye'' setting ending with a petronella turn
    to 2nd/4th places
25-32::
    1s followed by 3s+5s+4s cast (3s ending in 4th place & 4s in 2nd
    place), all turn partners RH (4 bar slow turns).  2 4 5 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5998, '2013-08-21 08:31:17.775234+00', '2023-02-04 01:20:48.760604+00', 9160, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, cross RH & cast into their 1st corner (pstn)
    as 1st corners dance in & loop round to face 1st corner (pstns)
9-16::
    Original 1st corners dance reels of 3 on sides passing 1st corner
    (pstns) RSh
17-24::
    1L & 2L also 1M & 3M pass LSh to dance reels of 3 across (original
    1st corner persons dance to their corners to enter reel), original
    corners end in their corners as 1s loop round to face their 1st
    corners
25-32::
    1s turn 1st corner RH, pass RSh, turn 2nd corner RH & pass RSh to
    2nd place own side

{{title}}
Alternate ending

{{explanation}}
On bar 24 1M ends between 3s facing up & 1L between 2s facing down

25-32::
    1s change places RH, cast round 2nd corner to end in 2nd place on
    opposite sides & 2s+1s+3s Adv+Ret

{{explanation}}
1s now repeat the dance as opposite gender', 0);
INSERT INTO 'dancecrib' VALUES (5999, '2013-08-21 08:31:17.785104+00', '2023-02-04 01:20:48.86663+00', 3541, 3, NULL, 'ace', '1-8::
    1L+2M Adv+Ret, turn 2H (Skip Change of step)
9-16::
    1M+2L Adv+Ret, turn 2H
17-24::
    1s followed by 2s (who first dance up) lead down middle & 2s lead
    back to 1st place followed by 1s who end in 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6000, '2013-08-21 08:31:17.793328+00', '2023-02-04 01:20:48.877635+00', 3544, 3, NULL, 'ace', '1-8::
    1s+2s dance 3/4 R&L & 2s+1s+3s set.  2 1 3
9-16::
    1s dance 1/2 Figs of 8 (Lady round 2s & Man round 3s) & dance RH
    across (Man with 2s & Lady with 3s)
17-24::
    1s dance 1/2 Figs of 8 (Lady round 2s & Man round 3s) & dance LH
    across (Man with 2s & Lady with 3s)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10084, '2017-09-03 23:44:53.495593+00', '2023-02-04 01:20:48.956759+00', 16205, 3, NULL, 'ace', '{{explanation}}
Couples in circle, Men in centre facing partner

1-8::
    Men Adv+Ret. (4 bars)  Ladies Adv+Ret (4 bars)
9-16::
    All dance DoSiDo with partner, all passing partner RSh dance round
    partner & back to place
17-24::
    _17-18_   All turn partner 3/4 RH (Men facing in, Ladies facing out)
::
    _19-22_   All turn next person 1.1/2 LH (Men facing out, Ladies
    facing in)
::
    _23-24_   All  turn new partner 3/4 RH to end Men with back to
    centre facing Ladies
25-32::
    All circle round to Left & back (Men''s circle & Ladies'' circle)', 0);
INSERT INTO 'dancecrib' VALUES (13248, '2020-10-16 00:20:36.563349+00', '2023-02-04 01:20:48.982617+00', 11616, 3, NULL, 'ace', '1-8::
    1s dance in & down NHJ (2 bars), turn 2H; cast up 1st place own side
    _while_
::
    2s cast up (2 bars), dance in & down NHJ (2 bars); turn 2H (2 bars),
    dance down & cast up into 3rd place _while_
::
    3s dance in & cast up to top (4 bars); dance in & down NHJ & turn 2H
    to 2nd place
9-16::
    1s & 3s dance Double Fig 8 giving hands (1s cross down, 3s cast up
    to start)
17-24::
    1s+3s+2s dance 6 bar mirror reels of 3 on sides (1s in/down, 3s
    out/up, 2s in/up), 1s dance down to 2nd place _while_ 3s cast to top
    & 2s turn 2H
25-28::
    3s turn 2H to face down _while_ 1s+2s set facing down/up on sides (2
    bars); 3s (at top) & 2s (3rd place) set _while_ 1s turn 2 hands (2
    bars). 3 1 2
29-32::
    1s+3s dance down & cast, 1s into 3rd place, 3s into 2nd place
    _while_ 2s cast up to 1st place (2 bars), 2s+3s+1s set', 0);
INSERT INTO 'dancecrib' VALUES (13249, '2020-10-16 00:20:36.583628+00', '2023-02-04 01:20:49.008439+00', 8684, 3, NULL, 'ace', '1-8::
    All face partner & dance 1/2 Grand Chain, no hands (6 bars), all set
    to partner
9-16::
    Repeat 1-8
17-24::
    Ladies dance RH across _while_ Men chase clockwise 1/2 round; all
    turn ''new partner'' 1.1/2 LH to bring Men into centre
25-32::
    Men dance RH across _while_ Ladies chase anticlockwise 1/2 round;
    all turn partner 1.1/4 LH to form square set again. 3 4 1 2 (all opp
    original place)
33-40::
    1s+3s BHJ slip across (Ladies pass BtoB) _while_ 2s+4s stamp x3 or
    set; 2s+4s repeat, 1s+3s stamp x3 or set; repeat back to places
41-48::
    All polka clockwise once round set & face partner. 3 4 1 2
49-64::
    »Drambuie Chain«:  all Advance (1) Pas de Valse, take partner''s RH
    then Retire (1) PdeV, cross RH with partner to meet next person;
    repeat 3 more times, Ladies face out.  3 4 1 2
65-80::
    Schiehallion Reels (16 bars), finish with partner in Allemande hold
    facing anticlockwise
81-88::
    All promenade anticlockwise 1.1/4 round, drop RH
89-96::
    Ladies followed by their partners chase 3/4 round clockwise to 4 1 2
    3 (4 bars); all circle 8H round to right to end 1 2 3 4', 0);
INSERT INTO 'dancecrib' VALUES (10445, '2018-02-24 07:52:46.997698+00', '2023-02-04 01:20:49.258424+00', 17757, 3, NULL, 'ace', '1-8::
    Extended Espagnole (4 couples):
::
    _1-2_    1L+2L also 3L+4L lead RH across to opp sides and cross
    _while_ 2M+3M lead LH to opposite sides and cross _while_ 1M & 4M
    cross singly (Ladies 2143 on Men''s side, Men: 1324 on Ladies'' side)
::
    _3-8_    Repeat 3 more times from new positions to end 4 3 2 1
9-16::
    3s turn 1.1/2 LH _while_ 2s turn 1.1/2 RH (4 bars).  4s+3s also
    2s+1s Set+Link (3) 4 1 (2)
17-24::
    4s+1s dance LH across _while_ 3s & 2s chase 1/2 round clockwise.
    2s+4c & 1s+3s dance RH across  2 4 1 3
25-32::
    RSh Reels of 4 on the sides, 4M+1M end with 1/2 LH turn, retaining
    hands ready for repeat.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13901, '2021-04-05 00:20:24.538806+00', '2023-02-04 01:20:49.285002+00', 3552, 3, NULL, 'ace', '1-4::
    1s+2s+3s set, 1M+2L also 2M+3L change places RH
5-8::
    1M+3M also 1L+3L change places LH, 1L+2M also 2L+3M change places
    RH.  3 2 1
9-16::
    1s+2s (at bottom) dance 1/2 R&L;  1s+3s (at top) dance 1/2 R&L.  1
    (3) (2)
17-20::
    1s lead down, cross below 3rd place & cast up to 2nd place opp sides
    (3s step up 19-20).  (3) (1) (2)
21-24::
    1s dance 1/2 Fig 8 up round 3s.   (3) 1 (2)
25-28::
    3s+1s+2s cross passing partner RSh (1 bar) & circle 6H 1/2 round.
    (2) 1 (3)
29-32::
    2s+1s+3s cross passing partner RSh (2 bars), 1s cross RH to 2nd
    place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15157, '2022-10-05 00:22:26.303886+00', '2023-02-04 01:23:08.602989+00', 20781, 3, NULL, 'ace', '1-8::
    1s dance in, cast to 2nd place (2s step up 3-4); 1s set advancing &
    3/4 turn 1st corners RH to 1L between 2s,1M between 3s all facing
    down
9-16::
    Line of 3 across dance down; pull back RSh & dance up to finish 1L
    between 2s facing down, 1M between 3s facing up
17-28::
    All dance R&L for 3 couples:
::
    _17-18_  All 3 couples cross RH with dancer opposite
::
    _19-20_  Dancers in 1M place & 3L place change places diagonally LH
    _while_ other couples change places LH on side
::
    _21-28_  Repeat bars 1-4 from new places twice to end 1L between 2s
    at top, 1M between 3s at bottom
29-32::
    1s turn 1.1/4 RH to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14200, '2021-08-14 00:18:28.672966+00', '2023-02-04 01:18:30.108151+00', 12135, 3, NULL, 'ace', '1-8::
    1M & 2L dance round their partners with RSh back to place; 1L & 2M
    dance LSh round their partners to finish in a diagonal line facing
    their partners
9-12::
    1L & 2M change places RH with partners (2 bars),  1L & 2M dance 1
    place anticlockwise _while_ 1M & 2L turn 3/4 LH to meet partners (2
    bars)
13-16::
    1M & 2L change places RH with partners (2 bars), 1M & 2L dance 1
    place anticlockwise _while_ 1L & 2M turn 3/4 LH to meet partners (2
    bars)
17-24::
    Repeat bars 9-16 but in last 2 bars 1M & 2L dance to place _while_
    1L & 2M cross LH to place. All finish curving through their places
    to meet in Promenade hold facing up
25-32::
    1s+2s dance Allemande.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (15165, '2022-10-07 21:51:37.331223+00', '2023-02-04 01:20:49.319578+00', 21148, 3, NULL, 'ace', '1-8::
    1s+2s dance Double Fig 8 giving hands (1s cross down, 2s dance up)
9-12::
    1s dance down NHJ & face (2 steps) _while_ 2s continue to dance up,
    1s set advancing passing LSh to face 1st corners
13-16::
    1s dance RSh round corner to face each other (1M between 3s, 1L
    between 2s) _while_ 1st corners turn 2H & dance back to place
17-20::
    Lines of 3 across set, 1s set advancing passing LSh to face 2nd
    corners
21-24::
    1s dance RSh round corner to 2nd place opp side _while_ 2nd corners
    turn 2H & dance back to place
25-28::
    All 3 couples set on sides, 1s turn RH once round
29-32::
    1s dance 1/2 Fig 8 (1L up, 1M down) to 2nd place own side
33-40::
    1s+3s dance Espagnole:
::
    _33-34_   1s+3s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _35-36_   1s+3s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _37-40_   3s turn RH as 1s turn LH to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6004, '2013-08-21 08:31:17.828374+00', '2023-02-04 01:20:49.344077+00', 3553, 3, NULL, 'ace', '1-8::
    1s set, dance in & cast 1 place to face 2nd corner, 1/2 turn corner
    2H to form diagonal line across set
9-16::
    1s with 2nd corners Set+Link, 1s pass LSh to face 1st corners & 1/2
    turn into diagonal line
17-24::
    1s with 1st corners Set+Link, 1s pass RSh to face 2nd corners & turn
    2nd corners 2H to end 2nd place between corners
25-32::
    2s+1s+3s Set+Link for 3 once, set & 1s cast to right to own sides
    _while_ 3s+2s change places RH on sides', 0);
INSERT INTO 'dancecrib' VALUES (6005, '2013-08-21 08:31:17.834343+00', '2023-02-04 01:20:49.375329+00', 13351, 3, NULL, 'ace', '1-4::
    1s+2s dance the »Typhon«: 1M+2L 3/4 turn RH to face each other &
    twirl out to 2nd/1st place own sides _while_ partners set & cast
    (down/up) 1 place
5-8::
    1s dance 1/2 reels of 3 on own sides (RSh to 2s)  2 1 3
9-16::
    1M followed by 1L casts up & dances down the middle 1L to face 3M
    _while_ 1M faces 2M, 1s dance 1/2 RSh reels of 3 across
17-24::
    1M followed by 1L dances down, cast up round 2L & crosses to end in
    2nd place on opposite sides, all turn RH into prom hold facing down
25-32::
    3s+1s+2s dance »Japonaise« : 3s+1s+2s dance up Ladies side (3 bars),
    dance 1 slip step towards middle, face ptnr  & turn partner RH (4
    bars)
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9378, '2016-10-06 07:18:36.633197+00', '2023-02-04 01:20:49.398567+00', 17143, 3, NULL, 'ace', '1-8::
    1s+3s set to partners, 1L followed by 1M dances between 4s, behind
    4L & back to place _while_ 3L+3M dance similar between 2s, behind 2L
    & back to place (1s+3s pass LSh in middle)
9-16::
    2s+4s repeat, 2s dancing between 1s, behind 1L _while_ 4s dance
    between 3s, behind 3L, all back to places.  2M & 4M face out
17-20::
    All turn partners 3/4 LH, retain hands as Men join RH. All set
21-24::
    Men dance RH across 1.1/4 round _while_ Ladies dance 1/2 round set
    anticlockwise
25-32::
    All pass partners RSh & dance ''La Baratte''  (4L+3M, 1L+4M, 2L+1M &
    3L+2M) Ladies end in original places, Men one place round
    anticlockwise
::
    _27-28_    Man 1/2 turns opposite Lady RH & retains hand but at
    arm''s length from each other
::
    _29-30_    Man retraces steps with Lady turning right under Man''s
    arm briefly into Allemande hold (Man behind Lady facing Lady''s
    original place) & releasing Lady''s RH she turns under Man''s left arm
    until almost in original places
::
    _31-32_    Couple change places LH to opposite places
33-40::
    All pass dancer in corner RSh & dance ''La Baratte''  (1L+2M, 2L+3M,
    3L+4M, 4L+1M) Ladies end in original places, Men one place round
    anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (9379, '2016-10-06 07:18:36.640417+00', '2023-02-04 01:20:49.423745+00', 17177, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & dance La Baratte with partners:
::
    _1-4_     1s+2s+3s set, turn partner R hand 1/2 way and retain R
    hands
::
    _5-6_     All dance back retracing steps Lady turning Right under
    Man''s arm briefly into Allemande hold (Man behind Lady facing Ladies
    original place) & releasing Ladies RH she turns under Man''s left arm
    until almost in original places & couples change place LH to
    opposite sidelines, Men facing up, Ladies facing down
9-16::
    1s+2s+3s chase anticlockwise to end 3 2 1;  1s set, cast up (2s step
    down)  3 1 2
17-28::
    3s+1s+2s        dance R&L for 3 couples
29-32::
    3s+1s+2s turn partners RH once round', 0);
INSERT INTO 'dancecrib' VALUES (12865, '2020-06-03 16:26:42.870684+00', '2023-02-04 01:20:49.443355+00', 19956, 3, NULL, 'ace', '1-8::
    1s+2s dance the Tourbillon:
::
    _1-4_   1s & 2s turn partners 2H 1/2 way, 1M & 2L lead partners on 1
    place clockwise to end 1s on Ladies side & 2s on Men''s side, 1s set
    to 2s
::
    _5-8_   1s & 2s 1/2 turn partners 2H, 1L & 2M lead partners on 1
    place to end 2s in 1st pl & 1s in 2nd pl & 2s+1s cross RH to own
    sides.  2 1
9-16::
    2s+1s dance RH across and LH back
17-24::
    2s+1s dance modified Bourrel:
::
    _17-20_   1M+2L set advancing, 3/4 turn 2H & twirl to end BtoB (Lady
    facing up & Man down) _while_ partners chase anticlockwise 3/4 way
::
    _21-24_   1s+2s set to partners & turn RH into allemande hold facing
    up. 1 2
25-32::
    1s+2s dance an Allemande.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (11701, '2019-03-18 21:02:24.547444+00', '2023-02-04 01:20:49.474803+00', 18288, 3, NULL, 'ace', '1-8::
    1s turn 2H, dance down NHJ, out through side couples & cast back up
    own side to face partner, turn 2H & face in NHJ
9-16::
    All dance Set+Link & face partner; 1/2 interlocking Reels of 4 & all
    1/2 turn partner LH
17-24::
    All set advancing passing partner LSh, 1/2 turn next person 2H, pull
    back RSh to face next person, set advancing passing LSh, turn
    partner RH ending with L facing out (Bourrel-like sequence). 123
25-32::
    Triangular Schiehallion (clover leaf) reels 312', 0);
INSERT INTO 'dancecrib' VALUES (6040, '2013-08-21 08:31:18.350852+00', '2023-02-04 01:20:53.020035+00', 3616, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s+2s+3s dance Grand Chain
17-24::
    1s lead down the middle & back to places
25-32::
    1s+2s dance 1/2 R&L & turn 2H 1.1/2 times to places', 0);
INSERT INTO 'dancecrib' VALUES (3982, '2013-08-21 08:30:40.795099+00', '2023-02-04 01:18:25.135838+00', 10913, 3, NULL, 'ace', '1-8::
    1L followed by partner casts 2 places, crosses below 3s, casts up to
    2nd place & crosses to own sides
9-16::
    2L+1L turn RH as 2M+1M turn LH & dance reels of 3 on sides (1s dance
    in & down to start)
17-24::
    1s+3s dance Tournee:
::
    1s+2s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 2s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (2s RH, 1s LH) & dance
    out to places
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5291, '2013-08-21 08:31:04.294863+00', '2023-02-04 01:20:49.728085+00', 14599, 3, NULL, 'ace', '1-8::
    1s+2s dance the Bourrel :
::
    1M+2L set advancing, 3/4 turn 2H & twirl to end BtoB (Lady facing up
    & Man down) _while_ partners chase anticlockwise 1/2 way,
::
    set to partners & turn 2H (1s end Lady behind partner facing his 4th
    corner as 2s end 1st place own sides)
9-16::
    1s dance Alternating Tandem 1/2 reel with 4th corner, Alternating
    Tandem 1/2 reel with his 1st corner & end 2nd place opposite sides
17-20::
    1s cast round 2nd corners, cross to own side & cast to 2nd place
    _while_ 2s+3s dance 1/2 R&L
21-24::
    2s+1s+3s Adv+Ret (1 step) & set
25-32::
    2s+1s dance Diamond poussette right round', 0);
INSERT INTO 'dancecrib' VALUES (5301, '2013-08-21 08:31:04.487719+00', '2023-02-04 01:20:49.763997+00', 3558, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across 1/2 way, 1/2 turn RH, dance LH across 1/2 way
    & turn LH to places
9-16::
    1s petronella to 2nd place opposite sides
17-24::
    2s+1s+3s circle 6H round & back
25-32::
    1s dance reels of 3 on opposite sides giving RSh to person on their
    right & cross to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13178, '2020-09-15 00:20:21.430197+00', '2023-02-04 01:20:50.394449+00', 13216, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Fig of 8 Progression:
::
    1s & 3s cross RH, cast, cross up & cast to 2nd/4th place _while_ 2s
    & 4s set, cross up, cast one place & cross up to 1st/3rd place on
    own sides facing out 2 1 4 3
9-16::
    All dance RSh mirror reels of 4 on the sides (taking hands when
    possible)
17-24::
    1s & 3s set, 3s cast up to 2nd place _while_ 1s NHJ dance down &
    cast into 4th place. 2s & 4s turn RH
25-32::
    All ladies dance Glasgow Highlanders setting step turning _while_
    all men, NHJ, dance rocking step. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14663, '2022-03-07 02:20:21.231811+00', '2023-02-04 01:20:50.426234+00', 16520, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole, finish with 2sin 1st place facing out, 1s in
    2nd place facing up
9-16::
    2s+1s+3s dance mirror reels of 3 on the sides (1s in/up to start),
    1s finish facing 1st corners
17-24::
    1s set to 1st corners, dance RSh round each other to face 2nd
    corners; 1s set to 2nd corners, dance RSh round each other to 2nd
    place own sides. 2 1 3
25-32::
    1s & 3s dance the ''The Roulette'':
::
    ''25-26  1s and 3s Petronella turn into the centre, Men facing up,
    Ladies facing down
::
    ''27-28  1s 1/2 turn 2H, finish NHJ facing Ladies'' side _while_ 3s
    turn similarly to end facing Men''s side.  1M 1L 3M 3L
::
    ''29-30  1L & 3M join RH (retain LH to partners) and all dance ¼
    clockwise in a line across the set
::
    ''31-32  1L & 3M continue turn RH _while_ 1M & 3L dance clockwise to
    end 2 3 1

{{explanation}}
Note:  If danced in 4 couples set (4x32), original 1s step down to 4th place on bars 1-2 of next turn', 0);
INSERT INTO 'dancecrib' VALUES (6013, '2013-08-21 08:31:18.073629+00', '2023-02-04 01:20:50.586393+00', 14447, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & 1/2 turn 2H to opposite sides, repeat back to own
    sides
9-16::
    1s cross down & dance reflaction reels of 3 on opposite sides ending
    in partners place
17-24::
    1s dance down for 2 bars & Lady turns under Mans R arm, turn 2H &
    dance up to places
25-32::
    1s+2s dance the Knot:
::
    _25/26_  Couples turn ptnrs RH 1/2 way to end in the centre facing
    down in Allemande position, the Lady having turned clockwise under
    her ptnrs arm
::
    _27/28_  Bottom couple followed by the others dance up on Ladies
    side
::
    _29/32_  Couples turn partners (slowly) by LH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6014, '2013-08-21 08:31:18.082192+00', '2023-02-04 01:20:50.623298+00', 3574, 3, NULL, 'ace', '1-8::
    1s cross & 1/2 turn 2s (1s dancing out), full turn 3s (dancing in),
    cross down RH & cast up on own sides above 2s
9-16::
    1s 3/4 turn RH to end between 2s, 1s+2s dance RH across 1/2 way & LH
    back, 1s turn LH 1.1/4 times to face 2s _while_ 2s cast to right
17-24::
    1s+2s dance reel of 4 across & 1s end facing 1st corners
25-32::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partner LH to
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6015, '2013-08-21 08:31:18.092246+00', '2023-02-04 01:20:50.733594+00', 3575, 3, NULL, 'ace', '1-8::
    1s+2s+3s lead down the middle & back ending with 1s & 3s on Men''s
    side & 2s on Ladies side
9-12::
    1s+2s in prom hold cross passing RSh & set pivoting to right to face
    centre
13-16::
    1s+3s in prom hold cross passing RSh & set pivoting right to face
    centre
17-24::
    2s+3s repeat 9-12; 2s+1s repeat 13-16
25-32::
    3s+1s repeat 9-12; 1s+2s+3s turn partner RH to original places
33-40::
    1s cross RH, cast to 2nd place (2s step up), 1s turn LH 1.1/2 times,
    2s step in ready for …
41-48::
    2s+1s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (6016, '2013-08-21 08:31:18.102364+00', '2023-02-04 01:20:50.895348+00', 3577, 3, NULL, 'ace', '1-8::
    1s lead down the middle for 3 steps, back to top & cast to 2nd place
9-16::
    2s repeat 1- 8
17-24::
    2s followed by 1s dance full Fig of 8 round 3s, 2s dancing up to 1st
    place
25-32::
    1s+3s dance R&L 1s end facing 1st corners
33-40::
    1s set to 1st corners, set to 2nd corners, pull back RSh to end on
    sides between corners & turn partner RH 1.1/2 times  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6017, '2013-08-21 08:31:18.110791+00', '2023-02-04 01:20:50.918829+00', 3579, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s set, cast in 1 place, 1/2 turn partners RH into prom hold
    facing each other & turn to right to end 1s facing 2M & 3s facing 3M
9-16::
    1s+4s dance 1/2 diagonal reel of 4 with 1st corners (end passing RSh
    to 1s face 3L & 4s face 2L) & dance 1/2 diagonal reel of 4 with 2nd
    corners & end with Men dancing across to other Lady who turns right
    about into prom hold with other Man
17-24::
    1M+4L & 4M+1L (prom hold) repeat 1/2 reel of 4 with 2M/3M, then with
    3L/2L & end on sides facing partners in order 2 4 1 3
25-32::
    2s+4s also 1s+3s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6018, '2013-08-21 08:31:18.120781+00', '2023-02-04 01:20:51.047554+00', 3580, 3, NULL, 'ace', '1-8::
    1M turns 2L RH then turns partner LH 1.1/2 times to end facing down
    with partner on RH & 2L on LH
9-16::
    1M with 1L+2L dance down & back to end in original pstns, 1M passing
    partner in front of him
17-24::
    1s+2s dance RH across & LH back ending in centre ready for …
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (6020, '2013-08-21 08:31:18.139395+00', '2023-02-04 01:20:51.201812+00', 3585, 3, NULL, 'ace', '1-8::
    1s+2L dance diagonal reel of 3 (1s start by passing RSh)
9-16::
    1s+2M dance diagonal reel of 3 (1s start by passing LSh)
17-24::
    1s lead down the middle, back to top & cast to 2nd places
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6021, '2013-08-21 08:31:18.173433+00', '2023-02-04 01:20:51.516732+00', 3588, 3, NULL, 'ace', '1-8::
    1L+2L dance between partners & cast into centre, turn 2H & 1s+2s
    turn partners 2H
9-16::
    1M+2M repeat above Fig
17-24::
    1s lead down & back to top
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (13874, '2021-04-05 00:18:24.052576+00', '2023-02-04 01:18:25.34052+00', 20229, 3, NULL, 'ace', '1-8::
    1s+2s change places on sides (Ladies LH, Men RH), 1s+3s change
    places on sides (Ladies RH, Men LH); 1s lead up to top, cross & cast
    to face 1st corners (3s step down 7-8)
9-16::
    1s set to & turn 1st corner 2H; set to & turn 2nd corner 2H
    finishing 1M between 2s & 1L between 3s facing 3rd corners
17-24::
    _6_ bar reels of 3 across, LSh to 3rd corner to start, 1s pass RSh
    to end in 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4053, '2013-08-21 08:30:42.751404+00', '2023-02-04 01:18:30.175851+00', 212, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp. sides

1-8::
    1s+4s dance Figs of 8 on sides round 2s+3s (dancing in between 2s/3s
    to start)
9-16::
    1s+2s & 3s+4s dance a variation of Espagnole:
::
    _9-10_    1s+2s & 3s+4s cross (Ladies lead across RH passing between
    Men) with Ladies changing places RH
::
    _11-12_  1s+2s & 3s+4s cross back (Men lead across RH between
    Ladies) with Men changing places RH
::
    _13-16_  2s/3s turn RH as 1s/4s dance LH across & face corners
17-24::
    1s & 4s dance double diagonal reels of 4 (1/2 LH across in middle) &
    1s+4s omit final LH across but curve in to face corner just passed
25-32::
    All set & turn facing person RH, 4s+1s circle 4H round to right.  2
    4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (13388, '2020-12-02 01:18:32.135784+00', '2023-02-04 01:18:31.606993+00', 20143, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 on own sides (dancing in front of 2s, & behind 3s to
    start)
9-16::
    1s+2s dance R&L
17-24::
    1s dance down middle & back to 1st place facing out
25-32::
    1s+2s turn 1.1/2 to change places (Ladies RH, Men LH);  1s+3s turn
    1.1/2 to change places (Ladies LH, Men RH).  End 2 3 1

{{explanation}}
Note:	May also be danced as a reel', 0);
INSERT INTO 'dancecrib' VALUES (6022, '2013-08-21 08:31:18.181737+00', '2023-02-04 01:20:51.539806+00', 3589, 3, NULL, 'ace', '1-8::
    1s+2s+3s Promenade
9-16::
    1s+2s dance Poussette to end 1L between 2s facing down & 1M between
    3s facing up
17-24::
    2s+1s+3s set twice 1s turning on to own sides (bars19-20), 2s+1s+3s
    set twice 1s turning to centre BtoB facing own sides (bars 23-24)
25-32::
    1s dance Double Triangles with 2s+3s & cross to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (12199, '2019-09-12 16:25:17.918221+00', '2023-02-04 01:20:51.735152+00', 3590, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret; 1s+2s dance 1/2 R&L
9-16::
    2s+1s repeat bars 1-8
17-24::
    1s cast _while_ 2s lead up to 1st place & 2s+1s set; 2s cast _while_
    1s lead up to 1st place & 1s+2s set
25-32::
    1s lead down (3 steps), lead up (3 steps) & cast to 2nd place (2s
    step up 31-32).  2 1', 0);
INSERT INTO 'dancecrib' VALUES (6023, '2013-08-21 08:31:18.190045+00', '2023-02-04 01:20:51.767634+00', 3592, 3, NULL, 'ace', '1-8::
    1s & 2s petronella turn into middle & set, then turn 2H 1.1/4 times
    to original places with 2s facing out
9-16::
    1s cross down to dance reflection reels of 3 on opposite sides, 1s
    end diagonally facing 2M & 3s facing 2L with partners on their right
17-24::
    1s+2M & 3s+2L set, 1s set to 3s, 1s set to 2L as 3s set to 2M, 1s &
    3s turn partners 2H to end 1s on opposite sides & 3s in own places
25-32::
    1s cast 1 place, 1/2 turn RH, 1M with 2s & 1L with 3s dance LH
    across to places', 0);
INSERT INTO 'dancecrib' VALUES (6024, '2013-08-21 08:31:18.20008+00', '2023-02-04 01:20:51.856839+00', 3593, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 on own sides round 2s+3s dancing between 2s to
    start
9-16::
    1s+2s+3s circle 6H round & back
17-24::
    1s+2s+3s Promenade & end with 1s+2s in centre for Allemande
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (6026, '2013-08-21 08:31:18.224088+00', '2023-02-04 01:20:52.104422+00', 3595, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret 1 step twice, then dance 1/2 Grand Chain
9-16::
    3s+2s+1s repeat above Figs
17-24::
    1s lead down the middle & back to top casting to 2nd places
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12087, '2019-08-30 09:54:28.873059+00', '2023-02-04 01:20:52.300158+00', 19552, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Inveran Reels
9-16::
    1s & 4s cross RH, cast 1 place (2s & 3s step up/down bars 11-12).
    1s+4s dance RH across in centre to finish in tandem with partner -
    1M (followed by 1L) facing 2L and 4L (followed by 4M) facing 3M
17-24::
    1s+2s also 4s+3s dance RSh tandem reels of 3 to finish with 1s on
    Man''s side (1L in 2M place) & 4s on Ladies'' side (4L in 2L place).
25-32::
    1s+4s join hands on side & set,  1L+4L also 1M+4M 1/2 RH turn &dance
    RH across finishing in tandem with 1M facing 3M with 1L behind him
    and 4L facing 2L with 4M behind her.
33-40::
    1s+3s also 4s+2s dance RSh tandem reels across finishing in centre
    (own sides), 1s facing down, 4s facing up, 2s & 3s finish facing
    out.
41-48::
    1s+3s also 4s+2s dance Double Figs 8 (may give hands when crossing)
    with the dancing couples crossing out the ends to begin and
    finishing BtoB in centre in ''Saltire'' formation facing corners
    (1M+3M, 1L+3L, 4M+2M and 4L+2L).
49-64::
    1s & 4s change places with corners RH, corners (2s+3s) dance 1/2 LH
    across _while_ 1s & 4s set. Repeat this movement 3 more times back
    to places on side finishing 2 4 1 3.
::
    Repeat with new top couple', 0);
INSERT INTO 'dancecrib' VALUES (6028, '2013-08-21 08:31:18.242304+00', '2023-02-04 01:20:52.477694+00', 12612, 3, NULL, 'ace', '1-8::
    1s set, dance 3/4 Fig of 8 round 2s
9-16::
    1s dance reels of 3 on sides (1s out & down to start)
17-24::
    1s dance 3/4 Figs of 8 (1L round 2s, 1M round 3s & casting to start)
    & 3/4 turn RH
25-32::
    1M dances LH across with 2L+3L _while_ 1L dances LH across with
    2M+3M; 1M dances down & casts to 2nd place own side _while_ 1L
    dances up & casts up to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6025, '2013-08-21 08:31:18.214067+00', '2023-02-20 13:42:06.562978+00', 3594, 3, NULL, 'ace', '1-8::

    1s lead down the middle & back to top

9-16::

    1s+2s dance Allemande

17-24::

    1s dance full Fig of 8 round 2s

25-32::

    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14557, '2022-01-17 17:01:37.842167+00', '2022-01-20 13:18:05.225151+00', 20633, 2, 1645, 'ace', '1-8::

  1M, 2W cross RH. 1s, 2s chase 1 place clockwise. 1/2 reel of 3 on sides (1s give LSh to 3s)

9-16::

  All set and cross RH. 1s 1/2 fig. 8 to own sides (W up, M down)

17-24::

  Diagonal R&L

25-32::

  6 hands round and back

', 2);
INSERT INTO 'dancecrib' VALUES (9347, '2016-10-06 07:18:02.649399+00', '2023-02-04 01:18:25.366518+00', 17152, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, set 1L casts up & 1M down
9-16::
    1s dance reels of 3 across (1L with 2s & 1M with 3s) & 1s end facing
    1st corners
17-24::
    1s set to 1st corners, turn partner RH, set to 2nd corner & turn
    partner RH to face 1st corners
25-32::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    Pass+Turn with 2nd corners & end passing RSh to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6030, '2013-08-21 08:31:18.260518+00', '2023-02-04 01:20:52.597621+00', 10089, 3, NULL, 'ace', '1-8::
    1s dance Inveran Reels with 2s+3s
9-16::
    1s & 3s set, turn 2H (1s to face 2L & 3s face 2M), 1s & 3s make
    arches & dance down/up & chase to form a circle (Men ending on own
    sides) _while_ 2s dance under arches & cast back to place
17-24::
    All circle 6H round & back to end 3 2 1
25-32::
    3M followed by partner casts 1 place, crosses up between 2s, casts
    down & crosses to 2nd place (2s step up).  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6031, '2013-08-21 08:31:18.268753+00', '2023-02-04 01:20:52.631481+00', 3608, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, circle 6H round to left 1/2 way, set & continue circle
    6H round to left to places
9-16::
    1s+2s dance reel of 4 across dance 1L+2M passing LSh to start & 1s
    finish in 2nd places.
17-24::
    1s lead down the middle for 3 steps, lead back to 2nd place crossing
    to opposite sides facing up to 2s & 2s+1s set.
25-32::
    1s dance reel of 3 on opposite sides giving RSh to 2nd corners (Man
    casts to right), 1s cross to own sides.', 0);
INSERT INTO 'dancecrib' VALUES (6032, '2013-08-21 08:31:18.278666+00', '2023-02-04 01:20:52.749299+00', 3609, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s+2s+3s dance Grand Chain
17-24::
    1s cross RH & cast to 2nd place, cross LH & cast down round 3s &
    lead up to face 1st corners
25-32::
    1s turn 1st corners RH & turn partners LH, turn 2nd corners RH &
    cross LH back to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6033, '2013-08-21 08:31:18.286974+00', '2023-02-04 01:20:52.772897+00', 11606, 3, NULL, 'ace', '1-8::
    1s & 3s turn RH & cast down 1 place, 1s & 3s turn LH to face 1st
    corners
9-16::
    1s & 3s set & turn comers RH to end forming a diag line with
    partners, 1s & 3s Bal-in-Line & turn LH to face 2nd corners
17-24::
    1s & 3s repeat with 2nd corners & end turning LH to opposite sides
25-32::
    1s & 3s set & cross RH, 1s & 3s cast down 1 place & all set', 0);
INSERT INTO 'dancecrib' VALUES (6034, '2013-08-21 08:31:18.295358+00', '2023-02-04 01:20:52.79869+00', 10195, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 2s+1s+3s set then 1s petronella turn to 1L between
    2s & 1M between 3s
9-16::
    All advance 1 step & retire twice, 1s turn 1.3/4 2H to end facing
    1st corners
17-24::
    1s set to & turn 1st corner to face 2nd corner, set to & turn 2nd
    corner
25-32::
    1M circles 3H round with 2s as 1L circles with 3s & 1s end turning
    Right about to face each other, 1s set & turn 2H to 2nd  places own
    side', 0);
INSERT INTO 'dancecrib' VALUES (6035, '2013-08-21 08:31:18.305606+00', '2023-02-04 01:20:52.824286+00', 12124, 3, NULL, 'ace', '1-4::
    All set, 1s+3s+5s petronella turn into centre _while_ 2M & 4M cast
    up 1 place as 2L & 4L cast down 1 place
5-8::
    1s+3s+5s set _while_ 2s & 4s cross to opposite sides, 1s+3s+5s
    petronella turn to opposite sides _while_ 2M & 4M cast down 1 place
    into middle to face up to partner as 2L & 4L cast up 1 place into
    middle & face down
9-16::
    2s+4s dance reel of 4 in middle
17-24::
    All dance LH across (2L+1s, 2M+3s+4L & 4M+5s) & end on opposite
    sides, all set & cross RH
25-32::
    1s+2s also 3s+4s Set+Link, 1s+4s also 3s+5s Set+Link.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (12729, '2020-04-11 10:51:56.304135+00', '2023-02-04 01:20:52.842222+00', 14985, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH into prom hold facing down, dance down 2 places, drop
    RH & cross below 3s, cast up to 2nd place, own sides (2s step up
    bars 5-6)
9-16::
    LSh reels of 3 across, 1L LSh to 2M, 1M LSh to 3L.  1s end 2nd place
    own side
17-20::
    1s petronella turn to finish 1M between 3s facing up, 1L between 2s
    facing down. Set in lines of 3 across
21-24::
    1s petronella turn to finish in 2nd place on opp side. 2s+1s+3s set
    on sides
25-28::
    1s turn 1.3/4 turn RH
29-32::
    1M+2s and 1L+3s dance LH across. 1s finish in 2nd place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6036, '2013-08-21 08:31:18.31379+00', '2023-02-04 01:20:52.860335+00', 3611, 3, NULL, 'ace', '1-8::
    1M casts to 2nd place as 2L casts up to 1st place & they turn 2H
    1.1/2 times to opposite sides
9-16::
    1L casts down as 2M casts up & they turn 2H 1.1/2 times to opposite
    sides to face their partners
17-24::
    2s+1s dance RH across & L H across back to places
25-32::
    2s+1s set twice & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (6037, '2013-08-21 08:31:18.324145+00', '2023-02-04 01:20:52.880883+00', 3613, 3, NULL, 'ace', '1-8::
    1s dance between 2s & cast behind 3s, meet & dance up to top & cast
    to 2nd places (2s step up 7-8)
9-16::
    1s dance reflection reels of 3 on sides (1s down/in, 3s out/up, 2s
    cast) all take hands when possible.  2s & 3s cast into place at end
    of reel
17-24::
    2s+1s+3s dance reels of 3 across (1L+2M & 1M+3L pass LSh) ending 2nd
    place own sides
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6038, '2013-08-21 08:31:18.332612+00', '2023-02-04 01:20:52.905336+00', 13748, 3, NULL, 'ace', '1-8::
    1s turn RH & cast to 2nd place, 1s dance down middle & cast round 3s
    to 2nd place
9-16::
    2s+1s+3s dance in & dance round partner RSh, all chase clockwise 1/2
    way.  (3)(1)(2)
17-24::
    1s dance »Turn-Pivot-Reel«:
::
    1s 3/4 turn RH (M faces down) & set pivoting right (retaining hands)
    to face 1st corner (pstn), 1s+1st corners dance 1/2 reel of 4 with
    1s ending in middle 1L at top &1M between 3s
25-32::
    1s dance a second »Turn-Pivot-Reel«:
::
    1s 3/4 turn RH (to opp sides) & set pivoting right (retaining hands)
    to face 4th corner (pstn), 1s+ 4th corners dance 1/2 reel of 4 with
    1s ending 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6039, '2013-08-21 08:31:18.340839+00', '2023-02-04 01:20:52.92541+00', 3615, 3, NULL, 'ace', '1-8::
    1L sets to 2M & turns 3M RH to end between 2M+3M, 1M sets to 2L &
    turns 3L RH ending between 3s in line across as 1L steps in between
    2s
9-16::
    2s+1s+3s set twice 1s turning to right onto opposite sides, set
    twice on sides & 1s end facing 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners (1s end in 2nd
    places opposite sides)
25-32::
    2s+1s+3s Adv+Ret, 1s turn 2H 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (5070, '2013-08-21 08:30:59.837904+00', '2023-02-04 01:20:53.175017+00', 3617, 3, NULL, 'ace', '{{explanation}}
1s start on opp sides

1-8::
    1s cast to 2nd place, turn RH, cast to 3rd place & turn LH
9-16::
    1s lead up to top & cast to 2nd place, 2s+1s+3s circle 6H round to
    left
17-24::
    2s+1L & 1M+3s circle 3H round to left, 1M+2L+3L & 1L+2M+3M circle 3H
    round to left
25-32::
    1s lead down below 3s & cast up to 2nd place (opposite sides), 2s+1s
    dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6041, '2013-08-21 08:31:18.370614+00', '2023-02-04 01:20:53.285901+00', 3620, 3, NULL, 'ace', '1-8::
    1s+2L dance RH across, 1s+2M dance LH across
9-16::
    1s cross RH, cast to 1 place, cross LH, cast below 3s & lead up to
    face 1st corners
17-24::
    1s set to 1st corners, set to 2nd corners, cross RH & cast up to top
    on own sides
25-32::
    1s+2s dance 1/2 R&L, set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (6042, '2013-08-21 08:31:18.379033+00', '2023-02-04 01:20:53.488842+00', 3623, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH across back & 1s cast to 2nd place
9-16::
    1s lead up & cross to form line of 4 across (Man facing Lady), 2s+1s
    set, 1s lead down to face 3s & set end facing 1st corners
17-24::
    1s turn 1st corners RH, set to each other up & down dance, turn 2nd
    corners RH & set across dance
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corner & 1s
    cross RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6044, '2013-08-21 08:31:18.397411+00', '2023-02-04 01:20:53.659298+00', 3626, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, turn partners 2H twice round
9-12::
    1s cross RH & change places with 2s on sides
13-16::
    1L & 2L cross & cast round partner LSh to change places _while_
    1M+2M advance turning left about & return to placess facing out
17-24::
    1s+2s dance Ladies Chain ending in prom hold
25-32::
    1s+2s dance the Tournee:
::
    _25-28_  1s+2s dance into prom hold (Men with partner on right, 1s
    face Men''s side & 2s face Ladies side), both couples wheel
    anticlockwise 1/2 way & Men turn Ladies into middle
::
    _29-32_  Both couples turn 1.1/2 times (2s RH, 1s LH) & dance out to
    places', 0);
INSERT INTO 'dancecrib' VALUES (14531, '2022-01-10 02:19:50.597061+00', '2023-02-04 01:20:53.686928+00', 10563, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 round 4th corner
    (1L up through 2s, 1M down through 3s) & end facing 1st corners
9-16::
    1s dance 1/2 diag reel of 4 with 1st corners & pull back RSh (twirl)
    to face 4th corners; 1s repeat with 4th corners & face 3rd corners
17-24::
    1s repeat with 3rd corners & face 2nd corners; 1s repeat with 2nd
    corners & 1/2 turn RH remaining in centre flowing into …
25-32::
    1s turn 1.1/2 RH _while_ 3s+2s chase 1/2 round clockwise; 1s join
    chase in 2nd place & all continue chase 1/2 round to own sides
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6045, '2013-08-21 08:31:18.406144+00', '2023-02-04 01:20:53.722103+00', 11986, 3, NULL, 'ace', '1-8::
    Ladies dance RH across 1/2 way, turn opposite Man LH into prom hold
    & all promenade anticlockwise 1/2 way
9-16::
    Men dance LH across 1/2 way, turn opposite Lady RH into prom hold &
    all promenade clockwise 1/2 way
17-24::
    1s & 3s continue to promenade to original places & then Adv+Ret
    _while_ 2s & 4s Adv+Ret & promenade clockwise to original places
25-32::
    1s & 3s dance NHJ to centre, join hands with opposite person & face
    side couple, set passing facing couple, centre couples set & pass
    _while_ side couples turn 2H, all set & pass facing couple (2s & 4s
    end with Lady on Man''s left)
33-40::
    1L+3M & 1M+3L cross (1M+3L make arch), dance out between 2s/4s &
    cross to meet partners, 1s & 3s set & turn partners 2H (All in
    opposite places with Lady on Man''s left)
41-56::
    2s+4s repeat bars 25-40 with 2M+4L making arch 2H (All in original
    places with Lady on Man''s left)
57-64::
    All DoSiDo with corners & Set+Link with partner
65-72::
    All dance Grand Chain
73-80::
    All take allemande hold & dance anticlockwise once round set,
    bringing Ladies into centre for bow/curtsey', 0);
INSERT INTO 'dancecrib' VALUES (13757, '2021-03-02 01:20:35.931358+00', '2023-02-04 01:20:53.800826+00', 13379, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opposite sides

1-8::
    All set, cross RH; set & turn partner 3/4 RH into Promenade hold (1s
    & 3s face Ladies'' side, 2s & 4s face Men''s side
9-10::
    1s+2s also 3s+4s change places dancing around each other passing RSh
11-12::
    1s+4s change places dancing around each other passing LSh
13-14::
    2s+4s also 1s+3s change places dancing around each other passing RSh
15-16::
    4s+1s change places dancing around each other passing LSh _while_
::
    2s+3s face partner facing up/down. 2s+3s separate from partner, 2s
    dance to 1st place own side, 3s dance to 4th place opp sides
17-24::
    2s+4s (in prom hold) also 3s+1s (in prom hold) dance reels of 3
    across the dance. 4s pass 2M RSh, 1s pass 3M RSh to begin.  1s & 4s
    end in line on 1st corner diagonal with ladies BtoB
25-32::
    4s+1s dance All Round Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6047, '2013-08-21 08:31:18.427777+00', '2023-02-04 01:20:53.840475+00', 9090, 3, NULL, 'ace', '1-8::
    1s+2s set, 2s cast up _while_ 1s dance down, 1s dance out behind 3s
    & lead up to 2nd place facing up
9-16::
    1s (prom hold) dance 1/2 diag reel of 3 with 2nd crnrs (RSh to 2L),
    1s pivot inward to face out Ladies side & dance 1/2 reel with 1st
    crnrs (RSh to 3L)
17-24::
    Pivoting inwards repeat with next corner (RSh to 3M place) & repeat
    with 4th corner RSh to 2M place
25-32::
    2s+3s set & cross RH twice _while_ 1s lead down below 3s, cross &
    cast up round 3s, lead up between 2s, cross & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6048, '2013-08-21 08:31:18.436034+00', '2023-02-04 01:20:53.876997+00', 12074, 3, NULL, 'ace', '1-8::
    1s & 3s petronella turn & set, petronella turn to opp sides & all 4
    couples set.
9-12::
    _1/2_ reels of 4 on sides
13-20::
    2s & 4s repeat bars 1-8
21-24::
    _1/2_ reels of 4 on sides
25-32::
    1s & 3s face down, 2s & 4s face up & all set (HS).  All turn person
    facing 1.1/2 2H
33-36::
    All set advancing, passing facing person LSh & all set.  1s+2s dance
    1/2 R&L
37-48::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L, 1s+4s dance 1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (6049, '2013-08-21 08:31:18.444508+00', '2023-02-04 01:20:53.903166+00', 3635, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast 1 place, lead down between 3s, cast down
    behind 4s & 1/2 turn RH to face up
9-16::
    1s lead up followed by 4s+3s+2s & all cast at top 1s ending in 4th
    place
17-24::
    1s turn RH 1.1/2 times, 1M turns 4L LH _while_ 1L turns 4M LH, 1s
    turn RH (Strip the Willow)
25-32::
    1s turn 3s LH, turn partner RH, turn 2s LH & partner RH (Strip the
    Willow)
33-40::
    1s+2s dance Allemande with 1s ending by dancing down to 4th place
41-48::
    2s+3s & 4s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6050, '2013-08-21 08:31:18.452858+00', '2023-02-04 01:20:53.934252+00', 3636, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    2s+3s dance RH across once round, 2s (Lady leading) dance out & cast
    up round 1st Lady _while_ 3s dance out & cast down round 4th Lady
9-16::
    2s with 1st Man & 3s with 4th Man, dance RH across once round, 2s
    with 1st Lady & 3s with 4th Lady, dance LH across once round
17-24::
    2s & 3s dance Tandem reels of 3 on sides (2s dance down & out on
    Men''s side as 3s dance up & out Ladies side).  At the end of reel 2s
    dance across top of dance ending in 1st place on own sides as 3s
    dance across bottom of dance ending in 4th place 1s end in 2nd place
    own side facing down & 4s in 3rd place opp side facing up
25-32::
    1L+4M also 1M+4L set on sides, change places RH, 1s+4s set to
    partners & cross to other side RH.  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (9012, '2015-11-30 08:59:57.326819+00', '2023-02-04 01:20:54.065519+00', 16102, 3, NULL, 'ace', '1-8::
    1s cast, dance down behind own lines, meet below 3s & dance up
    middle to top & cast off to 2nd place (2s step up 7-8)
9-16::
    2s+1s dance non-progressive Knot (»Slip Knot«):
::
    _9-14_      2s+1s dance as per Knot
::
    _15-16_    1s+2s dance 1/2 LH across.  2s finish in 1st place, 1s in
    middle NHJ facing 2L
17-24::
    1s set to 2L, turn inwards, set to 3M, set to 3L, turn inwards, set
    to 2M.  1M pull back RSh to face 1L as 3s dance in ready for ...
25-28::
    1s+3s dance 1/2 Poussette.  3s finish on sides as 1s turn in middle
    (bars 27-28) & 4s dance in (bar 28) ready for ...
29-32::
    1s+4s dance 1/2 Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6095, '2013-08-21 08:31:18.878309+00', '2023-02-04 01:20:57.149565+00', 3722, 3, NULL, 'ace', '1-8::
    1M+2L turn RH, 1L+2M turn RH
9-16::
    1s lead down the middle & back to top
17-24::
    1s+2s dance Poussette
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (13028, '2020-08-10 00:18:22.344293+00', '2023-02-04 01:18:25.414376+00', 114, 3, NULL, 'ace', '1-4::
    1s cast (2s step up), turn LH to end BtoB in centre facing own side
    _while_ 4s turn RH & cast up to face 1s
5-12::
    1s+4s dance reel of 4 across. 1s pass RH at end & retain hands, 4s
    face out
13-16::
    4s cast back to 4th place & turn LH _while_ 1s turn RH & cast back
    to 1st place (2s step down 15-16)
17-24::
    1s cross down below 2s, out behind 3s, cross LH & cast to bottom
    (2s+3s+4s step up 23-24)
25-32::
    2s+3s+4s+1s circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6051, '2013-08-21 08:31:18.461082+00', '2023-02-04 01:20:54.094363+00', 12625, 3, NULL, 'ace', '1-8::
    All set, turn RH, 1s+2s also 3s+4s circle left
9-16::
    1s+2s also 3s+4s dance Diamond Poussette
17-20::
    Top 3 Men change places RH with bottom 3 Ladies, top 3 on Ladies
    side change places LH with bottom 3 on Men''s side
21-24::
    Top 3 on Men''s side change places RH with bottom 3 on Ladies side,
    top 3 on Ladies side change pl LH with bottom 3 on Men''s side.
    (4)(3)(2)(1)
25-32::
    All change places with partner RH, 4s+3s dance RH across 1/2 way,
    4s+2s dance LH across 1/2 way, 3s+2s dance RH across 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (6052, '2013-08-21 08:31:18.46947+00', '2023-02-04 01:20:54.300992+00', 8730, 3, NULL, 'ace', '1-8::
    1M sets to 2L & casts to 2nd place, 1M+3L turn 2H
9-16::
    1L sets to 2M & casts to 2nd place, 1L+3M turn 2H
17-24::
    1s dance up between 2s, cast to 2nd place, dance down between 3s &
    cast up to 2nd place
25-32::
    2s+1s+3s set & cross RH, set again & 2s+3s cross back RH _while_ 1s
    turn RH to face 2nd corners
33-40::
    1s dance reels of 3 on sides giving RSh to 2nd corners ending with
    1s crossing to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6053, '2013-08-21 08:31:18.479452+00', '2023-02-04 01:20:54.441152+00', 3637, 3, NULL, 'ace', '1-8::
    1s set, cast below 3s, lead up to top & cast to face 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting & end facing 1st corners
17-24::
    1s turn 1st corners RH, partner LH, 2nd corners RH & partners LH to
    own sides facing down
25-32::
    1s dance down between 3s, cast up on own side, dance up between 2s &
    cast back to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6054, '2013-08-21 08:31:18.489403+00', '2023-02-04 01:20:54.542286+00', 3638, 3, NULL, 'ace', '1-8::
    1s cast to bottom, turn out & back to places
9-16::
    1s lead down the middle & back casting to 2nd place
17-24::
    2s+1s+3s circle 6H round & back 1s end facing 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting ending with a clap & petronella
    turn to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6055, '2013-08-21 08:31:18.497767+00', '2023-02-04 01:20:54.573893+00', 7441, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place, 2s+1s+3s turn partners RH ending in
    centre facing up
9-16::
    2s+1s+3s Promenade
17-24::
    1s dance Fig of 8 on own sides passing dancer on right RSh
25-32::
    1L+2s also 1M+3s dance RH across & 1s pass RSh to dance LH across
    with other couple', 0);
INSERT INTO 'dancecrib' VALUES (6056, '2013-08-21 08:31:18.5127+00', '2023-02-04 01:20:54.623647+00', 3642, 3, NULL, 'ace', '1-8::
    1s cast to 2nd place & dance RH across 1/2 way with 3s, 2s cast &
    dance 1/2 RH across with 1s
9-16::
    3s+1s+2s circle 6H 1/2 way round to left, 1s lead down & cross to
    own sides below 3s & cast up to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6057, '2013-08-21 08:31:18.522765+00', '2023-02-04 01:20:54.653777+00', 9092, 3, NULL, 'ace', '1-8::
    1s set & turn 2H, dance down below 3s & cast up to 2nd place (2s
    step up 7-8)
9-16::
    1s dance a reel of 3 on own sides (1s in & up to start), 1s end 1/2
    turn LH to face 2nd corners
17-24::
    1s dance 1/2 reel of 4 with 2nd corners, turn LH & dance 1/2 reel of
    4 with 1st corners
25-32::
    3s+1s+2s dance Allemande down, drop hands on bar 31 & pass LSh to
    own sides (similar to the Knot)', 0);
INSERT INTO 'dancecrib' VALUES (6058, '2013-08-21 08:31:18.531532+00', '2023-02-04 01:20:54.686851+00', 13850, 3, NULL, 'ace', '1-8::
    All dance reflection reels of 4 on sides (LSh Ladies side, RSh Mens
    side)
9-16::
    3s followed by 1s lead down middle, 2s & 4s make arches (2H) as 1s &
    3s dance back to places
17-24::
    All set & advance into middle, all set twice
25-32::
    All dance a poussette for 4 couples.  2 3 4 1
33-40::
    2s+3s also 4s+1s dance R&L
41-48::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13251, '2020-10-16 00:20:40.699681+00', '2023-02-04 01:20:54.864542+00', 16744, 3, NULL, 'ace', '1-8::
    1s+2s set, turn partner 2H, remain in centre facing down/up; 1s+2s
    set & turn opp dancer 2H to own sides. 1 2
9-16::
    1s+2s circle 4H round & back
17-24::
    1s+2s Set & Rotate
25-32::
    2s+1s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (13252, '2020-10-16 00:20:40.718009+00', '2023-02-04 01:20:54.903556+00', 15685, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Espagnole:
::
    _1- 2_   1s+2s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _3- 4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5- 8_   2s & 4s turn RH as 1s & 3s turn LH to face 1st corners
9-16::
    1s & 3s turn 1st corners RH, partner LH, 2nd corner RH, partner LH &
    face 1st corners again
17-24::
    Diag reels of 4 with 1st corners (RSh to corner to start)
25-32::
    1s & 3s turn partner LH & cast to 3rd/5th place opp side (4s & 5s
    step up 27-28); 1s & 3s dance 1/2 Fig 8 around couples above
    (4s/5s).  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (6059, '2013-08-21 08:31:18.539743+00', '2023-02-04 01:20:54.927668+00', 3645, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, 1s dance RH across (Lady with 2s & Man with
    3s)
9-16::
    2s+1s+3s Promenade
17-24::
    1s petronella turn to form lines across & 2s+1s+3s set, 1s
    petronella turn to opposite sides & 2s+1s+3s set
25-32::
    1s dance reels of 3 on sides giving RSh to 2nd corner & cross RH to
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (6062, '2013-08-21 08:31:18.568073+00', '2023-02-04 01:20:55.074738+00', 14364, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of round 2s.  2 1 3
9-16::
    All Set+Link for 3, 1s cast to 2nd place opposite sides as 2M+3L
    (left-enders) 1/2 turn LH into middle (BtoB) to face up/down as
    3M+2LW (right-enders) cast to form line of 4 in middle (3M facing 2M
    & 3L facing 2L)
17-24::
    All dance a Weasel Reel:
::
    2s+3s dance part reel of 4 up/down middle but when reaching either
    end they dance clockwise to top/bottom & re-enter reel _while_ 1s
    dance clockwise to replace dancer leaving the reel & all end where
    they started
25-30::
    3M+2M also 3L+2L 1/2 turn RH & 2M & 3L set as 3M+2L (middle cpl)
    change places (as Double Triangles) then 2s+3s petronella turn to
    own sides _while_ 1s chase clockwise to 2nd place own sides passing
    between 2s/3s
31-32::
    All set.  2 1 3

{{explanation}}
Note - Weasel Reel - Dancers facing down, reel down middle & dance up Men''s side while those facing up reel up middle & dance down Ladies'' side', 0);
INSERT INTO 'dancecrib' VALUES (6064, '2013-08-21 08:31:18.597732+00', '2023-02-04 01:20:55.249661+00', 3659, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast 1 place & turn LH to face 1st corners
9-24::
    1s dance Corner Chain with 1st & 2nd corners :
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end with a 1/2 turn LH to 2nd
    place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4069, '2013-08-21 08:30:42.991629+00', '2023-02-04 01:18:31.71267+00', 10402, 3, NULL, 'ace', '1-8::
    1s+3s+5s dance reels of 3 on sides round standing 2s & 4s, each
    couple crossing down to opp side from top (1s cross down, 3s out/up,
    5s in/up to start)
9-16::
    2s & 4s turn 2H 1.1/2 times to opposite sides, 1s, 3s & 5s cross RH
    back to places & all set
17-24::
    1s+2s & 3s+4s (top 4 couples) dance RH across 1/2 way. Bottom 4
    couples dance LH across 1/2 way. Top 4 couples RH across 1/2 way.
    Bottom 4 couples LH across 1/2 way
25-32::
    All 5 couples chase c''wise 2 places, all set, persons in 2nd & 4th
    places lead up/down thru ends, cross (RH at top, LH at bottom) &
    cast 1 place back to new place

{{explanation}}
Repeat 4 times, each time with new partners ie 2M with 5L, 4M with 3L, 1M with 4L, 5M with 1L & 3M with 2L', 4);
INSERT INTO 'dancecrib' VALUES (6065, '2013-08-21 08:31:18.605914+00', '2023-02-04 01:20:55.283887+00', 3660, 3, NULL, 'ace', '1-8::
    1M+2L set advancing & change places RH, 1L+2M set & turn RH to 1st
    place own sides
9-16::
    2s+1s dance Ladies Chain
17-24::
    1M leads 1L+2L down middle followed by 2M, 2M leads Ladies back to
    place
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6067, '2013-08-21 08:31:18.628312+00', '2023-02-04 01:20:55.432687+00', 7442, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s & 3s on own sides (dancing between 2s to
    start)
9-16::
    1s set, cast 1 place,1s+3s dance 1/2 Diamond Poussette
17-24::
    All set, turn 2H twice round & set again
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6068, '2013-08-21 08:31:18.638545+00', '2023-02-04 01:20:55.458236+00', 3665, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH.  1s & 3s Petronella turn to line up/down
    middle & set
9-16::
    1s+3s dance 1/2 reel of 4 ending 1L+3M pass LSh to face opp sides.
    1L+2s+3M dance 1/2 reel of 4 across ending 1L+3M pass LSh to face
    partners in centre
17-24::
    1s+3s dance 1/2 reel of 4 up/down. 1s+3s dance RSh round partner to
    original places.  1s+2s+3s set
25-32::
    1s+2s dance »Bourrel«:
::
    _25-28_    1M+2L set advancing, 3/4 turn 2H & twirl to end BtoB
    (Lady facing up & Man down) _while_ partners chase anticlockwise to
    face partner
::
    _29-32_    Set to partners & turn 2H to own sides having changed
    places', 0);
INSERT INTO 'dancecrib' VALUES (6069, '2013-08-21 08:31:18.648519+00', '2023-02-04 01:20:55.485717+00', 3666, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s dance down between 3s & cast up
    to 2nd place opp sides. 2 (1) 3
9-16::
    1L+2s & 1M+3s dance reels of 3 across (1L RSh to 2L, 1M RSh to 3M).
    1s end facing 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting & use last step to finish facing
    2nd corners
25-32::
    1s dance RSh reel of 3 on opposite sides
33-40::
    1s lead up, cross & cast to 2nd place own side; 2s+1s+3s turn
    partner RH', 0);
INSERT INTO 'dancecrib' VALUES (6070, '2013-08-21 08:31:18.658394+00', '2023-02-04 01:20:55.513866+00', 3669, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of 8 round 2s
9-16::
    3s followed by 1s+2s lead down & back
17-24::
    All Promenade to end 2 1 3
25-32::
    1s+2s dance RH across (1L with 2s, 1M with 3s), 1s dance LH across
    with other couple', 0);
INSERT INTO 'dancecrib' VALUES (6072, '2013-08-21 08:31:18.675291+00', '2023-02-04 01:20:55.557115+00', 10162, 3, NULL, 'ace', '{{explanation}}
2 chords - start 3s+4s on opp sides & on 2nd Chord 2M+3M change places

{{title}}
Strathspey

1-8::
    2s in prom hold dance reel of 3 on Ladies side (RSh to 1L to start)
    _while_ 3s dance reel of 3 on Men''s side (RSh to 4L to start)
9-16::
    Top 4 dancers also bottom 4 dancers dance RH across, middle couples
    dance LH across
17-24::
    All dance reels of 4 on sides
25-32::
    All set twice, turn partner 2H to end in a square set (Ladies on
    Men''s right).  1 3 4 2

{{explanation}}
Reel	Numbers refer to new pstns

1-8::
    1s+3s 1/2 turn opposite partner RH & twirl to opp place facing
    nearest side couple & dance 1/2 Fig of 8 round side couples back to
    places
9-16::
    2s+4s repeat
17-32::
    All dance full Schiehallion Reel
33-40::
    1M+4L also 3M+2L 1/2 turn & twirl to each others place & dance round
    outside of set back to place
41-48::
    2M+1L also 4M+3L repeat
49-56::
    1s+4s also 2s+3s dance RH across, 1s+2s & 3s+4s dance RH across
57-64::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6073, '2013-08-21 08:31:18.683753+00', '2023-02-04 01:20:55.584415+00', 3672, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place (2s step up 3-4) & dance 1/2 Fig of 8 up round
    2s.  2 (1) 3
9-16::
    1s set, cast to 3rd place (3s step up) & dance 1/2 Fig of 8 up round
    3s.  2 3 1
17-24::
    1s lead up to top, (2s & 3s step down 19-20); 1s set & cast to 2nd
    place (2s step up 23-24)
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (15418, '2023-02-04 01:20:55.608267+00', '2023-02-04 01:20:55.6097+00', 20303, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance mirror reels of 3 on sides (1s in/down to start)
9-16::
    1s dance down (4 bars); turn RH (2 bars) & cast behind 3s to 2nd
    place own side (2s step up 11-12)
17-24::
    1L+2s & 1M+3s dance 1/2 LSh reels of 3 across; 1L+2L+3L & 1M+2M+3M
    dance 1/2 RSh reels of 3 on sides.  (3) (1) (2)
25-28::
    1s dance 1/2 Fig 8 (1L up between 3s, 1M down between 2s) _while_
    3s+2s change places RH on side & cross LH with partner
29-32::
    All turn partner RH (or birl)

{{explanation}}
Note: Last time through, all couples turn (or birl)', 0);
INSERT INTO 'dancecrib' VALUES (6075, '2013-08-21 08:31:18.700273+00', '2023-02-04 01:20:55.652577+00', 7443, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All set to partner & turn RH, set to corner & turn LH
17-32::
    All dance full Schiehallion Reel
33-40::
    All set & Petronella-in-tandem twice
41-48::
    1s+3s dance R&L
49-56::
    2s+4s dance R&L
57-64::
    All set & Petronella-in-tandem twice

{{explanation}}
Repeat in reel time', 0);
INSERT INTO 'dancecrib' VALUES (9383, '2016-10-06 07:18:37.77988+00', '2023-02-04 01:20:58.344655+00', 17268, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    All dance RH across & LH back
9-16::
    1L+2L cross LH, cast to Left around partner back to places & turn
    opp man LH once round
17-24::
    1M+2M cross RH, cast to Right around partner back to places & turn
    opp women RH once round
25-32::
    1s+2s dance DoSiDo, pass opp person RSh & dance on to meet next
    couple', 0);
INSERT INTO 'dancecrib' VALUES (6066, '2013-08-21 08:31:18.620016+00', '2023-02-09 12:35:49.835211+00', 1914, 3, NULL, 'ace', '1-8::

    1s+2s+3s set & cross RH, set & cross back RH

9-16::

    1s dance in & cast to 2nd place, dance 1/2 Fig of 8 (1L round 2s, 1M

    round 3s) & end BtoB facing 1st corners

17-24::

    1s dance ''Hello-Goodbye'' setting & end set advancing & twirl to face

    1st corners

25-32::

    1s turn 1st corner RH & pass RSh to face 2nd corner, turn 2nd corner

    LH & pass LSh to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (8832, '2015-08-13 20:33:18.809508+00', '2023-02-04 01:18:31.740512+00', 14284, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All set to prtnr & turn 2H. All set to corner, Lady turns under
    Man''s R arm
9-16::
    1L & 3L cast round prtnr into centre & turn RH back to place.  1M &
    3M dance into centre (1 bar), set (L then R), dance back to place
17-24::
    All circle 8H 3/4 round to Left.  All dance 1/2 R&L (1s+3s cross RH,
    2s+4s change places with prntr RH to start)
25-32::
    ''Erika''s Viking Reels'':
::
    _25-28_    All face corners & dance interlocking RSh reels of 3 back
    to place
::
    _29-32_    All face partners & dance interlocking LSh reels of 3
    back to place
33-64::
    Repeat bars 1-32 from new positions with 2s & 4s as dancing couples

{{title}}
Reel

1-8::
    All set to prtnr & turn RH.  All set to corner, Lady turns under
    Men''s R arm
9-16::
    1s & 3s set advancing into line of 4 between 2s & 4s.  1L+3L join
    LH, all Bal-in-Line.  1M+3L also 1L+3M 1/2 turn RH back to places
17-32::
    As Strathspey bars 17-32
33-64::
    Repeat Reel bars 1-32 from new positions with 2s & 4s as dancing
    couples', 0);
INSERT INTO 'dancecrib' VALUES (11456, '2019-01-01 01:57:10.20672+00', '2023-02-04 01:20:55.677441+00', 14723, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s+4s cross to opp sides

1-8::
    1s+4s set, cast down/up (2s & 3s step up/down); 1s+4s dance 1/2 R&L.
    Men end facing out
9-16::
    4s+1s dance Ladies'' Chain. 4s face up, 1s face down.  2 4 (1) (3)
17-32::
    All dance *Axum Reel* to end back in position as bar 17
33-40::
    All turn person facing on sides LH once round; all dance
    anticlockwise 1/2 round to end 2 4 (1) (3)

{{explanation}}
*Axum Reel* Every 2 bars all dance to the next position on path 1M, 2L, 1L, 3L, 4L, 3M, 4M, 2M, 1M, passing LSh.', 0);
INSERT INTO 'dancecrib' VALUES (6076, '2013-08-21 08:31:18.70845+00', '2023-02-04 01:20:55.697842+00', 3684, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across & 1s cast to face 1st corners _while_ 2s
    dance up to top place
9-16::
    1s turn 1st corner RH, pass partner RSh to face 3rd corner, turn 3rd
    corner LH & pass partner LSh to face 2nd corner
17-24::
    1s turn 2nd corner RH, pass partner RSh to face 4th corner, turn 4th
    corner LH to end in 2nd place opposite side facing 2nd corner
25-32::
    1s dance LSh Reels of 3 on opposite sides & cross to 2nd place on
    own side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6077, '2013-08-21 08:31:18.718517+00', '2023-02-04 01:20:55.737945+00', 3685, 3, NULL, 'ace', '1-8::
    1s lead down, cross below 2s, cast down round 3s, lead up to top &
    cast to 2nd places
9-16::
    2s+1s+3s dance Grand Chain for 6 bars to end 1s (at top) & 3s 1/2
    turn 2H to remain in centre in circle formation, with 2s on sides in
    2nd pl
17-24::
    1s+2s+3s circle 6H round & back
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (6078, '2013-08-21 08:31:18.726767+00', '2023-02-04 01:20:55.76466+00', 3689, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 1M+2M+3M cast up, 1M followed by 2M+3M crosses &
    dances down Ladies side _while_ 1L+2L+3L cast down & 3L followed by
    2L+1L crosses & dances up Men''s side, 3s+2s+1s cross RH into circle
9-16::
    3s+2s+1s circle 6H round & back
17-24::
    3s+2s+1s dance reels of 3 on sides (1s cross up & 3s give RSh to 2s
    to start)
25-32::
    3s+2s+1s dance 1/2 reel of 3 on sides (1s cross up & 3s give RSh to
    2s to start); 1s turn RH into 2nd place _while_ 2s dance out & up to
    1st place', 0);
INSERT INTO 'dancecrib' VALUES (6079, '2013-08-21 08:31:18.735123+00', '2023-02-04 01:20:55.789412+00', 3690, 3, NULL, 'ace', '{{explanation}}
2 chords - on 2nd chord 3s & 4s cross to opposite sides

1-8::
    1s & 4s set, 1L followed by partner cast to dance Fig of 8 on Ladies
    side round 2L+3M & end diagonally facing 2M (partner behind her)
    _while_ 4L followed by partner cast to dance Fig of 8 round 3L+2M &
    ends diagonally facing 3M (2s & 3s step up/down on bars 7-8)
9-16::
    1s+4s dance 1/2 diagonal Alternating Tandem reel of 4 with 1st
    corners, 1s+4s pass LSh (1/2 turning other partner LH) & dance a 1/2
    Alternating Tandem reel of 4 with 2nd corners & end passing LSh (1/2
    turning other partner) & face 1st corners
17-24::
    1s+4s repeat above reels, pass LSh & 1/2 turn other partner to end
    singly on opposite sides (from which they started) order 2 (1) 4 (3)
25-32::
    All dance 1/2 reels of 4 on sides, 1s+4s do not pass LSh but turn 2H
    to (3)(1) 4 2, all set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (6080, '2013-08-21 08:31:18.743476+00', '2023-02-04 01:20:55.805671+00', 3691, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s+2s change places RH on sides & 1s+3s
    change places LH on sides
9-16::
    2s+3s+1s dance reel of 3 on own sides (3s+1s pass LSh to start)
17-24::
    3s+1s dance LH across, 1s & 3s change places LH on sides & 2s+1s+3s
    all set
25-32::
    2s+1s+3s circle 6H round to left for 3 bars & pivot left, all circle
    6H round to the right to places', 0);
INSERT INTO 'dancecrib' VALUES (9382, '2016-10-06 07:18:37.461838+00', '2023-02-04 01:20:55.825775+00', 12820, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up). 1s set to partner then set to 1st
    corner on sidelines.  2 (1)
9-16::
    1s+1st corners dance diag RSh reel of 4, 1s pass LSh to face 2nd
    corners
17-24::
    1s+2nd corners dance diag reel of 4 finishing in in centre as 3s
    step in, ready for …
25-32::
    1s+3s dance 1/2 Diamond Poussette, 1s+4s dance 1/2 Diamond Poussette
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8534, '2015-02-13 12:47:24.123425+00', '2023-02-04 01:18:30.363025+00', 15605, 3, NULL, 'ace', '1-8::
    1s+2s dance Set & Rotate:
::
    Set, Rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on to face 2M with 1L behind him
9-16::
    1s dance 1/2 Alternating Tandem Reel with 2M+3L & face 3M, 1s dance
    1/2 Alternating Tandem Reel with 3M+2L & end 2nd place opposite
    sides
17-24::
    All Set+Link for 3 twice
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4055, '2013-08-21 08:30:42.845579+00', '2023-02-04 01:18:30.390249+00', 215, 3, NULL, 'ace', '1-8::
    1s cross down & dance out between 2s & 3s turning 3s with nearer
    hand, dance up & turn 2s with nearer hand ending in 2nd place opp
    side
9-16::
    1s set advancing & turn R about to face 2nd crnrs & set, set to 1st
    corners & set turning R about to end LSh to LSh Lady facing down,
    Man up
17-24::
    1s dance RH across (1L on Men''s side & 1M dances on Ladies'' side),
    1s continue dancing up/down & cast to 2nd place opposite sides
25-32::
    1s dance reels of 3 across Lady with 2s & Man with 3s, 1s cross RH
    to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4087, '2013-08-21 08:30:43.298313+00', '2023-02-04 01:18:33.594597+00', 274, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross LH & cast on own sides (Lady up -
    Man down) to between 2s & 3s on sides facing 1st corners
9-16::
    1s touch 1st corners RH & loop round to face each other up/down
    centre _while_ 1st corners dance RSh round each other & back to
    places, 1s 3/4 turn LH & cast on own sides (Lady down - Man up) to
    end between 2s+3s on sides facing 2nd corners
17-24::
    1s touch 2nd corners LH & loop round to face each other up/down
    centre _while_ corners dance LSh round each other & back to places,
    1s 3/4 turn RH & cast on own sides (Lady up - Man down) to end
    between 2s+3s facing 2nd corners
25-32::
    1s dance reels of 3 on opposite sides (start by giving LSh to 2nd
    corners) 1s end crossing to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (6081, '2013-08-21 08:31:18.751965+00', '2023-02-04 01:20:55.848262+00', 3695, 3, NULL, 'ace', '1-8::
    2s 3/4 turn RH, 2s dance LH across 1/2 way (2L with 1s & 2M with
    3s), 2s cast on opposite sides & turn in to face 1st corner pstns
    _while_ 1s+3s dance 1/2 R&L starting by changing place on sides RH
9-16::
    2s change pl LH with 1st crnrs, 2s set as centre couple (1L+3M)
    change pl RH, change with crnrs LH, 1L+3M set as 2s turn face 2nd
    crnrs
17-24::
    2s change pl LH with 2nd crnrs, 2s set as centre cpl (1M+3L) change
    pl RH, change with crnrs LH, 1M+3L set as 2s turn RH to own side
25-32::
    1s+2s dance RH across 1/2 way, 1s+3s dance LH across 1/2 way, 2s
    turn RH 1.1/2 times _while_ 1s turn LH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (14664, '2022-03-07 02:20:25.646629+00', '2023-02-04 01:20:56.297225+00', 20703, 3, NULL, 'ace', '1-8::
    1s set, cross RH, 1M face out, 1L pulls back RSh to follow partner;
    1M followed by 1L casts 1 place & across to face 2M (2s step up 7-8)
9-12::
    1s dance 1/2 diag Alternating tandem reel with 1st corners (RSh to
    2M). End 1L followed by 1M facing 3M
13-16::
    1s dance 1/2 diag Alternating Tandem reel with 2nd corners (RSh to
    3M).  1s dance NHJ (Lady on Man''s left) into centre facing Ladies''
    side
17-20::
    1L+3s (at top) dance LH across _while_ 1M+2s (at bottom) dance RH
    across. 1M followed by 1L end facing Man''s 1st corner (pstn)
21-24::
    1s dance 1/2 diag Alternating tandem reel with 1st corners (RSh to
    2M). End 1L followed by 1M facing 3M
25-28::
    1s dance 1/2 diag Alternating Tandem reel with 2nd corners (RSh to
    3M).  1s dance NHJ (Lady on Man''s left) into centre facing Ladies''
    side
29-32::
    1M+2s (at top) dance RH across _while_ 1L+3s (at bottom) dance LH
    across.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6082, '2013-08-21 08:31:18.760331+00', '2023-02-04 01:20:56.319297+00', 3699, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left & end in centre facing other couple;
    1s+2s set, 1s turning inwards to face up, 1s+2s dance up & 1s cast
    to 2nd place
9-16::
    1s+3s repeat with 1s casting to 3rd place _while_ 3s end in 2nd
    place
17-24::
    1s dance up to top & cast to 2nd place own sides, 1L crosses up &
    casts to 2nd place opp side _while_ 1M crosses down & casts up to
    2nd place opp side
25-32::
    1s dance reels of 3 on opposite sides (RSh to 2nd corners to start)
    & cross RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (14797, '2022-05-05 00:20:24.51559+00', '2023-02-04 01:20:56.498622+00', 17107, 3, NULL, 'ace', '1-8::
    1s dance RSh round each other to BtoB in middle, 1M facing down, 1L
    facing up (2s step up); 1s dance 6 bars Double Triangles ending in
    middle BtoB, 1M facing up, 1L facing down
9-16::
    1s dance 1/2 reels of 3 across, 1s RSh to 2nd corner ending in 2nd
    place opp sides; 1s dance 1/2 reels of 3 on sides, 1s LSh to 1st
    corner. 1s end in 2nd place opp sides in middle facing up. (3) (1)
    (2)
17-24::
    1s dance up, cast, cross down LH between 2s & cast up to 2nd place
    own side _while_ 2s+3s set, cross RH with partner, set & change
    places RH on sides. 2 1 3
25-32::
    All circle 6H 1/2 round to left, pull back LSh & chase anticlockwise
    back to place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6120, '2013-08-21 08:31:19.128821+00', '2023-02-04 01:20:58.741462+00', 3759, 3, NULL, 'ace', '1-16::
    1s dance full Petronella figure back to place _while_ 2s step up
    bars 1-2, set bars 3-4, then follow 1s. 2s petronella turn to 2nd
    place on bars 15-16
17-24::
    1s lead down centre of set & back to top
25-32::
    1s+2s dance RH across once round & 1/2 Diamond Poussette to change
    places', 0);
INSERT INTO 'dancecrib' VALUES (4070, '2013-08-21 08:30:42.999659+00', '2023-02-04 01:18:31.769939+00', 12621, 3, NULL, 'ace', '1-8::
    All dance Grand Chain with Men ending in centre giving RH
9-16::
    Men dance RH across 1/2 way, turn opp Lady LH, dance RH across 1/2
    way _while_ Ladies dance anticl''wise 1 pl, Men 3/4 turn Lady LH to
    face corner (own partner)
17-24::
    All set, change places RH with partners to face new partner, all set
    & turn new partner RH into prom hold facing anticlockwise
25-32::
    All Promenade anticlockwise & end turning new partner RH ready for
    Grand Chain', 0);
INSERT INTO 'dancecrib' VALUES (13253, '2020-10-16 00:20:41.776784+00', '2023-02-04 01:20:56.524401+00', 12996, 3, NULL, 'ace', '1-8::
    1s set, turn RH; lead down below 3s & cast up to 2nd place (2s step
    up 7-8)
9-16::
    2s+1s+3s dance »Dolphin« figure:
::
    _9-12_   Men set as Ladies Adv, pull back RSh & Ladies followed by
    partners dance towards Ladies'' side & slightly down set, ll pull
    back LSh
::
    _13-16_ Men followed by partners dance towards Men''s side & slightly
    down, Men pull back RSh & turn partner RH.  All remain in centre
    facing up
17-24::
    2s+1s+3s promenade, Bars 23-24: 2s cast to 2nd place as 1s lead up
    to 1st place.  1 2 3
25-32::
    1s+2s dance 1/2 R&L (with polite turns); 1s+2s turn partner 1.1/2
    RH. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6083, '2013-08-21 08:31:18.768605+00', '2023-02-04 01:20:56.553236+00', 3700, 3, NULL, 'ace', '1-8::
    1M followed by 2M & 3M dance across top of set, down behind Ladies;
    Men pass between Ladies to own side (to end in reverse order) & all
    set
9-16::
    2s dance RH across (2L with top couple & 2M with bottom couple), 2s
    pass RSh & dance LH across with other couple
17-20::
    1L followed by 2L+3L dance across top of set & down behind Men who
    pull back LSh, turning in place to face down & take prom hold with
    partners
21-24::
    _3_ couples Promenade 1/2 round  to original positions, 1s remaining
    in middle facing up
25-32::
    1s cast to 2nd place (2s continue dancing up) & 1s turn 2H; 1s cast
    to 3rd place (3s step up) & 1s turn 2H.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6084, '2013-08-21 08:31:18.777279+00', '2023-02-04 01:20:56.58915+00', 12795, 3, NULL, 'ace', '1-8::
    1s+2s dance Jig Tourbillon :
::
    1s+2s 3/4 turn ptnrs RH onto sides (1s to Ladies side & 2s to Mens
    side) & 1s+2s set to partners (retaining RH)
::
    1s+2s 3/4 turn ptnrs RH to face prtnr across dance (1s to 2nd place,
    2s to 1st place) & 2s+1s cross RH to own sides
9-16::
    1s cast 1 place & dance up to 2nd place, 1L dances RH across with
    2L+3L _while_ 1M dances LH across with 2M+3M
17-24::
    1s dance up between 2s & cast on own side to 2nd place, 1L dances RH
    across with 2s _while_ 1M dances RH across with 3s
25-32::
    1s dance reels of 3 on opposite sides (RSh to 1st corner) & end
    crossing to 2nd place passing LSh', 0);
INSERT INTO 'dancecrib' VALUES (6085, '2013-08-21 08:31:18.787275+00', '2023-02-04 01:20:56.708671+00', 3701, 3, NULL, 'ace', '1-8::
    1s turn RH & cast to 3rd place
9-16::
    1s turn LH & cast back to places
17-24::
    1s lead down the middle & back to top, cross & cast to 2nd place
25-32::
    2s+1s+3s clap 3 times, 1 silent beat - tap with right heels 3 times
    - 1 silent beat, 1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (6086, '2013-08-21 08:31:18.796508+00', '2023-02-04 01:20:56.727759+00', 3702, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 on own sides (2s out & down to start)
9-12::
    1s & 4s turn RH & cast in 1 place _while_ 2s+3s dance 1/2 RH across
    & lead out to ends.  (3) 1 4 (2)
13-16::
    3s & 2s turn RH & cast in 1 place _while_ 1s+4s dance 1/2 RH across
    & lead out to ends.  (4)(3)(2)(1)
17-24::
    4s+3s also 2s+1s dance double Fig of 8  (3s cross up, 2s cross down)
25-32::
    4s+3s change places RH on sides & then 4s+2s change places LH on
    sides, 3s+2s change places RH on sides & all cross LH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6087, '2013-08-21 08:31:18.806591+00', '2023-02-04 01:20:56.751006+00', 9818, 3, NULL, 'ace', '1-8::
    1s dance in & cast behind 2s in front of 3s & behind 4s
9-16::
    All circle 8H round to left
17-24::
    1s dance in & cast up behind 4s in front of 3s & behind 2s
25-32::
    1s set & cast to 4th place & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6088, '2013-08-21 08:31:18.812892+00', '2023-02-04 01:20:56.776321+00', 10106, 3, NULL, 'ace', '1-8::
    1s set advancing, turn single, Slip-Step to bottom of set & cast up
    1 place own sides
9-16::
    2s repeat bars 1- 8
17-24::
    Top 2 couples also bottom 2 couples 1/2 R&L, middle 2 couples 1/2
    R&L _while_ end couples set & cross RH
25-32::
    All set, cross RH, circle 8H round to left 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (6089, '2013-08-21 08:31:18.821261+00', '2023-02-04 01:20:56.804944+00', 3704, 3, NULL, 'ace', '1-8::
    1s cast 2 places, dance up between 3s & behind 2s back to places
9-16::
    1s+2s set to partners, set to each other on sides & dance 1/2 double
    Fig of 8 (1s cross down to start)
17-24::
    1s dance reels of 3 on own sides (1s in & down to start) & end with
    1s continuing to 2nd place
25-32::
    2s+1s set to partners, set to each other on sides & dance 1/2 double
    Fig of 8 (1s cross up to start)
33-40::
    2s+1s+3s circle 6H round & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6090, '2013-08-21 08:31:18.829515+00', '2023-02-04 01:20:56.831679+00', 3705, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, set & 1/2 turn LH into prom hold
9-16::
    1s+2s+3s Promenade & end with 1s casting to 2nd place
17-24::
    1s dance reels of 3 on opposite sides (1s cross RH down to start) &
    1s end facing 2nd corners
25-32::
    1s dance Pass+Turn with 2nd corner, turn RH & repeat with 1st
    corners ending in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6091, '2013-08-21 08:31:18.841662+00', '2023-02-04 01:20:56.864906+00', 3706, 3, NULL, 'ace', '1-4::
    1s+2s also 3s+4s dance RH across 1/2 way & 1s+4s (middle couples)
    dance LH across 1/2 way
5-8::
    2s+4s also 1s+3s dance RH across 1/2 way & 2s+3s (middle couples)
    dance LH across 1/2 way. All end on opposite sides (4)(3)(2)(1)
9-12::
    3s & 2s dance up/down sides & cross RH at top/bottom _while_ 4s & 1s
    dance in & lead down/up & dance 1/2 RH across
13-16::
    1s & 4s dance up/down sides & cross RH at top/bottom _while_ 3s & 2s
    dance in & lead down/up & dance 1/2 RH across.  (1)(2)(3)(4)
17-24::
    1M+2L change place LH & 1L+2M also 1M+3M change places RH, 1L+3L &
    1M+4L change places LH & 1L+4M change place RH
25-32::
    All Ladies set on sides & advance, Ladies retire & set _while_ all 4
    Men advance & retire twice', 0);
INSERT INTO 'dancecrib' VALUES (11702, '2019-03-18 21:02:26.442566+00', '2023-02-04 01:20:56.911263+00', 11784, 3, NULL, 'ace', '1-4::
    1M+2L also 3M+4L 1/2 turn RH, pull back RSh & dance out to opp sides
    facing out, to change places
5-8::
    1M  (3M) dances up behind partner & across set to place _while_ 2L
    (4L) dances down behind partner & across set to place
9-12::
    1L+2M also 3L+4M repeat bars 1-4
13-16::
    1L (3L) dances up behind partner & across set to place _while_ 2M
    (4M) dances down behind partner & across set to place, stay facing
    out
17-24::
    1s+2s+3s+4s dance reels of 4 on sides
25-28::
    1s+2s also 3s+4s change places RH on sides, 1s face down & 4s face
    up; 1M+4M also 1L+4L change places LH
29-32::
    2s+4s also 1s+3s dance RH across once round.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3984, '2013-08-21 08:30:40.838048+00', '2023-02-04 01:18:25.450328+00', 116, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Promenade
9-16::
    1s+2s dance RH across for 3 steps, LH across & 1s cast 1 place, 2s
    dancing to top
17-24::
    2s+1s+3s circle 6H round & back 1s end facing 1st corners
25-32::
    1s set to 1st corners, turn corners RH & retaining hands
    Bal-in-Line, 1s turn LH to face 2nd corners
33-40::
    1s set to 2nd corners, turn RH & retaining hands Bal-in-Line; 1s
    turn LH to face 1st corners again
41-48::
    1s dance reels of 3 on opposite sides giving LSh to 1st corner, 1s
    cross to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (13032, '2020-08-10 00:18:27.829908+00', '2023-02-04 01:18:31.920163+00', 15539, 3, NULL, 'ace', '1-8::
    1L+3L pass LSh & dance LSh round opposite Man to change places;
    1s+3s 1/2 turn partner RH, pull back RSh & dance out to opp side
9-16::
    2L+4L repeat 1-8
17-24::
    All Men cast RSh round standing Lady, through centre & turn partner
    1.1/2 RH to original places.  Men face in, Ladies face out
25-32::
    All dance 8 bars Schiehallion Reel (all move 2 places anticlockwise
    to 3 4 1 2)
33-36::
    All turn partner 3/4 RH into prom hold & promenade 1 place round
    clockwise  (2 3 4 1)
37-40::
    All join NH with partner & dance in, dance out NH joined with
    corner, drop hands & turn away from corner to meet partner.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4071, '2013-08-21 08:30:43.095001+00', '2023-02-04 01:18:32.067667+00', 240, 3, NULL, 'ace', '1-8::
    1s cast to 2nd place, 2s+1s+3s set, 2s & 3s chase clockwise to other
    end as 1s turn RH to face 3rd corner (pstn)
9-16::
    1s dance 1/2 reel with 3rd corners, 2s & 3s chase clockwise to other
    end _while_ 1s turn ptnr RH to face 2nd corners
17-24::
    1s dance 1/2 reel with 2nd corners, 2s & 3s set & change places RH
    on sides _while_ 1s turn RH to end in 2nd place BtoB facing own
    sides
25-32::
    1s dance Double Triangles with 2s+3s crossing RH to own sides as 1s
    turn to face opposite sides, 1s pass RSh to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6092, '2013-08-21 08:31:18.850108+00', '2023-02-04 01:20:56.940693+00', 3710, 3, NULL, 'ace', '{{explanation}}
2 chords. On 2nd chord 1s+2 also 3s+4s step into Glasgow Highlanders positions

1-8::
    1s+2s also 3s+4s 1/2 turn partners RH into Reels of 4 across ending
    with Men BtoB facing partner
9-16::
    1s+2s also 3s+4s set to partners (in line across) & Ladies set again
    as Men petronella to right, 1s+2s & 3s+4s circle 4H round to left to
    orig places
17-24::
    2s also 3s dance across (passing opposite dancer LSh) & dance
    down/up opposite side, 1/2 turn partner LH & Prom to places (M pass
    LSh)
25-32::
    1s & 4s repeat bars 17-24 but pass opposite dancers RSh 1/2 turn
    partner RH & Promenade back to places (Ladies passing RSh)
33-40::
    All circle 8H round to left 1/2 way, turn partner 2H (moving on) &
    continue circle round to left back to places
41-48::
    All set to partners, 1/2 turn RH & dance 1/2 Reel of 4 on sides', 0);
INSERT INTO 'dancecrib' VALUES (6093, '2013-08-21 08:31:18.860121+00', '2023-02-04 01:20:57.045935+00', 3711, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s dance down the centre & back up ending BtoB between 2s, Man
    facing Lady
17-24::
    1s+2s dance a reel of 4 across 1s ending in centre on own sides
    facing up NHJ
25-32::
    1s dance up & cast 1 place, dance down between 3s & cast up to 2nd
    place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (6094, '2013-08-21 08:31:18.868443+00', '2023-02-04 01:20:57.079202+00', 12888, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH, lead down below 3s & cast up to top
9-16::
    1s cross down (each couple cross down as they reach top place) to
    dance reflection reels of 3 on sides
17-24::
    1s cross down (each couple cross down as they reach top place) to
    dance reflection reels of 3 on sides
25-32::
    1s+2s set & dance 3/4 R&L (3 moves)', 0);
INSERT INTO 'dancecrib' VALUES (13254, '2020-10-16 00:20:42.352861+00', '2023-02-04 01:20:57.111316+00', 16901, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up); 1s turn 1.1/4 RH to face 2nd corners
9-16::
    1s+2nd corners dance 1/2 diag reel of 4, 1s pass RSh to face 3rd
    corners; 1s+3rd corners dance 1/2 diag reel of 4.  End 1M between 3s
    (at top) facing down, 1L between 2s facing up
17-24::
    1s dance RSh round 1st corner (pstn) to change ends & turn 1.1/4 LH
    to face 2nd corners (pstn)
25-32::
    1s+corners dance 1/2 LSh diag reel of 4, 1s pass LSh to face 1st
    corner (pstn); 1s+corners dance 1/2 LSh diag reel of 4, 1s pass LSh
    to 2nd place own side
33-40::
    2s+1s+3s chase anticlockwise 1/2 round; 1s turn 1.1/2 LH to own side
    as 2s+3s continue chase to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6096, '2013-08-21 08:31:18.888209+00', '2023-02-04 01:20:57.254319+00', 3723, 3, NULL, 'ace', '1-8::
    1s+2s+3s Cross RH & cross back RH
9-16::
    1s+2s+3s Promenade
17-24::
    1s+2s dance 1/2 Diamond Poussette, 1s set to 1st corners & set to
    2nd corners
25-32::
    1s turn 1st corners RH, turn partner LH, turn 2nd corners & turn
    partners LH to end 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6097, '2013-08-21 08:31:18.907329+00', '2023-02-04 01:20:57.288336+00', 7795, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to top
9-16::
    1s cast 1 place (2s step up) & cross passing LSh, cast round 1st
    corner & turn partner LH to face 1st corners
17-32::
    1s dance Corner Chain with 1st & 2nd corners:
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end with 1/2 turn LH to end
    2nd pl own sides', 0);
INSERT INTO 'dancecrib' VALUES (6098, '2013-08-21 08:31:18.922057+00', '2023-02-04 01:20:57.314162+00', 3725, 3, NULL, 'ace', '1-8::
    1s set advancing, turn 2H, cast down 1 place & cross RH
9-16::
    1s dance reel of 3 on opposite sides, 1s giving RSh to 1st corner &
    end facing 1st corners
17-24::
    1s set to 1st corners & turn 2H, set to 2nd corners & turn
25-32::
    1s dance reels of 3 across (Man with 2s & Lady with 3s) & cross back
    to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8299, '2014-07-29 12:58:40.932321+00', '2023-02-04 01:18:25.518052+00', 15341, 3, NULL, 'ace', '1-8::
    1s followed by 2s, 3s & 4s lead down, cross and dance up to partners
    original place.
9-16::
    1s+3s petronella and set. 1s+3s petronella to own side and set.
17-20::
    1s+2s dance 1/2 R&L
21-24::
    1M+3L set and link, _while_ 1L+3M set and link.
25-28::
    1s+4s set and dance RH across 1/2 way.
29-32::
    1s set and turn 2H.', 0);
INSERT INTO 'dancecrib' VALUES (6099, '2013-08-21 08:31:18.933568+00', '2023-02-04 01:20:57.338991+00', 11111, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, 2s+1s+3s turn RH
9-16::
    2s+1s+3s circle 6H round & back
17-24::
    1s set adv to 1st corners, turn crnrs LH, 1M dances up between 2s &
    casts up to 2nd pl _while_ 1L dances down between 3s & casts up to
    2nd pl
25-32::
    1s set adv to 2nd corners, turn crnrs RH, 1M dances down between 3s
    & casts up to 2nd pl _while_ 1L dances up between 2s & casts to 2nd
    pl', 0);
INSERT INTO 'dancecrib' VALUES (6100, '2013-08-21 08:31:18.941885+00', '2023-02-04 01:20:57.366185+00', 3726, 3, NULL, 'ace', '1-8::
    1s turn 1.1/4 times moving down (2s step up 3-4), 1s dance 1/2 reels
    of 3 across [Man with 2s (LSh to 2L) & Lady with 3s (RSh to 3M)] &
    end lines of 3 across
9-16::
    Both lines dance down, all turning right about, dance back & end
    with 1M+2L (top line) turning to face 1L+3s
17-24::
    2s+1s+3s set & change places RH with person opposite, 1s cast into
    2nd place own sides _while_ 2s+3s cross LH; 3s+1s+2s set
25-32::
    3s+1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (6101, '2013-08-21 08:31:18.950317+00', '2023-02-04 01:20:57.392005+00', 3728, 3, NULL, 'ace', '1-4::
    1M & 2M dance across between 1L & 2L cross & cast back to each
    others place
5-8::
    1L & 2M dance 1/2 Figs of 8 round next couple (1s end on Mens side,
    2s Ladies side)
9-12::
    1M & 2M set & cast up/down 1 place as 1L+2L dance progressive DoSiDo
    to end 2M/1L places
13-16::
    2L & 1L set & cast down/up 1 place as 2M & 1M dance progressive
    DoSiDo to end 1L/2M places
17-24::
    2M+1L also 2L+1M 1/2 turn 2H & circle 4H round 1/2 way, 1s+2s dance
    R&L 1/2 way (1s ending Ladies side)
25-32::
    2s+1s dance variation of Tournee:
::
    Advance into middle (Men LSh to LSh) with partner on right (2s
    facing Ladies side & 1s Mens side) & couples 1/2 wheel anticl''wise,
    Men turn Ladies into middle & both couples turn 1.1/2 times (2s RH,
    1s LH) & dance out to places', 0);
INSERT INTO 'dancecrib' VALUES (6102, '2013-08-21 08:31:18.95856+00', '2023-02-04 01:20:57.419+00', 3730, 3, NULL, 'ace', '1-8::
    1s cast to 3rd place & cast back to top
9-16::
    1s cross RH, cast 1 place, cross LH cast to 3rd place lead up to end
    facing 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s dance out Mans side & dance Figs of 8 back to place (1L round 2s
    & 1M round 3s)', 0);
INSERT INTO 'dancecrib' VALUES (6104, '2013-08-21 08:31:18.978314+00', '2023-02-04 01:20:57.681434+00', 3737, 3, NULL, 'ace', '1-8::
    1s lead down to 3rd place, set, lead back to top & set
9-16::
    1s+2L circle 3H round to left, 1s+2M circle 3H round to left
17-24::
    1s set & cross RH to 2nd places, set & cross over
25-32::
    1s dance Figs of 8 on own sides (out & down round 3s to start)', 0);
INSERT INTO 'dancecrib' VALUES (6105, '2013-08-21 08:31:18.986646+00', '2023-02-04 01:20:57.704853+00', 3735, 3, NULL, 'ace', '1-8::
    1M casts down 1 place as 2L casts up, 1M+2L turn RH ending in
    original places
9-16::
    1L casts down 1 place as 2M casts up, 1L+2M turn LH ending in
    original places
17-24::
    1s lead down below 3s, set & dance 1/2 Fig of 8 round 3s
25-32::
    1s lead up 1 place, set & dance 1/2 Fig of 8 round 2s', 0);
INSERT INTO 'dancecrib' VALUES (13902, '2021-04-05 00:20:31.123051+00', '2023-02-04 01:20:57.938626+00', 3738, 3, NULL, 'ace', '1-8::
    1s cast one place, lead up, cross & cast to 2nd place (2s step up)
9-16::
    1s lead down between 3s, cross & cast to face 1st corners
17-24::
    1s set to & turn 1st corner; set to & turn 2nd corner
25-32::
    1s dance reel of 3 on opposite sides giving LSh to 1st corner &
    cross back to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (14798, '2022-05-05 00:20:25.737281+00', '2023-02-04 01:20:57.979869+00', 3739, 3, NULL, 'ace', '1-8::
    1s in prom hold dance reel of 3 with 2M+3M (pass 2M RSh) _while_ 4s
    in prom hold dance reel of 3 with 2L+3L (pass 3L RSh). All end on
    sides, 1s & 3s face down, 2s & 4s face up
9-16::
    All dance reels of 4 on sides
17-24::
    1s & 4s set to partners & cast in 1 place (2s+3s step down/up); all
    set to partners, 2s+1s also 4s+3s dance 1/2 RH across.  (1) (2) (3)
    (4)
25-28::
    All set, cross RH with partner to own side
29-32::
    1s cast to 4th place _while_ 2M+3M turn LH, 2L+3L turn RH & 4s lead
    up to top to end  4 2 3 1,  all finish in centre facing partner
    ready for …
33-40::
    4s+2s also 3s+1s dance Poussette to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6106, '2013-08-21 08:31:18.995085+00', '2023-02-04 01:20:58.011038+00', 10406, 3, NULL, 'ace', '1-8::
    1s followed by 2s lead down, 1s cast back up to top _while_ 2s lead
    back to place
9-16::
    1s cross down (each couple cross down as they reach top place) to
    dance reflection reels of 3 on sides
17-24::
    1s set, turn 1.1/4 LH into 1/2 Fig of 8 round 2s, crossing down &
    casting back to original places
25-32::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13903, '2021-04-05 00:20:31.173661+00', '2023-02-04 01:20:58.042024+00', 19492, 3, NULL, 'ace', '1-8::
    1s dance in & cast (2s step up); 1s set & Petronella turn to 1M
    between 3s, 1L between 2s
9-16::
    All set, circle 6H to left to sides (1s in 2nd place opp side) & all
    set.
17-20::
    1s dance through 3rd corner pstn _while_ 2s+3s set advancing
    diagonally, 1s chase anticlockwise back to 2nd place opp side
    _while_ 2s+3s circle 4H 1/2 round to right
21-24::
    1M+3L & 1L+2M take prom hold & chase 1/2 round anticlockwise _while_
    2L+3M turn 2H, pull back RSh & dance out to end in lines of 3
    across, 1M between 3s at top, 1L between 2s
25-32::
    Lines of 3 across Set+Link for 3 couples; 3s+1s+2s 1/2 turn 2H, pull
    back RSh & dance out to own side.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6107, '2013-08-21 08:31:19.003351+00', '2023-02-04 01:20:58.07675+00', 3743, 3, NULL, 'ace', '1-8::
    1s cross down (each couple cross down as they reach top place) to
    dance reflection reels of 3 on sides
9-16::
    1s cross down (each couple cross down as they reach top place) to
    dance reflection reels of 3 on sides
17-24::
    1s set & cross RH then cast 1 place, cross down between 3s & cast up
    to 2nd place on own sides
25-32::
    1s lead up between 2s & cast down 1 place, 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (14291, '2021-09-08 00:20:31.201811+00', '2023-02-04 01:20:58.100953+00', 20445, 3, NULL, 'ace', '1-8::
    1s+2s dance Chain & Turn:
::
    _1-2_   1M+2L turn 3/4 RH to face 1L & 2M on diagonal
::
    _3-4_   1L+2L also 1M+2M change places LH, 2L+1M face each other in
    the centre
::
    _5-8_   1L+2M turn 1.1/4 RH to finish 1L in 2L place. 2M in 1M
    place.  2 1 3
9-16::
    2s+1s+3s Set & Rotate for 3 couples:
::
    All set & rotate singly & chase clockwise to form lines of 3 across
    (Men facing down & Ladies up)  all change places RH with partner &
    chase clockwise to own sides. 3 1 2
17-24::
    1s pass LSh to dance 1/2 RSh diag reel of 4 with 1st corners; 1s
    pass LSh to dance 1/2 RSh diag reel of 4 with 2nd corners. 1s pass
    RSh to 2nd place own sides.  (2) 1 (3)
25-32::
    2s+3s dance 1/2 Double Fig 8 round 1s (2s cross down, 3s cast up to
    start); 2s+1s+3s turn partner 2H', 0);
INSERT INTO 'dancecrib' VALUES (6448, '2013-08-21 08:31:24.395634+00', '2021-09-08 00:20:52.491086+00', 7835, 3, NULL, 'ace', '1-8::
    1L+3M set & turn RH 1.1/2 times, dance out thru others pl & cast to
    partners place _while_ (bar 5) 1M+3L set & turn LH to face partner
    (in diag line)
9-16::
    1s+3s set to partners & turn RH & end in partners original place
    then 2s set & turn LH into diag line facing 1st corners (2M faces 1L
    & 2L faces 3M)
17-24::
    2s+1L+3M dance 1/2 reel of 4 with 1st corners & 1/2 reel with 2nd
    corners (2s+3s end in centre for Diamond Poussette)
25-32::
    2s+3s dance 1/2 Diamond Poussette, 3s+1s dance 1/2 Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (3986, '2013-08-21 08:30:40.892776+00', '2023-02-04 01:18:25.545305+00', 13629, 3, NULL, 'ace', '1-8::
    1s dance down between 2s & cast up, 1s dance 1/2 Fig of 8 round 2s
9-16::
    1s dance down between 3s & cast up, 1s dance 1/2 Fig of 8 round 3s &
    end facing 1st corners
17-24::
    1s turn 1st corners RH & pass RSh to face 2nd corners, turn corners
    RH & pass RSh to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4056, '2013-08-21 08:30:42.851752+00', '2023-02-04 01:18:30.415124+00', 9840, 3, NULL, 'ace', '1-8::
    1s+2s set & dance RH across 1/2 way, 1s+3s dance 1/2 R&L
9-16::
    3s+1s set & dance LH across 1/2 way, 2s+1s dance 1/2 R&L
17-24::
    1s lead down the middle for 4 steps, lead up to 2nd place & 2s+1s+3s
    set on sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6108, '2013-08-21 08:31:19.011751+00', '2023-02-04 01:20:58.126821+00', 3745, 3, NULL, 'ace', '1-8::
    1s & 3s turn RH 1.3/4 times, set (up/down) & dance 1/2 reel of 4 in
    centre
9-16::
    3M & 1L stand (in end of reel pstns) _while_ 3L+1M pass LSh to dance
    1/2 reel of 4 across with 2s & end facing ptnr & dance 1/2 reel
    up/down
17-24::
    1s+3s set to partners & petronella turn to partners original place,
    1s+2s+3s set & cross RH
25-32::
    2s followed by 1s dance out round 3s into centre & dance up to top
    with 1s continuing to dance up between 2s & cast to 2nd place
::
    (1s cast to 4th place 2nd time through)', 0);
INSERT INTO 'dancecrib' VALUES (6109, '2013-08-21 08:31:19.020074+00', '2023-02-04 01:20:58.142203+00', 9871, 3, NULL, 'ace', '1-8::
    1s set & cross down RH, set & 3/4 turn LH to face 1st corners
9-16::
    1s dance 1/2 diagonal reel with 1st corners, pass RSh & dance
    Pass+Turn with 2nd corners
17-24::
    1s dance Pass+Turn with 3rd corner (pstns) & 1/2 diagonal reel with
    4th corner (pstns)
25-32::
    1s dance RH across (1L with 3s at top & 1M with 2s) end in 2nd place
    opposite sides & chase clockwise 1/2 way
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6110, '2013-08-21 08:31:19.033557+00', '2023-02-04 01:20:58.274235+00', 9387, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s lead down, Lady turns under Mans arm to change places, lead up &
    turn RH to face 1st corners
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners, turn 2H to face
    2nd corners, dance 1/2 diagonal reel with 2nd corners & 1/2 turn 2H
    & pass RSh to face own side BtoB for Double Triangles

{{title}}
Reel

17-24::
    1s dance Petronella Triangles (1s dance Double Triangles as corners
    set & petronella on I place to right & repeat), 1s end facing 2nd
    corners pstns
25-32::
    1s dance RSh reels of 3 across (Man with 2s & Lady with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (13904, '2021-04-05 00:20:31.468793+00', '2023-02-04 01:20:58.431723+00', 10273, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s (dance up sides to start) lead down; 3s divide
    & 2s+1s+3s lead up. End: 2s in 1st place, 1s facing 1st corners & 3s
    in 3rd place
9-16::
    1s+1st corners dance diag reel of 4, 1s pass LSh to face 2nd corners
17-24::
    1s+2nd corners dance diag reel of 4, 1s end in middle facing down
    NHJ (Lady on Man''s left)
25-32::
    1s dance down below 3s, cast up, meet, dance up & cast to 2nd place
    _while_ 2s+3s dance R&L (change places RH on sides to start)', 0);
INSERT INTO 'dancecrib' VALUES (6114, '2013-08-21 08:31:19.066783+00', '2023-02-04 01:20:58.453308+00', 13081, 3, NULL, 'ace', '1-8::
    2s 1/2 turn RH twirl & dance out, 2s dance clockwise to ends & dance
    in (up/down) _while_ 1s & 3s 1/2 turn RH twirl & dance out
9-16::
    2s turn LH 1.1/2 times _while_ 2s & 3s dance clockwise 1/2 way, 2s
    dance RH across (2M with 3s at top, 2L with 1s) to end facing 3rd
    corner (pstn)
17-24::
    2s dance diagonal reel of 4 with 3rd corners & end passing LSh to
    face 2nd corner (pstn)
25-32::
    2s dance diagonal reel of 4 with 2nd corners & ending 2nd place own
    sides.  3 2 1
33-40::
    3s+2s 1/2 turn partners RH & dance RH across 1/2 way, 3s+1s 1/2 turn
    partners RH & dance RH across 1/2 way.  2 1 3
41-48::
    All set & cross RH, all chase clockwise 1/2 way.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (15419, '2023-02-04 01:20:58.372052+00', '2023-02-06 10:35:43.796711+00', 9780, 3, NULL, 'ace', '1-8::

    1s dance DoSiDo, dance in (briefly touch hands) & cast to 2nd place

    _while_ 2s stand (2 bars), dance DoSiDo & dance in, join NH & dance

    up to 1st place _while_ 3s stand (4 bars) & dance DoSiDo

9-24::

    1s dance Corner Chain with 1st & 2nd corners:

::

    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return

    to places giving RH to 1s who turn LH in centre to face 2nd crnrs

::

    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &

    return to places giving RH to 1s & 1s 3/4 turn LH to end in middle

    1L above 1M

25-32::

    1L+2s & 1M+3s dance RH across back to place; 2s+1s+3s turn partner

    RH', 0);
INSERT INTO 'dancecrib' VALUES (6115, '2013-08-21 08:31:19.075133+00', '2023-02-04 01:20:58.492974+00', 10919, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    1L followed by partner dance Fig of 8 round 2L+3M (in front of 2L to
    start) _while_ 4L followed by partner dances Fig of 8 round 3L+2M
9-16::
    2L+3L change places LH & turn partners RH on sides, cross back LH &
    turn RH adjacent Man on sides
17-24::
    2s dance up between 1s & cast to places _while_ 3s dance down & cast
    to places, all 4 couples set & 1/2 turn partners RH ready for…
25-32::
    All dance Interlocking Allemandes:
::
    1s+2s dance normal Allemande but end in 3rd/1st places _while_ 3s+4s
    Allemande (down) & up to 4th/2nd places to end 2(4)1(3)', 0);
INSERT INTO 'dancecrib' VALUES (6116, '2013-08-21 08:31:19.083823+00', '2023-02-04 01:20:58.511994+00', 14955, 3, NULL, 'ace', '1-8::
    1s set & dance down between 3s, 1s cast up behind 3s & pass LSh to
    face 1st corners (2s step up 3-4)
9-12::
    1s dance a »Gypsy Poussette« with 1st corners:
::
    Box setting:
::
    _9_    All set to the right, pull back RSh so 1L+2M also 1M+3L are
    BtoB
::
    _10_   All set to the left  & pull back RSh so 1L+2M also 1M+3L are
    facing having changed places
::
    _11_   All set to the right, pull back RSh so 1L+2M also 1M+3L are
    BtoB
::
    _12_   All set to the left, pull back RSh so 1s & 1st corners have
    returned to positions at start of figure
13-16::
    1s dance round to the right (2 bars) flowing into 2H turn 3/4 round
    (2 bars), 1M pulls back RSh to end with1s facing 2nd corners
17-24::
    Repeat bars 9-16 with 2nd corners. 1s end in middle BtoB (1M facing
    up, 1L down)
25-32::
    1s dance reels of 3 across passing 2nd corners RSh & 1s ending 2nd
    place own sides', 0);
INSERT INTO 'dancecrib' VALUES (3987, '2013-08-21 08:30:40.900937+00', '2023-02-04 01:18:25.739438+00', 10823, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place (2s step up), 1s dance down for 2 steps & back
    up to end BtoB facing own sides
9-16::
    All set & 1L+2L change places LH _while_ 1M+2M change places RH, all
    set & 2L+3L change places RH _while_ 2M+3M change places LH
17-24::
    All set & 1L+3L change places LH _while_ 1M+3M change places RH; 3s
    dance 1/2 reflection reel of 3 on sides (3s dance in & down to
    start)
25-32::
    All petronella turn & set, all petronella turn to opposite sides &
    all 1/2 turn partner RH to own sides.', 0);
INSERT INTO 'dancecrib' VALUES (8771, '2015-06-15 11:40:23.014142+00', '2023-02-04 01:18:25.777468+00', 16123, 3, NULL, 'ace', '1-8::
    1s+2s dance 3/4 double Fig 8 (1s dance down, 2s cross up). 2s set as
    1s turn 3/4 LH finishing BtoB (1L face up, 1M down)
9-16::
    1s dance Double Triangles up/down. Bars 11-12 2M+3M & 2L+3L change
    places RH; Bars 15-16 1s petronella turn to 2nd place opp sides
17-24::
    1s dance diag R&L (1M up, 1L down)  (2) (1) (3)
25-32::
    2s+1s+3s circle 6H round & back

{{explanation}}
Repeat:-  Bars 1-6 Men cross in front of Ladies in 3/4 doubleFig 8.  Bars 5-8 new 3s & standing top couple cross RH & set', 0);
INSERT INTO 'dancecrib' VALUES (4057, '2013-08-21 08:30:42.85998+00', '2023-02-04 01:18:30.445169+00', 218, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1L+2L+3L Adv+Ret & set _while_ 1M+2M+3M set & Adv+Ret, 1s+2s+3s
    cross RH
17-24::
    1s+2s set, 1s cross LH to 2nd pl own side as 2s cast up, 1s dance
    1/2 RSh reels of 3 on sides (1M up & 1L dn) & pass LSh to face 1st
    crnr (pstns)
25-32::
    1s dance 1/2 reels of 4 with 1st corners, turn to right about to
    face 4th corner (pstn) & dance 1/2 reel with 2nd corners', 0);
INSERT INTO 'dancecrib' VALUES (6117, '2013-08-21 08:31:19.092129+00', '2023-02-04 01:20:58.556862+00', 3755, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH & chase 1/2 way
9-16::
    1s set adv to 1st corners, turn 2H & open out (crnrs on right) &
    circle 6H to left 1/2 way, end with 1L between 2s facing up & 1M
    between 3s facing down
17-24::
    1s set adv to 2nd corner persons (in diag opp pstns), turn 2H & open
    out for 6H 1/2 way end with corners in own place & 1s in 2nd place
    opp side
25-32::
    1s dance RH across (Lady with 3s & Man with 2s), 1s cross LH & cast
    to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (6123, '2013-08-21 08:31:19.165304+00', '2023-02-04 01:20:58.996003+00', 7448, 3, NULL, 'ace', '1-8::
    1M dances out between 1L+2L & casts down round 2L to dance RH across
    with 1L+2L _while_ 3L dances out between 2M+3M & casts up round 2M
    to dance RH across with 2M+3M all ending in original places
9-16::
    1L dances out between 1M+2M & casts down round 2M to dance LH across
    with 1M+2ML _while_ 3M dances out between 2L+3L & casts up round 2L
    to dance LH across with 2M+3M all ending in original places
17-24::
    1s cross LH, cast 1 place & turn RH to face 1st corners
25-32::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners', 0);
INSERT INTO 'dancecrib' VALUES (6124, '2013-08-21 08:31:19.173673+00', '2023-02-04 01:20:59.04321+00', 9682, 3, NULL, 'ace', '1-4::
    1s & 3s set, 1M closely followed by partner cast 1 place to face 4L
    _while_ 3L closely followed by partner cast 1 place to face 5M
5-8::
    1s+4L dance RH across _while_ 3s+5M dance LH across
9-16::
    1M followed by partner dance an Alternating Tandem reel with 2L+4L
    (on sides LSh to 2L to start) _while_ 3L followed by partner dance
    an Alternating Tandem reel with 4M+5M giving RSh to 4M
17-24::
    Repeat on other side with 1s giving RSh to 2M & 3s giving LSh to 4L
25-32::
    1s & 3s cast on opposite sides to 3rd & 5th places, set & turn RH
    1.1/2 times to own sides', 0);
INSERT INTO 'dancecrib' VALUES (14532, '2022-01-10 02:19:53.398544+00', '2023-02-04 01:20:59.070493+00', 17967, 3, NULL, 'ace', '1-8::
    1s lead down middle & back to face 1st corners (2s step up 3-4)
9-16::
    1s dance diag reel of 4 with 1st corners, pass LSh to face 2nd
    corners
17-24::
    1s dance diag reel of 4 with 2nd corners, finish in middle, LSh to
    LSh facing opp sides
25-32::
    1s dance LSh round each other & out to 2nd place own side & cast to
    3rd place (3s step up 27-28); All turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (8982, '2015-11-30 08:59:27.075357+00', '2023-02-04 01:18:32.233486+00', 12754, 3, NULL, 'ace', '1-8::
    1s dance in, touch hands & cast to 3rd place (2s+3s step up).  1s
    turn RH (4 bars)   2 3 1
9-16::
    3s followed by 2s dance down (3 steps), cast up round 1s, meet &
    dance up to top & cast to 2nd place (2s cast into 1st place)
17-24::
    2s+3s+1s NHJ advance towards top & retire to places.  All turn
    partners RH  2 3 1

{{explanation}}
Repeat 5 times', 2);
INSERT INTO 'dancecrib' VALUES (4074, '2013-08-21 08:30:43.155087+00', '2023-02-04 01:18:32.263538+00', 7591, 3, NULL, 'ace', '1-8::
    1s & 4s set & cast in 1 place, dance 1/2 Fig of 8 round end couples
9-16::
    1s+4s dance LH across, 2s+1s also 4s+3s dance RH across
17-24::
    All dance RSh reels of 4 on sides
25-32::
    1s+4s dance 1/2 R&L & all turn partners', 0);
INSERT INTO 'dancecrib' VALUES (6125, '2013-08-21 08:31:19.182119+00', '2023-02-04 01:20:59.103592+00', 3765, 3, NULL, 'ace', '1-4::
    1s+2s also 3s+4s dance 1/2 RH across, 1L & 4M cast to end in middle
    facing up/down as 1M+4L turn 2H into middle to face partner
5-8::
    1s+4s dance 1/2 reel of 4 up/down middle
9-16::
    All set in diamond formation & Petronella turn (4s/1s to sides,
    2s/3s into middle); 2s+3s dance 1/2 reel of 4 (up/down)
17-24::
    All set in diamond formation & Petronella turn (3s/2s to sides,
    4s/1s into middle); 4s & 1s 3/4 turn RH onto sides (b''tw''n 3s/2s) &
    all set.  (3)(4)(1)(2)
25-32::
    All dance Double Snowball Grand Chain:
::
    _25-28_   3s & 2s cross RH & then change places LH on side with
    4s/1s
::
    _29-30_   4s & 1s cross RH _while_ 3s+2s change places on sides RH
::
    _31-32_   4s+2s & 3s+1s change places LH on sides.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8336, '2014-07-29 12:59:12.588063+00', '2023-02-04 01:20:59.278608+00', 15224, 3, NULL, 'ace', '1-8::
    All turn partners RH, all turn corners LH with 1M+3M retaining LH
    with corners moving towards centre, 1M+2L+3M+4L dance LH across.
    Finish facing partners in 2 parallel diagonal lines
9-16::
    All dance parallel reels of 4
17-24::
    All set, turn partners RH into promenade hold & face clockwise
    (1s+3s 1/2 turn, 2s+4s full turn)  & promenade 1/2 way round set
25-32::
    Ladies dance RH across, pick up partner in promenade hold &
    promenade clockwise 1/2(+) way round to form square set again   4 1
    2 3', 0);
INSERT INTO 'dancecrib' VALUES (12730, '2020-04-11 10:52:00.537956+00', '2023-02-04 01:20:59.300332+00', 9657, 3, NULL, 'ace', '1-4::
    1M+2M+3M set diagonally down  to 2L+3L+4L & change places diagonally
    RH
5-8::
    1L+1M+2M (top 3 Ladies'' side) set to 3L+4L+4M (bottom 3 Men''s side)
    & change places diagonally RH
9-12::
    Ladies circle 4H to left _while_ Men circle 4H to left; 1L+4L and
    1M+4M drop hands bar 12 to form circle of 8.
13-16::
    Circle 8H round to original places (2 bars), 1s+4s drop hands with
    partners, set on sides, joining hands on 1st bar, turning on 2nd bar
    to finish 1s+2s facing up, 3s+4s facing down
17-24::
    1s+2s dance double Fig of 8 (2s cross, 1s casting to begin) _while_
    3s+4s dance similar (3s cross, 4s casting) 1s finish in top place
25-32::
    1s cast behind 2s, dance in front of 3s, behind 4s and turn RH.
    (2s+3s+4s step up 29-30) Finish 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13415, '2020-12-02 01:20:32.297583+00', '2023-02-04 01:20:59.320082+00', 17800, 3, NULL, 'ace', '1-8::
    1s cast behind own lines, turn towards each other & dance up to
    place
9-16::
    1s cross down to dance mirror reels of 3 on opp sides
17-24::
    1s cross down to dance mirror reels of 3 on own side
25-32::
    1s followed by 2s+3s+4s cast behind own lines, 1s make arch & other
    couples dance up under arch. 2 3 4 1
33-40::
    2s+3s & 4s+1s dance RH across & LH across', 0);
INSERT INTO 'dancecrib' VALUES (8337, '2014-07-29 12:59:12.604265+00', '2023-02-04 01:20:59.350786+00', 15036, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels of 3 on own sides (1s in & down to start, all
    giving hands where possible)
9-16::
    1M dances across & down behind 2L (2L steps up bars11-12) while1L
    dances down & casts up round 2M. 1s+2s set diagonally & dance 1/2
    RHA
17-24::
    1M dances diagonally down thru 2cpl place & casts up to 1st place on
    opp side (2M steps down)  _while_ 1L crosses & casts up to 1st man''s
    place. 1s+2s set diagonally & dance 1/2 RHA
25-32::
    1s dance up between 2s and cast to 2nd place. 1M+3M turn RH as 1L+3L
    turn LH', 0);
INSERT INTO 'dancecrib' VALUES (6126, '2013-08-21 08:31:19.192198+00', '2023-02-04 01:20:59.371905+00', 11835, 3, NULL, 'ace', '1-8::
    1s set, turn LH & cast 1 place
9-16::
    1s cross LH, cast to left, cross LH (up/down) & cast left to 2nd
    places opposite sides
17-24::
    1s dance reels of 3 across (LSh to 3rd corner to start)
25-32::
    1s dance reels of 3 on opposite sides (LSh to 1st corner to start) &
    cross LH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6128, '2013-08-21 08:31:19.210148+00', '2023-02-04 01:20:59.402235+00', 3767, 3, NULL, 'ace', '{{explanation}}
Round the Room 3 facing 3

1-8::
    All set & change places RH with opposite person to face next trio,
    all dance DoSiDo with opposite person
9-16::
    1M+2M set & petronella turn, set & turn RH to face 1st corner
17-24::
    1M+2M turn 1st corners LH & turn RH to face 2nd corner, turn 2nd
    corner LH & turn RH to end between own partners (facing out)
25-32::
    1M & 2M dance RSh reels of 3 with partners', 0);
INSERT INTO 'dancecrib' VALUES (13416, '2020-12-02 01:20:32.40294+00', '2023-02-04 01:20:59.433418+00', 19931, 3, NULL, 'ace', '{{explanation}}
The single couple starts in 2nd place with no progression, chairs representing 1s+3s do not move

1-8::
    Man crosses up & Lady down to dance Fig of 8 across (1 M round 2s st
    top, 1L round 3s).  1s finish passing LSh to face 1st corner
9-16::
    ''Hello-Goodbye'' to end in centre, Man between 2s facing down & Lady
    between 3s facing up. 1s dance out to 2nd place opp side & face out
17-24::
    Lady casts down & Man casts up to dance Fig of 8 on opp sides
25-28::
    Lady casts down & Man casts up & chase 1/2 way round set to finish
    in 2nd place own side facing in
29-32::
    Dance round partner LSh (Gypsy turn) back to place', 0);
INSERT INTO 'dancecrib' VALUES (6127, '2013-08-21 08:31:19.201901+00', '2023-02-04 01:20:59.464342+00', 11438, 3, NULL, 'ace', '1-8::
    1s turn LH & cast 1 place, cross LH & cast left to both face 2L
9-16::
    1s set & turning inwards set to 3M & face 3L, set & turn inwards set
    to 2M end facing 1st corners
17-24::
    1s turn corners LH & partner RH to face 2nd corners, turn corner LH
    & partner RH to 2nd places own sides
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6129, '2013-08-21 08:31:19.220125+00', '2023-02-04 01:20:59.582164+00', 3769, 3, NULL, 'ace', '1-8::
    1L+2L+3L circle 3H round & back
9-16::
    1M+2M+3M circle 3H round & back
17-24::
    1s lead down the middle & back ending 1L between 2s & 1M between 3s
25-32::
    1s set twice & turn RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4075, '2013-08-21 08:30:43.164978+00', '2023-02-04 01:18:32.302794+00', 246, 3, NULL, 'ace', '1-8::
    All dance RSh reels of 4 on sides
9-16::
    1s cast behind 2s, in front of 3s, behind 4s to bottom & turn RH
17-24::
    1s+4s dance LH across 1/2 way, 1s+3s dance RH across 1/2 way, 1s+2s
    LH across 1/2 way & all 1/2 turn partners RH
25-32::
    1s+2s pass setting, 1s+3s pass setting _while_ 2s turn RH to own
    sides, 1s+4s pass setting _while_ 3s turn RH, 1s & 4s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (13256, '2020-10-16 00:20:44.202369+00', '2023-02-04 01:20:59.604852+00', 3770, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & cross RH; all set & 1/2 turn partner RH to face up in
    prom hold
9-16::
    1s+2s+3s Promenade
17-24::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s
25-32::
    1s+3s dance R&L.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6130, '2013-08-21 08:31:19.237454+00', '2023-02-04 01:20:59.775279+00', 10564, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set+Link, 1s & 3s dance 1/2 Figs of 8 around couple
    above
9-16::
    2s+1s also 4s+3s dance Ladies Chains
17-24::
    All dance LSh reels of 4 on sides
25-32::
    1s+3s turn partners RH & chase clockwise 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (14911, '2022-06-27 00:20:40.179584+00', '2023-02-04 01:20:59.824237+00', 20879, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 on own sides (dancing in & down to start)
9-16::
    1s+2s »Set&Stroll'':
::
    _9-12_   1s & 2s set. 1L+2M cast pulling back RSh _while_ 1M+2L
    dance to partner''s places
::
    _13-16_  2M+1L dance round each other by the right, 1M+2L chase
    clockwise 1/2 way round  2 1 3
17-20::
    All set, 2s & 3s Link as in Set+Link for 3 _while_ 1s Petronella
    turn to diagonally right. (1L+3s facing down & 1M+2s facing up)
21-24::
    All set, 2s & 3s Link as in Set+Link for 3 _while_ 1s Petronella
    turn to diagonally right. (3) (1) (2)
25-32::
    3s+1s+2s set in circle, dance into centre, pull RSh & dance out,
    chase clockwise half round to own sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6131, '2013-08-21 08:31:19.246095+00', '2023-02-04 01:20:59.856816+00', 3774, 3, NULL, 'ace', '1-8::
    1M+2L cross RH & cross back RH, turn to face each other & form an
    arch
9-16::
    1L dances under the arch & followed by her partner dances to the
    bottom (2L falls back to original place), 1s lead up to top
17-24::
    1s+2s Promenade
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (6132, '2013-08-21 08:31:19.256473+00', '2023-02-04 01:20:59.891748+00', 14430, 3, NULL, 'ace', '1-8::
    1s petronella turn into middle & set, 1s turn RH 1.1/2 times to end
    facing down (Man behind Lady) _while_ 2s+3s circle 4H round & back
9-16::
    1s dance alternating tandem reel of 3 with 2s (RSh to 2M to start) &
    end in middle facing down (2s in 1st place)
17-24::
    1s dance down between 3s & cast up on opposite sides, 2s+1s+3s
    Adv+Ret
25-32::
    1M+2s also 1L+3s dance RH across, 1s turn LH 1.1/2 times to own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (6133, '2013-08-21 08:31:19.275794+00', '2023-02-04 01:21:00.029353+00', 3775, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, 1s+3s dance RH across 1/2 way
9-16::
    1s set twice, 3s+1s dance 1/2 R&L (1s end facing 1st corners)
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s dance reels of 3 on opposite sides passing 1st corners LSh &
    cross to 2nd place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (6134, '2013-08-21 08:31:19.343835+00', '2023-02-04 01:21:00.166088+00', 3776, 3, NULL, 'ace', '1-8::
    1s set, cross RH, set & cast into middle facing 2s
9-16::
    2s+1s set, turn other partner (1s dancing out), 1s dance down
    between 3s & cast up into middle to face 3s
17-24::
    1s+3s set, turn other partner (1s dancing out), 1s dance up between
    2s & cast to 2nd place opposite sides
25-32::
    1s dance reels of 3 on sides (dancing down between 3s to start) &
    cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (14209, '2021-08-14 00:20:37.140717+00', '2023-02-04 01:21:00.181186+00', 12421, 3, NULL, 'ace', '1-4::
    1s+3s+5s set, 1s+5s turn partner 3/4 2H to form line in centre
    _while_ 3s turn 3/4 RH to finish back to back in the line (Men
    facing up, Ladies down, in order 1 3 5)
5-8::
    1s dance 1/2 RSh reel of 3 with 3L _while_ 5s dance RSh reel of 3
    with 3M
9-12::
    3s, now at the ends of the set, chase clockwise 1/2 round set to
    other end _while_ 1s+2s also 4s+5s dance 3/4 LH across (2s+4s now in
    the centre line with 3M at top+2s+4s+3L at bottom)
13-16::
    2s dance 1/2 LSh reel of 3 with 3M _while_ 4s dance 1/2 LSh reel of
    3 with 3L (3s finish in 3rd place on opposite sides, 2s & 4s in line
    in centre)
17-20::
    2s+4s set & Petronella turn to finish on opposite sides (2) (1) (3)
    (5) (4)
21-24::
    All set & cross RH to own sides
25-28::
    1s set to 3s & change places on sides (1M+3M RH, 1L+3L LH), 1s face
    out
29-32::
    1s cast 2 places to bottom of set _while_ 4s NHJ dance up to 3rd
    place, 4s & 1s set.  End 2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (9384, '2016-10-06 07:18:38.090529+00', '2023-02-04 01:21:00.216394+00', 17133, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up bars 3-4), 1s dance 1/2 Figs 8, 1L round
    2s, 1M round 3s
9-16::
    1s turn LH to face 1st corners & dance set to corners & partner
    (''Hello-Goodbye'') to end 1M between 2s facing down, 1L between 3s
    facing up
17-24::
    2s+1s+3s Set+Link, all set, all cross RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6135, '2013-08-21 08:31:19.352385+00', '2023-02-04 01:21:00.276122+00', 3778, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    1s turn 3s on sides (M-LH, L-RH), 2M+1M+3M dance RH across _while_
    Ladies dance LH across ending with 2s also 3s BtoB in centre facing
    own sides & 1s in 2nd place on side facing in
17-24::
    2s+1s+3s dance Inverted Double Triangles (all set & 2s & 3s dance
    around each to set on other side) ending all on own sides
25-32::
    2s+1s+3s circle 6H round to left turn left about & circle 6H back to
    right', 0);
INSERT INTO 'dancecrib' VALUES (6136, '2013-08-21 08:31:19.360852+00', '2023-02-04 01:21:00.29846+00', 12015, 3, NULL, 'ace', '1-8::
    All turn RH, all turn LH
9-24::
    All dance full reverse Schiehallion Reel (to left & Men follow
    Ladies).
25-40::
    All dance double reels of 4 giving LH in centre (ladies start with
    1/2 LH across in centre) except that on last 2 bars all 3/4 turn RH
    to face partner in opposite positions
41-48::
    All set HS to partner & dance 1/2 Grand Chain back to places
49-56::
    All set HS to partner & turn partner 2H
57-64::
    All circle 8H round & back
65-128::
    Repeat in Jig time but replace HS setting with normal PdB & turn RH
    in bars 53-56', 0);
INSERT INTO 'dancecrib' VALUES (6137, '2013-08-21 08:31:19.369188+00', '2023-02-04 01:21:00.328395+00', 12301, 3, NULL, 'ace', '1-8::
    All dance 8H round & back
9-16::
    Ladies dance Fig of 8 round corner & partner
17-24::
    Men dance Fig of 8 round corner & partner
25-32::
    All dance interlocking reels of 4
33-40::
    All Ladies dance RH across 1/2 way, dance round opp Man LSh & dance
    RH across 1/2 way & pass partner LSh back to places
41-48::
    All Men dance LH across 1/2 way, dance round opp Lady RSh & dance LH
    across 1/2 way & pass partner RSh back to places
49-56::
    All dance Grand Chain
57-64::
    All Promenade round', 0);
INSERT INTO 'dancecrib' VALUES (15085, '2022-09-05 00:22:25.555491+00', '2023-02-04 01:23:08.627066+00', 14788, 3, NULL, 'ace', '{{explanation}}
Round the Room dance 2 facing 2

1-4::
    All turn opposite person RH
5-8::
    All dance RH across
9-16::
    All dance 4H round & back
17-20::
    All dance DoSiDo with opposite person
21-24::
    All set & cross RH
25-28::
    All Adv+Ret
29-32::
    All Advance again, turn towards partner (turning back on other
    couple) take inside hands & dance forward (in direction originally
    facing) to meet next couple', 0);
INSERT INTO 'dancecrib' VALUES (3988, '2013-08-21 08:30:40.912653+00', '2023-02-04 01:18:25.810095+00', 123, 3, NULL, 'ace', '1-8::
    All set, cross RH, set & cross back RH
9-16::
    1s+2s also 3s+4s dance Diamond Poussette
17-24::
    1s+2s also 3s+4s dance double Fig of 8 (2s & 4s cross up to start)
25-32::
    All dance 1/2 reflection reel of 4 on sides (1s & 3s out & down to
    start), 4s+3s+2s continue & dance 1/2 reel of 3 _while_ 1s turn 2H
    to end 4th pl', 0);
INSERT INTO 'dancecrib' VALUES (4076, '2013-08-21 08:30:43.173051+00', '2023-02-04 01:18:32.33397+00', 9453, 3, NULL, 'ace', '1-8::
    1M & 3L set, change places RH & cast to 2nd place (2s step up/down)
    & turn partners RH on sides
9-16::
    1s+2s+3s dance reels of 3 on sides (1M & 3L start LSh to 2s)
17-24::
    1M+3L dance 1/2 Diag R&L (1M dn & 3L up) & chase cl''wise 2 steps &
    face ptnr in middle (order 1 2 3), 1s+2s 1/2 turn ptnr 2H _while_ 3s
    cross RH
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13999, '2021-05-03 00:20:25.903746+00', '2023-02-04 01:21:00.354126+00', 3781, 3, NULL, 'ace', '1-8::
    1s+2s set advancing to face up NHJ, 1s cast & dance 1/2 Fig 8 up
    round 1st place to end in 2nd place opp sides _while_ 2s follow
    ending in 1st place opp sides.  (2) (1) 3
9-16::
    1s+3s repeat bars 1-8.  End (2) (3) 1
17-20::
    1s+3s circle 4H 1/2 round to left, 1M+3L also 1L+3M turn 2H once
    round.  (2) (1) 3
21-24::
    1s+2s circle 4H 1/2 round to left, 1s+2s turn partner 2H once round,
    finishing in original places but slightly in from sides
25-32::
    1s+2s set twice with 1L & 2M advancing on bars 27-28 to BtoB &
    facing partner on 1st corner diagonal line; 1s+2s dance 1/2
    Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6138, '2013-08-21 08:31:19.377502+00', '2023-02-04 01:21:00.365307+00', 3782, 3, NULL, 'ace', '1-8::
    1s & 3s set, cast down 1 place & dance 1/2 Fig of 8 round 2s/4s
9-16::
    2s+1s also 4s+3s dance R&L, 1s/3s end facing 1st corners
17-24::
    1s & 3s dance ''Hello-Goodbye'' setting & end turning partner RH into
    Allemande hold with 4s/5s behind them
25-32::
    1s+4s also 3s+5s dance Allemande (2 Cpl) to end 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (14533, '2022-01-10 02:19:54.269432+00', '2023-02-04 01:21:00.375458+00', 17968, 3, NULL, 'ace', '1-8::
    1s+2s dance the »Poppy«:
::
    _1-2_  1s+2s dance in (1 bar), pull back RSh & dance out to place (1
    bar)
::
    _3-6_  1s+2s chase 2 place clockwise curving into place
::
    _7-8_  2s+1s dance 1/2 RH across back to original places
9-16::
    1s+2s set, 1s cast & 2s dance up to top; 1s+3s dance LH across
17-24::
    2s+1s+3s dance 3 couple Knot. 3 1 2
25-32::
    3s+1s+2s chase 1/2 round anticlockwise; all pass partner LSh to own
    side & all set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11741, '2019-03-26 02:05:52.50129+00', '2021-02-19 19:35:28.56396+00', 19247, 3, NULL, 'ace', '1-8::

    1s+2s set, dance 1/2 RH across; set & dance 1/2 LH across

9-16::

    1s+2s dance the Bourrel

17-24::

    2s+1s+3s dance RSh reels of 3 on own sides (1L+3L & 1M+2M pass RSh

    to start)

25-32::

    1s+3s dance Espagnole.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6139, '2013-08-21 08:31:19.385822+00', '2023-02-04 01:21:00.385326+00', 3783, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+2s & 3s+4s dance 1/2 R&L, 1s+4s dance 1/2 R&L
17-24::
    All dance reels of 4 on sides
25-32::
    4s+1s cross (L under M arch), 2s+4s & 1s+3s turn 1.1/4 times on side
    (4s+1s turning out) to form lines of 4 across (all Men at one end) &
    all set
33-40::
    Men dance RH across as Ladies dance LH across & all change places
    with partner (3s start) to dance Men LH across & Ladies RH across
41-48::
    3s followed by 1s+4s+2s dance up to top & cast to finish 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14120, '2021-07-07 00:20:09.34173+00', '2023-02-04 01:21:00.397109+00', 3784, 3, NULL, 'ace', '1-4::
    1s & 3s set advancing, turn partner 2H, 1s face down & 3s face up
    NHJ
5-12::
    1s+2s+3s dance reels of 3 on sides (1s in/down, 2s out up to start)
13-16::
    1s & 3s turn partner 2H twice round, 1s face out
17-24::
    1s+3s dance double Fig 8 round 2s, 1s cast & 3s cross up to start
25-32::
    1L+2M set advancing, turn 2H, finishing BtoB facing partner; 1s+2s
    dance 1/2 Poussette.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13308, '2020-11-02 01:20:37.549848+00', '2023-02-04 01:21:00.408124+00', 20095, 3, NULL, 'ace', '1-8::
    1s+4s facing in diagonally Adv+Ret, 1s+4s cast in & set (2s & 3s
    step out to ends bars 5-6).  2 1 4 3
9-16::
    2s+3s facing in diagonally Adv+Ret, 2s+3s cast in (1s+4s step out
    bars 13-14);  All 4 couples set.  1 2 3 4
17-24::
    1s+4s cross RSh, cast in 1 place (2s+3s step out bars 19-20), 1s
    dance 1/2 Fig of 8 round end couples, 1s+4s end passing LSh to end
    BtoB on sides facing up/down.  2 1 4 3
25-32::
    All dance reels of 4 on sides
33-40::
    4s+1s+3s dance Set+Link (no hands), 3s+1s+4s set (no hands), 1s
    dance petronella turn to 3rd place own sides 2 3 1 4
41-48::
    1s & 4s dance the Espagnole (no hands):
::
    _41- 42_   1s+4s cross (Ladies lead across, no hands, passing
    between Men) with Ladies changing places no hands
::
    _43- 44_   1s+4s cross back (Men lead across, no hands, between
    Ladies) with Men changing places no hands
::
    _45- 48_   4s dance round each other RSh _while_ 1s dance round each
    other LSh 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12866, '2020-06-03 16:26:50.036891+00', '2023-02-04 01:21:00.426517+00', 18446, 3, NULL, 'ace', '1-8::
    1s cast (2s step up) & set, 1s turn RH to end on 1st corner
    diagonal, 1M facing 2M with partner following
9-16::
    1s dance alternating RSh tandem reel of 3 with 1st corners.  End 1s
    on 2nd corner diagonal, 1M facing 3M, 1L facing 2L
17-24::
    1s dance RSh diag reel of 4 with 2nd corners.  1s pass LSh to end 1M
    facing down, 1L up (2nd corners curve into place)
25-32::
    1L+2s also 1M+3s dance reels of 3 across (1L+2M & 1M+3L pass LSh to
    start).  1s curve round to finish BtoB, 1M facing 3M, 1L facing 2L
    (second corner diagonal)
33-40::
    1s dance 6 bars ''Hello-Goodbye'' setting finishing in 2nd place opp
    side, 1s cross RH to own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6140, '2013-08-21 08:31:19.396029+00', '2023-02-04 01:21:00.445339+00', 11637, 3, NULL, 'ace', '1-4::
    1s+2s also 3s+4s dance LH across 1/2 way, 1s+4s dance RH across 1/2
    way.  (2) 4 1 (3)
5-12::
    All circle 8H round & back
13-16::
    4s+1s dance LH across 1/2 way, 1s cast up behind 2s _while_ 4s cast
    down behind 3s
17-24::
    All petronella into centre & set, petronella on to own sides & set.
    1 2 3 4
25-32::
    1s+2s also 3s+4s dance Tournee :
::
    1s+2s also 3s+4s dance into prom hold (Men with prtnr on right,
    1s/3s face M''s side & 2s/4s L''s side), couples 1/2 wheel anticl''wise
    & Men turn Ladies into middle, both couples turn 1.1/2 times (2s/4s
    RH, 1s/3s LH) & dance out to places
33-40::
    1s+4s dance the Knot.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3989, '2013-08-21 08:30:40.922557+00', '2023-02-04 01:18:25.840671+00', 10532, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L.  2s+1s set, cross RH
9-16::
    1s dance up between 2s, cast to 2nd place, meet, dance down & cast
    up round 3s to 2nd place own side
17-20::
    1s+1st corners »Allemande Right«:  1s advance 2 steps, give RH to
    corner, Lady turns Right about under Man''s arm & dances out to place
    as Man retire
21-24::
    1s+2nd corners »Allemande Left«: as bars 17-20 but giving LH and
    Lady turns Left about under Men''s arm
25-32::
    RH across, 1L+2s & 1M+3s.  2s+1s+3s turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (6141, '2013-08-21 08:31:19.404379+00', '2023-02-04 01:21:00.594972+00', 12302, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s dance 1/2 Fig of 8 round 2s/3s, dance down/up to pass other
    dancer RSh & turn right about to face them
9-16::
    4s+1s circle left, set turning to face corner & change places RH
    with corner & end facing them
17-24::
    All dance double diagonal reels of 4 giving LH in centre
25-32::
    2M followed by partner dance Fig of 8 round 4s (RSh to 4M) _while_
    3M followed by partner dance Fig of 8 round 1s (RSh to 1M) with 2s
    ending between 4s, 3s between 1s
33-40::
    All circle 8H round & back to end 2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (13417, '2020-12-02 01:20:33.251161+00', '2023-02-04 01:21:00.623323+00', 19159, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set+Link; 2s & 3s (end couples) chase clockwise 1/2
    round _while_ 1s+4s set & dance 1/2 LH across. (3) (4) (1) (2)
9-16::
    Reels of 4 on sides
17-24::
    3s+4s also 1s+2s set & dance 1/2 RH across; all 4 couples turn
    partner RH
25-26::
    4s & 1s (end couples) set _while_ 3s+2s cross RH
27-30::
    4s NHJ dance down below 4th place _while_ 1s cast up to top _while_
    3s+2s change places LH on sides & cross RH with partner
31-32::
    1s+2s+3s (top couples) set advancing to face up NHJ with partner
    _while_ 4s dance up to 4th place
33-40::
    2s+3s+4s make arches & dance up 1 place _while_ 1s dance down under
    arches to 4th place; all 4 couples Adv+Ret
41-48::
    2s+3s+4s+1s circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6142, '2013-08-21 08:31:19.4128+00', '2023-02-04 01:21:00.65839+00', 7310, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s+3s on own sides (between 2s to start)
9-16::
    1s set advg _while_ 2s+3s set, 1s Slip Step (RH joined) down to 3rd
    place _while_ 2s+3s cast up 1 place, 2s+3s dance 1/2 R&L _while_ 1s
    turn RH
17-24::
    3s set advg _while_ 2s+1s set, 3s Slip Step (RH joined) down to 3rd
    place _while_ 2s+1s cast up 1 place, 2s+1s dance RH across _while_
    3s turn RH
25-32::
    1s cross down & cast up to 2nd place opp side _while_ 3s set & cross
    RH, 1s cross up & cast to 2nd place _while_ 2s set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (9385, '2016-10-06 07:18:38.160776+00', '2023-02-04 01:21:00.690612+00', 14224, 3, NULL, 'ace', '1-8::
    1s dance Figs 8 on sides, dancing in/down to start
9-16::
    1s cross RH, cast (2s step up), &1s dance 1/2 Fig 8 round 3s
17-24::
    2s+1s+3s set, cross RH, Men face down, Ladies face up & all chase
    clockwise 1/2 round set
25-32::
    1L+3s & 1M+2s dance RH across flowing into ''Snake Pass'' 1M followed
    by 2s &1L followed by 3s pass LSh diagonally across to change ends &
    loop round to left to end in 2nd place own sides. End  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13180, '2020-09-15 00:20:29.172331+00', '2023-02-04 01:21:00.732452+00', 20056, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 2nd place (2s step up); 1s dance 1/2 Fig (1L
    up round 2s, 1M down round 3s) to 2nd place opp sides. 2 (1) 3
9-16::
    2s+1s+3s dance reels of 3 on sides, RSh to 2nd corner (1M up, 1L
    down)
17-24::
    2s+1s+3s dance DoSiDo; all chase 1/2 round clockwise. (3) 1 (2)
25-32::
    1s dance petronella turn & set, twice to end 2nd place opp side.
    (3) (1) (2)

{{explanation}}
2nd time through: 1s start from 2nd place opp sides, end 3rd place own side & slip to bottom.  
Starting positions 1st time:  1 2 3 4;  3rd time (3) (4) 1 2;  5th time (2) (1) (3) (4);  7th time  4 3 (2) (1)', 0);
INSERT INTO 'dancecrib' VALUES (6143, '2013-08-21 08:31:19.421111+00', '2023-02-04 01:21:00.754822+00', 3786, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH & cast in 1 place, 1s+4s dance LH across (1s+4s end
    BtoB in centre facing corners)
9-16::
    All set & change places RH with corners, set & change back with LH
17-24::
    1s+4s dance RH across & LH back _while_ 2s+3s chase all the way
    round anticlockwise
25-32::
    All set & 1s+4s 1/2 turn partner RH, 1M+4L chase clockwise 1/2 way
    as 1L+4M 1/2 turn LH, 4s+1s cross RH to 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6144, '2013-08-21 08:31:19.429522+00', '2023-02-04 01:21:00.778485+00', 3788, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Figs of 8 round 2s, 1s set to 2s on sides & 1s+2s set
    facing diagonally
9-16::
    1s in prom hold dance reel of 3 with 2s giving RSh to 2M
17-24::
    1s+2s set & turn 2H ending in middle 1s facing down & 2s up, 1s+2s
    Adv+Ret 1 step (up/down set) twice
25-32::
    1s+2s set & turn 2H into a line up/down centre with Men holding LH,
    couples dance anticlockwise round each other & turn to new places', 0);
INSERT INTO 'dancecrib' VALUES (6145, '2013-08-21 08:31:19.538984+00', '2023-02-04 01:21:01.072818+00', 3789, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance full R&L
9-16::
    1s followed by 2s+3s+4s lead down centre, cross & dance up opposite
    sides
17-24::
    All set, 1s+3s cast 1 place _while_ 2s+4s dance up, all set, 2s+1s &
    4s+3s dance 1/2 RH across back to places
25-32::
    1s cross RH, cast to 2nd place, cross LH & cast to 3rd place
33-40::
    1s cross RH, cast to 4th place & turn partner 2H 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (12867, '2020-06-03 16:26:50.356451+00', '2023-02-04 01:21:01.092276+00', 3792, 3, NULL, 'ace', '1-8::
    1L also 4M followed by partners cast in 1 place & cross to opposite
    side (2s & 3s step down/up 3-4); 1L+4M stay facing out. 1s+4s dance
    LH across
9-12::
    2s+1s also 4s+3s dance RH across to finish on side, 2s+4s facing
    down, 1s+3s facing up 2 (1) (4) 3
13-16::
    2s set to 1s also 4s set to 3s on sides, change places RH to finish
    1s+3s facing down, 2s+4s facing up
17-24::
    Reels of 4 on sides (1) 2 3 (4)
25-28::
    All set, 1s+2s also 3s+4s dance 1/2 RH across to finish in centre,
    1s+4s retain RH hold _while_ 2s/3s face Ladies''/Men''s side
29-32::
    2M also 3L followed by partners cast down/up to 4th & 1st places &
    cross to own sides _while_ 1s+4s turn RH to own sides ending 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (6146, '2013-08-21 08:31:19.547704+00', '2023-02-04 01:21:01.119006+00', 8518, 3, NULL, 'ace', '1-8::
    1s+3s set & dance La Baratte :
::
    Men 1/2 turn Lady RH & retains hand but at arm''s length from each
    other
::
    Men retrace steps with Lady turning right under Man''s arm briefly
    into Allemande hold (Man behind Lady facing Ladies original place) &
    releasing Ladies RH she turns under Mans left arm until almost in
    original places
::
    Couples change places LH to opposite places
::
    _while_ 2s+4s cast pass opposite person RSh & set to partner then
    set across the set - All are now opposite where they started on
    wrong side of prtnr
9-16::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L
17-24::
    All dance interlocking reels of 3 (pass crnrs RSh, about turn, pass
    crnr RSh, pass partner LSh, about turn & pass partner LSh) & end
    facing in
25-32::
    All 3/4 turn partners RH to end in prom hold facing anticlockwise &
    Promenade 3/4 way round to end 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (15340, '2022-12-19 01:20:41.594475+00', '2023-02-04 01:21:01.172967+00', 21181, 3, NULL, 'ace', '1-8::
    1s+2s DoSiDo; 1s+2s set and dance 1/2 RH across (2) (1) 3
9-16::
    1s+3s DoSiDo; 1s+3s set and dance 1/2 RH across (2) (3) 1
17-20::
    1s cross RH, cast up 1 place (3s step down). (2) (1) (3)
21-24::
    1L+2s & 1M+3s dance 1/2 RSh reel of 3 across. 2 1 3
25-32::
    2s+1s+3s dance Slip Knot (as for 3 cpl knot but on last 2 bars 1s+2s
    dance 1/2 LH across _while_ 3s 1/2 turn LH). 3 2 1
33-36::
    3s+2s+1s chase anticlockwise 1/2 round to (1) (2) (3).
37-38::
    1s+3s cross LH _while_ 2s 1/2 turn LH & face up (retain LH)
39-40::
    1s cast down 1 pl _while_ 2s lead up 1 place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12403, '2019-12-05 01:30:45.487592+00', '2023-02-04 01:21:01.229943+00', 11405, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across, 1s cast as 2s NHJ dance up to top
9-16::
    1s+3s dance Double Fig 8 (1s cross down, 3s dance up to start). 1s
    end just outside lines in 2nd place facing up
17-24::
    2L+1L+3L dance LH across as 2M+1M+3M dance RH across; Bar 20: 1s
    cross down and dance up opp sides, 3s then 2s cross and follow, 1s
    cast to 2nd place, 3s dance up to 1st place facing out.  (3)(1)(2)
25-32::
    3s+1s+2s dance 1/2 RSh reels of 3 across (1L up with 3s, RSh to 2M,
    1M down with 2s, RSh to 2L)
::
    3s+1s+2s dance 1/2 LSh reels of 3 on own side (1M in/up, 1L
    in/down). 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9013, '2015-11-30 08:59:58.301964+00', '2023-02-04 01:21:01.258573+00', 16727, 3, NULL, 'ace', '1-8::
    1s+4s dance Fig of 8 on sides, giving hands. 1s+4s start by dancing
    in down/up.
9-16::
    1s+2s set advancing, 1/2 turn 2H to face down. 2s+1s dance down and
    out behind 3s. 2s meet, lead up crossing to 1st place, _while_ 1s
    meet, dance up to face 3s.
17-20::
    1s+3s set advancing passing LSh. 1s cast right to finish in middle,
    1L between 2s facing down, 1M between 4s facing up, _while_ 3s turn
    3/4 RH to finish 3W facing up, 3M facing down.
21-24::
    1s+3s set advancing passing LSh, 3s cast right to finish in second
    place own side, _while_ 1s turn RH 3/4 to finish in middle facing
    down.
25-32::
    1s lead down below 4s, cross and cast to 3rd place. 1W+4W turn LH
    1.1/2 _while_ 1M+4M turn RH 1.1/2
33-40::
    2s+3s+4s+1s circle 8H round and back.', 0);
INSERT INTO 'dancecrib' VALUES (9014, '2015-11-30 08:59:58.310905+00', '2023-02-04 01:21:01.285408+00', 16534, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Rose Progression:
::
    _1- 2_     1M+2L set as 1L+2M change places RH
::
    _3- 4_     1M+2L 1/2 turn 2H as 1L & 2M dance into partners place
::
    _5- 6_     1M+2L cast into each other''s place as 1L+2M 1/2 turn 2H
::
    _7- 8_     1M & 2L dance into 2nd/1st places own side as 1L & 2M
    cast to right to new places  (3s+4s dance similarly)
9-16::
    All dance clockwise 1/2 way round set, all set. All 1/2 turn partner
    RH into allemande hold
17-24::
    3s+4s also 1s+2s dance 6 bars of allemande. All 1/2 turn LH to opp
    sides. (Men face up, Ladies down)
25-32::
    All dance anticlockwise 1/2 round set. 1s+2s also 3s+4s circle 4H
    round to Right  1 2 3 4
33-36::
    All 4 couples Set+Link with middle dancers linking 2 places; end
    dancers linking 1 place as follows:
::
    _33-34_ All set
::
    _35-36_ 1M dances down to 2nd place, 2M to 4th place, 3M casts up to
    1st place, 4M to 3rd place _while_ 1L casts to 2nd place, 2L to 4th
    place, 3L dances up to 1st place, 4L to 3rd place to end 3 1 4 2
37-40::
    3s+1s also 4s+2s circle 4H round to Left', 0);
INSERT INTO 'dancecrib' VALUES (13257, '2020-10-16 00:20:45.538207+00', '2023-02-04 01:21:01.497623+00', 16339, 3, NULL, 'ace', '1-8::
    1s cross, cast (2s step up); 1s dance down between 3s & cast up to
    2nd place
9-16::
    1M+2s & 1L+3s dance reels of 3 across (1M+2M & 1L+3L pass LSh to
    start). 1s end 2nd place opp sides
17-20::
    2M+3M dance RSh round 2L back to place _while_ 2L+3L dance RSh round
    1M back to place
21-24::
    1s dance RSh round partner back to place _while_ 2s+3s chase
    clockwise 1/2 round.  (3) (1) (2)
25-32::
    2s+3s dance path of Set+Link to change ends _while_ 1s cross RH,
    cast to right, cross RH up/down & cast to right to 2nd place own
    side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6148, '2013-08-21 08:31:19.566325+00', '2023-02-04 01:21:01.525351+00', 3797, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-4::
    All set, 1s & 4s cross down/up _while_ 2s & 3s cast to ends
5-6::
    2L+1M & 4M+3L change places LH _while_ 2M+1L & 4L+3M change places
    RH on sides.  (1)2 3(4)
7-8::
    1s & 4s cross down/up to position between 2nd & 3rd places - Men
    BtoB facing other Lady (4L on Mens side) _while_ 2s & 3s dance
    up/down to ends
9-12::
    1M & 4M dance out passing Ladies RSh, face in & set _while_ Ladies
    dance in & passing each other LSh petronella turn to face each other
    (1L facing up & 4L facing down) & set moving to right to face own
    partner
13-16::
    Repeat bars 9-12 with Men setting in centre & end facing other
    partner
17-24::
    Men turn other partner 2H 1.3/4 times onto sides (4s in 2nd pl & 1s
    in 3rd place), 4s+1s dance 4H round to left
25-28::
    All set, turn partners 2H to end in centre (top 2 couples face down
    & bottom 2 couples face up)
29-32::
    4M+1L also 4L+1M dance out sides, cast to ends, 4M+2M also 3M+1M
    change places RH on sides _while_ partners change places LH.  2
    4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (6149, '2013-08-21 08:31:19.574693+00', '2023-02-04 01:21:01.551308+00', 7790, 3, NULL, 'ace', '1-8::
    1s lead down & back to top
9-16::
    1s cross RH, cast to 2nd place, cross LH, cast below 3s & lead up to
    2nd place
17-24::
    1s (prom hold) dance 1/2 reel of 3 with 2L+3L (LSh to 2L to start) &
    dance 1/2 reel of 3 with 2M+3M (LSh to 3M to start), 1s end in 2nd
    places
25-32::
    3s+1s+2s dance the Knot & 1s end facing 1st corners
33-40::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partner LH to
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6151, '2013-08-21 08:31:19.595066+00', '2023-02-04 01:21:01.611361+00', 3799, 3, NULL, 'ace', '1-8::
    All cross passing partner RSh & set (arms folded), repeat back to
    place
9-16::
    1s dancing down change places with 2s RH, change places with 3s LH,
    change places with 4s RH & all set (arms folded)
17-20::
    4s+1s dance RH across
21-24::
    1s dance to top & face down _while_ 2s+3s+4s stand 2 bars then bars
    23-24 dance down 1 place, curve in to join NH with partner, all
    facing up in middle
25-32::
    1s progress to 4th place:
::
    _25-30_   1s dance under arch made by 2s, 1s make arch for 3s who
    dance up, 1s dance under arch made by 4s (2s+3s+4s in turn dance up
    1 place, 2 skip change)
::
    _31-32_   All set (arms folded) 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6152, '2013-08-21 08:31:19.606983+00', '2023-02-04 01:21:01.645513+00', 3800, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across (3 bars) & LH across (3 bars), 1s &
    3s cast down 1 place & others move up
9-16::
    1s & 4s dance Poussette
17-24::
    2s+4s also 1s+3s 1/2 R&L, set & cross RH.  4 2 3 1
25-32::
    2s+3s circle 4H round & back
33-40::
    4s set & cast _while_ 1s set & cast up, all turn RH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14581, '2022-02-05 02:20:26.806444+00', '2023-02-04 01:21:01.680524+00', 20613, 3, NULL, 'ace', '1-8::
    1s+2s+3s Advance setting, join hands in circle; all set again &
    circle 6H all way round to left (4 bars), remaining in centre in
    circle
9-16::
    All set, pull back RSh & cast back to original places,  Men facing
    up, Ladies facing down; all chase clockwise 1/2 round. (3) (2) (1)
17-24::
    1s+2s dance 1/2 R&L; all turn partner RH, 3s turning 1.1/2 times &
    all 3 couples remain in centre facing up ready for …
25-32::
    3s+1s+2s dance Allemande.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8601, '2015-02-13 12:47:57.756161+00', '2023-02-04 01:21:01.713296+00', 15932, 3, NULL, 'ace', '1-8::
    1s cross down RH into Double Triangle position with 2s+3s & set, 1s
    cast to top & dance down until they are between 2s & 3s
9-16::
    1s dance reflection reels on opposite sides (dancing down between 3s
    to start) & end in 2nd place opposite sides
17-24::
    1s dance 1/2 Fig of 8 round 2s, 1s dance down between 3s & cast up
    to 2nd place own sides
25-32::
    1s dance RH across (1L with 2s, 1M with 3s),& 1s dance LH across
    with other couple', 0);
INSERT INTO 'dancecrib' VALUES (6153, '2013-08-21 08:31:19.726862+00', '2023-02-04 01:21:01.739734+00', 3802, 3, NULL, 'ace', '1-8::
    1s set & cast to 3rd place (2s+3s step up 3-4); 1s set & cast back
    to top (2s+3s step down 7-8)
9-16::
    1s lead down the middle & back
17-24::
    1s+2s dance Allemande (1s end facing 1st corners)
25-32::
    1s turn 1st corners RH, partner LH, 2nd corner RH, partner LH to end
    in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (11457, '2019-01-01 01:57:11.786762+00', '2023-02-04 01:21:01.764354+00', 18612, 3, NULL, 'ace', '1-8::
    1s+3s dance double Fig 8 round 2s (1s cross down, 3s cast up to
    start)
9-16::
    1L followed by 1M dance down middle, dance RSh round each other & 1M
    leading dance up to 2nd place opp sides (2s step up 5-6).  2 (1) 3
17-24::
    Mirror reels of 3 on sides (1s out/up, 2s in/down, 3s in/up)
25-32::
    Corner Pass + Gypsy Turn
::
    As Corner Pass+Turn but corners dance RSh found each other instead
    of 2H turn', 0);
INSERT INTO 'dancecrib' VALUES (8602, '2015-02-13 12:47:57.772753+00', '2023-02-04 01:21:01.791736+00', 15586, 3, NULL, 'ace', '{{explanation}}
Square set - 5s in centre facing 1s

1-8::
    5s dance reflection reels of 3 with 1s+3s (dancing between 1s to
    start)
9-12::
    5L dances RH across with 2s as 5M dances LH across with 4s
13-16::
    5L followed by 2M+2L loops round to 4th place as 5M followed by
    4L+4M loop round to 2nd place (5M dancing behind 5L etc) into 5L
    dancing LH across with 2s as 5M dances RH across with 4s (5s end in
    middle)
17-24::
    5L followed by 2M+2L also 5M followed by 4L+4M dance up between 1s,
    cross & cast, 2s & 4s to places, 5s into middle where they turn RH
    once round to face up
25-32::
    All take ptnrs in prom hold, 5s change pl with 1s passing RSh, 1s
    pass 4s RSh, 4s pass 3s RSh, 3s pass 2s RSh & 2s end in centre
    facing up', 0);
INSERT INTO 'dancecrib' VALUES (10526, '2018-03-20 06:26:53.759477+00', '2023-02-04 01:21:01.817315+00', 17443, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance R&L
9-16::
    1s & 3s cross RH, cast 1 place (2s & 4s step up); 1s dance 1/2 Fig 8
    round 2s, 3s dance 1/2 Fig 8 round 4s
17-24::
    2s+1s also 4s+3s dance Strathspey Poussette ("all-round" poussette)
    2 1 4 3
25-32::
    _25-26_   1s cast to 4th place (4s+3s step up)
::
    _27-28_   4s+3s change places RH _while_ 2s+1s Adv+Ret (1 step each)
::
    _29-32_   All turn partners 2H  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6154, '2013-08-21 08:31:19.7655+00', '2023-02-04 01:21:01.847084+00', 3803, 3, NULL, 'ace', '1-8::
    1s cast down behind own sides & back to places
9-16::
    1s dance reels of 3 on sides (in & down to start)
17-24::
    1s lead down for 2 bars, set, lead up & cast to 2nd place
25-32::
    2s+1s+3s Adv+Ret 1 step, dance DoSiDo round partner & turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (6155, '2013-08-21 08:31:19.774801+00', '2023-02-04 01:21:01.880002+00', 8170, 3, NULL, 'ace', '1-8::
    All Men cast behind partner into centre & dance LH across then pass
    partner RSh to places
9-16::
    All Ladies repeat but dance RH across & pass partner LSh
17-24::
    1s+3s dance 1/2 Ladies'' Chain , 2s+4s dance 1/2 Ladies'' Chain
25-32::
    All turn corners RH 1.1/2 times, all turn partner LH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (12731, '2020-04-11 10:52:02.041196+00', '2023-02-04 01:21:01.915877+00', 9653, 3, NULL, 'ace', '1-8::
    1s dance in & cast (2s do not step up), 1s pass LSh & 1s+2s dance
    1/2 RSh reel of 4 (2s dance to Left to start). 1s finish NHJ facing
    down on opposite side between 2s
9-16::
    1s dance down, cast up round 3s. 1s pass LSh & 1s+3s dance 1/2 RSh
    reel of 4 (3s dance Left to start) 1s finish NHJ facing up between
    3s
17-24::
    1M+2L+3L dance LH across _while_ 1L+2M+3M dance RH across. Starting
    bar 21, all cross in order 1L, 1M, 3M, 3L, 2M, 2L, to join other
    hands across
25-32::
    1s followed by 3s+2s dance up & cast (1s to 3rd place, 3s to 2nd
    place, 2s to 1st place); 1s+3s turn 1.1/2 on sides (Men LH, Ladies
    RH), finishing with polite turns.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9386, '2016-10-06 07:18:38.39337+00', '2023-02-04 01:21:01.934116+00', 17208, 3, NULL, 'ace', '1-8::
    1s set & turn RH moving down to 2nd place in middle, 1s set (still
    retaining hands) & cast RSh round 3rd corners into lines across
9-16::
    1s dance Diag R&L (up/down) dancing to left to start
17-24::
    1s turn RH 1.1/4 times & set retiring to opp sides, all chase
    clockwise 1/2 way.  2 1 3
25-32::
    1s 1/2 turn 2H into prom hold & dance down middle, 1s turn RH 2.1/2
    times ending 3rd places own sides', 0);
INSERT INTO 'dancecrib' VALUES (6156, '2013-08-21 08:31:19.804616+00', '2023-02-04 01:21:01.960369+00', 10173, 3, NULL, 'ace', '1-8::
    All 3/4 turn partner RH to Ladies in centre LH joined, all set (HS),
    3/4 turn partner RH to Men facing out & Ladies in
9-16::
    All dance 1/2 Schiehallion Reel (Men follow Ladies) ending Ladies on
    partners left.  3 4 1 2
17-24::
    Men dance round partners RSh, dance LH across in centre & turn
    partner RH into prom hold facing clockwise (Men on outside)
25-32::
    All Promenade once round
33-40::
    Ladies cast round partners, dance RH across & 1/2 turn partner LH
41-48::
    All advance for 2 steps & turning round to right dance out to next
    place clockwise (left) Repeat to original places
49-56::
    All circle 8H round & back
57-64::
    All 3/4 turn partner RH to Ladies in centre LH joined, all set (HS)
    & turn partner RH to places', 0);
INSERT INTO 'dancecrib' VALUES (6157, '2013-08-21 08:31:19.813428+00', '2023-02-04 01:21:01.98152+00', 3812, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

{{title}}
Figure 1

1-8::
    All set & cross RH, all set & cross back RH
9-16::
    1s+2s also 3s+4s dance 1/2 RH across, (2 bars)  all pull back LSh
    cast round clockwise back to same place (2 bars); 1s+2s also 3s+4s
    dance RH across.  2(1)4(3)
17-24::
    2s+1s also 4s+3s Set+Link twice
25-32::
    2s+1s also 4s+3s circle 4H round to left 1/2 way (2 bars), Men turn
    Lady on right 2H (2 bars); all circle 8H 1/2 round to left.  End
    4(3)2(1)

{{title}}
Figure 2

1-8::
    All set & cross RH, 4s face 3s & 2s face 1s on sides (no polite
    turns);  4s+3s & 2s+1s turn LH 1.1/2 times. Ladies face in, Men face
    out (4)3(2)1
9-16::
    3s+4s also 1s+2s dance Ladies'' Chain
17-24::
    All dance RSh reels of 4 on sides
25-32::
    All turn Men turn Lady on sides (on their left) LH into Allemande
    hold & promenade anticlockwise 1/2 way, 1/2 turn ''Allemande partner''
    under Man''s right arm to end (1)2(3)4

{{title}}
Figure 3

1-8::
    1L+2M also 3M+4L dance RH across, 1L+2M also 3M+4L dance across
    between partners & cast right to vacant places (keeping Lady on
    left)
9-16::
    Top 2 couples also bottom 2 couples dance R&L
17-24::
    1M+2L also 3L+4M repeat bars 1-8 but dancing LH across & casting
    left (4)3(2)1
25-32::
    4s+3s also 2s+1s dance 1/2 R&L, turn partner RH 1.1/2 times to end
    3(4)1(2)', 0);
INSERT INTO 'dancecrib' VALUES (10014, '2017-07-23 15:57:49.348699+00', '2023-02-04 01:18:26.035253+00', 15438, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cast as 2s, NHJ, dance up & cast into 1st place.  1s
    turn 1.1/2 LH to face 1st corners
9-10::
    1s+1st corners set
11-14::
    1s pull back RSh to dance 1/2 round each other, 1M passes 2M RSh, 1L
    passes 3L RSh into middle at top/bottom _while_ 2M+3L dance in, turn
    RH & dance out to places
15-16::
    1s turn RH to face 2nd corners
17-24::
    1s+2nd corners repeat 9-14.  Bars 23-24 1s cross RH into 2nd place
    opp sides facing out
25-32::
    1s dance RSh reels of 3 on opp sides (1s RSh to 1st corners).  Bars
    31-32 1L crosses up, 1M crosses down into 2nd place own sides as
    2s+3s finish reels', 0);
INSERT INTO 'dancecrib' VALUES (12732, '2020-04-11 10:52:02.291894+00', '2023-02-04 01:21:02.175929+00', 16473, 3, NULL, 'ace', '1-8::
    1M+2M Set+Link; 2M+1M+3M dance 1/2 LSh reel of 3 (1M+3M pass LSh)
    _while_ 1L+2L Set+Link
9-16::
    1M+2M Set+Link; 3M+2M+1M dance 1/2 LSh reel of 3 (2M+3M pass LSh)
    _while_ 2L+1L+3L dance LSh reel of 3 (1L+3L pass LSh). Now 1 2 3 on
    Men''s side, 2 1 3 on Ladies'' side
17-24::
    1M  followed by 1L casts behind 2M, crosses up, casts down round 2L
    & crosses to 2nd place own side.  2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6159, '2013-08-21 08:31:19.842489+00', '2023-02-04 01:21:02.256327+00', 10062, 3, NULL, 'ace', '1-8::
    1s+3s lead down for 2 turning RH to Bal-in-Line (1L+3M join LH),
    dance RSh round 1st crnr to face ptnr up/down as crnrs turn RH in
    middle
9-16::
    1s+3s dance reel of 4 up/down middle
17-24::
    1s & 3s passing partners LSh dance reels of 4 with 2nd corners & end
    passing LSh to BtoB in 2nd place facing opposite side
25-32::
    1s dance Double Triangles for 6 bars, 1L+4L also 3L+5L 1/2 turn RH
    _while_ 1M+4M also 3M+5M turn 1/2 LH to end 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (10628, '2018-04-16 21:42:09.30297+00', '2023-02-04 01:21:02.289777+00', 12095, 3, NULL, 'ace', '1-8::
    2s+3s dance RH across; 1s+2s also 3s+4s dance LH across
9-12::
    2s+3s dance RH across _while_ 1M followed by 1L cast to 4th place
    own side & 4L followed by 4M cast up to 1st place own side
13-16::
    4s+2s also 3s+1s dance 1/2 LH across; 4s+1s cross LH so all on opp
    sides.  Order (2)(4)(1)(3)
17-32::
    "The Lindisfarne Knot":
::
    1st place (2s) set, cross to 2nd place (no hands) facing out
::
    2nd place (4s) cast to 3rd place & cross down to 4th place (no
    hands) facing partner
::
    3rd place (1s) cross to 2nd place (no hands) & dance up to 1st place
::
    4th place (3s) set, cast up to 3rd place [only true casting is in
    2nd/4th place at start of figure - other times just dance up or down
    outside set]
::
    Repeat from new positions 3 more times to end 2 4 1 3

{{explanation}}
Alternative version bars 17-32

17-20::
    2s+4s & 1s+3s circle 4H round to Left (or 4s / 3s lead up between 2s
    / 1s & cast back to place)
21-24::
    2s & 1s dance 1/2 Fig of 8 down round couples below
25-32::
    All dance 8 bars of the "Lindisfarne Knot" figure', 0);
INSERT INTO 'dancecrib' VALUES (12923, '2020-07-01 00:20:22.957389+00', '2023-02-04 01:21:02.309536+00', 17595, 3, NULL, 'ace', '1-8::
    1s set, dance in & cast to 3rd place (2s step up 3-4), 1s dance up
    to 2nd place own sides
9-16::
    2s+1s+3s dance reels of 3 on opp sides, each couple crosses from 1st
    place to opp sides
17-24::
    2s+1s+3s set, cross RH, Men face up, Ladies down & all chase
    clockwise - 2s & 3s chase 1/2 round to end with 3s at top _while_ 1s
    chase 1/4 round into centre to end BtoB 1M facing up, 1L facing down
25-32::
    1M+3s also 1L+2s circle 3H round to Left, 1M leads 3s down Ladies''
    side _while_ 1L leads 2s up Men''s side into circle 6H round to Left.
    All end on own sides & all set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6160, '2013-08-21 08:31:19.852771+00', '2023-02-04 01:21:02.328273+00', 9523, 3, NULL, 'ace', '1-8::
    1L+2L+3L Adv+Ret, 3L followed by 2L+1L cast down, cross below 3rd pl
    & dance up Men''s side _while_ 3 Men cross to partners place, face in
    & set
9-16::
    1M+2M+3M Adv+Ret, 1M followed by 2M+3M cast up, cross & dance down
    Men''s side _while_ 3 Ladies cross to own side, face in & set.  3 2 1
17-24::
    1s cross up to dance reels of 3 on opposite sides
25-32::
    1s cross up to dance reels of 3 on own sides
33-40::
    3s dance down between 2s+1s & cast up to 2nd place (2s step up), 1s
    dance up to top & cast to 2nd place (3s step down)', 0);
INSERT INTO 'dancecrib' VALUES (6161, '2013-08-21 08:31:19.861093+00', '2023-02-04 01:21:02.341929+00', 3828, 3, NULL, 'ace', '1-8::
    1s+2s dance the Knot (1s end facing out in 2nd place)
9-16::
    1L & 1M cast round dancer on their left (3M & 2L) & turn LH in
    middle, then cast around dancer on their left (3L & 2M)
17-24::
    1s turn 1st corners RH & pass RSh turn 2nd corners LH & pass LSh to
    end 2nd place opp sides facing out (corners dance for 4 bars & end
    in pl)
25-32::
    1s dance LSh Reels of 3 on opposite sides (1M LSh to 2L & 1L LSh to
    3M) & cross to own sides (1M up & 1L down)', 0);
INSERT INTO 'dancecrib' VALUES (6162, '2013-08-21 08:31:19.869403+00', '2023-02-04 01:21:02.368865+00', 13588, 3, NULL, 'ace', '1-8::
    1s & 2s Set+Link ending 2s facing 1s NHJ, 2s & 1s Set+Link with
    partners to opposite sides.  (2)(1)3
9-16::
    1s followed by 2s dance down for 3 bars & change places with Lady
    dancing under Mans arm, 2s+1s dance up to 1st & 2nd places
17-24::
    2M+1M turn LH as 2L+1L turn RH, 1M+3M turn RH as 1L+3L turn LH & 1s
    end facing 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting & petronella turn to 2nd place own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (12088, '2019-08-30 09:54:31.403505+00', '2023-02-04 01:21:02.396117+00', 19077, 3, NULL, 'ace', '1-8::
    1s set, petronella turn (2s step up); 1s+2s set to partner, 1s 3/4
    turn RH to end BtoB 1M facing 2L, 1L facing 2M
9-16::
    1s+2s dance 1/2 Celtic Reel:
::
    _9-12_    1s+2s pass RSh as for reel of 4, 1s dance clockwise 1/4
    way _while_ 2s dance 3/4 LSh round each other to face other partner
    (up/down)
::
    _13-16_  1s+2s pass RSh as for reel of 4, 2s dance clockwise 1/4 way
    _while_ 1s dance 3/4 LSh round each other to face other partner
    (across)
17-24::
    1s+2s set, 3/4 turn 1M+2L LH to end on Men''s side, 1L+2M RH to end
    on Ladies'' side.  2s+1s set & petronella in tandem
25-28::
    1s+2s circle 4H round to left to end with 1s on Ladies'' side, 2s on
    Men''s side (Lady on Man''s right)
29-32::
    1L+2L change places RH, 1s cross RH.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (6164, '2013-08-21 08:31:19.886131+00', '2023-02-04 01:21:02.452522+00', 3830, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, dance 1/2 Fig of 8 (1M with 2s & 1L with
    3s) & dance in to face 1st corner
9-16::
    1s dance RSh round 1st crnr _while_ crnrs change place RH, 1s pass
    RSh to face 2nd crnrs to repeat & pass LSh to 2nd pl own side (face
    out)
17-24::
    3s+1s+2s Bal-in-Lines on sides & dance 1/2 reel of 3 on sides (1s
    out & up) crossing down from top to 2nd place opposite side facing
    out & 2s+1s+3s Bal-in-Lines on sides
25-32::
    1s cast clockwise round 1st corner, meet in centre & twirl to dance
    1/2 RSh reel of 3 across (1L with 2s & 1M with 3s) ending 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (8983, '2015-11-30 08:59:27.105866+00', '2023-02-04 01:18:32.51886+00', 12579, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 1s cast to 3rd place _while_ 3s dance to the top,
    3s+1s set & turn partners 2H to finish 3s facing down and 1s facing
    up
9-16::
    3s+2s+1s circle 6H round & back
17-24::
    Mirror reels on the sides (3s+1s cast _while_ 2s dance in and down
    to begin), finish 2s+1s in middle facing
25-32::
    2s+1s dance the Rondel', 0);
INSERT INTO 'dancecrib' VALUES (6165, '2013-08-21 08:31:19.894397+00', '2023-02-04 01:21:02.476196+00', 3833, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s & 4s turn RH, cast in 1 place & dance 1/2 R&L
9-16::
    1s turn RH, cast to 4th place (opposite sides) & all circle 8H round
    to left 1/2 way.  1 (3) 4 (2)

{{title}}
Reel

17-24::
    1s+3s also 4s+2s dance Ladies Chain
25-32::
    3s & 2s cross RH, 1s+3s also 4s+2s change pl LH on sides, 1s+2s
    change pl RH on sides, 3s+2s also 1s+4s change pl LH on sides.  2 3
    4 1', 0);
INSERT INTO 'dancecrib' VALUES (6166, '2013-08-21 08:31:19.902787+00', '2023-02-04 01:21:02.50363+00', 11284, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s cross passing LSh & cast RSh round 1st
    corners into face them
9-16::
    1s dance ''Hello-Goodbye'' setting & end passing RSh to face out in
    2nd place own sides
17-24::
    Promenade (Chaperoned) Chain progression:
::
    _17-18_    2s & 3s 3/4 turn partner RH into middle _while_ 1s dance
    clockwise 1/4 round the set picking up 2L/3M …
::
    _19-22_    who promenade 1/2 way clockwise _while_ middle people (2M
    + 3L) turn LH 1.1/2.
::
    _23-24_    2s & 3s turn partner RH 3/4 to own sides _while_ 1s dance
    clockwise 1/4 round to end in 2nd place, all 3 couples in middle
    facing up 3 1 2
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (6167, '2013-08-21 08:31:19.912664+00', '2023-02-04 01:21:02.599135+00', 3834, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s+2s dance RH across & LH across
17-24::
    1s lead down the middle & back to top
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (8603, '2015-02-13 12:47:57.924792+00', '2023-02-04 01:21:02.622345+00', 15304, 3, NULL, 'ace', '{{explanation}}
Round the Room - Couple facing couple, 1s facing anticlockwise

1-8::
    All circle 4H round & back
9-16::
    All dance LH across & RH back
17-24::
    All dance DoSiDo with person opposite & DoSiDo with partner
25-32::
    1s+2s change place, 1s dancing under arch made by 2s. Repeat, arch
    made by 1s. Repeat,  arch made by 2s and all dance on to meet new
    couple', 0);
INSERT INTO 'dancecrib' VALUES (6168, '2013-08-21 08:31:19.921112+00', '2023-02-04 01:21:02.647261+00', 3837, 3, NULL, 'ace', '1-8::
    1M casts down 1 place _while_ 2L casts up to top, 1M+2L turn RH to
    original places
9-16::
    1L casts 1 place _while_ 2M casts up to top, 1L+2M turn RH to
    original places
17-24::
    1s lead down 2 steps & facing with RH joined set, lead up & cast to
    2nd place turning about for double triangles
25-32::
    1s dance Double Triangles ending BtoB facing own sides
33-40::
    1s dance diag Figs of 8 to end 2nd pl opp side (1M LSh round 3M &
    RSh round 2L as 1L LSh round 2L pass partner RSh to RSh round 3M)
41-48::
    2s+1s+3s Adv+Ret, 1s turn RH 1.1/2 times to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6169, '2013-08-21 08:31:19.929619+00', '2023-02-04 01:21:02.675987+00', 11524, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides 1s
    ending at top on opposite sides facing in & 2s face out
9-16::
    1s turn 2s 1.1/2 times with nearer hands, 1s turn 3s 1.1/2 times
    with other hand
17-24::
    1s cross up to dance reels of 3 on own side At end 3s face out
25-32::
    1s turn 3s 1.1/2 times with nearer hands, 1s dance up to top & cast
    to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (9741, '2017-04-06 08:39:57.555673+00', '2023-02-04 01:21:02.711058+00', 7802, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance mirror reels of 3 on sides (1s in/down, 2s out/up, 3s
    in/up)
9-16::
    1s cross, cast and dance 1/2 Fig 8 (1M round 2s, 1L round 3s)
    finishing facing 1st corner
17-24::
    1s turn 1st corner RH, then 2nd corner RH & turn partner LH ready
    for…
25-32::
    1M+3s & 1L+2s dance RH across.  1s pass RSh to dance LH across with
    other couple.', 0);
INSERT INTO 'dancecrib' VALUES (11703, '2019-03-18 21:02:27.863339+00', '2023-02-04 01:21:02.748098+00', 19139, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s cross LH & cast 1 place (Lady up, Man
    down) to finish LSh to LSh facing 1st corners
9-16::
    1s dance diagonal reel of 4 with 1st corners. at end 1s 1/4 turn LH
    to finish close to 1st corners, ready for …
17-24::
    1s dance RSh round 1st corner to 2nd place own side;  2s+1s+3s turn
    RH to finish 1L facing down, 1M facing up _while_ 2s+3s finish
    facing each other up and down the set
25-32::
    1s dance clockwise round outside (2 bars), 1s turn 3/4 RH to own
    sides _while_ 2s+3s advance, cast back to 1st & 3rd places, wait 2
    bars then all set', 0);
INSERT INTO 'dancecrib' VALUES (6170, '2013-08-21 08:31:19.937876+00', '2023-02-04 01:21:02.78119+00', 8937, 3, NULL, 'ace', '1-8::
    1s lead down 2 places crossing RH, cast up 1 place & dance 1/2 Fig
    of 8 round 3s
9-16::
    Bottom 3 couples dance reels of 3 on sides (1s in & down to start)
    as 2s stand
17-24::
    1s+3s turn twice on sides (Men RH & Ladies LH), 2s+1s turn 1.1/2
    times on sides (Men LH & Ladies RH).  1 2 3 4
25-32::
    1s & 4s cross RH, 1s+2s also 3s+4s change places LH on sides, 1s+4s
    change places RH on sides & cross LH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13258, '2020-10-16 00:20:46.906932+00', '2023-02-04 01:21:02.956334+00', 19717, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp sides

1-8::
    1M & 4M Adv+Ret; 1M+4M dance RSh round partner _while_ 1L & 4L set
    twice  pulling back RSh to end following partner
9-10::
    1s & 4s (Men leading) pass RSh & curve round, 1s facing up, 4s
    facing down _while_ 2s cast up to top, 3s cast to bottom
11-12::
    1M+4L also 4M+1L  join RH & set turning Lady under Man''s arm into
    allemande hold, 1M+4L facing Men''s side, 4M+1L facing Ladies'' side
    _while_ 2s & 3s dance in to meet partner & dance down/up into …
13-16::
    1M+4L cast up (1st place), 4M+1L cast down (4th place) into centre &
    Man turns Lady under arm to form line of 4 up/down centre _while_ 2s
    & 3s cast to ends, dance in down/up & out through original place &
    cast to ends.  2 1 (4) (3)
17-20::
    1M+4L+1L+4M dance 1/2 reel of 4 up/down centre; Bar 20: 1L+4L turn
    3/4 LH as Men dance 1/4 clockwise to face partner in line of 4
    across
21-24::
    1s+4s dance 1/2 reel of 4 across ending on sides  2 1 (4) (3)
25-32::
    1s+4s dance "Eddy":
::
    _25-27_   Ladies turn RH _while_  Men chase clockwise 1/2 round
::
    _28-30_   Men turn RH _while_ Ladies chase clockwise 1/2 round to
    end 1s in 3rd place own sides, 4s in 2nd place opp side 2 (4) 1 (3)
::
    _31-32_   4s+1s cross RH with partner.  End 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (6171, '2013-08-21 08:31:19.946208+00', '2023-02-04 01:21:03.020958+00', 13130, 3, NULL, 'ace', '1-8::
    1s set advancing & turn 2H to face up, 1s cast to face 1st corners
9-16::
    1s dance 1/2 RSh diagonal reel of 4 with 1st corners & pass LSh to
    face 2nd corners, 1s dance 1/2 RSh diagonal reel of 4 with 2nd
    corners & end facing 3rd corner pstns
17-24::
    1s dance ''Hello-Goodbye'' setting & end LSh to LSh facing opposite
    sides
25-32::
    1s dance RH across (1L with 3s at top, 1M with 2s), 3L followed by
    1L+2L & 2M followed by 1M+3M chase 1/2 way to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4077, '2013-08-21 08:30:43.184607+00', '2023-02-04 01:18:32.545011+00', 249, 3, NULL, 'ace', '1-8::
    1s+2s slip step round to left & set, 1s cast to 2nd place as 2s
    dance up to 1st place
9-12::
    1s petronella turn into middle _while_ 2s+3s set then 1s petronella
    turn to opposite sides as  2s+3s petronella l turn into middle
13-16::
    1s set as 2s+3s petronella turn to opposite sides then 1s petronella
    turn into middle & face 3rd corner (pstn) _while_ 2s+3s set
17-24::
    1s dance 1/2 reel of 4 with 3rd corners & face 4th corner (pstn), 1s
    dance 1/2 reel of 4 with crnrs & end 2nd place own sides 1M facing
    up & 1L down
25-32::
    1s dance 1/2 LSh reel on own side, 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6172, '2013-08-21 08:31:19.954487+00', '2023-02-04 01:21:03.049412+00', 3845, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across & 1M+2L change places RH
9-16::
    1s+2s set, dance LH across & 1L+2M change places LH
17-24::
    2s+1s set, cross RH, 2M & 1L cast down/up, pass LSh to face partner
    in diagonal line
25-32::
    2s+1s dance diagonal reel of 4 ending own sides 1s in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6173, '2013-08-21 08:31:19.963093+00', '2023-02-04 01:21:03.079201+00', 3847, 3, NULL, 'ace', '1-4::
    1s+2s set, circle 4H round 1/2 way, 2s NHJ face down, 1s NHJ face up
5-8::
    2s+1s Set+Link, 2s dancing out to 1st place own side _while_ 1s
    dance round each other RSh to face 1st corner
9-20::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s in the middle
    facing opp sides
21-24::
    1M dances up between 3s (at top) & casts to 2nd place own side
    _while_ 1L dances down between 2s & casts up to 2nd place
25-32::
    1s 1/2 turn RH & turn to right to face out on opposite sides, 1s
    dance clockwise round set to 2nd place own sides _while_ 2s+3s dance
    RH across 1/2 way, turning to right dance out to places', 0);
INSERT INTO 'dancecrib' VALUES (13259, '2020-10-16 00:20:47.098276+00', '2023-02-04 01:21:03.097884+00', 13680, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+4s set, cast down/up (2s+3s step down/up 3-4); 1s+4s dance 1/2
    Fig 8 round end couples. 2 (1) 4 (3)
9-16::
    1s+4s Set+Link; 1s+4s circle 4H round to left
17-24::
    2s+4s also 1s+3s Reverse Set+Link; 4s+2s also 3s+1s circle 4H round
    to right.  4 2 (3) (1)
25-32::
    All dance "Double Helix":
::
    All set advancing passing partner LSh & pull back RSh & cast back to
    own side; all 1/2 turn partner RH, 4s+2s also 3s+1s dance 1/2 RH
    across. End 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (8338, '2014-07-29 12:59:13.257901+00', '2023-02-04 01:21:03.125348+00', 15072, 3, NULL, 'ace', '1-8::
    1M+2L+3M+4L dance 1/2 RSh reel of 4 (1M+2L, 3M+4L pass RSh to
    begin).  1M+4L finish in each other''s place as 2L+3M take LH as they
    pass LSh & turn LH 1.1/2 times to finish in each other''s place
9-16::
    1L+2M+3L+4M repeat bars 1-8 dancing 1/2 LSh reel of 4  Finish (4)
    (3) (2) (1)
17-20::
    All chase 1/2 way round set to original places
21-24::
    On sides 1s+2s & 3s+4s set to each other, change places (Men RH,
    Ladies LH), 1s in 2nd place face out
25-32::
    1s+4s dance Cross Chase:
::
    _25-28_   1s cast down 1 place & cross up as 4s cross up 1 place &
    cast down 1 place
::
    _29-32_   1M+4M chase 1/2 way clockwise
::
    Meanwhile 4L+1L dance similarly but in anticlockwise direction,
    dancing on inside of Men
::
    Finish 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6175, '2013-08-21 08:31:19.979717+00', '2023-02-04 01:21:03.183853+00', 3857, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH, cast 1 place & dance 1/2 Fig of 8 round couple
    above them
9-16::
    1L+2s, 1M+3L+4s & 3M+5s  circle 3H / 4H round and back. 1s & 3s end
    facing own 1st corners
17-24::
    1s & 3s set to 1st crnrs, set to 2nd crnrs & end on sides between
    crnrs, cross RH & cast back to original places _while_ 2s & 4s set &
    lead down to places
25-32::
    All dance 8 bars of a mirror reel of 5 (1s in & down, 2s & 4s down &
    out, 3s & 5s up & in to start) to end 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (6176, '2013-08-21 08:31:19.989584+00', '2023-02-04 01:21:03.289788+00', 3859, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place & turn LH to face 2nd corners
9-16::
    1s set HS & turn 2nd corners, set HS & turn 1st corners (1s end
    between 2s+3s on opposite sides)
17-24::
    2s+1s+3s HS set, 1s turn RH to end Lady between 2s & Man between 3s
25-32::
    2s+1s+3s HS set, 1s turn RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (15341, '2022-12-19 01:20:43.523092+00', '2023-02-04 01:21:03.316553+00', 21182, 3, NULL, 'ace', '1-4::
    1s set, 1L casts down 1 place (2L steps up).
5-8::
    1L dances 1/2 Fig 8 round 3M _while_ 1M sets & casts down 1 place
    (2M steps up), 1s meet on Men''s side.
9-12::
    1s in prom hold dance 1/2 reel of 3 with 3s (pass 3L LSh).
13-16::
    1s divide, 1L dances 1/2 reel with 2s (pass 2M LSh) _while_, 1M
    continues 1/2 reel with 3s.
17-20::
    1s in prom hold dance 1/2 reel with 2s (pass 2M on Ladies'' side RSh)
21-24::
    1s dance out of Men''s side, 1M casts up to finish between 2s facing
    down, 1L casts down to finish between 3s facing up.
25-28::
    All Set+Link for 3. (2) (1) (3)
29-32::
    All turn partner RH 1.1/2 (or birl) to own sides. 2 1 3
::
    Optional variation on 2nd turn, 1M leads i.e., casts first, dances
    1/2 Fig 8 round 3L meets partner on Ladies'' side. Reels follow same
    pattern but to opp sides, set and link finishes (2) 1 (3) so 1s turn
    RH last 4 bars.', 0);
INSERT INTO 'dancecrib' VALUES (6180, '2013-08-21 08:31:20.025062+00', '2023-02-04 01:21:03.482752+00', 12830, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2  
4 Bar Introduction (music)

1-4::
    Couples facing clockwise dance between facing couple, divide & cast
    round them returning to place
5-8::
    Both couples turn partners RH
9-12::
    Couples facing anticlockwise dance between facing couple, divide &
    cast round them returning to place
13-16::
    Both couples turn partners LH
17-24::
    Both couples dance Ladies'' Chain
25-28::
    Both couples set to the opposite person & change places RH
29-32::
    Both couples set to the opposite person & turn right about to face a
    new couple', 0);
INSERT INTO 'dancecrib' VALUES (6181, '2013-08-21 08:31:20.033473+00', '2023-02-04 01:21:03.508338+00', 3866, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place (2s step up)  & dance RH across (Lady with 2s &
    Man with 3s) & end BtoB with Lady facing up & Man down
9-16::
    1s slip step out to left & circle 6H (with 2s+3s) round 1.1/4 way
    into lines across (2M+1L+3M at top & 2L+1M+3L at bottom) & lines set
17-28::
    2s+1s+3s dance 3 couple R&L (cross RH up/down to start)
29-32::
    1s cross RH up/down set & all set
33-40::
    2s+1s+3s Advance for 1 step, turn right about & chase 3/4 way to own
    sides & 1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6223, '2013-08-21 08:31:20.619718+00', '2023-02-04 01:21:06.562666+00', 3953, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across, set & dance 1/2 LH across
9-16::
    1s+2s+3s all set & cross RH, set & cross back RH
17-24::
    1s+2s dance Poussette.  2 1 3
25-32::
    1s dance Double Triangles', 0);
INSERT INTO 'dancecrib' VALUES (12457, '2020-01-02 06:58:37.191344+00', '2023-02-04 01:18:26.122065+00', 16679, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up) & dance 1/2 Fig 8 (1M round 2s, 1L
    round 3s) finishing in centre facing 1st corners
9-16::
    _1/2_ diag reel of 4 with 1st corners; 1s pass RSh & dance 1/2 diag
    reel of 4 with 2nd corners. 1s pass LSh to face 3rd corner position
17-24::
    1s set to & turn 3rd corner (pstn) 2H, set to & turn 4th corner
    (pstn) 2H. 1s end in 2nd place own sides.  (3) 1 (2)
25-32::
    1s dance diag R&L (1M down / 1L up)
33-40::
    2s+1s+3s circle 6H round & back. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6182, '2013-08-21 08:31:20.042049+00', '2023-02-04 01:21:03.528688+00', 3869, 3, NULL, 'ace', '1-8::
    1s lead down for 4 steps & 1s lead back to top _while_ 2s set, 2s+3s
    set then 2s+3s+4s set
9-11::
    1M+1L+2L+2M following each other dancing anticlockwise dance 2
    places around.  (2)(1)3 4
12-14::
    1M+1L+3M+3L following each other dancing clockwise dance 2 places
    around.  (2)(3)1 4
15-16::
    1M+1L+4L+4M following each other dancing anticlockwise dance 2
    places around.  (2)(3)(4)(1)
17-24::
    2s facing 3s also 4s facing 1s & all set HS, 2s+3s also 4s+1s circle
    4H round to left
25-32::
    1s dance bars 9-16 in reverse to end in original places
33-40::
    1s facing 2s also 3s facing 4s set & set HS across, 1s+2s also 3s+4s
    circle 4H round to left
41-48::
    1s dance under arch made by 2s & 3s dance under arch made by 1s then
    1s dance under arch made by 4s & all turn 2H twice.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6184, '2013-08-21 08:31:20.058523+00', '2023-02-04 01:21:03.690337+00', 11896, 3, NULL, 'ace', '1-2::
    1s set
3-14::
    1L followed by 1M casts behind 2L & crosses, casts behind 3M &
    crosses, casts up behind 3L & crosses, casts up behind 2M & crosses
    to place
15-16::
    1s+2s+3s set
17-24::
    1s dance RSh reels of 3 on sides
25-32::
    1s set & lead down the middle for 2, turn RH & cast up behind 3s to
    2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6185, '2013-08-21 08:31:20.066768+00', '2023-02-04 01:21:03.710052+00', 3876, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 (Lady round 2s & Man
    round 3s) to end facing 1st corners
9-16::
    1s change places RH with corners, 1s set _while_ corners turn LH,
    corners change places with 1s & set _while_ 1s turn LH to face 2nd
    corners
17-24::
    Repeat bars 9-16 with 2nd corners & 1s end facing 1st corners
25-32::
    1s dance reels of 3 across giving LSh to 1st corners & end in 2nd
    place own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14492, '2021-12-18 01:45:04.653695+00', '2023-02-04 01:21:03.75892+00', 15534, 3, NULL, 'ace', '1-8::
    1s+2s+3sdance reels of 3 on opp side with all 3 couples crossing
    down from 1st place
9-16::
    1s lead down (2s step up 11-12); 1L dances under 1M''s right arm to
    change sides & they lead up to end BtoB in centre facing own sides
17-24::
    2s+1s+3s dance Double Triangles, 2s & 3s pass partner RSh bars 19-20
    (skip change) _while_ 1s dance round each other.  1s end facing 3rd
    corner (pstn)
25-32::
    1s+3rd corners dance Corner Pass+Turn, 1s pass RSh to face 4th
    corners (pstn); 1s+4th corners dance Corner Pass+Turn & 1s end in
    2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (6187, '2013-08-21 08:31:20.083297+00', '2023-02-04 01:21:03.779311+00', 10306, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, cross LH, cast 1 place to meet partner in
    prom hold facing 3M (Lady on Man''s left)
9-16::
    1s dance LSh reel of 3 across with 3s
17-24::
    1s separate to dance reels of 3 on opposite sides
25-32::
    1s dance NHJ up to top, turn 2s with other hand, cross down between
    3s & cast up to 2nd place own sides
33-40::
    1s dance RH across (Lady with 2s & Man with 3s), pass RSh to dance
    LH across with other couple', 0);
INSERT INTO 'dancecrib' VALUES (6188, '2013-08-21 08:31:20.091617+00', '2023-02-04 01:21:03.793588+00', 3882, 3, NULL, 'ace', '1-8::
    1s+4s set diagonally, 1M+4L change places RH & cast on own side to
    original place _while_ 1L+4M cast behind own side & cross RH to
    place
9-16::
    All dance reels of 4 on sides
17-24::
    1L & 4M followed by partners cast in 1 place & petronella in to face
    each other in centre _while_ partners remain in 2nd place on
    opposite sides, 1s+4s set & circle 4H round to left 1/2 way to end
    on own side (2 4 1 3)
25-32::
    All set on sides, 2s+4s also 1s+3s circle 4H round to left 1/2 way,
    turn partners 2H & continue 4H round to end on own sides', 0);
INSERT INTO 'dancecrib' VALUES (8783, '2015-06-15 11:40:55.395091+00', '2023-02-04 01:21:03.809818+00', 16120, 3, NULL, 'ace', '1-8::
    1s dance down NHJ, 1L turns under 1M''s Left arm (bar 5) & dance up
    to 2nd place opp sides facing out (2s step up 5-6)
9-12::
    1s cast (3s step up), cross RH & face out as 2s dance down below 3rd
    place (passing 3rd place before 1s cross)
13-16::
    2L turns under 2M''s arm & dance up to 2nd place facing out _while_
    1s cast down behind 4s & lead up LH following 2s (3s step up 13-14)
17-24::
    3s+1s dance double Fig 8 (1s cross up, 3s cast); 1s finish in middle
    NHJ facing down, 3s in 1st place facing out _while_ 2s cast to 3rd
    place, cross RH, cast below 4s & dance up to 3rd place in middle
    facing up
25-32::
    3s cast down, 4s cast up _while_ 1s dance under arch made by 2s. All
    turn 1.1/4 (1M+4M & 2L+3L RH, 1L+4L & 2M+3M LH) to sides facing
    partners; All set. End  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6189, '2013-08-21 08:31:20.100013+00', '2023-02-04 01:21:03.82597+00', 3885, 3, NULL, 'ace', '1-8::
    1M+2M also 3L+4L cross, pass partner RSh & dance down/up opposite
    side, all Ladies also Men dance RH across at top & bottom
9-12::
    All dance 1/2 reels of 4 on sides (centre dancers do not complete
    1/2 reel but turn right about to face partner)
13-16::
    All set, 1/2 turn partner 2H & couples dance round to 4s/3s facing
    down & 2s/1s facing up.  4 2 3 1
17-24::
    4s+2s also 3s+1s circle 4H round to left, set & 4s turn inwards to
    face up & cast to 2nd pl _while_ 1s turn inwards to face down & cast
    up to 3rd place
25-32::
    4M+1M also 4L+1L cross to opposite sides (Mens arch) & turn 2H to
    face prtnrs, 4s & 1s dance 1/2 Figs of 8 round 2s/3s.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6190, '2013-08-21 08:31:20.110023+00', '2023-02-04 01:21:03.974749+00', 3887, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to places
9-16::
    2s lead down the middle for 3 steps, back to top & cast to places
17-24::
    3s lead down the middle for 2 steps, back to top & cast to places
25-32::
    1s+2s dance Allemande
33-40::
    2s+1s+3s dance Grand Chain
41-48::
    1s cross RH & cast down round 3s, lead up to top, cross & cast to
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6192, '2013-08-21 08:31:20.230534+00', '2023-02-04 01:21:04.218936+00', 9816, 3, NULL, 'ace', '1-8::
    1s & 3s petronella turn & set, turn partners RH 1.1/4 to places
9-16::
    2s petronella turn & set, change places LH & dance LSh round 3rd
    corners to places
17-24::
    All dance Grand Chain
25-32::
    All set, circle 6H round to left 1/2 way; all set & 3s+2s (top 2
    couples) dance 1/2 RH across _while_ 1s cross RH.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6193, '2013-08-21 08:31:20.23904+00', '2023-02-04 01:21:04.266847+00', 3889, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH, cast 1 place & lead up to end in lines of 4 across
    (1s between 2s, 3s between 4s) facing up; Lines of 4 across Adv+Ret
9-16::
    1s & 3s lead up, cross & cast to 2nd/4th place own sides (2s/4s step
    up 11-12); 2s+1s also 4s+3s dance 1/2 R&L  (1) (2) (3) (4)
17-24::
    1s lead down the middle in prom hold, followed by 2s+3s+4s (who
    dance up sides to start), then dance out to Men''s side (bar 19) &
    continue promenade back to original places, 1s face out. 1 2 3 4
25-32::
    1s cast, cross RH (1 bar), cast, cross LH (1 bar), cast to 4th place
    (2s+3s+4s step up bars 31-32). End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6194, '2013-08-21 08:31:20.247295+00', '2023-02-04 01:21:04.300011+00', 3891, 3, NULL, 'ace', '1-8::
    1s dance down the middle, set, dance up to top & cast to face 1st
    corners
9-16::
    1s turn 1st corners RH, pass RSh, turn 3rd corners LH, pass LSh to
    face 2nd corners
17-24::
    1s turn 2nd corners RH, pass RSh, turn 4th corners LH, into middle
    BtoB facing own sides
25-32::
    1s dance Double Triangles with 2s & 3s ending in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6195, '2013-08-21 08:31:20.255622+00', '2023-02-04 01:21:04.325367+00', 3893, 3, NULL, 'ace', '1-8::
    All Ladies dance RSh round partner, all set on sides
9-16::
    All Men repeat dance RSh round partner & end on own sides facing
    out, all set
17-24::
    All Ladies dance to partners left into prom hold & set turning,
    Ladies dance back to place & all set
25-32::
    3s dance 1/2 Fig of 8 round 4s, lead to top, cross & cast to 2nd
    place _while_ 2s follow 3s to dance 1/2 Fig of 8 round 4s, lead up
    to top & cross _while_ 1s follow 2s & dance 3/4 Fig of 8 round 4s to
    end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6196, '2013-08-21 08:31:20.263908+00', '2023-02-04 01:21:04.349736+00', 3894, 3, NULL, 'ace', '1-8::
    1s & 3s set, turn 2H to face 2s/4s, 1s+2s also 3s+4s set & 1/2 turn
    2H opposite person
9-16::
    All 5 couples turn RH, 1s & 3s turn LH & cast down 1 place _while_
    others turn LH for 4 bars (4s+5s dancing up 1 place)
17-24::
    4s+1s also 5s+3s set & dance RH across 1/2 way, 2s+1s also 4s+3s set
    & dance LH across 1/2 way
25-32::
    All dance Grand Chain (1 place each hand & 1s start crossing) to end
    2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (10446, '2018-02-24 07:52:51.732644+00', '2023-02-04 01:21:04.585244+00', 18075, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place (2s step up 3-4), 1s dance 1/2 Fig 8 up
    between 2s, finishing 2nd place opp sides facing in & down
9-16::
    2s+1s+3s dance reflection reels of 3 on side (1s in & down to start)
17-24::
    1s set, cross down between 3s, cast up round 3s to face 1st corners
25-32::
    1s Set to Corners & Partner (''Hello-Goodbye'' setting), finishing in
    2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (14665, '2022-03-07 02:20:32.460804+00', '2023-02-04 01:21:04.606495+00', 20514, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 on own sides (dance between 2s to start)
9-16::
    All turn RH, all turn LH
17-24::
    1s slip step down for 4 steps & set, slip step up to top & set
25-32::
    1s cast to 4th place, 2s+3s+4s step up. All dance DosiDo', 0);
INSERT INTO 'dancecrib' VALUES (6197, '2013-08-21 08:31:20.274722+00', '2023-02-04 01:21:04.629842+00', 12889, 3, NULL, 'ace', '1-8::
    1s dance down below 3s, cast up to 2nd place own side & turn RH
9-16::
    2s set, cross RH, set & cross back RH _while_ 1s stand for 2 bars,
    set, cross RH & set _while_ 3s stand for 4 bars, set & cross RH
17-24::
    2s+1s+3s dance reflection reels of 3 on sides (1s dance down between
    3s to start)
25-32::
    1s+3s dance 1/2 double Fig of 8 to end in order 2 1 3, 1s+3s turn
    (Men RH & Ladies LH)', 0);
INSERT INTO 'dancecrib' VALUES (6198, '2013-08-21 08:31:20.28306+00', '2023-02-04 01:21:04.646261+00', 3899, 3, NULL, 'ace', '1-8::
    1s set, cast 2 places, 2s+3s also 1s+4s dance 1/2 R&L
9-16::
    1s set, cast up 2 places, 3s+1s also 2s+4s dance 1/2 R&L.  1 3 4 2
17-24::
    1s+2s set & cross RH _while_ 3s+4s set & dance RH across 1/2 way,
    1s+2s dance clockwise 1/2 way _while_ 4s+3s set & dance LH across
    1/2 way
25-32::
    All dance reels of 4 on sides.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6199, '2013-08-21 08:31:20.291299+00', '2023-02-04 01:21:04.67132+00', 3900, 3, NULL, 'ace', '1-8::
    1s & 3s turn RH, cast 1 place & dance 1/2 Figs of 8 round 2s/4s
9-16::
    2s+1s also 4s+3s turn on sides (1s & 4s turning between 2s/4s) &
    1s/3s dance 1/2 Figs of 8 round 2s/4s
17-24::
    All dance reels of 4 on sides (LSh on Men''s side & RSh on Ladies
    side)
25-32::
    1s+4s+3s (bottom 3 couples) dance Allemande.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6200, '2013-08-21 08:31:20.29972+00', '2023-02-04 01:21:04.695569+00', 3901, 3, NULL, 'ace', '1-8::
    2s turn 2H & dance out own sides between 1s+3s, cast round person on
    right, change places RH to end Lady between 1s & Man between 3s
9-16::
    2s dance 1/2 RSh reels of 3 across (2L with 1s & 2M with 3s) & 2s
    turn LH & dance 1/2 LSh reels with other couple (1s & 3s dance full
    reels) 2s turn LH to end facing 2nd corners
17-24::
    2s dance Pass+Turn with 2nd corners & turn RH to dance Pass+Turn
    with 1st corners ending in original places
25-32::
    1s+2s+3s set, 1s cross RH _while_ 2s+3s dance RH across 1/2 way,
    1s+3s+2s set & 2s cross RH _while_ 1s+3s dance RH across 1/2 way.  3
    1 2', 0);
INSERT INTO 'dancecrib' VALUES (5188, '2013-08-21 08:31:02.246262+00', '2023-02-04 01:21:04.823834+00', 8855, 3, NULL, 'ace', '1-8::
    2s followed by 1s lead down, 1s followed by 2s lead up to top & 1s
    cast to 2nd place
9-16::
    2s+1s+3s dance Grand Chain
17-24::
    1s dance 1/2 Fig of 8 round 3s (giving RH) & 1/2 Fig of 8 round 2s
    (giving RH)
25-32::
    1s dance RH across (Lady with 2s & Man with 3s) & dance LH across
    with other couple', 0);
INSERT INTO 'dancecrib' VALUES (10834, '2018-06-11 00:36:39.324186+00', '2023-02-04 01:21:04.839782+00', 15460, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance, 2 facing 2 (1s face clockwise, 2s face anticlockwise)

1-8::
    1s+2s circle 4H round and back
9-16::
    1s+2s dance RH across, LH across
17-24::
    Ladies Adv+Ret; Men Adv+Ret
25-32::
    1M+2L also 1L+2M dance DoSiDo; couples take promenade hold & pass
    opposite couple LSh to meet new couple', 0);
INSERT INTO 'dancecrib' VALUES (6234, '2013-08-21 08:31:20.909952+00', '2023-02-04 01:21:07.48713+00', 3974, 3, NULL, 'ace', '{{explanation}}
Round the room.  Men with backs to centre of room facing partners

1-8::
    Set to partner, change places RH, set & turn RH to face
    anticlockwise in Allemande hold
9-16::
    Allemande 2 steps, set turning about to Reverse Allemande hold
    (retain hold of hands), Allemande 2 steps clockwise, set turning
    (retain hold of hands) to face partner & fall back to original place
17-24::
    Turn partner RH (4 bars) & turn next partner to left LH (your new
    partner)
25-32::
    Slip step anticlockwise 8 steps & back to new places facing new
    partner', 0);
INSERT INTO 'dancecrib' VALUES (12458, '2020-01-02 06:58:37.224996+00', '2023-02-04 01:18:26.151735+00', 16681, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set+Link; 2s+1s also 4s+3s dance 1/2 RH across,
    1s+2s also 3s+4s change places RH on side. (2) (1) (4) (3)
9-16::
    All dance RSh reels of 4 on sides
17-20::
    1s & 3s cross RH, cast up 1 place _while_ 2s+4s 1/2 turn RH & lead
    down 1 place looping into place
21-24::
    1s dance down NHJ looping into 4th place (2s+3s+4s step up 23-24)
25-32::
    All circle 8H round & back. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4078, '2013-08-21 08:30:43.192777+00', '2023-02-04 01:18:32.572692+00', 9421, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s turn LH & face out
9-16::
    1s dance reels of 3 on own sides (1M LSh to 3M & 1L LSh to 2L to
    start)
17-24::
    1s Petronella turn into middle _while_ 2s+3s change places RH on
    sides & all set, 1s petronella turn to opp sides _while_ 2s+3s cross
    RH & all set
25-32::
    1s Petronella turn into middle _while_ 2s+3s change places RH on
    sides & all set, 1s petronella turn to own sides _while_ 2s+3s cross
    RH & all set', 0);
INSERT INTO 'dancecrib' VALUES (14424, '2021-11-06 01:12:03.505893+00', '2023-02-04 01:21:04.97418+00', 20492, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance 3 couple Allemande (on bar 1 Men dance diagonally
    across as Ladies dance up slightly. As 1s meet they rotate to face
    Men''s side in Allemande hold) 3 2 1
9-16::
    1s lead up to top & cast to 2nd place (2s step down on bars 11-12).
    1s turn RH to 2nd place own sides facing out 3 1 2
17-24::
    3s+1s+2s dance Promenade (Chaperoned) Chain progression:
::
    _17-18_    3s & 2s 3/4 turn partner RH into middle _while_ 1s dance
    clockwise 1/4 round the set picking up 3L/2M …
::
    _19-22_    who promenade 1/2 way clockwise _while_ middle people (3M
    + 2L) turn LH 1.1/2.
::
    _23-24_    2s & 3s turn partner RH 3/4 to own sides _while_ 1s dance
    clockwise 1/4 round to end in 2nd place. 2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6201, '2013-08-21 08:31:20.385689+00', '2023-02-04 01:21:04.989984+00', 3908, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 2s+1s Set+Link
9-16::
    1M+2L turn 2H _while_ partners set, 1s+2s dance 4H round to left 1/2
    way. 1L+2M turn 2H _while_ partners set, 1s+2s dance 4H round to
    left 1/2 way.
17-24::
    1s turn 2H & cast 1 place, 1s turn 2H & cast up to places
25-32::
    1s+2s dance a Philabeg:
::
    1s+2s turn 2H, 1s dance down diagonally to Men''s side _while_ 2s
    dance diagonally up to Ladies'' side & 1s+2s 3/4 turn 2H
::
    1s dance down diag into middle _while_ 2s dance diag up into middle
    & 3/4 turn 2H, 1s+2s pass partner RSh & dance out to own sides to
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (6202, '2013-08-21 08:31:20.394001+00', '2023-02-04 01:21:05.011409+00', 10878, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s dance 1/2 Fig of 8 round 2s
9-16::
    1s dance RH across (1M with 2s, 1L with 3s), pass RSh to dance LH
    across with other couple & pass LSh to face 3rd corners
17-24::
    1s dance RSh reels of 3 across (1M with 2s, 1L with 3s) & end in
    middle facing each other (down/up)
25-32::
    1s turn RH once round, set & Petronella turn to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6203, '2013-08-21 08:31:20.402238+00', '2023-02-04 01:21:05.032272+00', 3909, 3, NULL, 'ace', '1-8::
    1s cross down, dance out between 2s+3s & cast to 3rd place as 2s+3s
    step up, 2s repeat with 3s+1s stepping up
9-16::
    3s cross down to dance reel of 3 on sides to end 3 1 2 on opp sides
17-24::
    1s dance out & up round 3s, cross down & dance 1/2 double Fig of 8
    with 2s (dancing out & down to start)
25-32::
    3s cross down to dance 1/2 reel of 3 on sides, 1s turn 1.1/2 times
    LH down into 3rd place & cast up to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6204, '2013-08-21 08:31:20.410655+00', '2023-02-04 01:21:05.239998+00', 9419, 3, NULL, 'ace', '{{explanation}}
Each couple dance 32 bars. A New Couple starts after 16 bars (ie on bars 1, 17, 33 & 49)

1-8::
    1s+2s+3s dance reels of 3 on sides (1s in & down to start)
9-16::
    1s cross RH, cast 1 place, cross LH & cast down 1 place
17-24::
    (New Couple starts as at bar 1) New couple starts reels of 3 on
    sides (new top couple in & down to start with original 1s in 3rd
    place)
25-32::
    Original 1s+4s facing each other on sides set & change places with
    nearer hand (1s dancing out), set again to each other & 1s set to
    partner _while_ new couple dance bars 9-32', 0);
INSERT INTO 'dancecrib' VALUES (8784, '2015-06-15 11:40:55.667248+00', '2023-02-04 01:21:05.264601+00', 16257, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance RSh reels of 3 on sides
9-16::
    1s+2s turn RH 1.1/2 times on sides; 1s+3s turn LH 1.1/2 times on
    sides to end 2 3 1 4
17-24::
    Top 3 couples dance RSh reels of 3 on sides
25-28::
    Top couples also bottom couples turn RH 1.1/2 times on sides
29-32::
    Middle couples turn LH 1.1/2 times on sides _while_ bottom couple
    turn LH once round to end 3 4 2 1
33-64::
    Repeat bars 17-32 twice more (original 1s+2s are now back at the top
    of the set)
65-72::
    Top 3 couples dance RSh reels of 3 on sides
73-80::
    Bottom couples (original 4s+3s) turn RH 1.1/2 times on sides & then
    the bottom couple (original 4s) turn LH to end 1 2 3 4', 0);
INSERT INTO 'dancecrib' VALUES (12405, '2019-12-05 01:30:48.667898+00', '2023-02-04 01:21:05.28644+00', 17536, 3, NULL, 'ace', '1-8::
    1s lead down middle (3 bars), lead up (3 bars) & cross to 1st place
    opp sides to face down, 2s face up
9-12::
    1s+2s set, 1s+2s change places on sides (1M+2L RH & 1L+2M LH)
13-16::
    1s turn 3/4 LH to finish 1L between 2s facing 2M & 1M between 3s
    facing 3L
17-24::
    1s dance LSh reels across, 2s+3s giving hands when possible
25-32::
    2s+1s+3s circle 6H round to the left for 6 steps, pivot & chase back
    to places. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9387, '2016-10-06 07:18:38.972812+00', '2023-02-04 01:21:05.309076+00', 17232, 3, NULL, 'ace', '1-8::
    1s lead down (3 steps), lead back (3 steps), cross and cast to 2nd
    place opp. sides
9-16::
    2s+1s dance R&L (Men finish facing out)
17-24::
    2s+1s dance Ladies'' chain (1M finishes facing out).
25-32::
    1M casts round 3L, 1L cast round 3M, 1s meet & lead up crossing over
    & casting to 2nd pl own sides', 0);
INSERT INTO 'dancecrib' VALUES (14799, '2022-05-05 00:20:34.668928+00', '2023-02-04 01:21:08.098142+00', 3999, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L;  1s+2s dance RH across (2) (1)
9-16::
    2s+1s dance 1/2 L&R (cross LH, change places RH on sides); 1s+2s
    dance 1/2 LH across
17-24::
    1s+2s set twice & turn RH remaining in centre facing up ready for …
25-32::
    1s+2s dance Allemande.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (6205, '2013-08-21 08:31:20.447308+00', '2023-02-04 01:21:05.422081+00', 3912, 3, NULL, 'ace', '1-8::
    Top couple followed by other 3 couples cast to bottom & lead back up
    to top
9-16::
    Top couple lead down to bottom & cast up to top on own sides
17-24::
    Bottom couple lead up to top & cast to 4th places
25-32::
    Top 2 couples also bottom 2 couples dance RH across, clap & dance LH
    across back to places (2nd time - middle couples dance RH/LH _while_
    end couples turn RH/LH)
33-40::
    1s+2s (top 2 couples) dance Allemande (2nd time - middle couples
    dance Allemande)
41-48::
    All turn RH then LH
49-56::
    1s lead up 1 place & cast 1 place to face 1st corners, 1s set to 1st
    corners then set to 2nd corners
57-64::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corners &
    cross to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (14582, '2022-02-05 02:20:30.091279+00', '2023-02-04 01:21:05.448164+00', 13273, 3, NULL, 'ace', '1-8::
    1s cross down to dance mirror reels of 3 on opp sides (2s out/up, 3s
    in/up). 1s meet at top & take NH, 2s face out.  1 (2) 3
9-16::
    1s dance down to 2nd place facing out _while_ 2s cast up to 1st
    place, 1s+3s turn (1M+3L RH, 1L+3M LH); 1s+2s turn 1.1/2 giving
    other hand. (1) 2 3
17-24::
    1s dance 1/2 Fig 8 down round 2s; 1s+2s dance RH across remaining in
    middle ready for …
25-32::
    1s+2s dance Allepouse (1s dance path of normal Allemande as 2s
    Poussette to change places).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6206, '2013-08-21 08:31:20.457286+00', '2023-02-04 01:21:05.535074+00', 3915, 3, NULL, 'ace', '1-8::
    All Adv+Ret & turn RH
9-16::
    Repeat above Fig
17-24::
    4s followed 3s+2s+1s dance down, 1s leading back to places
25-32::
    1s facing 2s Adv+Ret, 1s advance under arch made by 2s

{{explanation}}
Repeat with 1s from 2nd place but end in 4th places', 0);
INSERT INTO 'dancecrib' VALUES (6208, '2013-08-21 08:31:20.479282+00', '2023-02-04 01:21:05.581685+00', 3918, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s lead down for 3, 2s+3s divide & 1s followed by
    2s+3s lead up, 1s cross & cast to 2nd place
9-16::
    2s+1s+3s dance reels of 3 on sides (1s in & down to start)
17-24::
    2s+1s dance 1/2 double Fig of 8 (1s cross up to start), 1s+3s dance
    1/2 Fig of 8 (1s cross down to start)
25-32::
    2s+1s+3s cross RH & set, 1s dance RH across ( 1L with 2s & 1M with
    3s)', 0);
INSERT INTO 'dancecrib' VALUES (6209, '2013-08-21 08:31:20.4893+00', '2023-02-04 01:21:05.602892+00', 11001, 3, NULL, 'ace', '1-8::
    1s cast 2 places & dance up middle to places _while_ 3s dance up to
    top & cast to original places, all set
9-16::
    2s dance 1/2 Fig of 8 round 1s, 2s dance 1/2 Fig of 8 round 3s
17-24::
    1s+2s dance poussette.  2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6210, '2013-08-21 08:31:20.497691+00', '2023-02-04 01:21:05.620587+00', 9872, 3, NULL, 'ace', '1-8::
    1s+2s+3s set HS, cross to partner''s place with 1L & 2M also 2L & 3M
    passing RSh, cross back to place (1M & 2L also 2M & 3L passing RSh
9-16::
    1s+2s+3s circle 6H round & back
17-24::
    1s+2s dance The Knot
25-32::
    1s dance full Fig of 8 (1M round 3s & 1L round 2s) _while_ 2s+3s set
    & cross RH, set & cross back to own sides.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6211, '2013-08-21 08:31:20.505935+00', '2023-02-04 01:21:05.647473+00', 8951, 3, NULL, 'ace', '1-8::
    1s dance down middle for 2 steps, set, dance up to top & cast to
    face 1st corners
9-16::
    1s turn 1st corners RH, pass partner RSh, turn 2nd corners RH & pass
    RSh to end 2nd place own sides
17-24::
    1s dance RSh reels of 3 on own sides (Man up Lady down)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6212, '2013-08-21 08:31:20.515969+00', '2023-02-04 01:21:05.763014+00', 3921, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All dance Grand Chain
9-16::
    All circle 8H round & back
17-24::
    1s+2s also 3s+4s circle 4H round & back
25-32::
    1s+2s also 3s+4s dance RH across 1/2 way & dance 1/2 R&L back to
    places

{{title}}
Reel

1-8::
    All cross RH & cross back RH
9-16::
    1s+2s also 3s+4s dance All Round Poussette
17-24::
    All Promenade
25-32::
    All dance reels of 4 on sides', 0);
INSERT INTO 'dancecrib' VALUES (6213, '2013-08-21 08:31:20.524259+00', '2023-02-04 01:21:05.779622+00', 9137, 3, NULL, 'ace', '1-8::
    1s set & cross LH _while_ 2s+3s+4s circle 6H round 1/2 way, Top 3
    couples circle 6H round to right _while_ bottom couple set & cross
    RH
9-16::
    4s+1s (centre couples) dance LH across, 1/2 turn partners LH to face
    corner & change places RH
17-24::
    All dance interlocking diagonal reels of 4
25-32::
    Centre couples dance 1/2 LH across to opposite sides & all set, top
    2 couples also bottom 2 couples dance 1/2 R&L to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13529, '2021-01-09 01:20:32.472858+00', '2023-02-04 01:21:05.805504+00', 17050, 3, NULL, 'ace', '1-8::
    Men dance RSh round partners back to place, Ladies repeat
9-16::
    1s set & cast (2s step up 3-4), 1s pass partner LSh to dance RSh
    round 1st corners to finish BtoB facing 1st corners
17-24::
    1s set to 1st corners & 2nd corners & end on sides between corners.
    1s dance 1/2 Fig of 8 (1M down round 3s, 1L up round 2s)
25-32::
    1s dance LSh reels of 3 on the sides (LSh to 3rd corner, 1L down, 1M
    up).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6214, '2013-08-21 08:31:20.534366+00', '2023-02-04 01:21:05.832632+00', 8851, 3, NULL, 'ace', '1-8::
    Ladies dance Fig 8 round partner & next Man clockwise, passing in
    front of partner to start
9-16::
    Men dance Fig 8 round partner & next Lady anticlockwise, passing in
    front of partner to start
17-24::
    All Adv+Ret, all dance DoSiDo
25-32::
    All dance interlocking reels of 4 (start by giving RSh to partner)
33-40::
    Ladies cast to next place clockwise _while_ Men dance LH across once
    round ending BtoB in middle facing new prtnr, all set to new ptnr &
    3/4 turn 2H
41-48::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8062, '2013-10-01 08:47:05.747567+00', '2023-02-04 01:21:05.867497+00', 14456, 3, NULL, 'ace', '1-8::
    1s & 2s Set & Rotate
9-16::
    1s & 3s dance the Bourrel:
::
    1M+3L set advancing, 3/4 turn 2H & twirl to end BtoB (Lady facing
    up, Man down) _while_ partners chase anticlockwise 1/2 way,
::
    Set to partners & turn 2H (sometimes RH) to own sides having changed
    places
17-20::
    Top couple lead down to 3rd pl cross & cast up to 2nd pl as Middle
    couple set & cross down to 3rd pl as Bottom couple cast up to 1st
    place & cross RH
21-24::
    All set & 1/2 turn 2H to own sides
25-32::
    1s set & cross RH, 1s cast to bottom & cross LH', 0);
INSERT INTO 'dancecrib' VALUES (6215, '2013-08-21 08:31:20.544325+00', '2023-02-04 01:21:05.978726+00', 3931, 3, NULL, 'ace', '1-8::
    1s set & cast to 3rd place, 1s set & cast back to top
9-16::
    1s lead down the middle, back to top & cast to 2nd place
17-24::
    2s+1s+3s circle 6H round & back
25-32::
    2s+1s+3s Adv+Ret & turn partners 2H (4 PdB)', 0);
INSERT INTO 'dancecrib' VALUES (6216, '2013-08-21 08:31:20.554226+00', '2023-02-04 01:21:06.078815+00', 3932, 3, NULL, 'ace', '1-8::
    1M+2L set & turn 2H, 1L+2M set & turn 2H
9-16::
    1s crossing down RH cast down behind 3s, lead up to top, cross RH &
    cast to face 1st corners
17-24::
    1s turn 1st corners RH, passing RSh turn 2nd corner LH & pass LSh to
    end in lines across 1L between 2s & 1M between 3s
25-32::
    Lines Adv+Ret 1 step twice, 1s turn 2H 1.1/4 times to places', 0);
INSERT INTO 'dancecrib' VALUES (6217, '2013-08-21 08:31:20.562571+00', '2023-02-04 01:21:06.110358+00', 3933, 3, NULL, 'ace', '1-8::
    1s set advancing, turn 2H 1/2 way, lead down below 3s & cast up to
    2nd place opposite sides
9-16::
    1s set advancing to end BtoB (Man facing up & Lady down) & dance
    Crown Triangles
17-24::
    1s dance out to right & dance Fig of 8 on own sides _while_ 2s+3s
    dance R&L changing places on sides to start
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6218, '2013-08-21 08:31:20.5709+00', '2023-02-04 01:21:06.145053+00', 3934, 3, NULL, 'ace', '1-8::
    1s circle 3H round to left with 2L, 1s circle 3H round to left with
    2M
9-16::
    1s lead down the middle & back to top
17-24::
    1s+2s dance Allemande (1s end in lines across 1L between 2s facing
    1M between 3s)
25-32::
    2s+1s+3s set (1s turning onto sides on 2nd step), 2s+1s+3s set, 1s
    dance down below 3s & cast up to 2nd place
33-40::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (12858, '2020-06-03 16:25:02.225797+00', '2023-02-04 01:18:32.629537+00', 17754, 3, NULL, 'ace', '1-8::
    1s lead down below 3s, cross & cast up to 2nd place opp sides (2s
    step up); 1s cross RH, cast to Right to 1M between 2s 1L between 3s
9-12::
    1s turn 3/4 RH, turn 1st corners LH into lines across facing 4th
    corners, 1L taking 1st corner in prom hold (1L on the L), 1M alone
13-16::
    1s loop LSh round 4th corners back to same place,1L releases prom
    hold, _while_ 4th corners pass 1s LSh into centre and turn LH back
    to place
17-20::
    Repeat 9-12 with 2nd corners: 1s 3/4 turn LH, turn 2nd corner LH to
    face 3rd corners, 1L taking 2nd corner in prom hold (1L on the R)
21-24::
    Repeat 13-16 with 3rd corners: 1s loop RSh _while_ 3rd corners pass
    1s RSh into centre and turn RH back to place
25-32::
    All chase 1/2 way clockwise then 1s turn 1.1/4 RH _while_ corners
    continue chase back to place. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11458, '2019-01-01 01:57:13.319891+00', '2023-02-04 01:21:06.263738+00', 18945, 3, NULL, 'ace', '{{explanation}}
Alternative title "Tony''s Trauma"

1-8::
    1s cross RH, cast (2s step up).  2s+1s+3s Adv+Ret
9-16::
    1s lead down & back finish facing 1st corners
17-24::
    1s set to & turn 1st corner, set to & turn 2nd corner, finishing on
    opp sides between corners
25-32::
    1s set twice advancing & turn 1.1/2 times (any preferred turn, birl,
    etc) to end in 2nd place own sides

{{explanation}}
2nd time through - 4s step up bars 29-30 so 1s can turn into 4th place', 0);
INSERT INTO 'dancecrib' VALUES (6221, '2013-08-21 08:31:20.597306+00', '2023-02-04 01:21:06.280642+00', 3940, 3, NULL, 'ace', '1-8::
    1s set, cast to 3rd place, set & cast back to top
9-16::
    1s lead down the middle for 3 steps, back to top & cast to 2nd place
    to face 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners &
    cross to 2nd place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (6222, '2013-08-21 08:31:20.609731+00', '2023-02-04 01:21:06.293987+00', 3941, 3, NULL, 'ace', '1-8::
    1s+4s cross RH, cast 1 place down/up (2s+3s step up/down) & dance RH
    across ending 1s between 2s & 4s between 3s all facing up
9-16::
    All PdB coupe 4 times (popular version - All coupe PdB 4 times)
17-24::
    1s+2s also 3s+4s dance RSh reels of 4 across finishing by dancing to
    original places 1 2 3 4
25-32::
    All circle 8H round & back
33-40::
    1s cross RH (2s do not step up), cast to 2nd place, cross LH & cast
    to bottom (2s+3s+4s step up bars 39-40)

{{explanation}}
Note:  Guide to SCD has bars 33-40 1s cross RH, cast 1 place, cross RH again & cast to bottom place', 0);
INSERT INTO 'dancecrib' VALUES (6224, '2013-08-21 08:31:20.628208+00', '2023-02-04 01:21:06.59668+00', 3957, 3, NULL, 'ace', '1-8::
    1M sets to 2L & casts 1 place, 1L sets to 2M & casts 1 place
9-16::
    1s dance RH across (L with top cpl & M with cpl in 3rd pl), 1s (with
    cpls following) pass LSh to change ends into LH across, 1s end in
    2nd pl
17-24::
    1s dance LH across with same couples & repeat above Fig bars 13-16
    to end own side 2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6225, '2013-08-21 08:31:20.636667+00', '2023-02-04 01:21:06.628428+00', 3959, 3, NULL, 'ace', '1-4::
    1L+2L also 2M+3M also 3L+4L join hands to cross between partners as
    all cross, repeat back to place
5-8::
    1s & 3s turn partners RH _while_ 2s & 4s turn LH
9-16::
    All dance 1/2 RSh reels of 4 on sides, 4M+3L also 2M+1L passing LSh
    into 1/2 reels of 4 across with partners to end (3)(4)(1)(2)
17-24::
    4s+1s pass LSh to dance 1/2 RSh reels of 4 on sides, all set & cross
    RH.  2 1 4 3
25-32::
    1s & 3s set & turn 2H into middle, 1s followed by 3s lead up & cast
    to 4th & 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6226, '2013-08-21 08:31:20.64511+00', '2023-02-04 01:21:06.655514+00', 11785, 3, NULL, 'ace', '1-8::
    1s cross down _while_ 2s dance out & up, 1M+2L turn RH _while_ 1L+2M
    turn LH, 1M+3L turn LH 1.1/2 times _while_ 1L+3M turn LH 1.1/2
    times.  2 3(1)
9-16::
    1s cross up _while_ 3s dance out & down, 1L+3L turn RH _while_ 1M+3M
    turn LH, 1L+2L turn LH 1.1/2 times _while_ 1M+2M turn RH 1.1/2
    times.  1 2 3
17-24::
    1s cross RH, cast 1 place, 1L crosses up & casts to 2nd place
    _while_ 1M crosses down & casts up to 2nd place
25-32::
    1s dance RH across (1L with 2s & 1M with 3s) & pass RSh to dance LH
    across with other couple
33-40::
    1s dance reels of 3 across (1L with 2s & 1M with 3s) giving LSh to
    3rd corners to start', 0);
INSERT INTO 'dancecrib' VALUES (11201, '2018-09-30 22:20:06.224926+00', '2023-02-04 01:21:06.696152+00', 18621, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s set, 1s+4s cast in one place as 2s & 3s cross
    up/down: all dance 1/2 double 1/2 Figs of 8 to end 2 (1) 4 (3)
9-16::
    1s+4s dance RH across & LH back
17-24::
    1L followed by 1M dance Tandem reel of 3 across with 2s (LSh to 2M)
    as 4L followed by 4M dance Tandem reel of 3 across with 3s (LSh to
    3M). End with 1s+4s facing corners 1L/2M, 1M/2L, 4L/3M & 4M/3L
25-32::
    1s+4s dance ''Hello-Goodbye'' setting & end facing opposite corner
33-40::
    4s cross up between 2s & cast to end 2nd place own sides as 1s cross
    down between 3s & cast to end 3rd place opp sides; all 4 couples
    turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (13260, '2020-10-16 00:20:50.204664+00', '2023-02-04 01:21:06.726278+00', 14898, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s
9-16::
    1s cross LH & dance out & down into mirror reels of 3 on sides (2s
    in/down, 3s in/up to start).  1s end BtoB in centre facing own side
17-24::
    2s+1s+3s dance Double Triangles, 1s end 2nd place own side
25-32::
    1s set, dance RSh round each other & turn RH (4 bars).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12406, '2019-12-05 01:30:52.240361+00', '2023-02-04 01:21:08.972854+00', 4038, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s set, cast 1 place (2s step up) & dance 1/2 Fig 8 round 2s
17-24::
    2s+1s dance Ladies Chain
25-32::
    1s set, cast up, cross RH & cast 1 place. 2 1', 0);
INSERT INTO 'dancecrib' VALUES (9940, '2017-06-05 11:31:56.667674+00', '2023-02-04 01:23:08.650966+00', 17742, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp sides

1-2::
    1s & 4s 1/2 turn LH moving down/up 1 place _while_ 2s & 3s cast to
    1st/4th place.  End 1M & 4M following partners who face 2M & 3M
    places.  2 (1) 4 (3)
3-8::
    1s+2s also 4s+3s dance tandem RSh reels of 3 across
9-16::
    1s+2M also 4s+3M dance RH across.  1s+4s dance LH across in centre
17-20::
    1s+3L also 4s+2L dance RH across to end on sidelines 2 (4) 1 (3)
    with 4L & 1L facing out
21-24::
    4s+1s chase anticlockwise 1/2 round in centre of set. All face in  2
    (1) 4 (3)
25-32::
    All set.  1s+4s dance 3/4 R&L _while_ 2s+3s cross RH, set, cross
    back LH.  End 2 4 (1) (3), 4s & 1s facing out, 2s & 3s retaining
    hands to repeat from new positions', 0);
INSERT INTO 'dancecrib' VALUES (6227, '2013-08-21 08:31:20.752324+00', '2023-02-04 01:21:06.863169+00', 11226, 3, NULL, 'ace', '{{explanation}}
Square set. 5s face each other in centre, 5M facing up - 5L facing down

1-4::
    5M dances out between 2s & casts to left to above 1st place, 5L
    between 4s, casts to left to below 3rd place _while_ 1s+3s dance 1/2
    RH across
5-8::
    5M+1s & 5L+3s dance1/2 LH across, 1s/3s have continued turning to
    Lady on Man''s right _while_ 5s dance towards each other, pass LSh
9-12::
    5M dances out between 1s & cast to right to outside 4th place, 5L
    between 3s, casts right to outside 2nd place  _while_ 2s+4s dance
    1/2 RH across
13-16::
    5M+2s & 5L+4s dance 1/2 RH across & 5s turn partner LH to 5M facing
    1st place - 5L facing 3rd place _while_ 2s/4s continue turning to
    Lady on Man''s right
17-20::
    5M dances 1/2 reel of 3 up/dn with 3M+1L _while_ 5L 1/2 reel of 3
    with 1M+3L (start RSh to Man)
::
    5s end LSh to LSh facing sides (5M faces 4th place - 5L faces 2nd
    place)
21-24::
    5M dances 1/2 reel of 3 across with 2M+4L _while_ 5L dances 1/2 reel
    of 3 with 4M+2L (start RSh to Man), 5s end by turning RH to face
    each other (5M back to 3rd pl)
25-32::
    All set & 1/2 turn RH, each Man followed by partner dances into next
    couple''s place (5s to 1st place, 2s to 3rd place, etc…4s into
    centre) & all turn 2H. End 5 1 2 3 4(in centre)', 0);
INSERT INTO 'dancecrib' VALUES (9208, '2016-06-16 22:42:02.955204+00', '2023-02-04 01:21:07.082814+00', 12953, 3, NULL, 'ace', '1-8::
    1s cast (2s step up), 1/2 turn LH to face down, cross down LH
    through 3s & cast up to 2nd place
9-16::
    Diag. R&L (3) 1 (2)
17-20::
    »Cross & Link for 3«:  1s cross RH & face in as corners set, then
    all »link« to form lines across (persons on Left pass through
    middle)
21-24::
    1s cross LH & face in as corners set, then all reverse link (persons
    on Right pass through middle) to finish on sides  2 1 3
25-32::
    1s 1/2 turn 2H, dance up, cast to 2nd place opp sides, cross RH to
    own side & face out ready to repeat

{{explanation}}
Note:	Start of new couple''s turn, original 1s cast as 4s step up', 0);
INSERT INTO 'dancecrib' VALUES (6229, '2013-08-21 08:31:20.864325+00', '2023-02-04 01:21:07.095064+00', 3963, 3, NULL, 'ace', '1-8::
    1s lead down & 3/4 turn RH to 1L facing down, 1M up, set, retain
    hold of RH & 1L turns under ptnrs right arm, 1L followed by 1M dance
    up
9-16::
    1s dance RH across with 2L, 1s dance LH across with 3M to end facing
    1st corners
17-24::
    1s dance 1/2 reel of 4 with 1st corners, pass RSh to face 2nd
    corners. 1s dance 1/2 reel with 2nd corners, end in 2nd place opp
    side facing down
25-32::
    3s+1s+2s dance 1/2 Grand Chain (pass 3 persons); retain RH with 3rd
    person & turn once round to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14733, '2022-04-01 00:20:34.411595+00', '2023-02-04 01:21:07.118197+00', 14501, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back, to face 2M (2s step up 3-4)
9-16::
    1s set to 2M & 1s+2M dance RH across, 1s end facing 2L; 1s set to 2L
    & 1s+2L dance LH across. 1s end in middle 2nd place opp sides facing
    down
17-24::
    2s+1s+3s dance 6 bar mirror reels of 3 on sides (1s dance down/out,
    2s out/down, 3s out/up to start), Bars 23-24 1s cross to 2nd place
    own side
25-32::
    All circle 6H round & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12089, '2019-08-30 09:54:33.122663+00', '2023-02-04 01:21:07.128092+00', 19076, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up) & dance 1/2 Fig 8 (1M up round 2s, 1L down
    round 3s)
9-12::
    1s dance 1/2 RSh reels of 3 across (1L+2L & 1M+3M pass RSh), flowing
    into …
13-16::
    2s+1s+3s dance 1/2 LSh reels of 3 on own sides (1M up, 1L down). Bar
    16 1s 1/2 turn RH, retain hands & join LH with 1st corners (pstn)
17-24::
    1s+corners Bal-in-Line, 1/2 turn corner LH; Corners 1/2 turn RH
    _while_ 1s set. 1s 1/2 turn corners LH and 1s pass RSh to face 2nd
    corner (pstn)
25-32::
    1s dance 1/2 diag reel of 4 with 2nd corners; 1s end dancing in,
    pull back RSh to face partner (1M facing down between 2s, 1L facing
    up between 3s), set & turn 3/4 RH to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12645, '2020-03-02 01:53:13.101805+00', '2023-02-04 01:21:07.139833+00', 13917, 3, NULL, 'ace', '1-8::
    1s cross LH & face down (2s face up), 1s+2s dance "La Baratte":
::
    _3-4_   Man 1/2 turns opposite Lady RH & retains hand but at arm''s
    length from each other
::
    _5-6_   Man retraces steps with Lady turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies original
    place) & releasing Ladies RH she turns under Mans left arm until
    almost in original places
::
    _7-8_   Couple change places LH to finish in each other''s place
9-16::
    _9-10_    2M+1L & 2L+1M set
::
    _11-14_  2M+1M chase 1/2 round anticlockwise to change places
    _while_ 2L+1L 1/2 turn RH, face each other, pull back RSh & dance
    out to side having changed places  1 (2) 3
::
    _15-16_  1M+2M turn 3/4 LH to end BtoB in centre (1M facing up, 2M
    down) _while_ 1L+2L chase 1/4 anticlockwise into centre (1L facing
    2M, 2L facing1M)
17-24::
    2L+1M+2M+1L dance 3/4 reel of 4 (6 bars), turn partners 3/4 RH, 2s
    end in 1st place own side, 1s facing 1st corners
25-36::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s meet again in
    middle (2nd place opposite sides)
37-40::
    3s+2s chase clockwise 1/2 round to own side _while_ 1s turn 1.1/2 RH
    to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13261, '2020-10-16 00:20:50.676903+00', '2023-02-04 01:21:07.150888+00', 17312, 3, NULL, 'ace', '1-8::
    1s+4s dance in, touch NH, cast down/up (2s+3s step up/down); 1L+4L
    also 1M+4M dance RSh round each other on sides, 1L+4L face down,
    1M+4M face up
9-16::
    1L+4L also 1M+4M dance Alternating Tandem RSh reels of 3 on sides
17-24::
    2s+1s also  4s+3s Set+Link; 1s+2s also 3s+4s change places RH on
    sides & all set
25-32::
    1s+4s chase anticlockwise 1/2 round; 4s+1s 1/2 turn LH, pull back
    LSh & dance out to own side.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14000, '2021-05-03 00:20:31.568887+00', '2023-02-04 01:21:07.161004+00', 18383, 3, NULL, 'ace', '1-8::
    1M+2M+3M clap _while_ 1L+2L+3L dance round partner RSh, face partner
    & pull back RSh to dance back to place, all 3 couples set
9-16::
    2s dance »Figure of Love« (two inverted hearts):
::
    2L crosses up and casts down 1 place _while_ 2M crosses down and
    casts up 1 place.
::
    2s meet in the middle, touch both hands and twirl (pull back LSh)
::
    2L casts off (behind 3M) and crosses back to original place, _while_
    2M casts up (behind 1L) and crosses back to place
17-24::
    1s set advancing, pass RSh & face each other, turn 2H (about 3/4
    turn), 1L turns under 1M''s Left arm & 1L casts behind 2M _while_ 1M
    casts behind 2L (2s step up); 1s meet in second place, in the
    middle, dance LSh around each other & swivel left to face 1st
    corners
25-32::
    1s set to & turn 1st corner; set to & turn 2nd corner
33-40::
    Reels on opposite sides (1s LSh to 1st corners). 1s dance RSh around
    each other and swivel right to face their 1st corner
41-48::
    1s dance »Hello-Goodbye« setting, all clap & 1s Petronella turn to
    2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6362, '2013-08-21 08:31:23.058874+00', '2023-02-04 01:21:09.211913+00', 708, 3, NULL, 'ace', '1-8::
    1s cross down to dance reel of 3 on opposite sides
9-16::
    1s+3s dance Men''s Chain (up/down)
17-24::
    1s set, cast 1 place on opposite sides & turn RH 1.1/2 times to own
    sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (3990, '2013-08-21 08:30:40.930609+00', '2023-02-04 01:18:26.186854+00', 12867, 3, NULL, 'ace', '1-8::
    All set & turn 2H to face down, 1s dance down _while_ 2s & 3s cast
    up & follow, on bar 8 all turn in to face up
9-16::
    All dance up, cross & cast to partners original place, all set &
    cross RH
17-24::
    1s set, cast 1 place, dance down, cast up 1 place & all dance in
    for…
25-32::
    All dance Allemande to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6232, '2013-08-21 08:31:20.891631+00', '2023-02-04 01:21:07.198464+00', 12526, 3, NULL, 'ace', '1-8::
    1L followed by partner casts 1 place & crosses to opposite side,
    2s+1s circle 4H round to left & end in prom hold facing each other
9-16::
    2s+1s set, 2s set _while_ 1s retire 1 place & 3s cast up 1 place to
    face 1s in prom hold, 2s+1s+3s set, 2s+3s set _while_ 1s retire 1
    place & 4s cast up 1 place to face 1s in prom hold
17-24::
    All set & retire to sides, all Adv+Ret (with 1s 1/2 turning 2H after
    the advance)
25-32::
    All dance RSh reel of 4 on sides', 0);
INSERT INTO 'dancecrib' VALUES (6233, '2013-08-21 08:31:20.901677+00', '2023-02-04 01:21:07.303236+00', 3972, 3, NULL, 'ace', '1-8::
    1s dance full Fig of 8 round 2s
9-16::
    1s set twice & turn 2H twice
17-24::
    1s lead down the middle & back to face 1st corners
25-32::
    1s set & turn 1st corners, set & turn 2nd corners
33-40::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners, 1s
    cross to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13262, '2020-10-16 00:20:51.005544+00', '2023-02-04 01:21:07.462257+00', 3973, 3, NULL, 'ace', '1-8::
    1s dance in & cast (2s step up); 2s+1s+3s set twice (PdeB coupé)
9-16::
    2s+1s+3s dance interlocking 1/2 diag reels of 4 with 1st then 2nd
    corners (1s RSh to 1st corner to start, 2s+3s dance 1/2 LH across in
    centre)
17-24::
    1s join RH in centre, LH with 1st corner & Bal-in-Line; 1s turn 3/4
    RH, Bal-in-Line with 2nd corners & 1s turn RH to face up in centre
25-32::
    1s cross up & cast into reels of 3 on own side (2s & 3s cast down/up
    bar 25 to start reel).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6235, '2013-08-21 08:31:20.916334+00', '2023-02-04 01:21:07.50233+00', 10301, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 2s
9-16::
    1s dance LSh reels of 3 across (Lady with 2s & Man with 3s)
17-24::
    1s dance RH across (Lady with 2s & Man with 3s), pass RSh to dance
    LH across with other couple
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6236, '2013-08-21 08:31:20.924641+00', '2023-02-04 01:21:07.528683+00', 3978, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    2s+3s dance RH across to end facing corners, all set & turn facing
    person RH 1/2 way
17-24::
    1s+4s dance LH across to end facing corners, all set & turn corners
    to end on sides (1M & 2M also 3L & 4L by RH, others LH)
25-32::
    1s+2s also 3s+4s dance the Knot with 1s+4s changing places on sides
    during bars 27-28 to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6237, '2013-08-21 08:31:20.93317+00', '2023-02-04 01:21:07.561406+00', 3979, 3, NULL, 'ace', '1-8::
    1s & 5s dance in join nearer hands, dance round left & cast into
    centre, 1M+2s & 5L+4s dance LH across as 1L+3s+5M dance RH across
9-16::
    1s+5s in prom hold dance round clockwise 1/2 way to change places as
    3s turn LH, 5s cross up between 2s & cast 1 place (on own sides) as
    1s cross down between 4s & cast up 1 place (on own sides) as 3s turn
    RH.  2 5 3 1 4
17-24::
    5s+3s+1s reels of 3 on sides (3M dances up RSh to 5M & 3L dances
    down RSh to 1L)
25-32::
    2s+5s also 1s+4s dance double Fig of 8  with end couples casting to
    start
33-40::
    Bottom 4 couples (5s+3s & 1s+4s) dance 1/2 R&L & cross RH to own
    sides with 5s+4s changing places LH on sides', 0);
INSERT INTO 'dancecrib' VALUES (13905, '2021-04-05 00:20:39.169067+00', '2023-02-04 01:21:07.588712+00', 9019, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 2s cross to opp side

1-8::
    1s+2s dance Petronella in Tandem, set; repeat, 2s remain on sides,
    1s advancing to end BtoB between 2s
9-16::
    1s+2s dance reel of 4 across, 1s pass RSh to end 1L followed by 1M
    facing 2M
17-32::
    1s dance 1/2 diagonal Alternating Tandem reels of 3, RSh to 2M (1st
    corner diagonal); RSh to 3M (2nd corner diagonal): RSh to 2M (1st
    corner diagonal); RSh to 3M (2nd corner diagonal). 1s end in 2nd
    place opp sides. 2 (1) 3)
33-40::
    1s+3s dance Petronella in Tandem, set; repeat, 3s remain on sides,
    1s advancing to end BtoB between 3s
41-48::
    1s+3s dance reel of 4 across, 1s pass RSh to end in 3rd place own
    side.  2 (3) 1', 0);
INSERT INTO 'dancecrib' VALUES (6238, '2013-08-21 08:31:20.941538+00', '2023-02-04 01:21:07.606858+00', 3980, 3, NULL, 'ace', '1-8::
    1s in prom hold (Lady on Man''s left) dance reel of 3 with 2s (RSh to
    2M) & end facing 3M
9-16::
    1s dance reel with 3s (RSh to 3M) ending with 1s dancing into centre
    facing Men''s side
17-24::
    1M casts up & 1L dn into centre & dance out Ladies'' side, 1M cast up
    & 1L dn to end 1M b''tw''n 2s facing dn & 1L+3s face up as 2s+3s dance
    R&L
25-32::
    2s+1s+3s set twice, 1s turn RH 1.3/4 times to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6239, '2013-08-21 08:31:20.951507+00', '2023-02-04 01:21:07.723752+00', 3986, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across for 3 steps, LH across for 5 steps to end 1s
    on Men''s side & 2s on Ladies side
9-16::
    1s+2s slip step across (1s passing below 2s), set (using inside foot
    first), slip step back to centre (2s below 1s), 1/4 turn & retire to
    orig pl PdB
17-24::
    1s cast 1 place, turn RH, 1s lead up as 2s cast, 2s turn RH
25-32::
    1s+2s set, cross RH & dance 1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (6240, '2013-08-21 08:31:20.961618+00', '2023-02-04 01:21:07.743124+00', 3987, 3, NULL, 'ace', '1-8::
    1s lead down the middle for 2 steps, set, lead up to top, cross &
    cast to 2nd place
9-16::
    1s dance RH across (Man with 2s & Lady with 3s), 1s pass RSh & dance
    LH across with other couple, end facing 1st corners
17-24::
    1s set & turn 1st corners 2H, set & turn 2nd corners
25-32::
    1s dance reels of 3 on opposite sides (LSh to 1st corners to start)
    ending with 1s crossing LH to 3rd place as 3s dance up', 0);
INSERT INTO 'dancecrib' VALUES (9016, '2015-11-30 08:59:59.497943+00', '2023-02-04 01:21:07.765173+00', 16779, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of 8 round 2s & end
    facing 1st corners
9-12::
    Taking RHs with corner (who stand) twirl clockwise to 2nd place opp
    sides (changing to LH as corners stand), all set on the sides with
    hands (1 bar) then retaining hands with the 2nd corners 1s set
    advancing in to face them.
13-16::
    Repeat 9-12 to end 1s facing 3rd corner
17-20::
    Repeat 9-12 to end 1s facing 4th corner
21-24::
    1s dance 1/2 diagonal reel of 4 with 4th corners & pass RSh to face
    1st corner
25-32::
    1s dance 1/2 reel of 4 with 1st corners & chase clockwise 1/2 way. 2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (6242, '2013-08-21 08:31:21.093004+00', '2023-02-04 01:21:07.969109+00', 3989, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 2s end facing
    1st corners
9-16::
    1s turn 1st corner RH to 1M between 3s, 1L between 2s & 1s set to
    partner (up/down). 1s turn 2nd corner LH to 1M between 2s, 1L
    between 3s & 1s set to partner (up/down)
17-24::
    All dance DoSiDo with opposite person turning onto own sides 1s
    ending in 2nd place
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6253, '2013-08-21 08:31:21.234267+00', '2023-02-04 01:21:09.970126+00', 4068, 3, NULL, 'ace', '1-8::
    1s+2s set twice & dance RH across 1/2 way
9-16::
    1s+2s set twice & dance LH across back to places
17-24::
    1s lead down the middle, back to top & cast to 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (11704, '2019-03-18 21:02:29.452305+00', '2023-02-04 01:21:07.986676+00', 17471, 3, NULL, 'ace', '1-8::
    2s Petronella turn & set, 2s Petronella & set to just outside side
    lines & set _while_ 1s+3s Petronella & set
9-16::
    1s+2s+3s dance a Weasel Reel:
::
    1s+3s dance part reel of 4 up/down middle but when reaching either
    end they dance clockwise to top/bottom to re-enter reel _while_ 2s
    dance clockwise to replace the dancer leaving the reel & all end
    where they started
17-24::
    1s & 3s set and Petronella turn to opposite sides. 1L+2L reverse
    Set+Link _while_ 1M+2M Set+Link.  2s face out.
25-32::
    2s+1s+3s dance reels of 3 on sides, 1L+3L pass RSh,1M+3M pass LSh
    each couple crossing up from 2nd place to 1st place on own side.

{{explanation}}
Note - (Weasel Reel - Men always reel down middle & dance up Men''s side while Ladies always reel up middle & dance down Ladies'' side)', 0);
INSERT INTO 'dancecrib' VALUES (6243, '2013-08-21 08:31:21.101786+00', '2023-02-04 01:21:08.003519+00', 3994, 3, NULL, 'ace', '1-8::
    1L+2L+3L advance & 1L followed by 2L+3L cast to 3L+2L+1L, 1M+2M+3M
    advance & 3M followed by 2M+1M cast up to face partner
9-16::
    3s+2s+1s set, 3s & 1s cross RH, cast passing by LSh on sides & cross
    RH _while_ 2s turn 2H twice round
17-24::
    1s cast 1 place, turn 2H, dance down & cast up behind 3s to face 1st
    corners
25-32::
    »Hello-Goodbye setting« - 1s set to 1st corners, set to partner, set
    to 2nd corners, petronella turn to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (14534, '2022-01-10 02:19:59.316723+00', '2023-02-04 01:21:08.023511+00', 17969, 3, NULL, 'ace', '1-8::
    1s dance down & out between 3s & 4s, dance round 4s, out between 3s
    & 4s, up behind 3s to 2nd place (2s step up 3-4)
9-16::
    2s+1s+[3s with 4s in tandem] dance Mirror reels of 3 on sides, 2s
    out/down, 1s in/up, [3s followed by 4s] out/up. Bars 15-16: [3s+4s]
    don''t finish reel but curve into place, 4s to 3rd place, 3s to 4th
    place.  2 1 4 3
17-24::
    2s+1s also 4s+3s dance RH across & LH across back
25-30::
    1L followed by 4L & 4M followed by 1M chase anticlockwise to finish
    2 (4) (1) 3
31-32::
    4s+1s cross LH with partner to own side. 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12868, '2020-06-03 16:26:55.618654+00', '2023-02-04 01:21:08.045919+00', 3997, 3, NULL, 'ace', '1-8::
    1s+4s set on sides, 1L+4M cast down/up (2L/3M step up/down 3-4),
    2s+1s also 4s+3s dance RH across
9-16::
    1M+2L also 3M+4L set, 1M+4L cast down/up (2M/3L step up/down), 2s+1s
    also 4s+3s dance LH across to finish in centre
17-20::
    1M followed by 2M+2L+1L cross to Ladies'' side, down to 4th place,
    cross to Men''s side up to 3rd place (join hands as each dancer
    crosses to Ladies'' side to form circle) _while_
::
    4L followed by 3L+3M+4M cross to Men''s side, up to 1st place, cross
    the dance to Ladies'' side  joining hands to form circle (1M+dancers
    pass in front of 4L+ dances) 3 4 1 2
21-24::
    3s+4s also 1s+2s dance 4H round to left to finish on sides
25-30::
    All turn 3/4 2H to end in line in centre of dance facing partners (L
    facing down & M up), 3s+2s continue to turn 3/4 2H to opp sides &
    set _while_ 4s+1s dance 1/2 reel of 4, at end 1L+4M pass LSh
31-32::
    3s+2s cross RH to own sides _while_ 1s+4s turn 3/4 2H to own sides.
    End 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (6244, '2013-08-21 08:31:21.110108+00', '2023-02-04 01:21:08.066035+00', 8505, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1L+2M also 3M+4L change places RH, set diagonally & dance RH across
    once round
9-16::
    1M+2L also 3L+4M change places LH, set diagonally & dance LH across
    once round
17-24::
    1s & 4s chase clockwise 1/2 way to 4s in 2nd place & 1s in 3rd
    place, all set on sides, 2s & 3s cross RH _while_ 4s & 1s 1/2 turn
    RH to face up/down
25-32::
    4s dance up & cast to 2nd place own side _while_ 1s dance down &
    cast up to 3rd place on opp side & all set twice.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (9210, '2016-06-16 22:42:03.112662+00', '2023-02-04 01:21:08.125656+00', 16287, 3, NULL, 'ace', '1-8::
    1s+2s dance the Bourrel (Birl).  1s end facing out in 2nd place
9-16::
    _6_ bar reels of 3 on sides (1M+2M & 1L+3L pass RSh to start).  Bars
    15-16 1s meet, turn RH to finish in 2nd place opp sides, 1L facing
    out/up, 1M out/down
17-24::
    _6_ bar reels of 3 on sides (1M+3L & 1L+2M pass RSh to start).  Bars
    23-24 1s meet, turn 3/4 RH to finish in 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6245, '2013-08-21 08:31:21.118362+00', '2023-02-04 01:21:08.155701+00', 7814, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, set & cross RH
9-16::
    1s+3s dance double Fig of 8 with 1s casting & 3s crossing up to
    start
17-24::
    2s+1s+3s dance reels of 3 on sides with 1s dancing out & down to
    start
25-32::
    1L+2s & 1M+3s dance RH across, 1s cross LH & 2s+1s+3s set
33-40::
    1L+3s & 1M+2s dance RH across, 1s cross LH & 2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (13263, '2020-10-16 00:20:51.594512+00', '2023-02-04 01:21:08.186031+00', 16046, 3, NULL, 'ace', '1-8::
    1s cast (2s step up), 1s turn RH (4 bars) & cast back up to top (2s
    step down)
9-16::
    1s+2s dance "Rosette": 1s+2s 1/2 turn partner RH, join hands in
    circle & set; 1s+2s pull back RSh & chase clockwise 1/2 round. 2 1 3
17-24::
    1s set to & turn 1st corner RH; set to & turn 2nd corner RH. 1s end
    2nd place opp sides, 1M facing down, 1L facing up
25-32::
    Reels of 3 on sides (6 bars) Bars 31-32 1s cross RH to own side.  2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (9211, '2016-06-16 22:42:03.128661+00', '2023-02-04 01:21:08.218763+00', 16850, 3, NULL, 'ace', '1-4::
    1s+2s set, dance RH across 1/2 way and face on sides
5-8::
    2s+1s+3s dance 1/2 RSh reel of 3 on sides (2M & 3L dance loops at
    end of reel)
9-16::
    1s+2s set, dance RH across 1/2 way and face on sides.  3s+2s+1s
    dance 1/2 reel of 3 on sides to original places with 1M facing out
17-24::
    1L dances down middle followed by 1M (casts round 2M to start) &
    dance Fig 8 round 3s (1L round 3M, 1M round 3L to start) 2s step up
    19-20
25-32::
    1s+3s dance R&L  & take nearer hands ready to start again', 0);
INSERT INTO 'dancecrib' VALUES (6246, '2013-08-21 08:31:21.126468+00', '2023-02-04 01:21:08.250382+00', 10898, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s cross down RH between 2s & cast to top
9-16::
    1s+2s dance LH across, 2s cross up LH & cast to 2nd place
17-24::
    1s+2s set twice & turn LH 1.1/2 times ready for…
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (6247, '2013-08-21 08:31:21.135096+00', '2023-02-04 01:21:08.279903+00', 14234, 3, NULL, 'ace', '1-4::
    1M+3M pass RSh turning right & passing RSh change places with 4M/2M
    as 4M+2M pass RSh turning right to…
5-8::
    2M/4M with 1L/3L dance 1/2 Ladies Chain (giving LH in passing &
    turning LH at end)
9-12::
    1L+3L pass LSh turning left & passing LSh change places with 4L/2L
    as 4L+2L pass LSh turning left to…
13-16::
    2L/4L with 4M/2M dance 1/2 Men''s Chain (giving RH in passing &
    turning RH at end).  4 3 2 1
17-24::
    1s+3s dance RH across & chase 1/2 way to change places.  4 1 2 3
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13418, '2020-12-02 01:20:39.8799+00', '2023-02-04 01:21:08.310149+00', 19160, 3, NULL, 'ace', '1-8::
    1s cast (2s step up) turn 3/4 RH; 1s cast LSh round 1st corner to
    2nd place opp sides, cross RH & face out
9-16::
    2s+1s+3s dance RSh reels of 3 on sides (1M up, RSh to 2M, 1L down,
    RSh to 3L), 1s pass LSh to opp sides
17-24::
    2s+1s+3s dance LSh reels of 3 on sides (1M up, LSh to 2L, 1L down,
    LSh to 3M), 1s pass RSh to own sides facing out
25-32::
    1s dance behind own lines to 4th place _while_ 3s+4s circle 4H round
    to left moving up 1 place; all 4 couples turn partner RH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13877, '2021-04-05 00:18:30.788698+00', '2023-02-04 01:18:33.131972+00', 257, 3, NULL, 'ace', '{{title}}
Figure 1

1-8::
    All circle 8H round & back
9-12::
    All Ladies dance into centre, turn to face partner & set
13-16::
    All turn partners to finish Ladies in centre facing partner
17-24::
    All dance double reels of 4 across the dance to end in original
    places
25-48::
    Repeat bars 1-24 with Men in centre

{{title}}
Figure 2

1-8::
    Ladies dance 4H round & back
9-12::
    1L+2L also 3L+4L set & turn
13-16::
    1L+4L also 2L+3L set & turn
17-20::
    Ladies dance 1/2 RH across
21-24::
    Ladies set & turn opposite man
25-28::
    Ladies dance 1/2 LH across to face partner

{{title}}
Figure 3

1-8::
    1s+3s advance to 1/2 turn opposite dancer 2H, retire & 1/2 turn
    partner
9-16::
    2s+4s repeat bars 1-8
17-24::
    All dance double Ladies'' chain
25-28::
    1s+3s Allemande back to original places
29-32::
    2s+4s repeat bars 25-28

{{title}}
Figure 4

1-8::
    Ladies dance RH across (partners on their left) in St Andrews Cross
    formation, change to Men dancing LH across in centre back to places
9-16::
    All set & turn corners, then set & turn partners
17-32::
    All dance Grand Chain (2 bars to each hand)', 0);
INSERT INTO 'dancecrib' VALUES (9017, '2015-11-30 08:59:59.594193+00', '2023-02-04 01:21:08.352289+00', 16536, 3, NULL, 'ace', '1-8::
    1s+3s dance 6 bars R&L (Men polite turns) to finish in centre B-to-B
    with partner facing side couples (1L+2L, 1M+4M, 3L+4L, 3M+2M). All
    set
9-16::
    Reels of 4 across.  Finish in line up/down with Ladies (in middle)
    facing, 1M facing down, 3M facing up
17-24::
    Reel of 4 (1L+3L pass RSh) All pass LSh at ends, RSh in middle.
    Finish in original places facing partners
25-32::
    All set, all turn partner RH 1.1/4 (4 bars) into promenade hold &
    dance 1 place anticlockwise.  2 3 4 1

{{explanation}}
Repeat from new positions in Strathspey then twice in Reel time back to original places', 0);
INSERT INTO 'dancecrib' VALUES (6347, '2013-08-21 08:31:22.870082+00', '2023-02-04 01:21:08.564544+00', 4014, 3, NULL, 'ace', '1-8::
    All dance reels of 4 on sides
9-16::
    With hands joined on sides set with Highland steps
17-24::
    1M+2L, 3M+4L change places passing RSh (no hands), partners repeat
25-32::
    1M+2L, 3M+4L turn RH 1.1/2 times back to original places, partners
    repeat to end BtoB facing partners
33-40::
    1s+2s also 3s+4s dance diagonal reels of 4 ending with 1L, 2M, 3L,
    4M dancing in front of 2L, 1M, 4L, 4M respectively
41-48::
    Picking up Fig: 1M dances across to 1L, link left arms, set twice &
    on 2nd setting 1M turns left about to link nearer arms with 1L, 1s
    dance across to 2M, Men link left arms, set twice & 1s+2M with
    retaining linked arms turn left about on second setting with Men
    changing to link nearer arms (3s & 4M dance the similarly at the
    same time)
49-56::
    Picking up Fig: 1s+2M dance across with linked arms to link left
    arms with 2L, set twice & on 2nd set 2L turns left about to link
    nearer arms with  2M, all 4 (facing out) now turn left about to face
    down (Men in middle) & end above 3s+4s who have similarly danced
57-64::
    All Ladies cast to end behind Men & set, all Men cast to end beside
    partner to form new lines of 4 (Ladies in middle), all set
65-72::
    Ladies 4 slip steps to left _while_ Men slip step to right, all set
    & repeat back to places & set
73-80::
    Ladies turn to face partner & dance reels of 4 across set
81-88::
    Set twice to partners & turn 2H back to place
89-96::
    All petronella turn & set, petronella turn & set to change places
    with partners
97-104::
    All set to partners Men with Highland steps
105-112::
    Ladies set twice & twice facing down _while_ 2M followed by 1M (also
    4M followed by 3M) dance up round 2L/1L (or 4L & 3L) & to stand on
    left of their partners
113-120::
    1s+2s, 3s+4s Allemande (all facing the bottom with 2s & 4s leading)
    ending on bar 6 to ''whisper'' & retire to partner''s place', 0);
INSERT INTO 'dancecrib' VALUES (13758, '2021-03-02 01:20:47.680144+00', '2023-02-04 01:21:08.739693+00', 13380, 3, NULL, 'ace', '1-8::
    1s+3s Petronella turn into the centre and set. 1s+3s dance 1/2 reel
    of 4 up/down middle
9-16::
    3s+1s (facing up/down in the centre) set to & 3/4 turn partner 2H,
    retain hands & 3s+1s dance 1/2 Poussette
17-24::
    1s+2s dance 1/2 RH across, cross RH; 1s+3s dance 1/2 LH across,
    cross LH
25-32::
    2s+3s+1s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (6348, '2013-08-21 08:31:22.878237+00', '2023-02-04 01:21:08.77634+00', 4015, 3, NULL, 'ace', '1-8::
    2s dance full diagonal Reels of 4 with 1st corners, passing by the
    LSh to face 2nd corners
9-16::
    2s dance full diagonal Reel of 4 with 2nd corners to end in original
    places
17-24::
    All dance Snowball Grand Chain for 3 cples to end 3 (2) 1:
::
    1s cross RH & change places LH on side with 2s
::
    1s change places RH with 3s _while_ 2s cross over RH
::
    1s cross LH _while_ 2s & 3s change places LH.  3 (2) 1
25-32::
    3s+2s (top 2 couples) dance 1/2 R&L, 3s dance 1/2 Fig of 8 round end
    couples (3M up & 3L down) to end in 2nd place own side 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6349, '2013-08-21 08:31:22.884069+00', '2023-02-04 01:21:08.798859+00', 12089, 3, NULL, 'ace', '1-8::
    2s & 4s dance diagonal reels of four with 1st corners & end dancing
    LSh round partner to face 2nd corners
9-16::
    2s & 4s dance diagonal reels of four with 2nd corners & ending in
    original places
17-24::
    All dance a Cumulative Grand Chain:
::
    _17-20_  1s+3s cross RH & face down, 1s+2s also 3s+4s change places
    on the sides LH
::
    _21-24_  2s cross RH as 1s+4s also 3s+5s change places RH on the
    sides, 2s+4s also 1s+5s change pls LH on sides as 3s cross LH.
    4(2)5(1)3
25-32::
    4s+2s also 1s+5s dance 1/2 R&L, 4s+5s dance 1/2 Figs of 8 (Men up,
    Ladies down).  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (3729, '2013-04-17 12:51:19.909551+00', '2023-02-04 01:21:08.819261+00', 14812, 3, NULL, 'ace', '1-6::
    1s & 3s dance LSh reels of 3 across (1M LSh to 2L also 3L LSh 2M to
    start)
7-8::
    2L dances to the top, pulls RSh back to face down _while_ 1''s curve
    in  to face up NHJ _while_ 2M dances down pulls RSH back to face up
    _while_ 3''s curve in to face down NHJ.
9-16::
    All set & dance 1/2 RH across, 1s & 3s continue turning back to
    place as 2s meet turning LH back to original positions & all set
17-24::
    All circle 6H round & back
25-32::
    All set & cross RH, all chase clockwise back to own sides to end 3 2
    1
33-40::
    2s+1s dance the Knot to end 3 1 2', 2);
INSERT INTO 'dancecrib' VALUES (3991, '2013-08-21 08:30:40.936285+00', '2023-02-04 01:18:26.211992+00', 129, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH moving down to 2nd place, set, cross LH, cast round
    4th corner into middle to face 1st corner
9-16::
    1s dance RSh reels of 3 across (1L with 2s & 1M with 3s) & end
    facing 1st corners
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh & dance
    1/2 reel with 2nd corners to end in 2nd place on opposite side
25-32::
    1s dance down below 3s, cast up to 2nd place, 3s+1s+2s dance 1/2
    Grand Chain (2s in 3rd place, cross to start)', 0);
INSERT INTO 'dancecrib' VALUES (6350, '2013-08-21 08:31:22.90045+00', '2023-02-04 01:21:08.839653+00', 4022, 3, NULL, 'ace', '1-8::
    1M & 3L turn RH 1.1/2 times to change places _while_ their partners
    chase anticlockwise to face them; 1L & 3M turn LH 1.1/2 times to end
    in centre with LH joined _while_ their partners chase clockwise to
    join RH with partner in line of 4 down in centre
9-16::
    1s & 3s Bal-in-Line _while_ 2s change places by 2M dancing under
    arch made by 1s as 2L dances under arch made by 3s, 2s set twice
    _while_ 1s & 3s turn RH 1.1/4 times to end on opposite sides facing
    out
17-24::
    1s+2s+3s dance RSh reels of 3 on sides
25-32::
    1s+2s+3s set, 1s+2s dance RH across 1/2 way _while_ 3s 1/2 turn RH,
    2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6351, '2013-08-21 08:31:22.954765+00', '2023-02-04 01:21:08.867989+00', 4005, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    1s+3s dance in & Bal-in-Line, turn partners RH & 1s cast to 3rd
    place _while_ 3s lead up to 1st place
9-16::
    2s+4s dance in & Bal-in-Line, turn partners RH & 2s lead down to 4th
    place _while_ 4s cast up to 2nd place.  3 (4) 1 (2)
17-24::
    3s+4s also 1s+2s dance double Fig of 8  (1s & 4s cross down/up to
    start)
25-28::
    4s+1s set & 1/2 turn partners RH
29-32::
    4M followed by 1L dance up through top couple & cast to 3rd/2nd
    places Men''s side _while_ 1M followed by 4L dance down through end
    couple & cast up Ladies'' side to 2nd/3rd places.  3 (1) 4 (2)', 0);
INSERT INTO 'dancecrib' VALUES (6352, '2013-08-21 08:31:22.968261+00', '2023-02-04 01:21:08.892032+00', 4023, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-4::
    1s & 4s dance 1/2 Fig of 8 round next couples
5-8::
    1L also 4L cross diag to dance out between 2s & 3s, cast to right &
    cross to other side _while_ partners follow to end at other end of
    set (opposite partner)
9-16::
    All dance reel of 4 on sides
17-20::
    2M & 3M dance out & cast round end dancer, dance across set & cast 1
    place on other side as ptnrs follow - crossing & casting to R - but
    dance down/up 1 pl on opp side to ptnr, when 2M & 3L also 3M & 2L
    approach each other they pass RSh & Lady turns in behind passing Man
    (not her ptnr)
21-24::
    3M & 2M (followed by 2L/3L) dance up/down between end couples, cast
    to right & dance into original places
25-32::
    4s+2s also 3s+1s dance Tourbillon :
::
    4s+2s also 3s+1s 1/2 turn prtnrs 2H, 4M/2L also 3M/1L lead prtnrs 1
    pl cl''wise to end 4s/3s on Ladies side & 2s/1s on Men''s side, 4s/3s
    set to 2s/1s
::
    All 1/2 turn prtnrs 2H, 4L/2M also 3L/1M lead prtnrs on 1 pl to end
    2s/1s in 1st/3rd pl & 1s in 2nd/4th pl & all cross RH to own sides
    to end 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (14001, '2021-05-03 00:20:33.171857+00', '2023-02-04 01:21:08.916138+00', 4024, 3, NULL, 'ace', '1-4::
    1s+2s set advancing to face up NHJ, 1s lead up & cast to 2nd place
    _while_ 2s lead up and curve into 1st place
5-8::
    1s+3s repeat.  2 3 1
9-16::
    1s followed by 3s lead up to top, cast, meet & lead down. 1s cast up
    around 3rd place into 2nd place, 3s curve into 3rd place
17-20::
    2s+1s circle 4H round to left opening into line of 4 up/down middle
    facing partner (2M 2L 1M 1L)
21-24::
    2s+1s dance 1/2 reel of 4 (pass partner RSh to start), at end of
    reel pass partner RSh again & face partner joining 2H ready for …
25-32::
    1s+2s dance a »Philabeg«:
::
    _25-28_  1s+2s turn 2H, 1s dance down diagonally to Mens side
    _while_ 2s dance diagonally up to Ladies side & 1s+2s all 3/4 turn
    2H
::
    _29-32_  1s dance down diag into middle _while_ 2s dance diag up
    into middle & all 3/4 turn 2H, 1s+2s pass partner RSh & dance out to
    own sides to own sides.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6248, '2013-08-21 08:31:21.168499+00', '2023-02-04 01:21:08.950055+00', 4032, 3, NULL, 'ace', '1-8::
    1s set, cast & dance RH across with 3s
9-16::
    1s set, cast up & dance LH across with 2s
17-24::
    1s followed by 2s dance down, cast up behind 3s, in & dance up to
    top & 1s cast back to 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6356, '2013-08-21 08:31:23.000522+00', '2023-02-04 01:21:08.993172+00', 9753, 3, NULL, 'ace', '1-8::
    1s & 3s cast down & dance down outside of set turn outwards & dance
    back to place, 2s & 4s face up
9-16::
    All dance RSh reels of 4 on sides
17-24::
    All circle 8H round & back
25-32::
    All set, 1s+2s also 3s+4s dance 1/2 RH across; All set, 1s+4s dance
    1/2 LH across _while_ 2s & 3s cross to own side. 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6358, '2013-08-21 08:31:23.024532+00', '2023-02-04 01:21:09.134451+00', 4044, 3, NULL, 'ace', '{{title}}
Part A

1-8::
    1s+3s set, advance & dance RH across
9-16::
    1s+3s dance LH across & turn partners RH into 2 diagonal lines of 4
    (1M, 2L, 3M, 4L in own places facing partners)
17-24::
    1s+2s also 3s+4s set, advance & dance RH across
25-32::
    1s+2s also 3s+4s dance LH across & turn partners RH into original
    places
33-40::
    2s+4s set, advance & dance RH across
41-48::
    2s+4s dance LH across & turn partners RH into 2 diagonal lines of 4
    (1L, 2M, 3L, 4M in own places facing partners)
49-56::
    1s+4s also 2s+3s set, advance & dance RH across
57-64::
    1s+4s also 2s+3s dance LH across & turn partners RH into 2 diagonal
    lines (1L, 2M, 3L, 4M in own places facing partners)

{{title}}
Part B

1-8::
    All dance diagonal reels of 4
9-16::
    All set twice to partners & turn 2H to end in original places
17-24::
    All dance 1/2 Grand Chain & turn Tulloch hold
25-32::
    All dance 1/2 Grand Chain & turn Tulloch hold

{{title}}
Part C

1-8::
    1s turn RH into Allemande hold facing out (4 bars); 2s repeat to end
    behind 1s
9-16::
    3s repeat to end behind 2s, 4s repeat to end of line
17-32::
    All prom hold dance round clockwise into circle (1 springing PdB
    forward, 1 back & 2 skip change steps forward (4 times)

{{title}}
Part D

1-8::
    1s cross hands & spin to original place in square (4 bars); 2s
    repeat
9-16::
    3s repeat, 4s repeat, as each couple dances to place they wave
    farewell to others.  All end with a farewell wave.', 0);
INSERT INTO 'dancecrib' VALUES (6359, '2013-08-21 08:31:23.03274+00', '2023-02-04 01:21:09.154167+00', 4278, 3, NULL, 'ace', '1-8::
    2s & 3s dance out ends & cast back to place, 2s+3s dance LH across
    1/2 way then 1s+3s also 2s+4s dance RH across 1/2 way.  3 (1)(4) 2
9-16::
    All dance RSh reels of 4 on sides but 1s+4s end passing RSh.  3
    (1)(4) 2
17-24::
    4M+1L change pl RH & 4L+1M change pl RH, 1s+4s dance RH across
    _while_ 3s+2s chase clockwise 1/2 way & cross RH to own sides.  2 4
    1 3
25-32::
    1s+3s change places LH on sides & 3s turn RH, 4s+3s change places on
    sides LH & 3s turn RH, 4s+3s change places on LH on sides', 0);
INSERT INTO 'dancecrib' VALUES (15311, '2022-12-19 01:18:30.24017+00', '2023-02-04 01:18:33.402108+00', 21165, 3, NULL, 'ace', '1-4::
    1s+2s & 3s+4s dance 1st 4 bars of Tourbillon:
::
    All 1/2 turn partner 2H, 1M+2L & 3M+4L lead partner by nearer hand 1
    pl clockwise to end 1s+3s on Ladies'' side & 2s+4s on Men''s side, all
    set.
5-8::
    1s+2s & 3s+4s circle 4H round to left, finishing facing own partner.
9-16::
    All dance RSh reels of 4 on sides, passing own partner RSh to begin.
17-20::
    All dance 1/2 Grand Chain (1 bar/hand), finish facing own partner
    1/2 way round set.
21-24::
    3s+4s & 1s+2s dance 2nd 4 bars of Tourbillon.
::
    All 1/2 turn partner 2H, 4M+3L & 2M+1L lead partner 1 pl clockwise,
    all cross RH to opp sides. (3) (4) (1) (2)
25-28::
    2s dance up to top and curve into place (3s+4s+1s step down 27-28).
    (2) (3) (4) (1)
29-32::
    All set and cross RH with partner. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6360, '2013-08-21 08:31:23.040866+00', '2023-02-04 01:21:09.166105+00', 4046, 3, NULL, 'ace', '1-8::
    1s+4s set diagonally, 1M+4L 3/4 turn RH & cast up/down own side back
    to place _while_ 1L+4M cast down/up own side & 3/4 turn RH back to
    place
9-16::
    All dance reels of 4 on sides, ending as at start of reel
17-24::
    2s & 3s turn 1s & 4s RH into a St Andrew''s Cross, all set & turn
    crnrs to end 1s in 3rd pl & 4s in 2nd pl on own sides having passed
    other crnr RSh
25-32::
    1s & 4s set & cross over (Ladies dancing between Men) & dance 1/2
    Fig of 8 round end couples to 3rd/2nd places (giving RH at top, LH
    at bottom)', 0);
INSERT INTO 'dancecrib' VALUES (13181, '2020-09-15 00:20:35.591523+00', '2023-02-04 01:21:09.179935+00', 18502, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reels on own sides
17-24::
    1s+2s Set+Link, 1s+3s Set+Link 2 3 1
25-32::
    All turn partner 1/2 RH to finish in middle facing partner, all set,
    pull back RSh & curve out to opp sides. All cross RH to own sides 2
    3 1', 0);
INSERT INTO 'dancecrib' VALUES (8604, '2015-02-13 12:47:59.096785+00', '2023-02-04 01:21:09.228837+00', 15404, 3, NULL, 'ace', '1-4::
    1s+3s cross down (no hands) into centre back to back facing opp.
    sides (2s+4s step up) & all take hands and set (as »extended« double
    triangles)
5-8::
    1s+3s dance out opp. sides, and cast (Ladies up/Men down), dance
    into middle (1M+3L pass RSh) & pass partners RSh to face 2nd corners
9-12::
    1s+3s dance 1/2 diagonal reels of 4 with 2nd corners & pass partners
    RSh to face 3rd corners (pstns)
13-16::
    1s+3s repeat bars 9-12 with 3rd corners finishing facing 4th corners
    (pstns)
17-20::
    1s+3s repeat bars 9-12 with 4th corners finishing facing 1st corners
    (pstns)
21-24::
    1s+3s repeat bars 9-12 with 1st corners (pstns), take prom. hold
    with ptnrs (Lady above Man) 1s facing Ladies side, 3s facing Men''s
    side
25-28::
    1s cast to face 2M (in 5M place) as 3s cast up to face 5L (in 1L
    place)
29-32::
    3s+5L+5M (Ladies side) & 1s+2L+2M (Men''s side) dance 1/2 reels of 3
    on sides (3s+5L, 1s+2M pass LSh to start)
33-36::
    3s+4L+5M (at top) & 1s+4M+2L (at bottom) dance 1/2 reels of 3 across
    (3s+4L, 1s+4M pass RSh to start)
37-40::
    5M+2M (Men''s side) & 5L+2L (Ladies side) dance path of 1/2 reels of
    3 on sides as 3s cast down (passing 2M LSh) to face 4M (in 5M place)
    and 1s cast up (passing 5L LSh) to face 4L (in 1L place)
41-44::
    1s+4L+2L (Ladies side) & 3s+5M+4M (Men''s side) dance 1/2 reels of 3
    on sides (1s+4L, 3s+4M pass RSh to begin) finishing 1s+3s in line in
    middle, Men facing down, Ladies facing up)  2 1 4 3 5
45-48::
    1s+3s turn 3/4 RH to face own sides, 1s cast to 3rd place as 3s cast
    to 5th place (4s+5s step up)  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (6365, '2013-08-21 08:31:23.099312+00', '2023-02-04 01:21:09.255785+00', 7570, 3, NULL, 'ace', '1-4::
    1s+2s set & 1M+2L 3/4 turn RH to 2M/1L places _while_ 1L+2M cast 1
    place down/up
5-8::
    1L+2M 3/4 turn RH _while_ 1M+2L cast down/up to original places &
    set advancing
9-16::
    1s+2s dance Poussette
17-24::
    1s+3s dance double Fig of 8 (1s cross down to start)
25-32::
    2s+1s+3s dance reels of 3 on sides (1s in & up to start)', 0);
INSERT INTO 'dancecrib' VALUES (13182, '2020-09-15 00:20:35.689845+00', '2023-02-04 01:21:09.279083+00', 15217, 3, NULL, 'ace', '1-8::
    1s cast, dance Fig of 8 (taking hands when possible) on own sides.
    Bar 7 1s cast to 2nd place (2s step up)
9-12::
    2s+3s Adv+Ret _while_ 1s advance, 1/2 turn 2H, retire to opp sides.
13-24::
    2s+1s+3s dance 12 bars of R&L for 3 Couples:
::
    _13-14_  All 3 couples cross RH with dancer opposite
::
    _15-16_  Dancers in 1L place & 3M place change places diagonally LH
    _while_ other couples change places LH on side
::
    _17-24_  Repeat bars 1-4 from new places 2 more times with 1s
    finishing back to back facing 1st corners.
25-28::
    1s set to corners then to partner ''Hello-Goodbye'', 1s turn RH to
    face 2nd corners
29-32::
    Repeat bars 25-28 with 2nd corners to finish in 2nd place facing out
    ready to begin again 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6368, '2013-08-21 08:31:23.125438+00', '2023-02-04 01:21:09.438083+00', 4052, 3, NULL, 'ace', '1-8::
    1s set, cast to 2nd places, set & cast into lines of 3 across (Lady
    up Man down)
9-16::
    2s+1s+3s set advancing up/down, 2s+3s retire as 1s set turning right
    about to opposite sides (Lady between 2M+3M & 1M between Ladies),
    2s+1s+3s set advancing, 2s+3s retire as 1s set turning right about
    to face 1st corners
17-24::
    1s set to 1st corners turning to face partner, set (turning) to face
    2nd corners, 1s set to 2nd corners turning to right to face partner
    & set (up/down)
25-32::
    1s dance reels of 3 across (Man LSh with 2L & Lady RSh with 3L), 1s
    end in centre & turn RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6366, '2013-08-21 08:31:23.105471+00', '2023-02-04 01:21:09.457191+00', 4008, 3, NULL, 'ace', '1-8::
    1s cross out through sides cast down & dance up centre, 1L dances RH
    across with 2s & 1M dances LH with 3s & all end prom hold
9-16::
    All dance full reel of 3 across set (1s pass 2s RSh to start)
17-24::
    1s dance out through side couples (1M through 3s, 1L through 2s) &
    cast back to places, all turn partners LH (1s turn 1.1/2 times)
25-32::
    1s+3s dance 1/2 R&L, 3s+2s dance 1/2 R&L all ending 1 place round
    anticlockwise with 2s at top', 0);
INSERT INTO 'dancecrib' VALUES (10009, '2017-07-13 22:49:21.822063+00', '2023-02-04 01:18:26.236821+00', 17881, 3, NULL, 'ace', '1-8::
    1s dance Fig. 8 on own sides (1s dance in/down to start) giving
    hands when poss. 1s end in centre 1st place, 2s step in, ready for…
9-16::
    1s+2s dance Poussette
17-24::
    1s dance Diag R&L with 2s+3s.  1s finish 2nd place own sides, 1M
    facing up/out, 1L down/out
25-28::
    1M dance up behind  3L (in 1M place), across top of set, casts to
    2nd place opp. sides. 1L dances down behind 2M (in 3L place),
    across, casts into 2nd place opp. sides
29-32::
    1s turn LH 1.1/4 to face 1st corners (3rd corners pstn)
33-40::
    1s dance 1/2 Diag. reel of 4 with 1st corners, pass RSh, dance 1/2
    Diag. reel of 4 with 2nd corners   2 1 3', 1);
INSERT INTO 'dancecrib' VALUES (6367, '2013-08-21 08:31:23.115445+00', '2023-02-04 01:21:09.604383+00', 4051, 3, NULL, 'ace', '1-8::
    1s lead down the middle, lead back to face 1st corners
9-16::
    1s set to 1st corners & dance a full diagonal reel of 4 with 1st
    corners (1s end facing 2nd corners)
17-24::
    1s set to 2nd corners & dance a reel of 4 with 2nd corners (1s end
    in middle)
25-32::
    1L dances RH across with 2s _while_ 1M dances RH across with 3s then
    LH across to places', 0);
INSERT INTO 'dancecrib' VALUES (6249, '2013-08-21 08:31:21.178629+00', '2023-02-04 01:21:09.675499+00', 7454, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 4 on own sides (1s & 3s in & down to
    start)
9-16::
    1s+2s also 3s+4s dance double Fig of 8  (1s & 3s crossing down)
17-24::
    All turn partners 2H & dance DoSiDo
25-32::
    1s turn 2H, dance down, turn 2H, dance down & cast into 4th place as
    2s+3s+4s dance up', 0);
INSERT INTO 'dancecrib' VALUES (10835, '2018-06-11 00:36:40.894864+00', '2023-02-04 01:21:09.702127+00', 4057, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 1s+2s dance 1/2 RH across _while_ 3s cross RH;
    2s+1s+3s set, 2s & 3s cross RH _while_ 1s Petronella turn to face
    1st corners
9-16::
    1s+1st corners dance 1/2 diag reel of 4, as 1s meet, pull back RSh
    to face 4th corners; 1s+4th corners dance 1/2 diag reel of 4, 1s
    meet, pull back RSh to face 3rd corners (pstn)
17-24::
    1s+3rd corners dance 1/2 diag reel of 4, as 1s meet, pull back RSh
    to face 2nd corners (pstn); 1s+2nd corners dance 1/2 diag reel of 4,
    1s meet, pull back RSh to face 1st corners (pstn)
25-32::
    1s dance reels of 3 on opp sides (LSh to 1st corner to start) &
    cross RH to 2nd place own side bars 31-32

{{explanation}}
1s cross RH to 4th place end of 2nd time through', 0);
INSERT INTO 'dancecrib' VALUES (6250, '2013-08-21 08:31:21.187892+00', '2023-02-04 01:21:09.719311+00', 4058, 3, NULL, 'ace', '1-8::
    1s dance down below 3s, cast up to 2nd place, dance up between 2s &
    cast to 2nd place own side
9-16::
    1s Adv+Ret with 1st corners & dance DoSiDo with 1st corners
17-24::
    1s repeat with 2nd corners
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6251, '2013-08-21 08:31:21.196464+00', '2023-02-04 01:21:09.850213+00', 4063, 3, NULL, 'ace', '1-8::
    1s lead down below 3s cross & cast up to 2nd place opposite sides,
    2s+1s+3s Adv+Ret (1 step) & circle 6H round to left 1/2 way.  (3) 1
    (2)
9-12::
    1s cross RH & cast round 1st corner (pstn) to end 1L between 3s (at
    top) & 1M between 2s
13-16::
    All Adv+Ret (up/down for 1 step) & circle 6H round to left 1/2 way
17-20::
    1s advance setting passing LSh to face 1st corners & turn corners 2H
    to end between 2s/3s _while_ 2s+3s set diagonally in
21-24::
    1s advance setting passing LSh to face 2nd corners & turn corners 2H
    to end 2nd place opposite sides _while_ 2s+3s set diagonally in.
    (2) 1 (3)
25-32::
    1s dances reels of 3 on opposite sides (LSh to 1st corner to start)
    & cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6252, '2013-08-21 08:31:21.206495+00', '2023-02-04 01:21:09.885824+00', 4064, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s+2s+3s cross passing RSh & cross back passing RSh (some editions
    have cross RH & cross back RH)
17-20::
    1s+2s+3s turn 2H moving down to face 1st corners _while_ 2s turn 2H
    & cast up to 1st place & 3s turn 2H to 3rd place
21-24::
    1s set to 1st corner & set to 2nd corner
25-32::
    1s dance reels of 3 on opposite sides, 1s giving RSh to 2nd corners
    & 1s cross RH back to own sides', 0);
INSERT INTO 'dancecrib' VALUES (9380, '2016-10-06 07:18:36.671276+00', '2023-02-04 01:21:09.943781+00', 17326, 3, NULL, 'ace', '1-12::
    1s dance Figs of 8 on own sides (between 2s to start) & end in own
    places
13-16::
    1s+2s also 3s+ 4s dance 1/2 Poussette & turn to 1s+2s facing up,
    3s+4s facing down.  2 1(3)(4)
17-24::
    1s+2s dance Allemande (up) as 3s+4s dance Allemande (down) ending
    with all dancers curving right to original places.  1 2 3 4
25-32::
    1s+2s dance RH across 1/2 way then 1s+3s dance LH across 1/2 way,
    1s+4s dance RH across 1/2 way & all cross RH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6254, '2013-08-21 08:31:21.242644+00', '2023-02-04 01:21:09.985693+00', 4070, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 reels of 3 across (Lady with
    2s & Man with 3s)
9-16::
    1s lead down below 3s, cast up to 2nd place own sides & 1s+3s dance
    1/2 Ladies'' Chain
17-24::
    All circle 6H round to left for 2 bars (1s at top), Men 3/4 turn
    partner 2H into centre (3 pointed star) & Ladies dance LH across
    1.1/3 times _while_ Men chase once round clockwise to meet partner
    (in same position as at bar 17)
25-32::
    All turn RH (2s at top & 1s+3s into line across (1M+3L BtoB facing
    partners), all set, 2s turn RH (4 bars) _while_ 1s+3s dance 1/4 RSh
    reel of 4 & turn partners RH to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6255, '2013-08-21 08:31:21.250906+00', '2023-02-04 01:21:10.019296+00', 4073, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across 1/2 way, change places with partners RH &
    circle 4H round to left ending on sides
9-16::
    2s+1s dance LH across 1/2 way, change places with partners LH, set &
    1s cast to 2nd place as 2s dance up
17-24::
    1s in prom hold dance reel of 3 across with 2s giving RSh to 2L to
    start & 1s end dancing up centre & face down as 2s dance in
25-32::
    1s+2s dance the Rondel', 4);
INSERT INTO 'dancecrib' VALUES (15312, '2022-12-19 01:18:30.266735+00', '2023-02-04 01:18:33.453961+00', 20749, 3, NULL, 'ace', '{{title}}
Strahspey

1-8::
    1s+2s dance Tourbillon:
::
    1s & 2s 1/2 turn ptnrs 2H, 1M & 2L lead ptnrs by nearer hand 1 place
    cl''wise (end 1s on Ladies'' side & 2s Men''s side), 1s set to 2s
::
    1s & 3s 1/2 turn ptnrs 2H & lead ptnrs clockwise to end 2s in 1st
    place & 1s in 2nd place then both cross RH to own sides  2 1 3
9-12::
    1L+2s & 1M+3s dance RH across
13-24::
    2s+1s+3s dance R&L for 3 couples
25-32::
    2s+1s+3s dance 6H round & back

{{title}}
Reel

{{explanation}}
Repeat 1-32 in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (6256, '2013-08-21 08:31:21.259108+00', '2023-02-04 01:21:10.043643+00', 10163, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+4s set, cast in 1 place & dance 1/2 R&L
9-16::
    All dance RSh reels of 4 on sides
17-24::
    4M+1L also 4L+1M slip step to opposite sides (Ladies pass BtoB), set
    & slip step back (Men pass BtoB) & set _while_ 2s & 3s advance
    setting, slip step down/up (Ladies pass BtoB), set & slip step back
    (Men pass BtoB)
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6257, '2013-08-21 08:31:21.26769+00', '2023-02-04 01:21:10.074412+00', 14943, 3, NULL, 'ace', '1-8::
    All set & 2s+3s dance 1/2 RH across, 3L & 2L pass partners RSh &
    chase clockwise (crossing set above the 4s) to opposite sides to
    face new partners
9-16::
    1s & 4s turn partner RH & cast into middle, 1s& 4s dance 1/2 fig 8
    round end couples
17-24::
    All set & 1s+4s dance1/2 RH across, 1L & 4L cross passing partners
    RSh & chase clockwise crossing below top couple to own sides having
    changed partners.
25-32::
    All circle 8H round for 6 steps & set in a square set (3M/2L at top
    facing dn, 3L/2M at bottom facing up, 1L/4L in 2nd place & 4M/1M in
    4th place)
33-36::
    Top & bottom couples advance & dance RH across 1.1/4 round
37-40::
    2M followed by 3M dance out Men''s side (between other Men) & cast
    right to top of set _while_ 2L followed by 3L dance out Ladies'' side
    (between other Ladies) & cast  right to bottom of set
41-48::
    All Men chase clockwise 3 steps (2M leading) _while_ all 4 Ladies
    advance 2 small steps towards centre, pull back RSh. All join RH
    with partner & dance clockwise round into longwise set & all turn
    partners RH (2 3 4 1)', 0);
INSERT INTO 'dancecrib' VALUES (6258, '2013-08-21 08:31:21.381649+00', '2023-02-04 01:21:10.111205+00', 4075, 3, NULL, 'ace', '{{explanation}}
2 x 3 couple sets arranged end-to-end 1 2 3 (3) (2) (1)       (2nd set numbered 4,5, 6 in this crib)

1-8::
    All clap Ladies dance around partner RSh to face partner, all set &
    Ladies turn right about & dance back to places
9-16::
    All clap & Men repeat bars 1-8
17-24::
    1s & 6s dance down/up towards each other & dance RH across 1/2 way,
    dance to other end of set & cast 2 places.  2.3.6(1)(4)(5)
25-32::
    6s & 1s turn RH then turn LH (in last repetition all turn RH & LH)

{{explanation}}
Alternative (by Wes Glindinning) Bars 25-32: All circle 12H round & back  
Repeat x2 to finish in original positions but in opposite set', 0);
INSERT INTO 'dancecrib' VALUES (6259, '2013-08-21 08:31:21.391988+00', '2023-02-04 01:21:10.183578+00', 13357, 3, NULL, 'ace', '1-8::
    1s+2s set & 1s cross down (no hands) to Double Triangle positions as
    2s cast up, 2s+1s+3s set & 1s 3/4 turn 1st corners RH
9-16::
    1s dance 1/2 LSh reels of 3 across (1L with 2s, 1M with 3s) into RSh
    half reels of 3 on own sides & 1s pass LSh to face 1st corner pstns
17-24::
    1s dance 1/2 reel of 4 with corners & pass RSh to face 2nd corner
    pstnsd, 1s dance 1/2 reel of 4 with corners & end 2nd place own
    sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6260, '2013-08-21 08:31:21.470269+00', '2023-02-04 01:21:10.332833+00', 13113, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Double Fig of 8  (1s/4s cross dn/up) & end
    2s/3s dancing up/dn to 1st/4th places as 1s & 4s dance in to face
    dn/up
9-16::
    1s+4s dance the Rondel & end in middle 4s facing up & 1s facing down
17-24::
    2L+4L also 1M+3M turn RH 1.1/2 times as 2M+4M & 1L+3L turn LH 1.1/2
    times, 4s+2s also 3s+1s Set+Link to end 2 4 1 3
25-32::
    All dance RSh reels of 4 on sides', 0);
INSERT INTO 'dancecrib' VALUES (13309, '2020-11-02 01:20:46.417767+00', '2023-02-04 01:21:10.368126+00', 17626, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Inveran Reels, finishing with 2s and 3s in middle of
    the set 2H joined
9-16::
    1s set with 1M turning to face out, casts and dances down behind
    Men''s side followed by 1L to 3rd place opp. side  and set
::
    _while_ 2s+3s dance Poussette figure with both couple dancing out to
    Ladies side and moving up the set.  2 3 (1)
17-20::
    1s change place with 3s (1L+3M LH, 1M+3L RH) to finish 1s in centre
    BtoB in Double Triangle position. All set
21-22::
    All set advancing, pull back RSh to invert Double Triangle (do not
    take hands)
23-24::
    1s set as 2s+3s pull back RSh & dance RSh round partner to finish on
    opp sides
25-32::
    2s+1s+3s dance Set+Link for 3 couples twice to finish on own sides.
    3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6261, '2013-08-21 08:31:21.480618+00', '2023-02-04 01:21:10.396565+00', 4082, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s turn LH 1.3/4 times to end BtoB in
    middle facing 3rd corner (pstn) _while_ 2s+3s chase clockwise 1/2
    way
9-16::
    1s set to corners & dance 1/2 diagonal reel of 4 with 3rd corners
    into 1/2 reel of 3 on own sides (LSh to 4th corner pstn) to end
    facing 3rd corner (pstn)
17-24::
    1s repeat bars 9-16 but end facing each other (1L facing down to
    partner).  2 1 3
25-32::
    1s set & 3/4 turn 2H to 2nd place opposite sides _while_ 2s+3s dance
    1/2 R&L, all dance Grand Chain 1/2 way.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6262, '2013-08-21 08:31:21.490714+00', '2023-02-04 01:21:10.515074+00', 4086, 3, NULL, 'ace', '1-8::
    1s turn RH, cast to 3rd place, turn LH & cast back up to top
9-16::
    1s cross down to dance reflection reels of 3 on opposite sides (1s
    end facing 1st corners)
17-24::
    1s set to 1st corners, set to 2nd corners & turn RH 1.1/2 times to
    end 2nd place own sides
25-32::
    1s dance 1/2 reels of 3 across 1L with 2s & 1M with 3s, turn LH to
    2nd place opposite sides
33-40::
    1s dance 1/2 reels of 3 with same couples & turn RH to 2nd place own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (6263, '2013-08-21 08:31:21.499199+00', '2023-02-04 01:21:10.54621+00', 4087, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Espagnole:
::
    _1-2_   1s+2s also 3s+4s cross (Ladies lead across RH passing
    between Men) with Ladies changing places RH
::
    _3-4_   1s+2s & 3s+4s cross back (Men lead across RH between Ladies)
    with Men changing places RH to end 2 1 4 3 5
::
    _5-8_   2s, 4s & 5s turn RH as 1s & 3s turn LH & end facing 2nd
    corners
9-16::
    1s & 3s dance Pass+Turn with 2nd corners, turn RH & face 1st corners
    for Pass+Turn ending own sides in 2nd & 4th places
17-24::
    All set, 2s+1s+4L also 4M+3s+5s circle 5H round to Left, dance into
    centre & turning to right dance out to places.  2 1 4 3 5
25-32::
    1M+4L also 3M+5L change places RH & all set _while_ 1L+4M also 3L+5M
    set & change pl RH, 1M+4L also 3M+5L change places LH & cast (Ladies
    up & Men down) _while_ 1L+4M also 3L+5M set & cross to own sides to
    end 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (6264, '2013-08-21 08:31:21.508164+00', '2023-02-04 01:21:10.576999+00', 10063, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All dance 1/2 Grand Chain, set to partner & turn 2H
9-16::
    1s+3s circle 4H round to left for 3 bars & turn to right to face
    sides (BtoB with partner), 1M+3L+2s also 1L+3M+4s dance RH across
17-24::
    All dance parallel RSh reels of 4 across & end with 1s & 3s (LH to
    partners) dancing out to original places
25-40::
    2s & 4s repeat dancing reels of 4 up/down set
41-48::
    All set to partners, 1s+3s 3/4 turn RH to face clockwise in prom
    hold & dance round to opp places _while_ 2s & 4s petronella turn,
    set & return to pl
49-56::
    Repeat with 2s & 4s turning into prom hold
57-64::
    All Set+Link with partner travelling on 1 place, repeat back to
    original places

{{title}}
Reel

1-8::
    All set to partner, 3/4 turn RH into prom hold & dance 1/2 way round
    set
9-16::
    All dance Double Ladies Chain
17-24::
    All set to partner, 3/4 turn RH into prom hold & dance 1/2 way round
    set back to places
25-32::
    All dance Double Men''s Chain 1s & 3s retaining prom hold facing
    right
33-40::
    1s dance RSh Promenade reel with 4M/2L _while_ 3s dance RSh
    Promenade reel with 4L & 2M
41-48::
    1M+3L dance Figs of 8 round 2s _while_ 1L+3M dance Fig of 8 round 4s
49-56::
    4M+2L dance Figs of 8 round 1s _while_ 4L+2M dance Figs of 8 round
    3s & end with 2s & 4s in prom hold with partner
57-64::
    2s dance RSh reel of 3 with 1M & 3L _while_ 4s dance RSh reel of 3
    with 1L & 3M & end all turning partners RH', 0);
INSERT INTO 'dancecrib' VALUES (6266, '2013-08-21 08:31:21.528415+00', '2023-02-04 01:21:10.810792+00', 2387, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s & 2s set, turn 2H & open out & circle 4H round
9-16::
    1s & 2s dance the Slip Knot (usual Knot but end by passing Lady in
    front & dancing 1/2 LH across back to same places)

{{title}}
Reel

17-24::
    1s dance reel of 3 on Men''s side (1M & 2M pass LSh to start & Lady
    dances below 2M), Lady ends in own place with Men having changed
    places
25-32::
    1s dance reel of 3 on Ladies side (1L & 2L pass RSh to start & Man
    dances below 2L), 2s end in 1st place & 1s in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6267, '2013-08-21 08:31:21.538458+00', '2023-02-04 01:21:10.911964+00', 4100, 3, NULL, 'ace', '1-8::
    1M sets & casts to 2nd place as 2L sets & casts to top, 1L & 2M
    repeat this Fig to end in original places
9-16::
    1s pass LSh to dance RSh reel of 4 across with 2s, 1s ending in 2nd
    place
17-24::
    1s pass LSh to dance reel of 4 with 3s, 1s ending in 3rd place
25-32::
    3s+1s set, 1s cast to 2nd place, 2s+1s+3s turn partners 2H', 0);
INSERT INTO 'dancecrib' VALUES (8063, '2013-10-01 08:47:06.738591+00', '2023-02-04 01:21:10.940262+00', 14528, 3, NULL, 'ace', '1-8::
    1s & 4 s turn RH (2 bars) & cast down/up (2 bars), 1s+4s turn LH (2
    bars) & dance 3/4 LH across (2 bars) to end with Men at the top (4M
    facing 2M/ 1M facing 2L) Ladies at bottom (4L facing 3M/1L facing
    3L)
9-24::
    1s+4s dance "Mairi''s Wedding" reels round set (pass LSh in middle)
    _while_ 2s & 3s dance 2 diagonal reels of 4 dancing 1/2 LH across in
    middle. 1s+4s pass partner LSh at end to finish 1M facing 3M, 1L
    facing 3L, 4M facing 2M, 4L facing 2L
25-32::
    All dance Reels of 4 across & 1s+4s cross RH at end to 3rd/2nd
    places
33-40::
    2s+4s+1s+3s circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6268, '2013-08-21 08:31:21.546818+00', '2023-02-04 01:21:10.966504+00', 4102, 3, NULL, 'ace', '1-8::
    1s turn RH & cast to 2nd place (2s step up); 1s turn LH to face 1st
    corners
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners, 1s dance 1/2
    diagonal reel with 2nd corners
17-24::
    1s dance 1/2 diagonal reel with 3rd corner (pstns), 1/2 diagonal
    reel with 4th corner (pstns)
25-32::
    1s dance reel of 3 across (Lady with 2s, Man with 3s - LSh to 1st
    corner)
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6269, '2013-08-21 08:31:21.556916+00', '2023-02-04 01:21:11.076774+00', 4103, 3, NULL, 'ace', '1-8::
    1M+2M also 1L+2L set to each other on sides & change places RH,
    repeat Fig giving LH back to places
9-16::
    1s lead down for 3 steps & back to top, cross & cast to 2nd place
    opposite sides
17-24::
    2s+1s dance 1/2 R&L & dance 1/2 Ladies Chain
25-32::
    2s+1s dance 1/2 Men''s Chain (2s in 1st place & 1s in 2nd place
    opposite sides) & end turn partners RH to places (1s turn 1.1/2
    times)', 0);
INSERT INTO 'dancecrib' VALUES (6270, '2013-08-21 08:31:21.565363+00', '2023-02-04 01:21:11.103032+00', 9024, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, dance down between 3s & cast back to 2nd
    places own sides
9-16::
    1s dance RH across (Lady with 2s & Man with 3s) pass RSh & dance LH
    across with other couple to end facing Ladies side
17-24::
    1s dance out & cast (Man up Lady dn), meet in centre & dance out
    Men''s side, cast (Man up Lady dn) into centre & pass LSh to face
    up/dn
25-32::
    1L dances under 2s arch & casts to 2nd place own side _while_ 1M
    dances under 3s arch & casts to 2nd place, 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6271, '2013-08-21 08:31:21.576431+00', '2023-02-04 01:21:11.309001+00', 14021, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 1M followed by partner casts up & dances down middle
    to face 3L as 1L faces 2L
9-16::
    1s dance 1/2 LSh reels of 3 across, 1M followed by partner dances
    down & both cast up to 2nd place opposite sides.  (2)(1)(3)
17-24::
    1s dance 1/2 LSh reels of 3 on sides, 1s turn RH & twirl to face 1st
    corner (pstn) _while_ corners chase clockwise 1/2 way
25-32::
    1s dance Pass+Turn with corners & pass RSh to face 2nd corners, 1s
    dance Pass+Turn with corners & pass RSh to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6006, '2013-08-21 08:31:17.884241+00', '2023-02-04 01:21:11.330626+00', 3559, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 (Lady round 2s & Man
    round 3s)
9-16::
    1s set, turn 3/4 2H to end BtoB (1L facing up), 1s dance RH across
    (Lady with 2s & Man with 3s)
17-24::
    1s dance 1/2 LSh reel of 3 on own sides (1L gives LSh to 3L, 1M to
    2M) & 1/2 reels of 3 across set (1M gives RSh to 3L, 1L to 2M)
25-32::
    3s+1s+2s set, 3s dance in, cast 1 place & cross down to own place
    _while_ 1s lead up, cross & cast to 2nd place _while_ 2s dance in,
    cast up & cross to own side, 2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (6272, '2013-08-21 08:31:21.598355+00', '2023-02-04 01:21:11.360931+00', 4105, 3, NULL, 'ace', '1-8::
    1s cast 1 place, 1M+2L change places RH as 1L+2M set, 1L+2M change
    places RH as 1M+2L set, 1s+2s dance RH across 1/2 way to own sides
9-16::
    1M+3L change pl RH as 1L+3M set, 1L+3M change pl RH as 1M+3L set,
    1s+3s dance 1/2 RH across, 1L casts up & 1M down to end between
    2s/3s
17-24::
    2s+1s+3s adv up/down 2 steps, 2s & 3s retire as 1s petronella turn
    to sides, 2s+1s+3s adv, 2s & 3s retire as 1s petronella turn to
    ptnrs 2nd crnr
25-32::
    2s+3s dance reels of 3 across as 1s dance reels of 3 on opposite
    sides, 1s crossing back to own sides 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6273, '2013-08-21 08:31:21.606768+00', '2023-02-04 01:21:11.393258+00', 4106, 3, NULL, 'ace', '1-8::
    1s+2s 1/2 turn partners RH & dance RH across 1/2 way, 2s+1s full
    turn partner RH ending with 2s at top & 1s in 2nd place
9-16::
    2s+1s+3s dance reels of 3 on own sides (1L dances in & up as 1M
    dances in & down to start) & 1s end facing 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places
25-32::
    2s+1s+3s circle 6H round to the left for 6 steps, pivot & chase back
    to places', 0);
INSERT INTO 'dancecrib' VALUES (6274, '2013-08-21 08:31:21.615305+00', '2023-02-04 01:21:11.413744+00', 14689, 3, NULL, 'ace', '1-8::
    1s+3s Adv+Ret, set to partner & turn RH
9-16::
    1s+2s also 3s+4s dance diagonal reels of 4 passing partner RSh to
    start
17-24::
    Men dance Figs of 8 round partner & corner
25-32::
    1s+3s dance Mens Chain
33-40::
    2s+4s Adv+Ret, set to partner & turn RH
41-48::
    1s+4s also 2s+3s dance diagonal reels of 4 passing partner RSh to
    start
49-56::
    Ladies dance behind partners into centre to circle 4H round to left
    & retire by dancing LSh round partners
57-64::
    2s+4s dance Ladies Chain
65-72::
    Men dance RH across & turn partner LH
73-80::
    Ladies dance RH across & turn partner LH
81-96::
    All dance Grand Chain (2 bars per hand)', 0);
INSERT INTO 'dancecrib' VALUES (14425, '2021-11-06 01:12:08.786764+00', '2023-02-04 01:21:11.433706+00', 4110, 3, NULL, 'ace', '1-8::
    1s cross down to dance Fig of 8 round 3s & end in 2nd place own
    sides _while_ 2s dance up to top, down the middle & cast up to 1st
    place
9-14::
    1s set to 3s, 1s+3s set to partners, 1s set to 2s.  2 1 3
15-16::
    1s turn RH to face up _while_ 2s 1/2 turn RH to face down ready for
    Allemande
17-24::
    2s+1s dance Allemande (2s begin on left foot). On last 2 bars, 2s
    drop RH & turn LH into 2nd place 1 2 3
25-32::
    1s turn RH, 1s change places LH with 2s; 1s+3s turn RH, 1s turn
    partner LH to 2nd place own sides 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6275, '2013-08-21 08:31:21.625453+00', '2023-02-04 01:21:11.467956+00', 4111, 3, NULL, 'ace', '1-8::
    1s set, full turn RH & 1s+2s dance RH across once round
9-16::
    1s+3s dance double Fig of 8 round 2s (1s down to begin)
17-24::
    1s followed by 2s+3s+4s dance down the middle & back (with 2s+3s+4s
    separating), 1s end at top facing down & other couples facing up
25-32::
    All set (1s progressing down to bottom passing each couple LSh), all
    turn 2H
33-40::
    2s+3s also 4s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (14666, '2022-03-07 02:20:38.937269+00', '2023-02-04 01:21:11.49476+00', 16602, 3, NULL, 'ace', '1-4::
    1s cross RH, cast to 2nd place (2s step up bars 3-4).
5-16::
    2s+1s+3s dance 3 couple R&L to finish 1s facing 1st corners
17-24::
    1s & 1st corners set. 1s dance RSh round each other to face 2nd
    corners. 1s & 2nd corners set. 1s dance RSh round each other to 2nd
    place own sides. 2 1 3
25-32::
    All dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6276, '2013-08-21 08:31:21.631925+00', '2023-02-04 01:21:11.519562+00', 10109, 3, NULL, 'ace', '1-8::
    1s lead to bottom, cast behind 4s on own side, in front of 3s &
    behind 2s back to place
9-16::
    Men dance Rocking Step _while_ partners dance Glasgow Highlanders
    step
17-24::
    All set, cross Men making arch, repeat back to places
25-32::
    1s+2s dance 1/2 RH across, 1s+3s 1/2 LH across, 1s+4s 1/2 RH across
    & all cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6277, '2013-08-21 08:31:21.64536+00', '2023-02-04 01:21:11.562345+00', 14808, 3, NULL, 'ace', '1-8::
    1M sets to either 1L or 2L or 3L & casts 1 place, 1M turns either 1L
    or 2L or 3L RH & ends in 3rd place
9-16::
    1L sets to either 2M or 3M or 1M & casts down 1 place, 1L turns
    either 2M or 3M or 1M & ends in 3rd place
17-24::
    1L followed by prtnr casts up 1 place & crosses to opposite sides,
    1L with 2s or 3s dances LH/RH across as 1M with 3s or 2s LH/RH
    across
25-32::
    1L followed by prtnr casts down 1 place & crosses to own sides, all
    turn LH', 0);
INSERT INTO 'dancecrib' VALUES (6278, '2013-08-21 08:31:21.654129+00', '2023-02-04 01:21:11.586913+00', 4115, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Petronella to opposite sides (6 bars without final
    set) & cross RH
9-16::
    1s+2s dance RH across, 1s cast & turn LH to face 1st corners _while_
    2s lead up
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners & 1/2 reel with 2nd
    corners ending BtoB facing opposite sides
25-32::
    1s dance out turning about & dance across to 2nd place _while_ 2s+3s
    dance 1/2 R&L, 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (12407, '2019-12-05 01:30:54.807525+00', '2023-02-04 01:21:11.609231+00', 19784, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 1/2 turn partner RH; all set & 1/2 turn partner RH, 2s
    face out/up, 1s+3s face down/up
9-16::
    1s+2s+3s dance RSh reels of 3 on own sides, 1s end in centre 2nd
    place facing down, 2s in 1st place
17-24::
    2M+1M+3M dance RH across _while_ 2L+1L+3L dance LH across; 1s cross
    down through 2nd place, cast up behind 3s, dance up to 2nd in centre
25-32::
    2L+1M+3L dance RH across _while_ 2M+1L+3M dance LH across; 1s cross
    up through 2nd place, cast up behind 2s, dance down to 2nd place in
    centre, ending BtoB facing own sides
33-40::
    2s+1s+3s dance Double Triangles, 1s petronella turn (travelling
    step) to 2nd place own side. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6279, '2013-08-21 08:31:21.662694+00', '2023-02-04 01:21:11.629214+00', 4119, 3, NULL, 'ace', '1-8::
    1s set & 1/2 turn RH, set to 2s & turn with nearer hand
9-16::
    1s dance mirror reels of 3 on opp sides (1s in & down to start), on
    last bar 1s dance into double triangle position facing opposite
    sides
17-24::
    1s dance Double Triangles, ending with 1s turning to right to end
    with 1L between 3s facing up & 1M between 2s facing down
25-32::
    2s+1s+3s Adv+Ret & 1s 3/4 turn RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6280, '2013-08-21 08:31:21.670992+00', '2023-02-04 01:21:11.642552+00', 4120, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L dance down behind 1M+2M+3M & back up to place
9-16::
    1M followed by 2M+3M dance down behind 1L+2L+3L & back up to place
17-24::
    1s lead down the middle & back to top facing each other
25-32::
    1s join 2H & set twice to each other & cast to bottom (2s+3s+4s step
    up bars 7-8). End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6281, '2013-08-21 08:31:21.68111+00', '2023-02-04 01:21:11.763854+00', 4126, 3, NULL, 'ace', '1-8::
    1s+2s set twice & dance RH across to places
9-16::
    1s lead down, 1/2 turn RH & lead up to face 2s (1s BtoB in centre
    facing 2s who have stepped up), set & 1s face 1st corners
17-24::
    1s turn 1st corner RH, turn partner LH, turn 2nd corner RH & cross
    LH to 2nd place own sides
25-32::
    2s+1s+3s dance Grand Chain', 0);
INSERT INTO 'dancecrib' VALUES (6282, '2013-08-21 08:31:21.691537+00', '2023-02-04 01:21:11.783895+00', 13868, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, 1s turn RH to face 1st corner (pstn) _while_ 2s
    cross RH
9-16::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners 1s ending 2nd place opposite sides
17-24::
    2s+1s dance Men''s Chain & 1s end facing each other across set
25-32::
    1s dance 1/2 Figs of 8 (1L round 2s, 1M round 3s), all dance DoSiDo', 0);
INSERT INTO 'dancecrib' VALUES (9765, '2017-04-06 09:57:38.140981+00', '2023-02-04 01:21:11.791141+00', 8714, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All dance interlocking reels of 4 round the set
9-16::
    Men dance LH across 1/2 way, into centre & turn loop left to dance
    out opp place, Ladies repeat with 1/2 RH across & loop right to opp
    pl
17-24::
    3s+1s lead into centre, lead out (with opp partner) between side
    couples, cross & dance to meet partner & turn RH to orig places
25‑32::
    2s+4s repeat but turn partner RH 1.1/2 times

{{title}}
Reel

1-8::
    Men dance behind partner & next Lady, dance in to end BtoB facing
    the Lady just passed, all set & 1/2 turn RH
9-16::
    All dance double reels of 4 (Ladies giving LH in centre to start)
17-24::
    Ladies dance LH across once round & all turn RH 1.1/4 times to sides
    (Men now in new places with new partner)
25-32::
    All circle 8H round & back

{{explanation}}
Repeat three times to return to original places', 0);
INSERT INTO 'dancecrib' VALUES (15313, '2022-12-19 01:18:30.282449+00', '2023-02-04 01:18:33.493187+00', 21166, 3, NULL, 'ace', '{{explanation}}
Square set: Couples 1-4 in normal square, 5s & 6s inside square, 5s face 1s, 6s face 3s

1-8::
    5s & 6s dance reels of 3 with corner places, RSh to dancer to right
    ( 5M+1L+4M, 5L+1M+2L, 6M+2M+3L, 6L+3M+4L)
9-16::
    5s+6s dance RH across & LH across to end with couples in tandem
    (Lady following Man), 5M facing 4M, 6M facing 2M
17-24::
    5s+4+2L also 6s+2M+4L dance RSh tandem reels of 3 up/down set
25-32::
    1s+5s also 3s+6s dance Ladies'' Chain (Men cast to start). Bars 25-26
    & 29-30 Men pass LSh in centre. All end facing partner
33-40::
    Lines of 4 up/down (1M+5L+6M+3L & 1L+5M+6L+3M) also 2s & 4s on sides
    set, Adv+Ret (1 step each) twice & set
41-44::
    1s+5s also 3s+6s dance 1/2 R&L
45-48::
    1s+3s dance 1/2 R&L in centre _while_ 5s+2s+6s+4s set & dance 1
    place clockwise round to end  4 5 2 6 with 1s+3s in centre
::
    Repeat twice from new positions', 0);
INSERT INTO 'dancecrib' VALUES (14535, '2022-01-10 02:20:02.003898+00', '2023-02-04 01:21:11.826776+00', 17970, 3, NULL, 'ace', '1-6::
    1s+2s dance 6 bars of Chain progression:
::
    1s+2s 3/4 turn RH, 1M+2L turn LH 1.1/2 times as partners chase
    clockwise 1/2 way,
7-8::
    1s 3/4 turn RH to 2nd place facing clockwise _while_ 2s change
    places RH & 3s turn 3/4 RH. 2s & 3s remain in line up/down centre
    facing partner, Ladies facing down, Men facing up, ready for …
9-16::
    2s+1s+3s dance Weasel reels:
::
    2s+3s dance part reel of 4 up/down middle but when reaching either
    end they dance clockwise to top/bottom to re-enter reel _while_ 1s
    dance clockwise to replace dancer leaving the reel & all end where
    they started
17-24::
    1s set, cross RH, set & cross RH _while_ 2s+3s set, change places
    with partner RH, set & Petronella out to sides. 2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9388, '2016-10-06 07:18:39.861339+00', '2023-02-04 01:21:11.848463+00', 13872, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH.  Repeat back to places
9-16::
    1s turn RH, cast (2s step up), 1s dance 1/2 Fig 8 (1M round 3s, 1L
    round 2s)  2 (1) 3
17-24::
    1s dance 1/2 reels of 3 on opp sides (RSh to 2nd corner).  1s dance
    1/2 reels of 3 across (1M at top, 1L at bottom, LSh to 3rd corner
    pstn)
25-32::
    1s dance diag R&L  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6284, '2013-08-21 08:31:21.70868+00', '2023-02-04 01:21:11.87281+00', 12706, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on own sides (1s in & down to start)
9-16::
    1s+2s turn 1.1/2 times (1s turn between 2s), 1s cast down behind 3s
    & turn RH to face up in middle _while_ 3s step in to face down
17-24::
    3s+1s dance Half Rondel :
::
    3s dance down under the arch made by 1s who dance up, 1s+3s cross
    (Ladies cross in front of Men) & all cast to meet the other Lady or
    Man on the opp side & join nearer hands,  1s+3s set, cross LH
::
    ( 3s to own side & 1s end giving RH to 1st corners & LH to prtnr)
25-32::
    1s Bal-in-Line with 1st corners as 2nd corners set, 1s Bal-in-Line
    with 2nd corners as 1st corners set & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6285, '2013-08-21 08:31:21.717111+00', '2023-02-04 01:21:11.891591+00', 4133, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig of 8 (2s end facing out)
9-16::
    1s+2s+3s set; 1s+2s 1/2 turn on sides (Men RH & Ladies LH) _while_
    3s set, all 3 couples set, 1s+3s 1/2 turn on sides (Men LH & Ladies
    RH) _while_ 2s set
17-24::
    1s dance reels of 3 on sides (1s dancing in & up, 3s out & down to
    start) 1s end facing up between 3s who face down
25-28::
    1s+3s set, 3/4 turn on sides (Men LH, Ladies RH) to end on sides
    with 3s facing out
29-32::
    1s+3s set, turning about (Men pull back LSh, Ladies RSh), change
    hands, 1s+3s 1/2 turn (Men RH, Ladies LH)  to finish on sides , 3s
    facing out.   2 1 3 4  (On repeat 1s+3s turn once round, 1s end in
    4th place)', 1);
INSERT INTO 'dancecrib' VALUES (6286, '2013-08-21 08:31:21.727134+00', '2023-02-04 01:21:11.916598+00', 8506, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 R&L, 1s+4s dance 1/2 R&L
9-16::
    All dance RSh reels of 4 on sides & end facing up or down
17-24::
    All set & change places RH on sides, set to partner & 4s+2s dance
    1/2 RH across _while_ 3s+1s dance 1/2 LH across
25-32::
    4s lead up RH as 1s lead down LH, cross at top/bottom & cast to
    2nd/3rd place & all turn RH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8339, '2014-07-29 12:59:14.705985+00', '2023-02-04 01:21:11.940049+00', 4136, 3, NULL, 'ace', '1-8::
    1s+2s set, turn partners 2H, & dance  4H round to the left, back to
    place.
9-16::
    1s+2s Set+Link; 1s turn RH 1.1/2 to face 1st corners.
17-24::
    1s dance Corner Pass+Turn with 1st corners (corners turn RH) & pass
    RSh to face 2nd corners; dance Corner Pass+Turn with 2nd corners, 1s
    turn RH to finish facing partner in middle on own sides
25-32::
    1s Petronella turn to 1L between 2s facing down, 1M between 3s
    facing up; 1s set & turn RH 1.1/4 to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (13906, '2021-04-05 00:20:42.998903+00', '2023-02-04 01:21:11.976488+00', 18366, 3, NULL, 'ace', '1-4::
    1s cross down as 2s cast up, 1s+2s cross down as 3s cast up to 1st
    place. 3 (2) 1
5-8::
    3s+2s cross down as 1s cast up to 1st place, 1s+3s cross down as 2s
    cast up to 1st place.  2 (1) 3
9-12::
    1s set advancing, turn 3/4 RH to face 2nd corner (pstn) _while_
    2s+3s set (up/down) & change places RH on sides
13-16::
    1s+2nd corners (pstn) set & turn 2H
17-24::
    1M+3s (at top) & 1L+2s (at bottom) dance 1/2 LSh reels of 3 across;
    3s+1s+2s dance 1/2 RSh reels of 3 on sides (1M down/in, 1L up/in).
    (2) 1 (3)
25-32::
    2s & 3s Petronella turn, dance 1/2 LSh reel of 4, turn partner 3/4
    LH to own sides. 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (13386, '2020-12-02 01:18:27.387129+00', '2023-02-04 01:18:26.293581+00', 19146, 3, NULL, 'ace', '1-8::
    1M sets advancing to partner, 1/2 turns partner 2H, 1s (1L on 1M''s
    right) + 2L circle 3H round to left & face down (1M in middle)
9-16::
    1s+2L dance down middle & back up, pull back RSh (2L returns to
    place)
17-24::
    1s cross RH, cast (2s step up); 2s+1s turn partner RH
25-32::
    1s cross RH & face down, 1s+3s change places LH on sides; 1s+4s
    change places RH on sides, 1s cross LH to 4th place own side. 2 3 4
    1', 0);
INSERT INTO 'dancecrib' VALUES (13183, '2020-09-15 00:20:38.035772+00', '2023-02-04 01:21:12.014327+00', 19815, 3, NULL, 'ace', '1-8::
    1s 1/2 turn 2s on sides (Men RH, Ladies LH) into to centre facing
    out, 2s+1s+3s set as Double Triangles; 1s cast (1M up, 1L down) into
    middle LSh to LSh facing own side
9-16::
    1M+2s & 1L+3s dance RH across; 1s turn LH 1.1/2 to face 1st corner
    (pstn) _while_ 2s+3s chase clockwise 1/2 round
17-24::
    1s+1st corners dance 1/2 diag reel of 4, 1s pass RSh, 1s+2nd corners
    dance 1/2 diag reel of 4, 1s pass RSh to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6287, '2013-08-21 08:31:21.733751+00', '2023-02-04 01:21:12.057855+00', 10316, 3, NULL, 'ace', '1-8::
    1s cross RH & cast, cross LH & cast - Lady up & Man down (end LH to
    partner & RH to 1st corners)
9-16::
    1s Bal-in-Line with 1st corners, 1/4 turn & balance with 2nd
    corners, balance with 3rd corners & balance with 4th corners
17-24::
    1s dance reels of 3 on opp sides giving LSh to 2nd corner (end
    facing 1st corner)
25-32::
    1s dance diagonal reel of 4 with 1st corners (end in centre facing
    up with Lady on left)
33-40::
    1s lead up & cross to dance reflection reels of 3 on own sides (2s
    dance out & down to start)', 0);
INSERT INTO 'dancecrib' VALUES (6288, '2013-08-21 08:31:21.744225+00', '2023-02-04 01:21:12.093395+00', 4141, 3, NULL, 'ace', '{{explanation}}
2 Ladies facing 2 Men

1-8::
    Ladies advance set & turn opposite Man 2H
9-16::
    Ladies dance round outside of Men & return (NHJ) between Men to
    places
17-24::
    All circle 4H round & back
25-32::
    Men advance (clap hands with partner) & retire, all advance & Ladies
    dance under Men''s arms to face next 2 dancers', 0);
INSERT INTO 'dancecrib' VALUES (6289, '2013-08-21 08:31:21.75447+00', '2023-02-04 01:21:12.120978+00', 12309, 3, NULL, 'ace', '1-8::
    1s cross RH, cast down 1 place 2s+1s+3s set & 1s turn LH to face 1st
    corners
9-16::
    1s dance ''Hello-Goodbye'' setting & end turning RH to 2nd place own
    sides facing out
17-24::
    1s dance out & chase clockwise to 2nd place opposite sides _while_
    2M+3L change places RH then 2L+3M change places RH; 1s dance 1/2
    reels of 3 on sides, LSh to 1st cnr pstn to start
25-32::
    1s dance 1/2 LSh reels of 3 across (LSh to 3rd cnr pstn to start)
    ending in 2nd place own sides; 1s turn RH & cast to 3rd place 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6290, '2013-08-21 08:31:21.764729+00', '2023-02-04 01:21:12.155884+00', 11526, 3, NULL, 'ace', '1-8::
    All dance interlocking reels of 4
9-16::
    1s+3s dance round clockwise 1/4 way, pass round 2s/4s RSh into
    centre (M round M & L round L), 1s+3s dance round each other (round
    opposite partner) & dance out RSh round 2s/4s (same persons as
    before) & dance clockwise 1/4 to opposite places
17-24::
    1s+3s dance RH across & Men followed by partner dance clockwise
    round 2s/4s back to places
25-40::
    2s & 4s repeat above Fig
41-48::
    1s+3s Adv+Ret with opp partner to sides _while_ 2s & 4s retire to
    corner & advance to meet opp partner, all turn new partner twice RH
49-56::
    Repeat this Fig back to places
57-64::
    All circle 8H round & back

{{explanation}}
Repeat in jig time', 0);
INSERT INTO 'dancecrib' VALUES (6291, '2013-08-21 08:31:21.773242+00', '2023-02-04 01:21:12.181042+00', 4144, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH, set & cross back RH
9-16::
    1s lead down the middle & back to top
17-24::
    1s+2s dance 1/2 RH across, set, dance 1/2 LH across & set
25-32::
    1s+2s dance All Round poussette
33-40::
    1s+2s circle 4H round & back
41-48::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (6292, '2013-08-21 08:31:21.783477+00', '2023-02-04 01:21:12.218142+00', 4145, 3, NULL, 'ace', '1-8::
    2s & 3s cast up/down & dance down/up, change places RH on the side
    then LH with partners
9-16::
    1s+3s & 2s+4s dance RH across, change places RH on the sides then LH
    with partners.  3(1)(4)2
17-24::
    1s & 4s cast up/down & dance down/up, change places RH on the side
    then LH with partners.  3 4 1 2
25-32::
    2s lead up to 1st place & on bars 27/28 3s+4s+1s dance down, 2s+3s &
    4s+1s circle round to left.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6293, '2013-08-21 08:31:21.792096+00', '2023-02-04 01:21:12.258621+00', 4147, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    Ladies Adv+Ret twice _while_ Men dance Figs of 8 round ptnr+crnr
    (Men dance behind ptnrs to start & finish BtoB in middle facing
    ptnrs)
17-28::
    All dance double reels of 4 across dance giving LH in the middle
    (Men end in middle)
29-32::
    All set to partners & 3/4 turn RH
33-40::
    All dance Grand Chain 1/2 way & turn (spin) partners to face in
41-48::
    1s+3s set advancing, 1/2 turn opposite person 2H to face out & dance
    out to sides, cross & dance to meet partner
49-56::
    2s+4s repeat
57-64::
    All turn partners (spin) & dance Grand Chain 1/2 way to original
    places
65-80::
    Set to partners, 3/4 turn RH & dance double reels of 4 across dance
    all ending in original places
81-88::
    Men Adv+Ret twice _while_ Ladies dance Figs of 8 round
    partner+corner (Ladies behind partners to start)
89-96::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8700, '2015-03-03 08:47:48.414444+00', '2023-02-04 01:21:12.283528+00', 16110, 3, NULL, 'ace', '1-8::
    1s+2s Petronella turn into middle & set, dance 1/2 reel of 4 up/down
9-16::
    2s+1s turn RH (4 bars) & dance 1/2 reel of 4 up/down to end in
    original places
17-24::
    1s+2s dance the Knot
25-32::
    1s dance Fig of 8 round 2s
33-40::
    2s dance Fig of 8 round 1s
41-48::
    2s+1s set & turn 2H once round opening into 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (13419, '2020-12-02 01:20:43.153798+00', '2023-02-04 01:21:12.310791+00', 4149, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, LH across remaining in centre facing up
9-16::
    1s followed by 2s dance up & cast to 2nd/1st place; 2s+1s turn
    partner RH
17-24::
    1s lead down (3 steps), 1/2 turn RH to face up; 1s lead up to 2nd
    place opp sides
25-32::
    2L+1L change places RH, 1s change places with 2s crossing LH; 1L+2L
    change places RH, 2s cross LH to own side', 0);
INSERT INTO 'dancecrib' VALUES (6294, '2013-08-21 08:31:21.97747+00', '2023-02-04 01:21:12.475049+00', 13114, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, dance 1/2 Fig of 8 round 2s & end facing
    1st corner
9-16::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners & end BtoB facing 3rd corners
17-24::
    1s dance 1/2 Diag reel of 4 with 3rd corners, pass RSh & dance 1/2
    reel with 4th corners & end 2nd place opposite sides
25-32::
    3s+1s+2s dance Set+Link for 3 twice', 0);
INSERT INTO 'dancecrib' VALUES (11202, '2018-09-30 22:20:08.720787+00', '2023-02-04 01:21:12.496652+00', 18622, 3, NULL, 'ace', '1-8::
    1s lead down middle (2s up), 1L dances under partner''s arm & 1s lead
    up to 2nd place opposite sides
9-16::
    2s+3s petronella turn into middle & set, petronella turn to opposite
    sides & all set.  (2)(1)(3)
17-24::
    All dance reels of 3 on sides with 2s & 3s casting to start & 1s
    then 3s & 2s crossing up RH from 2nd place to complete reel on own
    side
25-32::
    1s+3s Set+Link, all turn partner 2H. End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (3992, '2013-08-21 08:30:40.955315+00', '2023-02-04 01:18:26.431945+00', 132, 3, NULL, 'ace', '1-8::
    1s+2L dance diagonal reel of 3 across, 1s passing RSh & 2L dances up
    to start
9-16::
    1s+2M dance diagonal reel of 3 across, 1s passing LSh & 2M dances up
    to start
17-24::
    1s dance down NHJ below 2s, cast back up to place & turn 2H
25-32::
    2s dance up to top NHJ, cast back to place & turn 2H
33-36::
    1L+2M & 1M+2L set (1s advancing, 1L in front of partner passing RSh)
    1L+2M & 1M+2L  turn RH & take short way back to place
37-40::
    1s turn LH & cast to 2nd place (2s step up)
41-48::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4084, '2013-08-21 08:30:43.250338+00', '2023-02-04 01:18:33.520692+00', 271, 3, NULL, 'ace', '1-8::
    1M+2L Adv+Ret, 1L+2M Adv+Ret
9-16::
    1s+2s chase round clockwise (in square formation) to places
17-24::
    1s followed by 2 lead down & 2s lead up
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6295, '2013-08-21 08:31:22.128164+00', '2023-02-04 01:21:12.559382+00', 4154, 3, NULL, 'ace', '1-8::
    1s & 4s face across as 2s+3s face on sides & dance reels of 4
    passing facing person RSh to start (sometimes known as Borrowing
    Reels)
9-16::
    All dance Petronella to opposite sides
17-24::
    1s cross RH & cast down 1 place _while_ 2s 1/2 turn RH & lead up 1
    place, 1s cross RH & cast down 1 place _while_ 3s 1/2 turn RH & lead
    up 1 place
25-32::
    1s cross RH & cast down 1 place _while_ 4s 1/2 turn RH & lead up 1
    place & 1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6296, '2013-08-21 08:31:22.136476+00', '2023-02-04 01:21:12.591303+00', 4155, 3, NULL, 'ace', '1-8::
    1s cross below 2s & cast down behind 3s, dance up, 1L dances LH
    across with 2M+3M & 1M dances RH with 2L+3L
9-16::
    1M+2L also 1L+2M continue to turn until 1s are in 2nd place, 1s 3/4
    turn 2H (to end Man above 2s & Lady above 3s), 1M+2s also 1L+3s
    dance 3H round to left to end in lines of 3 across
17-24::
    Both lines dance down, all turning right about, dance back & end
    with top line turning to face 1L+3s
25-32::
    2s+1s+3s set & change places RH with person opposite, set, 1s cast
    into 2nd place _while_ 2s & 3s change places RH with opposite person', 0);
INSERT INTO 'dancecrib' VALUES (6297, '2013-08-21 08:31:22.144558+00', '2023-02-04 01:21:12.619753+00', 7577, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1M+2L & 3L+4M change pl RH as others set, 1L+2M & 3M+4L change pl RH
    as others set, 1s+2s & 3s+4s dance RH across 1/2 way & all set
9-16::
    1s & 4s cross RH & cast in 1 place, 1s+4s dance 1/2 R&L All Ladies
    omit polite turns to end facing out
17-24::
    All dance RSh reels of 4 on sides
25-32::
    2s+4s also 1s+3s circle 4H round to left, 4s & 1s dance 1/2 Figs of
    8 to end 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (11204, '2018-09-30 22:20:08.849481+00', '2023-02-04 01:21:12.846922+00', 18567, 3, NULL, 'ace', '1-8::
    1s lead down (4 bars), 1/2 turn RH to face up, lead up to 2nd place
    opp. sides (2s step up on 3-4)
9-16::
    2s+1s dance Ladies Chain
17-24::
    1s+3s dance RH across, 1s cast to 3rd place _while_ 3s dance up to
    2nd place, 1s cross RH to own sides   2 3 1
25-32::
    2s+3s+1s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (6298, '2013-08-21 08:31:22.150741+00', '2023-02-04 01:21:12.858467+00', 11973, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 2nd place, turn LH to face 1st corners
9-16::
    1s dance 1/2 RSh reel of 4 with 1st corners, turn LH to face 4th
    corners, dance 1/2 RSh reel with 4th corners & turn LH to face 3rd
    corners
17-24::
    Repeat bars 9-16 with 3rd & 2nd corners & end in 2nd places opposite
    sides
25-32::
    1s dance cross down below 3s, cast up on own sides, dance up between
    2s & cast to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (11459, '2019-01-01 01:57:15.728471+00', '2023-02-04 01:21:12.880058+00', 18947, 3, NULL, 'ace', '1-4::
    2s step up as 1s dance down (briefly NHJ), curving away from each
    other to end facing each other again, then 1s set
5-8::
    1s dance down NHJ, cast up round 3s to finish facing 1st corners
9-12::
    1s dance 1/2 Rotating Reel of 4, ending in centre 1M facing up, 1L
    facing down
::
    _9_         1s+1st corners pass RSh
::
    _10_       1st corners twirl (rotate 360 degrees pulling back RSh)
    as they pass in centre
::
    _11-12_  1st corners dance out to opposite corner place passing 1s
    RSh
13-16::
    1s set advancing, 1/2 turn 2H, drop hands, pull back RSh to face 2nd
    corners
17-20::
    1s+2nd corners repeat 9-12
21-24::
    1s set, cross RH to 2nd place own side 3 1 2
25-32::
    3s+1s+2s set, dance RSh round partner to face own sides.  All dance
    out & chase clockwise (2s to top place, 3s to 3rd place) 1s start
    chase then from top/bottom place they turn RH in centre to end in
    2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (12869, '2020-06-03 16:26:59.272275+00', '2023-02-04 01:21:12.902216+00', 13919, 3, NULL, 'ace', '1-8::
    1s+2s dance the Knot. 1s end facing 1st corners
9-16::
    1s+1st corners set, turn 3/4 RH to 1L facing 2L, 1M facing 3M; 1L+2s
    & 1M+3s dance 1/2 LSh reels of 3 across, 1s pass RSh to face 3rd
    corner (pstn)
17-24::
    1s+3rd corners (pstn) set, turn 3/4 RH to face 2nd corners (pstn);
    1/2 reels of 3 across (1s LSh to 2nd corner pstn). 1s pass RSh to
    2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15342, '2022-12-19 01:20:52.466759+00', '2023-02-04 01:21:12.930439+00', 21183, 3, NULL, 'ace', '1-4::
    1s+3s dance 1/2 Fig 8 betwen side couples (Ladiers pass in front of
    partner then between couple on left, Men dance between couple on
    right)
5-8::
    All turn partner 3/4 RH into prom hold & promenade 1 place
    clockwise.
9-16::
    All Set & Rotate clockwise round square
::
    All set, pull back RSh and dance on one side of square clockwise
    (Man leading). All change RH with partner, dance on one side of
    square clockwise (Lady leading).
17-20::
    1s+3s turn opp person RH 1/2 way and Twirl out to opp side.
21-24::
    2s+4s turn opp person RH 1/2 way and Twirl out to opp side.
25-32::
    All dance Double Ladies'' Chain, Ladies dancing 1/2 RH across in
    middle.
::
    Repeat "widdershins" using LH and dancing anticlockwise.
33-36::
    2s+4s dance 1/2 Fig 8 between side couples, Ladies pass in front of
    partner then between cpl on L, M dance btwn cpl on R.
37-40::
    All turn partner LH 3/4 & promenade 1 place anticlockwise.
41-48::
    All Set &Rotate anticlockwise round square
::
    All set, pull back LSh and dance on one side of square anticlockwise
    (Ladies leading). All change LH with partner, dance on one side of
    square anticlockwise (Men leading).
49-52::
    2s+4s 1/2 turn opp person LH, pull back LSh & dance out to opp side.
53-56::
    1s+3s 1/2 turn opp person LH, pull back LSh & dance out to opp side.
57-64::
    All dance Double Men''s Chain, Men dancing 1/2 LH across in middle.
::
    Repeat 1-64 in reel time', 0);
INSERT INTO 'dancecrib' VALUES (3994, '2013-08-21 08:30:40.975453+00', '2023-02-04 01:18:26.467141+00', 10357, 3, NULL, 'ace', '1-4::
    1s dance down below 3s & cast up to 2nd place
5-16::
    2s+1s+3s dance 3 couple R&L
17-24::
    2s+1s+3s dance reel of 3 on sides, 1s LSh to person on left (1M in &
    up, 1L in & down) & 1s pass LSh to face 1st corners
25-32::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH to
    face 1st corners
33-40::
    1s dance reels of 3 across (Lady with 2s & Man with 3s) ending 2nd
    place own sides
41-48::
    2s+1s+3s circle left for 6 steps, pivot left & circle back to places', 0);
INSERT INTO 'dancecrib' VALUES (14667, '2022-03-07 02:20:40.129976+00', '2023-02-04 01:21:12.95603+00', 16603, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate 2 1 3
9-16::
    2s+1s+3s dance the Knot. On bars 15-16 1s turn to face 1st corners
17-24::
    1s dance 1/2 reel of 4 with 1st corners, pass RSh, to dance 1/2 reel
    of 4 with 2nd corners to finish 2nd place opposite sides
25-32::
    All set, 1s cast to 3rd place (3s step up bars 27-28). All turn 2H
    1.1/2 times.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (11460, '2019-01-01 01:57:15.784385+00', '2023-02-04 01:21:13.083518+00', 18977, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH.  Repeat back to place.
9-16::
    1s dance down between 2s, cast down behind 3s and lead up between
    them; cast up behind 2s and finish in original places. (Nearer hands
    joined whenever  possible.)
17-24::
    1s+2s dance the Bourrel:
::
    _17-20_    1M+2L set advancing, 3/4 turn 2H & twirl to end BtoB
    (Lady facing up & Man down) _while_ partners chase anticlockwise to
    face partner
::
    _21-24_    Set to partners & turn 2H to own sides having changed
    places
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (9742, '2017-04-06 08:39:59.467933+00', '2023-02-04 01:21:13.104762+00', 4169, 3, NULL, 'ace', '1-8::
    1s set, 1/2 turn RH to face down, cross below 2s & cast up round 2s
    to original places
9-16::
    1s+2s+3s dance »Inveran Reels«
::
    _9-12_    1s cross down to 2nd place opposite sides & dance 1/2 reel
    of 3 on opposite sides
::
    _13-16_  1s cross up to 2nd place own sides (from bottom) & dance
    1/2 reel of 3 on own sides to end in original places
17-24::
    1s+2s dance »Tournée«:
::
    _17-20_    1s+2s dance into prom hold (Men with partner on right, 1s
    face Men''s side & 2s face Ladies side), both couples wheel
    anticlockwise 1/2 way & Men turn Ladies into middle
::
    _21-24_   Both couples turn 1.1/2 times (2s RH, 1s LH) & dance out
    to places
25-32::
    1M+3s & 1L+2s dance 1/2 reels of 3 across (1M+3L & 1L+2M pass LSh).
    1s end in 2nd place opp sides.  All set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (9743, '2017-04-06 08:39:59.475098+00', '2023-02-04 01:21:13.140424+00', 16925, 3, NULL, 'ace', '1-8::
    1s cross down between 2s & 3s to dance Fig of 8 on opp sides to end
    in partner''s place
9-16::
    1s cross RH & cast 1 place (2s step up 11-12).  1s dance RH across
    (1L+2s & 1M+ 3s). 1s end facing 1st corners
17-32::
    1s dance Corner Chain with 1st & 2nd corners :
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end turning LH to 2nd places
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (15233, '2022-11-03 01:20:43.980568+00', '2023-02-04 01:21:13.173653+00', 4170, 3, NULL, 'ace', '1-8::
    1s dance down below 3s, cast to 2nd place, meet , dance up and cast
    to 2nd place (2s step up/in & 3s step in 7-8)
9-12::
    2s+1s+3s join hands on sides & slip-step down for 8 steps
13-16::
    All slip-step up for 4 steps, separate and dance back to sidelines
    finish facing up
17-24::
    2s, followed by 1s and 3s dancing up, cross at the top and cast down
    opposite sides. All turn in on bar 20 to face up and retrace steps,
    passing RSh when crossing at the top
25-32::
    2s+1s+3s circle 6H round and back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6300, '2013-08-21 08:31:22.167039+00', '2023-02-04 01:21:13.227036+00', 4173, 3, NULL, 'ace', '1-8::
    1s+2s 3/4 turn RH & Bal-in-Line (in middle), 1/2 turn partner RH &
    Bal-in-Line
9-16::
    1s+2s 3/4 turn partners RH to face up, 1s cast to 2nd place _while_
    2s lead up to 1st place, 1s turn LH 1.1/4 times to face 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting & end facing 3rd corners
25-32::
    1s dance reels of 3 across giving LSh to 3rd corner & 1s cross RH to
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6301, '2013-08-21 08:31:22.175437+00', '2023-02-04 01:21:13.248478+00', 4175, 3, NULL, 'ace', '1-8::
    1s cross down below 2s, 1L casts up & 1M casts down, meet & turn LH
    to face 1st corners
9-32::
    2s+1s+3s dance full Marigold Fig:
::
    _9-10_   1s change places with 1st corners passing RSh, 1st corners
    pass RSh to face next corner (2nd corner) (2nd corners stand for 2
    bars)
::
    _11-12_  1st crnrs change places with 2nd crnrs passing RSh, 2nd
    crnrs pass RSh to face next corner (1s in 3rd corner)
::
    _13-14_  2nd cnrs change places with 1s passing RSh
::
    _15-32_  Repeat this Fig until 2s & 3s are back in original places &
    1s end facing 2nd corners
33-40::
    1s turn 2nd corners RH, turn 1st corners LH & dance 1/2 Figs of 8
    (Lady round 2s & Man round 3s) to own sides', 0);
INSERT INTO 'dancecrib' VALUES (12408, '2019-12-05 01:30:55.874868+00', '2023-02-04 01:21:13.272864+00', 19420, 3, NULL, 'ace', '1-8::
    1s turn RH retaining hands briefly in centre & 1L crosses down RSh
    round 2M _while_ 1M dances RSh round 2L. 1s end BtoB between 2s
    facing opp sides
9-16::
    Modified "Spurtle":
::
    _9-12_    1s dance 1/2 reel of 4 with 2s & 1/2 turn partner RH to
    face 3s
::
    _13-16_  1s dance 1/2 reel of 4 with 3s & 1s cross RH to 3rd place
    own side
17-24::
    3s+1s set, dance 1/2 RH across; 2s+1s set, dance 1/2 LH across
    remaining in centre facing up ready for …
25-32::
    1s+2s dance Promenade, bars 31-32 1s cast & 2s dance up to top.  2 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (6302, '2013-08-21 08:31:22.181551+00', '2023-02-04 01:21:13.295026+00', 11527, 3, NULL, 'ace', '1-8::
    All circle 4H round & back
9-16::
    Heel & toe twice, Step, close step to right Repeat to left
17-24::
    Turn opposite person RH & dance RH across
25-32::
    Adv+Ret for 2 steps & travel on to meet next couple (clockwise
    facing couples making arches)', 0);
INSERT INTO 'dancecrib' VALUES (11461, '2019-01-01 01:57:15.836556+00', '2023-02-04 01:21:13.31748+00', 18958, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    All set & 1s+2s also 3s+4s dance 1/2 RH across, all set & 2s+1s also
    4s+3s dance 1/2 LH across
9-16::
    1s+4s chase anticlockwise 1/2 way _while_ 2s+3s dance 1/2 R&L, 4s+3s
    also 2s+1s set facing on sides & 1/2 turn RH.  (3)(4)(1)(2)
17-24::
    All dance RSh reels of 4 on sides
25-32::
    3s & 2s 1/2 turn RH _while_ 4s+1s dance 1/2 R&L, 1s & 4s dance out
    ends & cast in 1 place.  3 1 (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (6303, '2013-08-21 08:31:22.210483+00', '2023-02-04 01:21:13.34722+00', 4176, 3, NULL, 'ace', '1-8::
    1s+2s set & dance 3/4 R&L.  2 1
9-16::
    1s dance Figs of 8 on owns side casting round 3rd corner to start &
    end facing own sides for…
17-24::
    1s dance Double Triangles ending RSh to RSh (Man facing up)
25-32::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corner to
    start & crossing LH to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (15212, '2022-11-03 01:18:34.089256+00', '2023-02-04 01:18:33.661328+00', 275, 3, NULL, 'ace', '1-4::
    1s dance down below 3s and curve out to place (2s+3s step up 3-4)
5-8::
    2s+3s+1s set, 1s cross RH and remain facing out.  2 (1) 3
9-16::
    2s+1s+3s dance mirror reels of 3 on sides giving hands (1s out/up,
    3s in/down, 2s cast to begin)
17-20::
    1s+3s change places on the side (Men RH, Ladies LH), 1s+2s change
    places on the side (Men LH, Ladies RH)
21-24::
    All take hands and set. 1s cross RH to own sides
25-28::
    1s set advancing diagonally to face 2s (1M going in front of
    partner). 1L+2M turn BH 1.1/4 as 1M+2L turn BH 3/4. 2s finish in 1st
    place
29-32::
    1s set diagonally to face 3s (1L going in front of partner). 1L+3L
    turn BH 3/4 as 1M+3M turn BH 1.1/4. 3s finish in 2nd place and 1s in
    3rd place.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (12646, '2020-03-02 01:53:17.713564+00', '2023-02-04 01:21:13.379275+00', 19599, 3, NULL, 'ace', '1-4::
    2s cross LH, cast to the left into centre (2M at top facing down, 2L
    at bottom facing up as 1s & 3s step toward one another on the side,
    1s face up, 3s face down & join hands with 2s (as Crown Triangles)
5-8::
    2s+1s+3s dance 1/2 Inverted Double Triangles
9-12::
    2M+1s & 2L+3s dance 1/2 RSh reels of 3 across (2M RSh to 1L, 2L RSh
    to 3M), 2s finish in centre BtoB, 2M facing down, 2L facing up. 1s
    face down, 3s face up & join hands with 2s
13-16::
    1s+2s+3s dance 1/2 Inverted Double Triangles
17-20::
    2L+1s & 2M+3s dance 1/2 RSh reels of 3 across (2L RSh to 1L, 2M RSh
    to 3M), finishing in centre, LSh to LSh in 2nd place facing opp
    sides
21-28::
    2L+1s & 2M+3s dance RH across, 2s pass RSh to dance LH across with
    other couple. 2s end in 2nd place own side facing out
29-32::
    1s & 2s cast one place as 3s dance up to 1st place and all 3 couples
    set.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (11586, '2019-02-20 16:58:21.096154+00', '2023-02-04 01:21:13.453019+00', 7785, 3, NULL, 'ace', '1-8::
    1L followed by partner casts 1 place, crosses set, casts behind 3M,
    crosses set to between 3rd & 4th couple own side & 1s set.
9-16::
    1s NHJ dance up to top (3 bars), cast 1 place on own side & turn RH
    to face 2L (Man''s 2nd corner) in promenade hold
17-24::
    1s dance 1/2 diag reel of 3 (RSh to 2L); 1/2 diag reel of 3 (RSh to
    2M)
25-32::
    1s dance 1/2 diag reel of 3 (RSh to 3M; 1/2 diag reel of 3 (RSh to
    3L).  1s end in centre facing up retaining LH
33-40::
    2s+1s dance LH across; 1s+3s dance RH to end in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6306, '2013-08-21 08:31:22.231067+00', '2023-02-04 01:21:13.469537+00', 12527, 3, NULL, 'ace', '1-8::
    1s+2s turn 1.1/2 times on sides (1s b''tw''n 2s)), 1s+3s turn 1.1/2 on
    sides other hand
9-16::
    1s dance up to top, cast 1 place & turn RH to face 1st corners
17-24::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh to dance 1/2
    reel with 2nd corners & pass RSh to face own sides in Double
    Triangle pstns
25-32::
    2s+1s+3s set, 1s turn person on right RH & dance 1/2 reel of 3
    across (Man with 2s at top & Lady with 3s at bottom) ending in lines
    of 3 across
33-40::
    All Set+Link for 3 once, 3s & 1s set & cross down 1 place (no hands)
    _while_ 2s cross RH & dance up outside to top.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6307, '2013-08-21 08:31:22.243688+00', '2023-02-04 01:21:13.533133+00', 4181, 3, NULL, 'ace', '1-8::
    2s & 4s dance 1/2 Petronella to end on opposite sides
9-16::
    1s+2s also 3s+4s dance the Whirligig Progression :
::
    All turn 3/4 RH ending in prom hold with 1s/3s facing Men''s side &
    2s/4s facing Ladies side then 1s+2s also 3s+4s Promenade
    anticlockwise once round each other (Men keeping LSh to LSh) & all
    turn LH to own side 2s/4s casting up 1 place as 1s/3s move down 1
    place (2s+1s end facing down, 4s+3s facing up on sides)
17-24::
    All dance reflection reels of 4 on sides with 1M+4M passing LSh &
    1L+4L passing RSh to start
25-32::
    1s+4s+3s dance 1/2 reflection reels of 3 on sides, 2s & 4s turn RH.
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6308, '2013-08-21 08:31:22.251804+00', '2023-02-04 01:21:13.55752+00', 12613, 3, NULL, 'ace', '1-8::
    1s & 3s advance & 1/2 turn opposite partner RH, twirl & dance out to
    opposite side, 2s+4s repeat
9-16::
    All Ladies set & petronella turn to next place on right, Men repeat
17-24::
    All Reverse Set+Link, 1L+3L dance 1/2 Ladies Chain
25-32::
    1M+3M dance 1/2 Men''s Chain, dance RH across 1/2 way & turn partner
    into prom hold to face 3rd/1st pl _while_ 2s+4s set & turn RH into
    prom hold
33-40::
    All dance reel of 4 up/down (3s give RSh to 4s at top & 1s RSh to
    2s) 3s & 1s end passing RSh to curve out to 2nd/4th places', 0);
INSERT INTO 'dancecrib' VALUES (6309, '2013-08-21 08:31:22.259919+00', '2023-02-04 01:21:13.582649+00', 4183, 3, NULL, 'ace', '1-8::
    1s turn LH 1.1/2 times moving down to face 1st corner & dance 1/2
    diagonal reel of 4 with 1st corners
9-16::
    1s turn LH to face 2nd corner & dance 1/2 diagonal reel of 4 with
    2nd corners. 1s end in 2nd place opp sides
17-24::
    1s dance RH across (Man up with 3s, Lady down with 2s); 1s dance 1/2
    RSh reels of 3 on opp sides (RSh to 2nd corner pstn to start)
25-32::
    1s dance LH across (Man down with 3s, Lady up with 2s) ending BtoB
    Lady facing up; All set & 1s Petronella turn to 2nd place own sides
    _while_ 2s & 3s cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6310, '2013-08-21 08:31:22.268112+00', '2023-02-04 01:21:13.615235+00', 4185, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    Ladies dance RH across & turn partner RH
17-24::
    Men dance LH across & turn partner LH into prom hold
25-32::
    All Promenade clockwise once round
33-40::
    1s+3s in prom hold pass RSh & dance round to right behind 4s/2s back
    to places
41-48::
    2s+4s repeat
49-56::
    1s+3s Adv+Ret, 2s+4s Adv+Ret
57-64::
    Ladies with partners on their left dance RH across once round

{{explanation}}
Note:  This dance is frequently danced as a S64+R64 medley', 0);
INSERT INTO 'dancecrib' VALUES (6311, '2013-08-21 08:31:22.276098+00', '2023-02-04 01:21:13.659999+00', 4187, 3, NULL, 'ace', '1-8::
    1s & 4s set, cast in 1 place _while_ 2s & 3s step up/down to ends,
    1s+4s circle 4H round to left
9-16::
    All dance Grand Chain (2s & 3s cross RH to start)
17-24::
    1s+4s set, cast to ends _while_ 2s & 3s step up/ down to original
    places. 1s+2s also 3s+4s circle 4H round to the left
25-32::
    1s cast to 4th place _while_ 2s+3s+4s step up on bars 27‑28 & all
    turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (12813, '2020-05-14 23:13:12.667064+00', '2022-04-01 00:18:29.448103+00', 19966, 3, NULL, 'ace', '1-8::
    All join hands in a circle & Adv+Ret twice
9-16::
    All turn partner RH, turn partner LH
17-24::
    All join 2H with partner & slip step towards centre (2 bars), clap
    x4, slip step back, clap x4
25-32::
    All dance DoSiDo with partner;  Ladies dance clockwise, Men
    anticlockwise 1/4 round, passing partner & 1 more dancer RSh (ie
    Ladies on outside, Men inside)', 0);
INSERT INTO 'dancecrib' VALUES (3995, '2013-08-21 08:30:40.98533+00', '2023-02-04 01:18:26.537908+00', 12801, 3, NULL, 'ace', '1-8::
    All dance Snowball Grand Chain for 4 couples: 1s cross RH, 1s+2s
    change places LH on sides, 2s cross RH as 1s+3s change places RH on
    sides, 2s+1s also 3s+4s change places LH on sides to end 3(2)4(1)
9-16::
    3s+2s also 4s+1s dance Ladies'' Chain
17-24::
    2s & 1s dance 1/2 Fig of 8 round couple above, 2s+4s Set+Link
25-32::
    3s+4s also 2s+1s dance "Demi-Tournee":
::
    3s+4s (2s+1s similarly) dance into prom hold (Men with partner on
    right, 3s facing Men''s side & 4s face Ladies'' side), wheel
    anticlockwise 1/2 way & Men turn Ladies into middle & all set to
    partners & 3/4 turn (4s & 1s RH, 3s & 2s LH), to own sides.  4 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6312, '2013-08-21 08:31:22.284378+00', '2023-02-04 01:21:13.684024+00', 9724, 3, NULL, 'ace', '1-4::
    All set, 1s+3s dance forward passing opp dancer LSh _while_ 2s+4s
    chase clockwise 1 place to face 1s/3s
5-8::
    1s+2s also 3s+4s circle 4H round to left
9-16::
    All dance parallel reels of 4 up/down set
17-20::
    1s+2s also 3s+4s dance RH across
21-24::
    3s+1s dance LH across 1/2 way _while_ 4s+2s chase cl''wise 1 place,
    3s+1s set to prtnr (in centre) as 4s+2s set
25-32::
    1M+3L also 3M+1L lead out & cross between side couples casting to
    meet partner, 3s+1s turn 2H & all circle left 1 place.  2 3 4 1
::
    Repeat 3 more times', 0);
INSERT INTO 'dancecrib' VALUES (6313, '2013-08-21 08:31:22.292656+00', '2023-02-04 01:21:13.702255+00', 9834, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L+4L dance across, down behind Men, across & up
    to place
9-16::
    1M followed by 2M+3M+4M dance across, down behind Ladies, across &
    up to place
17-24::
    All dance DoSiDo & all turn RH
25-32::
    1s slip step to bottom & back to top
33-40::
    1s cast to 2nd place & turn RH _while_ 2s+3s+4s Adv+Ret, 1s cast to
    3rd place & turn RH _while_ 2s+3s+4s Adv+Ret
41-48::
    1s cast to 4th place & turn RH _while_ 2s+3s+4s Adv+Ret, all turn RH
    (or spin)', 0);
INSERT INTO 'dancecrib' VALUES (6314, '2013-08-21 08:31:22.300712+00', '2023-02-04 01:21:13.740174+00', 4190, 3, NULL, 'ace', '1-8::
    1s and 4s cast in 1 place and cross (Ladies between Men), 1s+4s
    changing places on sides cast to ends (4s up to top, 1s down) and
    cross RH to own sides
9-16::
    2s and 3s dance up/down crossing and cast in 1 place (opposite
    side), dance 1/2 R&L. 4321
17-24::
    4s+3s also 2s+1s circle 4H round to left, all dance 1/2 reel of 4 on
    sides. 1234
25-32::
    1s+2s dance 1/2 RH across; 1s+3s dance 1/2 LH across, 1s+4s dance
    1/2 RH across & all cross RH. 2341', 0);
INSERT INTO 'dancecrib' VALUES (6315, '2013-08-21 08:31:22.393644+00', '2023-02-04 01:21:13.890273+00', 4191, 3, NULL, 'ace', '1-8::
    1L+3M also 2L+4M set & change places RH, 1M+2L also 2M+4L set &
    change places RH.  (3)(4)(1)(2)
9-16::
    Middle couples lead up/down between end couples & cast to place, end
    couples lead down/up & cast back to place
17-24::
    All set, top 2 cpls also bottom cpls dance RH across 1/2 way, bottom
    cple (1s) followed by other 3 cpls cast to top.  1 2 3 4
25-32::
    All turn partners RH, 1s cast to bottom _while_ others dance up 1
    place & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (10017, '2017-07-23 15:58:35.843826+00', '2023-02-04 01:21:13.945418+00', 4193, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH moving down & face up NHJ _while_ 2s dance up and in
    to face 1s NHJ.  1s+2s set, circle 4H round to Left to end on sides
    2 (1) 3 4
9-12::
    2s+1s+3s set.  2s+3s cross RH, 2s face down, 3s up _while_ 1s turn
    RH to 2nd place opp sides facing out  (2) (1) (3)
13-16::
    1s cast (wide) as 3s+2s set to each other on sides.  1s dance down
    behind 3s, meet & dance up NHJ to 2nd place _while_ 2s+3s change
    places on sides (Men RH, Ladies LH).  3s (at top) face out, 1s up,
    2s in
17-19::
    3L+1L+2L dance LH across on Men''s side _while_ 3M+1M+2M dance RH
    across on Ladies'' side
20-24::
    Each couple, on meeting, crosses (1s then 2s, then 3s - Ladies
    dancing in front of partner) to join hands across on own side. End
    1s dancing up middle to 1st place, 2s to 2nd place, 3s dancing down
    sides to 3rd place, ready for ...
25-32::
    1s+2s+3s promenade (3s dance in to meet partner bar 25).  Bars 31-32
    1s cast to 2nd place as 2s dance up to top

{{explanation}}
Note:  Bars 20-24 dancers should maintain shapes of hands across while crossing from one side to other.  Hands are joined for promenade on bar 25', 0);
INSERT INTO 'dancecrib' VALUES (6317, '2013-08-21 08:31:22.411545+00', '2023-02-04 01:21:14.030113+00', 4196, 3, NULL, 'ace', '1-8::
    1s followed by 2s lead down the middle, 2s followed by 1s lead up to
    end 2s in 1st place
9-16::
    2s+1s+3s circle 6H round & back
17-24::
    2s+1s+3s dance Grand Chain (2s crossing to commence)
25-32::
    1s set twice, lead down between 3s divide & cast back to 2nd place
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (6318, '2013-08-21 08:31:22.419517+00', '2023-02-04 01:21:14.083679+00', 4198, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s dance reflection reels of 3 on own side with 1s dancing in & down
    to begin
17-24::
    1s cross RH, cast 1 place & petronella turn into lines of 3 facing
    down/up (1M between 2s 1L between 3s), all set
25-32::
    1s petronella turn to 2nd place own side, 2s+1s+3s set & turn
    partners 2H', 0);
INSERT INTO 'dancecrib' VALUES (8844, '2015-08-13 20:33:50.925886+00', '2023-02-04 01:21:14.112665+00', 15966, 3, NULL, 'ace', '1-8::
    1s set & 1L followed by partner cast to 2nd place, opposite sides.
    1s set.
9-16::
    1s dance RH across with 2s then LH across with 3s, ending with 1L on
    men''s side facing out.
17-24::
    1L followed by 1M casts up, across top of set to original places. 1s
    set & turn 3/4 RH moving down to give LH to 1st corners.
25-32::
    1s balance in line with 1st corners, turn partner RH, give LH to 2nd
    corners & balance in line with 2nd corners, 1s turn RH to 2nd place
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (6319, '2013-08-21 08:31:22.4294+00', '2023-02-04 01:21:14.140954+00', 11638, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    1L+3M dance Fig of 8 round 4s _while_ 1M dances reel of 3 with 2s
    (RSh to 2L) also 3L dances reel of 3 with 5s (RSh to 5M)
17-24::
    1M+3L dance Fig of 8 round 4s _while_ 1L dances reel of 3 with 2s
    (LSh to 2M) also 3M dances reel of 3 with 5s (LSh to 5L)
25-32::
    All set, 1s & 3s cast 1 place & all Adv+Ret', 0);
INSERT INTO 'dancecrib' VALUES (6320, '2013-08-21 08:31:22.447335+00', '2023-02-04 01:21:14.212125+00', 4204, 3, NULL, 'ace', '1-8::
    1s set & dance down below 3s, cast up to 2 place & 2s+1s+3s set
9-16::
    1s cross RH to 1st corner & turn LH, partner RH, 2nd corner LH & end
    NHJ facing out between 2L+3L
17-24::
    1s dance out & cast (Man up, Lady down), dance out between 2M+3M &
    cast (1M up, 1L down) finishing BtoB facing own sides ready for…
25-32::
    1s dance double triangles & cross to end 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6321, '2013-08-21 08:31:22.45541+00', '2023-02-04 01:21:14.234822+00', 14236, 3, NULL, 'ace', '1-8::
    All set & Adv+Ret (1 step), 2s dance 1/2 diag R&L (Lady up & Man
    down)
9-16::
    2s circle 3H round to left (2L with top Ladies & 2M with Men) into
    6H round 1/2 way
17-24::
    All set & Adv+Ret (1 step), 2s dance 1/2 diag R&L (Man up & Lady
    down).  1 (2) 3
25-32::
    2s turn 2H 1.1/2 times _while_ 1s set to 3s on sides & change places
    (Ladies LH & Men RH), 3s set to 2s on sides & 3s cast to 2nd pl as
    2s dance up', 0);
INSERT INTO 'dancecrib' VALUES (6322, '2013-08-21 08:31:22.463488+00', '2023-02-04 01:21:14.25914+00', 9008, 3, NULL, 'ace', '1-8::
    1s+2s turn on sides 1.1/2 times (Men RH & Ladies LH), 1s cast down
    behind 3s, meet & dance up to 2nd place facing own sides ready for -
9-16::
    1s dance Double Triangles & end by turning right about to face each
    other (remaining in middle)
17-24::
    1s slip step down centre & back
25-32::
    1L dances LH across on Men''s side as 1M dances RH across on Ladies
    side & dance 1/2 Fig of 8 round 2s', 0);
INSERT INTO 'dancecrib' VALUES (15343, '2022-12-19 01:20:53.661343+00', '2023-02-04 01:21:14.288405+00', 21132, 3, NULL, 'ace', '1-8::
    1s+3s lead down the middle & back up & remain in middle as 2s+4s
    step in behind 1s+3s respectively on bar 8. 1 2 3 4
9-16::
    1s+2s also 3s+4s dance Allemande.  2 1 4 3
17-24::
    All set. 1s+3s turn partner 3/4 RH to finish in line up/down the
    middle; 1s+3s dance 1/2 RSh reels of 3
25-26::
    3s+1s turn partner 3/4 RH to face up
27-32::
    3s lead up & cast round 2s to 2nd place _while_ 1s lead up & cast
    round 4s to 4th place. All set.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6323, '2013-08-21 08:31:22.47161+00', '2023-02-04 01:21:14.312827+00', 4209, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    All dance Grand Chain starting on sides (ie 1s with 2s & 3s with 4s)
::
    Bar 8: 1s & 4s do not pass LH but take prom hold, 1s facing Ladies''
    side, 4s facing Men''s side (Lady on Man''s left), 2s face up, 3s face
    down
9-16::
    1s in prom hold dance reel of 3 with 2s (LSh to 2L) _while_ 4s reel
    of 3 with 3s (LSh to 3L), ending in lines of 4 across (1s & 4s in
    centre of lines)
17-24::
    All set, 1s+4s dance RH across once round, 1s & 4s dance up/down
    between 2s/3s to ends & turn to face 2s+3s (who dance in to face
    them)
25-28::
    1s+2s & 3s+4s set passing opp couple LSh 2s & 3s turn partners 2H as
    1s+4s set passing LSh to 2 4 (1) (3)
29-32::
    2s+4s & 1s+3s circle 4H round to left.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (6324, '2013-08-21 08:31:22.479672+00', '2023-02-04 01:21:14.344414+00', 4211, 3, NULL, 'ace', '1-8::
    1s & 3s petronella into centre, set to partner, 3/4 turn RH & dance
    RH across 1/2 way
9-16::
    3s+2s+1s dance reels of 3 on sides (2s pass person on right RSh), 2s
    petronella turn into centre as 3s+1s dance down/up to meet on sides
17-24::
    3s+2s+1s set to partners, circle 6H round to left & set
25-32::
    2s advance towards each other _while_ 1s followed by 3s dance down &
    into prom hold (2 1 3) & Promenade', 0);
INSERT INTO 'dancecrib' VALUES (9018, '2015-11-30 09:00:00.616362+00', '2023-02-04 01:21:14.367987+00', 11747, 3, NULL, 'ace', '1-4::
    1s+2s dance 1/2 double Fig 8 (1s cast, 2s cross up to start)
5-8::
    2s+3s dance 1/2 double Fig 8 (3s cast up, 2s cross down to start)
9-16::
    2s dance round 1st corners LSh, 2M+1s also 2L+3s dance RH across
17-24::
    All circle 6H 1/2 round to Left.  2M+3s also 2L+1s dance RH across
25-32::
    2s cross LH, cast to 3rd place (1s step up 27-28).  All turn
    partners 2H   3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6325, '2013-08-21 08:31:22.489503+00', '2023-02-04 01:21:14.401304+00', 4215, 3, NULL, 'ace', '1-8::
    1M+2M+3M (arms folded) Adv+Ret (PdeB), 1L+2L+3L cross & dance RSh
    round partner back to place _while_ Men beat time
9-16::
    1s cross RH, cast 1 place to give RH to partner & LH to 1st corner,
    Bal-in-Line & turn corner LH to end 2nd place opposite sides
17-24::
    1s set, cross RH, cast 1 place (Man up & Lady down) to give RH to
    partner & LH to 2nd corner & Bal-in-Line
25-32::
    1s dance LH across (Man with 2s & Lady with 3s), 2s+1s+3s turn RH
    into prom hold
33-40::
    2s+1s+3s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (6327, '2013-08-21 08:31:22.505138+00', '2023-02-04 01:21:14.462128+00', 4217, 3, NULL, 'ace', '1-8::
    Ladies petronella turn into centre to face partner & set & turn RH
    back to places
9-16::
    Dance ''R&L'' using 2H (rotate clockwise each time)
17-20::
    Inner dancers dance out between partners (who dance in & follow
    them) & cast away from each other to form large circle
21-24::
    All advance 2 steps & retire
25-32::
    Each set dances 1/2 RSh reel of 4 & turn partner RH to face next
    couple', 0);
INSERT INTO 'dancecrib' VALUES (6328, '2013-08-21 08:31:22.513257+00', '2023-02-04 01:21:14.487443+00', 12890, 3, NULL, 'ace', '1-8::
    1s set advancing, turn 2H, dance down & turn 2H to face 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting & turn RH to face down
17-24::
    1s followed by 2s+3s dance down the middle, 2s+3s divide & 1s
    followed by 3s+2s dance up to top
25-32::
    1s+3s+2s dance Allemande to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (9766, '2017-04-06 09:57:38.730754+00', '2023-02-04 01:21:14.524935+00', 4222, 3, NULL, 'ace', '1-8::
    1s set, turn 2H, lead down to 2nd place (2s step up 5-6), turn RH to
    end 1M facing 3M, 1L facing 2L
9-16::
    1M+3s & 1L+2s dance RSh reels of 3 across.  1s end BtoB facing 1st
    corners
17-24::
    1s turn corner RH, partner LH, 2nd corner RH, cross LH with partner
    to 2nd place own sides
25-32::
    2s+1s+3s set twice and turn partner 2H', 0);
INSERT INTO 'dancecrib' VALUES (6329, '2013-08-21 08:31:22.523112+00', '2023-02-04 01:21:14.560595+00', 7256, 3, NULL, 'ace', '1-8::
    1s set & cross RH to face down, set to 2s on sides & change places
    LH
9-16::
    1s+2s dance Ladies Chain & 1s end in 2nd place opposite sides facing
    up _while_ 2s face down
17-24::
    2s+1s+3s dance LSh reels of 3 (1s dance up to start)
25-32::
    1s turn 2H in centre & end BtoB (Lady facing up & Man down), 1s
    circle 3H round to left (Lady with 2s & Man with 3s) ending 2nd pl', 0);
INSERT INTO 'dancecrib' VALUES (6330, '2013-08-21 08:31:22.531332+00', '2023-02-04 01:21:14.591397+00', 4223, 3, NULL, 'ace', '{{explanation}}
Round the Room dance 2 facing 2

1-8::
    All set to facing couple, turn opposite person 2H, set to partners &
    turn 2H
9-16::
    All dance RH across & LH back
17-24::
    All dance Ladies Chain
25-32::
    Clockwise couple set turning right about _while_ other couple dance
    between setting couple & all turn RH, repeat passing another couple', 0);
INSERT INTO 'dancecrib' VALUES (6331, '2013-08-21 08:31:22.539639+00', '2023-02-04 01:21:14.622058+00', 4224, 3, NULL, 'ace', '1-4::
    1M+2M cross & dance RSh round partner down to 3rd/4th places _while_
    3L+4L cross & dance RSh round partner up to 1st/2nd places
5-8::
    Top 2 couples & bottom 2 couples dance RH across
9-12::
    1L+2L cross & dance RSh round partner down to 3rd/4th places _while_
    3M+4M cross & dance RSh round partner up to 1st/2nd places.
    (3)(4)(1)(2)
13-16::
    Top 2 couples & bottom 2 couples dance LH across
17-24::
    3s & 1s lead (LH) down between couple below, cross & cast up 1 place
    own sides, 4s & 2s lead (RH) up between couple above, cross & cast
    down 1 place own sides.  3 4 1 2
25-32::
    4s+1s 1/2 turn RH & dance H across 1/2 way  & all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (13759, '2021-03-02 01:20:52.763183+00', '2023-02-04 01:21:14.658084+00', 13512, 3, NULL, 'ace', '1-8::
    1s dance in, cast off 3 places, dance up to 2nd place own side,
    facing out (2s step up 7-8)
9-16::
    1s dance RSh round 3rd corner (1M up, 1L down) into lines of 3
    across (1M between 2s, 1L between 3s) ; 1M+2s also 1L+3s set, 1s
    dance in, pull back RSh to face 2nd corner.
17-24::
    1s dance Corner Pass+Turn with 2nd corner; 1s pull back RSh to face
    1st corner;  1s dance Corner Pass+Turn with 1st corner. 1s end
    turning 1/4 RH into Allemande hold, 2s & 3s step in & take Allemande
    hold
25-32::
    2s+1s+3s dance Allemande.  3 1 2 4
33-40::
    1s+2s change places RH on sides, 3s+2s also 1s+4s change places LH
    on sides;  all 4 couples turn partner RH.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13760, '2021-03-02 01:20:52.786751+00', '2023-02-04 01:21:14.689909+00', 13702, 3, NULL, 'ace', '1-8::
    1s dance down to BtoB facing 4s on own sides (2s step up 3-4); 1M+4M
    also 1L+4L set change places 2H. 4s pull back RSh to face each other
9-16::
    4s turn 2H (2 bars), dance up to top NHJ and cast to 2nd place own
    side
17-24::
    4s+3s set, dance 1/2 RH across; 2s+3s also 4s+1s dance 1/2 RH across
    opening out to 3s+2s also 1s+4s circle 4H 1/2 round to left
25-26::
    3M+4M make arch, dance across _while_ 3L+4L NHJ dance under arch.
    3s+4s end facing out
27-32::
    3s cast up round 2s, meet & dance down to 2nd place own side _while_
    4s cast down round 1s, meet & dance up to 3rd place own side. 2 3 4
    1', 0);
INSERT INTO 'dancecrib' VALUES (6332, '2013-08-21 08:31:22.547893+00', '2023-02-04 01:21:14.720384+00', 4226, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1L+2M also 3M+4L turn RH, 1M+2L also 3L+4M turn RH 1.1/2 times
9-16::
    1s+2s also 3s+4s dance RH across, Men dance LH across & end facing
    partners on sides
17-24::
    All Advance to partner 1 step, Retire & pass RSh, repeat & end
    Ladies on partners right facing anticlockwise
25-32::
    All dance round in Allemande hold to end in square set with 4s at
    top
33-40::
    All dance Grand Chain 1/2 way, Men pass partner RSh & chase 1/2 way
    _while_ Ladies dance LH across 1/2 way & face out to partner

{{title}}
Reel

1-16::
    All turn partners RH (4 bars) into double reels of 4
17-32::
    All dance full Schiehallion Reel
33-40::
    All Men dance RSh round partner & dance LH across to places', 0);
INSERT INTO 'dancecrib' VALUES (6333, '2013-08-21 08:31:22.557668+00', '2023-02-04 01:21:14.845718+00', 4227, 3, NULL, 'ace', '1-8::
    1s turn RH, cast to 2nd place, cross RH, 1s cast round 1st corner to
    form lines of 3 across with 2s/3s
9-16::
    1s set & turn RH to opposite sides between 2s+3s, set & turn RH to
    face 1st corners
17-24::
    1s set to & turn 1st corners 2H, set to & turn 2nd corners 2H
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners &
    cross to own sides', 0);
INSERT INTO 'dancecrib' VALUES (10448, '2018-02-24 07:52:55.419001+00', '2023-02-04 01:21:14.88013+00', 17774, 3, NULL, 'ace', '1-8::
    1s turn RH, cast off 1 place, cross RH, cast RSh round 1st corners
    to finish in lines across, 1M between 3s, 1L between 2s
9-16::
    All cross RH up & down, chase clockwise round (2 bars) to side
    lines, all cross RH & chase clockwise round (2 bars) into lines
    across, 1M facing 3M & 1L facing 2L (2nd corner positions)
17-24::
    1M+3s (at top) also 1L+2s (at bottom) dance RSh reels of 3 across,
    bars 19-20 1s 1/2 turn LH to continue in other reel. 1s finish in
    2nd place opp sides
25-32::
    1M+3s (at top) & 1L+2s dance RH across; all chase clockwise to own
    side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6334, '2013-08-21 08:31:22.590807+00', '2023-02-04 01:21:14.940893+00', 7457, 3, NULL, 'ace', '{{explanation}}
Each couple dances 80 bars. A new couple starts after 40 bars (ie on bars 41, 81 & 121)

1-8::
    1s lead down for 3 bars, back to top & cast to 2nd place
9-16::
    1s dance 1/2 Fig of 8 round 2s, set advancing & 1/2 turn 2H into
    double triangle position
17-24::
    2s+1s+3s set & 1s+2s change places, set again with 1s+2s advancing
    into middle facing up
25-32::
    1s+2s dance Allemande
33-40::
    All dance 8H round & back
41-48::
    (New Couple starts as at bar 1) _while_ 1s (original) continue
    casting to bottom, turn RH & cast up to 3rd place
49-56::
    1s (2s) dance 1/2 Fig of 8 round 4s (3s), set advancing & 1/2 turn
    2H into a double triangle position (nearer hand joined with new
    dancing couple - 2s)
57-64::
    All set & 1s+4s change places, set again with 1s+4s advancing into
    middle facing up
65-72::
    1s+4s dance Allemande (also 2s+3s)
73-80::
    All dance 8H round & back. E

{{explanation}}
Note: First time through only 1st couple dance bars 1-40.  Last time through only 4s dance bars 41-80', 0);
INSERT INTO 'dancecrib' VALUES (9389, '2016-10-06 07:18:40.527055+00', '2023-02-04 01:21:14.98241+00', 17138, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Grand Chain
9-16::
    1L followed by 1M casts to 2nd place opp sides (2s step up).  1M
    followed by 1L casts to 3rd place own side (3s step up)
17-24::
    2s+3s+1s set, turn partners 1/2 RH, pull back RSh & dance out to opp
    sides. All set
25-26::
    2s+3s+1s circle 6H 1/2 round to Left . 1 3 2
27-32::
    1s+2s dance ''The Capstan''
::
    _27-28_   1s NHJ dance down 2 places _while_ 2s cast up to 1st place
::
    _29-30_   2s NHJ dance down 2 places _while_ 1s cast up to 1st place
::
    _31-32_   1s NHJ dance down 2 places curving into 3rd place _while_
    2s cast up to first place', 0);
INSERT INTO 'dancecrib' VALUES (9390, '2016-10-06 07:18:40.535598+00', '2023-02-04 01:21:15.001082+00', 14815, 3, NULL, 'ace', '1-4::
    1s+2s & 3s+4s turn on sides (Ladies LH, Men RH)
5-8::
    1s+2s+3s dance 1/2 reels of 3 on opp sides (1s cross down, 2s out/up
    & cross down, 3s cross up)
9-12::
    3s+2s+1s dance 1/2 reels of 3 on own sides (3s cross down, 2s
    out/down & cross up, 1s cross up)
13-20::
    1s dance down 2 steps, turn 2H, dance down 2 steps, turn 2H to end
    in 4th place own sides (2s+3s+4s step up 19-20)
21-24::
    2s+3s & 4s+1s turn on sides (Ladies LH, Men RH) 1s & 3s face out
25-28::
    3s+4s+1s dance 1/2 reels of 3 on opp sides (3s out/down & cross
    down, 4s cross down, 1s out/up & cross up)
29-32::
    1s+4s+3s dance 1/2 reels of 3 on own sides (1s out/down & cross
    down, 4s cross up, 3s out/up & cross up)  1s & 3s face out.  End 2 3
    4 1', 0);
INSERT INTO 'dancecrib' VALUES (14003, '2021-05-03 00:20:40.610787+00', '2023-02-04 01:21:17.682201+00', 17250, 3, NULL, 'ace', '1-8::
    1L+1M+2M dance reel of 3 on Men''s side (1L passes 2M LSh to start),
    1L dances loop back to place
9-16::
    1M+1L+2L dance reel of 3 on Ladies'' side (1M pass 2L RSh to start),
    1M dances across to place facing down
17-24::
    1s+2s dance LH across; 1s+2s dance RH across
25-32::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s', 0);
INSERT INTO 'dancecrib' VALUES (14121, '2021-07-07 00:20:21.381989+00', '2023-02-04 01:21:15.021023+00', 4231, 3, NULL, 'ace', '1-4::
    1s & 4s set, 1s cast as 2s dance up & face out _while_ 4s cast up as
    3s dance down & face out
5-12::
    2s+1s also 4s+3s dance Double Figs 8
13-16::
    1s+4s dance LH across to end facing nearest corner (1L+2L, 1M+2M,
    4L+3L, 4M+3M)
17-24::
    All set, 1s & 4s turn corners 2H twice round (6 bars), Bars 23-24:
    1s+4s dance 1/2 LH across to end facing diagonally opposite corner
25-32::
    All set, 1s & 4s turn corners 2H twice round (6 bars), Bars 31-32:
    1s & 4s turn partner LH to end 1s in 3rd place own side facing down,
    4s in 2nd place own side facing up
33-40::
    All dance reels of 4 on sides
41-48::
    All circle 8H round & back.  2 4 1 3
::
    Repeat once from new positions', 0);
INSERT INTO 'dancecrib' VALUES (6335, '2013-08-21 08:31:22.600717+00', '2023-02-04 01:21:15.037857+00', 4232, 3, NULL, 'ace', '1-8::
    1M followed by 1L cast 1 place & cross to opposite sides then cast
    down 1 place, cross to own sides & cast up to 2nd place then cross
    to opp sides
9-16::
    1s dance LSh reels of 3 on opposite sides 1M+2M ending facing out
17-24::
    2s+1s dance Ladies Chain
25-32::
    1s+3s dance RH across, 1s dance 1/2 fig. of 8 round 2s', 0);
INSERT INTO 'dancecrib' VALUES (8605, '2015-02-13 12:48:00.408734+00', '2023-02-04 01:21:15.054741+00', 12688, 3, NULL, 'ace', '1-6::
    1L+3M dance in, pull back RSh to finish BtoB facing ptnrs.  1s+3s
    dance 1/2 diag reel of 4
7-8::
    3L+1M dance to own sides. 3M dances to top, 1L to 3rd place - all on
    own sides.  3L+1M curve by Right towards centre ready for …
9-16::
    1s+2M dance reel of 3 on diag (between 1M & 2L places) also 3s+2L
    (between 2M & 3L places)  with 1M+1L also 3M+3L passing RSh, 2L & 2M
    dance to Right to start. 2s finish in own places
17-24::
    1L followed by 1M also 3M followed by 3L chase clockwise round to
    original places.  1s+2s dance RH across, finishing ready for …
25-32::
    1s+2s dance allemande', 0);
INSERT INTO 'dancecrib' VALUES (6336, '2013-08-21 08:31:22.667717+00', '2023-02-04 01:21:15.18485+00', 4233, 3, NULL, 'ace', '1-8::
    1s cross down & dance out between 2s+3s turning 3s by near hand,
    cross up & dance out between 2s+3s turning 2s with nearer hand into
    double triangle positions facing own sides
9-16::
    All set & 1s turn 3rd corners RH to double triangle position facing
    opp sides, all set & turn 1st corners RH to end between 2s/3s in
    lines across
17-24::
    1s dance reels of 3 across (LSh to 4th corner) 1s pass LSh ending in
    2nd place own sides, 1M facing up, 1L facing down
25-32::
    1s dance reels of 3 on sides (RSh to 3rd corner to start) then 1s
    cross to 2nd place opp side, dance 1M to 3rd place, 1L to 1st place
    opp sides & cross to 2nd place own side (2s+3s dance normal reels of
    3)

{{explanation}}
Second repeat 1s end crossing to 4th place', 0);
INSERT INTO 'dancecrib' VALUES (13266, '2020-10-16 00:20:57.498994+00', '2023-02-04 01:21:15.212495+00', 11615, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance mirror reels of 3 on sides (1s out/down, 2s in/up, 3s
    out/up). End 2s in 1st place, 1s in 2nd place, 3s in 3rd place
9-16::
    1s dance 1/2 diag R&L with 2L&3M (Man up, Lady down), 1/2 diag R&L
    with 2M&3L. 1s end BtoB in centre facing 1st corners (in 3rd corner
    pstn)
17-24::
    1s+corners set & turn 2H, 1s face 2nd corner (in 4th corner pstn);
    1s+corners set & turn 2H _while_ 1st corners chase clockwise 1/2
    round back to original places
25-32::
    1s+1st corners set & turn 2H _while_ 2nd corners chase clockwise 1/2
    round back to original places. 1s end BtoB facing 2nd corners
33-40::
    1s+2nd corners dance diagonal reel of 4. 1s pass LSh to face 1st
    corners
41-48::
    1s+1st corners dance diag reel of 4. 1s loop into 2nd place own side
    facing out.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6337, '2013-08-21 08:31:22.675977+00', '2023-02-04 01:21:15.243113+00', 4236, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross LH & cast to left to end facing 1st
    corner
9-16::
    1s set to & turn 1st corners RH, set & turn 2nd corners RH & end
    BtoB in middle (Man facing up)
17-24::
    1s dance Crown Triangles & Petronella turn to 2nd place on own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10338, '2017-12-22 15:44:42.08605+00', '2023-02-04 01:21:15.306888+00', 4238, 3, NULL, 'ace', '1-8::
    1s & 4s set twice, turn partners RH & cast down/up 1 place (2s step
    up, 3s step down)  2 1 4 3
9-16::
    RSh reels of 3 on sides, 1L+4L+3L (bottom 3 on Ladies'' side) &
    2M+1M+4M (top 3 on Men''s side), 1L+4L  also 4M+1M pass RSh to start
17-24::
    RSh reels of 3 on sides, 2L+1L+4L (top 3 on Ladies'' side) & 1M+4M+3M
    (bottom 3 on Men''s side), 1L+4L also 4M+1M pass RSh to start
25-32::
    1s+2s also 3s+4s dance RH across, LH back (6 bars) then 1s cast up,
    4s cast down, 2s & 3s dance up/down so all back in original places
33-36::
    1s+2s dance 1/2 R&L
37-40::
    1s+3s dance 1/2 R&L
41-44::
    1s+4s dance 1/2 R&L
45-48::
    All 4 couples cross RH  to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12409, '2019-12-05 01:30:57.855878+00', '2023-02-04 01:21:15.34635+00', 19413, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step 3-4); 1s+3s turn RH to finish in centre
    facing up
9-16::
    1s+3s dance Allemande ending with 3s casting back to 3rd place
    _while_ 1s lead up to face 1st corners
17-24::
    1s+1st corners dance Corner Chain, 1s face 2nd corners
25-32::
    1s+2nd corners dance Corner Chain, 1s end in 2nd place own side.  2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (14912, '2022-06-27 00:20:53.966425+00', '2023-02-04 01:21:15.373697+00', 10753, 3, NULL, 'ace', '1-8::
    1s dance in & cast (2s step up); 2M+1M dance between partners & cast
    back to place.  2 1 3
9-16::
    _9-10_    2L+1L advance NHJ _while_ 2M+1M also advance to end
    2M-2L-1L-1M
::
    _11-16_  2s turn 1.1/2 RH _while_ 1s turn 1.1/2 LH, couples dance
    out to sides curving into place.  2 1 3
17-24::
    1s Petronella turn to 1M between 3s facing up, 1L between 2s facing
    down, 1L+2s Adv+Ret & set _while_ 1M+3s set, Adv+Ret
25-32::
    1s Petronella turn to 2nd place opp sides & 2s+1s+3s set; 1s cast to
    3rd place (3s step up) & cross RH to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6340, '2013-08-21 08:31:22.705122+00', '2023-02-04 01:21:15.40206+00', 10881, 3, NULL, 'ace', '1-8::
    Men pass partner RSh & 4M followed by 3M+2M+1M casts to Right and
    chase up Men''s side to 1st place
9-16::
    All turn person opposite RH then LH
17-32::
    Ladies repeat bars 1-16.   4 3 2 1
33-40::
    4s cast to bottom, followed by 3s+2s+1s who dance up sides to start
    (4 bars).  All now in original places turn partner RH.  1 2 3 4
41-48::
    1s cast to 4th place (2s+3s+4s step up 43-44)  1s turn RH (4 bars).
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8300, '2014-07-29 12:58:41.032353+00', '2023-02-04 01:18:26.610518+00', 15220, 3, NULL, 'ace', '1-8::
    All Men pass partner RSh, dance down behind Ladies & back up Men''s
    side   4 3 2 1
9-16::
    All Ladies pass opp. Man RSh, dance up behind Men & down Ladies side
    4 3 2 1
17-24::
    All Adv+Ret, 4s dance down to 4th place (3s+2s+1s step up 23-24) 3 2
    1 4
25-32::
    3s+2s also 1s+4s dance Poussette   2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6341, '2013-08-21 08:31:22.715076+00', '2023-02-04 01:21:15.434383+00', 4243, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig 8 round 2s; 1s+2s dance 1/2 R&L
9-16::
    2s dance 1/2 Fig 8 round 1s; 1s turn RH once round to end facing own
    side in double triangle formation
17-24::
    All set, 1s PdB round to face opp side _while_ 2s+3s petronella turn
    1 place anticlockwise; all set (as double triangles), 1s PdB pivot
    round to face 1st corner (pstn) _while_ 2s & 3s petronella turn
    another place anticlockwise.
25-32::
    1s dance 1/2 diag reel of 4 with 1st crnrs, pass RSh to dance 1/2
    diag reel of 4 with 2nd crnrs & pass RSh to 2nd places on own side.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6342, '2013-08-21 08:31:22.723053+00', '2023-02-04 01:21:15.454394+00', 10789, 3, NULL, 'ace', '1-8::
    1s cross RH, 1s+3s dance 3/4 Fig of 8 round 2s (3s cross up to
    start).  3 2 1
9-16::
    2s+1s cross RH, 2s+1s dance RH across 1/2 way, 3s & 1s cross RH &
    dance RH across 1/2 way.  1 3 2
17-24::
    1s+3s circle 4H round to left, 1s dance down, cast up round 2s (3rd
    pl) to 2nd place
25-32::
    3s+1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (6343, '2013-08-21 08:31:22.799234+00', '2023-02-04 01:21:15.583442+00', 8507, 3, NULL, 'ace', '1-4::
    1M+2L also 2M+3L set (do not give hands on sides), change places RH
    to face out on opp sides
5-8::
    1M+2M also 2L+3L chase round 3rd/1st place clockwise to change
    places (on own sides)
9-16::
    1L+1M also 3M+3L set, change places LH & chase round 1st/3rd place
    anticlockwise changing places on own sides
17-24::
    3s+1s advance, retire diagonally with partner & turn partner RH to
    face up
25-32::
    3s+1s dance Allemande _while_ 2L dances up to top on bars 27-28.  2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (8606, '2015-02-13 12:48:00.585586+00', '2023-02-04 01:21:15.614015+00', 15308, 3, NULL, 'ace', '1-8::
    1s dance in, cast to 2nd place, turn 3/4 RH  to join LH with 1st
    corners & balance in line
9-16::
    1s turn 1st corners LH into prom hold (cnrs on Left of 1s) &
    promenade clockwise 1/2 way round. Corners finish in opp corner pstn
    _while_ 2nd corners change places RH and twirl (pull back RSh) out
    to opp corner
17-20::
    1s turn 3/4  RH, join LH with 2nd corner person (4th corner pstn) &
    balance in line
21-28::
    1s & 2nd corners repeat bars 9-16 _while_ 1st corners change places
    RH and twirl (pull back RSh) out to sides
29-32::
    1s turn 3/4 RH to 2nd place own sides.  2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (12647, '2020-03-02 01:53:19.286589+00', '2023-02-04 01:21:15.720438+00', 17371, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance reels of 4 across, 1L+2M & 3L+4M pass LSh to
    start.  End 2 1 4 3 5
9-16::
    1s+3s dance through new places into 1M+2s, 1L+4s+3M & 3L+5s  dance
    RH across & LH across back to place
17-20::
    _1/2_ Fig 8, 1s down round 4s, 3s down round 5s
21-24::
    _1/2_ Fig 8, 1s up round 2s, 3s up round 4s
25-32::
    1s+4s & 3s+5s Set+Link;  All 5 couples turn partners 2H.  End 2 4 1
    5 3', 0);
INSERT INTO 'dancecrib' VALUES (6345, '2013-08-21 08:31:22.815697+00', '2023-02-04 01:21:15.747054+00', 4251, 3, NULL, 'ace', '1-8::
    1M+4L 1/2 turn RH, cast up behind own line back to place _while_
    partners cast down behind own line & turn RH back to place
9-16::
    1s+2s also 3s+4s dance RH across for 3 steps, LH back & all turn
    partners LH to end in lines of 4 across facing up with Men side by
    side in middle
17-24::
    All Coupe & Shed for 8 bars ending with 3M & 4M turning to face down
25-32::
    Men cast round partner to meet other Man & turn RH, 1M+2L also 4M+3L
    change places RH & dance 1/2 RH across with ptnrs to end 2 1 (4)(3)
33-40::
    1s+4s+3s set, 1s cross & cast to bottom _while_ 4s turn 1/2 RH, lead
    up & cast to 3rd place _while_ 3s turn 1/2 RH & lead to 2nd place,
    1s cross to 4th pl', 0);
INSERT INTO 'dancecrib' VALUES (9212, '2016-06-16 22:42:04.44203+00', '2023-02-04 01:21:15.912148+00', 16865, 3, NULL, 'ace', '1-8::
    All dance interlocking reels of 4 (pass partner RSh to start) & end
    by turning RH to bring Men into centre
9-16::
    Men dance LH across twice round as Ladies chase clockwise (small
    steps) all back to places. All 1/2 turn partners RH to put Ladies in
    centre
17-24::
    Ladies dance LH across twice round as Men chase clockwise (small
    steps) all back to places. All 1/2 turn partners RH into prom hold
    facing anticlockwise
25-32::
    All promenade anticlockwise & when 1s reach the bottom (4 bars)  all
    dance up middle to form longwise set. (4 bars)  Order is 1 2 3
33-40::
    All dance up (no hands) casting at top to dance down to bottom,
    cross over (Ladies in front of Men) & dance up opposite sides to
    partners place.
41-48::
    All dance up (no hands) casting at top to dance down to bottom,
    cross over & dance up own sides to place.
49-52::
    All turn partners approx twice round 2H, 2s passing between 1s & 3s
    during turn to form triangular set (as at start)
53-56::
    All circle 6H round to Left.  All take allemande hold ready for ...
57-64::
    All allemande anticlockwise back to place (bar 62), slow LH 1/4 turn
    so Ladies in centre BtoB facing partner for bow/curtsey', 0);
INSERT INTO 'dancecrib' VALUES (6346, '2013-08-21 08:31:22.859563+00', '2023-02-04 01:21:15.955768+00', 4256, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+3s change places (1s dancing between 3s) as 2s & 4s set HS, 2s+4s
    change places (2s dancing between 4s) as 1s & 3s set HS
17-24::
    All dance 1/2 Grand Chain (back to places), all set to partners &
    turn 2H
25-32::
    1L & 3L set adv to corners (Man on their right), turn 2H ending in a
    diagonal line with corners facing the top & set, 1L+3L set to each
    other
33-40::
    1L & 3L in a diagonal line facing bottom set, 1L & 3L set to
    corners, turn 2H & pass corners RSh back to original places
41-56::
    2l & 4L repeat bars 25-40
57-64::
    All Ladies dance RH across, curve out & round partner LSh to
    original places
65-72::
    1M+4M dance Figs of 8 round 1L+4L as 2M+3M dance Figs of 8 round
    2L+3L Men passing LSh in middle & RSh round Ladies
73-80::
    All 4 couples in Allemande hold dance anticlockwise round set to
    places', 0);
INSERT INTO 'dancecrib' VALUES (6354, '2013-08-21 08:31:22.984348+00', '2023-02-04 01:21:15.973575+00', 4262, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels of 3 on sides all crossing at top to end on
    opposite sides.  (1)(2)(3)
9-16::
    1s cross RH & cast 1 place, dance 1/2 Figs of 8 (1L round 2s & 1M
    round 3s)
17-24::
    1s dance 1/2 reels of 3 on opposite sides giving RSh to 2nd corner,
    3s+1s+2s set & 1/2 turn RH
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (13420, '2020-12-02 01:20:45.894296+00', '2023-02-07 22:11:48.952242+00', 4246, 3, NULL, 'ace', '{{explanation}}

Double circle - Men on inside, backs to centre, facing partner



1-8::

    All set, change places RH with partner; repeat

9-16::

    Ladies dance Fig 8 round Men, RSh round Man on right, LSh round

    partner back to place

17-24::

    Men dance Fig 8 round Ladies, LSh round Lady to left, RSh round

    partner back to place

25-32::

    All promenade anticlockwise (4 bars); Men stand _while_ Ladies dance

    on, past 1 Man to meet the next as new partner', 0);
INSERT INTO 'dancecrib' VALUES (3997, '2013-08-21 08:30:41.001304+00', '2023-02-04 01:18:26.688227+00', 137, 3, NULL, 'ace', '1-8::
    1s advance for 2 steps, hold RH, retire & dance DoSiDo
9-14::
    1s turn LH (3 bars), 1L dances between 2s & casts back to 1st place
    as 1M casts to 3rd place (2M+3M step up 13-14)
15-16::
    1s set to opposite dancer (1L+2M, 1M+3L)
17-20::
    1L+2s dance RH across but 1L casts to 3rd place Men''s side _while_
    2s complete RH across
::
    _while_ 1M+4s dance LH across, 1M dances out through 3M''s place to
    meet partner (behind 3M''s place in prom hold facing down)
21-24::
    1s in prom hold dance down behind 4M & up between 4s to 3rd place &
    end facing up with nearer hands joined
25-32::
    1s followed by 4s dance up to top under arches made by 2s+3s, cast
    on own sides to 4th & 3rd places.  2 3 4 1
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6355, '2013-08-21 08:31:22.992481+00', '2023-02-04 01:21:15.991392+00', 4268, 3, NULL, 'ace', '1-8::
    1s cross RH, cast, cross up & cast to 2nd place _while_ 2s 1/2 turn
    RH, dance up, cast & cross up to top places
9-16::
    2s+1s+3s dance reels of 3 on sides (1s in & down to start)
17-24::
    1s petronella turn & set twice _while_ 2s & 3s cast (1/2 place) &
    join hands on sides, cross (Ladies dance under Men''s arch) & 3s
    dance to top as 2s to 3rd place & cross RH to own side
25-32::
    1s petronella turn & set twice back to places _while_ 2s & 3s repeat
    previous Fig but 1/2 turn partner at end
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6410, '2013-08-21 08:31:23.952505+00', '2023-02-17 19:27:51.74273+00', 9009, 3, NULL, 'ace', '1-8::

    1s followed by 2s+3s+4s dance down & cast round 5s back to places

9-16::

    1s & 5s dance Figs of 8 on own sides (1s down between 2s & 5s up

    behind 4s to start)

17-24::

    1s+2s dance RH across, 1s cross down & 1/2 turn 3s (LH Men''s side &

    RH Ladies side)

25-32::

    1s+4s dance LH across, 1s cross down & 1/2 turn 5s (LH Men''s side &

    RH Ladies side).  2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (6357, '2013-08-21 08:31:23.010162+00', '2023-02-04 01:21:16.076507+00', 4270, 3, NULL, 'ace', '1-8::
    1s lead down, lead back to top & cast to 2nd places
9-16::
    1s repeat above Fig to 3rd places
17-24::
    2s+3s+1s circle 6H round & back
25-32::
    1s dance up to top & cast to 2nd places, 2s+1s dance R&L (1 bar per
    hand)', 0);
INSERT INTO 'dancecrib' VALUES (9481, '2016-11-09 08:48:45.071162+00', '2023-02-04 01:21:16.114849+00', 4273, 3, NULL, 'ace', '1-8::
    1s lead down, cross & cast up round 3s to top place opp sides, dance
    in & 1/2 turn 2H (PdB), 2s step in ready for…
9-16::
    1s+2s Poussette, Bar 15-16 1s remain in centre & turn extra 1/4 2H,
    opening out to end BtoB, 1M facing up, 1L facing down
17-24::
    1s dance RSh round 2nd corners & turn 1.1/2 RH to 2nd place own
    sides _while_ 2s+3s set, cross RH, set, cross back RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6363, '2013-08-21 08:31:23.081084+00', '2023-02-04 01:21:16.273852+00', 4280, 3, NULL, 'ace', '1-8::
    1s+2s+3s turn partners RH & then turn LH
9-16::
    1s set & cast 1 place, 2s+1s dance RH across
17-24::
    1s set & cast 1 place, 3s+1s dance LH across
25-32::
    2s+3s+1s dance Grand Chain', 0);
INSERT INTO 'dancecrib' VALUES (6364, '2013-08-21 08:31:23.091244+00', '2023-02-04 01:21:16.455535+00', 4283, 3, NULL, 'ace', '1-8::
    1s & 3s advance to centre with 4 PdB, 1s dance between 3s & turn to
    face 4s _while_ 3s turn to face 2s (2 parallel diagonal lines of 4)
9-16::
    1s & 4s also 2s & 3s dance RH across & LH back
17-24::
    All set to partners twice, turn 2H into diagonal lines of 4 in other
    direction (1M & 4M, 2M & 3M BtoB)
25-32::
    All dance RSh parallel diagonal reels of 4
33-40::
    All set to partners & turn 2H to square formation (1s in 3rd pl), 1s
    & 3s in prom hold dance clockwise behind 2s/ 4s to original places
41-56::
    Men dance in front of partner & turn next Lady RH, repeat 3 times
    ending back in original places
57-64::
    Ladies dance into centre (PdB), turn setting & set to partner twice
65-72::
    Ladies dance back to places as Men dance in who turn setting & set
    to partner twice
73-80::
    Men dance out & behind partner back to places, all set to partners
    twice
81-96::
    All dance Grand Chain
97-104::
    All set twice to partner & turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (15344, '2022-12-19 01:20:55.691266+00', '2023-02-04 01:21:16.475118+00', 21133, 3, NULL, 'ace', '1-4::
    1s+2s set & mirror Link (1s dance down, 2s cast up). 1s finish
    facing out.
5-8::
    1s+3s set & change places on the sides (Men LH, Ladies RH). 3s end
    facing out   2 3 1
9-16::
    All dance mirror reels of 3 on the sides (3s dance/up to start)
17-20::
    All set, Adv+Ret (1 step each)
21-32::
    All dance R&L for 3 couples.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (12090, '2019-08-30 09:54:36.186101+00', '2023-02-04 01:21:16.503069+00', 19231, 3, NULL, 'ace', '1-8::
    1s dance in, cast to 4th place & dance up to original place as 4s
    set, dance up & cast back to 4th place
9-16::
    2s+3s set, 2s dance up as 3s dance down & 2s+3s cast back to
    original places & turn partners RH
17-24::
    1s cross RH, cast, meet & dance down & out below 3s, cast to 4th
    place & croos RH to own side. (2s step up 3-4, 3s on 5-6, 4s on 7-8)
25-32::
    All circle 8H round & back.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (15139, '2022-10-05 00:20:55.690991+00', '2023-02-04 01:21:19.544144+00', 10852, 3, NULL, 'ace', '{{title}}
Strathspey

1-4::
    All set on sides, 1s set advancing to face 1st corners (1M passes in
    front of 1L, 2s step up)
5-8::
    1s set to & turn 1st corners 2H to face 2nd corners
9-16::
    1s set to & turn 2nd corners 2H to finish between corners on
    opposite sides;1s turn 2H in the middle & retain hands.

{{title}}
Reel

1-8::
    1s dance a one couple Poussette (1/4 turn, travel down, 1/4 turn,
    1/4 turn, travel down, 1/4 turn, 1/2 turn & retire) down the middle
    to 4th place as 3s+4s step up on bars 7-8
9-16::
    4s+1s dance R&L.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6369, '2013-08-21 08:31:23.134123+00', '2023-02-04 01:21:16.542213+00', 10183, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    Ladies dance reel of 4 (1L passing 2L & 3L passing 4L RSh to start)
    _while_ Men chase anticlockwise (all end passing LSh to partners
    place)
9-16::
    All dance 1/2 reverse Schiehallion reel (to left & Men follow
    Ladies).
17-24::
    Men dance reel of 4 (1M passing 2M & 3M passing 4M to start) _while_
    Ladies chase anticlockwise (all pass LSh at end to partners place)
25-32::
    All dance 1/2 reverse Schiehallion reel (2 places to left & Men
    follow Ladies).  All now in original places
33-40::
    Men dance 1/2 LH across _while_ Ladies chase 1 place clockwise, turn
    facing Lady RH & repeat 1/2 turning partner RH turn at end
41-48::
    Ladies dance 1/2 LH across _while_ Men chase 1 place clockwise, turn
    facing Man RH & repeat

{{title}}
Reel

1-8::
    Men turn Ladies RH into cross with Ladies joined LH in middle,
    Balance, turn Men into middle & Balance, turn into prom hold facing
    clockwise
9-16::
    All Promenade round
17-24::
    1s+4s & 2s+3s pass RSh to end in longwise set (2 3 1 4 - 2s & 1s on
    opp sides), turn partners RH & 2s+3s also 1s+4s dance 1/2 RH across
25-32::
    Men dance reel of 4 (3M+2M, 1M+4M pass RSH to start)
33-40::
    All chase clockwise 1/2 way
41-48::
    1s & 3s turn partner RH _while_ 2s+4s dance 1/2 RH across, all turn
    partners RH moving to original places in square formation
49-56::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12924, '2020-07-01 00:20:34.513984+00', '2023-02-04 01:21:16.556734+00', 17596, 3, NULL, 'ace', '{{title}}
Strathspey

1-4::
    1s+2s+3s dance Gypsy Turn (dance round partner by RSh)
5-16::
    1s+2s+3s dance R&L for 3 couples
::
    _5-6_    All 3 couples cross RH with dancer opposite
::
    _7-8_    Dancers in 1L place & 3M place change places diagonally LH
    _while_ other couples change places LH on side
::
    _9-16_  Repeat bars 1-4 twice more from new places (No polite turns
    until bar 16)
17-24::
    1s dance down, cast behind 3s, dance up & cast up behind 2s back to
    1st place
25-32::
    1s+2s+3s circle 6H round & back

{{title}}
Jig

1-8::
    1s+2s+3s cross RH & set; all turn partners RH. 1s face out
9-16::
    1s cast (2s step up), set; 1s cross down giving LH, cast up round 3s
    & meet in middle joining LH
17-24::
    1s dance Corner Targe :
::
    _17-20_   corners chase clockwise to next corner _while_ 1s 3/4 turn
    LH.  1s turn 3rd corner pstn RH (1M+3L, 1L+2M) _while_ 2nd corners
    set
::
    _21-24_   corners chase clockwise to next corner _while_ 1s 3/4 turn
    LH.  1s turn 2nd  corners pstn RH (1M+3L, 1L+2M ) to end in 2nd
    place opp sides  _while_ 2nd corners set.  End 3 (1) 2
25-32::
    3s+1s+2s dance 1/2 reels of 3 on sides (1s LSh to 1st corner); 1s
    cross RH & cast to 3rd place.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (10085, '2017-09-03 23:45:00.762796+00', '2023-02-04 01:21:16.574477+00', 16206, 3, NULL, 'ace', '{{explanation}}
Round the Room, 2 facing 2

1-8::
    Ladies dance Fig 8 round Men (pass LSh in middle, dance Right round
    opp Man, pass RSh in middle & dance Left round partner)
9-16::
    All chase anticlockwise round back to place (4 bars) & dance RH
    across
17-24::
    Men dance Fig 8 round Ladies (pass RSh in middle, dance Left round
    opp Lady, pass LSh in middle & dance Right round partner)
25-32::
    "Progressive Rights + Lefts"
::
    All change places RH with opp person & LH with partner
::
    All change places RH with opp person (do not change direction of
    travel round room) & LH with partner (Men polite turn) to face new
    couple', 0);
INSERT INTO 'dancecrib' VALUES (14536, '2022-01-10 02:20:04.746449+00', '2023-02-04 01:21:16.591154+00', 17971, 3, NULL, 'ace', '1-8::
    1s cast (2s step up), 2s+1s+3s set; 1s dance DoSiDo with 1st corners
9-16::
    1s dance DoSiDo with 2nd corners; 2s+1s+3s set & 1s cast to 3rd
    place (3s step up)
17-24::
    2s+3s+1s Adv+Ret; 2s+3s+1s turn partners RH once round into prom
    hold facing up ready for …
25-32::
    2s+3s+1s promenade', 0);
INSERT INTO 'dancecrib' VALUES (6370, '2013-08-21 08:31:23.142232+00', '2023-02-04 01:21:16.605136+00', 4291, 3, NULL, 'ace', '1-8::
    1s+2s dance reel of 4 across (1M & 2L pass LSh _while_ 1L & 2M
    cast), 1L+2M pass RSh at end, 1L ends facing out
9-16::
    1s dance parallel Figs of 8 round 2s & 3s on own sides (pass 2s RSh
    to start)
17-24::
    1L followed by 1M casts round 2L, cross down between 3s, cast up to
    2nd place on Men''s side & cross to own side as 1M ends Men''s side
    (2s step up on bars 19-20)
25-32::
    1s dance RH across with 3s & LH across with 2s
33-40::
    2s+1s+3s dance reels of 3 on own sides (1s giving RSh to 3s to
    start)
41-48::
    2s+1s+3s circle 6H round & back. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9019, '2015-11-30 09:00:01.179558+00', '2023-02-04 01:21:16.738981+00', 10588, 3, NULL, 'ace', '1-8::
    All clap as 1s cross passing RSh, cast (2s step up). 1s petronella
    turn to 1M between 2s, 1L between 3s & all set
9-16::
    RSh reels of 3 across, 1s pass person on Right  by RSh to start (6
    bars).  All clap as 1s petronella turn to 2nd place own sides
17-24::
    1s dance down middle and back, stay in centre, 2s step down (19-20)
    & in behind 1s ready for …
25-32::
    1s+2s dance Allepousse:
::
    1s dance figure of allemande as 2s dance poussette', 0);
INSERT INTO 'dancecrib' VALUES (10222, '2017-11-04 01:45:44.649074+00', '2023-02-04 01:21:16.756137+00', 18029, 3, NULL, 'ace', '1-8::
    1L & 3L dance Figs of 8 round corner & partner, start dancing in
    front of corner
9-16::
    1s & 3s set approaching & 1/2 turn facing person to end facing side
    couples. 1L & 3M dance between 4s & cast (1L to 3rd place, 3M to 1st
    place) as 1M & 3L dance between 2s & cast (1M to 3rd place & 3L to
    1st place) & pass partner by right to finish
17-24::
    1M & 3M dance Figs of 8 round new corner & partner, start by passing
    corner LSh
25-32::
    All circle 1/2 way round set; 1s+4s & 3s+2s dance 1/2 Diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (14211, '2021-08-14 00:20:51.476425+00', '2023-02-04 01:21:16.773036+00', 12314, 3, NULL, 'ace', '1-8::
    1s+2s set & cross RH; 1s+2s set & cross LH retaining LH with partner
    & couples join LH in centre
9-10::
    1M+2L drop LH & set _while_ 1L+2M turn, retaining LH hold. At end of
    bar 10 1M+2L rejoin LH figure
11-12::
    1L+2M set _while_ 1M+2L turn, retaining LH hold. At end of bar 12
    1L+2M rejoin LH figure
13-16::
    Repeat bars 9-12. On bar 16 all return to side lines, 1s facing out.
    1 2 3
17-18::
    1s cast to 2nd place _while_ 2s step up
19-24::
    1s dance reels of 3 across (1L LSh to 2M at top, 1M LSh to 3L). 1s
    end in 2nd place own side
25-30::
    1s dance reels of 3 across with other couple (1L RSh to 3M, 1M RSh
    to 2L)
31-32::
    1s NHJ dance down between 3s & curve outwards into 3rd place _while_
    3s cast up into 2nd place. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (10836, '2018-06-11 00:36:43.326786+00', '2023-02-04 01:21:16.788407+00', 17475, 3, NULL, 'ace', '1-4::
    1s+3s dance 1/2 Fig 8 around nearest side couple (1M+3L round 2s,
    1L+3M round 4s) to finish in opp place, taking prom hold with
    partner (Ladies on Left of Man)
5-8::
    1s+3s in prom hold dance 1/2 reel of three across (3s pass 4M & 1s
    pass 2M RSh to start)
9-16::
    2s and 4s repeat bars 1-8 (2s pass 3L & 4s pass 1L RSh to start
    reels up/down set). All finish in original positions.
17-20::
    All set, all dance 2 bars of Schiehallion Reels
21-24::
    All set with ''new'' partner & all dance 2 bars of Schiehallion Reels
    (all now 1 place round anticlockwise with original partner)
25-28::
    All turn partner RH and turn corner LH
29-32::
    All turn partner RH into prom hold and dance on one place round
    anticlockwise to end opposite original place
::
    Repeat 1 more time from new positions', 0);
INSERT INTO 'dancecrib' VALUES (3998, '2013-08-21 08:30:41.014868+00', '2023-02-04 01:18:26.712079+00', 141, 3, NULL, 'ace', '1-8::
    1s dance down the middle & turn 3s with nearer hand, dance back to
    top & turn 2s with nearer hand to end 1 2 3
9-16::
    1s+2s dance double Fig of 8 (1s casting to start)
17-24::
    1s cast 1 place, turn 2H, cast to bottom & turn 2H
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6372, '2013-08-21 08:31:23.195239+00', '2023-02-04 01:21:16.803757+00', 4299, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, dance down between 3s & cast up 1 place to 1L
    between 2s & 1M between 3s all facing down
9-16::
    Al dance down & back with 2s+1L turning to face down
17-24::
    2s+1s+3s set, change places RH with opp dancer, 1L casts up Men''s
    side & crosses to 2nd pl own side as 1M follows to end on 2nd pl own
    side
25-32::
    3s+1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (6374, '2013-08-21 08:31:23.259814+00', '2023-02-04 01:21:16.844199+00', 7458, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, cross LH & cast 1 place, Lady up & Man
    down
9-16::
    1s dance RSh reels of 3 across (1L RSh to 2M & 1M RSh to 3L).  1s
    end facing 2nd corners
17-24::
    1s dance reels of 3 on opposite sides giving LSh to 2nd corners & 1s
    end turning RH to face up on opposite sides
25-32::
    1s lead up, cross & cast to 2nd place own sides; 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (8607, '2015-02-13 12:48:00.950595+00', '2023-02-04 01:21:16.861617+00', 12689, 3, NULL, 'ace', '1-8::
    1s dance down for 2 steps (2s step up), face & set passing LSh to
    finish BtoB facing 1st crns.  1s set to1st cnrs, set to 2nd cnrs &
    finish LSh to LSh, 1L facing down, 1M facing up
9-16::
    RH across on sides, 1M+2L+3L and 1L+2M+3M. 1s pass RSh to swap sides
    and dance LH across. 1s finish facing 3rd cnrs
17-24::
    1s set to 3rd cnrs, set to 4th cnrs, pull back LSh to face each
    other, turn LH and cast off (3s step up 23-24)   2 3 1
25-32::
    3s+1s dance Diamond (all-round) Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6375, '2013-08-21 08:31:23.268109+00', '2023-02-04 01:21:16.87425+00', 9873, 3, NULL, 'ace', '{{title}}
Part A

1-8::
    All face partner & dance 1/2 Grand Chain (1 bar each hand), set
    advancing to partner & turn 2H
9-16::
    All continue Grand Chain back to places, set advancing to partner &
    turn 2H to face in NHJ
17-32::
    All advance into centre, retire with corners, set HS to corners,
    turn corner 2H (4 bars) to face in NHJ, advance with corners &
    retire with partners to original places

{{title}}
Part B

33-36::
    1s & 3s cast away from partner, dance 1/4 round set to meet opp
    dancer behind standing 2s/4s, dance in between 2s/4s & curve away
    from partner to face 2s/4s (lines of 4 across)
37-44::
    Reels of 4 across, 2s & 4s ending in original places, 1s+3 omit
    passing LSh to end in line up/down with Ladies BtoB in centre facing
    partners (1M facing down, 3M up)
45-48::
    1s+3s set to partners & turn 2H back to places
49-64::
    2s & 4s repeat bars 33-48, with reels up/down, ending in lines
    across, Ladies BtoB in centre facing partners

{{title}}
Part C

65-80::
    All advance into centre, retire with corners, set HS to corners,
    turn corner 2H (4 bars) to face in NHJ, advance with corners &
    retire with partners to original places
81-96::
    All face partner & dance 1/2 Grand Chain (1 bar each hand)  set
    advancing to partner & turn 2H.  All continue Grand Chain back to
    places, set advancing to partner & turn 2H to face in NHJ', 0);
INSERT INTO 'dancecrib' VALUES (8028, '2013-09-09 06:47:41.044266+00', '2023-02-04 01:21:16.884978+00', 14976, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s dance 1/2 reels of 3 across passing 1st
    corners LSh to start & 1s ending 2nd place opposite sides
9-16::
    All Set+Link, 1s turn LH to face 1st corners (position)
17-24::
    1s dance 1/2 RSh diagonal reel of 4 & end facing 2nd corners (pstn),
    dance 1/2 reel of 4 with 2nd corners & end 2nd place own sides
25-32::
    1s+3s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (6376, '2013-08-21 08:31:23.278003+00', '2023-02-04 01:21:16.895447+00', 4303, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, turn 1st corners LH & end facing 1st
    corners
9-16::
    1s dance ''Hello-Goodbye'' setting & end Man facing up & Lady down
17-24::
    1s dance out ends (1M up between 2s) & cast round 2nd corners RSh to
    face them & turn 2nd corners RH
25-32::
    1s dance reels of 3 across (LSh to 3rd corner) & pass RSh to end in
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (8029, '2013-09-09 06:47:41.06197+00', '2023-02-04 01:21:16.905871+00', 14346, 3, NULL, 'ace', '{{title}}
Part 1

1-8::
    All Men dance RH across 1.1/4 times, cast right round opposite Lady
    & curve in to face her
9-16::
    All dance interlocking Reels of 4 (no hands in middle) ending with
    all Men facing in
17-24::
    All Men circle 4H round to right & pivot left to face same Lady, all
    set & 1/2 turn RH to change places & all Ladies face anticlockwise
25-28::
    All Ladies dance 3/4 LH across as Men dance 1 pl clockwise & all Men
    turn new partners RH once round
29-32::
    Repeat bars 25-28 but end all facing in (Ladies on left of Men)
    facing original partners across the set

{{title}}
Part 2

1-32::
    Ladies repeat bars 1-32 with Ladies leading & end with own partner
    (3 4 1 2)

{{title}}
Part 3

1-8::
    All set to partner & turn 3/4 turn RH into prom hold, all promenade
    clockwise 1/2 round to original places
9-16::
    1s & 3s set & rotate then dance clockwise to face across the dance,
    1s+3s circle 4H round to left 1/2 way & 1s & 3s dance out to
    original places
17-24::
    2s+4s repeat bars 9-16 to original places
25-32::
    All dance 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (11089, '2018-09-09 19:54:36.74711+00', '2023-02-04 01:21:17.048793+00', 18565, 3, NULL, 'ace', '1-8::
    1L followed by partner dancing in tandem crosses down to dance reel
    of 3 with 2M+3M (2M out/up & 1s pass 3M LSh to start)
9-16::
    1M followed by partner dancing in tandem crosses down to dance reel
    of 3 with 2L+3L (2L out/up & 1s pass 3L RSh to start)
17-24::
    1s dance reflection reels of 3 on own sides (1s in & down to start)
25-32::
    1s dance down middle & cast up behind 3s to 2nd place, 2s+1s+3s turn
    RH', 0);
INSERT INTO 'dancecrib' VALUES (12410, '2019-12-05 01:30:59.790434+00', '2023-02-04 01:21:17.083661+00', 19593, 3, NULL, 'ace', '1-8::
    1M passes partner RSh and dances down behind Ladies, across bottom
    of set, up Men''s side to place
::
    _while_ 2M stands 2 bars, passes partner RSh to follow 1M
::
    _while_ 3M stands 4 bars, passes partner RSh to follow 1M & 2M.  Men
    end in original places
9-16::
    Ladies repeat bars 1-8, passing partners by LSh, dancing behind Men
    & up Ladies'' side to original places
17-24::
    1s+2s turn1.1/2 times to change places (Men RH, Ladies LH); 1s+3s
    turn 1.1/2 times to change places (Men LH, Ladies RH)
25-32::
    2s+3s+1s dance DoSiDo with partner & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6378, '2013-08-21 08:31:23.317551+00', '2023-02-04 01:21:17.117528+00', 12316, 3, NULL, 'ace', '1-8::
    1s & 3s 3/4 turn RH into prom hold (Lady on left) & cast 1 place on
    Ladies side, 1s & 3s 1/2 turn RH into middle (1s facing down, 3s up)
9-16::
    1s+4s+3s circle 6H round & back
17-24::
    1s & 3s dance RH across, 1s & 3s cast to ends & cross down/up into
    double triangle positions facing opposite sides
25-28::
    All set (as in Double Triangles) 1s & 3s dance out & turn right
    about to face in _while_ 2s, 4s & 5s dance in & turn right about to
    face out
29-32::
    All set (Inverted Triangle formation), 1s & 3s petronella turn into
    line up/down in middle _while_ 2s, 4s & 5s dance to places
33-40::
    1s+3s dance reel of 4 up/down middle
41-48::
    1s & 3s turn RH, cast down 1 place opposite side & cross RH to new
    places.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (6379, '2013-08-21 08:31:23.325713+00', '2023-02-04 01:21:17.135673+00', 4311, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, 1s lead down between 3s & cast up to 2nd place
    own side
9-16::
    1s turn 1st corners RH, pass RSh,  turn 2nd corners RH & PdB in to
    end BtoB facing opposite sides
17-24::
    1s dance Crown Triangles & 1/4 turn to right to end Man facing up &
    Lady facing down
25-32::
    1s dance reels of 3 on opposite sides (RSh to 2nd corner to start) &
    cross RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6380, '2013-08-21 08:31:23.333843+00', '2023-02-04 01:21:17.152611+00', 4313, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, set & 1/2 turn LH to face 1st corners
9-16::
    1s dance diagonal reel of 4 with 1st corners
17-24::
    1s give LH to partner & RH to 1st corner & Bal-in-Line, 1s & 1st
    corners turn right about & Bal-in-Line, 1s turn RH to face 2nd
    corners
25-32::
    1s dance diagonal reel of 4 with 2nd corners
33-40::
    1s give LH to partner & RH to 2nd corner & Bal-in-Line, 1s & 2nd
    corners turn right about & Bal-in-Line, 1s turn RH to 2nd place own
    sides
41-48::
    1s set, cast 1 place; 1s+4s Set+Link', 0);
INSERT INTO 'dancecrib' VALUES (6381, '2013-08-21 08:31:23.341948+00', '2023-02-04 01:21:17.174808+00', 4312, 3, NULL, 'ace', '1-8::
    1s+3s set; petronella turn into centre & dance 1/2 reel of 4 in
    centre of dance
9-16::
    1M+3L (centre couple) dance LH across with 2s _while_ 1L+3M chase
    clockwise 1/2 way; 1s+3s dance 1/2 reel of 4 in centre of dance
17-24::
    1M+3L (centre couple) dance LH across with 2s as 1L+3M chase
    clockwise 1/2 way; 1s+3s turn RH 1.1/4 times ending with 1s facing
    down
25-32::
    1s+2s dance the Rondel but on bars 29/32 3s set advancing to make an
    arch & dance up to 2nd place as 1s dance under to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (6382, '2013-08-21 08:31:23.349945+00', '2023-02-04 01:21:17.20063+00', 4310, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    All dance RSh reels of 4 on sides
9-16::
    1s+2s also 3s+4s dance Men''s Chain & end holding RH & LH to next
    Lady for…
17-24::
    All Bal-in-Line, keeping RH (dropping LH) rotate into lines across
    (Men side by side) all Bal-in-Line, drop LH & rotate into lines on
    sides & Bal-in-Line, drop LH & 1/2 turn RH to original places all
    facing in
25-32::
    1s+2s also 3s+4s dance 1/2 R&L, 1s+4s dance 1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (8184, '2014-02-10 10:26:42.853953+00', '2023-02-04 01:21:17.230145+00', 14964, 3, NULL, 'ace', '1-8::
    1s & 2s dance the Espagnole:
::
    _1- 2_   1s+2s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _3- 4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5- 8_   2s turn RH as 1s turn LH
9-16::
    1M with 3s, 1L with 2s dance RH Across, 1s pass by right; 1M with
    2s, 1L with 3s dance LH Across (2 1 3)
17-24::
    1s & 3s dance the Rosette:
::
    _17-20_   1s & 3s set, turn partner RH 1/2 way, face partner, drop
    hands, pull back RSH & cast to opp sides (partner''s place)
::
    _21-24_   1s & 3s dance clockwise 1/2 way round to new positions (2
    3 1)
25-32::
    2s, 3s & 1s dance 6 hands round and back', 0);
INSERT INTO 'dancecrib' VALUES (13623, '2021-02-04 01:20:46.232452+00', '2023-02-04 01:21:17.25698+00', 11797, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp sides

1-8::
    1s+2s & 3s+4s dance 1/2 R&L; all set, all cross RH
9-12::
    2s+1s & 4s+3s dance RH across
13-16::
    1M followed by 1L casts up round 2M, 1M dances down centre to face
    3L & 1L faces 2M _while_
::
    4M followed by 4L casts down round 3M, 4M dances up centre (passes
    1M LSh) to face 2L & 4L faces 3M
::
    Positions now: lines of 4 across, 1L & 4M at top between 2s facing
    down, 1M & 4L at bottom between 3s facing up
17-24::
    Reels of 4 across. Bar 24: centre dancers instead of passing LSh 1/2
    turn LH (Men polite turn).  Lines across 2L 4M 1L 2M face down, 3L
    4L 1M 3M face up
25-32::
    1s+4s set, Petronella turn in tandem (Ladies lead); 1s+4s turn
    partners RH.  End 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (13268, '2020-10-16 00:20:59.413379+00', '2023-02-04 01:21:17.435955+00', 10795, 3, NULL, 'ace', '1-8::
    1s lead down (3 bars), lead up (3 bars), cast to 2nd place & cross
    RH (2s step up 7-8)
9-16::
    1s dance reels of 3 on opp sides (RSh to 1st corner), 1s end BtoB in
    centre, 1M facing up, 1L facing down
17-24::
    1s dance 4 bars "Crown Triangles"; 1s pull back RSh & turn1.1/4 RH
    to end BtoB again, 1M facing down, 1L facing up
25-32::
    1s dance 4 bars "Crown Triangles": 1s pull back RSh & turn RH to 2nd
    place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6383, '2013-08-21 08:31:23.357996+00', '2023-02-04 01:21:17.458713+00', 13281, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 2s+1s+3s advance setting & cast back to
    places facing clockwise
9-16::
    1s dance RSh round each other & back to place _while_ 2s+3s chase
    1/2 way, 1s chase 1/2 way _while_ 2s+3s circle 4H round
17-24::
    1s turn LH 1.1/4  times _while_ 2s+3s chase 1/2 way, 1s dance RH
    across (1L with2s, 1M with 3s)
25-32::
    1s dance LH across with other couple, 1s dance out ends (1L up, 1M
    down) & cast to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6384, '2013-08-21 08:31:23.366135+00', '2023-02-04 01:21:17.485904+00', 10593, 3, NULL, 'ace', '1-8::
    1s lead down for 4 bars & up
9-16::
    1s dance reflection reels on own side (1s out & down to start)
17-24::
    1s+2s+3s Promenade
25-32::
    1s+2s dance the RSh Helix:
::
    Set passing partner RSh into BtoB position & cast round partner to
    own sides, 1/2 turn partners RH & dance 1/2 RH across.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14292, '2021-09-08 00:20:48.125805+00', '2023-02-04 01:21:17.513625+00', 9166, 3, NULL, 'ace', '1-8::
    1s cross down RH, dance down behind 3s, cross up & dance up behind
    2s into centre top place facing up (2s & 3s step in ready for…)
9-16::
    1s+2s+3s dance Allemande. 3 2 1
17-24::
    1s set & cross RH; 2s+1s set & dance 1/2 RH across. 3 1 (2)
25-32::
    All set & cross RH; 3s+1s set & dance 1/2 RH across. 1 3 2
33-40::
    1s cross RH, cast (3s step up); 1s dance 1/2 Fig 8 up round 3s. End
    3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6385, '2013-08-21 08:31:23.375893+00', '2023-02-04 01:21:17.623925+00', 4318, 3, NULL, 'ace', '1-8::
    1s with nearer hands joined set to 2L twice & set to 2M twice
9-16::
    1s lead down the middle & back
17-24::
    1s cross & cast 1 place, cross LH & cast round 3s & lead up to face
    1st corners
25-32::
    1s set & turn 1st corners, set & turn 2nd corners
33-40::
    1s dance reels of 3 with corners (LSh to 1st corner to start) &
    cross to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (14002, '2021-05-03 00:20:40.586714+00', '2023-02-04 01:21:17.655165+00', 4320, 3, NULL, 'ace', '1-4::
    1s+2s & 3s+4s dance 1/2 RH across, 1s+4s change places LH on sides
5-8::
    2s+4s & 1s+3s dance 1/2 RH across, 4s+1s cross LH with partner to
    opp sides.  (4) 2 3 (1)
9-12::
    4s+2s & 3s+1s dance 1/2 LH across, 4s+1s change places RH on sides
13-16::
    2s+1s & 4s+3s dance 1/2 LH across, 1s+4s cross RH with partner to
    own sides. 1 2 3 4
17-24::
    1s+2s dance 1/2 R&L; 1s+3s+4s dance 1/2 mirror reels of 3 on sides
    (1s in/down, 3s out/up to start). (2) 3 4 (1)
25-32::
    3s+1s circle 4H round to left; 2s+1s set & cross RH with partner
    _while_ 4s+3s set to each other on sides & change places RH.  2 3 4
    1', 0);
INSERT INTO 'dancecrib' VALUES (6386, '2013-08-21 08:31:23.385828+00', '2023-02-04 01:21:17.799144+00', 4324, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place (2s step up), 1s turn LH & cast to 3rd
    place (3s step up)
9-16::
    2s+3s+1s circle 6H round to left for 6 bars (all end on sides) & 1s
    lead up to face 1st corners as 3s step down
17-24::
    1s set to 1st corners & turn 2H, set to 2nd corners & turn 2H,
    finishing between corners
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners &
    cross back to 2nd places. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3999, '2013-08-21 08:30:41.024634+00', '2023-02-04 01:18:26.826938+00', 140, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection (mirror) reels of 3 on opposite
    sides
9-16::
    1s cross down to dance reflection (mirror) reels of 3 on own sides
17-24::
    1s lead down the middle (2s step up)&  lead back up to 2nd place own
    sides
25-32::
    1s dance 1/2 Fig of 8 round 2s & 1/2 Fig of 8 round 3s back to 2nd
    place', 0);
INSERT INTO 'dancecrib' VALUES (4058, '2013-08-21 08:30:42.870046+00', '2023-02-04 01:18:30.47968+00', 219, 3, NULL, 'ace', '1-8::
    1s+2s set & circle 4H round to left, 1M+2M also 1L+2L turn 2H to end
    in centre BtoB with ptnr (facing out on own sides between 3s)
9-14::
    1M+2M+3M dance LH across _while_ 1L+2L+3L dance RH across. On
    meeting partners all take prom hold, 1s followed by 2s+3s dance up
    to top, 1s (both) cast on Men''s side, 2s (both) cast on Ladies''
    side, 3s dance to top
15-16::
    1s turn LH to end 1M in 2nd place & 1L in 3rd place, 2s turn RH to
    end 2M in 3rd place & 2L in 2nd place, 3s 1/2 turn RH to end in
    centre facing down (Lady on Mans right)
17-24::
    3s set to dancers in 2nd place _while_ dancers in 3rd place set to
    each other, all turn 2H & open out to circle 6H round to left 1/2
    way
25-32::
    1s+2s dance 1/2 Ladies'' Chain , 2s+1s+3s turn 2H with 1s turning
    1.1/2 times to end in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (9391, '2016-10-06 07:18:41.156019+00', '2023-02-04 01:21:17.828329+00', 17267, 3, NULL, 'ace', '1-4::
    1s dance in and up, touch nearer hands, cast back to places _while_
    2s dance similarly dancing in/down to start (a cloverleaf figure)
5-8::
    1s+2s dance RH across to places
9-16::
    1L+2M turn 2H once round. 1M+2L turn 2H once round
17-24::
    1s+2s turn partners 2H once round opening out into circle 4H round
    to Left.  End in centre, 1s facing down, 2s facing up
25-32::
    1s+2s dance »Rondel«
::
    _25_        2s make an arch & dance up _while_ 1s dance down under
    arch
::
    _26-27_  2s cross (2L pass in front of 2M) & both dance into 1st
    place on opp sides _while_ 1s cross (1L pass front of 1M) & both
    dance into 2nd place on opp sides
::
    _28_       Men make an arch & dance across _while_ Ladies dance
    under arch & across
::
    _29-30_  Men cross over (1M passing in front of 2M) & dance in to
    meet partner (as at start of Fig) _while_ Ladies cross (1L passing
    in front of 2L) & also dance in to meet partner
::
    _31-32_  2s make an arch & dance up to 1st place _while_ 1s dance
    under the arch to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6387, '2013-08-21 08:31:23.394095+00', '2023-02-04 01:21:17.863291+00', 14340, 3, NULL, 'ace', '1-8::
    1s cross RH & cast to 2nd place, 2s+1s+3s Adv+Ret
9-12::
    1s dance 1/2 reels of 3 on opposite sides giving LSh to 1st corners
    to start
13-16::
    1s cross RH & cast right to end in lines of 3 across (1M between 3s
    at top, 1L between 2s at bottom)
17-24::
    3s+1s+2s Adv+Ret (up/down), 1s dance 1/2 reels of 3 across (LSh to
    person on left) & end BtoB facing 3rd corner (pstn)
25-32::
    1s dance 1/2 reel of 4 with 3rd corners & pass LSh to face 4th
    corner (pstn), 1s dance 1/2 reel of 4 with corners & end 2nd place
    own side', 0);
INSERT INTO 'dancecrib' VALUES (6389, '2013-08-21 08:31:23.412075+00', '2023-02-04 01:21:18.01324+00', 4333, 3, NULL, 'ace', '1-8::
    All dance RH across & LH back to place
9-16::
    _1_+3 3/4 turn RH & join with 4+2 to Bal-in-Line, 1+3 1/2 turn RH &
    join with 2+4 & Bal-in-Line.
17-24::
    All dance reel of 4 (in this position) 1 & 3 returning to original
    places.
25-32::
    All Advance to centre (PdB), set turning to face out, all Petronella
    turn to end 1 place to left of original place & set.', 0);
INSERT INTO 'dancecrib' VALUES (6390, '2013-08-21 08:31:23.421727+00', '2023-02-04 01:21:18.10106+00', 4334, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret for 2 steps & dance 1/2 R&L
9-16::
    1L+2M turn RH 1.1/2 times; 1M+2L turn RH 1.1/2 times. All back in
    original places
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance a Poussette. 2 1', 0);
INSERT INTO 'dancecrib' VALUES (6391, '2013-08-21 08:31:23.435462+00', '2023-02-04 01:21:18.277321+00', 4336, 3, NULL, 'ace', '1-8::
    1s cast below 3s, lead up & cast to 2nd places
9-16::
    2s+1s+3s circle 6H round & back
17-24::
    2s+1s+3s turn RH & LH', 0);
INSERT INTO 'dancecrib' VALUES (9482, '2016-11-09 08:48:45.679026+00', '2023-02-04 01:21:18.297399+00', 17408, 3, NULL, 'ace', '1-8::
    1s set, cast to 3rd place (2s+3s step up). 2s set, cast to 3rd place
    (3s+1s step up).  3 1 2
9-16::
    1st corner diagonal:
::
    _9-12_    1s (in 2nd place) set to & cross RH with person diagonally
    to right (1M+2L, 1L+3M)
::
    _13-16_  1M followed by 3M & 1L followed by 2L chase clockwise 1/2
    round  behind standing dancers
17-24::
    2nd corner diagonal:
::
    _17-20_   Couple in 2nd place (3M & 2L) set to & cross LH with
    person diagonally to left (3M+3L & 2L+2M)
::
    _21-24_   3M followed by 2M & 2L followed by  3L chase anticlockwise
    1/2 round  behind standing dancers
25-32::
    1st corner diagonal:
::
    _25-28_   Couple in 2nd place (2M & 3L) set & cross RH with person
    diagonally to right (2M+1L & 3L+1M)
::
    _29-32_   2M followed by 1M & 3L followed by 1L chase clockwise 1/2
    round  behind standing dancers.  End 2 1 3
33-40::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (13421, '2020-12-02 01:20:47.881261+00', '2023-02-04 01:21:18.335506+00', 17793, 3, NULL, 'ace', '1-8::
    1s dance down NHJ, dance out between 3s & 4s, cast up round 4s &
    dance out behind 3s to 2nd place own side (2s step up 7-8)
9-16::
    All 4 couples Adv+Ret twice
17-24::
    1s+3s Set+Link; 1s+4s Set+Link
25-32::
    2s+3s also 4s+1s dance RH across & LH across
33-40::
    1s dance up 1 place & cast back to 4th place own side; 1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (14426, '2021-11-06 01:12:14.537654+00', '2023-02-04 01:21:18.368607+00', 13592, 3, NULL, 'ace', '1-8::
    1s+2s dance the Knot. 1s finish facing 1st corner
9-16::
    1s 1/2 turn 1st corners flowing into 1/2 diag reel of 4 with 1st
    corners, 1s 1/2 turn RH to face 4th corners
17-24::
    1s 1/2 turn 4th corners flowing into 1/2 diag reel of 4 with
    corners, 1s 1/2 turn 4th corner RH to end 1M between 3s at top, 1L
    between 2s in 3rd place
25-32::
    All chase clockwise 1/2 round; 1s turn 2H 1.1/4 to end in 2nd place
    own side.  2 1 3

{{explanation}}
Note: End of 2nd time, 1s+4s dance the Knot on bars 1-8 to bring 4s into 3rd place, 1s to 4th place', 0);
INSERT INTO 'dancecrib' VALUES (6392, '2013-08-21 08:31:23.443547+00', '2023-02-04 01:21:18.398954+00', 8968, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-16::
    1s dance down between 3s, cast up & dance up between 2s (2s step up
    11-12) & cast round 2s to 2nd places
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners ending 2nd place own sides
25-32::
    1s+3s Set+Link & all turn partners 2H', 0);
INSERT INTO 'dancecrib' VALUES (10623, '2018-04-16 21:41:24.990163+00', '2023-02-04 01:18:33.685817+00', 276, 3, NULL, 'ace', '{{explanation}}
Note: "Petronella-to-Left": 4 PdeB steps going diagonally forward to Left & turning 3/4 round to Left on 2nd/3rd steps

1-8::
    1s Petronella turn & set (2s step up); 1s turn 3/4 LH back to
    original places & set _while_ 2s Petronella turn & set (1M now
    facing 2L, 2M facing 1L)
9-16::
    1L & 2M stand (4 bars) _while_ 2L dances Petronella turn & 1M,
    dancing in front of 2L, dances Petronella-to-Left (1M & 2L have
    changed places); All dance RH across once round
17-24::
    1M+2M Petronella turn & set _while_ 1L & 2L, going inside them,
    Petronella-to-Left;  all dance LH across once round
25-32::
    1L dances anticlockwise round others to 2nd place own side (8 bars)
    as 1M dances Petronella turn & follows partner 2nd place own side
    _while_
::
    2L stands (2 bars), dances Petronella turn, dances anticlockwise
    round to 1st place own side as 2M stands (4 bars), dances Petronella
    turn & follows 1M to end in 1st place own side', 0);
INSERT INTO 'dancecrib' VALUES (6393, '2013-08-21 08:31:23.451556+00', '2023-02-04 01:21:18.431866+00', 4350, 3, NULL, 'ace', '1-8::
    All Adv+Ret & dance DoSiDo with partner
9-16::
    1s+2s also 3s+4s dance R&L
17-24::
    All dance RSh reels of 4 on sides
25-32::
    1s dance down to 4th place, others step up on bars 27-28 & all turn
    partner RH', 0);
INSERT INTO 'dancecrib' VALUES (6394, '2013-08-21 08:31:23.460242+00', '2023-02-04 01:21:18.46185+00', 4354, 3, NULL, 'ace', '{{title}}
Fig 1

1-8::
    1s+3s set & dance "La Baratte":
::
    Men 1/2 turn Lady RH & retains hand but at arm''s length from each
    other
::
    Men retrace steps with Lady turning right under Man''s arm briefly
    into Allemande hold (Man behind Lady facing Ladies original place) &
    releasing Ladies RH she turns under Mans left arm until almost in
    original places
::
    Couples change places LH to change places facing out
9-16::
    2s+4s (prom hold) Adv+Ret _while_ 3s & 1s Promenade anticlockwise
    3/4 way round to face out to side couples (1s face 4s & 3s face 2s),
    all (in prom hold) pass facing couples RSh, 1s & 3s dance back to
    original places _while_ side couples dance in & round opp couple LSh
    & return to pl
17-32::
    Repeat bars 1-16 with 2s & 4s dancing "La Baratte" & Promenading
    round

{{title}}
Fig 2

1-8::
    1L+2M & 3L+4M 1/2 turn RH & dance RH across 1/2 way, 1L & 3L turn
    their own corners RH 1.1/2 times to place
9-16::
    2L & 4L repeat bars 1- 8
17-24::
    All set to partners, petronella turn (Ladies BtoB) & set twice On
    second setting the Ladies turn right about to form a circle _while_
    partners dances in behind them & place hands on their hips
25-32::
    Ladies circle 4H round to left (small steps) with partners behind
    them then & all turn partners RH back to places

{{title}}
Fig 3

1-8::
    All circle 8H round & back
9-16::
    Ladies dance RH across & turn partners LH 1.1/2 times to bring Men
    into middle
17-24::
    Men dance RH across & turn partners LH into prom hold facing
    anticlockwise
25-32::
    All Promenade round', 0);
INSERT INTO 'dancecrib' VALUES (6395, '2013-08-21 08:31:23.468286+00', '2023-02-04 01:21:18.489873+00', 4355, 3, NULL, 'ace', '1-8::
    1s & 3s petronella to opposite sides _while_ 2s & 4s step up, set,
    petronella turn into centre & set
9-16::
    2s also 4s in prom hold dance reels of 3 across (RSh to 1L/3L)
    ending as bar 8
17-24::
    All set to partners, 1s+2s also 3s+4s circle 4H round to Left to end
    on own sides, 1L+2L also 3L+4L change places RH & 1L+4L turn LH.  2
    1 4 3
25-32::
    1s+3s+4s (bottom 3 cpls) dance the Knot.  2 3 4 1', 4);
INSERT INTO 'dancecrib' VALUES (6397, '2013-08-21 08:31:23.48445+00', '2023-02-04 01:21:18.549114+00', 4358, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s dance down below 3s & cast back to places, 1s+2s turn RH & change
    places LH with 2s on own sides
9-16::
    1s set advancing & face 1st corner, turn 1st corner RH, turn 2nd
    corner LH & turn partner RH to face 1st corners

{{title}}
Jig

{{explanation}}
*

1-8::
    1s set to 1st corner, set to each other across the dance (as in
    ''Hello-Goodbye'') & turn partner with 2H to end facing 2nd corners
9-16::
    Set to 2nd corner moving to place between 2s/3s (as in
    ''Hello-Goodbye''), set to partner & turn 2H to end in 2nd place own
    sides

{{explanation}}
* Some editions of RSCDS Book 22 and the original ''Silver Anniversary Booklet'' (Hamilton Ontario RSCDS) have ''Reel''', 0);
INSERT INTO 'dancecrib' VALUES (6398, '2013-08-21 08:31:23.494303+00', '2023-02-04 01:21:18.765421+00', 4359, 3, NULL, 'ace', '1-8::
    1s+2s set twice & dance 1/2 R&L
9-16::
    2s+1s repeat above Fig back to place
17-24::
    1s+2s dance Poussette.  2 1 3
25-32::
    1s lead down the middle, back to top & cast to face 1st corners
33-40::
    1s turn 1st corners RH, partner LH, 2nd corner RH partner LH to
    places', 0);
INSERT INTO 'dancecrib' VALUES (6399, '2013-08-21 08:31:23.502387+00', '2023-02-04 01:21:18.913325+00', 11892, 3, NULL, 'ace', '1-4::
    1s+2s also 3s+4s 3/4 turn on sides (Ladies RH, Men LH), 1s+2s also
    3s+4s set (1s & 3s BtoB with partners)
5-8::
    1s+2s also 3s+4s 3/4 turn on sides (Ladies RH, Men LH), 1s & 3s pass
    RSh to face opposite sides in double triangle position
9-16::
    All dance Double Triangles
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners ending 2nd/4th place opposite sides
25-32::
    1s & 3s turn RH & dance up, cast on opposite sides round 2s/4s &
    cross down to 3rd/5th places', 0);
INSERT INTO 'dancecrib' VALUES (6400, '2013-08-21 08:31:23.512445+00', '2023-02-04 01:21:18.924389+00', 13622, 3, NULL, 'ace', '1-8::
    1s dance down to 3rd place & cast back to places as 3s cast to top &
    dance down to places, 1s & 3s turn RH to face 4M/2M (Man following
    Lady)
9-16::
    1s dance RH across with 4M then LH across with 2L to end facing 4M
    (1M behind 1L) _while_ 3s dance RH across with 2M & LH across with
    4L to end facing 2M (3M behind 3L)
17-24::
    1s with 4M+2L & 3s with 2M+4L dance Alternating Tandem reels of 3
    across all end in orig places
25-32::
    All set advancing to form circle & retire to places, all petronella
    turn to right moving on 1 place & set
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8608, '2015-02-13 12:48:01.234019+00', '2023-02-04 01:21:18.93539+00', 15568, 3, NULL, 'ace', '1-4::
    1s dance down between the 2s and cast up round them back to places.
5-8::
    1s dance 1/2 Fig8 round 2s, joining RH with partner in passing.
9-16::
    2s repeat bars 1- 8 respectively round 1s, joining LH with partner.
17-24::
    1s and 2s Adv+Ret then 1/2 R&L.
25-32::
    RHA, LHA.', 0);
INSERT INTO 'dancecrib' VALUES (6401, '2013-08-21 08:31:23.754332+00', '2023-02-04 01:21:18.947463+00', 4365, 3, NULL, 'ace', '1-8::
    1s & 3s lead down & 3/4 turn RH to L facing down & M up, retaining
    hold of RH set & L turns under ptnrs Rt arm to dance up (Men follow
    prtnr)
9-16::
    1s & 3s dance RH across with 2L/4L, 1s & 3s dance LH across with
    4M/5M to end facing 1st corners
17-24::
    1s also 3s dance Pass+Turn with 1st corners & pass RSh to face 2nd
    corners, dance Pass+Turn with 2nd corners & into centre facing
    partner (L facing down M up)
25-32::
    1s+3s dance reel of 4 up & down centre of dance & end in centre
    holding partners nearer hand (1s face Ladies side & 3s face Men''s
    side)
33-40::
    1s also 3s dance out sides & cast, dance in to meet ptnr (1M & 3L
    pass LSh) to dance out other side & cast back to middle (1M & 3L
    pass RSh & face each other)
41-48::
    1L also 3M set twice _while_ 1M+3L turn RH, 1s & 3s turn partner LH
    & cast down 1 place on own sides.  End 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (6402, '2013-08-21 08:31:23.76249+00', '2023-02-04 01:21:18.960921+00', 9029, 3, NULL, 'ace', '1-8::
    1s & 3s set, dance down 2 places, cast up 1 place & cross RH to face
    1st corners
9-16::
    1s & 3s turn 1st corners LH, partner RH, 2nd corner LH & partner RH
    to face 3rd corners retaining hands
17-22::
    1s & 3s set to 3rd corner, releasing hands dance Pass+Turn & turn RH
    to face 4th corners
23-28::
    1s & 3s repeat with 4th corners
29-32::
    1s & 3s turn RH & cast 1 place.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (9020, '2015-11-30 09:00:01.661618+00', '2023-02-04 01:21:19.05028+00', 16524, 3, NULL, 'ace', '1-8::
    1s set, 1/2 turn RH, lead down, cross below 3s, cast up to 2nd place
    own sides (2s step up 5-6)
9-16::
    1s set advancing to 1st corners & turn 1st corners 2H finishing 1M
    between 3s, 1L between 2s.  1s set advancing to 2nd corners, turn
    2nd corners 2H & retain 2nd corner''s LH
17-24::
    1M+2s also 1L+3s circle 3H round to Left, 1s pull back RSh to face
    up/down set.  1s set, petronella turn to 2nd place own sides
25-32::
    2s+1s dance Poussette. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6403, '2013-08-21 08:31:23.770605+00', '2023-02-04 01:21:19.078091+00', 4366, 3, NULL, 'ace', '1-8::
    1s+2s set & dance RH across 1/2 way, set & 1/2 turn partners
9-16::
    1s followed by 2s lead down below 3s cross & cast up behind 3s, lead
    up crossing & 1s cast to 2nd place as 2s cross to 1st place.  2 1 3
17-24::
    1s dance 1/2 reels of 3 across giving LSh to 1st corners & 1/2 reels
    of 3 on opposite sides
25-32::
    1s dance 1/2 reels of 3 across giving LSh to 3rd corners & 1/2 reels
    of 3 on own sides', 0);
INSERT INTO 'dancecrib' VALUES (12817, '2020-05-14 23:15:23.478249+00', '2023-02-04 01:21:19.112615+00', 19724, 3, NULL, 'ace', '1-8::
    1s+2s set, cross passing partner RSh;  Repeat back to place
9-16::
    1s+2s circle 4H round to left; 1s+2s dance RH across, Bar 15 take
    partner''s hand & Lady turns under Man''s arm into allemande hold
17-24::
    1s+2s Allemande. 2 1
25-32::
    2s+1s dance double Fig 8 (2s cast, 1s cross up).  2 1', 0);
INSERT INTO 'dancecrib' VALUES (11462, '2019-01-01 01:57:18.288378+00', '2023-02-04 01:21:19.268243+00', 18975, 3, NULL, 'ace', '1-8::
    1s Adv+Ret for 1 step, dance in & cast 1 place, turn 2H to face 3L
9-16::
    1s+3L set, 1s dance 1/2 Alternating Tandem reel of 3 with 1st
    corners (1L leading), 1s turn 2H to face 2L
17-24::
    1s+2L set, 1s dance 1/2 Alternating Tandem reel of 3 with 2nd
    corners (1M leading), 1s turn 2H to 2nd place opposite sides
25-32::
    3s+1s+2s Adv+Ret for 1 step & 1/2 turn 2H, 3s followed by 1s+2s
    dance up & cast.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6404, '2013-08-21 08:31:23.806209+00', '2023-02-04 01:21:19.285736+00', 4371, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across & 1s cast to face 1st corners
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners, 1/2 reel with 2nd
    corners ending with 1M between 3s (at top) facing down & 1L between
    2s facing up
17-24::
    1s+2s+3s Set+Link for 3 twice
25-32::
    1s dance Figs of 8 across _while_ 2s+3s dance R&L (1M passes 3M LSh,
    1L passes 2L LSh to start) & 1s end in 2nd place on own side
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6405, '2013-08-21 08:31:23.816048+00', '2023-02-04 01:21:19.395544+00', 4374, 3, NULL, 'ace', '1-8::
    1L followed by partner casts to 2nd place 1L crosses to opposite
    side, 1M followed by partner casts up & crosses back to places
9-16::
    1s cross & 1/2 turn 2s on sides (1s dancing between 2s & giving
    nearer hand), 1s repeat with 3s but end facing 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting
25-32::
    1s lead up to top, cross RH, cast to 2nd place & circle 4H round to
    left with 3s', 0);
INSERT INTO 'dancecrib' VALUES (13761, '2021-03-02 01:20:56.955392+00', '2023-02-04 01:21:19.421723+00', 20001, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH & cast in (2s/3s step down/up); 1s & 4s dance 1/2
    Figs 8 (1s up round 2s, 4s down round 3s)
9-12::
    1s+4s set advancing diagonally into centre, pull back RSh on 2nd
    setting step to face corners & set to corners
13-16::
    1s+4s chase clockwise round in centre to end 1L followed by 1M
    facing 2M (at top), 4M followed by 4L facing 3L at bottom
17-32::
    »Progressive Wheels«:
::
    _17-20_   1s+2M dance RH across, 1s face 3M (at bottom) _while_
    4s+3L dance similar, 4s face 2L (at top)
::
    _21-24_   1s+3M dance LH across, 1s face  3L (at bottom) _while_
    4s+2L dance similar, 4s face 2M (at top)
::
    _25-28_   1s+3L dance RH across, 1s face 2L (at top) _while_ 4s+2M
    dance similar, 4s face 3M (at bottom)
::
    _29-32_   1s+2L dance LH across, 1s end between 2s facing down 1M
    with 1L on left _while_ 4s+3M dance similar to end between 3s facing
    up
::
    (Note LH across are 1/2 way round for dancing couples to enable
    travel to next couple)
33-40::
    Lines of 4 across set, 1s+4s dance 1/2 R&L finishing on sides 2 4 1
    3, & all set', 0);
INSERT INTO 'dancecrib' VALUES (6406, '2013-08-21 08:31:23.826028+00', '2023-02-04 01:21:19.449902+00', 4383, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, dance down between 3s & cast to 2nd place in
    centre facing up to 2s
9-16::
    1s+2s+3s dance Mill Wheels: 1M+2M+3M with left wrist hold (grip
    wrist of Man in front), dance twice round anticlockwise _while_
::
    1L+2L+3L with right wrist hold dance twice round clockwise (Ladies
    passing in front of partner) 1s end facing own side as for Double
    Triangles
17-24::
    2s+1s+3s set in triangular formation, dance on 1 place in triangle
    with a petronella turn (3M+2L BtoB), set & petronella on 1 place
    (2M+3L BtoB)
25-32::
    2s+1s+3s set, 2s+3s petronella on 1 place _while_ 1s set advancing
    to each other, dance to top & cast to 2nd place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6408, '2013-08-21 08:31:23.936336+00', '2023-02-04 01:21:19.565457+00', 9874, 3, NULL, 'ace', '1-8::
    All circle 8H round to left, 1s & 4s end in centre (1s facing down &
    4s up) as 2s & 3s end in original places
9-16::
    1s & 4s set & change places RH with opp person, 1M followed by
    partner dances up behind Men to 2nd place in centre of dance _while_
    4L followed by partner dances down behind Ladies to 3rd place in
    centre
17-24::
    1s & 4s circle 4H round to left, face up/down, set & set advancing
    to change places & end BtoB
25-32::
    4s & 1s dance out ends of set (4s up, 1s down), cast 1 place on
    opposite sides & turn partners 2H 1.1/2 times to own sides
33-40::
    All dance Grand Chain.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13033, '2020-08-10 00:18:29.06793+00', '2023-02-04 01:18:33.716783+00', 278, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set & dance 1/2 RH across; 1s+4s (middle couples)
    set & dance 1/2 LH across
9-16::
    Top 2 couples (2s+4s) & bottom 2 couples (1s+3s) set, dance 1/2 RH
    across; 2s+3s (middle couples) set, dance 1/2 LH across  (4) (3) (2)
    (1)
17-24::
    All circle 8H round & back
25-32::
    Top 2 Men''s side (4L+3L) & bottom 2 Ladies'' side (2M+1M) dance 1/2
    R&L; top 2 Ladies side (4M+3M) + bottom 2 Men''s side ( 2L+1L) dance
    1/2 R&L.  End 1 2 3 4
33-40::
    1s cross RH, cast 1 place (2s step up); cross LH & cast to 4th place
    (3s+4s step up).  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (11205, '2018-09-30 22:20:11.352875+00', '2023-02-04 01:21:19.600973+00', 18572, 3, NULL, 'ace', '1-8::
    1s set advancing, turn 2H & face down, 1s dance down middle & cast
    up round 3s to 2nd place own side
9-20::
    2s+1s+3s dance »Rights+Lefts & set« to end (3)(1)(2) :
::
    _9-12_  All cross RH, 2L+1L also 1M+3M change places on sides LH
    _while_ 2M+3L set
::
    _13-16_ All cross RH, 2M+3M also 2L+3L change places on sides LH
    _while_ 1M+1L set
::
    _17-20_ All cross RH, 1L+3L also 1M+2M change places on sides LH
    _while_ 3M+2L set
21-24::
    1M dances up to top & casts 1 pl own side _while_ 1L dances down
    below 3s & casts up 1 pl own side & 1s dance in to face 1st corner
    (pstn)
25-32::
    1s dance 1/2 reel of 4 with 1st corners, passing RSh dance 1/2 reel
    of 4 with 2nd corners & pass RSh to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (6409, '2013-08-21 08:31:23.944477+00', '2023-02-04 01:21:19.629975+00', 4393, 3, NULL, 'ace', '1-8::
    3s followed by 2s cross down between 4s & cast to each others places
    (opposite sides), 1s+3s also 2s+4s dance RH across
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1s+3s also 2s+4s dance RH across, 3s followed by 2s cross up between
    1s & cast back to original places
25-32::
    3s followed by 2s & 1s dance down between 4s, cross & cast up - 3s
    to top where they cross & cast to 2nd place as 2s follow but cross &
    cast into 1st place as 1s cross down to 4th place & cross to own
    side as 4s set & cast up to 3rd place on bars 29-32', 0);
INSERT INTO 'dancecrib' VALUES (6411, '2013-08-21 08:31:23.960594+00', '2023-02-04 01:21:19.67777+00', 4398, 3, NULL, 'ace', '1-8::
    1s lead down the middle, Lady dances under Mans arm & lead up to 2nd
    place opposite sides facing out
9-16::
    1s dance reels of 3 on opp sides (pass 1st crnr RSh) 1s turn 2H &
    end BtoB in centre (Lady face up, Man down) as 2s & 3s dance in
17-24::
    2s+1s+3s set, 2s+1L also 1M+3s circle 3H round 1/2 way, set, 2s
    dance out to 1st pl opp side & 3s to 3rd pl as 1s pass RSh in
    centre,
25-32::
    2s+1s+3s set, 2s+1M also 1L+3s circle 3H round 1/2 way, set, 2s & 3s
    dance out to sides as 1s petronella turn to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13907, '2021-04-05 00:20:49.580529+00', '2023-02-04 01:21:19.709971+00', 19481, 3, NULL, 'ace', '1-8::
    All Ladies Adv+Ret; All Men Adv+Ret
9-16::
    1s dance down, followed by 2s+3s (who dance up sides to start); 1s
    followed by 2s+3s cast back to original places
17-20::
    1s dance down, cast up round 3s to 2nd place own side (2s step up
    17-18)
21-24::
    1s dance 1/2 reels of 3 across, 1s pass 1st corner LSh to start.
    End all on opp sides (2) (1) (3)
25-32::
    1M+2s & 1L+3s dance RH across; 1s pass RSh to dance LH across with
    other couple.  (2) (1) (3)
::
    Dance is repeated »inverted« with 3s at bottom dancing as new 1s', 0);
INSERT INTO 'dancecrib' VALUES (14734, '2022-04-01 00:20:45.006796+00', '2023-02-04 01:21:19.74645+00', 18305, 3, NULL, 'ace', '1-8::
    All set, cross RH with partner; all Set+Link for 3 couples
9-12::
    1M+2M+3M also 1L+2L+3L dance RH across ending in lines of 3 across
    (2L between 3s at top, 2M between 1s)
13-16::
    All Set+Link for 3 couples, coming in to meet partner & take prom
    hold facing up
17-24::
    _3_ couples Promenade, Bars 23-24 3s cast to 2nd place & 2s dance up
    to top
25-32::
    All dance Grand Chain.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (9213, '2016-06-16 22:42:05.288142+00', '2023-02-04 01:21:19.834312+00', 13864, 3, NULL, 'ace', '1-4::
    2s set Advancing (pass LSh) to BtoB.  1s+2s+3s Advance (1 step),
    touch hands  & Retire (1 step)
5-8::
    2M+1L+3L also 2L+1M+3M dance 1/2 RH across.  1s+3s dance 1/2 LH
    across _while_ 2s chase clockwise to 2L between 1s, 2M between 3s
9-16::
    _1/2_ reels of 3 across (2M+3L also 2L+1M pass LSh).  1/2 reels of 3
    on sides (2L+3M also 2M+1L pass LSh)  End 2M between 3s (at top), 2L
    between 1s (3rd place)
17-24::
    2s cross RH & cast to 2nd place own sides.  2s turn 3s 1.1/2 times
    to change places on sides (Men LH, Ladies RH)
25-32::
    2s+3s+1s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (6413, '2013-08-21 08:31:23.976696+00', '2023-02-04 01:21:19.868035+00', 4404, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, 1s+2s+3s set & 1s+3s 3/4 turn RH (to form
    line up & down centre) as 2s cross RH to original places
9-16::
    1s+3s dance reel of 4 in centre of dance end with 1L+3M taking LH as
    partners end on sides
17-24::
    1L+3M 3/4 turn LH to face own sides, dance out & cast behind 2s to
    original places, 1s+2s+3s turn LH
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6472, '2013-08-21 08:31:24.711834+00', '2023-02-04 01:21:24.674413+00', 8066, 3, NULL, 'ace', '1-8::
    1s+2s set twice & dance RH across
9-16::
    1s+2s set twice & dance LH across
17-24::
    1s cast 1 place, cross RH, cast down 1 place & cross RH
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7877, '2013-08-21 08:31:50.343706+00', '2023-02-04 01:23:08.945753+00', 13730, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig of 8  (1s cross down to start)
9-16::
    1s turn 2s on sides (Men RH, Ladies LH) & 1s dance down to turn 3s
    on sides (Men RH, Ladies LH) & 1s end facing 1st corners
17-24::
    1s dance 1/2 reel of 4 with corners & pass RSh to face 2nd corner,
    1s dance 1/2 reel of 4 with crnrs & 1s end in middle LSh to LSh
    facing own sides
25-32::
    1M+3s (at top) also 1L+2s dance RH across (1s end in 2nd place
    opposite sides), all chase clockwise 1/2 way to own sides', 0);
INSERT INTO 'dancecrib' VALUES (11223, '2018-09-30 22:20:44.428966+00', '2023-02-04 01:23:08.97974+00', 18591, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up 3-4); 1s+3s dance RH across
9-16::
    1s cross LH, cast up to 1st place (2s step down 11-12); 1s+2s dance
    LH across
17-24::
    1s set, cast (2 step up 19-20); 1s turn RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7878, '2013-08-21 08:31:50.352064+00', '2023-02-04 01:23:09.174516+00', 10862, 3, NULL, 'ace', '1-8::
    All dancing in dance up & cast down own sides, cross (Lady in front
    of partner) & dance up opposite sides
9-16::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L
17-24::
    1s+4s dance 1/2 R&L & all turn partner RH
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6412, '2013-08-21 08:31:23.968587+00', '2023-02-08 11:03:12.600098+00', 7543, 3, NULL, 'ace', '1-8::

    1L+2M set & change places RH _while_ 1M+2L change places RH & set,

    1s+2s repeat back to places

9-16::

    1s+2M dance reel of 3 across (2M+1L pass RSh to start)

17-24::

    1s+2L dance reel of 3 across (2L+1M pass LSh to start)

25-32::

    1L+2M change places RH, 1L+1M change places RH on side, 1L+2L change

    places RH & 2s cross RH', 0);
INSERT INTO 'dancecrib' VALUES (4000, '2013-08-21 08:30:41.03284+00', '2023-02-04 01:18:26.849703+00', 7339, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 2 places, 2s+1s Adv+Ret on the diagonal
9-16::
    1s cross RH & cast back to places, 1s+3s Adv+Ret on the diagonal
17-24::
    1s lead down the middle & back to top facing out
25-32::
    1s+2s change places on sides (Lady RH & Man LH), 1s+3s change places
    (opp hands), 1s+4s turn on sides 1.1/2 times to 4th place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13184, '2020-09-15 00:20:44.686065+00', '2023-02-04 01:21:19.894008+00', 19814, 3, NULL, 'ace', '1-4::
    1s & 3s advance & 1/2 turn opposite partner RH & cast out to
    opposite side
5-8::
    1s & 3s chase 1/4 round set cl''wise & dance in passing 2s/4s RSh
    curving in to face 2s/4s as 2s & 4s repeat bars 1-4 & turn right
    about to face 1s/3s.  Now in 2 lines across 4 3 (1) (2)
9-16::
    »Best Set in the Hall« figure:
::
    _9-12_    Join hands with partner & set, 3s & 1s pull back RSh &
    cast to end of their lines _while_ 4s & 2s dance in & turn about to
    face 3s/1s
::
    _13-16_  All set, 2s & 4s pull back RSh & cast to end of their lines
    _while_ 1s & 3s dance in to middle.  End in lines facing in, (2) (1)
    3 4
17-24::
    All dance »La Baratte« figure in 2 lines facing partner:
::
    _17-18_  All join hands on sides & set
::
    _19-20_  1/2 turn partner RH, retain hand but at arm''s length from
    each other
::
    _21-22_  Man retraces steps with Lady turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies original
    place) & releasing Ladies RH she turns under Mans left arm until
    almost in original places
::
    _23-24_  Couples change places LH to opposite places. End in 2 lines
    2 1 (3) (4)
25-32::
    »Best Set in the Hall« figure (4 bars only):
::
    _25-28_   Join hands with partner & set, 1s & 3s pull back RSh &
    cast to end of lines _while_ 2s & 4s dance in & turn about to face
    3s/1s. (3) 2 (4) 1
::
    _29-32_   2s & 4s 1/2 turn partner RH (1 bar), opening out to circle
    4H round to left (1 bar), continue circle with partner to reform
    square set (2 bars)

{{explanation}}
End 2 3 4 1, all having moved 1 place anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (6414, '2013-08-21 08:31:23.986476+00', '2023-02-04 01:21:19.92274+00', 4407, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance RH across (1L with 2s & 1M with 3s)
9-16::
    1s dance reels of 3 with 2s+3s on own sides (1s start by dancing up
    to top & casting)
17-24::
    1s dance reels of 3 across (1L with 2s & 1M with 3s) 1s end BtoB in
    the middle 1L facing 2s & 1M facing 3s
25-32::
    1s dance Double Triangles up/down set (1L with 2s & 1M with 3s to
    start) ending in 2nd place own sides
33-40::
    2s+1s+3s circle 6H round & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6415, '2013-08-21 08:31:23.994673+00', '2023-02-04 01:21:19.941598+00', 9933, 3, NULL, 'ace', '{{explanation}}
2s start on opp sides

1-8::
    2s passing LSh dance 1/2 diagonal reel of 4 with 3rd corners & pass
    RSh to dance 1/2 reel with 4th corners ending in 2nd place own sides
9-16::
    2s dance 1/2 reels of 3 across (Man with 3s at top & Lady with 2s) &
    1/2 reel s of 3 on sides ending 2nd place opposite sides
17-24::
    All join hands on sides & set (HS), 2s dance down & cast up to 2nd
    places opposite sides
25-32::
    2s+1s 1/2 turn 2H on sides _while_ 3s (at bottom) 1/2 turn 2H & all
    circle 6H round to left 1/2 way, 1s+3s 1/2 turn 2H on sides _while_
    2s (at bottom) 1/2 turn 2H & all circle 6H round to left 1/2 way to
    end 2 (3) 1', 0);
INSERT INTO 'dancecrib' VALUES (6416, '2013-08-21 08:31:24.00333+00', '2023-02-04 01:21:19.960819+00', 7460, 3, NULL, 'ace', '{{explanation}}
3 couple Triangular Set

{{title}}
Strathspey

1-8::
    All turn partner RH & giving LH to corner dance Grand Chain
9-16::
    All set to partner, turn RH, set to corners & turn LH
17-24::
    Ladies dance behind partner to next Ladies place _while_ Men
    petronella turn to next place to right, all set & repeat bars 17-20
25-32::
    Ladies dance RH across, set to ''new'' partner & turn RH
33-40::
    Ladies dance behind ''new'' partner to next Ladies place _while_ Men
    petronella turn to next place, all set & repeat
41-48::
    Ladies dance RH across, set to ''new'' partner & turn RH
49-56::
    Ladies dance behind ''new'' partner to next Ladies place _while_ Men
    petronella turn to next place, all set & repeat (back to own
    partner)
57-64::
    All turn partner RH & giving LH to corner dance Grand Chain

{{title}}
Reel

1-8::
    All circle 6H round & back
9-16::
    All set to partner, turn RH, set to corners & turn LH
17-24::
    All dance 1/2 Schiehallion reel (2 places) passing RSh in middle
25-32::
    Men dance LH across, set to partner & turn RH
33-40::
    All dance 1/2 Schiehallion reel (2 places) passing RSh in middle
41-48::
    Men dance LH across, set to partner & turn RH
49-56::
    All dance 1/2 Schiehallion reel (2 places) passing RSh in middle
57-64::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9214, '2016-06-16 22:42:05.339806+00', '2023-02-04 01:21:19.97818+00', 16280, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 on own sides (1s dance in/down to start)
9-16::
    1s+2s+3s dance mirror reels of 3 on sides (1s in/down to start)
17-20::
    1s turn 2s 1.1/2 times (Men RH, Ladies LH)
21-24::
    1s turn 3s 1.1/2 times (Men LH, Ladies RH)
25-26::
    3s dance down to 3rd place _while_ 1s cross up to 2nd place opp side
    facing out
27-32::
    1s cast up, cross RH, cast to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (6417, '2013-08-21 08:31:24.011389+00', '2023-02-04 01:21:20.005864+00', 4411, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-16::
    1s dance down for 2 steps, turn 2H, dance up to top & turn 2H
    remaining in centre facing up
17-24::
    1s+3s dance double Fig of 8 round 2s with 1s casting to start
25-32::
    1M+2M turn LH 1.1/2 times _while_ 1L+2L turn RH 1.1/2 times, 1M+3M
    turn RH 1.1/2 times _while_ 1L+3L turn LH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (14372, '2021-10-11 22:41:00.095364+00', '2023-02-04 01:21:20.251254+00', 20450, 3, NULL, 'ace', '1-8::
    1s turn 2H; 1s+2s set, 1s dance down to 2nd place _while_ 2s cast up
    to 1st place
9-16::
    Mirror reels of 3 on sides (2s in/down, 1s out/down, 3s in/up).  1s
    end in 2nd place own side
17-20::
    1s turn 2H moving down to 3rd place in centre facing partner (3
    bars) _while_ 3s cast up to 2nd place & advance 1 step. Bar 20:
    3s+1s join hands & retire 1 step
21-24::
    All 4 couples join hands on sides, set advancing, pull back RSh &
    dance back out to place. 2 3 1 4
25-28::
    2s & 1s dance down between couple below & cast back up to place
29-31::
    2s+3s circle 4H round to left ending in centre facing partner (3
    bars) _while_ 1s turn 2H moving down to 4th place in centre _while_
    4s cast up to 3rd place & advance 1 step

{{explanation}}
32	All 4 couples join hands on sides & retire 1 step to sides.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6418, '2013-08-21 08:31:24.019422+00', '2023-02-04 01:21:20.281594+00', 12929, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 1s dance down between 3s & cast up to 2nd place
    _while_ 3s set & cross RH
9-16::
    All dance Grand Chain (3s cross to start) for 4 places only.
    (3)(2)(1)
17-24::
    2s+1s change places (1s make arch), 3s+1s change places (3s make
    arch), 3s+2s change places (2s make arch) & all 1/2 turn RH to …
25-32::
    1s+2s+3s dance Poussette.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6419, '2013-08-21 08:31:24.029138+00', '2023-02-04 01:21:20.320002+00', 14785, 3, NULL, 'ace', '1-8::
    1s cast down to bottom, meet & dance up to face out at top
9-16::
    1s dance Reflection reels of 3 on own sides (1s out & down to start)
17-24::
    1s+2s change places on sides (Men LH, Ladies RH), 1s+3s change
    places (Men RH, Ladies LH), 1s+4s turn 1.1/2 times (Men LH, Ladies
    RH)
25-32::
    3s+4s+1s dance Reflection reels of 3 on own sides (1s in & up to
    start)  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6420, '2013-08-21 08:31:24.039067+00', '2023-02-04 01:21:20.353345+00', 4417, 3, NULL, 'ace', '1-8::
    1s & 2s set & cross RH, 1M followed by partner cast 1 place & cross
    to own sides _while_ 2L followed by partner cast up & cross to own
    sides
9-16::
    1s repeat with 3s
17-24::
    2s+3s+1s set, cross LH & chase anticlockwise back to own sides
25-32::
    1s+3s+2s set, 1s cast 1 place _while_ 3s cross up to top _while_ 2s
    cross RH, 1s turn LH to face 1st corners _while_ 2s & 3s chase
    cl''wise to own sides
33-40::
    1s dance ''Hello-Goodbye'' setting & turn RH to 2nd place own side
41-48::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14427, '2021-11-06 01:12:16.383886+00', '2023-02-04 01:21:20.419485+00', 15726, 3, NULL, 'ace', '1-8::
    1s cast (2s step up) & cross LH; 1s cast to left (1M up, 1L down) to
    face up/down centre & cross LH to face 1st corners
9-16::
    1s set to & turn 1st corners; set to & turn 2nd corners
17-24::
    1s dance Fig 8 down round 3s
25-32::
    1s dance 6 bar mirror reels of 3 on opp sides (1s in/up to start) &
    cross RH to own side', 0);
INSERT INTO 'dancecrib' VALUES (6421, '2013-08-21 08:31:24.047314+00', '2023-02-04 01:21:20.456663+00', 9815, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, turn RH 1.3/4 times to face 1st corner pstns
    _while_ 2s+3s dance 1/2 R&L
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners & 1/2 diagonal reel
    of 4 with 2nd corners ending with 1/2 turn LH to face opposite sides
17-24::
    1s dance RH across (Lady with 2s & Man with 3s), pass LSh & dance LH
    across with other couple & pass LSh to face 1st corners
25-32::
    1s dance LSh reels of 3 on opposite sides & 1s cross RH to 2nd place
    own side', 0);
INSERT INTO 'dancecrib' VALUES (10527, '2018-03-20 06:26:59.629674+00', '2023-02-04 01:21:20.484321+00', 17444, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link; 1s+3s Set+Link
9-16::
    2s+3s+1s circle 6H round & back
17-24::
    1s lead up to face 1st corners, set to 1st corner, set to 2nd
    corner, pull back RSh & 1s cross RH to 2nd place own side
25-32::
    2s+1s+3s dance DoSiDo & turn partners 2H once round', 0);
INSERT INTO 'dancecrib' VALUES (6422, '2013-08-21 08:31:24.057115+00', '2023-02-04 01:21:20.517549+00', 4424, 3, NULL, 'ace', '1-8::
    All clap as 1L+2L+3L dance RSh round partners; 3s followed by 2s &
    1s lead down
9-16::
    All 1/2 turn (Lady under Man''s R arm) & 1s followed by 2s & 3s lead
    back to places on opposite sides; 1s+2s+3s set on sides, 1/2 turn
    partner RH ending in centre of dance facing up ready for …
17-24::
    1s+2s+3s dance Promenade
25-32::
    1s+2L dance RH across, 1M ends in 2nd place (2M step up 27-28);
    1s+2M dance LH across (2L step up 31-32), 1s end in 2nd place own
    side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6423, '2013-08-21 08:31:24.066981+00', '2023-02-04 01:21:20.55372+00', 12446, 3, NULL, 'ace', '1-8::
    1s set & 1M casts 1 place, 1M dances 1/2 reel of 3 across with 2s to
    end in middle facing up below 2s as 1L steps in to face partner
9-16::
    1s+2s set & dance RH across 1/2 way, 1L followed by partner dances
    out below 3M & casts up to cross to orig place
17-24::
    1s set & 1L casts 1 place, 1L dances 1/2 reel of 3 across with 2s to
    end in middle facing up below 2s as 1M steps in to face partner
25-32::
    1s+2s set & dance LH across 1/2 way, 1L followed by partner dances
    out above 2M & casts down & crosses to own side', 0);
INSERT INTO 'dancecrib' VALUES (6424, '2013-08-21 08:31:24.157826+00', '2023-02-04 01:21:20.695668+00', 4425, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 R&L, 1s+4s dance RH across
9-16::
    2s+1s also 4s+3s dance 1/2 R&L (back to places), 2s+3s dance LH
    across
17-24::
    All Adv+Ret & turn partners RH to end 1s/3s facing down & 2s/4s
    facing up
25-40::
    All four couples in allemande hold dance RSh reel of 4 (16 bars)
41-48::
    1L 1/2 turns 2M RH, 1/2 turn 3M LH & 1/2 turn 4M RH _while_ 1M 1/2
    turns 2L LH, 1/2 turn 3L RH & 1/2 turn 4L LH, 1s cross to own sides
    LH', 0);
INSERT INTO 'dancecrib' VALUES (6426, '2013-08-21 08:31:24.174223+00', '2023-02-04 01:21:20.750117+00', 4431, 3, NULL, 'ace', '1-8::
    1L+2L dance between partners & cast round them to face own partner,
    1s+2s turn partners with 2H
9-16::
    1M+2M repeat above Fig
17-24::
    1s cross RH, cast 1 place, cross LH & cast down 1 place
25-32::
    1s lead up to top, set, cast 1 place & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6427, '2013-08-21 08:31:24.188021+00', '2023-02-04 01:21:20.883452+00', 4433, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, set & cross back RH
9-16::
    1s lead down the middle & back placing 1L between 2s & 1M ends
    between 3s facing up
17-24::
    2s+1s+3s set twice with 1s turning to 2nd place own side, 2s+1s+3s
    set twice on sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6428, '2013-08-21 08:31:24.197761+00', '2023-02-04 01:21:20.976469+00', 4434, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH, set & cross back RH
9-16::
    1s lead down & up to end Lady between 2s all facing down & Man
    between 3s all facing up
17-24::
    All set twice with 1s turning to left onto own sides & all set twice
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6429, '2013-08-21 08:31:24.206004+00', '2023-02-04 01:21:21.004793+00', 12662, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    1M dances 1/2 Fig of 8 round 2s _while_ 4M dances 1/2 Fig of 8 round
    3s, pick up partner (on left) in prom hold dance down/up into 1/2 LH
    across
9-12::
    Change places with corner 2s/3s passing RSh, 1s & 4s set _while_
    2s+3s dance 1/2 LH across
13-16::
    3s & 2s change places with corners 4s/1s, 3s & 2s set _while_ 4s+1s
    dance 1/2 LH across
17-20::
    1s dance up between 3s (at top) & cast to 2nd place own sides
    _while_ 4s dance down & cast up to 3rd place opposite side.  (3) 1
    (4) 2
21-24::
    All 1/2 turn & twirl to other side.  3 (1) 4 (2)
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7880, '2013-08-21 08:31:50.479022+00', '2023-02-04 01:23:09.391408+00', 7019, 3, NULL, 'ace', '1-8::
    1s 3/4 turn RH moving down (2s step up) & dance 6 bars Crown
    Triangles ending with Man between 2s & Lady between 3s all facing
    down
9-16::
    1M+2s also 1L+3s dance down the middle & back 1M+2s turning to face
    1L+3s
17-24::
    1s change places RH, cast to right to 2nd place & turn RH _while_
    2s+3s set facing on sides, change places RH, set to partner & cross
    RH
25-32::
    1s dance diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (4001, '2013-08-21 08:30:41.042721+00', '2023-02-04 01:18:26.885424+00', 9974, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 RH across, 2s+1s+3s dance reels of 3 on sides (1s
    LSh to 3s).  (2) (1) 3
9-16::
    1s+3s dance 1/2 LH across,  2s+3s+1s dance reels of 3 on sides (2s
    RSh to 3s).  (2) (3) 1
17-24::
    1s lead up crossing to 1st place opposite sides, all turn partners
    2H 1.1/2 times & 1s & 2 end NHJ with partner in middle ready for …
25-32::
    1s+2s dance Rondel', 0);
INSERT INTO 'dancecrib' VALUES (12091, '2019-08-30 09:54:37.73808+00', '2023-02-04 01:21:21.03487+00', 4737, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 "St Andrew''s Cross" formation:
::
    _1_ - 4   1s+2s (also 3s+4s) face diagonally in, dance in 1 step,
    turn 1/4 right about & dance out (all have moved 1 place round
    anticlockwise),  All set (4 bars)
::
    _5_ - 8    1s+2s also 3s+4s repeat to end (2)(1)(4)(3)
9-16::
    All NHJ on sides Adv (1 step), Ret (2 steps), Adv (1 step);  1s+2s
    also 3s+4s dance 1/2 RH across back to original places
17-24::
    1s NHJ face down & make arch, 2s, 3s & 4s face up NHJ, all set as 2s
    (bar 18), 3s (bar 20) & 4s (bar 22) dance up under arch made by 1s.
    Bars 23-24 all 4 couples turn LH
25-32::
    2s+3s+4s make arches 1s dance up under arches followed by 4s, 3s &
    2s; 1s cast to 4th place own sides, 2s loop round back into 1st
    place.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6430, '2013-08-21 08:31:24.215754+00', '2023-02-04 01:21:21.223564+00', 4438, 3, NULL, 'ace', '1-8::
    1M+2L cross RH, 1L+2M cross RH, 2s & 1s turn RH 1.1/2 times
9-16::
    1s lead down the middle, back to top & cast to 2nd place
17-24::
    2s+1s set advancing, set, set retiring & set
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12925, '2020-07-01 00:20:38.116006+00', '2023-02-04 01:21:21.406013+00', 4439, 3, NULL, 'ace', '1-8::
    1s cast (2s step up), 1s dance LSh reels of 3 across (Lady with 2s &
    Man with 3s) & end in 2nd places
9-16::
    1s turn 1st corners RH, pass RSh, turn 2nd corners LH, pass LSh to
    face 1st corners
17-20::
    1s set & turn 1st corners 2H & end between corners. 2 (1) 3
21-24::
    2s+1s+3s circle 6H round 1/2 way to left (3 bars) Bar 24: 3s+2s turn
    2H into centre & 1s dance in, all face up taking Allemande hold
25-32::
    3s+1s+2s dance Allemande 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6431, '2013-08-21 08:31:24.223683+00', '2023-02-04 01:21:21.421383+00', 4440, 3, NULL, 'ace', '1-8::
    1s turn RH 1.1/2 times, face 2s on sides & turn LH
9-16::
    1s turn 2s on sides RH & 1s turn LH 1.1/2 times to original places
17-24::
    1s lead down the middle & up
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6432, '2013-08-21 08:31:24.233612+00', '2023-02-04 01:21:21.437417+00', 4441, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across 1/2 way, set & 2s cross LH to 1st place
    own sides _while_ 1s turn LH to face 1st corners
9-24::
    1s dance Corner Chain with 1st & 2nd corners:
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end turning LH to face 3rd
    corner pstns
25-32::
    1M dances LSh reel of 3 with 2s _while_ 1L dances LSh reel of 3 with
    3s, 1s cross RH to 2nd places own sides', 0);
INSERT INTO 'dancecrib' VALUES (6433, '2013-08-21 08:31:24.241827+00', '2023-02-04 01:21:21.451384+00', 4442, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & circle 4H round to left with 3s
9-16::
    1s set, cast up & circle 4H round to left with 2s
17-24::
    1s lead down below 3s, cross, cast to top on opposite sides, cross
    RH & cast 1 place to face 1st corners
25-32::
    1s turn 1st corners RH, turn partners LH, turn 2nd corners RH & turn
    partner LH to face 1st corners
33-40::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners &
    cross RH to 2nd place own sides
41-48::
    1s dance reels of 3 on own sides giving RSh to 3rd corner', 0);
INSERT INTO 'dancecrib' VALUES (6434, '2013-08-21 08:31:24.249896+00', '2023-02-04 01:21:21.470343+00', 4444, 3, NULL, 'ace', '1-8::
    1s lead down below 3s, cross & cast up to 2nd pl opp sides, 2s+3s
    turn once as 1s turn with 2H 1.1/2 times to end in centre facing up
9-16::
    1s dance up for 2 steps, set to each other, dance down for 2 steps &
    turn 2H to face 1st corners
17-24::
    1s set to 1st corners, pass partner by RSh, set to 2nd corner & pass
    by RSh to face 4th corner
25-32::
    2s & 3s dance reels of 3 across as 1s dance 1/2 reel with each cpl
    (1L+2s & 1M+3s giving RSh to 4th crnr to start), 1s cross RH to 2nd
    pl', 0);
INSERT INTO 'dancecrib' VALUES (6435, '2013-08-21 08:31:24.257868+00', '2023-02-04 01:21:21.495649+00', 10589, 3, NULL, 'ace', '1-8::
    1L+2L Set+Link _while_ 1M+2M Reverse Set+Link, 1s dance 1/2 Fig of 8
    round 2s
9-16::
    1M+3L Set+Link _while_ 1L+3M Reverse Set+Link, 1s dance 1/2 Fig of 8
    round 3s
17-24::
    2s+3s+1s petronella turn into centre & set to partners, 1/2 turn 2H
    & petronella turn back to sides for…
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14373, '2021-10-11 22:41:01.195789+00', '2023-02-04 01:21:21.527918+00', 17885, 3, NULL, 'ace', '1-4::
    1s+4s cross RH, cast to middle (2s/3s step down/up)
5-8::
    1s+4s dance RH across to finish 1s/4s facing up/down NHJ 2 (1) (4) 3
9-16::
    2s+1s also 4s+3s change places on sides (2s & 3s moving outwards)
    then dance 6 bars double Fig of 8 (1s & 4s casting inwards to start)
    2 1 4 3
17-24::
    1s+4s dance Set & Rotate 2 4 1 3
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6436, '2013-08-21 08:31:24.2678+00', '2023-02-04 01:21:21.624127+00', 4447, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, 2s cross RH _while_ 1s turn RH to form a line
    across between 2s & Bal-in-Line & face down
9-16::
    1s+2s dance down & up to top to end 2s in 1st place & 1s BtoB facing
    other partner
17-24::
    1s+2s dance reel of 4 across 1s & 1s end facing 1st corners
25-32::
    1s turn 1st corners RH, turn partners LH, turn 2nd corners RH & turn
    partner LH to 2nd places own sides', 0);
INSERT INTO 'dancecrib' VALUES (6439, '2013-08-21 08:31:24.293548+00', '2023-02-04 01:21:22.118631+00', 4455, 3, NULL, 'ace', '1-8::
    1s+2s dance reel of 4 on Ladies side (1L+2L pass LSh _while_ 1M+2M
    cross to above partner''s place, then 1M+2L & 2M+1L pass RSh then Men
    pass LSh. End 2M passing in front of 1M as Men dance back to places)
9-16::
    1s+2s dance reel of 4 on Men''s side (1M+2M pass LSh _while_ 1L+2L
    cross to below partner''s place, then 1L+2M & 2L+1M pass RSh then
    Ladies pass LSh. End  2L passing in front of 1L as Ladies dance back
    to  places)
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Allemande. 2 1', 0);
INSERT INTO 'dancecrib' VALUES (6506, '2013-08-21 08:31:25.452336+00', '2023-02-04 01:21:26.507567+00', 4618, 3, NULL, 'ace', '1-8::
    All dance interlocking reels of 4 passing partner RSh
9-16::
    1s+3s dance Men''s Chain
17-24::
    1s pass partner RSh & weave out & in to meet partner behind 3s, lead
    in between 3s & cross to original places (M turning ptnr under his
    arm)
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6440, '2013-08-21 08:31:24.303251+00', '2023-02-04 01:21:22.224853+00', 4461, 3, NULL, 'ace', '1-8::
    1s cast to 3rd place, cross RH & cast up to 2nd place opp sides (2s
    step up on 7-8 & face out)
9-16::
    2s+1s+3s with near hands joined on sides rotate about the 1s who set
    (3s dancing inwards) to 3 (1) 2.  All turn right about to give other
    hand & reverse rotate back to places  2 (1) 3
17-24::
    1s reels of 3 on opp sides, 1s pass person on Right RSh, 1s cross up
    RH to 1st place as 2s cast to 2nd place, both couples in middle
    ready for ...
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9021, '2015-11-30 09:00:02.408582+00', '2023-02-04 01:21:22.247564+00', 16526, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Mirror (Reflection) reels of 3 on sides (1s in/down
    to start)
9-16::
    1s set, cast (2s step up) & turn RH.  1L casts to 3rd place, 1M
    casts up to 1st place (2M steps down & 3L steps up)
17-24::
    All dance 3 couple Bourrel:
::
    _17-20_     1M+3L also 2M+1L set advcg & 3/4 turn 2H to line up/down
    middle then pull back RSh turning to face own prtnrs as 3M & 2L
    chase anticl''wise to face them
::
    _21-24_     All set & turn 2H to own sides.  3 1 2
25-32::
    3s+1s+2s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6441, '2013-08-21 08:31:24.311487+00', '2023-02-04 01:21:22.27603+00', 4466, 3, NULL, 'ace', '1-8::
    1s cross down to dance RSh reels of 3 across (1L RSh to 2M, 1M RSh
    to 3L, 2s dancing up to top to start reel). 1s join LH in centre &
    RH with 1st corners
9-16::
    1s Bal-in-Line with 1st corners, turn corners into centre &
    Bal-in-Line, turn 1st corners out & end BtoB facing 2nd corners.
17-24::
    1s dance RSh diagonal reel of 4 with 2nd corners & end in 2nd place
    own sides
25-32::
    1s cross down between 3s & cast up to 2nd place on opposite sides,
    1s cross up & cast to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6442, '2013-08-21 08:31:24.323215+00', '2023-02-04 01:21:22.296507+00', 8960, 3, NULL, 'ace', '1-8::
    1s & 3s petronella turn into middle, 1/2 turn partner RH into prom
    hold & promenade clockwise 1/4 way round to end behind 2s (a line of
    6 across)
9-16::
    1s+2L also 3s+2M dance 2 reels of 3 (1M & 3L pass partners RSh to
    start)
17-24::
    1s & 3s in prom hold promenade clockwise 1/4 way (to top & bottom
    facing up/down - 3s & 1s on opp sides) & all circle 6H 1/2 way to
    left.   1(2)3
25-32::
    1s+2s dance 1/2 R&L, 1s cross RH & cast to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (6443, '2013-08-21 08:31:24.337031+00', '2023-02-04 01:21:22.475624+00', 4471, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, set & cast back to top
9-16::
    1s lead down for 2 steps, back to top, cast & lead to top
17-24::
    1s+2s dance Allemande
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6444, '2013-08-21 08:31:24.348725+00', '2023-02-04 01:21:22.516239+00', 4473, 3, NULL, 'ace', '1-8::
    1s dance Inveran reels with 2s+3s
9-16::
    1s lead down to bottom & back to top
17-24::
    1s cross RH, cast 1 place & turn RH 1.1/2 times to 2nd places
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6445, '2013-08-21 08:31:24.362756+00', '2023-02-04 01:21:22.656239+00', 4476, 3, NULL, 'ace', '1-8::
    1s lead down 1 place, cross & turn 3s on sides with nearer hands to
    end 2nd place opposite sides, 2s+1s+3s Adv+Ret
9-16::
    2s+1s+3s circle 6H round & back
17-24::
    2s followed by 1s (who 1/2 turn RH at top) & 3s lead down the
    middle, turn inwards, 3s followed by 1s & 2s dance up & 3s cast to
    3rd place
25-32::
    1s set, cast to 2nd place & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6446, '2013-08-21 08:31:24.370997+00', '2023-02-04 01:21:22.675655+00', 4477, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 2s+1s+3s set on sides, 1s petronella turn into lines
    across (1L between 2s & 1M between 3s) _while_ 2s & 3s set
9-16::
    2s+1s+3s set, 1s dance reel of 3 opp sides giving LSh to 2nd crnrs,
    2s end in middle at top facing down, 1s & 3s in middle facing up
17-24::
    2s, 1s & 3s Set+Link with partners, 1s end facing down, 2s, 1s & 3s
    Set+Link again, 2s & 3s ending on own sides & 1s facing 2nd corners
25-32::
    1s dance Pass+Turn with 2nd corners & turn partners RH, dance
    Pass+Turn with 1st corners ending in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6447, '2013-08-21 08:31:24.385488+00', '2023-02-04 01:21:22.980797+00', 4479, 3, NULL, 'ace', '1-8::
    1s set twice to 2L, set twice to 2M
9-16::
    1s dance Figs of 8 round 2s+3s on own sides (dancing between 2s to
    start)
17-24::
    1s & 4s advance (down/up), set, circle 4H round to left ending in
    2nd/3rd places
25-32::
    2s & 3s repeat all ending in original places
33-40::
    1s+2M dance RH across; 1s+3M dance LH across
41-48::
    1s+4L dances RH across & 1s turn 2H to 4th places', 0);
INSERT INTO 'dancecrib' VALUES (6449, '2013-08-21 08:31:24.431706+00', '2023-02-04 01:21:23.107304+00', 4483, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 RH across, 1s+3s 1/2 LH across, 1s cast to top
    (2s+3s step down) & 1/2 turn RH into prom hold facing down _while_
    2s+3s cross RH
9-16::
    1s dance 1/2 LSh reel of 3 with 2s (passing 2L to start) then 1/2
    RSh reel of 3 with 3s (passing 3M to start)
17-24::
    1s dance 1/2 RSh reels across (Man RSh to 2L & Lady RSh to 3M) & 1s
    turn RH 1.1/2 times to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6450, '2013-08-21 08:31:24.44+00', '2023-02-04 01:21:23.134174+00', 4484, 3, NULL, 'ace', '1-8::
    1s+2s set, turn partners 2H opening out into 4H round
9-16::
    1s+2s dance the Knot, 1s turn LH to end facing 1st corners
17-24::
    1s turn 1st corners RH, partner LH, 2nd corners RH & partner 3/ 4 LH
    finishing in middle facing opp sides ready for …
25-32::
    1s dance RH across, (1M with 3s & 1L with 2s), pass partner RSh &
    dance LH across with other couple, 1s end in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (12467, '2020-01-02 07:00:42.03796+00', '2023-02-04 01:21:23.332201+00', 16684, 3, NULL, 'ace', '1-4::
    1s dance down to BtoB facing 3s (2s step up), 1s+3s set
5-8::
    1s+3s turn (Ladies LH, Men RH) to end on sides & all set.  2 1 3
9-16::
    2s+1s+3s circle 6H 1/2 round to left; 3s+1s+2s dance DoSiDo
17-20::
    1s set, petronella turn _while_ 2s+3s cross RH with partner & set
21-24::
    1s set, petronella turn _while_ 2s+3s change places RH on side & set
25-32::
    1L+2s also 1M+3s dance RH across; 2s+1s+3s turn partner 2H.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6451, '2013-08-21 08:31:24.449659+00', '2023-02-04 01:21:23.418738+00', 4491, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s set & cast (2s step up); 2s+1s+3s all turn RH to end in Allemande
    hold ready for …
17-24::
    2s+1s+3s dance Allemande
25-32::
    3s+1s+2s Adv+Ret for 2 steps; 3s cast to 3rd place _while_ 1s+2s
    dance up, 1s casting to 2nd place.  2 1 3
::
    2nd turn bars 29-32: 3s cast to bottom & dance up to 3rd place,
    original 1s cast to bottom, 2s dance up to place', 0);
INSERT INTO 'dancecrib' VALUES (6452, '2013-08-21 08:31:24.457735+00', '2023-02-04 01:21:23.446198+00', 4494, 3, NULL, 'ace', '1-8::
    All set, 1s & 4s turn 1.1/2 & face up/down, cast to 2nd/3rd place
    _while_ 2s+3s cross RH, dance 1/2 RH across, dance down/up to
    4th/1st pl.  3 1 4 2
9-16::
    1s+3s also 2s+4s dance 3/4 double Fig of 8 (1s/4s crossing up/down
    to start & end 1 3 2 4 on opp sides), all change pl on sides (M LH &
    L RH)
17-24::
    2s & 3s dance to opposite ends (passing RSh), cross RH, 1s+4s dance
    1/2 RH across & circle 4H left for 4 bars to 2 4 1 3, all set
25-32::
    2s+4s also 1s+3s dance Diamond Poussette.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6455, '2013-08-21 08:31:24.485575+00', '2023-02-05 18:08:14.642877+00', 9875, 3, NULL, 'ace', '1-8::

    1s turn RH, cast 1 place; 1s turn LH to face 1st corners

9-16::

    1s dance 1/2 diagonal reel of 4 with 1st corners, 1s dance RH across

    (Man with 2s & Lady with 3s) end facing 2nd corners

17-24::

    1s dance 1/2 diagonal reel of 4 with 2nd corners, 1s dance RH across

    (Man with 3s & Lady with 2s) end in centre facing own side LSh to

    LSh

25-32::

    1s dance out on own side & cast round 3rd corner to face up/down

    set, change places RH with opposite person & cast round corner to

    2nd place own side _while_ 2s+3s cross RH, set & change places RH on

    sides & all set', 0);
INSERT INTO 'dancecrib' VALUES (6453, '2013-08-21 08:31:24.467463+00', '2023-02-04 01:21:23.577819+00', 4499, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, set & turn 2H to face up
9-16::
    2L+1L also 2M+1M set & turn 2H, 1s cross RH & clap (1L on 1st beat
    of bars 15-16, 1M on 3rd beat of those bars)
17-24::
    2L+1M also 2M+1L set & turn 2H 1.1/2 times, 2s repeat bars 13-16
25-32::
    1s+2s circle 4H round to left 1/2 way & 4H once round to right to
    2nd place own sides
33-40::
    2L+1M set, 2M+1L set, 2s+1s set & turn partners', 0);
INSERT INTO 'dancecrib' VALUES (6454, '2013-08-21 08:31:24.47742+00', '2023-02-04 01:21:23.596274+00', 4500, 3, NULL, 'ace', '1-8::
    1M+2L set & 3/4 turn RH, 2L dances up & casts round 1L back to place
    _while_ 1M dances down & casts up round 2M back to place
9-16::
    1L+2M set & 3/4 turn LH, 2M dances up & casts round 1M back to place
    _while_ 1L dances down & casts up round 2L back to place
17-24::
    1s turn RH, lead down 2 places, cross & cast up round 3s to 2nd
    places
25-32::
    2s+1s+3s dance reflection reels of 3 on sides (1s in & up to start)
    & 1s end facing 1st corners
33-40::
    1s dance "Hello-Goodbye" setting ending with petronella turn to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (15345, '2022-12-19 01:21:02.113519+00', '2023-02-04 01:21:23.768132+00', 21134, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig of 8 up round 2s.
    2 1 3
9-16::
    2s+1s+3s dance mirror reels of 3 on the sides (1s dance in/down to
    start)
17-24::
    1s+3s dance Double Figs 8 (1s cross down, 3s cast up)
25-32::
    2s+1s circle 4H round  to left & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6456, '2013-08-21 08:31:24.495289+00', '2023-02-04 01:21:23.828163+00', 4506, 3, NULL, 'ace', '1-8::
    1s lead down for 3 steps, 1/2 turn RH, lead up to top & cast to 2nd
    place opposite sides
9-16::
    2s+1s dance R&L, 1s turning to own sides
17-24::
    2s+1s Promenade
25-32::
    2s+1s Adv+Ret 1 step twice, turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (12092, '2019-08-30 09:54:38.522974+00', '2023-02-04 01:21:23.863741+00', 4508, 3, NULL, 'ace', '1-8::
    1L dances 1/2 reel of 3 across with 2s (RSh to 2M); 1s take prom
    hold & continue reel of 3 with 2s (LSh to 2M in 2L''s place) to end
    at top in middle on opp sides facing down
9-16::
    1s lead down & back to face 2L (1L on 1M''s left)
17-24::
    1s+2L dance RH across, 1s face 2M  (1L on 1M''s right); 1s+2M dance
    LH across.  1s end in middle, top place with 2H joined & 2s step in
    for …
25-32::
    1s+2s dance Poussette. 2 1', 0);
INSERT INTO 'dancecrib' VALUES (14212, '2021-08-14 00:20:57.249183+00', '2023-02-04 01:21:23.892982+00', 12318, 3, NULL, 'ace', '1-8::
    1s cross, cast 1 place & dance 1/2 Fig of 8 round 3s. 2s step up
    bars 3-4
9-16::
    1s dance RH across (1L with 2s at top, 1M with 3s) back to 2nd place
    own side; 1s dance LH across with other couple & finish facing 1st
    corners
17-20::
    1s turn 1st corner RH into a diagonal line between 2L & 3M who give
    LH to their partner (diagonal line order 2L 2M 1L 1M 3L 3M) (Note:
    Corners have to dance well out to meet 1s)
21-24::
    All 3 couples balance in line, all drop hands & 1s & their corner
    curve to right. dancing into the place of the person they have just
    turned.
25-32::
    1s & their 1st corners repeat bars 17-24, 1s finish in 2nd place.
    (Note: 1s have to dance out further to meet corners & turn RH. 1L &
    2L, 1M & 3M, 2M & 3L give LH to each other & balance in line). End 2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (6457, '2013-08-21 08:31:24.503419+00', '2023-02-04 01:21:23.915416+00', 9701, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 2nd place, 1s dance 1/2 Fig of 8 round 2s
9-16::
    2s+1s+3s set & cross RH, 2s+3s set & cross RH _while_ 1s turn RH,
    pull back RSh to face 1st corners
17-24::
    1s turn corners 2H, pass RSh to turn 2nd corners 2H & pass RSh to
    2nd place own side
25-32::
    2s+1s+3scircle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6458, '2013-08-21 08:31:24.514396+00', '2023-02-04 01:21:23.949913+00', 8098, 3, NULL, 'ace', '1-8::
    1L casts below 4L & joins her in prom hold _while_ 4M casts above 1M
    & joins him in prom hold, 4M+1M cross down & dance RSh round 3L to
    face up _while_ 4L+1L cross up & dance RSh round 2M to face down (2s
    step up & 3s step down)
9-12::
    4L+1L between 2s & 4M+1M between 3s all joining hands in line across
    Adv+Ret
13-16::
    4s turn RH into prom hold to face 2M pl _while_ 1s turn RH into prom
    hold facing 3L pl _while_ 2s+3s dance 1/2 R&L (change pl RH on sides
    to start)
17-24::
    4s & 1s (prom hold) dance 1/2 diag reel of 4 with 1st corners, pass
    RSh & 1/2 diag reel of 4 with 2nd corners to end with 1s on Ladies
    side & 4s on Men''s side
25-32::
    4s & 1s dance LSh round each other 3/4 way, 4s turn RH & 1s turn LH
    to end in order 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6459, '2013-08-21 08:31:24.584518+00', '2023-02-04 01:21:23.979788+00', 4511, 3, NULL, 'ace', '1-8::
    1L & 4M petronella turn & set, 1L turns 2M 1.1/2 RH then 1/2 turns
    3M LH _while_ 4M turns 3L 1.1/2 RH then 1/2 turns 2L LH (End 1L in
    4M''s place, 4M in 1L''s place)
9-16::
    1M & 4L repeat above Fig (bars 1-8) to end (4) 2 3 (1)
17-24::
    4s+2s also 3s+1s circle 4H round to left (3 bars), opening (4M & 1L
    leading) into circle of 8H (momentarily bar 20), breaking &  flowing
    into 1s+2s also 3s+4s circle 4H round to Left to original places
25-32::
    All dance 1/2 Grand Chain (4 steps), 1s (at bottom) turn RH 1.1/2
    times to 4th place own side _while_ 4s+3s+2s continue Grand Chain.
    End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6461, '2013-08-21 08:31:24.602758+00', '2023-02-04 01:21:24.179954+00', 4512, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place (2s step up 3-4), 1L dances LH across
    with 2s _while_ 1M dances LH across with 3s  2(1)3 4
9-16::
    1s cross RH & cast to 3rd place (3s step up 11-12), 1L+4s dance LH
    across _while_ 1M+3s dance LH across.  2 3 1 4
17-24::
    1s set & lead up to top & cast to 4th place (4s step up 19-20)
25-32::
    2s+3s & 4s+1s dance full reels of 4 across (2L+3M & 4L+1M pass LSh
    to start) 2 3 4 1
33-40::
    All set twice, all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4003, '2013-08-21 08:30:41.062424+00', '2023-02-04 01:18:26.942348+00', 144, 3, NULL, 'ace', '1-8::
    1M followed by 1L casts 1 place, 1M crosses to 2nd place opp side &
    dances RSh round 3L as 1L dances RSh round 3M both to 2nd pl opp
    sides
9-16::
    2s+1s+3s dance reels of 3 on sides (1s giving LSh to 2s)
17-24::
    2s+1s dance Ladies'' Chain
25-32::
    1s dance 1/2 Fig of 8 round 2s & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (10086, '2017-09-03 23:45:02.884848+00', '2023-02-04 01:21:24.215569+00', 4514, 3, NULL, 'ace', '1-8::
    1s+2s set, circle 4H 1/2 round to Left & back, 1s cast to 2nd place
    _while_ 2s dance up to top
9-16::
    1s cross RH (2), 2s cross RH (2), 3s cross RH _while_ 1s+2s set (2).
    All dance 6H 1/2 round to Left
17-24::
    1s+2s cross RH to form circle & dance 4H 1/2 round to Left.  1s+2s
    cross LH to form circle & dance 4H 1/2 round to Right
25-32::
    3s+1s+2s set, circle 6H 1/2 round to Left.  All set, cross RH to own
    sides.  2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (6462, '2013-08-21 08:31:24.610861+00', '2023-02-04 01:21:24.244734+00', 14294, 3, NULL, 'ace', '1-8::
    1s set, dance down to 2nd place, cast down behind 3s & dance up to
    into 2nd place
9-16::
    1s dance reflection reels of 3 on sides (1s dancing out & up). 1s
    end in 2nd place BtB in middle facing own side
17-24::
    1s dance Double Triangles as corners set & petronella turn, set &
    petronella turn.  1s end in middle with 1L facing up & 1M facing
    down
25-28::
    1s dance 1/2 RSh reels of 3 across (1L with 3s in 2nd pl., RSh to
    3M, 1M with 2s in 3rd pl., RSh to 2L) ending on own sides
29-32::
    1s dance LSh 1/2 reels of 3 on sides (1L LSh to 2L, 1M LSh to 3M)
    2s+3s dance loops on reels as appropriate.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6463, '2013-08-21 08:31:24.620898+00', '2023-02-04 01:21:24.283147+00', 4517, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+4s set, cast in 1 place & dance RH across
9-16::
    1s+4s set & cast back to places, 1s+2s & 3s+4s circle 4H round to
    left
17-24::
    1L+4M cast to change pl as 1M+2L, 2M+3L & 3M+3L cross RH & set,
    3M+2L cast to change pl as 4M+3L, 1M+4L & 2M+1L cross RH & set
25-32::
    All repeat above Fig bars 17-24

{{title}}
Reel

1-8::
    All petronella turn into centre, petronella turn to opposite sides,
    petronella turn to centre & petronella turn to places
9-24::
    1s turn RH & cast 1 place, cross, cast back to top, dance down below
    3s & cast to 2nd place opposite sides, all turn partners RH
25-32::
    2s+1s with 3s+4s dance Poussette (in pairs) to 3 4 2 1', 0);
INSERT INTO 'dancecrib' VALUES (6465, '2013-08-21 08:31:24.647777+00', '2023-02-04 01:21:24.428197+00', 9638, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s followed by 3s dance up & cast - 1s to 3rd
    place & 3s to 2nd place
9-16::
    1s cross down & dance reflection reels of 3 with 4s+5s on opposite
    sides - 1s end in 3rd place opposite sides
17-24::
    1s cross up & dance reflection reels of 3 on own sides with 2s+3s -
    1s ending in 3rd place own sides
25-32::
    1s set & cast down 1 place, 1s followed by 5s dance up between 4s &
    cast - 1s to 5th place & 5s to 4th place', 0);
INSERT INTO 'dancecrib' VALUES (6466, '2013-08-21 08:31:24.655956+00', '2023-02-04 01:21:24.4512+00', 4521, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across 1/2 way, set to partners, 1s followed by 2s
    lead down, cross below 3s & cast to original places
9-16::
    1s+2s dance the Knot 2s end at top & 1s in prom hold facing 3L
17-24::
    1s in prom hold dance full reel of 3 with 1st corners end facing 2nd
    corners
25-32::
    1s dance reel of 3 with 2nd corners with corners dancing full reel
    but 1s after 4 bars dance down, cross over & cast up behind 3s', 0);
INSERT INTO 'dancecrib' VALUES (6467, '2013-08-21 08:31:24.664011+00', '2023-02-04 01:21:24.468663+00', 12320, 3, NULL, 'ace', '1-8::
    2s+3s set, cross RH & all chase clockwise 1/2 way.  (4)3 2(1)
9-16::
    4s+3s also 2s+1s dance 1/2 R&L, 4s+1s (centre couples) dance 1/2
    R&L.  (3)(1)(4)(2)
17-24::
    4s dance 1/2 RSh diagonal reel of 4 with 1L+2M, pass RSh to dance
    diagonal reel of 4 with 1M+2L & 4s end 3rd place own sides.  (3)2 4
    1
25-32::
    3s (at top) full turn RH & 1/2 turn 2s on sides (RH Ladies side & LH
    Men''s side), 3s dance 1/2 Fig of 8 round.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14004, '2021-05-03 00:20:45.961661+00', '2023-02-04 01:21:24.488883+00', 4527, 3, NULL, 'ace', '1-8::
    1s lead down, cross & cast up round 3s to 2nd place opp sides (2s
    step up 3-4); 1s lead up top, cross & cast to 2nd place own side
9-16::
    2s+1s+3s set, cross RH; 2s & 3s chase clockwise to diagonally opp
    place _while_ 1s chase for 2 steps then turn RH to face 4th corners
    (pstn)
17-24::
    1s dance Corner Pass+Turn with corners; 1s turn RH to face 3rd
    corners (pstn) & dance Corner Pass+Turn with corners.  1s pass RSh
    to 2nd place opp sides (1M facing down, 1L facing up)
25-32::
    Reels of 3 on sides, 1s pass 1st corners RSh to start. 1s cross to
    2nd place own side from ends of set bars 31-32', 0);
INSERT INTO 'dancecrib' VALUES (6468, '2013-08-21 08:31:24.672085+00', '2023-02-04 01:21:24.511119+00', 4528, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 on own side dancing between 2s to
    start
9-16::
    1s+3s dance RH across, 1s+3s dance round clockwise into diagonally
    opposite places
17-20::
    1L casts to top as 3M casts to bottom _while_ 1M+3L 1/2 turn LH &
    retaining LH give RH to partner & Bal-in-Line
21-24::
    1L+3M dance to original places and set _while_ 1M+3L turn LH back to
    original places
25-32::
    1s+2s dance 1/2 R&Ls, set & cross RH to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14583, '2022-02-05 02:20:45.361117+00', '2023-02-04 01:21:24.538783+00', 20610, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left (8 slip steps); 1s+2s dance LH across
    back to place
9-16::
    1s cast (2s step up), meet & dance down, cast up round 3s & turn LH
    to face 1st corners
17-24::
    1s turn 1st corner RH, partner LH to face 1st corner; 1s dance RSh
    round 1st corner, pass LSh to face 2nd corners
25-32::
    1s turn  2nd corner RH, partner LH, 1L faces down, 1M faces up; 1M
    dances out of top, 1L out of bottom & they cast to 2nd place own
    side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13270, '2020-10-16 00:21:05.123171+00', '2023-02-04 01:21:24.599574+00', 12321, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across & 1s cast as 2s dance up to top
9-16::
    2s+1s+3s dance mirror reels on sides, 1s in/down to start; Bars
    13-14: 1s cross up from 2nd place opp sides  to end 2 (1) 3
17-24::
    2s+1s+3s set, 1s Petronella turn to 1M between 2s, 1L between 3s
    _while_ 2s+3s set again; lines of 3 across set & 1s Petronella turn
    to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (11463, '2019-01-01 01:57:20.815399+00', '2023-02-04 01:21:24.619158+00', 19117, 3, NULL, 'ace', '1-8::
    1s cast (2s step up 1-2) & petronella turn to 1L between 2s, 1M
    between 3s; all set, 1s turn RH to face 1st corners _while_ 2s+3s
    cross RH
9-16::
    1s+1st corners dance 1/2 diag reel of 4, 1s pass RSh; 1s+2nd corners
    dance 1/2 diag reel of 4. 1s end in 2nd place opp sides. (2) (1) (3)
17-24::
    2s+1s+3s Adv(1 step)+Ret(1 step), all 1/2 turn partners 2H to face
    partner in middle; all set, pull back RSh & cast to own sides.  2 1
    3
25-32::
    2s+1s dance Diamond (All Round) Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6470, '2013-08-21 08:31:24.68822+00', '2023-02-04 01:21:24.634931+00', 4140, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, cross LH, cast round 2nd corners (M cast up, L
    down) to face 1st corners
9-16::
    1s dance 1/2 reel of 4 with 1st corners, 1/2 reel of 4 with 2nd
    corners to end facing 3rd corner
17-24::
    1s turn 1st corner, partner, 2nd corner, partner & end facing 3rd
    corners
25-32::
    1s dance 1/2 reels of 3 across giving LSh to 3rd corner & 1/2 reels
    of 3 on side (RSh to 4th corner)', 0);
INSERT INTO 'dancecrib' VALUES (4088, '2013-08-21 08:30:43.309542+00', '2023-02-04 01:18:33.745589+00', 280, 3, NULL, 'ace', '{{explanation}}
12 Dancer Square Set, each man between 2 ladies

{{title}}
Part 1

1-8::
    All circle 12H round & back
9-16::
    Men dance RH across with RH partner & next Lady & LH across with LH
    partner & next Lady
17-24::
    All Men dance reels of 3 with partners (Men give RSh to RH partner
    to start)
25-32::
    Men dance LH across in centre, pass RH partner & loop round to end
    outside set behind original pstns
33-40::
    »Wheelie Chain« - Each trio dances 1/2 RH across, LH, partner
    followed by Man dances anticlockwise 1 place _while_ RH partners
    dance cl''wise, 3 dancers meet & dance 1/2 LH across, LH ptnr
    followed by Man again dances anticlockwise 1 pl _while_ RH ptnr
    dances clockwise
41-48::
    All repeat back to original places
49-56::
    Each trio dance RH across to end with Ladies in orig pls & Men
    outside set to circle 3H round to left, at end Ladies drop hands to
    open into circle
57-64::
    All circle 12H round & back

{{title}}
Part 2

1-8::
    »Fiddich Formation« - 1M+3M with their RH partners adv setting &
    dance 1/2 RH across _while_ 1st LH & 3rd LH partners dance in front
    of 2s/4s clockwise round their dancing partners to join them on opp
    sides of square Repeat 1M+3M with their LH partners to end in
    original places
9-16::
    1s & 3s dance reels of 3 on sides (Men giving RSh to RH partner to
    start)
17-24::
    1s & 3s Adv+Ret, 1st RH partner & 3rd RH partner turn Ladies on
    their right with RH _while_ 1st LH partner & 3rd LH partner turn
    Ladies on their left with LH _while_ all 4 Men dance RH across to
    end in middle facing partners
25-32::
    Men join hands with partners as in Double Triangles & set, Ladies
    dance in with 2 steps as Men dance out, all turn right & set again
    in triangular form, Men set to place _while_ Ladies dance to place
33-64::
    Repeat bars 1-32 with 2s & 4s leading & end Men dancing to a
    position in front of their original pstns

{{title}}
Part 3

1-16::
    »Wheelie Chain« as in Part 1 but with Men on inside following RH
    partner clockwise
17-24::
    Each trio dances RH across to end with Ladies in places & Men in
    centre, Men dance through place of Man originally on his right &
    behind his LH & own RH partner back to own place
25-32::
    All circle 12H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6471, '2013-08-21 08:31:24.701897+00', '2023-02-04 01:21:24.65664+00', 4537, 3, NULL, 'ace', '1-8::
    All set then 1s & 4s cast in, 1s & 4s turn LH 1.1/2 times moving out
    to finish back to back in middle facing 2s/3s
9-16::
    2s+1s also 3s+4s dance reels of 4 across
17-20::
    1s+4s turn facing person RH & dance 1/2 LH across in centre as
    corners set facing in
21-24::
    4s & 1s turn corners RH & dance 1/2 LH across as corners set & all
    end on the sides.  2 (1) (4) 3
25-32::
    All dance 1/2 Grand Chain (3s & 2s cross to start) (1bar per pass),
    3s & 2s turn 2H 1.1/2 times as 1s+4s turn 2H 1.1/2 times on sides to
    end 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (6473, '2013-08-21 08:31:24.721556+00', '2023-02-04 01:21:24.765575+00', 4543, 3, NULL, 'ace', '1-8::
    1L sets advcg to 2M & turns 3M 2H to end b''tw''n 2M+3M, 1M sets advcg
    to 2L & turns 3L 2H & ends facing down with 1L (who crosses) on left
9-16::
    1s lead down the middle & back
17-24::
    1s+2s dance Allemande 1s end facing 1st corners
25-32::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partner LH to
    end in 2nd places own side', 0);
INSERT INTO 'dancecrib' VALUES (6474, '2013-08-21 08:31:24.729702+00', '2023-02-04 01:21:24.794243+00', 4548, 3, NULL, 'ace', '1-8::
    1s dance parallel RSh reels of 3 on own sides
9-16::
    1s+2s+3s dance Grand Chain
17-24::
    1s lead down the middle & back to top
25-32::
    1s cast 1 place on own sides, dance in & lead down between 3s, cast
    up round 3s & cross to face 1st corners
33-40::
    1s turn 1st corners RH, partners LH, 2nd corners RH & partners LH
    end facing 1st corners
41-48::
    1s dance reels of 3 on opposite sides passing 1st corner LSh to
    start & 1s cross RH back to places', 0);
INSERT INTO 'dancecrib' VALUES (11739, '2019-03-26 02:05:44.207061+00', '2023-02-04 01:21:24.846948+00', 4550, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s cross LH, 1L casts up to end
    between 2s facing down, 1M casts down to end between 3s facing up
9-16::
    1s set advancing, pull back RSh to finish in Crown Triangles
    position _while_ 2s & 3s set turning 1/4 on the spot to face
    down/up, all set;
::
    All set again advancing to "invert" Triangle & all set
17-18::
    1s change places RH (up/down set) _while_ 2s & 3s dance up/down to
    2nd/3rd place and face out.
19-24::
    1M+2s & 1L+3s dance reels of 3 across, 1s RSh to 2nd corner to start
    (6 bars). 1s end in 2nd place own side
25-32::
    1M+2s & 1L+3s dance LH across; 1s turn RH to end in 2nd place own
    side & all set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6475, '2013-08-21 08:31:24.73799+00', '2023-02-04 01:21:24.871681+00', 14361, 3, NULL, 'ace', '1-8::
    2s followed by 1s lead down & back to places
9-16::
    1M+2M & 1L+2L Set+Link, 1s set advancing & turn 2H
17-24::
    1s+3s dance the Knot
25-32::
    1s dance up, turn 2H twice & dance back to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (6476, '2013-08-21 08:31:24.746152+00', '2023-02-04 01:21:24.898874+00', 4552, 3, NULL, 'ace', '1-8::
    1s+3s set & 3/4 turn RH to Men face up & Ladies down (1s+3s move
    down & 2s+4s step up 1/2 place). 1s+3s set & turn RH once round
9-16::
    1s+2s also 3s+4s dance RH across & LH back, 1s also 3s end BtoB
    (with partner) on opposite sides facing 2s/4s
17-24::
    All dance reels of 4 across, on last 2 bars 1M+2M, 1L+2L, 3M+4M &
    3L+4L turn RH, 1s into centre facing down & others in original
    places
25-32::
    1s lead down _while_ 2s+3s+4s step up, all set & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6477, '2013-08-21 08:31:24.755976+00', '2023-02-04 01:21:25.041566+00', 4555, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, 1s face 2s NHJ with partners.  1s+2s
    set, 1s turning towards each other to face up, then 1s cast _while_
    2s dance up & face out
9-16::
    2s+1s+3s dance reflection reels of 3 on own sides 1s dancing in
    between 3s to start.  All take hands where possible
17-24::
    2s+1s+3s set, 2s+1s 1/2 turn LH, 1s followed by 2s lead down between
    3s, cross & cast up on own sides
25-32::
    1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (6478, '2013-08-21 08:31:24.886345+00', '2023-02-04 01:21:25.076453+00', 12035, 3, NULL, 'ace', '1-8::
    1s dance 1/2 RSh reel of 3 on own sides; 1L followed by 1M dances up
    behind 2L+3L & 1L crosses to end in 1M original place (2s+3s step
    down 7-8)  (1) 3 2
9-16::
    1s dance 1/2 LSh reel of 3 on opp sides; 1L followed by 1M dances up
    behind 3M+2M & 1L crosses to end in original place (2s+3s step down
    on 15-16)
17-24::
    3s followed by 2s+1s lead down the middle, Ladies turn under Man''s
    arm to change sides & all dance up to places opp sides  (1) (2) (3)
25-32::
    All set & cross RH, 1s set facing 2s & change places LH on the sides
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6479, '2013-08-21 08:31:24.896428+00', '2023-02-04 01:21:25.113719+00', 4558, 3, NULL, 'ace', '1-8::
    2s dance Allemande as 1s cast & join in behind 2s
9-16::
    3s dance Allemande as 1s cast & join in behind 3s
17-24::
    1s set, dance up to top, cast to 2nd place & 2L casts to 2nd place
    as 1L dances up to meet 2M
25-32::
    1s+2s with other partner dance Allemande & 1M+2M change places LH', 0);
INSERT INTO 'dancecrib' VALUES (6480, '2013-08-21 08:31:24.9044+00', '2023-02-04 01:21:25.132719+00', 4559, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round for 2 slip steps & 2 cross jumps twice, repeat
    back to places
9-16::
    1s lead down between 3s, cast up to 2nd place, dance up between 2s &
    cast to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6481, '2013-08-21 08:31:24.923896+00', '2023-02-04 01:21:25.178078+00', 4561, 3, NULL, 'ace', '{{explanation}}
Round the Room dance 3 facing 3 (Man beteen 2 Ladies)

1-8::
    All Adv+Ret for 1 step, Men petronella turn to ends, all Adv+Ret
    (from ends) for 1 step, Men petronella turn to opposite sides
9-16::
    Men giving RSh to Lady on right dance reels of 3 on opposite sides
17-24::
    All Ladies petronella turn to 1 place to right & set, petronella
    turn to 1 place to right & set
25-28::
    All dance DoSiDo with opposite dancer (NHJ where possible);
29-32::
    Retaining NH, all Adv 1 step, bow/curtsey, Ladies change places, LH
    Lady+Man make arch, LH Lady dances 1/2 circle clockwise _while_ RH
    Lady dances under arch & Man turns under own Left arm.  All face
    next 3', 0);
INSERT INTO 'dancecrib' VALUES (6482, '2013-08-21 08:31:24.93206+00', '2023-02-04 01:21:25.196906+00', 4562, 3, NULL, 'ace', '1-8::
    1s+2s set twice, turn to face 2s on sides & set twice
9-16::
    1s cross below 2s, cast down behind 3s, lead up to top, cross & cast
    to 2nd place own sides
17-24::
    1s dance reels of 3 across passing 1st corner LSh
25-32::
    1s+3s dance RH across, 2s+1s dance LH across', 0);
INSERT INTO 'dancecrib' VALUES (6484, '2013-08-21 08:31:25.05108+00', '2023-02-04 01:21:25.352547+00', 4564, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    1s & 4s cast in 1 place as 2s & 3s dance up/down, 1s+4s dance RH
    across & all set
9-16::
    2s & 3s cast in 1 place as 1s & 4s dance up/down, 2s+3s dance RH
    across & all set advancing (1s & 3s face up _while_ 2s & 4s face
    down)
17-24::
    All dance ''Linked'' Allemandes:
::
    1s+3s dance normal Allemande to end in each others place as 2s+4s
    dance down to end in each others place.  3(4)1(2)
25-32::
    All set, cross RH, 2s lead up between 1s crossing, out & up behind
    4s+3s to top & cross RH.  2(3)4(1)', 0);
INSERT INTO 'dancecrib' VALUES (6485, '2013-08-21 08:31:25.249381+00', '2023-02-04 01:21:25.410681+00', 8734, 3, NULL, 'ace', '1-8::
    1s cross RH & cast to 2nd place, 1s cross LH & cast left (Lady up,
    Man down) & dance in to face Mens side (nearer hands joined)
9-16::
    1s dance reflection reels of 3 across (1L with 2s, 1M with 3s) & end
    facing opposite sides
17-24::
    1s dance reels of 3 on opposite sides giving LSh to 2nd corner & end
    facing out between corners
25-32::
    1s cast left & dance into middle, turn LH 1.1/4 times to end 2nd
    place own side', 4);
INSERT INTO 'dancecrib' VALUES (6486, '2013-08-21 08:31:25.25763+00', '2023-02-04 01:21:25.435886+00', 4565, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-16::
    1s lead down the middle for 3 steps, back to top & cast to 2nd place
17-24::
    1s+3s circle 4H round & back
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6487, '2013-08-21 08:31:25.267775+00', '2023-02-04 01:21:25.460673+00', 10462, 3, NULL, 'ace', '1-8::
    1s dance down below 2s, cast up to top, dance down below 3s & cast
    up to 2nd place
9-16::
    1s dance 1/2 reels of 3 on sides (1s in & up between 2s to start),
    turn 2H to face 1st corners
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners & 1/2 reel with 2nd
    corners to end 2nd place opposite sides
25-32::
    2s+1s+3s petronella turn, set, petronella turn & set', 0);
INSERT INTO 'dancecrib' VALUES (6488, '2013-08-21 08:31:25.277784+00', '2023-02-04 01:21:25.480623+00', 12323, 3, NULL, 'ace', '1-8::
    1s+2s dance Tournee:
::
    1s+2s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 2s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (2s RH, 1s LH) & dance
    out to places
9-16::
    1L casts up to round 2L to end between 2s _while_ 1M casts down
    round 3M to end between 3s facing up, 2s+1s+3s Set+Link for 3 to
    sides
17-24::
    2s+1s+3s again Set+Link for 3, 1s cross LH up/down & cast left to
    2nd places opposite side
25-32::
    Persons in 1st+2nd pstns Men''s side change places RH with persons in
    2nd+3rd pstns Ladies'' side
::
    Persons in 1st+2nd pstns Ladies side change places LH with persons
    in 2nd+3rd pstns Men''s side
::
    Persons in 1st+2nd pstns Men''s side change places RH with persons in
    2nd+3rd pstns Ladies'' side
::
    All cross LH with partner to order 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6489, '2013-08-21 08:31:25.286091+00', '2023-02-04 01:21:25.508562+00', 4571, 3, NULL, 'ace', '1-8::
    1M casts down 1 place as 2L casts up both into middle & change
    places RH, 2L+1M cast to each others place & 2L+1L also 2M+1M turn
    RH
9-16::
    1L casts down 1 place as 2M casts up both into middle & change
    places LH, 2L+1M cast to each other''s place & 2s+1s cross RH
17-24::
    2s+1s circle 4H round & back
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6490, '2013-08-21 08:31:25.294299+00', '2023-02-04 01:21:25.532942+00', 4575, 3, NULL, 'ace', '1-8::
    1s+3s dance RH across, 1M+3L (Allemande hold) dance out between 2s &
    down to 3rd pl _while_ 1L+3M (Allemande hold) dance out between 4s
    to 1st place
9-16::
    2s+4s repeat with 2M+4L dancing between couple in 3rd place to end
    in 4th place & 2L+4M into 2nd place
17-24::
    All dance double 1/2 Ladies'' Chain, Ladies cross diagonally left to
    next Man''s place & cast to Ladies'' place _while_ Men cast into
    partner''s place & cross diagonally left to next Man''s place.  2 3 4
    1
25-32::
    All set, dance into middle, turn to & dance out with corner, all
    cast back to meet own partner.  2 3 4 1

{{explanation}}
Repeat from new places', 0);
INSERT INTO 'dancecrib' VALUES (6491, '2013-08-21 08:31:25.302336+00', '2023-02-04 01:21:25.555599+00', 11300, 3, NULL, 'ace', '1-8::
    1s set & turn 2H, dance down to bottom & cast up to 2nd place own
    sides
9-16::
    2s+1s+3s set & cross RH, chase clockwise 1/2 way.  3 1 2
17-24::
    3s+1s dance RH across 1/2 way & 3s+2s dance LH across 1/2 way, 1s+2s
    dance RH across 1/2 way & all turn RH.  2 1 3
25-32::
    All dance Allemande.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (12412, '2019-12-05 01:31:07.144969+00', '2023-02-04 01:21:25.747738+00', 7842, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    All chase clockwise 1/2 round to opp sides; all chase anticlockwise
    back finishing in middle with partner ready for…
17-24::
    1s+2s+3s promenade ending with 1s casting to face 1st corners
    _while_ 2s dance up to 1st place, 3s to 3rd place
25-32::
    1s set to 1st corner, set to 2nd corner & 1s turn 1.1/2 RH to own
    side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6492, '2013-08-21 08:31:25.312187+00', '2023-02-04 01:21:25.850225+00', 4579, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH, set & dance 1/2 RH across to end ready for
    promenade
9-16::
    2s+1s+3s dance Promenade
17-24::
    2s+1s dance 1/2 Diamond Poussette, 1s+2s+3s circle 6H round to left
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (6493, '2013-08-21 08:31:25.320282+00', '2023-02-04 01:21:25.87624+00', 10800, 3, NULL, 'ace', '1-8::
    1M+2L 3/4 turn RH to end 1M facing 2M & 1L facing 2L & 1/2 turn
    facing person LH, 1L+2M turn 1.1/4 times RH to end 2 1
9-16::
    1s petronella turn into centre, 2s+1s+3s set, 1s petronella turn to
    opposite sides & 2s+1s+3s set
17-24::
    1s pass LSh into 1/2 diag reel of 4 with 3rd corners & twirl right
    to face 2nd corner, dance 1/2 reel of 4 with 2nd crnrs & twirl right
    to 2nd place opp side
25-32::
    3s+1s+2s chase 1/2 way & turn partner 2H to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10018, '2017-07-23 15:58:39.496037+00', '2023-02-16 14:42:29.475436+00', 17811, 3, NULL, 'ace', '1-8::

    1s+2s dance Espagnole

9-16::

    2s+1s+3s set advancing to RSh/RSh with partner, all dancing to R

    chase back to own sides, 2s & 3s cross RH whilst 1s turn RH to face

    3rd corner positions

17-24::

    1s dance 1/2 diagonal reel of 4, pass RSh to face 4th corner

    position, dance 1/2 diagonal reel of 4, finishing 2nd place own

    sides

25-32::

    1s+3s dance Bourrel to finish 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (12093, '2019-08-30 09:54:39.313317+00', '2023-02-04 01:21:25.903408+00', 4581, 3, NULL, 'ace', '1-8::
    1L sets advancing to 2M, 1L+2M turn RH to end 1L between 1M & 2M; 1s
    NHJ set advancing to 2L, 1s+2L dance RH across with 1s ending in
    middle, top place, own sides facing up
9-16::
    Reels of 3 on sides, 1s cast, 2s dance up/in, 3s up/out
17-24::
    1s cast, lead down between 3s, divide & cast up round 3s to 2nd
    place own sides facing down (2s step up 23-24)
25-28::
    1s dance down under arch made by 3s, divide & cast up round 3rd
    place to meet & face up _while_ 3s dance up, turn inwards & dance
    down to original place
29-32::
    1s dance up under arch made by 2s, divide & cast down to end in 2nd
    place own side _while_ 2s dance down, turn inwards & dance up to 1st
    place. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9744, '2017-04-06 08:40:01.69404+00', '2023-02-04 01:21:26.116036+00', 4597, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance 1/2 reflection reel of 3 on sides (1s in/down).  1s
    dance 1/2 Fig 8 round 2s  End 3 2 (1)
9-16::
    3s+2s+1s dance 1/2 reel of 3 on sides (1s in/up, 2s down/out) & all
    dance DoSiDo with partners  (1) 2 3
17-24::
    1s NHJ dance down to between 3s, 1M facing 3L, 1L facing 3M as 2s
    dance up to 1st place, 1s+3s set, 1s dance up to between & face 2s,
    1s+2s set
25-32::
    1s dance down/out through 2nd place opp sides to dance reflection
    reels of 3 on sides, 1s crossing to 2nd place own side from top  2 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (6497, '2013-08-21 08:31:25.358785+00', '2023-02-04 01:21:26.1383+00', 4601, 3, NULL, 'ace', '1-8::
    1s followed by 2s & 3s lead down, cross, dance back on opposite side
    & cross RH back to place
9-16::
    1s, 2s & 3s dance 2 steps forward slightly to right, join hands in
    line & retire, repeat to left
17-24::
    1s cross down RH to 2nd place, set, cross down to 3rd place LH & set
25-32::
    2s+3s+1s turn partners RH & LH', 0);
INSERT INTO 'dancecrib' VALUES (6498, '2013-08-21 08:31:25.367024+00', '2023-02-04 01:21:26.154452+00', 4602, 3, NULL, 'ace', '1-8::
    1s dance down to 2nd pl (2s step up), 1s set dancing in & turn about
    to face 4th crnrs, 1s turn 4th crnr RH, 1/2 turn 1st corner LH into
    lines across (2M & 3L in middle)
9-16::
    1s dance reels of 3 across (1L+2M, 1M+3L pass LSh to start) & end
    dancing through 2nd pl opp sides and in to face 2nd corners _while_
    2s+3s set (15-16)
17-24::
    1s dance Pass+Turn with 2nd corners & turn RH, dance Pass+Turn with
    1st corners & 1s end 2nd pl own sides as 2s+3s dance in to face
    down/up
25-32::
    2s+1s+3s set, circle 6H round to left, dance in & pull back RSh to
    spiral out clockwise & chase to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6499, '2013-08-21 08:31:25.377108+00', '2023-02-04 01:21:26.188981+00', 10376, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, turn LH 1.1/4 times to end 1L between 2s,
    1M between 3s
9-16::
    1s dance LSh reels of 3 across with 2s/3s curving round to end LSh
    to LSh (1L facing up) in middle
17-24::
    1s dance up/down & cast left to 2nd place opposite sides _while_
    2s+3s dance 1/2 R&L (RH on sides to start), 1s turn LH. (3)(1)(2)
25-32::
    3s+1s+2s Set+Link twice', 0);
INSERT INTO 'dancecrib' VALUES (6500, '2013-08-21 08:31:25.387182+00', '2023-02-04 01:21:26.209931+00', 14534, 3, NULL, 'ace', '1-8::
    1s+2s set & circle Left 1/2 way, 2s+1s turn 2H 1.1/2 times  2 1 3
9-16::
    1s dance 1/2 figure of 8, (1M with 2s, 1L with 3s) to end 2nd place
    opposite side, 1s dance 1/2 diag R&L (1L up, 1M down)
17-20::
    1s dance 1/2 Fig of 8 (1M down, 1L up) & end 2nd place opposite side
21-24::
    1s dance 1/2 diag R&L (1M up, 1L down) 1s end passing LSH to face
    1st corner (pstns)
25-28::
    1s dance Pass+Turn with 1st corners (corners turn 2H & twirl to end
    in each others places) & 1s pass RSh to face 2nd corner (pstns)
29-32::
    1s repeat with 2nd corner (pstns) then 1s pass RSh to 2nd place own
    side  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13762, '2021-03-02 01:21:02.42499+00', '2023-02-04 01:21:26.231339+00', 12290, 3, NULL, 'ace', '1-8::
    1s+2s face in diagonally, set & circle 4H 1/2 round to left; 1s+2s
    pull back RSh, dance out to opp sides & cross RH with partner. 1s
    end facing out
9-12::
    1s cast round 3rd corners (1M up, 1L down), cross LH up/down middle
13-16::
    1s cast to left round 1st corners, dance in & turn LH to face 1st
    corner
17-20::
    1s dance 1/2 diag reel of 4 with 1st corners, 1s pull back RSh to
    face 4th corner
21-24::
    1s dance 1/2 diag reel of 4 with 4th corners. 1s pull back RSh to
    face 3rd corner
25-32::
    3s+1s+2s chase clockwise 1/2 round (1s dance out through own side to
    begin) to end 2 (1) 3; 1s turn 2H 1.1/2 times.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6501, '2013-08-21 08:31:25.398448+00', '2023-02-04 01:21:26.259836+00', 8985, 3, NULL, 'ace', '1-8::
    1s cast 1 place, dance down between 3s, cast up to 2nd place &
    2s+1s+3s 1/2 turn RH into allemande hold
9-16::
    2s+1s+3s dance Allemande 1s end facing 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting ending with 1s turning RH to 2nd
    place own side facing out but when 1s set to each other across the
    set 2s & 3s cross RH & when the 1s set down/up 2s+3s change places
    LH on sides
25-32::
    1s dance RSh reel of 3 on own sides (dancing to right) & end 2s & 3s
    crossing RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6502, '2013-08-21 08:31:25.407847+00', '2023-02-04 01:21:26.287875+00', 4610, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 2 places as 2s+3s set & cross up 1 place, 2s
    cross & cast 2 places as 3s+1s set & cross up 1 place
9-16::
    1s+2s circle 4H round to left, 3s+1s circle 4H round to right 1s end
    facing 1st corner pstns
17-24::
    1s set to 1s corner pstns, set to 2nd corner pstns, 1s turn right to
    face each other, set & petronella to 2nd places own sides
25-32::
    3s+1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (14800, '2022-05-05 00:20:50.04673+00', '2023-02-04 01:21:26.315748+00', 17108, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Poussette. 2s, 3s & 4s end in place _while_
    1s pass RSh to BtoB facing opp sides ready for …
9-24::
    All dance »Spurtle«:
::
    _9-12_    1s dance 1/2 RSh reel of 4 with 2s & turn RH to face 3s (M
    facing L)
::
    _13-16_  Repeat 1/2 reel of 4 with 3s, end facing 4s
::
    _17-20_  Repeat 1/2 reel of 4 with 4s
::
    _21-24_  1s continue to turn RH to 4th place.  (2) (3) (4) (1)
25-32::
    All turn partner 2H 1.1/2 flowing into 2s+3s & 4s+1s circle 4H round
    to left, opening into …
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (11464, '2019-01-01 01:57:22.128755+00', '2023-02-04 01:21:26.376051+00', 17668, 3, NULL, 'ace', '1-8::
    1s turn RH, 1s+2s dance RH across. 1L faces out
9-16::
    1L followed by 1M casts round 2L, crosses up through 1M place, casts
    round 2M & cross to 2nd place own side facing down (2s step up
    15-16)
17-24::
    2s+1s+3s dances reels of 3 on side, 1s RSh to 3s.  3s end facing up
25-32::
    1s+3s dance RH across; 1s turn 2s LH.', 0);
INSERT INTO 'dancecrib' VALUES (6503, '2013-08-21 08:31:25.423297+00', '2023-02-04 01:21:26.406463+00', 10765, 3, NULL, 'ace', '1-8::
    All Adv+Ret & turn partners RH
9-16::
    1s cross RH, cast to 6th place & cross back to own side. Others step
    up on bars 13-14
17-24::
    2s+3s dance R&L _while_ 4s+5s circle 4H round & back _while_ 6s+1s
    dance RH across & LH back
25-32::
    2s cross RH, cast to 6th place & cross back to own side Others step
    up on bars 29-30
33-40::
    All circle 12H round & back.  3 4 5 6 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6504, '2013-08-21 08:31:25.434222+00', '2023-02-04 01:21:26.42795+00', 4617, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across & 1s cast 1 place as 2s dance up
9-16::
    2s+1s+3s dance reels of 3 on sides (1s in & down to start)
17-20::
    1s+3s turn on sides (dancing between 3s) _while_ 2s turn RH & face
    out
21-24::
    2L+1L+3L dance RH across _while_ 2M+1M+3M dance LH across. 1s end
    facing up in centre & 2s+3s facing each other on sides
25-32::
    2s+3s dance R&L (RH on sides to start) _while_ 1s dance Fig of 8 on
    own sides dancing to top & casting to start', 0);
INSERT INTO 'dancecrib' VALUES (10087, '2017-09-03 23:45:03.557773+00', '2023-02-04 01:21:26.452063+00', 4616, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s+2s circle 4H round & back
17-24::
    1s lead down the middle and back
25-32::
    1s+2s dance the Poussette', 0);
INSERT INTO 'dancecrib' VALUES (15213, '2022-11-03 01:18:35.519966+00', '2023-02-04 01:18:35.500808+00', 12140, 3, NULL, 'ace', '1-8::
    1s cast (2s step up), cross RH; 1s cast  up to top, meet & dance
    down NHJ to 2nd place in centre
9-16::
    1M+2L+3L dance LH across _while_ 1L+2M+3M dance RH across; 1s dance
    down & cast up to 2nd place opp side
17-24::
    1M+2s at top & 1L+3s at bottom dance RH across, 1s pass RSh & dance
    LH across with other couple
25-32::
    1s dance 1/2 Fig 8 (1M up round 2s,1L down round 3s); 2s+1s +3s turn
    partner RH', 0);
INSERT INTO 'dancecrib' VALUES (6505, '2013-08-21 08:31:25.444268+00', '2023-02-04 01:21:26.484976+00', 10914, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All set twice, turn partner RH & 1/2 corner LH to end Men in
    original places & Ladies 1 place to right (anticlockwise)
17-24::
    All set twice to new partner, turn RH & 1/2 corners LH to end Ladies
    in places at bar 17 & Men 1 place to left (clockwise)
25-32::
    Ladies in 1st & 3rd places dance 1/2 Ladies Chain & Ladies in 2nd &
    4th places repeat All end 1 place to left (clockwise) with own
    partners', 0);
INSERT INTO 'dancecrib' VALUES (12926, '2020-07-01 00:20:42.221637+00', '2023-02-04 01:21:26.521272+00', 17597, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Inveran reels
9-16::
    1s+2s set, cross RH; 1s+2s change places LH on side, cross RH to own
    side
17-24::
    2s+1s+3s circle 6H round & back
25-32::
    1s+3s dance ''Divided Knot:
::
    1s+3s set & 1/2 turn prtnrs 2H to face down, 3s cast up on opp side
    to 1st pl as 1s dance down & cast to 3rd pl & 3s+1s cross RH.  End 2
    3 1', 0);
INSERT INTO 'dancecrib' VALUES (12413, '2019-12-05 01:31:07.913839+00', '2023-02-04 01:21:26.548794+00', 19419, 3, NULL, 'ace', '1-8::
    1s dance down NHJ, cast up round 2s to place; 1s dance 1/2 Fig 8
    round 2s
9-16::
    Mirror reels of 3 on sides, joining hands where possible (1s
    in/down, 2s out/up to start, 3s in/up to start) Bars 11-12: 2s from
    top cross  down (no hands) to 2nd place opp sides & continue reel
    (1) (2) 3
17-24::
    1s+3s dance Men''s Chain (Men cross LH) 1s finish in 1st place opp
    sides, 3s in original place
25-32::
    1s+2s dance »Spiral Progression«:
::
    _25-28_   1M+2L turn RH, give LH to partner & Bal-in-Line, 1L+2M
    pull back LSh to join nearer hands with partners
::
    _29-30_   1s+2s, in diagonal line, dance clockwise 1 place round
::
    _31-32_   1L+2M drop hands, dance on to next place on side _while_
    1M+2L continue RH turn to own sides opposite partners.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6507, '2013-08-21 08:31:25.460436+00', '2023-02-04 01:21:26.576276+00', 9936, 3, NULL, 'ace', '1-8::
    1s 1/2 turns 2s on sides into double triangle position & dance 6
    bars of Double Triangles end facing 1st corners
9-16::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners with 1s fending in 2nd place opp
    side
17-24::
    1s set, cross RH, cast to top & dance down to 2nd place in centre
25-32::
    1s dance reels of 3 on own side (1s in & down to start)', 0);
INSERT INTO 'dancecrib' VALUES (6508, '2013-08-21 08:31:25.468551+00', '2023-02-04 01:21:26.601371+00', 11287, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, dance down between 3s & cast back to 2nd
    place
9-16::
    2s+1s+3s set & cross RH, all chase clockwise 1/2 way.  3 1 2
17-24::
    1s dance RH across (1L with 3s at top, 1M with 2s), LH across with
    other couple
25-32::
    All chase anticlockwise 1/2 way, all cross LH & set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6509, '2013-08-21 08:31:25.477102+00', '2023-02-04 01:21:26.627098+00', 4628, 3, NULL, 'ace', '1-8::
    1s cross, dance out between 2s & 3s turning 3s once round, 1s in
    double triangle position set, 2s+1s 1/2 turn to bring 2s into double
    triangle position
9-16::
    1s+2s+3s set, 2s 1/2 turn 3s into double triangle position & set, 3s
    1/2 turn 1s & 1L faces her 2nd corner (pstn) with partner behind
17-24::
    1s dance 1/2 Tandem reel of 3 with 2nd corners to face Mans 1st
    corner (pstn) & dance 1/2 reel with 1st corners
25-32::
    1s dance up to top & cast to 2nd place on opposite sides, all set &
    cross over', 0);
INSERT INTO 'dancecrib' VALUES (6510, '2013-08-21 08:31:25.485294+00', '2023-02-04 01:21:26.656321+00', 4629, 3, NULL, 'ace', '1-8::
    1s turn 2H, cast to 2nd place, dance down between 3s, cast up 1
    place on own sides & dance in to face 1st corners
9-16::
    1s turn 1st corner RH, partner LH, 2nd corner RH, partner LH end
    facing 1st corners
17-24::
    1s dance reels of 3 across (1L+2s & 1M+3s) giving LSh to 1st crnrs
    (6 bars), & all turn partners 2H
25-32::
    1s pass RSh to dance Corners Pass+Turn:
::
    1s dance a loop RSh round 1st cnr positions _while_ 1st cnrs
    (persons) turn each other 2H & return to places, 1s pass RSh in the
    middle & repeat with 2nd corners.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14428, '2021-11-06 01:12:21.672789+00', '2023-02-04 01:21:26.683698+00', 20542, 3, NULL, 'ace', '1-8::
    1s cross RH & cast (2s step up & face out 3-4); 1s+2s turn on sides
    (1L+2M LH, 1M+2L RH)
9-16::
    2s+1s+3s dance 1/2 mirror reels of 3 on sides (1s in/down, 2s & 3s
    loop into place at end); 1s dance up NHJ, cast to 2nd place opp side
    3 (1) 2
17-20::
    3s+1s+2s dance Set+Link for 3 couples. 2s & 3s finish on sides
    facing partner, 1L between 2s at top, 1M between 3s at bottom
21-24::
    1s turn 1.1/4 RH to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6511, '2013-08-21 08:31:25.493868+00', '2023-02-04 01:21:26.712444+00', 3244, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s 1/2 turn RH moving down as 2s cast up, 1s set & turn
    LH to Bal-in-Line with 1st corners
9-12::
    1s+1st corners HS Bal-in-Line :
::
    With hands joined as for normal balancing in line all dance 1st bar
    of Highland schottische with right foot
::
    Centre couple drop left hands & all move to right joining LH with
    crnrs (under their RH) then drop RH & crnrs join right hands in
    centre
::
    All repeat HS with left foot & drop hands in centre, all move to
    left to bring original centre couple into centre to face corners
13-16::
    1s+1st corners dance 1/2 diagonal reel of 4 1s end ready to
    Bal-in-Line with 2nd corners
17-24::
    1s+2nd corners HS Bal-in-Line & dance 1/2 diagonal reel of 4
25-32::
    1s turn LH in middle to end Lady facing 2s & Man 3s _while_ corners
    dance round clockwise to own corners, 1L+2s & 1M+3s dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (13423, '2020-12-02 01:20:58.013787+00', '2023-02-04 01:21:30.520476+00', 19161, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Promenade
9-16::
    1s+2s dance the Knot. 1s end facing 1st corner
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & cross LH to own
    sides 2nd place facing out/down
25-32::
    Mirror reels of 3 on sides (1s out/down to start), 1s+3s continue
    reel to change places.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4004, '2013-08-21 08:30:41.155042+00', '2023-02-04 01:18:27.02279+00', 10053, 3, NULL, 'ace', '1-8::
    1s cross down & set in Double Triangles pstn, 1s PdB into 2nd place
    opposite sides & all set
9-16::
    1s dance reels of 3 on opposite sides giving RSh to 3s & 1s+2s end
    dancing LSh round each other to form a line across (Ladies in
    middle)
17-24::
    1s+2s dance the Targe:
::
    _17-18_ 1st & 2nd Ladies 3/4 turn RH _while_ Men dance 1/4 way round
    anticlockwise
::
    _19-20_ 1st Man with 2nd Lady & 1st Lady with 2nd Man full turn LH
::
    _21-22_ 1st & 2nd Ladies 3/4 turn RH _while_ Men dance 1/4 way round
    anticlockwise
::
    _23-24_ 1st Man with 2nd Lady & 1st Lady with 2nd Man turn LH to end
    1s on own sides & 2s on opposite sides
25-32::
    1s+2s dance 1/2 R&L, 1s dance 1/2 Fig of 8 round 3s', 0);
INSERT INTO 'dancecrib' VALUES (4005, '2013-08-21 08:30:41.163483+00', '2023-02-04 01:18:27.052966+00', 10761, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s+2s dance double Fig of 8 (1s cross down to start)
17-24::
    1s cross RH, cast 1 place & turn RH
25-32::
    1s+3s dance double Fig of 8 (1s cross down to start)', 0);
INSERT INTO 'dancecrib' VALUES (6512, '2013-08-21 08:31:25.594201+00', '2023-02-04 01:21:26.881066+00', 4630, 3, NULL, 'ace', '1-8::
    1s cast 1 place, dance down between 3s, cast up & pass RSh to face
    1st corner
9-16::
    1s+1st corners Adv+Ret for 1 step to right, Adv+Ret 1 step to left,
    1s dance RSh round 1st corner & pass RSh to face 2nd corner
17-24::
    1s repeat with 2nd corners but end leading up & Lady turning in
    front of partner ready for…
25-32::
    1s+2s dance Allemande.', 0);
INSERT INTO 'dancecrib' VALUES (13422, '2020-12-02 01:20:55.072081+00', '2023-02-04 01:21:26.901821+00', 4632, 3, NULL, 'ace', '1-8::
    1M+2L also 3M+4L turn 3/4 RH, Men cast up, Ladies cast down to
    original places; 1s+2s also 3s+4s circle 4H round to left
9-16::
    1L+2M also 3L+4M turn 3/4 LH, Men cast down, Ladies cast up to
    original places;  1s+2s also 3s+4s circle 4H round to right
17-24::
    1s lead down, Bar 20: 2s+3s+4s face down; 1s followed by 4s+3s+2s
    lead up, remaining in centre ready for …
25-32::
    All 4 couples dance allemande', 0);
INSERT INTO 'dancecrib' VALUES (6515, '2013-08-21 08:31:25.624351+00', '2023-02-04 01:21:26.975021+00', 12090, 3, NULL, 'ace', '{{explanation}}
4s+5s+6s start on opp sides

1-8::
    1M/6M cast in & cross then cast round 1st corner to face crnr
    _while_ 1L/6L cross & cast then dance 1/2 Fig of 8 round 2s/5s & end
    facing 1st crnr
::
    (popular variation approved by J Rigby: 1s/6s cast in 1 pl (2s/5s
    step up/dn) & cross RH, 1s/6s dance clockwise round 1st crnrs to end
    BtoB facing 1st crnrs)
9-16::
    1s & 6s dance 1/2 diagonal reel of 4 with corners, pass RSh to dance
    1/2 reel of 4 with other corners ending 2nd place other side.
    (3)(1)(2)5 6 4
17-24::
    3s/4s (end couples) cross RH & cast 2 places to middle, 3s+4s dance
    1/2 R&L
25-32::
    2s+4s also 3s+5s dance 1/2 R&L, 1s+4s also 3s+6s dance 1/2 R&L.  4 1
    2(5)(6)(3)', 0);
INSERT INTO 'dancecrib' VALUES (8610, '2015-02-13 12:48:02.676991+00', '2023-02-04 01:21:27.133585+00', 13781, 3, NULL, 'ace', '1-8::
    1s cross RH & cast to 2nd place, 1s dance 1/2 Fig of 8 round 2s
9-16::
    1s 1/2 turn RH to finish nearer hands joined facing 3M.  1s set to
    3M.  1s+3M dance RH across.  1s finish in 2nd place opposite sides.
17-24::
    1s 1/2 turn LH to finish nearer hands joined facing 3L.  Set to 3L.
    1s+3L dance LH.  1s finish 1M facing 2M, 1L following partner
25-32::
    1s dance Alternating Tandem Reel of 3 with 1st corners. Finish 1M
    facing 3M.
33-40::
    1s dance Alternating Tandem Reel of 3 with 2nd corners. 1s finish
    2nd place on own side, 1M facing out
41-48::
    Reels of 3 on side 1s+3s pass LSh to start.  1s and 3s dance extra
    loop to change places  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6516, '2013-08-21 08:31:25.718871+00', '2023-02-04 01:21:27.153186+00', 4637, 3, NULL, 'ace', '1-8::
    1L passes in front of partner to dance RH across with 2M+3M as 1M
    dances LH across with 2L+3L; 1s pass RSh, 1L dances LH across with
    2L+3L as 1M dances RH across with 2M+3M
9-16::
    1s followed by 2s dance down middle & 2s followed by 1s dance back
    up, 2s end at top & 1s in 2nd place in middle
17-24::
    Reels of 3 on sides (1s in/up, 2s cast & 3s out/up to start)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6517, '2013-08-21 08:31:25.727158+00', '2023-02-04 01:21:27.171828+00', 14688, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s/4s cross RH as 2s/3s set, 1s+2s & 4s+3s dance 3/4 double Fig of 8
    (1s/4s casting down/up to start).  2 1(4)(3)
9-16::
    1s+4s Set & Rotate:
::
    Set, Rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides.  2(4)1(3)
17-20::
    1L+4M also 4L+1M (Lady leads) 1/2 alternating tandem diag RSh reel
    of 4 with 3L+2L & passing LSh curve to right to next corner (same
    end)
21-24::
    4M+1L also 1M+4L (Man leads) 1/2 alternating tandem diag RSh reel of
    4 with 3M+2M & pass RSh to end 3(1)4(2)
25-32::
    1s & 4s cross passing RSh & loop into places, all Adv+Ret.  3
    1(4)(2)', 0);
INSERT INTO 'dancecrib' VALUES (6518, '2013-08-21 08:31:25.737029+00', '2023-02-04 01:21:27.255081+00', 4638, 3, NULL, 'ace', '1-8::
    1s+2L circle 3H round & back 1s end in diagonal line with 2L (1L in
    1M place & 1M between 1L+2L)
9-16::
    1s+2L dance diagonal reel of 3 (1M gives RSh to 2L to start), 1s end
    (Lady on Mans right) facing 2M
17-24::
    1s+2M circle 3H round & back, (1M in 1L place & 1L between 1M+2M)
25-32::
    1s+2M dance diagonal reel of 3 (1L gives RSh to 2M to start), 1s end
    in own places
33-40::
    1s lead down the middle & back
41-48::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6519, '2013-08-21 08:31:25.745143+00', '2023-02-04 01:21:27.277462+00', 9010, 3, NULL, 'ace', '1-8::
    1M+2M also 3L+4L turn RH, 1M followed by 2M also 4L followed by 3L
    chase clockwise to change places
9-16::
    1L+2L also 3M+4M turn LH, 1L followed by 2L also 4M followed by 3M
    chase anticlockwise to change places.  (4)(3)(2)(1)
17-24::
    4L+3L also 2M+1M cross (pass ptnr RSh) & cast to change places, 4M+
    3M also 2L+1L cross (pass opp person LSh) & cast to change pls.  2 1
    4 3
25-32::
    1s & 4s dance 1/2 Fig of 8 round end couples & dance 1/2 R&L.  2 4 1
    3
33-40::
    All dance RSh reels of 4 on sides', 0);
INSERT INTO 'dancecrib' VALUES (6520, '2013-08-21 08:31:25.755117+00', '2023-02-04 01:21:27.299331+00', 7849, 3, NULL, 'ace', '1-8::
    All dance Grand Chain
9-16::
    1s+2s also 3s+4s dance RH across, 1s turn RH 1.1/4 times moving down
    the set to end RSh to RSh, Man facing 2L & Lady facing 2M
17-24::
    1s dance the Spurtle: 1s dance 1/2 reel of 4 with 2s & turn partner
    RH to face 3s, 1s dance 1/2 reel of 4 with 3s & turn partner RH to
    face 4s
25-32::
    1s dance 1/2 reel with 4s & turn RH to 4th place opposite sides, all
    set & cross RH 1s ending in 4th place', 0);
INSERT INTO 'dancecrib' VALUES (6521, '2013-08-21 08:31:25.763359+00', '2023-02-04 01:21:27.327321+00', 9541, 3, NULL, 'ace', '1-4::
    1L+2M also 3L+4M set & turn 2H 1.1/2 times, 1L+2M face up NHJ, 3L+4M
    face down NHJ
5-8::
    1L+2M dance up _while_ 3L+4M dance down & cast to end in 2nd/4th
    place opp sides (2L & 4L step up 5-6). Each man now has partner
    beside him on right. (Ladies'' side: 2L 2M 4L 4M, Men''s side: 1M 1L
    2M 2L)
9-16::
    1s+2s also 3s+4s circle 4H round to left, Petronella-in-tandem 1
    place anticlockwise to end 1s facing 2s & 3s facing 4s & all set.
    (2)1(4)3
17-28::
    All in prom hold dance reel of 4 (12 bars) but 1s & 4s do not pass
    at end but curve round to face 2s/3s.  (2)4(1)3
29-32::
    2s+4s also 1s+3s dance RH across & all end on sides (2)4(1)3
33-40::
    2s & 1s dance 1/2 Figs of 8 round 4s/3s to end on own sides & all
    turn partners RH (4 bars).  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6523, '2013-08-21 08:31:25.779679+00', '2023-02-04 01:21:27.402664+00', 13684, 3, NULL, 'ace', '1-8::
    1M+2L 1/2 turn RH, face each other, pull back RSh, dance out to each
    other''s original place _while_ 1L+2M chase clockwise 1/2 way. 1M+2L
    chase 1/2 way _while_ 1L+2M 1/2 turn RH, pull back RSh & dance out
    to original place
9-16::
    1s dance reels of 3 on own sides
17-24::
    1L followed by partner casts 1 place & crosses to opposite sides
    then 1L casts round 3M, 1L crosses to own side & cast up to 2nd
    place as 1M dances up middle to 2nd place
25-32::
    1M+3M also 1L+3L set & change places RH, 3s+1s dance 4H round to
    left', 0);
INSERT INTO 'dancecrib' VALUES (6524, '2013-08-21 08:31:25.787772+00', '2023-02-04 01:21:27.53674+00', 4641, 3, NULL, 'ace', '1-8::
    1s cross RH & cast down to 2nd place (2s step up), cross LH & 1L
    casts up _while_ 1M casts down
9-16::
    1s dance reels of 3 across, 1L with 2s (RSh to 2M) & 1M with 3s (RSh
    to 3L)
17-24::
    1s NHJ (Lady on Mans left) set to 2L & turn inwards to set to 3M,
    set to 3L & turn inward & set to 2M. End facing own 2nd corner (1L
    pull back LSh to face down)
25-32::
    2s+1s+3s dance reels of 3 on opposite sides 1s giving RSh to 2nd
    corner, 1s cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6525, '2013-08-21 08:31:25.795814+00', '2023-02-04 01:21:27.562296+00', 11814, 3, NULL, 'ace', '1-8::
    1s & 4s set & cross RH, cast in 1 place (2s & 3s step down/up) &
    dance LH across 1/2 way
9-16::
    All dance RSh reels of 4 on sides & end facing up/down
17-24::
    All set to facing person on sides & turn 2H, 2s+4s also 1s+3s circle
    4H round to left
25-32::
    2s+4s also 1s+3s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6526, '2013-08-21 08:31:25.886264+00', '2023-02-04 01:21:27.605903+00', 4642, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s turn RH & cast 1 place,1s 3/4 turn LH to dance up/down & cast to
    2nd place own sides
9-12::
    2s+1s+3s circle 6H round, finishing in from sidelines facing partner
    on angle (Men facing slightly down, Ladies slightly up)
13-14::
    All dance DoSiDo with partner
15-16::
    All cross RH with partner to opposite sides. (2) (1) (3)

{{title}}
Reel

17-24::
    All clap & 1s Petronella turn in to lines of 3 across & all set
    (1M+2s facing 1L+3s), 1s Petronella turn to own sides & all set to
    partner
25-32::
    All clap & 1s dance 1/2 reels of 3 across (1M with 2s, 1L with 3s);
    1s turn 1.1/2 RH to own sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6527, '2013-08-21 08:31:26.078787+00', '2023-02-04 01:21:27.629464+00', 13360, 3, NULL, 'ace', '1-8::
    1s dance down to 3rd place & turn 3s (Ladies LH, Men RH) to end 2nd
    place, 1s cross passing RSh & turn 2s to meet in middle at top NHJ
9-16::
    1s dance down to 3rd place & turn 3s to end in 2nd place, 1s cross
    passing RSh & turn 2s to end in 1st places own sides
17-32::
    1s set & cast 1 place, 2s+1s+3s dance R&L for 3 couples.', 0);
INSERT INTO 'dancecrib' VALUES (6528, '2013-08-21 08:31:26.08884+00', '2023-02-04 01:21:27.64883+00', 11601, 3, NULL, 'ace', '1-8::
    All set & petronella-in-tandem, all set & petronella-in-tandem  (3)
    (2) (1)
9-16::
    All Set+Link for 3 twice   1 2 3
17-24::
    All dance the Knot.  3 2 1
25-32::
    3s+2s (1st & 2nd place)  Set & Rotate ending with a clap to finish 2
    3 1
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides

{{title}}
Reel

{{explanation}}
Repeat in reel time to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6529, '2013-08-21 08:31:26.160854+00', '2023-02-04 01:21:27.780509+00', 4644, 3, NULL, 'ace', '1-8::
    1s+2s on sides, 2s+3s set on sides, 1s+2s+3s set advancing to
    partners into prom hold facing up
9-16::
    1s+2s+3s Promenade
17-24::
    1s cross RH, cast to bottom of set, pass RSh & cast back to places
25-32::
    1s+2s+3s set turning to face down _while_ 4s set turning to face up,
    4s change places RH with 3s, LH with 2s & RH with 1s
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6530, '2013-08-21 08:31:26.168963+00', '2023-02-04 01:21:27.802114+00', 4646, 3, NULL, 'ace', '1-8::
    1s turn RH & cast to 2nd place; turn 1.1/4 times LH (4 bars) to end
    1L between 2s facing down, 1M between 3s facing up
9-16::
    2s+1s+3s set twice, 1s Petronella turn on second setting onto
    opposite sides(bars 11-12) & all set twice again on sides. 2 (1) 3
17-24::
    2s+1s+3s circle 6H round & back
25-32::
    1s dance reels of 3 on sides giving RSh to person on their Right
    (2nd corner) & 1s cross RH to places. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14213, '2021-08-14 00:21:00.829594+00', '2023-02-04 01:21:27.824208+00', 12326, 3, NULL, 'ace', '1-4::
    1s cross down RH between 2s to face out on opposite sides. 1L casts
    up round 2M to give RH to 3M & LH to 2L _while_ 1M casts down round
    3L to give LH to 4M & RH to 3L. All turn so that diagonal lines of 3
    face each other.
5-6::
    All dancers set. 1s drop hands at end of bar 6, 1s 1/4 turn to the
    right. 1L gives RH to 2M & LH to 3L, 1M gives RH to 4L & LH to 3M &
    diagonal lines of 3 face on other diagonal
7-8::
    All set. All drop hands
9-16::
    1s+3s dance RH across; 1L+2s also 1M+3s dance LH across
17-20::
    1s+3s dance RH across, at the end 1s retain RH hold & 3s return to
    place.
21-24::
    1s turn into Allemande hold facing up & dance up to top. 1M crosses
    1L in front & both curve round to face down on opposite sides.
25-32::
    1s dance right & left chain to the bottom of the set & cross to own
    side (2 bars/hand) 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (15420, '2023-02-04 01:21:27.85876+00', '2023-02-04 01:21:27.860301+00', 20299, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole:
::
    _1- 2_  1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3- 4_  1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5- 8_  2s turn RH as 1s turn LH & face out
9-16::
    LSh reels of 3 on sides (1s LSh to dancer on left - 4th corner) Bar
    12 1s cross RH to continue reels on opp sides. 1s end facing 1st
    corners
17-24::
    1s set to & turn 1st corner (2H), 1s set to & turn 2nd corner (2H).
    2 (1) 3
25-32::
    1L crosses up, 1M crosses down to dance RSh reels of 3 on own side', 0);
INSERT INTO 'dancecrib' VALUES (6531, '2013-08-21 08:31:26.177236+00', '2023-02-04 01:21:27.888161+00', 4651, 3, NULL, 'ace', '1-8::
    1M followed by ptnr cast 1 pl, 1s dance up followed by 3s, 1M
    followed by ptnr cast to 3rd pl & cast to own side as 3s end at top.
    (3)(2)(1)
9-16::
    1s set to 2s set on sides & change places RH, 1s set & cross LH.  3
    (1) 2
17-24::
    3s+1s+2s dance 3 Couple Men''s Chain: All 3 Men dance RH across 1/2
    way _while_ partners cast left to meet approaching Man, all turn LH
    (1M+1L, 2M+3L & 3M+2L), Men dance RH across 1/2 way _while_ partners
    cast to meet approaching Man & all turn LH (1M+2L, 2M+1L & 3M+3L) to
    end as bar 16
25-32::
    3s+1s+2s dance 1/2 reels of 3 on sides (1M RSh to 3L & 1L RSh to
    2M), 1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (4006, '2013-08-21 08:30:41.17331+00', '2023-02-04 01:18:27.090958+00', 12517, 3, NULL, 'ace', '1-8::
    1s set, turn RH, cast off 1 place (2s step up), 1s turn 3/4 RH, end
    BtoB in center (L up, M down)
9-16::
    1s dance Crown Triangles, 1s finish facing 1st corners
17-24::
    1s dance diagonal reel of 4 with 1st corners, pass LSh to face 2nd
    corners
25-32::
    1s dance diagonal reel of 4 with 2nd corners finishing in 2nd place
    own side', 0);
INSERT INTO 'dancecrib' VALUES (6532, '2013-08-21 08:31:26.187394+00', '2023-02-04 01:21:27.915535+00', 4652, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cross down to 2nd place as 2s step up, 1s turn 3s
    (1M+3L RH, 1L+3M LH). 2 (1) 3
9-16::
    1s dance reels of 3 on sides, 1s start by facing up & out,  crossing
    down on bars 11-12 to complete reels on own side. 1s end in 2nd
    place. 2 1 3
17-24::
    1s & 3s dance Chain Progression:
::
    _17-18_  1s & 3s 3/4 turn RH
::
    _19-22_  1M+3L turn LH 1.1/2 times _while_ partners chase clockwise
    1/2 way
::
    _23-24_  3s & 1s 3/4 turn RH to end on sides in order 3 1
25-32::
    2s+3s+1s set & all turn RH 1.1/4 times, all petronella turn to own
    sides. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (14429, '2021-11-06 01:12:23.058182+00', '2023-02-04 01:21:28.1449+00', 4658, 3, NULL, 'ace', '1-8::
    All set HS facing diagonally in; 1s+2s also 3s+4s circle 4H round to
    left
9-16::
    1M+2L+3M+4L dance RSh diag reel of 4 (1st corner diagonal) & end in
    prom hold with partner in centre facing up
17-24::
    1s+2s+3s+4s Promenade
25-32::
    1s+2s also 3s+4s dance Poussette
33-40::
    1L+2M+3L+4M dance RSh diag reel of 4 (2nd corner diagonal) & end
    joing NH with partner in centre facing up
41-48::
    1s followed by 2s+3s+4s cast to bottom; 1s make arch & 2s+3s+4s
    dance up under arch to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6534, '2013-08-21 08:31:26.205083+00', '2023-02-04 01:21:28.16596+00', 11908, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across 1/2 way, 1s+3s dance LH across once round &
    2s+1s dance RH across 1/2 way
9-20::
    1s+2s+3s dance R&L for 3 couples
21-24::
    1s set & cast 1 place
25-32::
    2s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6535, '2013-08-21 08:31:26.21501+00', '2023-02-04 01:21:28.201434+00', 13497, 3, NULL, 'ace', '1-4::
    1s dance 1/2 reflection reels of 3 on own sides (1s in & down to
    start)
5-8::
    1L+2L turn RH 1.1/2 times as 1M+2M turn LH 1.1/2 times & 1s end BtoB
    facing own sides
9-16::
    1s dance 4 bars of Double Triangles, 1s dance 1/2 RSh diagonal reel
    of 4 with 1st corners (pstn) & pass RSh to face own sides
17-24::
    1s dance 4 bars of Double Triangles, 1s dance 1/2 LSh diagonal reel
    of 4 with 2nd corners (pstn) & pass LSh to end facing out 2nd place
    own sides
25-32::
    1s cast left & cross up/down to 2nd place opposite sides, all set &
    cross RH.  2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (6536, '2013-08-21 08:31:26.2248+00', '2023-02-04 01:21:28.226922+00', 4661, 3, NULL, 'ace', '1‑8::
    1L+2M also 3L+4M change places RH & set to partner, 1M+2L also 3M+4L
    change places LH & set to partner.
9-16::
    All dance RSh reels of 4 on sides
17‑24::
    All Adv+Ret, 1s+2s also 3s+4s dance 1/2 R&L back to orig places
25‑32::
    2s+3s dance RH across, cast to ends & set
33‑40::
    1s+4s dance LH across, cast to ends & set
41-48::
    1s+2s+3s dance 1/2 reel of 3 on sides (1s in & down to start) & end
    3s facing 2 & 1s facing 4s, all set & change place LH on sides to 2
    3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14669, '2022-03-07 02:20:52.941599+00', '2023-02-04 01:21:28.259639+00', 20402, 3, NULL, 'ace', '1-8::
    1s+2s set and dance 1/2 RH across;1s+3s Set+Link.  (2) 3 (1)
9-16::
    2s+3s+1s dance reels of 3 on sides (1s RSh to 3s)
17-24::
    2s & 1s set and cross RH; 3s & 1s face on sides, set and change
    places LH on sides. 2 1 3
25-32::
    2s+1s+3s circle 6H round and back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6537, '2013-08-21 08:31:26.232981+00', '2023-02-04 01:21:28.288677+00', 4662, 3, NULL, 'ace', '1-8::
    1s dance Inveran Reels with 2s+3s & 1s cross RH to opposite sides
9-16::
    1s set advancing & turn 2H, dance down & out between 2s & 3s then
    cast down behind 3s to turn in to face 3s
17-24::
    1s set & turn 3s (1s dancing out between 2s & 3s), dance up between
    3s & out between 2s+3s then cast up behind 2s to turn in to face 2s
25-32::
    1s set & turn 2s (1s dancing out between 2s & 3s) into 1st place opp
    sides, 1s dance 1/2 Fig of 8 round 2s back to 1st place own sides
33-40::
    1s+2s circle 4H once round to Left, 1s facing 2s set & 1s cast to
    2nd place as 2s lead up to 1st place
41-48::
    1s+3s circle 4H once round to Left, 1s facing 3s set & 1s cast to
    3rd place as 3s lead up to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6538, '2013-08-21 08:31:26.246747+00', '2023-02-04 01:21:28.422058+00', 4663, 3, NULL, 'ace', '1-8::
    1M+2L cross RH, 1L+2M cross RH
9-16::
    Repeat above Fig Bars 1- 8 back to places
17-24::
    1s lead down the middle for 3 steps, back to top & cast to face 1st
    corners
25-32::
    1s turn 1st corners RH, partner LH, 2nd corners RH & partner LH back
    to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6539, '2013-08-21 08:31:26.254893+00', '2023-02-04 01:21:28.432102+00', 7465, 3, NULL, 'ace', '1-8::
    1s lead down for 4 steps (2s step up bars 3-4), set & lead back up
    to face Man''s 2nd corner (2L) in prom hold
9-16::
    1s dance diagonal RSh reel of 3 with 2nd corners & end facing Lady''s
    1st corner (2M)
17-24::
    1s dance LSh reel of 3 with 1st corners & ending in the middle (Man
    on Men''s side facing partner)
25-32::
    1s set in middle, petronella turn to 2nd place own sides & 2s+1s+3s
    turn RH (4 bars)', 0);
INSERT INTO 'dancecrib' VALUES (6540, '2013-08-21 08:31:26.262988+00', '2023-02-04 01:21:28.442893+00', 13098, 3, NULL, 'ace', '{{explanation}}
Top	2 · 3

::
    _1_ · 4
1-8::
    All dance RH across, 1 & 2 dance 1/2 Fig of 8 round 3 & 4
9-16::
    All Adv+Ret diagonally, 2 & 3 dance DoSiDo
17-24::
    _1_ & 4 dance DoSiDo, all Adv+Ret diagonally
25-32::
    All Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to end:

{{explanation}}
Top	3 · 1

::
    _4_ · 2', 0);
INSERT INTO 'dancecrib' VALUES (11088, '2018-09-09 19:44:27.617046+00', '2023-02-04 01:21:28.598049+00', 18564, 3, NULL, 'ace', '1-8::
    1s set & cast to meet below 3s, 1s lead up to top & end facing out
9-16::
    1s+2s+3s dance reflection reels of 3 on sides (1s dance out & down
    to start, 2s in & up)
17-24::
    1s cast to 2nd place as 2s dance up to 1st place & 1s set, 1s+3s
    dance RH across
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (13271, '2020-10-16 00:21:09.354494+00', '2023-02-04 01:21:28.754823+00', 16071, 3, NULL, 'ace', '1-4::
    1s turn 1/2 RH moving down, 1s, in centre, set & pull back RSh to
    face 2nd corners
5-16::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s in the middle 2nd
    place facing down NHJ (Lady on Man''s right)
17-24::
    1s dance down, Bar 20: 1L dance under 1M''s arm to change sides, 1s
    dance up to 2nd place own side
25-32::
    1s dance diag R&L (Man down, Lady up). End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4007, '2013-08-21 08:30:41.181637+00', '2023-02-04 01:18:27.120892+00', 10888, 3, NULL, 'ace', '1-8::
    1s set, dance down & out between 2s+3s on own sides, 1M casts down
    round 3M & up to face Ladies'' side _while_ 1L casts up & dances down
    to face Men''s side (BtoB with partner)
9-16::
    1s circle 3H round left (1M with 2L+3L & 1L+Men), dance 3H round to
    right (1M with 2s & 1L with 3s) & pass LSh to face own sides
17-24::
    1s circle 3H round left (1M with 2M+3M & 1L+Ladies), dance 3H round
    to right (1L with 2s & 1M with 3s) & end facing 1st corners
25-32::
    1s dance reels of 3 on opposite sides (RSh to 1st corner) ending in
    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (14005, '2021-05-03 00:20:49.848927+00', '2023-02-04 01:21:28.787284+00', 19825, 3, NULL, 'ace', '1-4::
    1s dance down NHJ between 2s _while_ 4s dance up NHJ between 3s to
    finish in the middle facing partner (2 bars), 1s+4s turn partner 2H
    to finish 1s/4s facing up/down
5-8::
    1s dance up NHJ & cast down round 2s _while_ 4s dance down NHJ &
    cast up round 3s (2s/3s step up/down bars 7-8)
9-16::
    2s+1s also 4s+3s dance Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides 1 2 3 4
17-24::
    1s+2s also 3s+4s set & dance 1/2 RH across. 1s+4s set & dance 1/2 LH
    across _while_ 2s+3s set & cross RH 2 4 1 3
25-32::
    4s+1s dance all round Poussette', 0);
INSERT INTO 'dancecrib' VALUES (15140, '2022-10-05 00:21:02.506438+00', '2023-02-04 01:21:28.825686+00', 19668, 3, NULL, 'ace', '1-2::
    All advance (right foot) pulling back LSh to pass BtoB with partner
    (Man face up, Ladies down), all advance (left foot) pulling back RSh
    to end on opp side facing in
3-4::
    All set
5-8::
    All repeat 1-4 passing BtoB with partner (Ladies face up, Men down).
    1 2 3
9-16::
    1s+2s+3s dance the Knot for 3 couples and face anticlockwise.  3 2 1
17-24::
    All chase anticlockwise 1/2 round; all set & cross RH. 2s face out
25-28::
    1s+2s change places on sides (Men RH, Ladies LH), 2s turn partner 2H
    & face down _while_ 1s+3s change places on sides (Men LH, Ladies
    RH). 3s face up NHJ
29-32::
    2s+3s circle 4H round to left to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (14670, '2022-03-07 02:20:53.460825+00', '2023-02-04 01:21:28.848517+00', 16606, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 2 places (2s+3s step up bars 3-4). 1s cross RH
    cast up to 2nd place (3s step down 7-8)
9-16::
    2s+1s+3s dance mirror reels of 3 on the sides (1s in/up, 2s
    out/down, 3s out/up to start)
17-24::
    2s+1s+3s set, cross RH, set, cross back RH
25-32::
    All dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6541, '2013-08-21 08:31:26.293198+00', '2023-02-04 01:21:28.864743+00', 4666, 3, NULL, 'ace', '1-8::
    1s+2s set, 1M+2M also 1L+2L change places RH, 2s+1s circle 4H round
    to left, all finishing on sides
9-16::
    1s turn 1st corner RH, pass RSh, turn 2nd corner LH & pass LSh,
    ready for …
17-24::
    1s dance RH across and LH back (1L with 2s & 1M with 3s), finish
    facing each other, 1L facing down, 1M facing up
25-32::
    1s cross down/up giving RH, & dance Figs of 8 (6 bars) on opp sides
    (RSh to 2nd corner to start) & cross RH to 2nd place own sides bars
    31-32', 0);
INSERT INTO 'dancecrib' VALUES (6542, '2013-08-21 08:31:26.301402+00', '2023-02-04 01:21:28.878112+00', 4668, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across, 1s & 3s cross RH & cast down 1
    place
9-16::
    1s+4s 1/2 turn RH into allemande hold (1s face up, 4s down), dance
    anticl''wise round each other to change pl, dance LH across & join RH
    with crnrs
17-24::
    All Set+Link with corners & Set+Link again with same persons. 2s &
    3s stay facing clockwise
25-32::
    4s & 1s turn corners RH onto sides, order 2 (4) 1 (3).  4s & 3s
    dance 1/2 Figs of 8 round couple above to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6543, '2013-08-21 08:31:26.30954+00', '2023-02-04 01:21:28.889956+00', 4669, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    2M+1L+3M set, dance 1/2 RH across in centre, 1L dances LSh round 1M
    _while_ 2M dances LSh round 3L _while_ 3M round 2L & all chase
    anticlockwise around inside of set to places
17-24::
    2L+1M+3L set, dance 1/2 LH across in centre, 1M dances RSh round 1L
    _while_ 2L dances RSh round 3M _while_ 3L round 2M & all 3 chase
    clockwise around inside of set to end in places
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6544, '2013-08-21 08:31:26.317536+00', '2023-02-04 01:21:28.902278+00', 9473, 3, NULL, 'ace', '1-8::
    1s+3s dance double Figs of 8 round standing 2s (1s cast, 3s cross up
    to start)
9-16::
    1s+2s+3s dance *Triple Petronella-in-Tandem & set, Triple
    Petronella-in-Tandem & set (3)(2)(1)
17-24::
    3s+2s+1s Adv+Ret, set & 1/2 turn partners LH into prom hold
25-32::
    3s+2s+1s Promenade & end 3s casting to 3rd place, 2s dancing up to
    top & 1s into 2nd place facing out  2 1 3

{{explanation}}
Note:	*Triple Petronella-in-Tandem is similar to Petronella-in-tandem but 3 dancers petronella in line together', 0);
INSERT INTO 'dancecrib' VALUES (6546, '2013-08-21 08:31:26.335377+00', '2023-02-04 01:21:29.13191+00', 4672, 3, NULL, 'ace', '1-4::
    1s & 4s cast in 1 place & dance back to pl, 2s & 3s dance up/down &
    cast back to pl,
5-8::
    2s & 3s 3/4 turn RH to end in middle, Men facing up, Ladies facing
    down. 2s & 3s set advg & pass LSh
9-16::
    2M dances reel of 3 with 1s (RSh to 1L to start) _while_ 3L dances
    reel of 3 across with 4s (RSh to 4M) _while_ 2L+3M turn RH in middle
    for 4 bars & dance out through partner''s reel & loop round to right
    all back to orig place
17-24::
    1s+2s also 3s+4s dance RH across; 2s+3s dance LH across1s & 4s step
    in bar 24 to end 2s+3s+4s facing up & 1s facing down
25-32::
    1s+2s set Advg to change places passing opposite dancer LSh, 1s+3s
    repeat, 1s+4s repeat, 2s+3s+4s+1s turn 2H to sides. End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12870, '2020-06-03 16:27:11.713652+00', '2023-02-04 01:21:29.1529+00', 13920, 3, NULL, 'ace', '1-8::
    1s+2s dance the Knot.  1s end facing 1st corners
9-16::
    1s dance Corner Pass+Turn with 1st corners, pass RSh, dance Corner
    Pass+Turn with 2nd corners.  2 (1) 3
17-24::
    1s cross passing RSh to dance 6 bar reels of 3 on own side (RSh to
    3rd corners), end 1M between 3s facing up, 1L between 2s facing
    down, 1s turn 3/4 RH to face down RH joined
25-32::
    1s lead down, Bar 4: 1M dances below 1L who dances under 1M''s arm to
    change sides & 1s face up; 1s lead up to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14735, '2022-04-01 00:20:52.55857+00', '2023-02-04 01:21:29.176447+00', 16801, 3, NULL, 'ace', '1-4::
    1s+3s Petronella turn & set. (2s+4s step up slightly bars 3-4)
5-8::
    1s+2s also 3s+4s dance RH across (1s+3s remain in centre)
9-16::
    1s+3s dance reel of 4 in the centre (2s+4s step down slightly bars
    15-16)
17-20::
    1s+3s Petronella turn & set _while_ 2s+4s set & cross passing RSh.
    (1) (2) (3) (4)
21-24::
    All chase1/2 way clockwise to own sides (4s finish facing out, 3L
    in/down, 3M in/up) 4 3 2 1
25-28::
    4s+3s+2s dance 1/2 reel of 3 on own sides (4s dance out/down, 3L
    in/down, 3M in/up, 2s out/up) _while_ 1s may Tulloch turn or turn RH
29-32::
    All Tulloch turn or turn RH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9215, '2016-06-16 22:42:07.215355+00', '2023-02-04 01:21:29.195957+00', 12954, 3, NULL, 'ace', '1-8::
    "Diamond Chase":  1M+2L also 4L+3M change places RH, face clockwise,
    chase 3/4 round standing dancers (1M & 4L in original places, 2L &
    3M have changed places)
9-16::
    Partners repeat: 1L+2M also 4M+3L change places LH, face
    anticlockwise, chase 3/4 round to finish  1 (3) (2) 4
17-24::
    1s dance 1/2 Fig 8 through 3s.  1s+3s+2s set, 1/2 turn partner RH
    remaining in middle for ...
25-32::
    1s+3s+2s Allemande   2 3 1 4
33-40::
    1s set, cast to 4th place (4s step up).  2s+3s also 4s+1s dance RH
    across  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6547, '2013-08-21 08:31:26.344522+00', '2023-02-04 01:21:29.22437+00', 12690, 3, NULL, 'ace', '1-8::
    1s dance RSh reels of 3 on own sides
9-16::
    1L followed by partner casts to 3rd place (2s+3s up) & crosses to
    opposite side, 3s+1s dance RH across
17-24::
    1s dance LSh reels of 3 on opposite sides with 4s+5s
25-32::
    1L followed by partner casts to bottom & crosses to own side, 5s+1s
    dance LH across', 0);
INSERT INTO 'dancecrib' VALUES (6549, '2013-08-21 08:31:26.360726+00', '2023-02-04 01:21:29.292286+00', 4677, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 LH across _while_ 3s+4s dance 1/2 RH across, all set
    on sides; 1s+4s dance 1/2 R&L (1 bar per hand) & all set
9-16::
    2s+4s dance diag LSh reel of 4 _while_ 1s+3s dance diag RSh reel of
    4 (V'' shape reels & all pass partner to start) to end (2) 4 1 (3)
17-24::
    2s+3s advance with nearer hands joined & circle 4H round to left,
    2L+3L dance between 4M & 1M & cast to ends _while_ partners dance
    through Ladies side, 2s & 3s cross RH.  2 4 1 3
25-32::
    2s+4s also 1s+3s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6550, '2013-08-21 08:31:26.368754+00', '2023-02-04 01:21:29.303348+00', 4679, 3, NULL, 'ace', '1-8::
    1M+2L set advancing & turn RH, 1L+2M set advancing & turn RH
9-16::
    1s lead down the middle for 3 steps, back to top & cast to 2nd place
17-24::
    1s lead down between 3s & cast up to face 1st corners, set to 1st
    corners & set to 2nd corners
25-32::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corners &
    cross to places', 0);
INSERT INTO 'dancecrib' VALUES (8611, '2015-02-13 12:48:03.29192+00', '2023-02-04 01:21:29.472606+00', 14965, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance mirror (reflection) reels of 3 on sides (1s in and
    down to start)
9-12::
    2s+3s Set+Link
13-24::
    1s+3s+2s dance R&L for 3 couples
25-32::
    1s+3s+2s dance the Knot to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6118, '2013-08-21 08:31:19.102832+00', '2023-02-04 01:21:29.509292+00', 7286, 3, NULL, 'ace', '1-8::
    Men circle 4H round to left, turn to face partner & dance round
    partner (passing LSh) to original places
9-16::
    Ladies circle 4H round to left, turn to face out between partner &
    corner, dance LSh round corner to original places
17-24::
    All dance "Wheel" Chain (1/2 Nottingham Lace Chain) -
::
    All 3/4 turn ptnrs RH, Ladies dance LH across 1/2 way as Men dance
    1/4 way round set clockwise, all change places with "new" partners
    RH, Men dance LH across 1/2 way as Ladies dance 1/4 way round set
    clockwise & end Men facing out to own partners
25-32::
    All dance "Rosace" (1/4 Schiehallion Reel but with Ladies leading) &
    turn ptnrs RH 1.1/4 times (Ladies on Men''s left & opposite original
    places)
33-40::
    1s+3s reverse Set+Link (Men dance in as Ladies cast), 1s+3s dance
    1/2 Ladies Chain
41-48::
    2s+4s repeat bars 33-40 Men end facing corners
49-56::
    All dance DoSiDo with corners, Men dance RH across as Ladies set
    facing in & set again turning to left to face out
57-64::
    Men dance LH across as Ladies dance 1/2 way anticl''wise round set,
    meet partner in prom hold & dance anticl''wise 1/2 way (to original
    places)', 0);
INSERT INTO 'dancecrib' VALUES (14006, '2021-05-03 00:20:50.546574+00', '2023-02-04 01:21:29.53317+00', 9214, 3, NULL, 'ace', '1-8::
    1s set, cross down RH (2s step up), 1M casts up round 2L, 1L casts
    down round 3M, dance up/down middle passing LSh to face 1st corners
9-12::
    1s turn corners 3/4 2H, 1s+corners NHJ face diagonally across & set
13-16::
    1s+corners drop hands, advance passing opposite person LSh, 1s+1st
    corners dance 1/2 LH across to end 1s facing 2nd corners with 1st
    corner following in tandem
17-24::
    1s+1st corners dance Tandem reel of 4 with 2nd corners. End with 1st
    corners dancing to place as 1s & 2nd corners finish reel
25-32::
    1L+2s (at top) & 1M+3s dance RH across; 2s+1s+3s turn partner 2H', 0);
INSERT INTO 'dancecrib' VALUES (13185, '2020-09-15 00:20:52.89213+00', '2023-02-04 01:21:29.612742+00', 18503, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on sides (1s in & down to
    start)
9-16::
    All set & turn partners 2H twice & set again
17-24::
    1s followed by 2s lead down, 2s separate & follow as 1s lead up,
    finish in the middle
25-32::
    1s+2s dance Allemande. On bars 31-32, 1s cast to 3rd place as 3s
    dance up to 2nd place 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13624, '2021-02-04 01:20:56.68787+00', '2023-02-04 01:21:29.786097+00', 4684, 3, NULL, 'ace', '{{title}}
Strathspey

1-4::
    All Ladies set, Adv+Ret (1 step each) _while_ all Men Adv+Ret (1
    step each) & set
5-8::
    4s+3s dance 1/2 RH across, 4s+2s dance 1/2 LH across
9-12::
    4s+1s & 2s+3s dance RH across (once round)
13-16::
    4s+2s dance 1/2 LH across, 4s+3s dance 1/2 RH across.  1 2 3 4

{{title}}
Reel

1-8::
    All dance 1/2 RSh reel of 4 on sides; 4s+3s+2s dance 1/2 reel of 3
    on sides (4s+3s pass RSh to start)
9-16::
    1s followed by 4s+3s+2s (who dance down sides to start) lead up &
    cast to 4th place.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13625, '2021-02-04 01:20:56.723927+00', '2023-02-04 01:21:29.817151+00', 4685, 3, NULL, 'ace', '1-8::
    2s+3s chase anticlockwise round (inside set) _while_ 1s & 4s turn
    partners RH, turn partners LH
9-16::
    1M+2M+3L+4L dance diag RSh reel of 4 (1M+2M pass RSh, 3L+4L pass RSh
    to start)
17-24::
    1L+2L+3M+4M dance diag LSh reel of 4 (1L+2L pass LSh, 3M+4M pass LSh
    to start)
25-28::
    All cross to opp side passing partner RSh, 1s+2s & 3s+4s change
    places passing LSh on sides
29-32::
    All cross to opp side passing partner RSh, 1s+4s change places
    passing LSh on sides', 0);
INSERT INTO 'dancecrib' VALUES (6551, '2013-08-21 08:31:26.508742+00', '2023-02-04 01:21:29.982653+00', 13464, 3, NULL, 'ace', '1-8::
    1L & 2M set twice, turn RH to places
9-16::
    1M & 2L set twice, turn LH to places (1M facing out)
17-24::
    1M followed by partner casts behind 2M & crosses up, casts behind 2L
    & crosses to 2nd place own side
25-32::
    2s+1s dance RH across, LH back', 0);
INSERT INTO 'dancecrib' VALUES (13186, '2020-09-15 00:20:53.059998+00', '2023-02-04 01:21:30.007061+00', 16078, 3, NULL, 'ace', '1-8::
    All 1/2 turn 2H to face each other in the middle. All set, pull back
    right shoulder & curve into partner''s place. All cross RH to own
    side, 1s finish facing out
9-16::
    1s (joining hands when possible) dance Fig of 8 on their own sides.
    On bars 7-8 1s cast into 2nd place to face down _while_ 2s NHJ dance
    up to 1st place.
17-20::
    1s 1.1/2 turn 3s on the side (Ladies LH, Men RH)
21-24::
    1s 1.1/2 turn 4s (Ladies RH, Men LH)
25-32::
    All circle 8H round & back 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6552, '2013-08-21 08:31:26.516956+00', '2023-02-04 01:21:30.027618+00', 7466, 3, NULL, 'ace', '1-8::
    1L+2M set twice & turn RH
9-16::
    1M+2L repeat
17-24::
    1s lead down the middle & back to 2nd places
25-32::
    2s+1s set twice, 2s+1s dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (6603, '2013-08-21 08:31:27.538884+00', '2023-02-04 01:21:34.542877+00', 10324, 3, NULL, 'ace', '1-8::
    1M+2L 1/2 turn 2H & twirl & dance out to opposite side, 1L+2M repeat
    to end (2) (1) 3
9-16::
    2s+1s chase clockwise 1/2 way, turn partners RH into positions for
    Diamond Poussette
17-24::
    1s+2s dance 1/2 Diamond Poussette, 1s+3s dance 1/2 Diamond Poussette
25-32::
    All circle 6H round to left & back', 0);
INSERT INTO 'dancecrib' VALUES (4008, '2013-08-21 08:30:41.288382+00', '2023-02-04 01:18:27.150068+00', 9837, 3, NULL, 'ace', '1-8::
    1s+2s set & dance 3/4 double Fig of 8 (2s cross up to start) Ending
    with 1s in 2nd place on opposite sides & 2s in top place own side
9-16::
    1s+3s dance double Fig of 8 (1s cross down to start & end back on
    opposite sides)
17-24::
    2s+1s+3s Set+Link for 3 once & chase round 1/2 way clockwise
25-32::
    All 3 couples Set+Link to LEFT once & turn partner LH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (4009, '2013-08-21 08:30:41.423253+00', '2023-02-04 01:18:27.188276+00', 152, 3, NULL, 'ace', '1-8::
    1s cast & 1/2 Fig of 8 round 2s & set advancing to end BtoB facing
    opposite sides
9-12::
    2s+1s+3s set (as in Double Triangles), 1s set advancing & turn R
    about to face in _while_ 2s & 3s dance in & turn R about to face out
13-16::
    2s+1s+3s set (Inverted Triangle formation), 1s dance in & face 1st
    corners _while_ 2s & 3s dance out all turning R about
17-24::
    1s turn 1st corners RH, pass partners RSh to face 2nd corner, turn
    LH & pass partner giving RH
25-32::
    1s dance reels of 3 across (1L with 2s & 1M with 3s) giving RSh to
    4th corner & cross back RH to end in 2nd place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (8342, '2014-07-29 12:59:18.352556+00', '2023-02-04 01:21:30.058531+00', 15369, 3, NULL, 'ace', '{{explanation}}
5 persons in square set with 5th person in center

1-8::
    Corners slip-step round to the left for 4 bars, pivot turn, chase
    back to place, as 5 sets in centre
9-16::
    _5_ turns 1 once round RH, dance 1/2 LSh reel of 3 with 3+1
17-24::
    _5_ turns 4 once round LH, dance 1/2 RSh reel of 3 with 2+4, end
    facing top joining hands with 3+2
25-30::
    Petronella Double Triangles (all dancing 8 bars pas de basque):
::
    All set, corners petronella 1 place anticlockwise _while_ 5 pivots
    around to join hands with 3+4 (in 2nd & 3rd place), all set
31-32::
    All continue setting as person 5 turns 4 RH into centre using pas de
    basque', 0);
INSERT INTO 'dancecrib' VALUES (13908, '2021-04-05 00:20:58.393822+00', '2023-02-13 12:43:34.735356+00', 20284, 3, NULL, 'ace', '1-8::

    1s cross down RH, cast down behind 3s. On bar 5 1s cross down LH to

    4th place as 2s+3s+4s step up. 2s+3s+4s+1s set

9-16::

    2s repeat bars 1-8 3 4 1 2

17-24::

    All dance reels of 4 on the sides to finish in square set formation

    (3s/2s in the centre at top/bottom, 1s&4s one pace back on own

    sides)

25-32::

    3s+2s dance 1/2 R&L, 1s+4s dance 1/2 R&L

33-36::

    2s 3s 1L&4L 1M&4M all turn 1.1/2 2H to finish in square set with

    2s+3s facing up & 1s+4s facing down

37-40::

    2s NHJ lead up 2 bars to end above 1st place & cast out to top place

    in a longwise set

::

    _while_ 3s lead up 2 places, quick RH turn into 2nd place

::

    _while_ 1s followed by 4s cast down 1 place & cross RH with partners

    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6553, '2013-08-21 08:31:26.526785+00', '2023-02-04 01:21:30.093692+00', 4692, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, dance 1/2 Fig of 8 (M round 3s, L round
    2s) & pass LSh to face 1st corner
9-16::
    1s dance 1/2 diagonal reel with 1st corners, pass RSh & dance 1/2
    diagonal reel with 2nd corners 1s ending 2nd place on opposite sides
17-24::
    3s+1s+2s cross RH, 3s & 2s set to partners _while_ 1s cast round 3rd
    corner (pstn) to end facing up/down (M between 3s at top), 3s+1s+2s
    cross up/down RH & 3s+2s set to each other _while_ 1s cast to 2nd
    places
25-32::
    1s dance reels of 3 on sides with 1s giving LSh to 3rd corners', 0);
INSERT INTO 'dancecrib' VALUES (12927, '2020-07-01 00:20:44.951616+00', '2023-02-04 01:21:30.166721+00', 17598, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s cross down RH between 3s. 1s cast up
    to 2nd place opp side _while_ 3s set turning to face up
9-16::
    All dance crossing mirror reels of 3 on sides:
::
    1s cross up to dance reel on own sides
::
    2s dance out/down & cross down from 2nd place to opp side
::
    3s dance out/up & cross up from 2nd place to opp side.  (2) 1 (3)
17-24::
    2s+1s+3s circle 6H round & back
25-32::
    1s dance 1/2 Fig 8 (1L round 2s, 1M round 3s); 2s+1s+3s turn partner
    1.1/2 RH to own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6555, '2013-08-21 08:31:26.544633+00', '2023-02-04 01:21:30.1864+00', 15003, 3, NULL, 'ace', '1-4::
    1s+2s+3s dance DoSiDo
5-12::
    2s cross passing RSh & dance reel of 3 on opposite sides starting
    RSh to 1st corner
13-16::
    1s+2s+3s turn RH into Allemande hold with 2s facing down  1(2)3
17-24::
    1s+2s+3s dance Interlocking Allemandes:
::
    1s & 3s dance normal Allemande but end in 3rd/1st place as 2s
    Allemande (down) & up to 2nd place opposite sides.  3(2)1
25-32::
    2s+1s dance 1/2 R&L, all set & 1s cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (9023, '2015-11-30 09:00:04.596852+00', '2023-02-04 01:21:30.215114+00', 16103, 3, NULL, 'ace', '1-8::
    1s+2s turn 3/4 2H into line up/down middle (Men face up/Ladies down)
    & dance 1/2 reel of 4.  1s 1/2 turn 2H, pull back RSh to face 1st
    corners as 2s turn 3/4 RH to 1st place own sides
9-16::
    1s set to 1st corners, pull back RSh & dance round each other to
    face 2nd corners.  1s set to 2nd corners, pull back RSh, 1L dances
    up to face 2L, 1M down to face 3M
17-20::
    1s dance 1/2 RSh reels of 3 across, turn LH (bar 20) to swap ends,
    1L facing 3L place, 1M facing 1M place
21-24::
    1s dance 1/2 LSh reels of 3 across.  Is finish in 2nd place own
    sides (2s & 3s dance full reels of 3 across bars 17-24)
25-32::
    1s+3s dance Bourrel:
::
    _25-28_    1M+3L set advancing, 3/4 turn 2H & twirl to end BtoB
    (Lady facing up & Man down) _while_ partners chase anticlockwise to
    face partner
::
    _29-32_    Set to partners & turn 2H (sometimes RH) to own sides
    having changed places       2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6556, '2013-08-21 08:31:26.552671+00', '2023-02-04 01:21:30.231139+00', 13865, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, set & petronella turn to finish 1L between 2s
    (facing down) & 1M between 3s facing up
9-16::
    2s+1s+3s Set+Link, 2s+1s+3s turn partners RH & 1s end facing 3rd
    corners
17-24::
    Corners Pass+Turn to face 4th corners, corners Pass+Turn.
25-32::
    1L+2s dance 1/2 reel of 3 across (1L+2L pass L Sh to start) as 1M+3s
    dance 1/2 reel of 3 across (1M+3M pass LSh to start), 1s dance 1/2
    figs of 8 (1M round 2s, 1L round 3s)', 0);
INSERT INTO 'dancecrib' VALUES (8701, '2015-03-03 08:47:51.890565+00', '2023-02-04 01:21:30.246409+00', 15281, 3, NULL, 'ace', '1-4::
    1M+2M and 3L+4L (Top 2 men and bottom 2 ladies) dance around their
    partners by the RSh and curve into the centre to face their partner
5-8::
    All join nearer hands with the person beside and set. 1M, 2M, 3L &
    4L pull back RSh & dance out to places
9-12::
    1L+2L and 3M+4M (Top 2 ladies and bottom 2 men) Set and Link
13-16::
    1L +3L and 2M+4M (Middle ladies and men) Set and Link (Ladies'' order
    2,3,1,4 and men''s order 1,4,2,3)
17-24::
    Four Couple Bourrel:
::
    _17-20_    2L and 3M  dance across set & up/down to finish in the
    centre at the opp end _while_ all others set  advancing to person
    diagonally to their right, turn each other 3/4 2H. (1M+3L, 4M+1L,
    2M+4L)
::
    All pull back right shoulder (twirl), finish in the centre ladies
    facing up, men facing down, facing original partner.
::
    _21-24_   All set to partners and turn 3/4 with 2 hands to finish on
    own side. (Order 3,1,4,2)
25-32::
    All circle 8H round and back.   Repeat with new top couple.', 0);
INSERT INTO 'dancecrib' VALUES (13272, '2020-10-16 00:21:10.566783+00', '2023-02-04 01:21:30.267878+00', 17463, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate, 1s face out
9-16::
    2s+3s dance RH across _while_ 1s chase clockwise 1/2 round to 2nd
    place opp  sides; 1s turn 1.1/4 2H to 1M between 3s, 1L between 3s
17-24::
    Lines of 3 across set advancing, pass opposite dancer RSh & cast to
    right to reform lines across (2s & 3s now on opp sides), 2s+3s
    change places RH up/down _while_ 1s turn 3/4 2H to face up NHJ
25-32::
    1s dance up, cast to 2nd place opp side; 3s+1s+2s turn partner 1.1/2
    2H to own sides. End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (13273, '2020-10-16 00:21:10.594317+00', '2023-02-04 01:21:30.285073+00', 18233, 3, NULL, 'ace', '1-8::
    1s dance down, cast up round 3s (2s step up 3-4); 1s turn 1.3/4 LH
    to face 1st corners
9-16::
    1s turn 1st corner RH, turn 2nd corner LH; 1s turn partner RH to
    face 3rd corner, turn 3rd corner LH
17-24::
    1s turn 4th corner RH, turn partner LH; 1M+2s (at top) & 1L+3s dance
    RH across. 1s face out
25-32::
    1s chase clockwise 1/2 round to opp sides & turn 1.1/2 RH to own
    side.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6558, '2013-08-21 08:31:26.653309+00', '2023-02-04 01:21:30.544457+00', 10364, 3, NULL, 'ace', '1-8::
    All 1/2 turn partners RH, twirl into partner''s place & circle 8H
    round to left 1/2 way
9-16::
    All 1/2 turn partners LH, twirl into partner''s place & circle 8H
    round to right 1/2 way
17-24::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L
25-32::
    1s+4s dance 1/2 R&L, all set & cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6560, '2013-08-21 08:31:26.671407+00', '2023-02-04 01:21:30.5879+00', 4716, 3, NULL, 'ace', '1-8::
    1s set, cross RH, set to 2s & 3/4 turn opp. person RH into lines
    across (Men BtoB)
9-16::
    1s+2s dance 1/2 reel of 4 across, end Men passing RSh, set to opp.
    person & turn RH - Ladies crossing to other side Men on same side
    with partner on right  (1s on Men''s side, 2s on Ladies'' side) Men
    face in, Ladies face out
17-24::
    1s+2s dance Men''s Chain ending with 1s turn RH 1.1/4  & 2s turn RH
    3/4 into line across with 1L+2M BtoB facing partner
25-32::
    1s+2s dance 1/2 reel of 4 across ending with 1L+2M passing RSh, set
    to partner & turn RH - 1M+2L to own side facing partner.  2 1 3', 1);
INSERT INTO 'dancecrib' VALUES (6561, '2013-08-21 08:31:26.681186+00', '2023-02-04 01:21:30.607038+00', 14293, 3, NULL, 'ace', '1-8::
    2s & 3s set & cast out to ends, 2s & 3s crossing down/up b''tw''n
    1s/4s & turn them with nearer hand into lines across with 2s facing
    3s in middle
9-16::
    2s+3s dance 1/2 R&L down/up (no hands) & dance 1/2 RSh reel of 4
    across with 4s/1s
17-24::
    2s+3s turn facing person RH to end with 2s in 4th place & 3s in 1st
    place on opposite sides, all 4 couples set & cross RH
25-32::
    All circle 8H round & back.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (6562, '2013-08-21 08:31:26.690911+00', '2023-02-04 01:21:30.632451+00', 4720, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & cross RH, 1s+2s Set+Link
9-16::
    2s+1s+3s dance reflection reel of 3 on sides, taking hands where
    possible (1s in & down) & 1s+3s 1/2 turn partner 2H ready for …
17-24::
    3s+1s dance 1/2 Diamond Poussette, set to partners & dance RH across
    1/2 way
25-32::
    1s dance 1/2 RSh reel of 3 across (1L with 2s & 1M with 3s); All
    turn partner 2H

{{explanation}}
End of 2nd time through, 1s & 4s turn (2 bars), 1s cast as 4s dance up NHJ to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (13909, '2021-04-05 00:20:59.112101+00', '2023-02-04 01:21:30.812006+00', 19487, 3, NULL, 'ace', '1-8::
    1s+2s dance Double Fig 8 (1s cross down, 2s cast up). 2s face out
9-16::
    1s followed by 2s dance down middle, cast up round 3s, meet & dance
    up to top & cast, 1s to 2nd place, 2s to 1st place facing out
17-24::
    1s cross down RH to dance reels of 3 on opp sides giving hands (3s
    out/up, 2s out/down to start).  2s & 3s face out
25-32::
    1s cross down LH to dance reels of 3 on own sides giving hands (3s
    out/up, 2s out/down to start).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6563, '2013-08-21 08:31:26.704596+00', '2023-02-04 01:21:30.945415+00', 4725, 3, NULL, 'ace', '1-8::
    1s+2s Promenade
9-16::
    1s lead down the middle & up to top
17-24::
    1s+2s dance Allemande
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6564, '2013-08-21 08:31:26.712693+00', '2023-02-04 01:21:30.972954+00', 4726, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels on own sides (1s in & down to start)
9-16::
    1s turn RH into 2nd place (2s up), dance out & cast round 3s & turn
    LH into 2nd place own sides
17-24::
    2s+1s dance 1/2 R&L & dance DoSiDo with partner
25-32::
    1s+2s turn partners RH 1.1/2 times to own sides, turn on sides LH
    1.1/2 times', 4);
INSERT INTO 'dancecrib' VALUES (6565, '2013-08-21 08:31:26.72076+00', '2023-02-04 01:21:30.9898+00', 4728, 3, NULL, 'ace', '1-8::
    1s cast down to 3rd place as 3s set & lead up to top, 3s cast down
    to 3rd place as 1s set & lead up to top
9-16::
    1s set to 2s on sides & change places RH, 1s turn LH to face 1st
    corner
17-24::
    1s turn 1st corner RH, turn partner LH, 2nd corner RH & partner LH
    to end in 2nd places
25-32::
    1s+3s circle 4H round to left & 2s+1s circle 4H round to right', 0);
INSERT INTO 'dancecrib' VALUES (12094, '2019-08-30 09:54:40.793607+00', '2023-02-04 01:21:31.006105+00', 4734, 3, NULL, 'ace', '1-8::
    1s in prom hold dance below 3s, cast up round 3L, in between 2L &
    3L, dance up between 2s, cast down round 2M to end between 2M & 3M
    (2s step up 7-8)
9-16::
    1s dance across, out between 2L & 3L, cast up round 2L, dance down
    middle, cast up round 3M to end between 2M & 3M
17-20::
    1L+2s dance 1/2 RSh reel of 3 across _while_ 1M+3s dance 1/2 LSh
    reels of 3 across to end with 1s between 2M & 3M on Ladies'' side
21-24::
    1L dances across in front of 1M & 1L+3s dance 1/2 RSh reel of 3
    across _while_ 1M+2s dance 1/2 LSh reel of 3 across. 1s end between
    2M & 3M on Men''s side
25-32::
    1L dances RSh round 3M to dance reel of 3 across with 3s _while_
    1M+2s dance reel of 3 across (1M RSh to 2L to start). 1s end 2nd
    place own side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12928, '2020-07-01 00:20:45.512619+00', '2023-02-04 01:21:31.031059+00', 17599, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 2s+1s+3s turn partner 2H
9-16::
    2s+1s+3s circle 6H round & back
17-24::
    1s turn 3/4 RH, 1M faces up, 1L faces down, join LH & set right,
    join RH & set left, retain RH & turn 1.1/4 to 2nd place own side
    _while_
::
    2s+3s dance L&R (change places LH on side to start)
25-32::
    1s+3s dance ''Divided Knot:
::
    1s+3s set & 1/2 turn prtnrs 2H to face down, 3s cast up on opp side
    to 1st pl as 1s dance dn & cast to 2nd pl & 3s+1s cross RH.  End 2 3
    1', 0);
INSERT INTO 'dancecrib' VALUES (13910, '2021-04-05 00:20:59.348266+00', '2023-02-04 01:21:31.06716+00', 4738, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s lead down, cross below 3s & cast up to
    2nd place opp sides
9-16::
    1M+2s & 1L+3s dance RH across; 1s pass RSh to dance LH across with
    other couple
17-24::
    All set & cross RH with partner; all set & turn partner RH finishing
    2s & 1s facing down, 3s facing up, Ladies on Man''s right in prom
    hold
25-32::
    2s+1s+3s dance Promenade Reel of 3 (1s+3s pass LSh to start).  End 2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (4132, '2013-08-21 08:30:44.015939+00', '2023-02-04 01:18:36.314592+00', 13750, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-4::
    1s & 4s turn 2H & remain in middle as 2s & 3s step down/up into
    lines across & all set 1s+4s advancing to pass partner LSh to face
    2s/3s
5-8::
    1s+2s also 3s+4s dance 1/2 reels of 4 across & 1s+4s end 1/2 turning
    partner LH to face up/down LH to partner & RH to 2s/3s
9-16::
    All Bal-in-Line twice, 1M & 4M turn left about & lead LH partners
    out ends of set crossing & casting to 2nd/3rd places.  (2)(1)4 3
17-20::
    1s+4s turn 2H on sides & all set (2s+1s facing down, 4s+3s up) with
    1s+4s advancing to pass LSh on sides to face 2s/3s
21-24::
    All dance 1/2 reels of 4 on sides & 1s+4s end 1/2 turning LH to face
    across giving other partner LH & RH to 3s/2s.  3(1)4(2)
25-32::
    All Bal-in-Line twice, 1M+4L also 1L+4M change places LH & then
    chase anticlockwise 1/2 way.  3 1(4)(2)', 0);
INSERT INTO 'dancecrib' VALUES (13274, '2020-10-16 00:21:11.158306+00', '2023-02-04 01:21:31.097932+00', 16902, 3, NULL, 'ace', '1-8::
    1s dance in & cast (2s cross up bars 3-4); 1s turn 2H, face up &
    cast to 3rd place (3s cross up bars 7-8 & face out)
9-16::
    1s take prom hold & dance 1/2 reel of 3 across (RSh to 3M in 2L''s
    place); 1s dance 1/2 reel of 3 across (LSh to 2L), Bar 16: 1s 1/2
    turn LH to face opp sides
17-24::
    1L+2s (at top) also 1M+3s dance RH across; 1s 3/4 turn LH & cast to
    3rd place (3s step up)
25-32::
    2s+3s+1s circle 6H 1/2 round to left (3 bars), dance in (1 step),
    pull back RSh & chase 1/2 round clockwise to own side.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6570, '2013-08-21 08:31:26.766967+00', '2023-02-04 01:21:31.378327+00', 7855, 3, NULL, 'ace', '1-8::
    All set to partner & turn RH, all dance 1/2 Grand Chain
9-16::
    All set to partner & turn RH, all complete Grand Chain back to
    places
17-20::
    1L+4M (corner couple) cross to opp corner _while_ 3L+2M (opp corner
    couple) turning inwards cast round outside of set to opp places
21-24::
    Repeat with 1M+2L crossing _while_ 3M+4L cast (Men now with new
    partners on their left)
25-28::
    All set to corners & change places RH to meet own partners (all now
    opp orig places)
29-32::
    1s+3s dance 1/2 R&L
33-36::
    2s+4s dance 1/2 R&L (all now in orig places)
37-40::
    1s+3s turning inwards cast behind corners into lines of 4 across
41-48::
    All dance reels of 4 across set with (all ending in orig places)
49-52::
    4s+2s turning inwards cast behind corners to form lines of 4 on
    sides
53-60::
    All dance reels of 4 up/down (all ending in orig places)
61-64::
    All turn partners RH 1.3/4 times to end with Ladies in centre facing
    partners', 0);
INSERT INTO 'dancecrib' VALUES (6571, '2013-08-21 08:31:26.775162+00', '2023-02-04 01:21:31.415201+00', 9343, 3, NULL, 'ace', '1-8::
    All set, 1s lead down middle & cross over to cast up to 2nd pl as 2s
    set & cross RH to 3rd pl as 3s cast up to 1st place & cross RH, all
    set.  (3)(1)(2)
9-16::
    1s+3s dance 1/2 diagonal reel of 4 (1L passes 3M LSh to start & then
    Partner RSh), 1s+3s dance 1/2 Diamond Poussette 1s end opp sides.
    3(1)(2)
17-24::
    1s+2s dance 1/2 diagonal reel of 4 (1M passes 2L LSh to start & then
    Partner RSh), 1s+2s dance 1/2 Poussette ending 3(1)2
25-32::
    1s cast right (1L up & 1M down) to meet in centre, turn 2H, 1s dance
    out same end & cast to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6572, '2013-08-21 08:31:26.922793+00', '2023-02-04 01:21:31.585301+00', 9814, 3, NULL, 'ace', '1-8::
    All dance RSh round partners & back, 1L & 4M cast down/up 1 place,
    meet & 3/4 turn RH _while_ partners cross & cast 1 place
9-16::
    1s+4s dance RH across, LH back to end facing corners
17-24::
    All dance reels of 4 on sides ending 2 (1)(4) 3
25-32::
    1s+4s lead up to top, cast to 4th/3rd places opposite sides _while_
    3s follow but cross & cast to 2nd place, 3s+4s+1s cross RH to own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (13763, '2021-03-02 01:21:06.889543+00', '2023-02-04 01:21:31.596181+00', 12330, 3, NULL, 'ace', '1-8::
    1s & 2s set, turn partners 2H once round opening out to circle 4H
    round to left
9-16::
    1s+2s Set+Link; 1s cross RH, 1s turn 2s on sides (1L+2M - RH, 1M+2L
    - LH) to finish in a line of 4 facing down
17-24::
    All dance down, turn right about & dance up finishing 1s between 2s
    (1L facing 2M, 1M facing 2L)
25-32::
    1s+2s dance reel of 4 across the dance, 1s finish in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6573, '2013-08-21 08:31:27.076613+00', '2023-02-04 01:21:31.716911+00', 4752, 3, NULL, 'ace', '1-8::
    1s cross down RH to double triangle position with 2s+3s & set, 1s
    turn R about to face each other & turn 2H to face 1st corners
9-16::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partners LH to
    end facing down
17-24::
    1s lead down the middle & back to 2nd places
25-32::
    2s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6574, '2013-08-21 08:31:27.086457+00', '2023-02-04 01:21:31.885828+00', 4755, 3, NULL, 'ace', '1-8::
    1s cast down own sides, turn out & cast back to top
9-16::
    1s lead down the middle & back to end 1L between 2s facing down & 1M
    between 3s facing up
17-24::
    2s+1s+3s set twice with 1s turning onto own sides, 2s+1s+3s set
    twice
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6575, '2013-08-21 08:31:27.11406+00', '2023-02-04 01:21:31.925045+00', 15077, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link & dance RH across
9-16::
    1s+3s Set+Link & dance RH across
17-24::
    1s set & dance up to top, 1s cast to face 1st corners
25-32::
    1s set to 1st corners, pull back RSh & turn partner RH to face 2nd
    corners, set to 2nd corners & turn partner RH to face out own side
33-40::
    1s dance reels of 3 on own sides giving RSh to 3rd corners (Man up,
    Lady down) & end changing places with 3s (Men LH, Ladies RH)', 0);
INSERT INTO 'dancecrib' VALUES (6576, '2013-08-21 08:31:27.122237+00', '2023-02-04 01:21:31.956766+00', 4759, 3, NULL, 'ace', '1-8::
    1s set, dance down below 3s, cast up round 3s & dance to top facing
    out _while_
::
    Bar 3:  2s set, dance down below 3s then cast up round 3s to 2nd
    place
::
    Bar 5:  3s set, dance in & down touching hands & cast back to 3rd
    place facing out
9-16::
    Reels of 3 on sides (1s cast down, 2s dance in/up, 3s cast up to
    start)
::
    Bar 11:  1s cross RH to 3rd place opp side & continue reel
::
    Bars 15-16:  1s lead up (RH) & 1/2 turn to finish NHJ facing down,
    2s finish in middle facing up, 3s in 3rd place
17-24::
    1s+2s dance the Rondel.  1s in 2nd place face down
25-32::
    2s+1s+3s dance Grand Chain. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6578, '2013-08-21 08:31:27.140062+00', '2023-02-04 01:21:32.006898+00', 7469, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & chase clockwise 1/2 way
9-16::
    1s+3s dance LH across & chase anticlockwise 1/2 way
17-24::
    3s+1s dance 1/2 R&L (Start RH on sides), 2s+1s dance 1/2 R&L (Start
    RH on sides)
25-32::
    1s set, cast 1 place & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6579, '2013-08-21 08:31:27.14816+00', '2023-02-04 01:21:32.0317+00', 4765, 3, NULL, 'ace', '1-8::
    1s+2s+3s set twice, cross RH
9-16::
    1s+2s+3s set twice, cross RH
17-24::
    1s+2s dance reel of 4 (1L & 2M pass LSh to start) & 1s pass LSh to
    face 3s
25-32::
    1s+3s dance reel of 4 (1M & 3L pass LSh to start) & 1s end in 2nd
    place
33-40::
    1s+3s dance RH across & LH across to places
41-48::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6580, '2013-08-21 08:31:27.157869+00', '2023-02-04 01:21:32.148515+00', 4767, 3, NULL, 'ace', '1-4::
    1s slip step down (2 bars), drop hands nearest top & both set as 1L
    pulls back RSh to Bto B with partner, 1L faces 3M & 1M faces 3L (3s
    set & 2s step up 3-4)
5-8::
    1s turn 3s (1M+3L RH, 1L+3M LH) to end 1s between 3s all facing up
    in line across; 1s+3s set
9-12::
    1s slip step up middle (2 bars), drop hands nearest bottom of set, &
    both set as 1L pulls back RSh to face 2L & 1M faces 2M (2s set
    11-12)
13-16::
    1s 3/4 turn 2s (1M+2M LH, 1L+2L RH), 1s end in 2nd place own side,
    2s in 1st place, 2s+1s set to partners. 2 1 3
17-24::
    2s+1s dance 1/2 R&L with full LH turn on opp sides; 2s cross RH to
    own sides (in top place) as 1s cross & dance RSh round 3rd corners
    back to 2nd place own sides facing down
25-32::
    2s+1s+3s dance Grand Chain', 0);
INSERT INTO 'dancecrib' VALUES (6581, '2013-08-21 08:31:27.165924+00', '2023-02-04 01:21:32.174311+00', 12642, 3, NULL, 'ace', '1-8::
    1s set, 1L followed by partner casts 1 place, crosses down between
    3s, casts up Men''s side & into centre
9-16::
    1s dance LH across with 2s & RH across with 3s
17-24::
    1L followed by partner casts down 1 place on Ladies side, crosses up
    between 3s & turns right about to turn partner RH to 2nd places own
    sides
25-32::
    2s+1s+3s circle 6H round to left for 6 steps, pivot left & chase
    back to places', 0);
INSERT INTO 'dancecrib' VALUES (13275, '2020-10-16 00:21:12.350531+00', '2023-02-04 01:21:32.19459+00', 14426, 3, NULL, 'ace', '1-8::
    1s+2s set, cross (Ladies dance across passing between Men); 1s turn
    1.1/2 RH moving down _while_ 2s cross LH & cast up to 1st place
9-16::
    2s+1s+3s Adv+Ret (1 step each), 1s 1/2 turn 2H, pull back RSh to
    face 1st corners; 1s set to & turn 1st corner 2H to end 1L between
    2s facing down, 1M between 3s facing up
17-24::
    Lines of 3 Adv+Ret (1 step each), 1s 1/2 turn 2H, pull back RSh to
    face 2nd corners; 1s set to & turn 2nd corner 2H. 1s end in 2nd
    place opp side
25-32::
    1M+3s also 1L+2s dance 6 bar reels of 3 across (1M+3M & 1L+2L pass
    RSh), Bars 31-32: 1s cross LH to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6582, '2013-08-21 08:31:27.174018+00', '2023-02-04 01:21:32.21954+00', 13262, 3, NULL, 'ace', '1-8::
    1s dance round each other RSh & cast 1 place, 1s dance 1/2 reels of
    3 on sides
9-16::
    1s dance round each other LSh & cast to 3rd place, 1s dance 1/2
    reflection reels of 3 with 3s+2s (1s in & up to start)
17-24::
    1s followed by 2s+3s dance down & 1s turn right about to dance 2
    parallel 1/2 reels of 3 in middle (1s RSh to 2s to start)
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (6583, '2013-08-21 08:31:27.182943+00', '2023-02-04 01:21:32.252276+00', 13444, 3, NULL, 'ace', '1-8::
    1s set & dance down to below 3s, cast up to 2nd place & cross
    (passing LSh) to face 1st corners
9-16::
    1s set to corners & set to 2nd corners, 1s cast round 1st corners to
    end LSh to LSh in middle (1M facing up, 1L facing down)
17-24::
    1s dance RH across (1M with 2L+3L, 1L with 2M+3M), 1s dance LH
    across with other couple 1L ending between 2s & 1M between 3s
25-32::
    All Adv+Ret up/down, 1s turn RH 1.1/4 times to end 2nd place own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (9216, '2016-06-16 22:42:07.979063+00', '2023-02-04 01:21:32.286884+00', 11204, 3, NULL, 'ace', '1-8::
    1s cast behind lines, turn outwards & dance up to place
9-16::
    1s+2s dance RH across, LH across
17-24::
    1s turn RH, cast (2s step up).  1s+2s dance DoSiDo
25-32::
    2s+1s circle 4H round and back', 0);
INSERT INTO 'dancecrib' VALUES (14801, '2022-05-05 00:20:55.746169+00', '2023-02-04 01:21:32.315732+00', 4781, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All circle 8H round to left (3 bars), Men pull back LSh & chase
    anticlockwise back to place _while_ Ladies dance RH across 1.1/2
    round back to place
9-16::
    All circle 8H round to right (3 bars), Ladies pull back RSh & chase
    clockwise back to place _while_ Men dance LH across 1.1/2 round back
    to place
17-24::
    All set to & turn corner; all set to & turn partner
25-32::
    All dance full interlocking reels of 4 (Men start with 1/2 LH across
    in centre) ending with Ladies BtoB in centre facing partner

{{title}}
Reel

1-8::
    All Adv+Ret & change places RH with partner; Men with backs to
    centre join hands & circle 4H round to left to end facing partner
9-16::
    All Adv+Ret & change places RH with partner; Ladies with backs to
    centre join hands & circle 4H round to left to end facing partner
17-32::
    All dance Star Grand Chain starting RH to partner

{{explanation}}
Repeat Strathspey bars 1-32  
Repeat Reel bars 1-16 then continue reel:

17-24::
    All turn partner R elbow hold; All turn partner L elbow hold
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6584, '2013-08-21 08:31:27.192546+00', '2023-02-04 01:21:32.416468+00', 4782, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s dance NHJ down the middle & up to face 1st corners
17-24::
    1s set to 1st corners & turn 2H, set & turn 2nd corners
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners &
    cross to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6585, '2013-08-21 08:31:27.200559+00', '2023-02-04 01:21:32.447267+00', 4784, 3, NULL, 'ace', '1-8::
    1s dance Inveran Reels with 2s+3s
9-16::
    1s turn RH 1.1/2 times moving down to 2nd place opp sides (2s step
    up); 1s cast up behind 2s & cross down to 2nd place own side
17-24::
    2s+1s+3s dance Grand Chain
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6586, '2013-08-21 08:31:27.213605+00', '2023-02-04 01:21:32.60808+00', 4785, 3, NULL, 'ace', '1-8::
    1s in Prom hold (Lady on Mans left) dance reel of 3 across with 2s
    (RSh to 2M to start) & end 1M crossing his ptnr over to face opp
    sides
9-16::
    1L with 2M+3M dance RH across as 1M with 2L+3L dances LH across, 1s
    pass LSh to change places & dance LH Ladies side & RH Men''s side
17-24::
    1s in Prom hold (Lady on Mans left) dance reel of 3 with 3s (RSh to
    3M to start) & 1s end in middle facing down on own sides
25-32::
    1s lead down below 3s & cast up to 2nd place, 2s+1s+3s turn partners
    RH', 0);
INSERT INTO 'dancecrib' VALUES (6587, '2013-08-21 08:31:27.221789+00', '2023-02-04 01:21:32.622223+00', 4789, 3, NULL, 'ace', '1-8::
    All turn partners 2H & set, 1s & 4s cross RH & petronella turn to
    end in line up/down middle (L facing down & M up) as 2s & 3s step
    down/up
9-12::
    1s+4s dance 1/2 reel of 4
13-16::
    1s+4s turn RH _while_ 2s+3s chase clockwise 1/2 way & when crossing
    the set dance 1/2 RH across with 1s/4s (3 hands across) 1s+4s end in
    middle
17-24::
    Repeat bars 9-16, 2s end in 1st place, 3s in 4th place,1s & 4s in
    middle of set
25-32::
    1M & 4L followed by ptnrs dance out ends, cast to right & cross to
    own sides (order 2143), 1s+4s+3s dance 1/2 LSh reel of 3 on sides.
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9745, '2017-04-06 08:40:03.775503+00', '2023-02-04 01:21:32.650623+00', 16706, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across.  1s cast to 2nd place, 2s lead up to top
9-16::
    1s+3s repeat 1-8.  1s end in 3rd place
17-24::
    1s lead up to the top, cross & cast to 2nd place (3s step down
    17-18). 1s dance 1/2 Fig 8 round 2s to finish in 2nd place own side
25-32::
    2s+1s+3s dance mirror reels of 3 on sides taking hands (1s in/down,
    2s cast down, 3s out/up)', 0);
INSERT INTO 'dancecrib' VALUES (6655, '2013-08-21 08:31:28.470026+00', '2023-02-04 01:21:37.969728+00', 4925, 3, NULL, 'ace', '1-8::
    1s+3s dance Diamond Poussette
9-16::
    1s+2s+3s Promenade
17-24::
    1s lead down the middle for 3 steps, back to top & cast to 2nd
    places
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14788, '2022-05-05 00:18:26.993876+00', '2023-02-04 01:18:30.764912+00', 220, 3, NULL, 'ace', '1-8::
    1s+2L dance RH across; 1L leads as 1s+2M dance LH across. All end
    back in place
9-16::
    1s+2s dance R&L
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance »New Poussette«:
::
    _25-26_  Couples set advancing to meet partner & turn 2H just over
    1/4 to couples side by side on diagonal (Men with backs to Ladies''
    side)
::
    _27-28_  Couples advance diagonally (1s to Men''s side, 2s to Ladies''
    side) & 1/4 turn
::
    _29-30_  Couples advance into centre & 1/4 turn into line up/down
    centre facing partner (2s above 1s, 2L+1M BtoB)
::
    _31-32_  Couples turn partner RH out to own sides (2 skip change of
    step).  2 1', 0);
INSERT INTO 'dancecrib' VALUES (4136, '2013-08-21 08:30:44.048816+00', '2023-02-04 01:18:36.413734+00', 354, 3, NULL, 'ace', '1-8::
    All pass partner with LH (1 bar), turn next person RH (3 bars), pass
    partner LH (1 bar) & turn corner RH (3 bars) back to original places
9-16::
    Ladies circle 4H round to left & dance LH across back to places
17-24::
    Men circle 4H round to left & LH across to places _while_ Ladies
    dance cl''wise around set ending LH to partner & Men in centre (RH
    wheel)
25-32::
    All dance round for 2 bars, Ladies lead partners on one place, all
    circle round to left & end turning partners 2H back to original
    pstns
33-40::
    1s & 3s set to partners, turn RH into Allemande hold & pass other
    couple LSh, drop RH & Men pass Ladies in front & dance LH across to
    end BtoB with partner facing side couples (facing own corners)
41-48::
    1s+3s dance reels of 4 across with corners & end taking partners LH
    & return to places
49-64::
    2s & 4s repeat bars 33-48 with reel up/down set
65-96::
    All repeat bars 1-32', 0);
INSERT INTO 'dancecrib' VALUES (8343, '2014-07-29 12:59:18.942221+00', '2023-02-04 01:21:32.673895+00', 15225, 3, NULL, 'ace', '1-8::
    1M+2L, 2M+3L, 3M+4L turn 2H 1.1/2 times as 1L and 4M dance
    anticlockwise 1/2 way round set; all set, cross RH with opposite
    person
9-16::
    1M+2L, 2M+3L, 3M+4L turn 2H 1.1/2 times as 1L and 4M dance
    anticlockwise 1/2 way round set; all set, cross RH with opposite
    person; 1s+4s finish in middle in 1st/4th place facing down/up
17-24::
    1s+4s dance in (1 step), circle 4H 1/2 way round to left & turning
    inwards (1 step) dance out of ends of set;  4s cast down behind 2s &
    cross up to 1st place, as 1s cast up round 3s & cross down to 4th
    place     4 2 3 1
25-32::
    4s+2s also 3s+1 Set+Link; 2s+4s also 1s+3s dance RH across  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6588, '2013-08-21 08:31:27.230029+00', '2023-02-04 01:21:32.6988+00', 4796, 3, NULL, 'ace', '1-8::
    1s & 3s join hands with partner & adv for 2 steps, turn opposite
    partner RH once round, retaining opp ptnr hand dance RH across with
    2s/4s
9-16::
    Dancing couples (1M+3L & 1L+3M) facing side couples dance parallel
    reels of 4 across the dance
17-18::
    Dancing couples (1M+3L & 1L+3M) set to side couples
19-22::
    Dancing couples (1M+3L & 1L+3M) dance out between side couples &
    cast to original places _while_ side couples separate & dance into
    centre to meet partners then holding nearer hands dance out to
    original places
23-24::
    All turn partners 2H
25-32::
    All circle 8H 1/2 way round to left, 3/4 turn partners RH into prom
    hold (Ladies on inside) & all Promenade 1 place clockwise', 0);
INSERT INTO 'dancecrib' VALUES (6589, '2013-08-21 08:31:27.407032+00', '2023-02-04 01:21:32.859409+00', 13866, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1M+2M Set+Link as 1L+2L reverse Set+Link & 1s
    remain facing out.  2 1 3
9-16::
    1s dance 1/2 reels of 3 on sides (2M+1M also 1L+3L pass RSh to
    start), 1M+2M also 3L+1L turn LH
17-24::
    1s dance 1/2 reels of 3 on sides. (3M+1M also 1L+2L pass RSh to
    start), 1M+3M also 2L+1L turn LH & 1s end BtoB facing 4th corners
25-32::
    1s dance Hello-Goodbye setting & end turning RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (9024, '2015-11-30 09:00:05.495622+00', '2023-02-04 01:21:32.892633+00', 10882, 3, NULL, 'ace', '{{explanation}}
Any number of couples in circle, Lady on Man''s right

1-8::
    All Advance 2 steps (no hands), clap & Retire.  Repeat & face
    partner
9-16::
    Men pass prtnr RSh, dance round prtnr and behind next Lady (on
    prtnr''s Right) passing LSh & back to place
17-24::
    Ladies repeat bars 9-16.  Finish facing partner
25-32::
    Grand Chain 1 bar to each hand (alternative: 2 bars to each hand) to
    meet new partner & form circle again', 0);
INSERT INTO 'dancecrib' VALUES (14294, '2021-09-08 00:21:01.06176+00', '2023-02-04 01:21:32.919408+00', 20353, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 on own side, dancing in/down to start
9-16::
    1s dance Inveran reels with 2s+3s (1s cross at top & bottom of
    reel). 1 2 3
17-24::
    1s lead down the middle & back up remaining in centre 1st place (2s
    step in behind 1s ready for …)
25-32::
    1s+2s dance Allemande.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9746, '2017-04-06 08:40:03.828403+00', '2023-02-04 01:21:33.10282+00', 15656, 3, NULL, 'ace', '1-8::
    1L sets to 3M, they change places RH, 1M sets to 3L, they change
    places LH
9-16::
    2L+3M also 2M+1L set and turn 2H. 2L+1M also 2M+3L set and turn BH
    3/4. 2s end BtoB on 1st diagonal
17-24::
    2s dance 1/2 diagonal Reel of 4, pass RSh to dance 1/2 diagonal Reel
    of 4 on 2nd diagonal. (All now back in original places)
25-32::
    1s 1/2 turn 2H, retain NHJ & dance down to 2nd place in middle (2s
    step up). 1s 1/2 turn 2H, cast out and down to 3rd place _while_ 3s
    step in and up.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6642, '2013-08-21 08:31:28.16424+00', '2023-02-04 01:21:36.978408+00', 7474, 3, NULL, 'ace', '1-8::
    1s dance in, cast to 2nd place & dance 1/2 Fig of 8 round 2s
9-16::
    1s+2s dance Ladies Chain
17-24::
    2s+1s set to other partner on sides, to own partner, 1s dance 1/2
    Fig of 8 round 2s
25-32::
    2s+1s dance RH across & LH back', 0);
INSERT INTO 'dancecrib' VALUES (4137, '2013-08-21 08:30:44.056924+00', '2023-02-04 01:18:36.429163+00', 355, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH & change places LH on sides with 2s/4s, repeat back
    to places
9-16::
    1s cross RH & dance reflection reels of 3 on opposite sides dancing
    outside 2s to start
17-24::
    1s pass RSh & cast to 2nd place own side to dance reels of 3 on own
    sides dancing down between 3s to start (1s end in 2nd place)
25-32::
    2s+1s+3s set, 2s set again as 1s cast 1 place & 3s lead up, 3s+1s+4s
    set, 3s set again as 1s cast & 4s lead up', 0);
INSERT INTO 'dancecrib' VALUES (9025, '2015-11-30 09:00:05.503781+00', '2023-02-04 01:21:33.132659+00', 16730, 3, NULL, 'ace', '{{explanation}}
2 chords - on second chord 3s & 4s cross to opposite side

1-4::
    1s+4s cross RH, 1s cast off, _while_ 4s cast up.
5-8::
    1s+4s turn RH 1.1/2 into prom hold. 1s facing 2M, 4s facing 3M.
9-16::
    1s+4s dance 1/2 RSh reel of 4 with their 1st corners. 1s and 4s pass
    LSh to their 2nd corners. 1s+4s dance 1/2 RSh reel of 4 with their
    2nd corners. 1s and 4s pass RSh to finish in prom hold.
::
    3L,4L,4M,2M
::
    3M,1M,1L,2L
17-24::
    4L+1M dance Fig 8 round 3s, _while_ 1L +4M dance Fig 8 round 2s.
25-32::
    1s+4s take prom hold. 1s and 4s pass LSh and dance 1/2 RSh diagonal
    reel with 1st corner position, pass LSh and dance 1/2 RSh diagonal
    reel with 2nd corner position to finish in prom hold.
::
    2L,1L,1M,3M
::
    2M,4M,4L,3L
33-40::
    All circle 8H round and back.

{{explanation}}
Note 1s & 4s have changed partners.', 0);
INSERT INTO 'dancecrib' VALUES (12929, '2020-07-01 00:20:47.498941+00', '2023-02-04 01:21:33.186254+00', 17600, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH across back to place
9-16::
    1s dance down middle & back, remaining in centre at top
17-24::
    1s cast (2s step up) & turn RH
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6591, '2013-08-21 08:31:27.425346+00', '2023-02-04 01:21:33.341641+00', 4803, 3, NULL, 'ace', '1-8::
    1s & 2s Petronella turn into centre & set, 3/4 turn partner RH &
    1s+2s dance 1/2 RH across (1s end in 2nd place own sides)
9-16::
    1s cross down RH through 3rd place to dance reel of 3 with 2s+3s on
    opp sides (2s+3s start passing RSh on Ladies'' side & LSh on Men''s
    side). 1s end facing 2nd crnrs
17-24::
    1s dance 1/2 diag reel of 4 with 2nd corners, turn LH for 1/2 LSh
    reel with 1st crnrs passing LSh to end BtoB in centre (1M face up 1L
    down)
25-32::
    1s circle 3H round to left (Man with 3s & Lady with 2s), 1s drop LH
    & open up to circle 6H round to left 1/2 way & all set', 0);
INSERT INTO 'dancecrib' VALUES (10339, '2017-12-22 15:44:47.888783+00', '2023-02-04 01:21:33.378208+00', 17711, 3, NULL, 'ace', '1-8::
    All set, 1/2 turn partner RH, pull back RSh (twirl), dance out to
    opp sides & chase 1/4 round clockwise to lines across (Men 3rd
    place, Ladies at top)
9-16::
    All set, 1/2 turn partner RH, pull back RSh (twirl), dance up/down
    to opp line & chase 1/4 round clockwise to opp sides (3)(2)(1)
17-20::
    3s+2s dance 1/2 RH across _while_ 1s 1/2 turn RH.  All set.  2 3 1
21-32::
    R&L for 3 couples.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6592, '2013-08-21 08:31:27.439123+00', '2023-02-04 01:21:33.558293+00', 4804, 3, NULL, 'ace', '1-8::
    1s+2s set twice, 1s+2s cross over Ladies under Men''s arch
9-16::
    1s+2s repeat above Fig
17-24::
    1s lead down the middle & back to top
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (6593, '2013-08-21 08:31:27.447303+00', '2023-02-04 01:21:33.575921+00', 4805, 3, NULL, 'ace', '1-8::
    1s set, 1L followed by partner casts 2 places, 1L crosses (below 3s)
    & casts up on Men''s side to 2nd place facing down _while_ 1M dances
    round 3L & up the middle to 2nd place Ladies'' side facing down
9-16::
    2s+1s+3s dance Grand Chain, end with 2M & 1M facing out
17-24::
    2s+1s dance Ladies'' Chain
25-32::
    2s+1s+3s Adv+Ret; 1s turn 1.1/2 RH to own sides.  213', 0);
INSERT INTO 'dancecrib' VALUES (6595, '2013-08-21 08:31:27.465328+00', '2023-02-04 01:21:33.618885+00', 4808, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 2s+1s+3s set & 1s set adv & turn right about
    to face out to own sides _while_ 2L & 3M petronella right into
    middle to diamond formation (2L in centre at top, 3M in centre at
    bottom) _while_ 2M & 3L cast into 2nd places to 1M facing 2M & 1L
    facing 3L in a line across
9-16::
    1s+2M+3L 1/2 reel of 4 across, 1s 3/4 turn LH to Lady facing up &
    Man down (M face M, L face L), 1s change pl RH with facing persons
    (2L & 3M)
17-24::
    2L+3M+1s 1/2 reel of 4, 2L+3M 3/4 turn LH to M face Ladies side (M
    facing M) & Lady face M side in line across & change place RH with
    facing prsns
25-32::
    2M+3L dance 1/2 reel of 4 across with 3M+2L to end Man facing Men''s
    side (M facing M), all set & 2s+3s 3/4 turn RH onto sides _while_ 1s
    set & turn right about to form a circle with 1s+2s+3s all facing
    clockwise
33-40::
    All chase clockwise (8 bars) after 4 bars 1s turn RH in centre to
    end on own sides 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11740, '2019-03-26 02:05:47.058594+00', '2023-02-04 01:21:33.676348+00', 19242, 3, NULL, 'ace', '1-8::
    1s set, turn RH to face down; 1s dance 1/2 mirror reels of 3 on own
    side (1s in/down to start)
9-12::
    1s take promenade hold & dance 1/2 reel of 3 across with 2s (in 3rd
    place), RSh to 2L to start.  3 1 (2)
13-16::
    1s dance 1/2 RH across with 3s (in top place) & all set (1) (3) (2)
17-20::
    All chase 1/2 round clockwise to own side.  End 2 3 1
21-24::
    2s+3s+1s turn partner RH, 2s end in 1st place own side _while_ 3s+1s
    remain in centre, joining 2H with partner ready for …
25-32::
    1s+3s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6597, '2013-08-21 08:31:27.490649+00', '2023-02-04 01:21:33.810994+00', 4813, 3, NULL, 'ace', '1‑8::
    1s+2s Adv+Ret (1 step), cross RH, 1s+2s turn LH on sides & 1s+2s
    cross RH back to own sides
9‑16::
    1s dance down middle for 2 bars, set, dance back up & cast to 2nd pl
    (2s step up)
17‑24::
    2s+1s face diagonally & set, circle 4H round to left & set to
    partners
25‑32::
    2s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (12174, '2019-09-04 22:16:04.440728+00', '2023-02-04 01:21:33.83703+00', 19567, 3, NULL, 'ace', '1-8::
    1s+2s dance Double Fig 8 (1s cross down, 2s cast up to start)
9-16::
    1s lead down the middle and back remaining in centre, 2s step in bar
    16 ready for …
17-24::
    1s+2s dance Allemande
25-32::
    1s+3s Set+Link; 3s+1s turn partners RH.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6598, '2013-08-21 08:31:27.498807+00', '2023-02-04 01:21:33.861037+00', 13214, 3, NULL, 'ace', '1-8::
    All dance 8H round to left for 3 bars, pivot left & chase back to
    places
9-16::
    1s+2s also 3s+4s dance LH across, then turning right about dance RH
    across & 1s end BtoB between 2s Man facing Lady
17-24::
    1s dance the Spurtle: 1s dance 1/2 reel of 4 with 2s & turn partner
    RH to face 3s, 1s dance 1/2 reel of 4 with 3s & turn partner RH to
    face 4s
25-32::
    1s dance 1/2 reel with 4s & turn RH to 4th place opposite sides, all
    set & cross RH 1s ending in 4th place', 0);
INSERT INTO 'dancecrib' VALUES (4089, '2013-08-21 08:30:43.319604+00', '2023-02-04 01:18:33.776212+00', 14348, 3, NULL, 'ace', '1-8::
    1s set & cross down to 2nd place, 1s cast down behind 3s & dance up
    for Double Triangles
9-16::
    1s dance Double Triangles & end facing 1st corners
17-24::
    1s turn 1st corners RH & pass RSh to face 2nd corners, 1s turn 2nd
    corners RH & pass RSh to 2nd place own sides facing out
25-32::
    1s dance reels of 3 on own sides (1M RSh to 2M & 1L RSh to 3L to
    start)', 0);
INSERT INTO 'dancecrib' VALUES (6599, '2013-08-21 08:31:27.506863+00', '2023-02-04 01:21:33.885315+00', 4818, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 3s
9-16::
    2s+1s+3s set, set advancing, turn to right to end BtoB with partner
    in centre & set, 2s & 3s return to own side _while_ 1s dance round
    each other to right to face 1st corners
17-24::
    1s dance 1/2 reel with 1st corners & 1/2 reel with 2nd corners to
    end in 2nd place opposite sides
25-32::
    3s+1s+2s turn RH & chase back to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6600, '2013-08-21 08:31:27.515009+00', '2023-02-04 01:21:33.913798+00', 11529, 3, NULL, 'ace', '1-8::
    1s & 3s cast 1 place & dance LH across 1.1/2 way to end facing
    corners (1M-5L, 1L-4M, 3M-4L, 3L-2M)
9-16::
    1s & 3s dance 1/2 diagonal reel of 4 with 1st corners, 1/2 diagonal
    reel with 2nd corners & end facing 3rd corner
17-24::
    1s & 3s dance 1/2 diagonal reel with 3rd corners ending on side (5 3
    4 1 2) & all set & cross RH
25-32::
    5s+3s also 4s+1s Set+Link & dance RH across
33-40::
    All dance 5 couple Set+Link twice (as 3 couple Set+Link but 2
    couples on left dance up/down _while_ others 3 cast & chase).  2 4 1
    5 3', 0);
INSERT INTO 'dancecrib' VALUES (12414, '2019-12-05 01:31:14.82794+00', '2023-02-04 01:21:34.137728+00', 4352, 3, NULL, 'ace', '1-8::
    1s cast (2s step up), 2s+1s+3s circle 6H round to right ending with
    1s facing 1st corners
9-16::
    1s set to 1st corner, turn partner RH to face 2nd corner; set to 2nd
    corner & cross RH with partner to 2nd place own side
17-24::
    2s+1s+3s dance RH across, LH across back to place
25-32::
    2s+1s+3s  Adv+Ret, turn partners RH once round.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9392, '2016-10-06 07:18:44.322817+00', '2023-02-04 01:21:34.155684+00', 17269, 3, NULL, 'ace', '1-8::
    All couples Adv+Ret, 1s+4s turn RH once round moving down/up to
    2nd/3rd places _while_ 2s+3s dance in & cast up/down to 1st/4th
    places
9-16::
    1s+4s Set & Rotate - Set, rotate singly & dance on 1 place
    clockwise, change places RH on sides & dance on 1 place to own sides
    2 4 1 3
17-24::
    All dance LSh reels of 4 on sides
25-32::
    2s+4s also 1s+3s circle 4H round and back', 0);
INSERT INTO 'dancecrib' VALUES (13276, '2020-10-16 00:21:14.410816+00', '2023-02-04 01:21:34.352206+00', 19769, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s cross, cast (2s step up) & dance 1/2 Fig 8 up round 2s
9-12::
    1s set advancing to 1st corner _while_ all corners set facing
    diagonally in, 1s turn 1st corners 2H to end 1L between 2s facing
    down, 1M between 3s facing up
13-16::
    1s set advancing to 2nd corner _while_ all corners set facing
    diagonally in, 1s turn 2nd corners 2H to end in 2nd place opp sides

{{title}}
Reel

1-8::
    1s cross passing RSh, cast below 3s, meet & dance up between 2s &
    cast to 2nd place own side
9-16::
    Mirror reels of 3 on sides (1s dance in/down, 3s out/up, 2s cast to
    start).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6602, '2013-08-21 08:31:27.53085+00', '2023-02-04 01:21:34.518947+00', 9766, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place,1s cross down between 3s & cast back to
    2nd place (opp side)
9-16::
    All Set+Link for 3 couples on sides to end 1M+2nd couple facing up
    as 1L+3rd couple face down, all set & cross RH with opposite dancer
17-24::
    All Set+Link for 3 couples, all set & cross RH with partner
25-32::
    All chase clockwise 1/2 way, circle 6H round to own sides & all set', 0);
INSERT INTO 'dancecrib' VALUES (11705, '2019-03-18 21:02:37.312719+00', '2023-02-04 01:21:34.562552+00', 19186, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 2s+1s+3s turn RH remaining in centre
    facing up in allemande hold
9-16::
    2s+1s+3s dance Allemande
17-24::
    3s+1s+2s dance Set & Rotate
25-32::
    2s+1s+3s circle 6H round & back

{{explanation}}
Note:  Can be danced as a strathspey, a reel or a medley of 32S+32R', 0);
INSERT INTO 'dancecrib' VALUES (12930, '2020-07-01 00:20:48.566197+00', '2023-02-04 01:21:34.586979+00', 4828, 3, NULL, 'ace', '1-8::
    Reels of 4 on sides, Ladies LSh, Men RSh.  Finish reels forming a
    circle
9-12::
    All join hands in circle & set, 1M, 3M, 2L & 4L petronella turn
    right into next but 1 place in circle
13-16::
    All join hands in circle & set, 2M, 4M, 1L & 3L petronella turn left
    into next but 1 place in circle
17-20::
    2s+3s set & change places RH with partner ending in 1st/4th places
    _while_ 4M+1M & 4L+1L change places RH & set.  2 1 4 3
21-24::
    All set, turn partner RH, 2s to 1st place on sides, 1s+4s+3s in
    middle facing up ready for…
25-32::
    1s+4s+3s dance allemande. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9026, '2015-11-30 09:00:05.673521+00', '2023-02-04 01:21:34.617425+00', 16104, 3, NULL, 'ace', '1-8::
    1s set twice, dance down middle, cast up round 3s into 2nd place own
    sides (2s step up 7-8)
9-16::
    1s set twice to 1st corners, turn corners RH back to places
17-24::
    1s set twice to 2nd corners, turn corners LH.  1s finish in 2nd
    place, own side, facing out
25-32::
    Reels of 3 on sides (1M+3M & 1L+2L pass LSh to start)  1s pass LSh
    in middle & pulling back RSh, 1s curve into 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (6604, '2013-08-21 08:31:27.548734+00', '2023-02-04 01:21:34.712818+00', 4830, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place, cross RH & cast up to partners place
9-16::
    1s+2s dance R&L
17-24::
    2L+1M followed by 1L+2M lead down middle, (2M casts to partner as 1M
    dances up) 1s followed by 2s lead back to original places
25-32::
    1s+2s dance Tournee :
::
    1s+2s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 2s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (2s RH, 1s LH) & dance
    out to places', 0);
INSERT INTO 'dancecrib' VALUES (6605, '2013-08-21 08:31:27.559178+00', '2023-02-04 01:21:34.755818+00', 4121, 3, NULL, 'ace', '1‑8::
    1s & 3s turn RH, cast 1 place & turn LH to face 1st crnrs
9‑24::
    1s & 3s dance Corner Chain with 1st & 2nd corners :
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end turning LH back to places
25‑32::
    1L & 3L cast up 1 place _while_ 1M & 3M cast down 1 place, 1s & 3s
    turn RH & cast 1 place.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (12931, '2020-07-01 00:20:48.712299+00', '2023-02-04 01:21:34.781848+00', 4834, 3, NULL, 'ace', '1-8::
    All petronella turn into line up/down middle & set; All turn
    partners 1.1/4 RH back to place
9-16::
    All set, cross RH; All set, 1s+2s 1/2 turn RH into allemande hold
    facing up _while_ 3s+4s cross RH to own side
17-24::
    1s+2s dance 6 bars of allemande, 1s drop LH & lead down crossing to
    4th place (face out) _while_ 2s drop RH & turn partner LH to 1st
    place facing out (3s+4s step up 23-24).  2 3 4 (1)
25-26::
    1s/2s cast up/down 1 place, Men passing Lady they meet LH & dance in
    between 3s & 4s to meet partner
27-28::
    1s/2s lead up/down & cross to 1st/4th place
29-32::
    1s+2s repeat 25-28 from new places. End 1s in 4th place opp sides
    facing out, 2s in 1st place own side facing in
33-36::
    2s+3s (top 2 couples) dance RH across
::
    _while_ 4s turn partner 1/2 RH moving down to 4th place as 1s cast
    up to 3rd place opp sides, 1s+4s dance 1/2 RH across
37-40::
    2s+3s & 4s+1s dance LH across
41-48::
    2s+3s+4s+1s circle 8H round & back.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4139, '2013-08-21 08:30:44.076907+00', '2023-02-04 01:18:36.482839+00', 11259, 3, NULL, 'ace', '1-4::
    1M dances 1/2 reel of 3 with 2s (LSh to 2L)
5-8::
    1M dances 1/2 reel with 3s (RSh to 3M) _while_ 1L dances 1/2 reel of
    3 with 2s (RSh to 2L on opp side) Finish1L facing down behind 1M in
    middle. 2s finish in 1st place
9-16::
    1s 1/2 Tandem reel of 3 with 3s (LSh to 3M), 1M followed by prtnr
    dances out b''tw''n 2M+3M, up round 2M to end 1st pl opp sides (2s
    step down 15-16).
17-24::
    1s cross RH, cast 1 place to face 1st corners, dance 1/2 diagonal
    reel of 4 with 1st corners & end facing 2nd corners.
25-32::
    1s dance 1/2 reel with 2nd corners & turn 1.1/2 RH to 2nd places
    _while_ corners chase clockwise 1/2 way.   End 2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (6606, '2013-08-21 08:31:27.567256+00', '2023-02-04 01:21:34.812712+00', 4835, 3, NULL, 'ace', '1-8::
    1s+4s dance RH across, dance out to ends & stand for 2 _while_ 2s &
    4s step up/down & stand for 2 then dance LH across
9-16::
    All dance RSh reels of 4 on sides
17-24::
    All set, Adv+Ret for 2 steps & set
25-32::
    1s lead down & cross RH below 2s, cast down behind 3s+4s & turn RH
    1.1/2 times
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12872, '2020-06-03 16:27:14.840501+00', '2023-02-04 01:21:34.83724+00', 13922, 3, NULL, 'ace', '1-8::
    2s cross down & cast up to 2nd place opp sides; 2s cross up RH to
    1st place own side facing out (1s step down), 2s+1s turn on side
    (Men LH, Ladies RH). 2s face out
9-16::
    2s+1s+3s dance mirror reels of 3 on sides (1s cross down RH to
    start), Bars 13-14: 1s cross up RH to continue reel on own side
17-24::
    All set, petronella in tandem into lines across; all set &
    petronella in tandem to opp sides. (3) (1) (2)
25-32::
    3s+1s+2s turn partner RH once round, chase clockwise 1/2 round to
    own sides & all set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9767, '2017-04-06 09:57:42.358797+00', '2023-02-04 01:21:34.869604+00', 17651, 3, NULL, 'ace', '{{explanation}}
5s in centre Left shoulder to Left shoulder, 5M facing 2s & 5L facing 4s

1-4::
    5M+2s & 5L+4s circle 3H round to Left.  End 5M facing 1s & 5L facing
    3s, 1s & 3s take prom hold
5-8::
    5s+1s+3s dance 1/2 RSh reel of 4.  5s pass LSh to face 2s & 4s
9-12::
    Repeat bars 1-4, 5M with 4s & 5L with 2s.  End 5M facing 1s (in 3rd
    place) 5L facing 3s
13-16::
    Repeat bars 5-8.  End 5s facing partner, 5M with back to 4s & 5L
    with back to 2s
17-24::
    5s set, 1/2 turn 2H, pull back RSh & dance RH across, 5M+2s & 5L+
    4s.  End 5s facing partner
25-28::
    5s set, 3/4 turn 2H to face 1st place _while_ 1s+2s+3s+4s set, pull
    back RSh & chase clockwise one place round
29-32::
    5s+4s dance 1/2 R&L. Bars 31-32 4s (in centre) turn 3/4 LH to face
    side couples (4M facing 2nd place, 4L facing 4th place)', 0);
INSERT INTO 'dancecrib' VALUES (6607, '2013-08-21 08:31:27.575353+00', '2023-02-04 01:21:34.899468+00', 4840, 3, NULL, 'ace', '1-8::
    1s cast 1 place (2s up) & cross down between 3s, cast up to top to
    meet partner in prom hold facing down
9-16::
    1s dance reel of 3 with 2s (RSh to 2M)
17-24::
    1s dance reflection reels of 3 on opposite sides (1s dance cross
    down & out round 3s to start) & end in 2nd place opposite sides
25-32::
    1s+3s circle 4H round to left, 1s set & cross RH

{{title}}
Popular variation

25-32::
    1s turn 3s (with nearer hand -1s dancing out) & dance 1/2 Fig of 8
    round 3s (1s cast) to end 2nd place facing out', 0);
INSERT INTO 'dancecrib' VALUES (10449, '2018-02-24 07:53:02.511864+00', '2023-02-04 01:21:34.945634+00', 13299, 3, NULL, 'ace', '1-8::
    1s cross, cast (2s step up) & 1s dance 1/2 Fig of 8 round 2s
9-16::
    2s+1s+3s dance the Knot for 3 couples 3 1 2
17-24::
    3s+1s+2s Set & Rotate
25-32::
    2s+1s+3s circle 6H round and back.', 0);
INSERT INTO 'dancecrib' VALUES (6609, '2013-08-21 08:31:27.591423+00', '2023-02-04 01:21:34.976428+00', 4844, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place & turn partner LH to Bal-in-Line position
    with 1st corners
9-16::
    1s Bal-in-Line with 1st corners then face 1st corners & set, 1s turn
    to right again & Bal-in-Line with corners then turn ptnr RH to face
    2nd crnrs
17-24::
    1s Bal-in-Line with 2nd corners then face 2nd corners & set, 1s turn
    to left again & Bal-in-Line with corners then turn prtnr LH to end
    1L facing 2s, 1M facing 3s
25-32::
    1s dance RH across (1L with 2s & 1M with 3s), 1s change places
    passing RSh & dance LH across with other couple.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6610, '2013-08-21 08:31:27.599547+00', '2023-02-04 01:21:35.008019+00', 4845, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    2s & 3s dance out ends & cast back to places, dance out other end
    after passing other partner LH, cross & cast to 1 3 (2)(4)
9-16::
    All set, 1s & 4s cross down/up _while_ 2s & 3s cast to ends, 1s & 4s
    cast round ends & dance in crossing into a line across with Men BtoB
    facing other partner
17-24::
    1s+4s dance reel of 4 across
25-32::
    1s+4s set to other partners, Men turn right to face each other in
    middle of dance _while_ partners set, circle 4H 3/4 round to left to
    end 1s in 2nd place & 4s in 3rd place.  3 1 (4)(2)', 0);
INSERT INTO 'dancecrib' VALUES (6611, '2013-08-21 08:31:27.737215+00', '2023-02-04 01:21:35.122138+00', 9560, 3, NULL, 'ace', '1-8::
    1s & 3s dance Figs of 8 round couples below them _while_ 2s & 4s
    set, cross RH, set & cross back RH
9-16::
    3s followed by 1s dance down for 2 steps, set to partner, 1s
    followed by 3s dance up & 1s cast to 3rd place & 3s end at top
17-24::
    3s+2s also 1s+4s dance R&L all ending in middle
25-32::
    3s+2s also 1s+4s dance Poussette.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9483, '2016-11-09 08:48:49.223148+00', '2023-02-04 01:21:35.149668+00', 17403, 3, NULL, 'ace', '1-8::
    1s+2s dance "Espagnole". 1s end facing 1st corners
9-14::
    Dance to Corners & Set: (6 bars):
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 2 more times to end
    with corners in diagonally opposite place and 1s meet again in the
    middle.
15-16::
    1s turn RH to face 3rd corner position _while_ others set
17-22::
    Repeat bars 9-14 of Dance to Corners & Set:
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 2 more times to end
    with corners in diagonally opposite place and 1s meet again in the
    middle.
23-24::
    1s turn 1.1/4 RH to face 4th corner position _while_ others set
25-32::
    _1/2_ reels of 3 across (1L RSh to 3M at top, 1M RSh to 2L).  1/2
    reels of 3 on sides (1L down RSh to 2L, 1M up RSh to 3M)  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14559, '2022-01-21 21:51:07.926554+00', '2022-01-22 19:51:26.889882+00', 20634, 1, 1645, 'ace', '1--::
  1c+2c Circle4 to L & back
9--::
  3c+4c Circle4 to L & back
17--::
  5c dance up to the top ; cast off back to 5pl
25--::
  1c &frac12; turn 2c RH on sides | &frac12; turn 3c LH ; 4c RH | 5c LH (2,3,4,5,1)
::
  *NB crib derived from the video*
', 0);
INSERT INTO 'dancecrib' VALUES (14671, '2022-03-07 02:20:58.827235+00', '2023-02-04 01:21:35.171777+00', 16607, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s
9-16::
    1s cross down to dance reels of 3 on opposite sides (2s out/up, 3s
    in/up)
17-24::
    1s take Promenade hold to dance RSh reel of 3 with 2s across the
    dance (1s give RSh to 2M to start)
25-32::
    1s in Promenade hold, dance down the middle of the set, drop RH,
    cross LH below 3s, cast up round 3s to meet in middle. 1s dance up,
    cast round 2s to 2nd place own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11206, '2018-09-30 22:20:16.751651+00', '2023-02-04 01:21:35.205143+00', 18655, 3, NULL, 'ace', '1-8::
    1s dance in & cast (2s step up). 2s+1s+3s set & cross RH
9-16::
    2s+1s+3s circle 6H 1/2 round to Left.  1s 1/2 turn RH, face each
    other, pull back RSh & dance out to 2nd place opp sides
17-24::
    3s+1s+2s modified ''Set & Rotate''
::
    _17-20_    3s+2s+1s Set & Rotate singly & chase clockwise to form
    lines of 3 across
::
    _21-24_    All change places RH with partner & 2s+3s chase clockwise
    to own sides _while_ 1s cast to Left  to end 2 1 3 (3s face up)
25-32::
    1s+3s turn on sides (1L LH, 1M RH), 3s dance up to 2nd place _while_
    1s cross down
::
    1s+4s turn on sides (1M LH, 1L RH), 4s dance up to 3rd place _while_
    1s cross down to 4th place own side.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5838, '2013-08-21 08:31:15.071756+00', '2023-02-04 01:21:35.234072+00', 3235, 3, NULL, 'ace', '1-8::
    1M+2L turn RH 1.1/2 times, 1L+2M turn RH 1.1/2 times
9-16::
    1s & 2s repeat above Fig
17-24::
    1s lead down, back to 2nd places & turn LH
25-32::
    2s+1s R&L', 0);
INSERT INTO 'dancecrib' VALUES (6612, '2013-08-21 08:31:27.753106+00', '2023-02-04 01:21:35.2606+00', 7472, 3, NULL, 'ace', '1-8::
    1s set, cast 2 places & dance up to face own side BtoB for Double
    Triangles
9-16::
    2s+1s+3s dance Double Triangles
17-24::
    1s dance out between 2s & 3s on own side & cast round to right &
    face 1st corners, set to 1st corners & set to 2nd corners
25-32::
    1s dance reels of 3 on opposite sides (RSh to 2nd corners) & cross
    to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (6613, '2013-08-21 08:31:27.76484+00', '2023-02-04 01:21:35.280991+00', 12927, 3, NULL, 'ace', '1-8::
    1s+2s 3/4 turn 2H & dance 1/2 reel of 4 in middle, 1/2 turn 2H &
    face opposite sides (3s dance in on bar 8)
9-16::
    2s+1s+3s balance (strathspey setting) & 1/2 turn RH, balance & dance
    out to sides.  2 1 3
17-24::
    1s dance Fig of 8 own sides (round person on right to start)
25-32::
    1s dance LSh Pass+Turn with 1st corners & pass LSh to face 2nd
    corners, dance LSh Pass+Turn with 2nd corners ending 2nd place own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (10528, '2018-03-20 06:27:05.340881+00', '2023-02-04 01:21:35.303751+00', 17442, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All Adv+Ret & turn partners RH
17-24::
    1s lead down (4) & back up to place & face out
25-32::
    1s dance behind 2s, in front of 3s & behind 4s; 1s turn RH (2s+3s+4s
    step up 31-32)', 0);
INSERT INTO 'dancecrib' VALUES (6614, '2013-08-21 08:31:27.773147+00', '2023-02-04 01:21:35.327924+00', 4857, 3, NULL, 'ace', '1-8::
    1s+2s dance the Bourrel & end facing up for Allemande :  -
::
    1M+2L set advancing, 3/4 turn 2H & twirl to end BtoB (Lady facing up
    & Man down) _while_ partners chase anticlockwise 1/2 way
::
    set & turn RH to face up for Allemande
9-16::
    2s+1s dance Allemande (5 bars) & dance into middle M turning
    partners under their right arms to face up, 1s cast & 2s lead up
17-24::
    2s+1s+3s Adv+Ret 1 step, cross RH, 1s+3s circle 4H round to left
25-32::
    2s+1s+3s Adv+Ret 1 step, cross LH, 2s+1s circle 4H round to right', 0);
INSERT INTO 'dancecrib' VALUES (15234, '2022-11-03 01:21:01.183315+00', '2023-02-04 01:21:35.357741+00', 20225, 3, NULL, 'ace', '1-8::
    1L+3M set, cross RH & chase clockwise back to place
9-16::
    1M+3L set, cross LH & chase anticlockwise back to place
17-24::
    1s+2s+3s dance mirror reels of 3 on sides (1s out/down, 2s in/up, 3s
    out/up)
25-32::
    1s followed by 2s (who dance up to start) lead down; turn inwards &
    2s followed by 1s lead up.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15074, '2022-09-05 00:21:05.765229+00', '2023-02-04 01:21:35.387397+00', 18208, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH & cast in 1 place (2s & 3s step up/down); 2s+1s
    also 4s+3s dance RH across ending 1L followed by 1M facing 2M at
    top, 4M followed by 4L facing 3L at bottom
9-16::
    1s & 4s dance ''Alternating Tandem Corners Pass & Turn'':
::
    _9-12_   1s & 4s in tandem pass corners RSh, change lead & dance in
    passing other couple RSh, 1s to face 3M (1M leading) & 4s to face 2L
    (4L leading) _while_ corners turn RH return to place
::
    _13-16_  Repeat with »2nd corners«. 1s & 4s end in centre in 2nd/3rd
    place,1s facing down, 4s facing up, (Lady on partner''s right)  2 1 4
    3
17-24::
    1s+4s dance RH across, 1s face up, 4s face down; 1s & 4s dance out
    of ends, separate & cast down/up to 2nd/3rd place own side. 2 1 4 3
25-32::
    1s+4s dance ''Chain Progression'':
::
    1s+4s 3/4 turn RH, 1M+4L turn LH 1.1/2 times _while_ partners chase
    cl''wise 1/2 way, 4s+1s turn prtnrs RH, 4s end in 2nd & 1s in 3rd
    place. 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6616, '2013-08-21 08:31:27.789407+00', '2023-02-04 01:21:35.44305+00', 9011, 3, NULL, 'ace', '1-8::
    1L+2M advance for 1 step, turn individually to right, cast round
    2L/1M & turn RH 1.1/4 times to end in each others place
9-16::
    1M+2L repeat bars 1- 8 but turn to left & turn LH
17-24::
    2s+1s set, advance passing partner RSh & turn individually to right
    to face each other, continue turn & dance out to own side, 2s+1s set
25-32::
    2s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6617, '2013-08-21 08:31:27.79918+00', '2023-02-04 01:21:35.533513+00', 4862, 3, NULL, 'ace', '{{explanation}}
1s start on opp sides

1-8::
    1s+2s set on sides, change places RH, set to partner & cross RH
9-16::
    2s+1s repeat above Fig
17-24::
    1s+2s circle 4H round to left twice
25-32::
    1s+2s dance Poussette (1s end on opposite sides to repeat dance but
    cross to own sides at end of 3rd dance)', 0);
INSERT INTO 'dancecrib' VALUES (8612, '2015-02-13 12:48:04.575533+00', '2023-02-04 01:21:35.559797+00', 4863, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret, dance 1/2 R&L
9-16::
    1s+2s set, 1s cast up, cross RH _while_ 2s turn RH moving down to
    2nd place opp. sides, 1s+2s set  1 (2)
17-24::
    1s dance in, turn away & cast 1 place (4 bars), turn RH once round,
    cast back to 1st place
25-32::
    1s dance 1/2 Fig. 8 round 2s, 1s+2s dance 1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (6618, '2013-08-21 08:31:27.808876+00', '2023-02-04 01:21:35.825109+00', 4864, 3, NULL, 'ace', '1-8::
    1s dance parallel RSh reels of 3 on own sides
9-16::
    1s set, cast 1 place & dance 1/2 Figs of 8 round 2s
17-24::
    2s+1s+3s Adv+Ret & turn 2H (1s 1/2 or 1.1/2 times to end BtoB facing
    own sides)
25-32::
    1s dance Double Triangles with 2s+3s', 0);
INSERT INTO 'dancecrib' VALUES (6619, '2013-08-21 08:31:27.816863+00', '2023-02-04 01:21:35.83974+00', 4865, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L dance across, cast down behind Men & dance up
    own side to places
9-16::
    Men repeat above Fig (Bars 1- 8)
17-24::
    1s+2s Promenade
25-32::
    1s+3s dance Diamond Poussette 1s ending in 2nd place (2s step up
    25-26)', 0);
INSERT INTO 'dancecrib' VALUES (6620, '2013-08-21 08:31:27.834289+00', '2023-02-04 01:21:35.861255+00', 4871, 3, NULL, 'ace', '1-8::
    1s set, cast to 2nd place & turn RH 1.1/2 times to end in centre Man
    facing down Lady up
9-16::
    1s dance LH across with 2s/3s, pass LSh & dance RH across on own
    sides, 1s pass RSh to end in centre facing out on opposite sides
17-24::
    1s join hands with corners & set, dance reels of 3 on sides giving
    RSh to 1st corners, 1s pass LSh to end facing own sides
25-32::
    1s repeat 17-24 on own sides', 0);
INSERT INTO 'dancecrib' VALUES (8613, '2015-02-13 12:48:04.615986+00', '2023-02-04 01:21:35.883803+00', 4873, 3, NULL, 'ace', '1-8::
    1M+2L set advancing, turn RH to places. 1L+2M set advancing, 1/4
    turn RH, 1L casts up round 1M, 2M casts down round 2L
9-16::
    1L + 2M continue to dance clockwise followed by partners (turn R
    about to follow), all finish on opp. sides, 1s+2s turn RH 1.1/2 to
    own sides
17-24::
    2s+3s set advancing, turn RH back to places. 1s set advancing, turn
    RH to 1M facing up/1L facing down
25-32::
    1M dances up, casts round 2M, 1L dances down, casts up round 3L.  1s
    turn LH to 2nd place own sides _while_ 2M+3M also 2L+3L turn RH  2 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (4090, '2013-08-21 08:30:43.32943+00', '2023-02-04 01:18:33.809357+00', 9138, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across once round, 1s cast to 2nd place as 2s
    dance up
9-16::
    1s dance reflection reel of 3 on own sides (down between 3s to
    start)
17-24::
    1s dance 1/2 Figs of 8 (1M up with 2s & 1L down with 3s), 2s+1s+3s
    chase clockwise 1/2 way
25-32::
    1s dance diag R&L (1M crossing down & 1L crossing up to start)', 0);
INSERT INTO 'dancecrib' VALUES (13911, '2021-04-05 00:21:03.660239+00', '2023-02-04 01:21:35.915516+00', 19482, 3, NULL, 'ace', '1-8::
    1s+2s set, dance in touching nearer hands & cast (1s follow 2s);
    2s+1s dance up between 3s to end 2s at top facing out, 1s in 2nd
    place
9-16::
    1s+2s dance Double Fig 8 (2s cast, 1s cross up to start).  1s face
    out
17-24::
    2s+1s+3s dance mirror reels of 3 on sides (1s in/down to start)
25-32::
    1L+2s & 1M+3s dance RH across; 1s pass RSh to dance LH across with
    other couple.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6621, '2013-08-21 08:31:27.842312+00', '2023-02-04 01:21:35.955006+00', 4875, 3, NULL, 'ace', '1-8::
    1s dance mirror Figs of 8 on own sides round standing 2s & 3s,
    dancing in/down to start
9-16::
    1s cross down & dance mirror reels of 3 on opp sides
17-24::
    1s cross RH & cast to 2nd place, cross down between 3s & cast up to
    2nd place opposite sides
25-32::
    2s+1s+3s Adv+Ret, 1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (9217, '2016-06-16 22:42:08.525434+00', '2023-02-04 01:21:35.986985+00', 16837, 3, NULL, 'ace', '1-4::
    1s turn RH & cast off.
5-8::
    1s cross RH & cast to right round 1st corner _while_ 2s+3s turn
    partner RH.  Finish in lines of 3 across the dance 1L between 2s, 1M
    between 3s
9-16::
    All Set+Link for 3 twice.
17-24::
    All set, circle 6 hands round to left (4 bars), corners chase to
    finish 2 ladies at top, 2 men at bottom _while_ 1s dance closely RSh
    round each other to face 2nd corner position.
25-32::
    All dance ''Star Chain'':
::
    _25_       1M+3L and 1L+2M change RH
::
    _26_       3L+2M turn 3/4 LH _while_ 1s dance out to sides
::
    _27_       2s and 3s change places RH
::
    _28_       2L+3M turn 3/4 LH _while_ 2M and 3L dance out to sides
::
    _29_       1M+2L and 1L+3M change places RH
::
    _30_       1s turn 3/4 LH _while_ 2L and 3M dance out to sides
::
    _31-32_  1s turn LH to finish on own sides in 2nd place.', 0);
INSERT INTO 'dancecrib' VALUES (14007, '2021-05-03 00:20:56.145722+00', '2023-02-04 01:21:36.020125+00', 19194, 3, NULL, 'ace', '1-8::
    1s dance down between 3s (2s step up), turn inwards (PdeB) & face
    up; 1s turn 3s NH & 1/2 turn 2s with other hand. 1 2 3
9-16::
    1s+2s+3s dance Inveran reels of 3 on the sides (1s crossing down to
    start and crossing back to own side) to finish 1 2 3
17-24::
    1s cross RH (2s step up 19-20), cast below 3s, meet & dance up to
    face 1st corners
25-32::
    1s+1st corners dance 1/2 diag reel of 4, pass LSh; 1s+2nd corners
    dance 1/2 diag reel of 4, to finish (3) (1) (2).
33-40::
    3s+1s+2s Set+Link for 3 twice. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6622, '2013-08-21 08:31:27.852104+00', '2023-02-04 01:21:36.047951+00', 4878, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, passing partner LSh dance RSh round 1st
    corner to end facing 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting end setting to partner & face 3rd
    corner (pstn) _while_ 2s+3s set & cross RH, set & change places RH
    on sides
17-24::
    1s turn 3rd corners RH, pass RSh & turn 4th corner (pstn) RH, pass
    RSh to 2nd place opposite sides
25-32::
    3s+1s+2s Adv+Ret & turn partners RH ready for…
33-40::
    3s+1s+2s dance the Knot.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6623, '2013-08-21 08:31:27.860219+00', '2023-02-04 01:21:36.075486+00', 4879, 3, NULL, 'ace', '1-8::
    1s cast 1 place to face 1st corners, turn corners RH into line
    up/down middle (1s BtoB with 1L facing up, 1M facing down)
9-16::
    1s+1st corners dance reel of 4 up/down middle, corners ending in
    original places, 1s BtoB 1L facing up & 1M facing down
17-24::
    1s dance RSh round 4th corners & in (1s pass RSh) to face own 2nd
    corner, turn corners RH into line across in 2nd place (1s BtoB
    facing opp sides)
25-32::
    1s+2nd corners dance reel of 4 across, corners ending in original
    places & 1s dancing RSh round each other to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (9922, '2017-06-05 11:31:32.712876+00', '2023-02-04 01:21:36.198021+00', 4884, 3, NULL, 'ace', '1-8::
    2s followed by 1s dance down below 4s, cast up, meet & dance up
    middle, casting to original places
9-16::
    3s followed by 4s dance up above 1s, cast, meet & & dance down
    middle, casting up to original places
17-24::
    1s+2s also 3s+4s Set & Rotate to end 2 1 4 3 with 1M & 4L facing out
25-26::
    1s+4s dance 1/2 LH across   2 (4) (1) 3 with 1M & 4L facing out
27-32::
    4s & 1s pass "corner" (dancer on Right) by RSh then 4M followed by
    4L dances behind 2L (at top) & across to 2nd place own side _while_
    1L followed by 1M dances behind 3M (at bottom) & across to 3rd place
    own side.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6626, '2013-08-21 08:31:27.904183+00', '2023-02-04 01:21:36.216473+00', 10535, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, turn LH 1.1/4 times to end in Bal-in-Line
    position between 1st corners
9-16::
    1s+1st corners Bal-in-Line & turn corners RH (4 bars) to Bal-in-Line
    again with 1st corners
17-24::
    1s dance reel of 3 on sides (LSh to 2nd corner) & end diagonally
    between 2nd corners
25-32::
    1s+2nd corners Bal-in-Line & turn corners RH (4 bars), Bal-in-Line
    again with 2nd corners
33-40::
    1s dance reels of 3 across (LSh to 3rd corners) & cross RH to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (9218, '2016-06-16 22:42:08.592523+00', '2023-02-04 01:21:36.242346+00', 16829, 3, NULL, 'ace', '1-8::
    1s dance reflection reels on own sides (down between 2s to start)
9-16::
    1L+2M pass LSh & dance round partner RSh to places, 1s+2s dance RH
    across
17-24::
    1M+2L pass RSh & dance round partner LSh to places, 1s+2s dance LH
    across ending in middle for…
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12932, '2020-07-01 00:20:49.815553+00', '2023-02-04 01:21:36.266819+00', 17601, 3, NULL, 'ace', '1-8::
    1s lead down & back to top & face out
9-16::
    1s+2s dance double Fig 8, 1s cast, 2s cross up to start
17-24::
    2s dance reels of 3 on opp sides, 1s cast, 2s cross up, 3s dance
    out/up to start.  End 1s facing out.  1 (2) 3
25-32::
    1s cast to 2nd place _while_ 2s lead up & cross to own side 1st
    place, 1s NHJ dance down between 3s, cast up to 2nd place, 2s+1s+3s
    set', 0);
INSERT INTO 'dancecrib' VALUES (6627, '2013-08-21 08:31:27.937194+00', '2023-02-04 01:21:36.293633+00', 4888, 3, NULL, 'ace', '1-8::
    1s+2M dance reel of 3 across (1s pass LSh & 2M dances up to start).
    2M finishes in place facing out
9-16::
    1M+2L cross RH but 2L goes to 2M place as 2M casts to top, 1s+2s set
    diagonally, advance & Men join hands as Ladies joins hands under
    them, 1s+2s set & Men raise hands & lower them behind Ladies & on
    last bar Ladies drop hands & place them behind Men
17-24::
    1s+2s circle to left 2.1/4 times gradually expanding to normal
    circle & end with 2s in top place on opposite sides & 1s in 2nd
    place on own side
25-32::
    2s dance 1/2 Fig of 8 around 1s & 2s+1s turn LH', 0);
INSERT INTO 'dancecrib' VALUES (4091, '2013-08-21 08:30:43.442656+00', '2023-02-04 01:18:33.843516+00', 282, 3, NULL, 'ace', '1-8::
    1s dance reflection (mirror) reels on own sides (1s in & down).  1s
    & 3s finish in centre facing down/up
9-16::
    1s & 3s Adv+Ret down/up finishing on sidelines, 1s & 3s dance DoSiDo
    with partners
17-24::
    1s+2s Set+Link, 1s+3s Set+Link (Set+Link using 8 pas de basque
    steps)
25-32::
    2s+3s+1s circle 6H round & back  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (10450, '2018-02-24 07:53:02.96152+00', '2023-02-04 01:21:36.318728+00', 18090, 3, NULL, 'ace', '{{explanation}}
Circle, Man has Lady on his right

1-8::
    All dance interlocking reels of four, turning RH at end to finish
    facing partner
9-16::
    All set, 3/4 turn partner RH, all set, change places RH with partner
    to finish Men on inside of circle, Ladies on outside
17-24::
    Men dance out passing partner RSh, behind partner, in & LSh all
    round next Lady round circle, & dance back to place
25-32::
    Ladies dance in passing partner RSh, behind partner, out & LSh all
    round next Man round circle, & dance back to place
33-40::
    All set, Petronella turn to reform circle, set, & change places LH
    to face new partner

{{explanation}}
Repeat from new places', 0);
INSERT INTO 'dancecrib' VALUES (13626, '2021-02-04 01:21:02.242861+00', '2023-02-04 01:21:36.340624+00', 18837, 3, NULL, 'ace', '1-8::
    1L+2L turn 1.1/2 RH on sides, then 1L+3L turn 1.1/2 LH _while_
    1M+2M+3M dance reel of 3 on the side (1M+2M pass RSh to start)
::
    (Ladies: order 2 3, 1 and Men 1 2 3)
9-16::
    All couples dance 3 couple Bourrel:
::
    _9-12_     1M+3L also 2M+1L set advcg & 3/4 turn 2H to line up/down
    middle then pull back RSh turning to face own prtnrs as 3M & 2L
    chase anticl''wise to face them
::
    _13-16_     All set & turn 2H into promenade hold facing up  3 1 2
17-24::
    All dance 3 couple Allemande, 1s end facing 1st corners
25-32::
    1s turn corner RH, partner LH, 2nd corner RH,  cross LH with partner
    to end in 2nd place own sides 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6628, '2013-08-21 08:31:27.945456+00', '2023-02-04 01:21:36.359647+00', 4890, 3, NULL, 'ace', '1-8::
    All set & turn partners 2H twice & set again
9-16::
    All dance Grand Chain
17-24::
    1s dance down between 2s, cast behind 3s, dance up between 3s, cast
    up behind 2s.  1s+2s end ready for a 1/2 Diamond Poussette
25-32::
    1s+2s dance 1/2 Diamond Poussette,  3s dance in on bar 28 & 1s+3s
    dance 1/2 Diamond Poussette 1s ending in 3rd place. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6630, '2013-08-21 08:31:27.974157+00', '2023-02-04 01:21:36.424456+00', 4896, 3, NULL, 'ace', '{{explanation}}
2 couples facing 2 couples - Men at corners & Ladies between

1-8::
    All set & turn partners RH, Ladies dance LH across _while_ Men chase
    clockwise 1/2 way
9-16::
    All turn ''new'' partner RH 1.1/2 times to end with Men in inside
    pstns, Men dance LH across _while_ Ladies chase clockwise 1/2 way &
    end with Men in centre BtoB facing partner
17-24::
    Ladies dance R&L _while_ Men dance rocking step 4 times & Men move
    on last bar to take partner in Allemande hold
25-32::
    All dance anticlockwise 1.1/2 times round set & turn Ladies LH into
    centre BtoB with Men in corners facing partner
33-40::
    Men dance R&L _while_ Ladies dance Glasgow Highlanders step & turn
    inwards
41-48::
    Ladies circle 4H round 1/2 way _while_ Men cast into centre & circle
    4H round 1/2 way _while_ Ladies cast into centre
49-56::
    Repeat bars 41-48 to end with Men BtoB facing Ladies
57-64::
    All dance double diagonal reels of 4 ending with Men between Ladies', 0);
INSERT INTO 'dancecrib' VALUES (8379, '2014-07-31 07:49:18.810043+00', '2023-02-04 01:21:36.692389+00', 12448, 3, NULL, 'ace', '1-8::
    1s turn R hand & cast off (2s step up on 3-4) 1s turn L hand, retain
    L hands & take R hands with 1st corners, ready to balance-in line.
9-16::
    1s dance the Spoke ending between 1st corners but no hands joined.
17-24::
    1s dance LSh reels of 3 on opposite sides giving LSh to 2nd corners
    to begin.
25-28::
    1L continues to dance down & out around 3M whilst 1M casts down
    around 3L.
29-32::
    1s meet and lead up, cross & cast into 2nd place on own sides.', 0);
INSERT INTO 'dancecrib' VALUES (6633, '2013-08-21 08:31:28.087246+00', '2023-02-04 01:21:36.716433+00', 9876, 3, NULL, 'ace', '1-8::
    Taking 1 step to each hand end couples cross RH _while_ middle
    couples dance RH hands across 1/2 way, change places LH on sides &
    repeat until back in original places (as 1st 16 bars of Trip to
    Bavaria)
9-16::
    1s & 4s set & cast in 1 place & circle 4H round to left
17-24::
    2s & 3s repeat
25-32::
    All set, circle 8H round to left for two steps, Men (at top) &
    Ladies (at bottom) dance RH across
33-40::
    All set, circle 8H round to right for 2 steps, 1s+2s also 3s+4s
    dance LH across ending in lines across (2M+1M+1L+2L facing
    3M+4M+4L+3L)
41-48::
    All pass opposite person RSh loop round to right & pass LSh to
    original places
49-56::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6634, '2013-08-21 08:31:28.09562+00', '2023-02-04 01:21:36.738549+00', 8520, 3, NULL, 'ace', '1-4::
    1M+2s dance 1/2 RH across with 2M ending in 2nd place opposite side
    as 1M turns 2L RH into her partners place
5-8::
    1L+2s dance 1/2 LH across with 2M ending in original place as 1L
    turns 2L LH into original place
9-16::
    1s set, cast 1 place, turn RH to face 1st corners
17-32::
    1s dance LH Corner Chain with setting:
::
    1s change pl LH with 1st crnrs, _while_ 1s set, 1st crnrs turn RH in
    centre & return to places giving LH to 1s who turn RH in centre to
    face 2nd crnrs
::
    1s change places LH with 2nd crnrs, _while_ 1s set, 2nd crnrs turn
    RH in centre & return to places giving LH to 1s & 1s & 3s end with a
    1/2 turn RH into 2nd pls', 0);
INSERT INTO 'dancecrib' VALUES (6635, '2013-08-21 08:31:28.105608+00', '2023-02-04 01:21:36.778008+00', 8727, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, dance down between 3s & cast up to face 1st
    corners
9-16::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 1st crnrs
17-24::
    1s dance ''Hello-Goodbye'' setting & end dancing in turning right
    about to face 2nd corners
25-32::
    1s change pl RH with 2nd crnrs, 2nd crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to 2nd place own
    side facing out
33-40::
    2s+1s+3s dance reels of 3 on sides (1s give LSh to person on left)', 0);
INSERT INTO 'dancecrib' VALUES (6636, '2013-08-21 08:31:28.11366+00', '2023-02-04 01:21:36.804201+00', 4906, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1L followed by partner casts 1 place &
    crosses to opposite side
9-16::
    1s+3s dance LH across, 1L followed by partner casts 1 place &
    crosses to own side
17-24::
    1s lead up to top & cast to 2nd places, 1s lead down between 3s &
    cast up to 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6637, '2013-08-21 08:31:28.121703+00', '2023-02-04 01:21:36.823014+00', 4907, 3, NULL, 'ace', '1-8::
    1s set to 2L & circle 3H round to left, 1s set to 2M & circle 3H
    round to left
9-16::
    1s lead down the middle for 3 steps, back to top & cast to 2nd
    places to face diagonally in with 3s
17-24::
    1s+3s set twice & circle 4H round to left
25-32::
    2s+1s set twice & circle 4H round to left
33-40::
    1s set twice, lead up to top & cast to 2nd places
41-48::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6638, '2013-08-21 08:31:28.129755+00', '2023-02-04 01:21:36.85237+00', 4908, 3, NULL, 'ace', '1-16::
    1M dances 1/2 reel of 3 with 2s (LSh to 2L), 1M picks up his partner
    & dances a further full reel of 3, 1s followed by 2s lead down to
    bottom
17-24::
    2s followed by 1s lead up to top & 1s lead up between 2s cross over
    & cast to 2nd place on own sides
25-32::
    1s dance 1/2 Fig of 8 round 2s, 2s+1s set & cross LH', 0);
INSERT INTO 'dancecrib' VALUES (6639, '2013-08-21 08:31:28.137872+00', '2023-02-04 01:21:36.895684+00', 9474, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s, cross RH (briefly) & 1L crosses to
    own place & casts to 2nd place _while_ 1M crosses down between 2s &
    casts up to own place (2L steps up 7-8)
9-16::
    1s+2s dance RH across followed by LH across but as 2s turn inwards
    to dance LH across 1s dance round the person ahead into the LH
    across, 2s end dancing onto own sides (pull back RSh) _while_ 1s end
    BtoB in middle facing 2s (1M facing 2L, 1L facing 2M)
17-24::
    1s+2s reel of 4 across ending with 2s in top place & 1s pass by RSh
    to face down NHJ, Lady on Man''s right
25-32::
    1s dance down for 2 steps, Man dances below partner as she dances
    under his arm to face up, dance to top & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6640, '2013-08-21 08:31:28.147935+00', '2023-02-04 01:21:36.922174+00', 12539, 3, NULL, 'ace', '{{explanation}}
4s & 5s & 6s start on opp sides

1-8::
    1s cross RH & cast to 2nd place, cross LH & cast to 3rd place
    _while_ 6s cross RH & cast to 5th place, cross LH & cast to 4th
    place
9-16::
    1M+6L Prom hold dance reel of 3 with 4s (pass 4M LSh to start)
    _while_ 6M+1L dance reel of 3 with 3s (pass 3M LSh) end 1s in 3rd
    place side by side facing up & 6s in 4th place facing down ready
    for:..
17-24::
    1s & 6s dance reflection reels on sides dancing up/down between
    3s/4s to start
25-32::
    1s+6s dance R&L ending with 1s facing up & 6s facing down
33-36::
    End couples cross RH _while_ cpl in 2nd+3rd pl also cpl in 4th+5th
    pl dance 1/2 RH across & all (1st+2nd pl, 3rd+4th pl, 5th+6th pl)
    change pl LH on side
37-40::
    Repeat bars 33-36
41-44::
    Repeat bars 33-36
45-48::
    All turn partners RH  5 4 6(1)(3)(2)

{{explanation}}
Dance 3 times to end 6 5 4 (3) (2) (1) or 6 times to end 1 2 3 (4) (5) (6)', 0);
INSERT INTO 'dancecrib' VALUES (6641, '2013-08-21 08:31:28.156207+00', '2023-02-04 01:21:36.950427+00', 10095, 3, NULL, 'ace', '1-4::
    1M+3L 3/4 turn RH dance out 3rd/1st places own sides & cast back to
    places _while_ 1L+3M cast to 3rd/1st place & then 3/4 turn RH back
    to places
5-8::
    1s+2s+3s chase clockwise 1/2 way.  (3)(2)(1)
9-16::
    2s dance RH across (2M with 3s at top, 2L with 1s), 2s dance LH
    across with other couple
17-20::
    3M+1L 3/4 turn LH dance out through 3rd/1st places & cast back
    _while_ 1M+3L cast to 1st/3rd places & then 3/4 turn LH back to
    places
21-24::
    3s+2s+1s chase anticlockwise 1/2 way to original places.  1 2 3
25-28::
    1M casts 1 place & crosses to Ladies sides _while_ 1L crosses to
    Men''s side & casts to 2nd place.
29-32::
    1M casts down to 3rd place & crosses up to 2nd place own side
    _while_ 1L crosses up & casts to 2nd place own side
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13277, '2020-10-16 00:21:16.654472+00', '2023-02-04 01:21:37.026873+00', 13769, 3, NULL, 'ace', '1-8::
    1s+2s dance the "Celtic Cross Progression":
::
    _1-4_   1M+2L turn RH as 1L+2M chase anticlockwise 1/2 way into a
    line of 4 across, 1/2 turn partner LH;
::
    _5-8_   1L+2M 3/4 turn RH as 1M+2L chase 1/4 way anticlockwise into
    a line up/down middle, 2s 3/4 turn partner LH to end on own side as
    1s turn LH to face 1st corners
9-24::
    1s "Swing Corners":
::
    _9-12_   1s turn 1st corner RH, 1s 1/2 turn LH to face 3rd corner
::
    _13-20_ 1s repeat 9-12 with 3rd & 2nd corners to face 4th corner
::
    _21-24_ 1s turn 4th corner RH to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6644, '2013-08-21 08:31:28.180414+00', '2023-02-04 01:21:37.058308+00', 15054, 3, NULL, 'ace', '1-8::
    1s & 3s set & cross down between 2s/4s, 1s & 3s cast down round
    4s(5s) & set
9-16::
    4s+1s also 5s+3s dance the Swirl:
::
    Turn partners RH into Allemande hold & dance LSh round other couple
    1/2 way, dance LH across & swirl to Ladies facing 1st crnrs(Men
    behind them)
17-24::
    1s & 3s dance Alternating Tandem reels of 3 with corners to end in
    2nd/4th places opp side
25-32::
    1s+4s also 3s+5s dance the Helix (variation):
::
    1s/3s set advancing & turn about as 4s/5s set passing partner RSh
    into BtoB position & then cast round prtnr to own sides, 1/2 turn
    prtnr RH & dance 1/2 RH across.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (6645, '2013-08-21 08:31:28.188408+00', '2023-02-04 01:21:37.082439+00', 4911, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & 1s cross RH, 1s change places LH with 2s on the side
    & 2s+1s+3s set
9-16::
    1s dance Petronella turn & set, 1.1/2 turn partner LH to face 1st
    corners
17-24::
    1s dance LSh reels of 3 across (Lady with 2s & Man with 3s)
25-32::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corner &
    cross RH', 0);
INSERT INTO 'dancecrib' VALUES (6646, '2013-08-21 08:31:28.196728+00', '2023-02-04 01:21:37.256977+00', 7613, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & turn RH to face out on own sides
9-16::
    1L dances up behind 2L & down middle to meet 1M who has danced down
    behind 3M & up the middle, 1s turn LH to Lady facing up & Man down
17-24::
    1L+2s also 1M+3s circle 3H round to left, 1s pass RSh to circle 3H
    round to right with other couple
25-32::
    1s ''Slip Step'' down the middle for 2 steps & back, dance up between
    2s & cast to meet in middle (2nd place)
33-40::
    1s ''Slip Step'' up the middle & back again, lead down between 3s,
    cross over & cast up to 2nd place
41-48::
    1s dance reflection reels of 3 on opposite sides (1s dancing in
    between 2s to start) & cross to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6647, '2013-08-21 08:31:28.204722+00', '2023-02-04 01:21:37.283523+00', 9096, 3, NULL, 'ace', '1-8::
    1M+2L also 3M+4L set, change places LH & dance round partners back
    to places
9-16::
    1L+2M also 3L+4M set, change places RH & dance round partners back
    to places
17-24::
    1s+2s also 3s+4s dance RH across, 2s+3s dance LH across
25-32::
    1s+2s also 3s+4s dance RH across, 1s dance down the middle to 4th
    place', 0);
INSERT INTO 'dancecrib' VALUES (6648, '2013-08-21 08:31:28.212701+00', '2023-02-04 01:21:37.3141+00', 7475, 3, NULL, 'ace', '1-8::
    1s+2s+3s advance for 2 steps & retire, turn partners RH ending in
    centre for promenade
9-16::
    1s+2s+3s dance Promenade
17-24::
    1s dance down the middle below the 4s (2s+3s+4s step up 19-20),
    dance up between 4s & cast down to 4th place
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14561, '2022-01-23 18:36:24.992912+00', '2022-01-23 20:08:18.821352+00', 3333, 1, 1645, 'ace', '1-::

  1c & 3c set adv to P | turn 1&frac14; RH to centre line ; 1M & 3W set _while_ 1W+3M turn LH | 1c & 3c turn &frac34; RH to sides (1,2,3)

9-::

  1c+2M & 2W+3c RHA, 2c end facing out ; 2c &frac12; Fig8 L round 4cnrs & face out on opp side (1,2x,3)

17-::

  Reels3 on sides, 2c start RSh to 1cnrs, 1c end NHJ facing down to 2c who pass LSh to face up NHJ

25-::

  1c+2c Rondel (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (4140, '2013-08-21 08:30:44.088652+00', '2023-02-04 01:18:36.52761+00', 358, 3, NULL, 'ace', '1-8::
    1M & 3M set turning on the spot (hands on hips), 1L & 3L dance
    toward partner & back to places
9-16::
    1L & 3L followed by ptnrs cast 1 pl, dance up between couple above,
    cast down 1 pl (Mens side) & dance in give RH to 1st crnr & LH to
    partner
17-24::
    1s & 3s Bal-in-Line with corners, dance on to 2nd corners,
    Bal-in-Line, 1s & 3s 1/2 turn LH into
25-32::
    All dance RH across (1L with 2s, 1M & 3L with 4s, 3M with 5s), 1s &
    3s 1/2 turn LH & cast down 1 place', 0);
INSERT INTO 'dancecrib' VALUES (14672, '2022-03-07 02:21:00.719091+00', '2023-02-04 01:21:37.450759+00', 20662, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across & LH across back to places
9-16::
    1s lead down the middle & back
17-20::
    1s followed by 2s+3s+4s cast down on own sides
21-24::
    1s meet & lead back up to top followed by 2s+3s+4s
25-28::
    2s+3s+4s mke arches & 1s lead down to bottom under arches made by
    2s+3s+4s
29-32::
    All 4 couples turn partner RH (or birl), moving up 1 place as they
    turn. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6649, '2013-08-21 08:31:28.306786+00', '2023-02-04 01:21:37.646084+00', 4916, 3, NULL, 'ace', '1-8::
    Top 3 dancers on Men''s side change RH with bottom 3 on Ladies side,
    dancers in 2nd & 3rd place only change LH on side, top 3 dancers on
    Ladies side change RH with bottom 3 on Men''s side, dancers in 2nd &
    3rd place only change LH on side
9-16::
    Repeat ending with 4 Men at top
17-20::
    All turn opp person 3/4 RH, top 2 Men & bottom 2 Ladies chase 1/4 in
    direction they are facing (3M & 2L dance clockwise as 4M & 1L dance
    anticlockwise) passing oncoming dancer to face in _while_ middle
    couples dance 1/4 RSh reel of 4 up/down end with 1M+4L passing LSh
21-24::
    1M+3L also 2M+4L 3/4 turn RH to end in square set with 2M+4L at top
    & 3L+1M at bottom & all set
25-32::
    All circle 8H round to left until 3s are at top & all opposite
    partner in longwise set, all set & 1s & 4s cross RH.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (6651, '2013-08-21 08:31:28.328731+00', '2023-02-04 01:21:37.765665+00', 12334, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 2s
9-16::
    1s dance Inveran reels with 3s+4s
17-24::
    4s cross RH, cast up 1 place & dance 1/2 Fig of 8 round 3s
25-32::
    4s dance Inveran reels with 2s+1s
33-40::
    2s+1s+4s set, cross RH, set & turn RH into Allemande hold
41-48::
    2s+1s+4s dance Allemande.  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (6652, '2013-08-21 08:31:28.338452+00', '2023-02-04 01:21:37.783464+00', 10819, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance RH across, 1s & 4s chase clockwise 1/2 way & end
    1s in 4th place & 4s in 1st place opposite sides
9-16::
    All dance reel of 4 on sides & end facing up/down
17-24::
    1s & 4s 1/2 turn facing person RH & dance LH across in middle &
    cross LH with partner to own side  2 4 1 3
25-32::
    All circle 8H round & back.', 0);
INSERT INTO 'dancecrib' VALUES (9028, '2015-11-30 09:00:06.55599+00', '2023-02-04 01:21:37.807432+00', 16105, 3, NULL, 'ace', '1-8::
    1s lead down middle & back, finishing facing out
9-12::
    1M followed by 2M, 3M & 4M also 1L followed by 2L, 3L &4L, cast
    behind lines to bottom of set
13-16::
    Each couple in turn crosses (Lady in front of Man) to opposite side
    and dances up - order is (1) (2) (3) (4)
17-24::
    1s cross RH, cast (2s step up), 1s cross LH, cast to 4th place
    (3s+4s step up)
25-32::
    All dance down middle NHJ (3 steps)  Ladies dance under partners''
    arms (bars 28-29) & all dance back up to own sides 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6653, '2013-08-21 08:31:28.348239+00', '2023-02-04 01:21:37.881628+00', 4919, 3, NULL, 'ace', '1-8::
    1s set twice to 2L & set twice to 2M & end facing down
9-16::
    1s cross down, cast down round 3s, lead up to top & cast 1 place on
    opposite sides to face 1st corners
17-24::
    1s set twice to 1st corners & set twice to 2nd corners & 1s end in
    centre on own sides facing down
25-32::
    1s followed by 2s+3s lead down, cast up on own sides to places, 1s
    cast to 2nd place & 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (13278, '2020-10-16 00:21:17.369875+00', '2023-02-04 01:21:37.90657+00', 19307, 3, NULL, 'ace', '1-8::
    2L followed by 1L dance in front of 3L, RSh round 4L, behind 3L & up
    to 1st place _while_ 3M followed by 4M dance similar, in front of
    2M, round 1M & down to 4th place
9-16::
    3L followed by 4L & 2M followed by 1M repeat 1-8.  2 1 4 3
17-24::
    1s+4s (middle couples) Set & Rotate.  2 4 1 3
25-32::
    Men make arches & Adv+Ret _while_ Ladies dance under arches passing
    partner RSh & back to place; all turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (12165, '2019-09-04 17:11:48.098723+00', '2023-02-04 01:21:37.924782+00', 19568, 3, NULL, 'ace', '1-8::
    1s & 4s 1/2 turn RH to form a square set & all 4 couples set, all
    circle 8H round to left 1/2 way.   4 (3)(2) 1
9-16::
    4L & 1M (followed by partner) dance Figs of 8 in tandem (4s out
    round 3s, 1s out round 2s) 4s & 1s end on opposite sides.
    (4)(3)(2)(1)
17-24::
    4s dance 1/2 reels of 3 with 3s+2s on sides (dancing out to start),
    all set & cross RH.  2 3 4 1
25-32::
    2s+3s also 4s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6654, '2013-08-21 08:31:28.460273+00', '2023-02-04 01:21:37.94369+00', 4924, 3, NULL, 'ace', '1-8::
    1s set & cross down RH to opposite side, 1M casts up to end up
    between 2s as 1L casts down to end between the 3s both facing 3rd
    cnrs
9-16::
    1s dance reels of 3 across (RSh to 3rd corners) ending facing 3rd
    corner
17-20::
    1s dance RSh round 3rd corners as corners 1/2 turn RH in the middle,
    twirl (pull back RSh) & dance out to opposite sides
21-24::
    1s pass RSh, dance RSh round 4th corners as corners 1/2 turn RH in
    the middle, twirl (pull back RSh) & dance out to opp sides (1s end
    2nd pl own side)
25-32::
    1s 1/2 turn RH in the middle, pull back RSh & dance out to opp sides
    & 2s+1s+3s chase clockwise back to own sides.  End 213', 0);
INSERT INTO 'dancecrib' VALUES (14008, '2021-05-03 00:20:57.673977+00', '2023-02-04 01:21:38.004071+00', 7866, 3, NULL, 'ace', '{{title}}
Start

::
    6L··3M··3L
::
    5L··2M··2L
::
    4L··1M··1L
::
    ····Top

{{explanation}}
2 chords: 1st chord Men honour Ladies on right, 2nd chord Men honour Ladies on left

1-8::
    Men join hands with Ladies on right in prom hold & 3 couples
    promenade round 1L, 2L & 3L
9-16::
    Men join hands with Ladies on left in prom hold & 3 couples
    promenade round 4L, 5L & 6L back to place
17-24::
    1M+2L+3M+5L circle 4H round & back
25-32::
    1L+3L+6L+4L circle 4H round & back
33-40::
    1M+2M+4L+5L dance LH across; 1M+2M+1L+2L dance RH across
41-48::
    2M+3M+2L+3L dance LH across; 2M+3M+5L+6L dance RH across
49-56::
    In 3 lines of 3 across - all dance RSh reels of 3 across (Men RSh to
    Lady on his right)
57-64::
    1L followed by 1M+4L cast round 2L, dance across set, cast round 6L
    & across set to form new bottom line (standing lines step up)

{{explanation}}
Note:	Bars 17-32 centre Man (2M) may set (Highland steps) during circles', 0);
INSERT INTO 'dancecrib' VALUES (6720, '2013-08-21 08:31:29.926747+00', '2023-02-04 01:21:43.908263+00', 8473, 3, NULL, 'ace', '1-8::
    1s cross RH & set, 1s+2s cross RH & set
9-16::
    1s+2s+3s cross RH & set, 1s+2s+3s cross RH & set
17-24::
    1s+2s dance 1/2 R&L, 1s dance 1/2 Figs of 8 (1L round 3s & 1M round
    2s)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6656, '2013-08-21 08:31:28.479845+00', '2023-02-04 01:21:38.10795+00', 4927, 3, NULL, 'ace', '1-16::
    1L+2L also 3M+4M dance full petronella around inside of set & return
    to own places
17-24::
    All Ladies dance RH across once round & turn partners LH 1.1/2 times
25-32::
    All Men dance RH across & turn partners LH 1.1/2 times
33-40::
    All Ladies dance a RH St Andrews Cross with partner on left hand
    once round ending facing partner on sides holding 2H
41-48::
    All Poussette around set to original places
49-96::
    Repeat all of the above with 1M+2M & 3L+4L dancing bars 1-16', 0);
INSERT INTO 'dancecrib' VALUES (9029, '2015-11-30 09:00:06.717296+00', '2023-02-04 01:21:38.131513+00', 12756, 3, NULL, 'ace', '1-8::
    All set twice, turn partners 2H. 1s face down
9-16::
    1s lead down, cross below 4s, cast up to top place opp sides
17-24::
    All Adv+Ret twice, turn partners 2H (1s turn 1.1/2 times to own side
    & face out)
25-32::
    1s cast to 4th place, 2s+3s+4s take hands on sides & step up bars
    3-4.  1s turn 2H (4 bars)', 0);
INSERT INTO 'dancecrib' VALUES (6657, '2013-08-21 08:31:28.489585+00', '2023-02-04 01:21:38.248925+00', 4928, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s dance reels of 3 on own sides giving RSh to 2s
17-24::
    1s lead down the middle & back to top
25-32::
    1s cross RH, cast 1 place (3 bars), cross LH & cast to 3rd place (3
    bars), begin to lead up (2 bars)
33-40::
    1s lead up to top & cast 1 place to face 1st corners.  1s set to 1st
    corner & to 2nd corner
41-48::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corner &
    cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6660, '2013-08-21 08:31:28.523407+00', '2023-02-04 01:21:38.495946+00', 4931, 3, NULL, 'ace', '1-8::
    1s & 3s set & cross RH, 1s set to 2s & turn RH, _while_ 3s set to 4s
    & turn RH
9-16::
    All dance reel of 4 on sides
17-24::
    All circle 8H round & back
25-32::
    All dance Grand Chain
33-40::
    1s turn RH _while_ 3s cross RH, 1s on opposite sides change places
    LH with 2s, RH with 3s, LH with 4s & 1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (6662, '2013-08-21 08:31:28.541942+00', '2023-02-04 01:21:38.604725+00', 4933, 3, NULL, 'ace', '1-16::
    All set & change places with partner RH, all circle 8H round & back,
    all set & change places with partner RH
17-24::
    1s+3s slip step across (Men BtoB) & set, slip step back (Ladies
    BtoB) & set
25-32::
    2s+4s repeat bars 17-24
33-40::
    Ladies dance RH across & dance round partners LSh to places
41-48::
    All set, dance DoSiDo & set
49-56::
    All Men dance LH across & dance round partners RSh to places
57-64::
    All set, dance DoSiDo & set
65-72::
    1M+3L dance Figs of 8 thru 2nd couple _while_ 1L+3M dance Figs of 8
    thru 4th couple
73-80::
    1s in prom hold dance 1/2 Fig of 8 round 4s as 3s dance round 2s,
    1s+3s dance round each other (M pass LSh) to places
81-88::
    2L+4M dance Figs of 8 thru 1s _while_ 2M+4L dance Figs of 8 thru 3s
89-96::
    2s in prom hold dance 1/2 Fig of 8 round 1s as 4s dance round 3s,
    2s+4s dance round each other (M pass LSh) to places
97-104::
    All Ladies dance R&L (1L+2L & 3L+4L to start)
105-112::
    All Men dance R&L (1M+4M & 3M+2M to start)
113-128::
    Repeat first 16 bars', 0);
INSERT INTO 'dancecrib' VALUES (6663, '2013-08-21 08:31:28.551805+00', '2023-02-04 01:21:38.749027+00', 4935, 3, NULL, 'ace', '1-8::
    1s+2s dance across (ladies dance between men), change places LH on
    sides & repeat back to places
9-16::
    1s cross RH, change places LH with 2s on sides & turn 3s RH on sides
17-24::
    2s+1s+3s Adv+Ret.  All advance again & 2s cast to 2nd place as 1s
    1/2 turn RH moving up to 1st place & 3s Retire
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10088, '2017-09-03 23:45:09.858083+00', '2023-02-04 01:21:38.786782+00', 17898, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 on own sides (pass 2s RSh to start).  1L ends facing
    out
9-16::
    Reels of 3 on sides (1s+2s pass RSh to start).  1L end facing out
17-24::
    1L followed by 1M dances behind 2L, up between 2s, behind 2M, across
    set to 2nd place own side (2s step up 23-24)
25-32::
    1s+3s dance RH across.  2s+1s dance LH across.  1L finishes facing
    out, ready to start again', 0);
INSERT INTO 'dancecrib' VALUES (15141, '2022-10-05 00:21:11.29631+00', '2023-02-04 01:21:38.977245+00', 21030, 3, NULL, 'ace', '{{explanation}}
2 chords - on 2nd chord 1M & 2L change places LSh also 3L &4 M change places RSh - face in & join NH with partner

1-4::
    1s+2s also 3s+4s Set+Link to finish Men facing clockwise, Ladies
    facing anti-clockwise
5-8::
    Ladies dance LH across. Men chase 1/2 way clockwise, pull back RSh
    to form St Andrews cross facing anti-clockwise
9-12::
    All Set+Link with "new partner" to change places
13-16::
    Men dance LH across _while_ Ladies chase 1/2 way clockwise. Men face
    diagonally out to face partner, Ladies at top / bottom of sides
17-24::
    All dance reels of 4 on the sides passing partner RSh to start
25-32::
    All 1/2 turn partners 2H (1 bar), dance 8H to the left 3/4 round (5
    bars), all  Advance 1 step to centre + Retire 1 step

{{explanation}}
Note: End of 4th time through: Bars 31-32  All 3/4 turn to face each other in St Andrew''s cross, Men in centre (All Men dance in towards centre to start)', 0);
INSERT INTO 'dancecrib' VALUES (9484, '2016-11-09 08:48:50.146917+00', '2023-02-04 01:21:39.000684+00', 17406, 3, NULL, 'ace', '1-8::
    1s set, cross (no hands) into centre. 1L+2s dance LH across as 1M+4s
    dance RH across
9-16::
    1s cross between 3s, cast round set to place & set
17-24::
    All Advance with partner, Retire with corner.  All couples Set+Link
25-32::
    All Advance with corner, Retire with next person to form square set.
    All couples Set+Link
33-40::
    Dancers in 1st+3rd places (2M+4L & 2L+4M) dance 1/2 R&L, then dance
    1/2 Ladies'' Chain
41-48::
    Dancers in 2nd+4th places repeat 33-40.  All have moved 1 place
    anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (8614, '2015-02-13 12:48:05.33617+00', '2023-02-04 01:21:39.023655+00', 15401, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance 6H round and back
9-16::
    1s set, cast off (2s step up), turn LH to face 1st corners
17-24::
    1s+ 1st corners set, 1s dance round each other by right to face 2nd
    corners. 1s + 2nd corners repeat, 1s finish in middle facing own
    sides, 1M below 1L
25-32::
    1L+2s also 1M+3s dance LH across. 1s finish in 2nd place opposite
    sides.  2s+1s+3s set, 1s cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8615, '2015-02-13 12:48:05.344108+00', '2023-02-04 01:21:39.051163+00', 15626, 3, NULL, 'ace', '1-4::
    1s & 3s cross RH, cast 1 place
5-24::
    All dance five couple R&L :
::
    _5-6_     All cross Right Hands
::
    _7-8_    Dancers in 1M & 2M pstns also 4L & 5L pstns change places
    LH on sides _while_ dancers in 1L place & 3M place cross diagonally
    LH as dancers in 2L place & 4M place cross diagonally LH as dancers
    in 3L place & 5M place cross diagonally LH
::
    _9-12_  Repeat Bars 5-8 four more times to end in same places as at
    bar 4
25-32::
    1s & 3s cross RH, cast 1 place & all turn partner RH.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (12735, '2020-04-11 10:52:28.424817+00', '2023-02-04 01:21:39.132451+00', 9649, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up ); 1L+2s & 1M+3s dance 1/2 RSh reel of
    3 across (RSh to 4th corner to start)
9-16::
    1s dance Corner Pass+Turn with 1st corner (pstn), 1s pass RSh; 1s
    dance Corner Pass+Turn with 2nd corner pstn (2) (1) (3)
17-24::
    2s+1s+3s set, cross RH with partner; chase clockwise 1/2 round (3)
    (1) (2)
25-32::
    2s+1s+3s Set+Link twice.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6705, '2013-08-21 08:31:29.464618+00', '2023-02-04 01:21:42.766559+00', 5007, 3, NULL, 'ace', '1-8::
    1M turns 2L RH, Bal-in-Line with 2M as 1L dances RSh round her
    partner passing under arms
9-16::
    1s lead down the middle & back to top
17-24::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (4093, '2013-08-21 08:30:43.459048+00', '2023-02-04 01:18:33.923123+00', 287, 3, NULL, 'ace', '{{explanation}}
 2s & 4s start on opp. sides

1-8::
    1s+2s also 3s+4s dance RH across, 1L followed by 1M casts below 2nd
    pl & 1L crosses to 3rd pl Men''s side & 1M ends in 3rd pl Ladies''
    side _while_ 4L followed by 4M casts up above 3rd pl & crosses up to
    2nd pl Ladies'' side & 4M ends in 2nd pl Men''s side (2s & 3s step
    up/down)  (2)4(1)3
9-16::
    2s+4s also 1s+3s dance LH across, 2L followed by 2M casts below 2nd
    pl & 2L crosses down to 3rd pl Ladies'' side as 1M dances down to 3rd
    pl _while_ 3L followed by 3M casts up to 3rd pl & crosses up above
    2nd pl Men''s side as 4M dances up to 2nd place (4s & 1s step
    up/down)  4(3)2(1)
17-24::
    All dance RSh 1/2 reels of 4 on sides, 1s & 4s turn RH _while_ 2s+3s
    dance 1/2 Ladies'' Chain
25-32::
    3L followed by 3M crosses & casts up to top & 3L crosses to Ladies''
    side as 3M casts up _while_ 2L followed by 2M crosses & casts down
    to bottom (1s & 4s having stepped into middle places), 3s+1s also
    4s+2s turn 2H on sides & all set to partners', 0);
INSERT INTO 'dancecrib' VALUES (15075, '2022-09-05 00:21:08.618101+00', '2023-02-04 01:21:39.161868+00', 20907, 3, NULL, 'ace', '1-8::
    1s+2s cross RH, Men pull back RSh to face diag down, 1M+3M also
    2M+4M change places RH, Men pull back RSh to face clockwise; all 4
    couples chase clockwise 1/2 round to end Men''s side: 4L 3L 4M 3M,
    Ladies'' side: 2M 1M 2L 1L
9-16::
    Ladies cross set passing opp Man RSh & chase clockwise to end
    opposite partner; all 4 couples cross RH & set.  2 1 (4) (3)
17-24::
    RSh reels of 4 on sides, 1s & 4s do not pass LSh at end but loop
    round, 4s to face up, 1s face down.  2 (4) 1 (3)
25-32::
    2s+4s also 1s+3s turn RH on sides, all 4 couples set; 4s & 3s dance
    1/2 Fig 8 up round couples above them.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6665, '2013-08-21 08:31:28.599769+00', '2023-02-04 01:21:39.188931+00', 4943, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place (2s step up), dance down between 3s &
    cast back to 2nd place
9-16::
    1s dance reels of 3 across (1L with 2s, 1M with 3s, 1s LSh to 1st
    corners)
17-24::
    1s set & cross RH, set & 3/4 turn LH
25-32::
    1s dance RH across (1L with 2s, 1M with 3s), pass RSh & dance LH
    across with other couple', 0);
INSERT INTO 'dancecrib' VALUES (12166, '2019-09-04 21:29:26.045248+00', '2023-02-04 01:21:39.213593+00', 19569, 3, NULL, 'ace', '1-8::
    1M followed by partner casts 1 pl & cross to opp side (1M turns left
    about), 1s dance 1/2 Figs of 8 across (1M round 2s & 1L round 3s
9-16::
    1s dance 1/2 Figs of 8 across (1M round 3s & 1L round 2s) ending in
    2nd place opposite sides, 1s turn person on right RH
17-24::
    1s turn person on the left LH, 1L followed by partner casts to
    bottom & crosses to own sides
25-32::
    All dance 6H across RH & back LH', 0);
INSERT INTO 'dancecrib' VALUES (6666, '2013-08-21 08:31:28.633216+00', '2023-02-04 01:21:39.235959+00', 4947, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH
9-16::
    1s dance RH across (Lady with 2s & Man with 3s), 1s pass RSh & dance
    LH across with other couple
17-24::
    1s dance 1/2 reels of 3 on own sides giving RSh to person on their
    right, 3s+1s+2s turn partners RH
25-32::
    3s+1s+2s Set & Rotate for 3 couples - set, rotate singly, chase 1
    place clockwise & form lines of 3 across (Men facing down & Ladies
    up), all change places with partner & chase clockwise to own sides.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6667, '2013-08-21 08:31:28.643026+00', '2023-02-04 01:21:39.309434+00', 4948, 3, NULL, 'ace', '1-8::
    1L sets to 2M & turns RH _while_ 1M sets to 2L & turns RH, 1L+2L set
    & turn LH _while_ 1M+2M set & turn RH (1s between 2s)
9-16::
    1s lead down the middle & back to places
17-24::
    1s+2s set, dance RH across 1/2 way, set & dance back LH across
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6668, '2013-08-21 08:31:28.651043+00', '2023-02-04 01:21:39.325572+00', 10946, 3, NULL, 'ace', '1-8::
    1s & 3s turn RH, cross down between 2s/4s & cast to partners place
9-16::
    1s & 3s in prom hold dance reels of 3 with 2s/4s (pass 2M/4M RSh to
    start) end with 2s/4s dancing up to 1st/3rd places
17-24::
    1s & 3s lead down for 3 bars, lead up above 2s/4s cross & cast to
    2nd/4th places
25-32::
    1s+4s turn 1.1/2 times on sides (Men RH & Ladies LH), 2s+4s also
    1s+3s dance RH across.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6669, '2013-08-21 08:31:28.659035+00', '2023-02-04 01:21:39.342098+00', 10947, 3, NULL, 'ace', '1-8::
    1s & 3s Figs of 8 round couple below them
9-16::
    1s cross & cast 1 place as 2s set & cross up also 3s set & cross
    down as 4s cross & cast up, 1s+4s dance 1/2 R&L as 2s & 3s cross RH
    & set
17-24::
    All dance RSh reels of 4 on sides
25-32::
    All circle 8H round & back.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6670, '2013-08-21 08:31:28.667099+00', '2023-02-04 01:21:39.359546+00', 10948, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-4::
    1s+2s also 3s+4s dance RH across;
5-8::
    1s cross down to 2nd place opp sides _while_ 2s cast up, 3s cast
    down 1 place & 4s cross up to 3rd place own side; 1s & 4s dance
    up/down behind 2s/3s
9-16::
    1s in prom hold dance a reel of 3 across with 2s (RSh to 2M to
    start) _while_ 4s in prom hold dance reel of 3 across with 3s (RSh
    to 3M to start)
17-24::
    1s+4s (prom hold) dance clockwise round each other & dance out ends
    (1s up between 2s, 4s down between 3s) & cast to 2nd/3rd places
25-32::
    1s+4s dance 1/2 R&L (no polite turns) & all 4 couples turn partners
    2H.  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (4095, '2013-08-21 08:30:43.485991+00', '2023-02-04 01:18:34.045543+00', 292, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, set advancing to 1st corners & turn 2H
9-16::
    1s+1st corners circle 4H round to left, 1s set advancing to 2nd
    corners & turn 2H
17-24::
    1s+2nd corners circle 4H round to left, 1s set advancing towards
    each other & turn 2H to face up (on opposite sides)
25-32::
    2s+1s+3s dance reels of 3 on opposite sides (1s dancing in & up to
    start), 1s cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4097, '2013-08-21 08:30:43.502416+00', '2023-02-04 01:18:34.192736+00', 295, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place (2s step up), 1s cross LH & cast up to
    original places (2s step down)
9-16::
    1s dance reflection reels of 3 on sides (in & down to start)
17-24::
    1s lead down the middle & back to place
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (14736, '2022-04-01 00:21:01.314593+00', '2023-02-04 01:21:39.377198+00', 14489, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-4::
    All cross RH, 1s+2s also 3s+4s dance 1/2 RH across.  2 1 (4) (3)
5-8::
    1s+4s (middle couples) dance LH across _while_ 2s & 3s turn partners
    RH to end 1s+4s with LH joined in centre & RH with corners
9-16::
    All set, 1s & 4s turn corners RH into centre & corners join LH; all
    set & 1s & 4s turn corners RH back to place, 1s & 4s finish on sides
    (retain RH)
17-24::
    Reels of 4 on sides, 1s+4s end passing RSh & face down/up on sides
    _while_ 2s & 3s face across 2 1 (4) (3)
25-28::
    All set & change places RH with facing person.  (2) (4) 1 3
29-32::
    2s+4s also 1s+3s dance 1/2 Double Figs 8 (2s & 3s cast, 4s cross up,
    1s cross down), giving RH when crossing up/down.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (6671, '2013-08-21 08:31:28.675108+00', '2023-02-04 01:21:39.394186+00', 4951, 3, NULL, 'ace', '1-8::
    1s dance down NHJ between 2s, dance out behind 3s, meet below 3s,
    dance up to top & cast to 2nd place (2s step up 7-8)
9-16::
    1s dance LSh reels of 3 across set (L with 2s, M with 3s), 1s end
    facing down
17-24::
    2s+1s+3s dance 1/2 Grand Chain (2s crossing), set & cross LH, 1s end
    facing up
25-32::
    3s+1s+2s dance 1/2 Grand Chain (2s crossing), 2s+1s+3s set & cross
    LH', 0);
INSERT INTO 'dancecrib' VALUES (6672, '2013-08-21 08:31:28.689659+00', '2023-02-04 01:21:39.430692+00', 11227, 3, NULL, 'ace', '1-8::
    2s 3/4 turn RH, 2L+1s also 2M+3s (LH joined) set & dance LH across
9-16::
    2s dance reels of 3 across (2L LSh to 1L & 2M LSh to 3M) & 2s turn
    RH to face 4th corners
17-24::
    2s dance 1/2 diagonal RSh reel of 4 with corners, pass RSh & dance
    1/2 diagonal reel with 1st corners ending in own places.  (3) 2 (1)
25-32::
    3s+2s Set+Link, 3s+1s set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (6673, '2013-08-21 08:31:28.697655+00', '2023-02-04 01:21:39.465733+00', 4953, 3, NULL, 'ace', '1‑8::
    1L+2L+3L+4L Adv+Ret twice
9‑16::
    1M+2M+3M+4M Adv+Ret twice
17‑24::
    1s cast to 4th place (2s,3s & 4s step up on bars 19), all turn
    partners RH
25‑32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6674, '2013-08-21 08:31:28.710735+00', '2023-02-04 01:21:39.612917+00', 11976, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All 1/2 turn partners RH & Men cast 1 place clockwise _while_ Ladies
    dance 1/2 LH across & turn Man in opposite place RH to end on Mans
    left
17-24::
    Dancers in 1st+3rd places dance 1/2 R&L, dancers in 2nd+4th places
    dance 1/2 R&L
25-32::
    Men turn new partners RH & giving LH to next Lady (as for Double
    Triangles with Ladies BtoB in centre) set, Men turn new partners RH
    to place

{{explanation}}
Repeat with new partners, Men having moved on 1 place anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (6675, '2013-08-21 08:31:28.72065+00', '2023-02-04 01:21:39.624855+00', 9104, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 3 facing 3

1-8::
    All circle 6H round & back
9-16::
    Centre Man dances RH across with partner on right & opposite dancer
    & LH across with partner on left & opposite dancer
17-24::
    Centre Man dances out to the right & dances a Fig of 8 round the
    opposite 2 Ladies ending between them
25-32::
    All Ladies turn opposite Lady RH 1.1/2 times back to their partners,
    all join hands set in lines of 3 & set again turning to right to
    face next group of 3', 0);
INSERT INTO 'dancecrib' VALUES (8616, '2015-02-13 12:48:05.520694+00', '2023-02-04 01:21:39.638735+00', 15642, 3, NULL, 'ace', '1-8::
    1s dance down middle below 3s, cast up thru 2nd place, meet, dance
    up & cast to 2nd place own sides (2s step up 3-4)
9-12::
    2s+1s+3s dance 1/2 mirror (reflection) reels of 3 on sides (1s
    in/down to start)
13-16::
    1M+2s at bottom & 1L+3s at top dance 1/2 LSh reels of 3 across
    (1M+2L & 1L+3M pass LSh)
17-20::
    3s+1s+2s dance 1/2 RSh reels of 3 on sides 1M up/1L down (1M+3M at
    top & 1L+2L at bottom pass RSh)
21-24::
    1M+2s at top & 1L+3s at bottom dance 1/2 LSh reels of 3 across
    (1M+2L & 1L+3M pass LSh) 1s finish in 2nd place own sides (2s & 3s
    dance loops at all reel ends)
25-32::
    2s+1s+3s set, circle 6H round to Left', 0);
INSERT INTO 'dancecrib' VALUES (6629, '2013-08-21 08:31:27.963938+00', '2023-02-04 01:21:39.729381+00', 4894, 3, NULL, 'ace', '{{explanation}}
Round the Room or up & down room, 2 couples facing 2 couples (1s face 3s, 2s face 4s, 1s on right of 2s)

1-8::
    All circle 8H round & back
9-16::
    1s+3s dance R&L _while_ 2s & 4s set twice & turn partner RH twice
17-24::
    2s+4s dance R&L _while_ 1s & 3s set twice & turn partner RH twice
25-32::
    Ladies dance reel of 4 passing opposite Lady RSh to start
33-40::
    Men dance reel of 4 passing opposite Man RSh to start
41-48::
    All Adv+Ret, & pass RSh to new set', 0);
INSERT INTO 'dancecrib' VALUES (8344, '2014-07-29 12:59:20.239913+00', '2023-02-04 01:21:39.763062+00', 15040, 3, NULL, 'ace', '{{title}}
Start

::
    _7_· ·8· ·9
::
    _4_· ·5· ·6
::
    _1_· ·2· ·3
::
    · ·Top
1-8::
    Dancer 5 sets _while_ others dance 8H round & back
9-16::
    _5_ dances a RSh reel with 1 & 9 as 2+3+6 also 4+7+8 dance RH across
    & LH back
17-24::
    _5_ dances a LSh reel with 3 & 7 as 1+2+4 also 6+8+9 dance RH across
    & LH back
25-28::
    Dancers 1+2+3 set to & changes places RSh under arches made by 4+5+6
29-32::
    Dancers 1+2+3 set to & changes places RSh under arches made by 7+8+9', 0);
INSERT INTO 'dancecrib' VALUES (6676, '2013-08-21 08:31:28.738149+00', '2023-02-04 01:21:39.791487+00', 4954, 3, NULL, 'ace', '1-8::
    2s & 4s dance 1/2 Figs of 8 round end couples to face 1st corners,
    set to corners & set to 2nd corners
9-16::
    2s & 4s dance diagonal reels of 4 with 2nd corners, 2s & 4s end
    passing partner RSh to opposite sides
17-24::
    All Adv+Ret, top 4 Men''s side cross diagonally RH with bottom 4
    Ladies side, top 4 Ladies side cross diag LH with bottom 4 Men''s
    side
25-32::
    Top 4 Men''s side cross diagonally RH with bottom 4 Ladies side, top
    4 on Ladies side cross diagonally LH with bottom 4 on Men''s side &
    end with couples (with new partners) in 2nd & 4th places turning RH
    1.1/2 times to own sides
::
    Ladies side 5L,3L,4L,1L,2L : Mens side 4M,5M,2M,3M,1M

{{explanation}}
Repeat with new partners', 0);
INSERT INTO 'dancecrib' VALUES (14430, '2021-11-06 01:12:33.765163+00', '2023-02-04 01:21:39.818544+00', 15727, 3, NULL, 'ace', '1-8::
    1s turn RH cast (2s step up); 1s turn LH 1.1/4 to face 1st corners
9-24::
    1s dance Corner Chain with 1st & 2nd corners:
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s. 1s 1/2 turn LH to end 1M between
    2s, 1L between 3s facing own side
25-32::
    1s dance 6 bar reels of 3 across (LSh to 3rd corner to start), 1s
    cross LH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (14122, '2021-07-07 00:20:41.91293+00', '2023-02-04 01:21:39.854044+00', 11969, 3, NULL, 'ace', '1-8::
    All circle 8H 1/2 round to left; Ladies dance 1/2 RH across & turn
    opp Man LH
9-16::
    Ladies dance 1/2 RH across & turn partner LH (finish on Man''s
    right); all circle 8H 1/2 round to right to original places
17-24::
    Men dance 1/2 LH across & turn opp Lady RH; Men dance 1/2 LH across
    & turn partner 3/4 RH, Men face in, Ladies face out
25-32::
    All dance 1/2 Schiehallion reel to opp place. End with Men joining
    LH in centre, RH with partner all facing anticlockwise
33-40::
    Men dance LH across 1.1/2 times round _while_
::
    Ladies dance 2 steps then pull back RSh & cast back, passing 1 Man
    to join LH with opp Man (e.g. 1L+3M), Ladies dance 2 steps & cast
    back, pass partner RSh & all end in partner''s original place, Ladies
    facing in, Men facing out
41-48::
    All dance 1/2 Schiehallion reel to opp place. End with Ladies
    joining LH in centre, RH with partner all facing anticlockwise
49-56::
    Repeat 33-40 with Ladies dancing LH across & Men casting. End with
    Ladies BtoB in centre facing partner
57-64::
    1s+3s dance 1/2 reel of 4  & turn partner RH to opp side _while_
    2s+4s turn partner RH then dance 1/2 reel of 4 to opp side
65-72::
    Repeat 57-64 to end in original places
73-80::
    Dancer''s choice (e.g. circle 8H round & back)', 0);
INSERT INTO 'dancecrib' VALUES (14123, '2021-07-07 00:20:42.127725+00', '2023-02-04 01:21:40.100639+00', 17781, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All circle 8H 1/2 round to left; Ladies dance 1/2 RH across & turn
    opp Man LH
9-16::
    Ladies dance 1/2 RH across & turn partner LH (finish on Man''s
    right); all circle 8H 1/2 round to right to original places
17-24::
    Men dance 1/2 LH across & turn opp Lady RH; Men dance 1/2 LH across
    & turn partner 3/4 RH, Men face in, Ladies face out
25-32::
    All dance 1/2 Schiehallion reel to opp place. End with Men joining
    LH in centre, RH with partner all facing anticlockwise
33-40::
    Men dance LH across 1.1/2 times round _while_
::
    Ladies dance 2 steps then pull back RSh & cast back, passing 1 Man
    to join LH with opp Man (e.g. 1L+3M), Ladies dance 2 steps & cast
    back, pass partner RSh & all end in partner''s original place, Ladies
    facing in, Men facing out
41-48::
    All dance 1/2 Schiehallion reel to opp place. End with Ladies
    joining LH in centre, RH with partner all facing anticlockwise
49-56::
    Repeat 33-40 with Ladies dancing LH across & Men casting. End with
    Ladies BtoB in centre facing partner
57-64::
    1s+3s dance 1/2 reel of 4  & turn partner RH to opp side _while_
    2s+4s turn partner RH then dance 1/2 reel of 4 to opp side
65-72::
    Repeat 57-64 to end in original places
73-80::
    All dance Grand Chain (RH to partner to start)

{{title}}
Reel

1-72::
    Repeat Strathspey 1-72 in Reel time
73-80::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13187, '2020-09-15 00:21:01.187829+00', '2023-02-04 01:21:40.160255+00', 16064, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, dance DoSiDo
9-16::
    1s+2s+3s with hands joined dance PdB coupe twice. All 1.1/2 turn RH
17-24::
    1s+2s dance R&L for 6 bars. On last 2 bars full turn LH. 2 1 3
25-32::
    1s+3s dance RH across & finish on side. 1s+2s dance LH across 2 1 3

{{explanation}}
On second repeat 1s break out of hands across. Man dances behind his side to 4th place, lady dances through middle & curves into 4th place. 4s step up 31-32', 0);
INSERT INTO 'dancecrib' VALUES (6677, '2013-08-21 08:31:28.746209+00', '2023-02-04 01:21:40.182914+00', 12335, 3, NULL, 'ace', '1-8::
    1s+3s advance & 1/2 turn opp partner RH, twirl & dance out to opp
    side, 1M+3L dance 1/2 Fig of 8 round 2s _while_ 1L+3M dance 1/2 Fig
    of 8 round 4s
9-16::
    1s in prom hold dance reel of 3 with 2s _while_ 3s in prom hold
    dance reel of 3 with 4s
17-24::
    1s in prom hold dance reel of 3 with 4M+2L (RSh to 4M) _while_ 2s in
    prom hold dance reel of 3 with 2M+4L (RSh to 2M)
25-32::
    1s+3s dance LH across, turn corner persons RH & with partner
    promenade 1 place anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (6316, '2013-08-21 08:31:22.401793+00', '2023-02-04 01:21:40.33079+00', 4195, 3, NULL, 'ace', '1-8::
    1s dance RSh reels of 3 on own sides & continue to 2nd places
9-16::
    1s lead down the middle & back to 2nd places
17-24::
    2s+1s circle 4h round & back to places', 0);
INSERT INTO 'dancecrib' VALUES (8617, '2015-02-13 12:48:05.575909+00', '2023-02-04 01:21:40.353724+00', 15622, 3, NULL, 'ace', '1-8::
    2s set, cross RH, cast round 1st corners, pass LSh to face 2nd
    corners
9-16::
    2s dance Pass+Turn with 2nd corners, pass RSh to face 3rd corners,
    1s Pass+Turn with 3rd corners finish back-to-back in middle (2nd
    place) 2M facing up/2L facing down
17-24::
    Set as in Double Triangles (2), 1s set again, swivelling to face
    opp. sides _while_ corners dance 1 place clk''wise (2 bars). Repeat
    to finish 2M facing down/2L facing up in middle
25-32::
    2s cast round 4th crnr pos. (to right) into 2nd place own sides
    _while_ crnrs set & cross RH.  2s+1s dance up, cast to 3rd/2nd
    places  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (14673, '2022-03-07 02:21:03.003019+00', '2023-02-04 01:21:40.380732+00', 20653, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance down NHJ between 3s & cast up to
    2nd place
9-16::
    1L+2s & 1M+3s dance reels of 3 across, 1s pass 1st corners LSh to
    start. 1s pass LSh to face 1st corners again
17-24::
    1s dance Corner Pass+Turn with 1st corners; 1s repeat with 2nd
    corners (corners dance RSh round each other rather than give hands)
25-32::
    2s+1s+3s chase clockwise round to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12096, '2019-08-30 09:54:44.140856+00', '2023-02-04 01:21:40.635013+00', 19232, 3, NULL, 'ace', '1-4::
    1s & 4s dance in, pull back RSh & dance out, 1s cast down & 4s cast
    up to 2nd/3rd place (2s/3s step down up bars 3-4)
5-8::
    1s & 4s dance 1/2 Fig 8 round 2s/3s to 2nd/3rd place opp sides
9-16::
    All dance DoSiDo with partners then DoSiDo on sides (2L+1M, 4M+3L,
    2M+1L, 4L+3M)
17-24::
    All dance RSh reels of 4 on sides
25-32::
    1s+4s Adv+Ret diagonally. 1s+4s chase clockwise 1/2 round to own
    sides.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4098, '2013-08-21 08:30:43.51053+00', '2023-02-04 01:18:34.223312+00', 300, 3, NULL, 'ace', '1-8::
    1s & 3s cast down 1 place & turn in to join nearer hands facing up
    _while_ 2s & 4s 1/2 turn LH moving up 1 place & face down with
    nearer hands joined, 2s+1s & 4s+3s set, dance RH across once round
    ending with Ladies turning to prom hold with other Man facing out
9-16::
    All dance out to sides & down, on reaching 4th place turn & dance up
    the middle to top & cast Men to original places but Ladies to end 2
    1 4 3
17-24::
    All dance modified »Espagnole«:
::
    1s+2s & 3s+4s cross (Ladies dance across passing between Men)
::
    1s+2s & 3s+4s cross back (Men lead across RH between Ladies) & Men
    change places RH to face partner
::
    2s & 4s turn partner RH as 1s & 3s turn partner LH
25-32::
    1s+4s Set+Link & circle 4H round to left.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14374, '2021-10-11 22:41:16.413026+00', '2023-02-04 01:21:40.676919+00', 20501, 3, NULL, 'ace', '1-8::
    1M followed by 1L dances down middle, couple about turn & 1L
    followed by 1M dances up, remain in centre facing up
9-16::
    1s dance tandem reel of 3 across (LSh to 2M). 2s finish at top, 1s
    face 1st corners
17-24::
    1s dance Corner Pass+Turn with 1st corners, pass RSh to face 2nd
    corners & Pass+Turn with 2nd corners (Corners do not turn, they
    Adv+Ret)
25-32::
    1s dance 1/2 Fig 8 up round 2s; 2s+1s+3s dance DoSiDo with partners.
    End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13424, '2020-12-02 01:21:06.819076+00', '2023-02-04 01:21:40.70023+00', 19901, 3, NULL, 'ace', '1-8::
    2s dance full diagonal reel of 4 with 1st corners, on bar 8 2s pass
    LSh to end back to back in the centre, Man facing up & Lady down
9-16::
    2s dance 1/2 LSh reels of 3 across (Man with 1s & Lady with 3s), 2s
    dance 1/2 RSh reels of 3 on sides (Lady up, Man down) (3) 2 (1)
17-24::
    2s dance full diagonal reel of 4 with 2nd corners, 2s end in 2nd
    place own sides facing out (3) 2 (1)
25-26::
    2s chase clockwise 1 place _while_ 3s+1s Petronella Turn to centre
27-28::
    3s+1s set _while_ 2s dance between them to opposite sides
29-32::
    3s+1s Petronella Turn to sides & set _while_ 2s chase anticlockwise
    to 2nd place own sides 3 2 1
33-40::
    2s dance 1/2 Fig of 8 down round 1s, 2s dance 1/2 Fig of 8 up round
    3s & dance down to 3rd place (1s step up 39-40) 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6679, '2013-08-21 08:31:28.771621+00', '2023-02-04 01:21:40.729725+00', 10968, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s set advancing to join RH & 1L turns
    underneath own right arm, drop hands, to end facing out Ladies side
    with partner behind her
9-12::
    1s dance 1/2 Tandem reel with 1st corners (RSh to 3L) to end in
    middle & both turn right about to face down (1M leading)
13-16::
    1s dance 1/2 Tandem reel with 2nd corners [position] (RSh to 3M) to
    end in middle & both turn right about to face out Men''s side (1L
    leading)
17-24::
    Repeat with 1st corners (3L) & end facing up (1M leading) & repeat
    with 2nd corners (3M) & 1s end facing up nearer hands joined
25-32::
    1s set to 2s, dance up, cross & 1s cast to 2nd place opposite sides
    & cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6680, '2013-08-21 08:31:28.854637+00', '2023-02-04 01:21:40.875002+00', 12057, 3, NULL, 'ace', '1-8::
    1s+2s set advancing to dance round partner RSh & twirl out partner''s
    place, 1s+2s dance RH across 1/2 way
9-12::
    All cross RH & 1s cast to right to end 1L between 2s & 1M between 3s
    in lines across _while_ 2s & 3s set (on diag)
13-16::
    All change places RH (up/down) with opposite person & 1s cast to
    right to end 2nd place opposite sides _while_ 2s & 3s set (on diag)
17-24::
    All turn RH & chase clockwise 1/2 way to own sides with 1s ending
    facing 1st corners
25-32::
    1s turn 1st corner RH & pass partner RSh to face 2nd corner, turn
    corner RH & pass partner RSh to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6681, '2013-08-21 08:31:28.862992+00', '2023-02-04 01:21:40.898807+00', 9162, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s set, dance in & cast (1s follow 2s), 2s meet below 3s & dance
    to top facing out _while_ 1s end in middle in 2nd place facing up
9-16::
    1M dances LH across with 2M+3M as 1L dances RH across on Ladies side
    (3 steps), 2s & 3s continuing to wheel 1s changing sides (3 steps),
    1s dance up to 1st place opposite side _while_ 2s+3s change places
    on sides.  (1) 3 2

{{title}}
Reel

17-24::
    All clap as 1s cross RH, cast & dance RH across, 1L with 3s (at top)
    & 1M with 2s
25-32::
    1M followed by 2s & 1L followed by 3s, pass LSh to change ends, loop
    round & dance LH across 1s end in 2nd places. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6683, '2013-08-21 08:31:29.087581+00', '2023-02-04 01:21:41.012072+00', 11372, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s (1s cross down to start), 1s+2s turn
    other partner on sides (1s dancing between 2s)
9-16::
    2s dance 1/2 Fig of 8 round 1s (2s dance up behind 1s to start),
    1s+2s turn on sides (1s dancing between 2s)
17-24::
    1s+2s set facing diagonally in, dance RH across 1/2 way (to 2 1 on
    own sides), 2M+1L set & 3/4 turn LH into diag line facing partners
25-32::
    2s+1s dance diagonal reel of 4 & on last 2 bars 2M & 1L dance onto
    own side facing partner (1s in 2nd place) _while_ partners loop
    round', 0);
INSERT INTO 'dancecrib' VALUES (12933, '2020-07-01 00:20:53.514933+00', '2023-02-04 01:21:41.040669+00', 17602, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance RH across & LH back to place
9-16::
    1s/3s dance Fig 8 down round 2s/4s
17-24::
    1s NHJ slip step down (4 steps), back up (4 steps) & cast to 4th
    place (2s+3s+4s step up 23-24)
25-32::
    2s+3s+4s+1s circle 8H round & back

{{explanation}}
Note: If danced as 3 couple set, Bars 1-16: danced by 1s+2s only,  Bars 25-32: 2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14562, '2022-01-24 12:42:20.712869+00', '2022-01-24 12:45:08.897526+00', 3001, 1, 202, 'ace', '1--::

  All set | turn P BH ½ and face up NHJ | 1c dance up slightly, cast off to 3plx and dance up to face 1cnrs _while{4}_ 2c following dance up and cast off to 3plx _while{4}_ 3c following dance up to top and cast off to 1plx

9--::

  6 bars of Set to Corners[pos] and Partner. On [14] 1c pull RSh back on 2diag RSh to P | 1c turn P RH to face 3cnrs[pos]

17--::

  ½ Reel4 on 1diag, pass RSh | ½ Reel4 on 2diag (2,1,3)

25--::

  1c+3c Tourbillon (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (4099, '2013-08-21 08:30:43.518492+00', '2023-02-04 01:18:34.24987+00', 11598, 3, NULL, 'ace', '1-8::
    1s set, cross down to 2nd place, 2s+1s+3s set & cross RH
9-16::
    2s+1s+3s Set+Link for 3, 1s dancing to their left dance a 1/2 reel
    of 3 across
17-24::
    2s+1s+3s dance reverse Set+Link for 3 couples (anticlockwise), 2s+3s
    chase anticlockwise 1/2 way _while_ 1s turn LH to 2nd place own
    sides
25-32::
    2s+1s+3s circle 6H back & round (circle right then left)', 0);
INSERT INTO 'dancecrib' VALUES (13279, '2020-10-16 00:21:19.922074+00', '2023-02-04 01:21:41.065593+00', 14543, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s Petronella in Tandem & set, Petronella in Tandem, 2s+1s cross
    RH with partner, 1s remain in centre
9-12::
    1s set, 1/2 turn 2H, pull back RSh & dance out to 2nd place opp
    sides (1M facing down, 1L facing up)
13-16::
    _1/2_ Reels of 3 on sides, 1s RSh to 1s corner, 1s end facing 1st
    corner & all clap twice

{{title}}
Reel

1-8::
    1s dance Corner Pass+Turn with 1st corners, on bar 4 1s 1/2 turn RH
    to face 2nd corners, 1s dance corner Pass+Turn wth 2nd corners
    passing corners LSh.. 1s 1/2 turn LH to end LSh to LSh facing opp
    sides
9-16::
    1L+3s (at top) & 1M+2s dance RH across (3 bars), 3s+1s+2s circle 6H
    1/2 round to left (all on opp sides), all cross RH with partner.  2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (13090, '2020-08-10 00:20:46.425595+00', '2023-02-04 01:21:41.262776+00', 20048, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place (2s step up 3-4), 4s set & cast up 1 place (3s
    step down 7-8) 2 1 4 3
9-16::
    2L & 3M petronella turn into centre & set, 2M & 3L petronella turn
    into centre & set, all end facing partner up or down ready for …
17-24::
    2s+3s dance 1/2 reel of 4, 3M & 2L (with partner following) chase
    1/2 way clockwise behind standing couples back to places 2 1 4 3
25-32::
    1s+4s Set+Link (no hands); all 4 couples dance DoSiDo with partners
    2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9393, '2016-10-06 07:18:45.869238+00', '2023-02-04 01:21:41.277556+00', 17145, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up). 1L+2s & 1M+3s dance RH across  2 1 3
9-16::
    1s set, turn 1/2 RH, face partner, pull back RSh & cast round 1st
    corner into middle, 1L facing down (top), 1M facing up (3rd place)
    _while_ 2M+3L turn 1/2 RH, face each other, pull back RSh & cast to
    diagonally opp place
17-24::
    1s repeat bars 9-16 dancing with 2nd corners. 1s end 2nd place opp
    sides  (3) (1) (2)
25-32::
    3s+1s+2s chase clockwise 1/2 round to own sides (4 bars) & all turn
    partners RH  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6684, '2013-08-21 08:31:29.095825+00', '2023-02-04 01:21:41.29596+00', 4968, 3, NULL, 'ace', '1-8::
    1s turn RH, cast to 2nd place & turn LH (L ending between 2s across
    the dance & M between 3s)
9-16::
    2s+3s set twice _while_ 1s set once & petronella turn to 2nd place
    opposite sides & all set twice on sides
17-24::
    2s+1s+3s dance RSh reels of 3 on sides 1s giving RSh to 2nd corners
    & end BtoB between 2s (1M+2L & 1L+2M facing) for reel of 4 across
25-32::
    1s+2s dance reel of 4 across, 1s meet in centre, 2s curve in behind
    ready for …
33-40::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (6685, '2013-08-21 08:31:29.106085+00', '2023-02-04 01:21:41.332298+00', 7547, 3, NULL, 'ace', '{{title}}
Strathspey

1‑8::
    All circle 8H round & back
9‑16::
    Ladies dance RH across 1/2 way & set to opposite Man, all turn 2H to
    end in St Andrews cross (Ladies RH in middle with Men on outside)
17‑24::
    All wheel clockwise 1/2 way, Ladies set & dance out to place _while_
    Men chase 1/2 round back to place

{{title}}
Chorus

25‑32::
    All couples dance a square - 1s+3s advance to meet opposite person &
    turn 2H, lead out between side couples, separate & dance back to
    places _while_ side couples dance away from each other, turn to face
    opposite person & dance in to meet opposite person, turn 2H & lead
    in to middle, separate & dance out to places

{{explanation}}
End of Chorus

33‑40::
    1s+3s dance 1/2 Ladies Chain, 2s+4s dance 1/2 Ladies Chain
41‑48::
    Repeat Chorus with new partner from new places

{{title}}
Reel

1‑8::
    Ladies dance 2 Petronella turns round set to opposite places & dance
    LH across 1/2 way back to place
9‑16::
    Men dance LH across 1/2 way & dance 2 Petronella turns back to place
17‑24::
    Repeat Chorus
25‑32::
    1s+3s dance 1/2 Ladies Chain, 2s+4s dance 1/2 Ladies Chain
33‑40::
    Repeat Chorus
41‑48::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6687, '2013-08-21 08:31:29.190732+00', '2023-02-04 01:21:41.506629+00', 11826, 3, NULL, 'ace', '1-4::
    All set, 1L+3L cast down 1 pl & dance into middle facing up _while_
    2M+4M cast up 1 pl into middle facing down
5-8::
    2M+1L+4M+3L dance 1/2 reel of 4 up/down & each end facing own sides
9-16::
    3L+2L & 1M+4M pass RSh into reel of 4 across as 1L+4L & 3M+2M pass
    RSh into reel of 4 across & all end own sides.  Men1432, Ladies 3214
17-20::
    All set & 2 centre dancers on both sides Link for 2 _while_ 1M & 4L
    dance 1/2 way down/up the middle _while_ 2M & 3L casts up/down for…
21-24::
    All Men dance RH across on Men''s side _while_ Ladies dance RH across
25-32::
    2M & 3L lead dancers out of the RH across into a chase clockwise (4
    bars) then circle 8H round left to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6688, '2013-08-21 08:31:29.200545+00', '2023-02-04 01:21:41.541925+00', 13732, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate & 1s end facing 4th corners:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & 2s dance on 1 place to own sides as 1s dance in to face 4th
    corners
9-16::
    1s dance 1/2 Diag reel of 4 with corners & 1s turn about to face 3rd
    corners, 1s dance 1/2 reel of 4 with crnrs & end 1M b''tw''n 3s a top,
    1L b''tw''n 2s
17-24::
    1s dance Diag R&L (up/down)
25-32::
    1s cross up/down & cast to right to 2nd place own sides, all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (13425, '2020-12-02 01:21:07.7001+00', '2023-02-04 01:21:41.572793+00', 17792, 3, NULL, 'ace', '1-8::
    1s dance down, cast up round 3s, dance up & cast to 2nd place own
    side (2s step up 7-8)
9-16::
    1s dance Diag R&L (Man down, Lady up). (3) 1 (2)
17-24::
    3s+1s+2s dance Set+Link for 3 couples twice. 2 (1) 3
25-32::
    2s+1s+3s set, 1s turn 1.1/2 RH to 2nd place own side, 2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (6689, '2013-08-21 08:31:29.208594+00', '2023-02-04 01:21:41.601474+00', 13737, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 2 places, turn 2H & cast up to 2nd place opp sides
    _while_ 3s stand (2 bars), dance up to top & turn 2H into 1st place
    (2s step down 7-8).  3 (1) 2
9-16::
    1s dance Diag R&L (1L up, 1M down)  (2) (1) (3)
17-24::
    1s dance reels of 3 on opp sides giving RSh to 2nd corner (pstn)
25-32::
    All Set+Link for 3; 1s turn 2H 1.1/4 times to own sides as 3s+2s
    chase clockwise 1/2 way round.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15346, '2022-12-19 01:21:18.315387+00', '2023-02-04 01:21:41.628448+00', 20776, 3, NULL, 'ace', '1-8::
    Ladies Advance moving slightly to left & set; Ladies dance RSh round
    partners back to place
9-16::
    Men repeat 1-8. 1M faces out & 1L pulls back RSh to face out
17-24::
    1s cast to 4th place (2s+3s+4s step up 19-20); 1s dance DoSiDo
25-32::
    All circle 8H round & back.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6690, '2013-08-21 08:31:29.218499+00', '2023-02-04 01:21:41.654823+00', 9539, 3, NULL, 'ace', '1‑8::
    1s+3s turn RH, cast down 1 place, turn RH (4 bars) to end in prom
    hold (Lady on Men''s left) with 1s facing 2M & 3s facing 4M
9‑16::
    1s & 3s dance RSh reels of 3 across with 2s/4s & into centre facing
    partner (L facing down M up)
17‑24::
    1s+3s set  (Ladies Coupé & set _while_ Men dance Cuts & points)
25‑32::
    1s+3s dance RSh reel of 4 & end in original places
33‑40::
    All Adv+Ret & turn RH into allemande hold
41‑48::
    1s+2s also 3s+4s dance 6 bars of Allemande, 1s cast to bottom
    _while_ 3s lead up to 2nd place _while_ 2s & 4s retire.  2 3 4 1

{{explanation}}
The last time through, there will be a pause at bar 46 to kiss partners & retire', 0);
INSERT INTO 'dancecrib' VALUES (6691, '2013-08-21 08:31:29.226479+00', '2023-02-04 01:21:41.680646+00', 9080, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All set, circle 4H round to left 1/2 way, dance 1/2 R&L back to
    places
9-16::
    All dance RH across & DoSiDo with opposite person
17-24::
    All dance LH across & DoSiDo with partner
25-32::
    All set, change places RH with partner into RH across 1/2 way, turn
    RH to face new couple (Men have partners on their left each
    alternate 32 bars)', 0);
INSERT INTO 'dancecrib' VALUES (6692, '2013-08-21 08:31:29.234496+00', '2023-02-04 01:21:41.712088+00', 4983, 3, NULL, 'ace', '1-8::
    1s+2s+3s set,  circle left (all the way) & end in prom hold facing
    up
9-16::
    1s+2s+3s Promenade & end with 1s casting to 2nd place
17-24::
    1s cross RH & face 1st corner, set to corner, set to partner & set
    to 2nd corner
25-32::
    1s dance reels of 3 on sides giving RSh to 2nd corner, 1s cross RH
    to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6693, '2013-08-21 08:31:29.242737+00', '2023-02-04 01:21:41.73971+00', 4984, 3, NULL, 'ace', '1-4::
    1M & 2M cross, pass ptnrs RSh & cast down to 3rd/4th places _while_
    3L & 4L cross, pass ptnrs RSh & cast up to 1st/2nd places.
5-8::
    All Ladies  (at top) dance RH across _while_ Men also dance RH
    across
9-12::
    1L & 2L cross, pass opposite person RSh & cast down to 3rd/4th
    places _while_ 3M & 4M cross, pass opp person RSh & cast up to
    1st/2nd places.
13-16::
    All set to partners & turn RH into allemande hold
17-24::
    3s+4s+1s+2s dance 6 bars of Allemande, 2s fall back to sides in 1st
    place _while_ 1s+4s+3s set to partner in middle & face up
25-32::
    1s followed by 4s+3s dance up, cross above 2s, cast down on opposite
    sides & cross RH to own sides.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6694, '2013-08-21 08:31:29.250875+00', '2023-02-04 01:21:41.774726+00', 4988, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1L & 4L followed by partners cast 1 place into centre, 2s+1s also
    4s+3s RH across
9-16::
    1s+4s LH across _while_ corners chase clockwise to other end of set,
    3s+1s also 4s+2s 1/2 Ladies Chain
17-24::
    All 1/2 LSh reel of 4 on sides, Ladies set diag _while_ 2M+4M also
    1M+3M turn RH, 2s+4s also 1s+3s dance 1 place on clockwise to end
    facing partners
25-32::
    4L+2M & 3L+1M & 4M+2L & 3M+1L Set+Link on sides, end couples turn RH
    1.1/2 times _while_ centre couples turn RH once to end 2 4 1 3
33-40::
    All circle round & back', 0);
INSERT INTO 'dancecrib' VALUES (12555, '2020-02-02 02:49:03.827907+00', '2023-02-04 01:21:41.804169+00', 19281, 3, NULL, 'ace', '1-8::
    1s+3s Adv+Ret; 1s+3s dance 1/2 R&L
9-16::
    2s+4s repeat 1-8
17-24::
    Ladies dance 1/2 RH across, join LH with opposite Man & all set;
    Ladies turn Men LH into centre, retain hands & set
25-32::
    Men dance 1/2 RH across, join LH with partner & all set; Men turn
    Ladies into centre, retain hands & set
33-40::
    All turn partner 3/4 LH back to places & face partner; all set, Men
    pulling back RSH to face clockwise & all chase 1 place clockwise
41-48::
    All circle 8H round & back.  End 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (6695, '2013-08-21 08:31:29.286022+00', '2023-02-04 01:21:41.897049+00', 9388, 3, NULL, 'ace', '1-4::
    1s turn RH 1.1/2 times moving down the set, end facing out opposite
    sides in second place (2s step up)
5-12::
    1s cast down behind 3s & lead up to 2nd place opposite sides, 1s
    dance out & up behind 2s & lead down to face 1st corners, _while_
    2s+3s dance R&L
13-16::
    1s set to 1st corners & set to 2nd corners
17-24::
    1s dance reel of 3 on sides (RSh to 2nd corners to start) & 1s cross
    to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6696, '2013-08-21 08:31:29.356844+00', '2023-02-04 01:21:42.02254+00', 4990, 3, NULL, 'ace', '1-4::
    1s+2s dance the Bourrel -1M+2L set advcg & turn 2H to end BtoB Lady
    facing up & Man down _while_ their partners chase anticl''wise to
    face prtnr
5-8::
    1s+2s set & 3/4 turn 2H to own sides  2 1
9-16::
    1s+3s repeat bars 1-8 & 2s+3s+1s end in middle for…
17-24::
    2s+3s+1s dance Allemande
25-32::
    1s+2s dance 1/2 R&L _while_ 3s set & cross RH, 2s+3s+1s set & cross
    RH', 0);
INSERT INTO 'dancecrib' VALUES (13912, '2021-04-05 00:21:08.522456+00', '2023-02-04 01:21:42.062125+00', 19493, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 2nd place (2s step up 3-4); 1s set, dance in,
    pull back RSh & dance out to own side 2nd place
9-12::
    2M+1M also 1L+3L Set+Link
13-16::
    1M+2M+3M also 2L+3L+1L Set+Link for 3 couples into lines of 3 across
17-20::
    1L+2M+3M also 1M+2L+3L Set+Link for 3 couples
21-24::
    2M+1M also 1L+3L Set+Link. All now on opp sides (3) (1) (2)
25-28::
    All set, 1s dance 3/4 round each other LSh to end in middle, 1L
    above 1M _while_ 3s & 2s cross passing partner RSh to own sides
29-32::
    Snake Pass:  1M followed by 2s & 1L followed by 3s pass LSh
    diagonally across through 2nd place to change ends, loop round to
    left & dance up/down sides, 1s end in 2nd place own side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9396, '2016-10-06 07:18:46.861833+00', '2023-02-04 01:21:45.681312+00', 17233, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across (4bars) finish facing on the sides. 1s+2s+3s
    dance 1/2 RSh reel of 3 on sides   3 2 1
9-16::
    2s+1s dance LH across (4bars) finish facing on the sides. 3s+2s+1s
    dance 1/2 LSh reel of 3 on sides, 1s+2s finish facing on the sides.
17-24::
    1L+2L & 1M+2M turn RH with polite turn. 1s+2s turn LH & finish in
    the middle for
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (8540, '2015-02-13 12:47:25.521062+00', '2023-02-04 01:18:36.561675+00', 15607, 3, NULL, 'ace', '1-4::
    1M+2M also 3L+4L cross passing partner RSh & cast up/down 2 places
    to end on sides with 4L facing 1M & 3L facing 2M
5-8::
    4L+1M turn 1.1/2 LH & dance out thro'' each others place _while_
    3L+2M twirl & dance towards each other, 4L+1M cast to original
    places _while_ 3L+2M turn 3/4 LH to end in original places
9-16::
    3M+4M also 1L+2L repeat above figure but pass partners LSh & turn RH
    in middle
17-24::
    1s+2s also 3s+4s dance LH across, 2s+3s dance RH across & twirl back
    to places
25-28::
    4s lead up to top & cast into 1st places as 1s+2s+3s Set (Men change
    feet moving left to start) & 3s lead up behind 4s then cast to 2nd
    places as 1s+2s cast down 2 places to end 4 3 1 2
29-32::
    All set & turn partner 2H', 0);
INSERT INTO 'dancecrib' VALUES (4141, '2013-08-21 08:30:44.120606+00', '2023-02-04 01:18:36.590026+00', 360, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, turn LH & cast on own side (Lady up to 1st
    pl & Man down to 3rd pl as 2L & 3M step up/down)
9-12::
    1L+2M 1/2 turn 2H to face 3M _while_ 1M+3L 1/2 turn 2H to face 2L &
    all set
13-16::
    1L+3M also 1M+2L dance LH across 1s end casting, 1L to 1st pl, 1M
    to3rd pl own sides _while_ 2M+3L end in 2 diag lines (1L+3M+2M &
    3L+2L+1M)
17-24::
    All dance diagonal LSh reel of 3 (3M+2M & 3L+2L pass LSh to start)
    [6 bars] ending in bar 8 positions then 1L+2L also 3M+1M 1/2 turn RH
    to end 2 1 3
25-32::
    All set, petronella turn into middle & turn partners 2H 1.1/4 times', 0);
INSERT INTO 'dancecrib' VALUES (6697, '2013-08-21 08:31:29.365127+00', '2023-02-04 01:21:42.106223+00', 4991, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret for 1 step, cross RH, Adv+Ret, cross LH
9-16::
    1s+2s dance the Bourrel:
::
    1M+2L set advancing & 3/4 turn 2H into BtoB position _while_
    partners chase anticlockwise to face own partner, set & 3/4 turn 2H
    to sides
17-24::
    1s cross RH, 2s+1s+3s circle 6H round 1/2 way but after 2 steps Men
    turn Lady (behind) 2H (moving backwards) & continue circle
25-27::
    1s dance 1/2 reels of 3 across - 1L with 3s (at top), 1M with 2s
    giving LSh to 1st corner (pstn)
28-30::
    1s dance 1/2 reels of 3 on sides giving RSh to 2nd corner (pstn). 1s
    end in 2nd place opp sides, 2s at top facing up NHJ, 3s at bottom
    facing down NHJ
31-32::
    1s cross RH to 2nd place own side _while_ 2s & 3s separate & curve
    into place 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6698, '2013-08-21 08:31:29.373191+00', '2023-02-04 01:21:42.142262+00', 4992, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, cross RH & dance round 1st corner RSh to end
    in centre above below 2s/3s
9-16::
    1s dance RH (1L with 2s & 1M with 3s), 2s+3s dance LH across _while_
    1s chase clockwise 1/2 way
17-24::
    1s dance RH across with other couple, 2s+3s dance LH across _while_
    1s chase 1/2 way clockwise
25-32::
    1s turn in centre to 2nd place opposite sides _while_ 2s+3s set &
    cross RH, 2s+1s+3s set & cross back', 0);
INSERT INTO 'dancecrib' VALUES (6699, '2013-08-21 08:31:29.38163+00', '2023-02-04 01:21:42.182392+00', 13734, 3, NULL, 'ace', '1-8::
    1s set & cast down 1 place, 1s dance LSH round 1st corner to finish
    back to back in centre of set facing 1st corner.
9-16::
    "Saltire figure":
::
    _9-10_     1s dance out to 1st corner position _while_ 2M & 3L dance
    across set as 2L & 3M dance into centre & turn LH to face 3rd crnr
    pstn.
::
    _11-12_   2L & 3M dance out to 3rd corner position _while_ 1L & 1M
    dance across set as 2M & 3L dance into centre & turn LH to face 1st
    crnr pstn
::
    _13-14_   2M & 3L dance out to 1st corner position _while_ 2L & 3M
    dance across set as 1s dance into centre & turn LH face 3rd corner
    position
::
    _15-16_   1s dance out to 3rd corner position _while_ 2M & 3L dance
    across set as 2L & 3M dance on one place up/dn on opp side to end:
::
    Ladies'' side:  3L  3M  1L  Men''s side:  1M  2L  2M
17-24::
    All 3 couples set & circle left 2 places to end 2 (1) 3; 1L dances
    1/2 Fig of 8 up round 2s _while_ 1M dances 1/2 Fig of 8 round 3s.
25-32::
    1s+3s Set+Link & circle 4H round to left to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6700, '2013-08-21 08:31:29.391461+00', '2023-02-04 01:21:42.33769+00', 4995, 3, NULL, 'ace', '1-8::
    1s set, cast to 2nd place, set & 1L casts up to end between 2s
    facing down as 1M cast down to end between 3s facing up
9-16::
    2s+1s+3s set twice with 1s petronella turning to Left to own sides,
    2s+1s+3s set on sides & 1s cross to 1st corners
17-24::
    1s turn 1st corners RH, turn partners LH, turn 2nd corners RH & turn
    partner LH to 2nd place own sides
25-32::
    2s+1s+3s advance for 2, give RH to partner & Lady turns under Man''s
    arm, Lady dances back to place as Man retires, 2s+1s+3s repeat using
    LH', 0);
INSERT INTO 'dancecrib' VALUES (6701, '2013-08-21 08:31:29.399612+00', '2023-02-04 01:21:42.372773+00', 10569, 3, NULL, 'ace', '1-8::
    All set, cross RH, 1s+2s also 3s+4s Set+Link (persons casting loop
    into centre)
9-16::
    2L+1M+4L+3M dance reel of 4 in middle & ending BtoB in middle facing
    partners
17-24::
    1s+2s also 3s+4s dance reels of 4 across & end with middle persons
    (followed by 1L/2M or 3L/4M) pass RSh dancing to original places
25-32::
    1s+2s 1/2 turn RH & dance RH across 1/2 way, 1s+3s 1/2 turn RH &
    dance RH across 1/2 way
33-40::
    1s+4s 1/2 turn RH & dance RH across 1/2 way, all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6702, '2013-08-21 08:31:29.407654+00', '2023-02-04 01:21:42.397185+00', 3996, 3, NULL, 'ace', '1-8::
    1s+2s reel of 4 across (1L+2M start passing LSh), 1L & 2M end in
    centre BtoB Lady facing up & Man down _while_ 1M+2L dance round
    clockwise to end facing partner in line of 4 in centre (1s at top)
9-16::
    2s+1s dance 1/2 RSh reel of 4 & turn partners RH 1.1/4 times to own
    sides
17-24::
    2s+1set, turn partners 2H & circle 4H round to left
25-32::
    2s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7957, '2013-08-21 08:31:51.839045+00', '2023-02-04 01:23:13.734819+00', 11984, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s & 3s petronella turn in tandem to face across, set & turn
    opposite person LH & face side couples
17-24::
    All dance reels of 4 across
25-32::
    All turn opposite persons RH & 1s+3s end facing each other, 1s+3s
    set & Petronella-in-tandem into 3rd/1st places
33-40::
    2s+4s dance R&L
41-48::
    All set to partners, turn RH 1.3/4 times into prom hold & dance 1
    place round clockwise
49-56::
    1s+3s dance R&L
57-64::
    All set to partners, turn RH 1.3/4 times into prom hold & dance 1
    place round clockwise
65-88::
    2s+4s repeat bars 9-32
89-96::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6703, '2013-08-21 08:31:29.419104+00', '2023-02-04 01:21:42.412741+00', 4998, 3, NULL, 'ace', '{{title}}
PART 1

1-8::
    All dance 1/2 Grand Chain & set to partners, 3/4 turn RH to end with
    Ladies in centre for LH across
9-12::
    Ladies dance LH across 1/2 way _while_ Men dance 1/4 way round
    clockwise, Ladies 1/2 turn nearest Man RH
13-16::
    Men dance LH across 1/2 way _while_ Ladies dance 1/4 way round
    clockwise & all 1/2 turn partners RH
17-24::
    All repeat bars 9-16 to original places

{{title}}
PART 2

25-32::
    1L & 3M change places RH, cast behind 4s & change places RH to join
    end of line _while_ 1M & 3L dance similarly behind 2s, all set
33-40::
    All Adv+Ret, 1s+2L+4M also 3s+2M+4L circle 4H round to left to end
    in line across (1s & 3s in centre of line)
41-48::
    All Adv+Ret, circle 8H round 1/2 way to end in Sq.Set opposite to
    original places

{{title}}
PART 3

49-72::
    Repeat PART 2 with 2s & 4s as dancing couples, all ending in
    original places

{{title}}
PART 4

73-96::
    Repeat PART 1', 0);
INSERT INTO 'dancecrib' VALUES (10223, '2017-11-04 01:45:52.581918+00', '2023-02-04 01:21:42.573744+00', 11990, 3, NULL, 'ace', '1-8::
    1s followed by 2s (dance up to start) cast below 3s, dance up to
    top, cast to 2nd place & pass LSh to BtoB facing opp sides (2s end
    in 1st place)
9-16::
    Inverting Double Triangles:
::
    _9-12_     2s+1s+3s set (as in Double Triangles) 1s PdB out & turn
    right about to face in _while_ 2s & 3s PdB in & turn right about to
    face out
::
    _13-16_   2s+1s+3s set (Inverted Double Triangle formation), 1s PdB
    in _while_ 2s & 3s PdB out all turning R
17-24::
    1s dance out between corners, cast (Man down, Lady up) round 1st
    corner, pass RSh to dance LH across (2M+1M+3M also 2L+1L+3L)
25-32::
    1s dance out of ends (1M at top, 1L at bottom), cast (Man down, Lady
    up) round 2nd corners.  All turn RH (1s turn 1.1/2 to end 2nd place
    own side)', 0);
INSERT INTO 'dancecrib' VALUES (13913, '2021-04-05 00:21:08.910819+00', '2023-02-04 01:21:42.598532+00', 5001, 3, NULL, 'ace', '1-8::
    1s cast to 2nd place _while_ 2s step up. 1s set advancing to 1st
    corners. 1s turn 1st corners RH, partner LH to finish facing out in
    2nd place
9-16::
    Repeat bars 1-8 with 2nd corners to finish in 3rd place facing out
    (3s step up bars 9-10)
17-20::
    1s cast to 4th place _while_ 4s step up. 1s turn RH into promenade
    hold facing 4M (in 3M place)
21-24::
    1s dance 1/2 reel of 3 with 4s (LSh to 4M). 4s finish in 4th place
    on opposite sides
25-28::
    1s dance 1/2 reel of 3 with 3s (RSh to 3L). 3s finish in 3rd place
    on opposite sides
29-32::
    1s dance 1/2 reel of 3 with 2s (LSh to 2M). 2s finish in 2nd place
    on opposite sides _while_ 1s finish in 1st place own sides
33-34::
    1s 1/2 turn 2H to opposite sides to face down with LH joined _while_
    2s+3s+4s 1/2 turn 2H to form arches in centre
35-38::
    1s lead down slowly for 4 steps under arches crossing below 4th
    place to own sides facing up to follow:
39-40::
    2s+3s+4s+1s NHJ dance up 1 step. 2s+3s (now in 1st & 2nd places)
    continue to dance up _while_ 3s+4s separate & dance to sides. 2s are
    ready to cast & 3s are ready to lead up to top on next repeat.
::
    Note: The last time through all couples should separate on bar 40', 0);
INSERT INTO 'dancecrib' VALUES (6704, '2013-08-21 08:31:29.451765+00', '2023-02-04 01:21:42.638767+00', 5006, 3, NULL, 'ace', '1-8::
    1s set, cross down RH between 2s & cast down behind 3s & dance up
    centre to 2nd place to face out on opposite sides
9-12::
    2s+1s+3s set (as in Double Triangles) 1s PdB out & turn right about
    to face in _while_ 2s & 3s PdB in & turn right about to face out
13-16::
    2s+1s+3s set (Inverted Double Triangle formation), 1s PdB in _while_
    2s & 3s PdB out all turning R about for RH across
17-24::
    2s+1s+3s dance RH across on sides, 1s pass RSh & dance LH across on
    own side ending in lines across 1L between 2s & 1M between 3s
25-32::
    Lines Adv+Ret, 1s turn RH 1.1/4 times to end in 2nd place on own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (13310, '2020-11-02 01:21:14.707235+00', '2023-02-04 01:21:42.783049+00', 5013, 3, NULL, 'ace', '1-10::
    Mirror reels of 5 on sides (1s+3s out/down, 2s+4s in/up, 5s out/up
    to start)
11-12::
    1s+3s cast off 1 place (2s+4s step up)
13-16::
    1s+3s dance 1/2 Fig of 8 round 4s/5s
17-20::
    1s+3s dance 1/2 Fig of 8 round 2s/4s 2 1 4 3 5
21-30::
    All dance Grand Chain (1 step per hand - 2s cross RH, 1s+4s also
    3s+5s change places RH on sides)
31-34::
    1s+3s 3/4 turn partner RH to give LH to 1st corners, 1s+3s balance
    in line
35-38::
    1s+3s repeat bars 31-34 with 2nd corners
39-40::
    1s/3s turn RH into 3rd/5th place own side (4s+5s step up). 1s+3s
    finish facing out ready to start again. 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (13627, '2021-02-04 01:21:07.437041+00', '2023-02-04 01:21:42.798737+00', 16475, 3, NULL, 'ace', '1-8::
    1s set, 1/2 turn RH into prom hold (2s step up 3-4); 1s dance down,
    cross & cast up round 3s to 2nd place own side
9-16::
    2s+1s+3s circle 6H round & back
17-24::
    1s+3s dance »Divided Knot«:
::
    1s+3s set,1/2 turn partners 2H to face down NHJ: 3s split & cast up
    to 2nd place as 1s follow, split & cast to 3rd place, 3s+1s cross RH
    to own side
25-32::
    1s dance up to top & cast to 3rd place; all 3 couples dance RSh
    round partner back to place.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6706, '2013-08-21 08:31:29.480423+00', '2023-02-04 01:21:42.814339+00', 5016, 3, NULL, 'ace', '1-16::
    All petronella turn & set, 1s+2s+3s dance reel of 6 passing partner
    RSh _while_ 4s petronella turn to opposite sides & set
17-24::
    1s+2s+3s petronella to opposite sides & set, 2L+3L+4L advance to
    give RH to partner & LH to next Man & set _while_ 1L casts to 4th pl
    (opp side)
25-32::
    2L+3L+4L dance LSh round Man on left back to opposite sides 1 place
    up, 2M+3M+4M advance to give RH to own partner & LH next Lady & set
    _while_ 1M casts to 4th place (opp side)
33-40::
    2M+3M+4M dance RSh round partners back to opposite sides 1 place up,
    all set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (8846, '2015-08-13 20:33:57.164498+00', '2023-02-04 01:21:42.832336+00', 14281, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    Ladies set, pull back RSh, cast 1 place clockwise;  Men set, pull
    back LSh, cast 1 place anticlockwise
17-24::
    _1/2_ interlocking reels of 4 (1M+3L, 4M+2L, 3M+1L, 2M+4L pass RSh
    to start); All set to prtnr & turn RH
25-32::
    Repeat 17-24 passing prtnr RSh to start; All set & turn RH (1M+3L,
    4M+2L, 3M+1L, 2M+4L)
33-40::
    Repeat bars 9-16
41-48::
    1s+3s dance R&L
49-56::
    2s+4s dance R&L
57-64::
    Repeat bars 9-16, Ladies face out at end
65-80::
    Full Schiehallion Reels (16 bars)
81-88::
    Repeat bars 9-16
89-96::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6707, '2013-08-21 08:31:29.495008+00', '2023-02-04 01:21:42.871898+00', 5019, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cross down to 2nd place opposite side as 2s cast up,
    2s+1s set & 1s cross down to 3rd place own sides as 3s cast up
9-16::
    1s turn RH 1.1/2 times & cast up to 2nd place opp side as 3s step
    down, 2s+1s circle 4H round to left 1s end in centre 1L on left of
    1M) facing 2L
17-24::
    1s set to 2L, turn inwards & set to 3M, turn inwards & set to 3L,
    turn inwards & set to 2M, turn inwards to face Ladies side
25-28::
    1s cross & cast 1L up behind 2L as 1M casts down behind 3L, meet
    partner in centre facing Men''s side
29-32::
    Repeat with 1L casting down & 1M up on Men''s side to end 2nd place
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (6708, '2013-08-21 08:31:29.711306+00', '2023-02-04 01:21:43.096998+00', 7873, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L.  (2)(3)1
9-16::
    1s cross RH & cast up 1 place, 1s turn LH & face 1st corner (pstns)
    _while_ 2s+3s set facing on sides & change places RH
17-24::
    1s dance 1/2 reel of 4 with corners & pass LSh to face 2nd corner
    (pstns), 1s dance 1/2 reel of 4 with corners & end 2nd place
    opposite sides.  2(1)3
25-32::
    1s dance 1/2 Figs of 8 (1M round 2s, 1L round 3s) to 2nd place own
    sides, 2s+1s+3s, turn RH', 0);
INSERT INTO 'dancecrib' VALUES (13037, '2020-08-10 00:18:31.238716+00', '2023-02-04 01:18:36.674123+00', 365, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s+4s cross to opp sides

1-8::
    1s & 4s cross RH & cast in 1 place (2s & 3s step up/down 3-4); 2s+1s
    also 4s+3s Set+Link (Men face out)
9-12::
    1L+2L dance in, turn 3/4 RH, dance out to sides passing Men RSh
    _while_ 1M+2M curve Right, dance in, turn 1.1/2 LH to face partners
::
    4s+3s dance similar
13-16::
    1L+2L dance in passing partner LSh, turn LH & dance out to sides
    _while_ 1M+2M dance round partner''s place anticlockwise & take prom
    hold with partner facing anticlockwise round
17-24::
    »Circulating Allemande«:
::
    _17-20_   All dance anticlockwise round to Ladies'' side: 3s 1s;
    Men''s side: 4s 2s
::
    _21-24_   All face in on sides, all dance in & Men bring partner
    round to face, all retire bars 23-24.  End (3) 4 (1) 2
25-28::
    3s+2s set to partner, turn 2H to end 3s facing down NHJ, 2s facing
    up NHJ
29-32::
    3M+2L dance 1/2 Fig 8 round 4M+1L (Men''s side) _while_ 3L+2M dance
    similar round 4L+1M (Ladies'' side).  End 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (6709, '2013-08-21 08:31:29.737151+00', '2023-02-04 01:21:43.14177+00', 5023, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s
9-16::
    2s dance Fig of 8 round 1s
17-24::
    1s turn RH, cast 1 place & turn LH to places
25-32::
    2s+1s dance R&L

{{explanation}}
Note:  May also be dance as Reel', 0);
INSERT INTO 'dancecrib' VALUES (6710, '2013-08-21 08:31:29.745259+00', '2023-02-04 01:21:43.1604+00', 10949, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, Slip-Step down for 4 steps, set
    turning to face down
9-16::
    2s followed by 1s cast up behind 3s to top on own sides, 2s+1s turn
    on sides (Men LH & Ladies RH)
17-24::
    2s+1s+3s dance reels of 3 on sides (1s in & down to start)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6711, '2013-08-21 08:31:29.753303+00', '2023-02-04 01:21:43.182813+00', 7874, 3, NULL, 'ace', '1-8::
    All 4 Men dance RH across to places; all 4 Ladies dance RH across
    finishing facing out
9-24::
    All dance Alternating Tandem Schiehallion reels (each couple dances
    as one person, the lead changing at each place round set) to end in
    each others original places (Ladies in front of partner)
25-32::
    All chase clockwise 1 place (Ladies leading) & set, 1s+3s (side
    couples) cross RH then 2s+4s cross RH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13311, '2020-11-02 01:21:15.086451+00', '2023-02-04 01:21:43.205016+00', 14448, 3, NULL, 'ace', '1-8::
    1s & 3s turn RH, cast 1 place into centre LSh to LSh with partner
    (2s & 4s step up 3-4), 1M+4s+3L dance RH across _while_ 2s+1L &
    3M+5s dance 1/2 LSh reel of 3 across
9-16::
    1s & 3s (1M & 3L leading) dance 1/2 Alternating Tandem diag reels of
    3 with 1M/3L 1st corners  to face 1M/3L 4th corners'', 1s & 3s (1L &
    3M leading) dance 1/2 Alternating Tandem diag reels with 1M/3L 4th
    corners
17-24::
    1s & 3s (1M & 3L leading) dance 1/2 Alternating Tandem diag reels
    with 1M/3L 3rd corners, 1s+4s+3s chase clockwise to (5) (3) (4) (1)
    (2)
25-32::
    All 1/2 turn partner RH, balance in line down centre, turn partner
    RH to own sides & set.  5 3 4 1 2', 0);
INSERT INTO 'dancecrib' VALUES (12170, '2019-09-04 21:48:12.564887+00', '2023-02-04 01:21:43.226744+00', 19574, 3, NULL, 'ace', '1-8::
    1s followed by 2s lead down & 2s followed by 1s lead back up. 2s end
    in 1st place, 1s in centre facing up
9-16::
    1L crosses in front of 1M, followed by 1M casts round 2M & across
    set, casts down round 3L & up middle to end 1L between 2s facing
    down, 1M between 3s facing up
17-24::
    All circle 6H round & back, ending in line across again
25-32::
    All Adv+Ret; 1s pull back RSh & cast to 2nd place own sides &
    2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (9394, '2016-10-06 07:18:46.444936+00', '2023-02-04 01:21:43.421109+00', 13627, 3, NULL, 'ace', '1-8::
    1s NHJ (briefly) dance down & out between 2s+3s, meet below 3s and
    dance up. 1L turns under 1M''s arm (slow) & 1s take prom hold facing
    down in middle (2s step up 5-6)
9-16::
    1s dance reel of 3 with 3M+2L passing 3M RSh
17-24::
    1s dance reel of 3 with 3L+2M passing 3L LSh.  1s end in middle
    facing down.  Bar 24 2s & 3s dance in & take prom hold facing up
25-32::
    2s+1s+3s dance ''Circulating Allemande''
::
    2s & 3s dance normal Allemande but end in 3rd/1st place as 1s
    Allemande (down) & up to 2nd place opposite sides, 1s cross to own
    sides bars 31-32  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6712, '2013-08-21 08:31:29.763077+00', '2023-02-04 01:21:43.442126+00', 10571, 3, NULL, 'ace', '1-8::
    All 3/4 turn RH, set & all chase clockwise 1/2 way
9-16::
    All 3/4 turn RH, set & all chase clockwise 1/2 way
17-24::
    1s 1/2 turn RH & chase clockwise to 2nd place _while_ 2s step up, 1s
    1/2 turn RH & chase clockwise to 4th place _while_ 3s+4s step up
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6713, '2013-08-21 08:31:29.771204+00', '2023-02-04 01:21:43.45775+00', 5027, 3, NULL, 'ace', '1-8::
    All dance reflection reels of 4 on sides, (Men RSh reel & Ladies
    LSh)
9-16::
    1s+2s dance double Fig of 8 _while_ 3s+4s circle 4H round & back.
    All finish 2H joined with partner ready for …
17-24::
    1s+2s also 3s+4s dance 1/2 Diamond Poussette; 1s+4s dance 1/2
    Diamond Poussette. 2 4 1 3
25-28::
    4s dance 1/2 Fig of 8 round 2s _while_ 1s dance 1/2 Fig of 8 round
    3s _while_ 2s & 3s set & cross RH.
29-32::
    All circle 8H round to left 1/2 way to end 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (14584, '2022-02-05 02:21:00.318166+00', '2023-02-04 01:21:43.482447+00', 20609, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig 8 down round 2s; 1s+2s circle 4H round to left.
    (1) 2 3
9-16::
    1s dance Fig 8 on sides (pass 2s RSh to start)
17-24::
    1s+2s+3s circle 6H round & back
25-28::
    1M+2M change places RH, 1L+2L change places RH.  (2) 1 3
29-32::
    2s+1s set, 2s cross RH to own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6714, '2013-08-21 08:31:29.779253+00', '2023-02-04 01:21:43.532799+00', 10096, 3, NULL, 'ace', '1-8::
    1L+2M also 3L+4M set & change places RH, 1s+2s also 3s+4s dance RH
    across & end facing partners on sides
9-16::
    All dance reel of 4 on sides
17-24::
    1M+2L also 3M+4L set & change places LH, 2s+1s also 4s+3s dance LH
    across
25-32::
    End couples (2s & 3s) set & cross RH to face down/up _while_ 1s+4s
    dance 1/2 R&L, all turn next person on sides RH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6715, '2013-08-21 08:31:29.867335+00', '2023-02-04 01:21:43.562514+00', 10419, 3, NULL, 'ace', '1-8::
    1s lead down for 2 bars, lerad up to top, cross & cast to 2nd places
    opposite sides
9-16::
    2s+1s dance Ladies'' Chain, 1M finishes facing out
17-24::
    1M followed by partner casts down below 3s, up to top & casts on
    Ladies'' side & crosses to 2nd place own sides  2 1 3
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5322, '2013-08-21 08:31:04.78312+00', '2023-02-04 01:21:43.678895+00', 5032, 3, NULL, 'ace', '1-8::
    1L sets twice to 2M, 1M sets twice to 2L
9-16::
    1s lead down the middle, up & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (13608, '2021-02-04 01:18:31.34718+00', '2023-02-04 01:18:34.325754+00', 20213, 3, NULL, 'ace', '1-8::
    1s NHJ dance down the middle (2 bars), 1/2 turn RH (2 bars) _while_
    2s step up; 1s NHJ dance up to 2nd place (2 bars), 1s 1/2 turn LH to
    end on 1st corner diagonal, still holding LH, 1s give RH to 1st
    corner
9-16::
    1s dance the Spoke: Bal-in-Line with 1st corners, then with 2nd
    corners, then with 3rd corners & 4th corners to end 1L between 2s
    facing down & 1M between 3s facing up
17-24::
    All circle 1/2 way to the left; retaining hands all advance into
    middle, all retire
25-32::
    All cross RH over LH & set advancing into middle (2 bars). All drop
    LH & raise RH as they Pas de Basque turning right (2 bars) to face
    out; All dance out to sides & chase clockwise 1/2 way to end 1L
    facing clockwise between 2s at the top and 1M facing clockwise
    between 3s
33-40::
    1s dance 1/2 Fig of 8 (1L gives RSh to 2L, 1M gives RSh to 3M) to
    end 2nd place own sides. 1s dance RH across (Lady with 2s & Man with
    3s)', 0);
INSERT INTO 'dancecrib' VALUES (6717, '2013-08-21 08:31:29.894331+00', '2023-02-04 01:21:43.787015+00', 5033, 3, NULL, 'ace', '1-8::
    1s cast 1 place, cross RH, cast down 1 place, cross LH & cast to 4th
    place
9-16::
    1s cast up retracing above Fig back to places
17-24::
    1s+2s also 3s+4s cross (Ladies under Men''s arches) & repeat back to
    places
25-32::
    1s+2s+3s+4s dance Poussette (1s to 4th place by dancing out to Men''s
    side _while_ other cpls dance out to Ladies side 1 place up)', 0);
INSERT INTO 'dancecrib' VALUES (6718, '2013-08-21 08:31:29.910618+00', '2023-02-04 01:21:43.849046+00', 10818, 3, NULL, 'ace', '1-8::
    1s cast 1 place & cross RH, cast behind 3s & dance up to 2nd place
    opposite sides to end in middle facing up
9-16::
    1L dances LH across & RH across with 2M+3M _while_ 1M dance RH & LH
    across with 2L+3L
17-24::
    1s dance down cross below 3s, cast up to 2nd place & turn RH to end
    facing out on own side
25-32::
    1s dance reels of 3 on sides (1M RSh to 2M, 1L RSh to 3L)', 0);
INSERT INTO 'dancecrib' VALUES (6719, '2013-08-21 08:31:29.918715+00', '2023-02-04 01:21:43.87956+00', 5034, 3, NULL, 'ace', '1-8::
    1s slip step down the middle & back to place
9-16::
    2s repeat, finishing in centre 2nd place facing up
17-24::
    1s+2s turn 1.1/2 times (Ladies RH, Men LH) to finish on sidelines;
    1s dance DoSiDo
25-32::
    2s+1s dance RH across & LH back', 0);
INSERT INTO 'dancecrib' VALUES (6721, '2013-08-21 08:31:29.936715+00', '2023-02-04 01:21:43.932048+00', 5035, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH, lead down middle to 3rd place & turn RH
9-16::
    1s dance reflection reels of 3 on opposite sides (1s up between 3s
    to start)
17-24::
    1s turn 3s on sides (1M+3L RH, 1L+3M LH), 1s lead up to top & cross
    & cast to 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6722, '2013-08-21 08:31:29.950646+00', '2023-02-04 01:21:44.130936+00', 12364, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, dance 1/2 Fig of 8 (Lady round 2s & Man round
    3s)
9-16::
    1s dance RH across (Man with 2s & Lady with 3s), pass RSh to dance
    LH across with other couple
17-24::
    1s dance reels of 3 across (Lady with 2s & Man with 3s) & pass LSh
    into…
25-32::
    1s turn 1st corner RH, partner LH, 2nd corner RH & cross LH to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (8618, '2015-02-13 12:48:06.518705+00', '2023-02-04 01:21:44.160509+00', 15587, 3, NULL, 'ace', '1-8::
    5s dance RSh alternating tandem("dolphin") reel with 1s+3s in
    promenade hold (5s pass 1s RSh to start)
9-16::
    5s dance LSh alternating tandem("dolphin") reel  with 4s+2s in prom
    hold, passing 4s LSh to start, 5s finish facing up in middle.
17-20::
    5L+2s dance RH across as 5M+4s dance LH across, 5 finish facing each
    other in middle
21-24::
    5s set and turn RH into promenade hold facing up
25-32::
    All take ptnrs in prom hold, 5s change pl with 1s RSh, 1s pass 4s
    RSh, 4s pass 3s RSh, 3s pass 2s RSh & 2s end in centre facing 5s', 4);
INSERT INTO 'dancecrib' VALUES (6723, '2013-08-21 08:31:29.959084+00', '2023-02-04 01:21:44.183808+00', 5009, 3, NULL, 'ace', '1-8::
    All turn partners RH & turn corner LH
9-16::
    1s+3s change places RH with opposite person into circle 4H round to
    left & cross back to place RH
17-24::
    2s+4s repeat bars 9-16
25-32::
    1s+3s dance RH across & LH back _while_ 2s & 4s cast to meet other
    partner in 1st & 3rd places, turn RH & dance back to places
33-40::
    2s+4s dance RH across & LH back _while_ 1s & 3s cast to meet other
    partner in 2nd & 4th places, turn RH & dance back to places
41-48::
    All dance round corners LSh (facing corner) & similarly dance RSh
    round partner (Ladies end facing out)
49-64::
    All dance full Schiehallion reel
65-72::
    1s turn partners RH (4 bars);  1s turn LH & 2s turn RH into
    promenade hold facing clockwise (Men on outside)
73-80::
    2s followed by 1s Promenade clockwise round outside of set back to
    places _while_ 3s turn RH & LH with 4s turning RH on bars 77-80
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14737, '2022-04-01 00:21:05.126026+00', '2023-02-04 01:21:44.211818+00', 20652, 3, NULL, 'ace', '1-8::
    1M+2L dance DoSiDo; 1L+2M dance DoSiDo
9-16::
    1s turn RH _while_ 2s+3s Set+Link; 1M+3M also 1L+3M Set+Link
17-20::
    3L+1M change places LH, 3L+2L change places RH
21-24::
    1M+2L change places LH, 2L curves into 1L''s place _while_ 1M remains
    in centre to dance 1/2 RH across with 2M+3M.  End 2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6724, '2013-08-21 08:31:29.968843+00', '2023-02-04 01:21:44.357154+00', 5040, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH to dance reel of 3 with 2s. (1s out & down, 2s in &
    up)
9-16::
    1s & 3s cross back RH to dance reels of 3 on own sides.
17-24::
    1s cast below 3s, meet, lead up & cast to 2nd place.
25-32::
    2s+1s+3s set & cross RH, set & cross back.', 0);
INSERT INTO 'dancecrib' VALUES (4930, '2013-08-21 08:30:57.272189+00', '2023-02-04 01:21:44.391852+00', 8349, 3, NULL, 'ace', '1-16::
    1s set, cross RH, cast below 3s, dance 1/2 Fig of 8 round 3s, slip
    step up to top, cast to 2nd place & cross LH _while_ 2s stand for 2
    bars repeat (without the final crossing) ending in 1st place own
    sides
17-24::
    1s dance reels of 3 on opposite sides giving LSh to 2nd corner & end
    passing RSh to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round to left for 6 steps, pivot left & chase
    back to places', 0);
INSERT INTO 'dancecrib' VALUES (6776, '2013-08-21 08:31:30.756889+00', '2023-02-04 01:21:48.253866+00', 8474, 3, NULL, 'ace', '1-8::
    1s+2s set & cross RH, 1s+2s set & cross back RH
9-16::
    1s lead down the middle & back (2s step in on bar 16)
17-24::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4011, '2013-08-21 08:30:41.443815+00', '2023-02-04 01:18:27.254562+00', 154, 3, NULL, 'ace', '{{explanation}}
2 chords with 1L+3L passing LSh on 2nd chord to face other partner

1-8::
    1s+3s dance reel of 4, Ladies do not finish reel but turn right
    about to face clockwise
9-16::
    All Ladies giving RH in centre & LH to partner wheel round to places
    but 2L & 4L pass LSh to face other partner
17-32::
    Repeat bars 1-16 with 2s+4s dancing
33-40::
    1M & 3M facing partners corner set & turn RH to face other Lady, set
    & turn RH to face own corner
41-48::
    2L+1M+3M+4L dance reel of 4 across ending in original places
49-64::
    Repeat bars 33-48 with 2M & 4M dancing
65-72::
    1L+3L set advancing & turn RH, facing partner set & turn RH
73-80::
    All dance 1/2 Grand Chain & set & turn partner RH
81-96::
    Repeat bars 65-80 with 2L & 4L dancing with1M & 3M ending in centre
97-104::
    1s+3s Bal-in-Line, turn ptnr RH (Ladies in centre) & Bal-in-Line,
    turn ptnr RH (Men in centre) & Ladies turn right about (LH to ptnr)
105-112::
    All Men giving LH in centre & RH to partner wheel round
    anticlockwise to places
113-128::
    Repeat bars 97-112 with 2s & 4s dancing', 0);
INSERT INTO 'dancecrib' VALUES (10630, '2018-04-16 21:42:22.837297+00', '2023-02-04 01:21:44.420697+00', 14023, 3, NULL, 'ace', '1-8::
    1s+2s set, 1L casts down _while_ 2M casts up _while_ 1M+2L pass LSh
    to face partners on 1st corner diagonal; 1s+2s dance 1/2 diag reel
    of 4
9-16::
    1s+2s dance "Revolving Chain":
::
    _9_         1s+2s 1/2 turn partner RH
::
    _10_       1L+2M turn 3/8 LH _while_ partners dance 1/8 round
    outside (into line up/down)
::
    _11-14_  Repeat bars 9-10 twice (bar 12 - line on 2nd corner
    diagonal, bar 14 - line across set)
::
    _15-16_  Men turn 3/4 RH, Ladies turn 3/4 RH all to progressed
    positions, 1M & 2L face out
17-24::
    1M casts up, 2L casts down, dance DoSiDo & set _while_ 1L+2M dance
    DoSiDo, set twice Advancing, passing retiring 2L / 1M & passing each
    other to face partner on diagonal
25-32::
    1s+2s turn partner 2H (2 bars), dance 1/2 poussette and set', 0);
INSERT INTO 'dancecrib' VALUES (6725, '2013-08-21 08:31:29.984702+00', '2023-02-04 01:21:44.436845+00', 9075, 3, NULL, 'ace', '1-8::
    1s+2s+3s Set+Link for 3, set up/down & change places RH with
    opposite person
9-16::
    2s dance RSh reels of 3 (Lady with 1s at top & Man with 3s), 1s cast
    to 2nd place & 2s dance up to top (2s on opposite sides)
17-24::
    2s+1s+3s Set+Link for 3, set up/down & change places RH with
    opposite person
25-32::
    1s dance RSh reels of 3 across (Lady with 2s at top & Man with 3s),
    2s cast to 2nd place & 1s dance up to top (1s& 2s on opposite sides)
33-40::
    2s followed by 1s cross down between 3s & cast up own sides, 2s
    dance into centre & loop into 1st place facing out, 2s+1s turn on
    sides', 0);
INSERT INTO 'dancecrib' VALUES (14431, '2021-11-06 01:12:37.454455+00', '2023-02-04 01:21:44.451759+00', 5046, 3, NULL, 'ace', '1-4::
    1s & 4s set, change places RH with partner, to finish in the middle,
    side by side retaining hands (1s face down & 4s face up)
5-8::
    1s+4s set, advance & turn right about ending back to back in centre
    (2s+3s step up/down bars 7-8). 2 1 4 3
9-12::
    1s with 2s, 4s with 3s, set & turn 2H. 1s+4s end in middle facing
    each other
13-16::
    1s+4s set, 1L+4L also 1M+4M change places RH to end back to back in
    centre
17-20::
    1s with 3s also 4s with 2s set & turn to remain in centre
21-24::
    1s+4s set, pass LH.
25-32::
    All dance reel of 4 on sides (1L/1M give RSh to 2M/2L
33-34::
    1s+4s (middle couples) cross RH with partner
35-40::
    1s followed by 4s&3s, cast up on own sides behind 2s, meet at top &
    lead down to bottom 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12097, '2019-08-30 09:54:45.426806+00', '2023-02-04 01:21:44.490443+00', 19233, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 2s+1s+3s Adv, 2s+3s Ret _while_ 1s turn
    LH to face 1st corners
9-16::
    1s turn 1st corners RH to end 1M between 3s facing down, 1L between
    2s facing up.  1s set & change places LH up/down & cast to left to
    2nd place own side.  Bar 16: 2s+3s face diagonally in.
17-24::
    2s+3s Set & Rotate. 3 1 2
25-28::
    1s cross RH _while_ 3s+2s 1/2 turn partners RH to face down/up NHJ;
    All set, 1s to each other across, 3s+2s up/down
29-32::
    All dance 6H 1/2 round to the left. 2 1 3
33-40::
    2s+1s+3s dance Grand Chain (2s cross, 1s+3s change place on sides).
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6726, '2013-08-21 08:31:29.99476+00', '2023-02-04 01:21:44.531343+00', 12760, 3, NULL, 'ace', '1-8::
    All Ladies dance RH across, pass partner RSh & chase around set to
    opposite sides
9-16::
    All Ladies dance RH across, pass opposite partner RSh & chase around
    set to own sides
17-32::
    Men repeat but pass partners LSh & dance LH across ending back in
    places
33-40::
    1s+3s cross RH & set _while_ 2s+4s set & cross RH, all repeat back
    to places
41-44::
    All facing corners set & turn RH,
45-52::
    Ladies diagonal dance R&L (starting with 1L+2L & 3L+4L)
53-56::
    All set to partners & turn RH
57-64::
    Men repeat bars 45-52 (Starting with 1M+4M & 2M+3M)
65-72::
    All dance Grand Chain
73-88::
    All dance Schiehallion Reels
89-96::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10089, '2017-09-03 23:45:12.603517+00', '2023-02-04 01:21:44.575189+00', 5061, 3, NULL, 'ace', '1-8::
    1s+2s set twice, 1s+2s dance RH across to finish beside partner, 1s
    facing down 2s facing up
9-16::
    1s+2s set twice, 1s+2s dance RH across to finish in centre into
    promenade hold facing up
17-24::
    1s+2s dance the Allemande
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6727, '2013-08-21 08:31:30.002812+00', '2023-02-04 01:21:44.599211+00', 5062, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1L followed by partner casts 1 place & 1L
    crosses to 2nd place opposite sides
9-16::
    1s+3s dance LH across, 1L followed by partner casts down 1 place &
    1L crosses to 3rd place own side
17-24::
    1s set, dance up to top & cast to 2nd place
25-32::
    2s+1s R&L', 0);
INSERT INTO 'dancecrib' VALUES (6778, '2013-08-21 08:31:30.773329+00', '2023-02-04 01:21:48.335574+00', 9475, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s petronella turn to centre, turning RH dance out of ends &
    cast down/up to 2nd/3rd places on original sides
9-16::
    1L+4M also 1M+4L in prom hold dance LSh reel of 3 with 2s/3s
17-24::
    1s & 4s dance up/down between 2s/3s & cast down/up to 2nd/3rd place,
    1s+4s 1/2 R&L
25-32::
    All dance reel of 4 on sides.  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (4103, '2013-08-21 08:30:43.556415+00', '2023-02-04 01:18:34.403939+00', 306, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, cross RH & turn 2H to face down (on
    opposite sides)
9-16::
    1s lead down, cross below 3s, cast to top own sides, 1s+2s 1/2 turn
    RH & circle 4H round to left 1/2 way
17-24::
    1s set advancing to 1st corner, turn corner 2H, set to 2nd corner &
    turn 2H to end 2nd place opposite sides
25-32::
    1s dance 1/2 reel of 3 on sides giving LSh to 1st corners, 3s & 2s
    cross RH _while_ 1s turn RH & 3s+1s+2s circle 6H round to left 1/2
    way', 0);
INSERT INTO 'dancecrib' VALUES (6728, '2013-08-21 08:31:30.010811+00', '2023-02-04 01:21:44.627221+00', 5064, 3, NULL, 'ace', '1-4::
    1L dances crosses down & casts down behind 3M & into middle below 3s
    _while_ 1M dances across, round 2nd Lady & into centre below 2s
5-8::
    1s+3s dance LH across
9-16::
    1L dances round 3L into middle below 2s facing up _while_ 1M dances
    round 2M into middle above 2s & faces down; 1s+2s dance RH across
17-24::
    1s set to each other (up/down), 1s 3/4 turn RH & face up, 1s dance
    up & cast to 2nd place own sides (2s step up 23-24)
25-32::
    1s dance LSH reels of 3 across (1L with 2s & 1M with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (6729, '2013-08-21 08:31:30.020504+00', '2023-02-04 01:21:44.752704+00', 5065, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, lead down between the 3s, cross & cast up
    to 2nd place on opposite sides
9-16::
    2s+1s+3s set & dance reels of 3 across, 1L with 2s, 1M with 3s
17-24::
    2s+1s+3s dance reels of 3 on sides, 1s cross RH & holding nearer
    hands face up
25-32::
    2s+1s circle 4H round to left, 1s turn about & 1s+3s circle 4H round
    to right', 0);
INSERT INTO 'dancecrib' VALUES (13531, '2021-01-09 01:21:03.624261+00', '2023-02-04 01:21:44.786781+00', 17693, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH & pull back RSh & dance out to opposite side. 1s cast
    one place (2s step up bars 5-6). 1s 1/2 turn LH as 2s+3s step in to
    take promenade hold facing up
9-16::
    2s+1s+3s dance Allemande
17-20::
    3s+1s dance 1/2 RH across, 3s+2s dance 1/2 LH across
21-24::
    1s turn 1.1/2 RH _while_ 2s turn 1.1/2 LH, both couples finishing in
    centre ready for …
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6730, '2013-08-21 08:31:30.028475+00', '2023-02-04 01:21:44.819058+00', 7480, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place & dance 1/2 Fig of 8 around 2s/3s
9-16::
    1s+4s dance RH across, 2s+1s also 4s+3s dance LH across
17-24::
    1s+4s dance R&L but turn last person full LH to change places.  2 4
    1 3
25-32::
    All dance RSh reels of 4 on sides', 0);
INSERT INTO 'dancecrib' VALUES (6731, '2013-08-21 08:31:30.036908+00', '2023-02-04 01:21:44.854771+00', 11934, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, cross down below 3s & cast up to 2nd place
9-16::
    2s+1s+3s dance 1/2 reel of 3 on sides (1s in & up to start),
    3s+1s+2s set, 1s turn RH 1.1/4 times to face 4th corner pstns
    _while_ 3s & 2s cross RH
17-24::
    1s dance Pass+Turn with 4th corners, 1s loop round to right in
    centre to face 3rd corners & dance 1/2 diagonal reel of 4 with 3rd
    corners & 1s loop round to face 2nd corners
25-32::
    1s dance 1/2 diagonal reel of 4 with 2nd corners, 1s loop round to
    face 1st corners & dance Pass+Turn with 1st corners & end crossing
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6732, '2013-08-21 08:31:30.045422+00', '2023-02-04 01:21:44.923722+00', 10052, 3, NULL, 'ace', '1-8::
    1s cross RH & cast down to 2nd place, cross LH & 1L casts up _while_
    1M casts down
9-16::
    1s dance reels of 3 across RSh to 1st corners (1M followed by Ghost)
    & 1/2 turn LH in middle to face 3rd corners
17-24::
    1s dance RSh reels of 3 across (Man with 2s & Lady with 3s) & pass
    RSh to face 1st corners
25-32::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partner LH back
    to 2nd place own side

{{explanation}}
1st Ghost (1st 32 bars)

1-8::
    4M stands for 8 bars
9-16::
    4M ''ghosts'' 1M in reel with 3s & joins in with LH turn
17-24::
    4M ''ghosts'' 1L reeling with 3s & changes to ''ghost'' 1M who faces 1st
    corner
25-32::
    4M joins in with 1M turning 1st corner & dances long way round to
    lead 1M into 2nd corner, joins in RH turn & crosses back to place

{{explanation}}
2nd Ghost (2nd 32 bars)

1-8::
    Original 2nd Lady (now in 1st place) stands for 8 bars
9-16::
    Lady ''ghosts'' 1L in reel with 3rd couple & joins in with LH turn
17-24::
    Lady ''ghosts'' 1M reeling with 3rd couple & changes to ''ghost'' 1L who
    faces Ladies 1st corner
25-32::
    Lady joins in with 1L turning 1st corner & dances long way round to
    lead 1L into her 2nd corner, joins in RH turn & crosses back to
    place

{{explanation}}
Deviser''s note:  this jig may be danced with or without "The Ghost"', 0);
INSERT INTO 'dancecrib' VALUES (6733, '2013-08-21 08:31:30.059356+00', '2023-02-04 01:21:45.141144+00', 8729, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 round 2s+3s on own sides dancing between 2s to
    start
9-16::
    1s dance DoSiDo, cast 1 place & 3/4 turn RH to face out on Men''s
    side with nearer hands joined (Lady on Mans right)
17-24::
    1s dance out Men''s side & cast back to middle (Lady up & Man down),
    dance out Ladies side & cast back to middle facing up (Lady on Mans
    right)
25-32::
    2s+1s dance RH across & LH back (1s end in 2nd place own sides)
33-40::
    1s turn RH, lead up between 2s & cast to 3rd place own sides
41-48::
    3s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6734, '2013-08-21 08:31:30.067511+00', '2023-02-04 01:21:45.16168+00', 14799, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set & Rotate:
::
    Set, Rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl & 3s in 4th pl).
    2 1 4 3
9-16::
    2s+1s also 4s+3s dance RH across, 1s+4s dance LH across
17-24::
    All dance reels of 4 ending & 1s facing 2s also 4s facing 3s
25-32::
    All turn RH on sides, 1s+4s dance LH across 1/2 way & cross LH to
    own sides.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9219, '2016-06-16 22:42:10.552315+00', '2023-02-04 01:21:45.187301+00', 16877, 3, NULL, 'ace', '1-8::
    1s set, cross passing RSh, 1s+2s change places by turning 1.1/2
    times (1M+2L RH, 1L+2M LH)
9-16::
    1L+2s (at top) also 1M+3s (at bottom) dance LH across, 1s swap end
    to dance RH across
17-24::
    1s set, 1M casts down 1 place as 1L casts up 1 place, meet facing
    up/down in middle & turn 2H 1.1/4 times to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (6735, '2013-08-21 08:31:30.075576+00', '2023-02-04 01:21:45.217362+00', 11787, 3, NULL, 'ace', '1-8::
    1s+2s set, 1/2 turn 2H to face down/up to each other, set & circle
    4H 1/2 way round to left
9-16::
    1s set, turn RH, cast on own side to left & face 1st corners
17-24::
    1s set to corners & turn RH, cast on opposite side to left & face
    2nd corners
25-32::
    1s set to corners & turn RH, 1M dances up between 2s & casts left to
    2nd place _while_ 1L dances down between 3s & casts left to 2nd
    place', 0);
INSERT INTO 'dancecrib' VALUES (4105, '2013-08-21 08:30:43.572871+00', '2023-02-04 01:18:34.454012+00', 309, 3, NULL, 'ace', '{{explanation}}
 3s & 4s start on opp. sides

1-8::
    2s+3s set, 2L followed by partner casts down 1 place & dance LSh
    round 4M to 2nd place opp sides _while_ 3L followed by partner casts
    up & dance LSh round 1M to 3rd place correct sides
9-16::
    1s+2L also 3s+4L dance RH across, 1s+2M also 3s+4M dance LH across
    all back to original places
17-24::
    1M followed by partner casts down to 3rd place opp sides _while_ 4M
    casts up to 2nd place correct sides, 2s+4s also 1s+3s turn RH on
    sides
25-32::
    All circle 8H round & back.  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (4106, '2013-08-21 08:30:43.584498+00', '2023-02-04 01:18:34.511739+00', 11801, 3, NULL, 'ace', '1-8::
    1s & 3s turn RH, cast down 1 place, 3/4 turn partner 2H, set
    advancing to end BtoB in centre Men facing up & Ladies down (2s & 4s
    step up 3-4)
9-16::
    2s+1M also 1L+4s+3M also 3L+5s circle round & back.  1s & 3s end in
    centre facing opp sides
17-24::
    1s+3s dance reel of 4 up/down centre (pass partner RSh to start)
25-32::
    1s & 3s 3/4 turn partner 2H, cast 1 place on own sides (4s & 5s step
    up), turn partner LH & all set.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (13426, '2020-12-02 01:21:10.889932+00', '2023-02-04 01:21:45.244887+00', 17797, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s+2s circle 4H round to left, 1s dance down 1 place
    _while_ 2s step up & 3s set
9-16::
    1s+3s circle 4H round to left; 1s followed by 3s lead down & cast up
    round 4s, flowing into …
17-24::
    Mirror reels of 3 on sides (1s dance in/up, 2s out/down, 3s out up
    to start)
25-32::
    1s+3s dance 1/2 R&L; 3s+1s cross RH with partner, 1s+4s change
    places LH on sides.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6736, '2013-08-21 08:31:30.083551+00', '2023-02-04 01:21:45.290074+00', 10403, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back
9-16::
    1s+2s+3s dance reels (6 bar) of 3 on sides (1s out & down to start)
    & 1s+2s continue to change places
17-24::
    2s+1s dance double Fig of 8 (1s cross up to start)
25-32::
    1s+3s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (8619, '2015-02-13 12:48:06.670604+00', '2023-02-04 01:21:45.312735+00', 15695, 3, NULL, 'ace', '1-8::
    All dance Grand Chain back to place, Ladies face out
9-24::
    All dance full Schiehallion Reel
25-32::
    1s & 3s turn partner RH & Men followed by partners chase clockwise,
    dancing behind 2s/4s with Ladies passing between side couples, 1s+3s
    pass RSh to original places
33-40::
    2s & 4s turn LH & Ladies followed by partners chase anticlockwise
    dancing behind 1s/3s with Men passing between end couples, 2s+4s
    pass LSh to original places
41-48::
    All set & petronella-in-tandem 1 place to right, set & turn partner
    2H', 0);
INSERT INTO 'dancecrib' VALUES (14375, '2021-10-11 22:41:19.914176+00', '2023-02-04 01:21:45.332269+00', 20491, 3, NULL, 'ace', '1-8::
    1s+2s set, turn partner 2H, opening out to circle 4H round to left
9-16::
    1s dance 1/2 Fig 8 down round 2s; 1s dance 1/2 Fig 8 down round 3s
    (2s step up  to end facing 1st corners)
17-24::
    1s dance Corner Pass+1/2 Turn & Twirl with 1st corners, pass RSh &
    repeat with 2nd corners (as Corner Pass+Turn but corners only 1/2
    turn RH then pull back RSh & dance out to opp corner). End (3) 1 (2)
25-32::
    3s+1s+2s dance diag R&L (Man down, Lady up).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13312, '2020-11-02 01:21:16.891879+00', '2023-02-04 01:21:45.356704+00', 17308, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Diamond Poussette
9-16::
    2s+3s dance Set & Rotate:
::
    Set, Rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides. 1 3 2 4
17-20::
    3s+2s dance RH across to finish on sides _while_ 1L & 4M followed by
    partners chase clockwise 1/2 way (4) 3 2 (1)
21-24::
    4s+1s dance RH across to finish on sides (2nd & 3rd places) _while_
    2L followed by 3L also 3M followed by 2M chase clockwise 1/2 way to
    finish  (2) (4) (1) (3)
25-32::
    All 1/2 turn partner RH, pull back RSh & dance out to own sides;
    2s+4s & 1s+3s circle 4H round to left 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6737, '2013-08-21 08:31:30.120486+00', '2023-02-04 01:21:45.393009+00', 12836, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, turn LH 1.1/4 times to join RH with 1st
    corners
9-16::
    1s+1st corners Bal-in-Line & dance 1/2 reel of 4 with corners then &
    1s 3/4 turn LH to join RH with 2nd corners
17-24::
    1s+2nd corners Bal-in-Line & dance 1/2 reel of 4 with corners then
    1s 1/2 turn LH
25-32::
    1s dance RH across (1M+3s at top, 1L+2s) end 2nd place opp sides,
    all chase clockwise 1/2 way.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8345, '2014-07-29 12:59:21.370556+00', '2023-02-04 01:21:45.418425+00', 15340, 3, NULL, 'ace', '1-8::
    1L+2L also 3M+4M Set+Link, 1L+4M change places LH & 1L+3M also 2L+4M
    change places RH on sides
9-16::
    1M+2M also 3L+4L Set+Link, 1M+4L change places LH & 2M+4L also 1M+3L
    change places RH on sides
17-24::
    2s+3s dance 1/2 R&L, all dance 1/2 RSh reels of 4 on sides.
    (1)(2)(3)(4)
25-32::
    1s+2s also 3s+4s dance 1/2 RH across & 1s+4s dance 1/2 LH across,
    4s+1s set & cross LH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6738, '2013-08-21 08:31:30.156706+00', '2023-02-04 01:21:45.434532+00', 10065, 3, NULL, 'ace', '1-8::
    1s+2s set facing on sides & change places RH, set again to same
    person & 3/4 turn RH into line of 4 across (1M+2L in centre facing
    each other
9-16::
    1s+2s dance reel of 4 across (1M+2L passing LSh to start) ending
    with 1s in 2nd place facing down
17-24::
    1s+3s dance R&L starting on sides & 1s end facing 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places as others clap', 0);
INSERT INTO 'dancecrib' VALUES (14214, '2021-08-14 00:21:15.76261+00', '2023-02-04 01:21:45.456349+00', 12367, 3, NULL, 'ace', '1-4::
    1s+3s face down, 2s+4s face up. All turn facing person (RH on Men''s
    side, LH on Ladies'' side)
5-8::
    1s+3s dance 1/2 Fig of 8 round couple below to finish 1s+3s facing
    down, 2s+4s up (1) 2 (3) 4
9-16::
    All dance 1/2 Grand Chain, start by changing places RH on the sides
    (2 bars/hand) (4) 3 (2) 1
17-24::
    4s+2s repeat bars 1-8. At the end 4s+2s dance in & take Promenade
    hold _while_ 3s step in on bar 24 (order  4 3 2 1) ready for …
25-32::
    4s+3s+2s (top 3 couples) dance  3 couple Allemande. End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12818, '2020-05-14 23:15:43.264861+00', '2023-02-04 01:21:45.474241+00', 19939, 3, NULL, 'ace', '1-8::
    1s set, 1L followed by 1M casts 2 places, crosses set & casts up
    behind Men''s line, 1M up centre to end in 2nd place opp sides (2s
    step up 7-8)
9-16::
    2s+1s dance Men''s Chain. Bar 15-16 finish RH turn in line of 4
    across between 1st/2nd place (1M+2L & 2M+1L facing)
17-24::
    Reel of 4 across 1M+2M pass RSh at end to finish with 1s in 2nd
    place opp sides.  2 (1) 3
25-32::
    1s set, 1M followed by 1L casts below 3L, crosses set, casts up
    behind Men''s line, 1L up centre to end in 2nd place own sides.  2 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (4143, '2013-08-21 08:30:44.13657+00', '2023-02-04 01:18:36.70895+00', 366, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH moving down to 2nd place, set & turn 2H 1.1/4 times
    to face 4th corners
9-16::
    1s dance reels of 3 across (1L+2s also 1M+3s) & 1s end 1/2 turning
    4th crnrs 2H to face in diag NHJ _while_ other crnrs set
17-20::
    1s+4th corners set & dance 1/2 RH across _while_ other corners (3L &
    2M) dance anticlockwise 1/2 way
21-24::
    1s (in 2nd pl) joining with other corner (1L+3L & 1M+2M) set & dance
    1/2 LH across _while_ other corners (3M & 2L) dance clockwise 1/2
    way
25-32::
    2s+1s+3s set, petronella turn; 1/2 turn partner 2H & petronella turn
    to places. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6739, '2013-08-21 08:31:30.1648+00', '2023-02-04 01:21:45.495889+00', 5079, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s turn RH, cast 1 place & dance 1/2 Fig of 8 (1L round 2s & 1M
    round 3s)
17-24::
    1s dance Diag R&L to end 3 1 2 on opposite sides
25-32::
    3s+1s+2s set, turn RH & chase clockwise 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (9395, '2016-10-06 07:18:46.838516+00', '2023-02-04 01:21:45.577659+00', 14816, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s+4s cross to opp sides

1-2::
    1s, 2L+3M, 2M+3L & 4s turn 3/4 RH, retain hands as 1M+2L+4M+3L join
    LH in centre to form a Cross
3-6::
    All set, all pull back RSh to change hands re-forming the Cross &
    all set
7-8::
    1s, 2L+3M, 2M+3L & 4s turn 3/4 LH to original places
9-16::
    1s+2s dance 1/2 R&L (1M omit polite turn).  1s+3s dance 1/2 R&L
17-20::
    1s+4s set, 1s cast to 4th place, 4s dance up to 3rd place & face out
21-24::
    2s & 1s set Adv to partner, 1/2 turn 2H _while_ 3L+4M & 3M+4L set,
    turn 2H once round & all form circle
25-32::
    Circle 8 hands round and back.', 0);
INSERT INTO 'dancecrib' VALUES (15142, '2022-10-05 00:21:16.600052+00', '2023-02-04 01:21:45.591001+00', 20783, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); lead down & cast up round 3s to 2nd place
    opp sides
9-16::
    2s+1s+3s set advancing, 1/2 turn partner 2H (PdeB); 1s dance in
    towards partner, pull back RSh & dance 1M up, 1L down into lines of
    3 across, 1M between 2s, 1L between 3s
17-24::
    Lines of 3 across set advancing & 1/2 turn partner 2H (PdeB); 1s
    dance in towards partner, pull back RSh & dance out to 2nd place own
    side
25-32::
    3s & 2s chase clockwise 1/2 round _while_ 1s Adv+Ret; 2s+1s+3s turn
    partners RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6741, '2013-08-21 08:31:30.182487+00', '2023-02-04 01:21:45.633879+00', 5083, 3, NULL, 'ace', '1-8::
    1s cast 1 place & cross RH, cast down 1 place dance up to 2nd place
    opposite sides
9-16::
    1s dance reflection reels of 3 on opposite sides (out & up to start)
    ending in middle facing 2s
17-24::
    1s+2s set facing & set to partners, 1s lead up & cast to 2nd place
    ending in middle facing 3s
25-32::
    1s+3s set facing & set to partners, 1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (6742, '2013-08-21 08:31:30.190842+00', '2023-02-04 01:21:45.654165+00', 9177, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across, chase 1 place (cl''wise) & turn
    partner RH 1.1/4 times to end in line across (1L+2M BtoB in centre
    facing partners)
9-16::
    1s+2s dance reel of 4 across
17-24::
    1s+2s dance variation of Highland Schottische Poussette :
::
    1s set HS step with both hands joined dancing down _while_ 2s set &
    dance up ending with a 1/4 turn to right
::
    1s dance HS across to Ladies side & 2s dance across to Mens side
    ending with a 1/4 turn to right
::
    1s dance up _while_ 2s dance down ending with a 1/4 turn to right
::
    1s+2s dance into middle without the final turn & end in a line
    up/down middle (Men facing up & Ladies down)
25-32::
    1s+2s dance the Knot starting with a turn 3/4 RH into Allemande hold', 0);
INSERT INTO 'dancecrib' VALUES (6743, '2013-08-21 08:31:30.198837+00', '2023-02-04 01:21:45.70233+00', 10077, 3, NULL, 'ace', '1-8::
    1s & 3s set & dance down 1 place, cast behind 4s/5s & dance up to
    face Mans 2nd corner in prom hold
9-16::
    1s & 3s dance diagonal reel of 3 with 2nd corners
17-24::
    1s & 3s dance up (Lady followed by Man) & dance LH across with
    2M/4M, 1s & 3s dance RH across with 4L/5L
25-32::
    1s & 3s turn 2nd corners LH, turn partner RH & cast on own sides to
    3rd/5th places', 0);
INSERT INTO 'dancecrib' VALUES (6744, '2013-08-21 08:31:30.212543+00', '2023-02-04 01:21:45.831194+00', 5088, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance 1/2 Fig of 8 around 2s
9-16::
    2s+1s+3s Adv+Ret 2 steps & turn partner RH
17-24::
    1s cross down between 3s, cast up to 2nd place, lead up & cast to
    2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15347, '2022-12-19 01:21:21.956857+00', '2023-02-04 01:21:45.849402+00', 19306, 3, NULL, 'ace', '1-8::
    1s+2s set, turn partner 2H flowing into 1/2 Strathspey (Diamond)
    Poussette. 1s finish facing 1st corners.  2 1 3
9-16::
    1s dance 1/2 diagonal RSh reel of 4 with 1st corners, pass RSh to
    dance 1/2 diagonal reel with 2nd corners (3) (1) (2)
17-24::
    1s dance a One Couple knot:
::
    _17-18_ 1s 1/2 RH turn into Allemande hold facing up
::
    _19-20_ 1s dance LSh round 3L & face down along Men''s side
::
    _21_  release RH, 1M guides 1L in front to face down just outside
    the Men''s side with LH joined
::
    _22_  1M dancing down & slightly in, guides 1L into centre
::
    _23-24_  1s 1/2 turn LH to 2nd place opposite sides
25-32::
    3s+1s+2s set & turn partners 2H to face clockwise; all chase
    clockwise 1/2 way round to own sides 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13914, '2021-04-05 00:21:11.480382+00', '2023-02-04 01:21:45.872644+00', 14499, 3, NULL, 'ace', '1-8::
    1s+3s Petronella in tandem to face each other in the centre, 1s+3s
    set, 1s+3s dance LH across to finish 1s/3s facing 4s/2s
9-12::
    All dance 1/2 reels of 4 across
13-16::
    1s+4s also 3s+2s dance 1/2 R&L (on bars 15-16 4s turn 3/4 LH so that
    4M faces 1s on the side & 4L faces 2s in middle)
17-20::
    3s set twice _while_ 4L+2s & 4M+1s circle 3H to the left. On bar 20
    4M pulls RSh back to finish on 4L''s left facing 2s
21-24::
    2s+4s dance Petronella in tandem to finish 4s at top & 2s at bottom,
    2s+4s set 4 1 2 3
25-32::
    All dance 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6745, '2013-08-21 08:31:30.220986+00', '2023-02-04 01:21:45.936045+00', 5093, 3, NULL, 'ace', '{{explanation}}
Each couple dance 64 bars. A New Couple starts after 32 bars (ie on bars 1, 33, 65 & 97)

1-8::
    1st couple cross RH, cast down 2 places, cross RH & cast up to 2nd
    place
9-16::
    1st couple dance RH across with couple above, 1st couple dance LH
    across with couple below
17-24::
    All dance RSh reels of 4 on sides
25-32::
    1st couple turn RH on sides with person above, 1st dance LH across
    with couple below & 1st couple cast to 3rd place as 3s dance up to
    2nd pl
33-40::
    (New Couple starts as at bar 1) as 1s continue, dancing R&L with
    bottom couple (NB New dancing couple will dance through middle of
    R&L)
41-48::
    Top couples also bottom couples dance RH across, middle couples
    dance LH across
49-56::
    All dance RSh reels of 4 on sides
57-64::
    Top couples also bottom cpls turn RH on sides, middle cpls dance LH
    across & both cpls cast off 1 pl as bottom cpl dance up to 2nd place

{{explanation}}
Note:	On bars 159-160 (last 2 bars of dance) couple in 4th place (original 3s) dance up to 3rd place while original 4s cast to bottom. End in order 1234', 0);
INSERT INTO 'dancecrib' VALUES (4107, '2013-08-21 08:30:43.592559+00', '2023-02-04 01:18:34.5608+00', 312, 3, NULL, 'ace', '1-8::
    1s cross, cast down to 3rd place & 3s+1s dance RH across.
9-16::
    1s lead up to top, cross, cast to 2nd place & 2s+1s dance LH across.
17-24::
    2s & 3s set & cross RH as 1s cross RH & cast to right; 2s+3s set on
    sides & change pls RH as 1s cross RH up/down centre & cast to right
25-32::
    3s & 2s set & cross RH as 1s cross RH & cast to right; 3s+2s set on
    sides & change pls RH as 1s cross RH up/down centre & cast to 2nd
    place', 0);
INSERT INTO 'dancecrib' VALUES (6746, '2013-08-21 08:31:30.229068+00', '2023-02-04 01:21:45.95737+00', 12691, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 3rd place, 2s dance in & cast to 3rd place. 3
    1 2 4
9-16::
    1s+2s dance up & cast to 2nd place then dance down between 4s & cast
    up to 3 1 2 4
17-24::
    1L+2L & 1M+2M (2s dancing b''tw''n 1s) turn 1.1/2 times, 3L+2L & 3M+2M
    (3s b''tw''n 2s) also 1L+4L & 1M+4M (1s b''tw''n 4s) turn 1.1/2 times to
    2 3 4 1
25-32::
    All dance reflection reels of 4 on sides (LSh reels Ladies side &
    RSh Mens side)', 0);
INSERT INTO 'dancecrib' VALUES (13313, '2020-11-02 01:21:17.364288+00', '2023-02-04 01:21:45.976451+00', 17315, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-16::
    1s dance down for 3 steps, lead up to top & cast to 2nd place (2s
    step up) 2 1 3
17-24::
    1s+3s dance Tourbillon:
::
    1s & 3s 1/2 turn partners 2H, 1M & 3L lead partners on 1 place
    clockwise to end 1s on Ladies'' side & 3s on Men''s side, 1s set to 3s
::
    1s & 3s 1/2 turn partners 2H, 1L & 3M lead partners on 1 place to
    end 3s in 2nd pl & 1s in 3rd pl & 3s+1s cross RH to own sides 2 3 1
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9432, '2016-10-17 00:02:26.248478+00', '2023-02-04 01:21:46.001691+00', 16855, 3, NULL, 'ace', '{{explanation}}
May be danced as Jig or Strathspey

1-8::
    1s+2s dance RH across, LH back and 1s face out
9-16::
    1s+3s dance double Fig 8 (1s cast, 3s cross up to start).  1s end
    facing out
17-24::
    1s cast to 4th place (4s step up 19-20).  4s+1s turn RH
25-32::
    2s+3s+4s+1s circle 8H round and back', 0);
INSERT INTO 'dancecrib' VALUES (10451, '2018-02-24 07:53:06.01034+00', '2023-02-04 01:21:46.023721+00', 17773, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link; 1s face down & 2s+1s+3s dance 1/2 LSh reels of 3 on
    sides (1s pass 3s LSh).  3 1 2
9-16::
    3s+1s Set+Link; 3s face down & 1s+3s+2s dance 1/2 LSh reels of 3 on
    sides (3s pass 2s LSh).  2 3 1
17-24::
    1s set, cast up 1 place (3s step down), turn 1.1/2 LH to 2nd place
    opp. side 2 (1) 3
25-28::
    1s dance 1/2 Diag R&L with 2s and 3s (1M down, 1L up)
29-32::
    1s dance 1/2 Diag R&L with 2s and 3s (1M down, 1L up)  (3)(1)(2)
33-40::
    3s+1s+2s dance clockwise 1/2 way round and turn partner RH to own
    side. End  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13764, '2021-03-02 01:21:18.45576+00', '2023-02-04 01:21:46.057124+00', 12352, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 on own sides dancing in to begin
9-12::
    1L turns 2M 1.1/2 RH _while_ 1M & 2L dance clockwise to change
    places
13-16::
    1M & 2L set & change places RH _while_ 1L & 2M dance clockwise back
    to place
17-24::
    1s lead down, cross below 2s, cast down behind 3s, cross LH & cast
    up to 2nd place. 2s step up 23-24
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6747, '2013-08-21 08:31:30.262962+00', '2023-02-04 01:21:46.095447+00', 10010, 3, NULL, 'ace', '1-8::
    Top 3 on Men''s side turn bottom 3 on Ladies side RH, top 3 on Ladies
    side turn bottom 3 on Men''s side RH
9-16::
    All dance RSh reels of 4 on the sides
17-24::
    1L followed by partner dance down behind 2L, cross down to 4M place,
    dances up behind 3M, cross up to original place as 1M dances up
    behind Men to own place _while_ 4M followed by partner dances up
    behind 3M, crosses up to 1L place, casts down behind 2L, cross down
    to original place as 4L dances down outside Ladies to place
25-28::
    Top 3 on Men''s side change places RH with bottom 3 on Ladies side,
    top 3 on Ladies side change places RH with bottom 3 on Men''s side
29-32::
    Repeat (All now on opposite side opposite partners.  4 3 2 1
33-40::
    Top 2 couples (4s+3s) also bottom 2 couples (2s+1s) set on side &
    dance 1/2 RH across, middle 2 couples (4s+1s) Set+Link
41-48::
    All circle 8H round & back.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (6748, '2013-08-21 08:31:30.268642+00', '2023-02-04 01:21:46.12121+00', 10938, 3, NULL, 'ace', '1-8::
    1s dance down 1 place & cast on own side back to places, 1s+2s turn
    1.1/4 times on sides (Men RH & Ladies LH) to end in line of 4 facing
    down
9-16::
    1s+2s in line of 4 dance down for 4 bars & 1s swing 2s into face
    partners, 1s+2s slip step up to top
17-24::
    1s+2s dance Poussette
25-32::
    2s dance down between 1s & cast back to top places, 1s dance up
    between 2s & cast back to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (12167, '2019-09-04 21:38:42.55401+00', '2023-02-04 01:21:46.255346+00', 19570, 3, NULL, 'ace', '1-8::
    All Advance+Retire, 1s+2s also 3s+4s dance 1/2 RH across & set
9-16::
    All dance reels of 4 on sides
17-24::
    2s+1s also 4s+3s circle 4H round & back
25-32::
    1s+4s+3s Set+Link twice _while_ 2s set twice & turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (6749, '2013-08-21 08:31:30.392615+00', '2023-02-04 01:21:46.336412+00', 5098, 3, NULL, 'ace', '1-8::
    1s+3s dance RSh round each other, 1s+3s chase clockwise 1/2 way
    round 2s who dance RSh round each other
9-16::
    3s+2s+1s circle 6H round & back ending in centre
17-20::
    1M followed by ptnr dances behind 2L to end in middle facing down
    _while_ 3L followed by ptnr dances behind 2M to end in middle facing
    up
21-24::
    1s+2s+3s set in circle, 1s+3s change places (1s under 3s arch), 1s
    face up _while_ 3s dance to 1st place own sides.
25-32::
    2s+1s set, change places (Men RH & Ladies LH), 3s+1s+2s dance 1/2
    Reel of 3 on sides (1s in & up to start)', 0);
INSERT INTO 'dancecrib' VALUES (6750, '2013-08-21 08:31:30.400969+00', '2023-02-04 01:21:46.361556+00', 10701, 3, NULL, 'ace', '1-8::
    All turn RH & clap (bar 4); all turn LH & clap (bar 8)
9-16::
    1s+2s also 3s+4s dance RH across & LH back
17-24::
    All dance DoSiDo with partner & turn partner RH (4 bars)
25-32::
    1s cast 1 place & dance down between 3s, out behind 4s to 4th place
    (2s+3s+4s step up 31-32)
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6751, '2013-08-21 08:31:30.409295+00', '2023-02-04 01:21:46.390951+00', 13071, 3, NULL, 'ace', '{{explanation}}
3s & 4s start  on opposite sides.  To allow both Men & Ladies to be lead dancers, this standing pattern does not  reform until the end of dance

1-8::
    1s & 4s set then 1M & 4M cast in 1 place, 1M with 1L+2L & 4M
    with3L+4L dance RH across
9-16::
    1M+4M turn LH & cast left (1M round 2L, 4M round 3L) into prom hold
    with partners (Lady on right), 1s+2s & 4s+3s  dance 1/2 RSh reels
    across
17-24::
    1s down on Ladies side & 4s up on Mens side dance 1/2 Rsh reel in
    prom hold, 4s+1s (in middle) dance LH across & end facing corners
    3(4)1(2)
25-32::
    All dance 1/2 double diag reels of 4 (corners dance 1/2 LH across in
    middle) as  4s+1s loop back to starting places, 4s+1s circle 4H
    round to left to end 2(4)1(3)

{{explanation}}
NOTE:- Danced 4 times successively led by - 1M+4M, 2M+3M, 4L+1L, 3L+2L', 0);
INSERT INTO 'dancecrib' VALUES (6752, '2013-08-21 08:31:30.417505+00', '2023-02-04 01:21:46.533724+00', 5099, 3, NULL, 'ace', '1-8::
    1L+2L Adv+Ret, cross between partners & cast back to places
9-16::
    1M+2M repeat above Fig
17-24::
    1s lead down below 2s, cross RH, cast round 3s, cross LH & cast back
    to 2nd place own sides
25-32::
    2s+1s+3s Adv+Ret, 1s turn 1st corners LH to end on opposite sides
    between corners
33-40::
    2s+1s+3s Adv+Ret, 1s turn 4th corner RH 1s end in 2nd place own
    sides
41-48::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10522, '2018-03-20 06:26:08.546916+00', '2023-02-04 01:18:36.751747+00', 18261, 3, NULL, 'ace', '1-4::
    1s+3s set advancing into line up/down centre, 1/2 turn partner RH
    moving down 1 place to end Men facing up, Ladies facing down in
    centre (2s & 4s step up bars 3-4)
5-8::
    1s+3s dance 1/2 reel of 4 to end in centre, 3M with 3L following
    facing up, 1L with 1M following facing down
9-16::
    3s+2s also 1s+5s dance tandem reels of 3 across. 3s & 1s end in
    centre, 3M with partner on Right facing down, 1M with partner on
    Left facing up
17-24::
    3s+4s+1s circle 6H round & back
25-28::
    3s+1s set , change places RH with person opposite, 1s face Ladies''
    side, 3s face Men''s side
29-32::
    1M followed by 1L casts 1 place to Right to 3rd place own side,
    _while_ 3L followed by 3M casts 1 place to Left to 5th place (4s &
    5s step up 31-32). End 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (6753, '2013-08-21 08:31:30.423853+00', '2023-02-04 01:21:46.549132+00', 9647, 3, NULL, 'ace', '1-8::
    All Adv+Ret, 1s slip step to bottom
9-16::
    All Adv+Ret, 2s slip step to bottom
17-24::
    3s+4s _while_ 5s+6s dance RH across & LH back _while_ 1s+2s dance
    R&L
25-32::
    1s+2s slip step to top, 1s cast to bottom _while_ all other couples
    turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6754, '2013-08-21 08:31:30.431977+00', '2023-02-04 01:21:46.575285+00', 5102, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, dance up to face each other between 2s &
    turn RH to face other partner
9-16::
    1s+2s dance RSh reel of 4 to end Man behind Lady facing 2L
17-24::
    1s+2s dance Tandem reel of 3 across & 1s end in middle facing down
25-32::
    1s dance down between 3s, cast up 1 place on opposite sides, cross
    RH & all set', 0);
INSERT INTO 'dancecrib' VALUES (6755, '2013-08-21 08:31:30.440085+00', '2023-02-04 01:21:46.60033+00', 10112, 3, NULL, 'ace', '1-8::
    1M (long steps) followed by ptnr dance down for 3 steps (2s step
    up), turn right about & dance up (L leading), 1L turns 2L 2H _while_
    1M turn 3L 2H
9-16::
    1L followed by partner dance up for 3 steps, turn right about &
    dance down (Man leading), 1L turns 2M with 2H _while_ 1M turn 3M 2H
17-24::
    1s dance reels of 3 across (Lady with 2s & Man with 3s) giving LSh
    to 2L/3L, 1s turn LH quickly into…
25-32::
    1s dance RH across (Lady with 2s & Man with 3s), pass RSh & dance LH
    across with other couple to end in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6756, '2013-08-21 08:31:30.449985+00', '2023-02-04 01:21:46.856566+00', 12530, 3, NULL, 'ace', '1-8::
    All Adv+Ret & dance RH across
9-16::
    All Adv+Ret & dance LH across
17-24::
    All dance Ladies'' Chain
25-32::
    All dance interlocking parallel reels of 3 dancing RSh round person
    in front & LSh round person behind ending passing person in front
    RSh to face next couple', 0);
INSERT INTO 'dancecrib' VALUES (9032, '2015-11-30 09:00:08.759086+00', '2023-02-04 01:21:46.885364+00', 15710, 3, NULL, 'ace', '1-4::
    1s NHJ dance down (2 step), face each other & set advancing passing
    BtoB to face up (2s step up 3-4)
5-8::
    1s dance up, cast to 2nd place opp sides.  1M faces out
9-16::
    2s+1s dance Ladies'' Chain, 1s dancing on at end to finish in centre,
    BtoB, 1L facing up, 1M facing down
17-24::
    "Glorified" Fig 8:
::
    _17-20_    1s dance out of ends, cast Left, dance in through 2nd
    place opp sides and turn 3/4 LH _while_ bars 19-20 2s+3s Adv(1)
    touch RH +Ret(1)
::
    _21-24_    1s dance out of same ends as before, cast Right, into 2nd
    place own sides
25-32::
    1s+3s dance Bourrel:
::
    _25-28_    1M+3L set advancing, 3/4 turn 2H & twirl to end BtoB
    (Lady facing up & Man down) _while_ partners chase anticlockwise to
    face partner
::
    _26-32_    Set to partners & turn 2H (sometimes RH) to own sides
    having changed places', 0);
INSERT INTO 'dancecrib' VALUES (6757, '2013-08-21 08:31:30.457897+00', '2023-02-04 01:21:46.913242+00', 5107, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, dance down between 3s & cast up 1 place
    into centre facing up
9-16::
    1s (Lady Leading) dance an Alternating Tandem reel of 3 with 2s (RSh
    to 2L to start)
17-24::
    1s dance up between 2s, cast to 2nd place & turn RH.', 0);
INSERT INTO 'dancecrib' VALUES (14125, '2021-07-07 00:20:48.021898+00', '2023-02-04 01:21:47.187924+00', 12071, 3, NULL, 'ace', '{{explanation}}
Longways set for any number of couples

1-8::
    1s turn RH (spin or birl)
9-16::
    1s turn next dancer on opp side LH (2 bars), turn partner in middle
    RH (2 bars) & continue down lines, turning dancer on opp side then
    partner in middle until reaching bottom where 1s turn partner to end
    of phase

{{explanation}}
New couple starts every 16 bars', 0);
INSERT INTO 'dancecrib' VALUES (12934, '2020-07-01 00:20:57.887654+00', '2023-02-04 01:21:47.218106+00', 19991, 3, NULL, 'ace', '1-8::
    1L dances Fig 8 round 1M+2M back to place (pass 2M LSh to start)
9-16::
    1M dances Fig 8 round 1L+2L back to place (pass 2L RSh to start)
17-24::
    1s+2s+3s dance mirror reels of 3 on sides (1s in/down to start)
25-32::
    1L+2L  & 1M+2M Set+Link; 1L+3L & 1M+3M Set+Link.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (10340, '2017-12-22 15:44:51.469948+00', '2023-02-04 01:21:47.249519+00', 17538, 3, NULL, 'ace', '1-8::
    1M leading 2M+3M also 3L leading 2L+1L chase clockwise 1/2 round to
    opp sides (4 bars).  All set, 1s+3s turn partners 3/4 RH into line
    up/down (Men facing down)
9-12::
    3s+1s dance 1/2 reel of 4, 1M+3L pass LSH to face 2s (1M+2M & 3L+2L
    facing), 1L+3M remain in centre at top/bottom
13-16::
    1M+3L+2s dance 1/2 reel of 4 across, 1M & 3L pass LSh to face
    partners up/down set
17-24::
    1s+3s dance 1/2 reel of 4, 1M+3L pass LSh to face own partners.
    3s+1s set, petronella turn to own sides.  3 2 1
25-32::
    2s followed by 1s dance up to top, cast, 2s to 3rd place, 1s to 2nd
    place (4 bars). 3s+1s+2s turn partners 2H', 0);
INSERT INTO 'dancecrib' VALUES (6758, '2013-08-21 08:31:30.465916+00', '2023-02-04 01:21:47.289041+00', 9684, 3, NULL, 'ace', '1-8::
    1s & 4s set & turn 2H, 1s lead down to bottom _while_ 4s cast to top
    & 4s also 1s turn RH to own sides
9-16::
    2s+3s set & cross RH, set to each other on sides & turn LH
17-24::
    All dance Grand Chain
25-32::
    4s+2s & 3s+1s Set+Link, 2s & 3s dance 1/2 Fig of 8 (2s round 4s & 3s
    round 1s) to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7881, '2013-08-21 08:31:50.499032+00', '2023-02-04 01:23:09.410621+00', 7020, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 on own sides round 2s & 3s dancing between 2s to
    start
9-16::
    1s cross down & dance reels of 3 across (1L with 2s passing 2M RSh &
    1M with 3s passing 3L RSh) to end in facing lines of 3 across
17-24::
    2s+1s+3s set, change places RH with opposite person, set, 1s turn RH
    to face 1st corners _while_ 2s & 3s change places RH on sides back
    to pl
25-32::
    1s dance 1/2 reel of 4 with 1st corners, pass RSh & dance 1/2 reel
    with 2nd corners
33-40::
    1s 3/4 turn RH, 1M dances up & casts down on Ladies side _while_ 1L
    dances down & casts up on Men''s side, 1s chase clockwise to 2nd
    place on own sides _while_ 2s+3s set diagonally & dance LH across
    1.1/2 times', 4);
INSERT INTO 'dancecrib' VALUES (4144, '2013-08-21 08:30:44.144624+00', '2023-02-04 01:18:36.794766+00', 369, 3, NULL, 'ace', '1-8::
    All set, 1s+2s also 4s+5s Petronella-in-tandem to opp sides _while_
    3s cast & chase clockwise between 1s+2s or 4s+5s to ptnrs pl.
    (2)(1)(3)(5)(4)
9-16::
    2s, 3s & 4s (top, middle & bottom couples) set & petronella turn
    into middle, turn 2H & petronella turn to own sides. 2(1)3(5)4
17-24::
    1s & 5s set & 3/4 turn LH, all dance RH across (2s+1L, 1M+3s+5L &
    5M+4s) with 1s & 5s ending on own sides.  2 1 3 5 4
25-32::
    1s+3s also 5s+4s Set+Link, 1s dancing in cast to bottom _while_ 4s &
    5s turn 2H & lead up 1 place.  2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (4146, '2013-08-21 08:30:44.277021+00', '2023-02-04 01:18:36.991783+00', 14247, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance R&L
9-16::
    All dance reels of 4 on the sides
17-24::
    1s+2s also 3s+4s set, dance 1/2 RH across, all set & cross RH
25-32::
    1s+4s+3s (bottom 3 couples) dance Allemande to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4148, '2013-08-21 08:30:44.294999+00', '2023-02-04 01:18:37.05729+00', 375, 3, NULL, 'ace', '1-8::
    1s lead down, cast up round 3s, set & 2s+1s change places on sides
    (Ladies LH & Men RH)
9-16::
    1s set, dance in & lead down 1 place, cast down behind 3s & dance up
    to 2nd place
17-24::
    1s dance reflection reels of 3 on sides (1s dance out & up to start)
25-32::
    2s+1s+3s dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6759, '2013-08-21 08:31:30.474534+00', '2023-02-04 01:21:47.320346+00', 5109, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+3s also 2s+4s dance R&L (2s+4s begin by changing with partner on
    sides)
9-16::
    1s+3s cross LH & dance out sides (1M+3L dance between 4s cast to
    opposite places as 1L+3M dance similarly between 2s to meet partners
    in prom hold & dance back to original places (Ladies passing RSh)
17-24::
    1s (prom hold) pass 2L RSh to dance reel of 3 with 2L+4M _while_ 3s
    pass 4L RSh to dance reel of 3 across with 4L+2M & end in own places
25-32::
    1s & 3s Promenade clockwise around set _while_ 2s & 4s advance, turn
    opposite person RH & dance RH across, all ending in original places
    in Ballroom hold with Men on outside facing in
33-40::
    All set HS (Men starting on left foot) then turn partner 2H back to
    square formation
41-48::
    1s & 3s set advancing, turn opposite person 2H & open to face side
    couples, all circle 4H round to left
49-56::
    All dance 2 reels of 4 across set BUT each couple on reaching centre
    dance 1/2 LH across & continue reel in other line (1s+3s end facing
    sides)
57-64::
    All dance RH across on sides, 1s+3s LH across in centre & back to
    places

{{title}}
Jig

1-32::
    Repeat first 32 bars as above ending in Ballroom hold with Men on
    outside facing in
33-40::
    All slip step (to Men''s left) for 2 bars, slip step back (2 bars) &
    polka anticlockwise 1 place
41-48::
    Repeat
49-56::
    Repeat
57-64::
    Repeat', 0);
INSERT INTO 'dancecrib' VALUES (6761, '2013-08-21 08:31:30.490939+00', '2023-02-04 01:21:47.380356+00', 13749, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH & cast in, 1s+4s dance LH across ending in St
    Andrews Cross (RH to corners)
9-16::
    1s+corners Bal-in-Line & 1/2 turn corners RH, Bal-in-Line & 1/2 turn
    corners RH
17-20::
    1M+4M dance out top & cast left _while_ 4L+L dance out bottom & cast
    left, 1M+4M & 4L+1L cross passing LSh as corners Adv+Ret
21-24::
    1M+4M dance out Ladies side & cast up _while_ 4L+L dance out Mens
    side cast down, 1M+4M & 4L+1L cross diag passing LSh as crnrs
    Adv+Ret
25-32::
    1M+4M also 4L+1L dance LSh Tandem reels on own sides to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6762, '2013-08-21 08:31:30.499491+00', '2023-02-04 01:21:47.408812+00', 12538, 3, NULL, 'ace', '1-8::
    All change places with partner RH & set (Men facing out), all change
    places with partner RH & set (Ladies facing out)
9-24::
    All dance full Schiehallion Reels
25-28::
    Men dance LH across 1/2 way _while_ Ladies chase clockwise 1 place
    to join RH with next Man & Balance in a wheel formation
29-32::
    Men dance LH across 1/2 way _while_ Ladies chase clockwise 1 place
    to join RH with next Man & change places RH
33-40::
    Repeat bars 25-32 with Ladies in centre & change places RH
41-56::
    Repeat bars 25-40 ending with Men BtoB facing own partner
57-60::
    All set & Men set turning to right 1 place clockwise _while_ Ladies
    petronella turn to next place anticlockwise
61-64::
    Repeat to end facing partner opposite side
65-72::
    All turn RH (4 bars) to face anticlockwise in prom hold, all
    Promenade back to places
73-80::
    1s+3s dance Ladies'' Chain
81-88::
    2s+4s dance Ladies'' Chain
89-96::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6763, '2013-08-21 08:31:30.507634+00', '2023-02-04 01:21:47.454008+00', 9685, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s dance down to meet 4s who dance up, set to partners, 1s lead up &
    cast to 2nd place as 4s lead down & cast up to 3rd place
9-14::
    1s in prom hold dance reel of 3 on Ladies side (giving RSh to 2L to
    start) _while_ 4s dance reel on Men''s side (giving RSh to 3L)
15-16::
    1s+4s dance LSh round each other to face corners (4s face 2s & 1s
    face 3s Men to Men & Lady to Lady)
17-24::
    1s+4s dance 1/2 interlocking diagonal reels of 4 with corners to end
    on sides 3 1 4 2, 3s+1s & 4s+2s circle 4H round to left open into-
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9033, '2015-11-30 09:00:08.823866+00', '2023-02-04 01:21:47.475202+00', 16523, 3, NULL, 'ace', '1-8::
    1s set, 1L casts & followed by 1M, dances across to 2M''s place
    facing out (2s step up 5-6).  1L+3M also 1M+3L 1/2 turn LH & Men
    face out
9-16::
    3s+1s dance Ladies'' Chain, 1M finishes facing out
17-24::
    1M followed by 1L casts up, dances across to 2M place (3s step down
    19-20).  2s+1s dance RH across.  1M & 2L face out
25-32::
    2s+1s+3s dance reels of 3 on sides (1s+3s pass LSh to start)', 0);
INSERT INTO 'dancecrib' VALUES (6764, '2013-08-21 08:31:30.521146+00', '2023-02-04 01:21:47.492634+00', 14536, 3, NULL, 'ace', '1-8::
    1s+2s dance the Knot  & 1s end facing 1st corners
9-16::
    1s dance 1/2 diagonal reel with 1st corners & pass RSh to face 2nd
    corners, 1s dance 1/2 diagonal reel with 2nd corners & end 2nd place
    opp sides
17-24::
    All set & corner persons cast clockwise 1 place as 1s petronella
    turn into middle, repeat bars 17-20 with 1s ending 2nd place own
    sides
25-32::
    All set & turn partners 2H, 1s+3s dance 1/2 Diagonal Poussette.  2 3
    1', 0);
INSERT INTO 'dancecrib' VALUES (12415, '2019-12-05 01:31:26.218162+00', '2023-02-04 01:21:47.518766+00', 12828, 3, NULL, 'ace', '1-4::
    1s advance (skip change), face each other & set;
5-8::
    1s pull back RSh, 1M dances between 2s, behind 2M to end between 2nd
    & 3rd couples facing up _while_
::
    1L dances between 3s, behind 3M to end in 1M''s place facing down
9-16::
    1s set, change places RH, set & turn RH into prom hold facing 3s
    _while_
::
    2s+3s set, turn 2H 1/2 round (skip change) , set (2H joined) & 1/2
    turn into prom hold
17-24::
    2s+1s+3s dance reel of 3 across (1s pass 3s RSh to start). All end
    in original places facing partner
25-32::
    _3_ couples dance Grand Chain
::
    Repeat with 2s then 3s starting', 0);
INSERT INTO 'dancecrib' VALUES (6765, '2013-08-21 08:31:30.54771+00', '2023-02-04 01:21:47.552636+00', 7878, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & 3s+4s dance LH across, 1L also 3M (followed
    by their partners) chase clockwise to change ends
9-16::
    3s+2s dance RH across & 1s+4s dance LH across, 1s & 3s chase 1/2 way
    to end in line up/down centre with 1L & 3M facing in middle
17-24::
    1s+3s dance reel of 4 with 1L+3M passing LSh ending in original
    places
25-32::
    1s cast to 4th place as others step up, 2s & 3s turn RH as 4s & 1s
    turn LH', 0);
INSERT INTO 'dancecrib' VALUES (6766, '2013-08-21 08:31:30.6521+00', '2023-02-04 01:21:47.725726+00', 11727, 3, NULL, 'ace', '1-8::
    1s dance down between 2s behind 3s, cross & cast up to 2nd place
    opposite sides
9-16::
    1s set, turn right about & dance reels of 3 on opposite sides (RSh
    to 1st corner) & end facing 1st corner
17-24::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partner LH to
    face each other up/down (Lady above Man)
25-32::
    2s+1L also 1M+3s dance RH across & 1s pass RSh to dance LH across
    with other couple ending 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8186, '2014-02-10 10:26:51.104532+00', '2023-02-04 01:21:47.749672+00', 14458, 3, NULL, 'ace', '{{explanation}}
2 chords on 2nd chord 3s +4s cross to opposite sides

1-8::
    All set to partners & 1M+2L also 3L+4M cross over RH, 1L+2M also
    3M+4L cross over LH & all cross RH
9-16::
    2s+1s also 4s+3s dance RH across, 1s+4s dance LH across
17-24::
    2s+1s also 4s+3s dance reels of 4 across (2M+1L also 4L+3M passing
    LSh to start as partners cast into reel)
25-32::
    1L followed by 4M dance up between top couple & cast round top man
    (2M) & dance down to 3rd/2nd places _while_ 4L followed by 1M dance
    down between bottom couple & cast round bottom Man (3M on Ladies
    side) to 2nd/3rd places & all turn LH  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (6767, '2013-08-21 08:31:30.660721+00', '2023-02-04 01:21:47.763112+00', 13302, 3, NULL, 'ace', '1-8::
    1M+3M set advancing & turn RH back to place, 1L+3L set advancing &
    turn RH
9-16::
    1s+3s set advancing & 1/2 turn 2H opposite partner, 1M+3L also 1L+3M
    dance between 2s/4s & cast to each others place
17-32::
    2s+4s repeat bars 1-16
33-40::
    Ladies dance RH across & dance LSh round corner person
41-48::
    Ladies dance LH across & RSh round corner person
49-56::
    Men dance RH across & dance LSh round corner person
57-64::
    Men dance LH across & RSh round corner person
65-72::
    1s+3s dance in, turn right about & chase clockwise 1/2 way end
    turning partner RH to original places
73-80::
    2s+4s dance in, turn left about & chase anticlockwise 1/2 way end
    turning partner LH to original places
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15143, '2022-10-05 00:21:18.674087+00', '2023-02-04 01:21:47.774996+00', 21111, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH & retain hands (2s step up), 1scross down, dance
    behind 3s & cast up, meet in centre & lead up LH to face 1st corners
9-16::
    1s dance Corner Pass+Turn with 1st corners (corners turn 2H), pass
    RSh & dance Corner Pass+Turn with 2nd corners. End: 1s in middle opp
    sides  facing down, 2s at top & 3s at bottom facing up, all in prom
    hold with partner
17-24::
    2s+1s+3s dance "Circulating Allemande":
::
    2s & 3s dance normal Allemande but end in 3rd/1st place as 1s
    Allemande (down) & up, pull back RSh & dance out to 2nd place
    opposite sides.  3 (1) 2
25-32::
    1M casts down, 1L casts up to 1M between 2s at bottom, 1L between 3s
    at top, 1s set advancing; 1s 1/2 turn RH to face each other &
    Petronella turn to 2nd place own side.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (12736, '2020-04-11 10:52:34.333904+00', '2023-02-04 01:21:47.785383+00', 19945, 3, NULL, 'ace', '1-8::
    1s turn RH & cast (2s step up); 1L+2s & 1M+3s dance RH across.  1s
    end facing 1st corners
9-16::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh, dance 1/2
    diag reel of 4 with 2nd corners to end in 2nd place on opp side (3)
    (1) (2) all facing clockwise
17-24::
    All chase clockwise 1/2 round to own side; all turn partner RH (or
    birl)
25-32::
    2s+1s+3s circle 6H round & back.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6768, '2013-08-21 08:31:30.670486+00', '2023-02-04 01:21:47.818357+00', 5118, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 on own sides (in between 2s to start)
9-16::
    1s+2s+3s dance Grand Chain
17-24::
    1s cross down RH, cast down behind 3s, cross LH & cast up round 3s
    to face 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting & all clap as 1s end with
    petronella turn to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (14563, '2022-01-24 15:10:51.86937+00', '2022-01-26 01:49:54.791062+00', 20640, 1, 202, 'ace', '1--::

  2c Knot (2,1,3)

9--::

  Chase cclw ½ ; all turn P LH (3x,1x,2x)

17--::

  Diagonal R&L (2,1x,3)

25--::

  Pick-up Chain, 3c crossing RH to start (3,1,2)', 5);
INSERT INTO 'dancecrib' VALUES (6769, '2013-08-21 08:31:30.67845+00', '2023-02-04 01:21:47.834992+00', 8247, 3, NULL, 'ace', '1-8::
    1s+2s+3s cross RH & set, 1s cross RH & cast 1 place
9-16::
    2s+1s+3s dance reflection reels on sides (1s in & down to start) &
    set advancing & turn right to face own sides
17-24::
    1s dance Double Triangles with 2s+3s crossing RH on bars 19/20 & 1s
    ending 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8346, '2014-07-29 12:59:22.043793+00', '2023-02-04 01:21:47.853987+00', 12368, 3, NULL, 'ace', '1-8::
    1s cross RH & cast to 2nd place; 1s turn once LH to opposite sides
    (2s step up 3-4), all set.
9-16::
    2s+1s+3s 1/2 turn RH, twirl & chase 1/2 way round clockwise, 1s
    finish RSh to RSh in middle facing 4th corner.
17-24::
    1s dance 1/2 diagonal reel of 4 with 4th corners, pass RSh; 1s dance
    1/2 diagonal reel of 4 with 1st corners. 1s finish between those
    corners facing up/down.
25-32::
    1s 3/4 turn RH to opposite sides, 2s+1s+3s set; 2s+1s+3s turn RH
    1.1/2 times.', 0);
INSERT INTO 'dancecrib' VALUES (13765, '2021-03-02 01:21:20.009228+00', '2023-02-04 01:21:47.88588+00', 12353, 3, NULL, 'ace', '1-8::
    1s set, dance down NHJ & cast up round 3s to finish in centre
    joining LH & giving RH to 1st corners (2s step 3-4)
9-16::
    1s dance the Spoke: Bal-in-Line with 1st corners, then with 2nd
    corners, then with 3rd corners & 4th corners to end 1s facing 1st
    corners
17-24::
    1s dance 6 bar reels of 3 on opp sides (1s giving LSh to 1st corners
    to start) & end between corners, All set
25-32::
    1s dance 1/2 Fig 8 (1M up between 2s, 1L down between 3s) into 2nd
    place own side; All turn partner RH 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6770, '2013-08-21 08:31:30.693909+00', '2023-02-04 01:21:47.907651+00', 5120, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance double Fig of 8 (1s & 4s cast to start)
9-12::
    1s cast to 3rd place & turn 2H _while_ 3s turn 2H & dance up b''tw''n
    2s
13-16::
    1s dance down between 4s & cast up to 3rd place _while_ 3s cast to
    3rd place then turn 2H
17-20::
    1s turn 2H & dance up between 2s _while_ 3s dance down between 4s,
    cast up to 3rd pl
21-24::
    1s cast to 3rd pl & turn LH to face 2nd crnrs _while_ 3s turn 2H &
    dance up top
25-32::
    1s dance Pass+Turn with 2nd corners & turn RH to face 1st corners,
    dance Pass+Turn with 1st crnrs to end in 3rd place own sides.  3 2 1
    4
33-40::
    All set, 3s+2s also 1s+4s dance RH across, 3s cast to 2nd place
    _while_ 2s dance up & 1s dance down.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13427, '2020-12-02 01:21:12.934315+00', '2023-02-04 01:21:47.937801+00', 20138, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link flowing into RH across.  End 2s in 1st place own
    side, 1s retain RH briefly turning to face 1st corners
9-16::
    1s dance Corner Pass+Turn with 1st corners, pass RSh & repeat with
    2nd corners, passing RSh to end in 2nd place own side facing
    out/down
17-24::
    »Modified Double Fig 8«:
::
    1s+4s dance double Fig 8 round 3s (1s cast down, 4s cross up to
    start).  Bars 23-24: 3s step up to 2nd place _while_ 1s cross up to
    3rd place, 4s finish in 4th place
25-32::
    1s+4s dance RH across. Bar 28: 1L & 4L curve in to face up, join NH
    with partner; 1s+4s dance up & cast round 3s to end 1s in 4th place,
    4s in 3rd place own side. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6771, '2013-08-21 08:31:30.702144+00', '2023-02-04 01:21:47.962263+00', 5122, 3, NULL, 'ace', '{{explanation}}
2 chords - 3s & 4s cross to opp sides on 2nd chord

1-8::
    1s & 4s set to partners, turn 2H, 1L followed by partner casts
    behind 2L & dances round other couple LSh to face 3L _while_ 4L
    followed by partner casts up behind 3L, round other couple to face
    2L
9-16::
    4s+2L also 1s+3L dance RH & LH across 2M/3M, 4s end facing up in 2nd
    place, 1s facing down in 3rd place & 2M & 3M face out
17-20::
    4s & 1s dance out ends & cast to 2nd/3rd pl _while_ 2s & 3s dance
    down/up sides 1 place then dance in & 2s dance  up to 1st place, 3s
    down to 4th place
21-24::
    4s+1s circle 4H round to left
25-32::
    All circle left for 2 steps, set, drop hands & dance 1 more step to
    left & cast back anticlockwise to places.  2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (14674, '2022-03-07 02:21:09.168501+00', '2023-02-04 01:21:47.980126+00', 16155, 3, NULL, 'ace', '1-4::
    1L followed by partner, casts 2 places to 3rd place opposite sides
    (2s+3s step up bars 3-4)
5-8::
    1s+4s dance LH across, 1L finishes facing out
9-12::
    1L followed by partner casts up 2 places to original places
13-16::
    1s+2s dance RH across
17-24::
    All set, all 1/2 turn partner 2H. 1s+2s also 3s+4s dance 4H round to
    left to finish on opposite sides (1) (2) (3) (4)
25-32::
    1L & 2M changes places LH, 1M & 2L also 1L & 3L change places RH, 1M
    & 3M also 1L & 4M change places LH, 1M & 4L changes places RH.  2 3
    4 1', 0);
INSERT INTO 'dancecrib' VALUES (6772, '2013-08-21 08:31:30.722575+00', '2023-02-04 01:21:47.99688+00', 9878, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s circle 4H round & back
9-16::
    All set, 1s & 4s cast to centre as 2s & 3s dance up/down to ends; 1s
    & 4s dance 1/2 Figs of 8 round end couples
17-24::
    All set, 2s & 3s cast to centre as 1s & 4s dance up/down to ends;
    2s & 3s dance 1/2 Figs of 8 round end couples. All now on opposite
    sides
25-40::
    1s+2s change places RH on sides, cross LH with partners, 1s+3s
    repeat, 1s+4s repeat.  All turn partners 2H', 0);
INSERT INTO 'dancecrib' VALUES (6773, '2013-08-21 08:31:30.730706+00', '2023-02-04 01:21:48.013338+00', 10520, 3, NULL, 'ace', '1-8::
    1s+2s dance Double Fig of 8 (1s cast to start)
9-16::
    1s 1/2 turn RH & lead down the middle & back to end BtoB facing
    opposite side
17-24::
    2s+1s+3s dance Double Triangles ending BtoB facing 1st corners
25-32::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners & turn RH to 2nd places own sides
33-40::
    1s dance reels of 3 on own sides (between 3s to start)', 0);
INSERT INTO 'dancecrib' VALUES (13316, '2020-11-02 01:21:19.037181+00', '2023-02-04 01:21:48.032822+00', 10011, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s+4s cross to opp sides

1-8::
    1M dances reel of 3 with 2s (LSh to 2L) picking up partner in prom
    hold to complete reel as 4M dances similarly with 3s (LSh to 3L), at
    end 2s&3s face out
9-10::
    1s/4s in promenade hold, dance into middle & down/up to 2nd/3rd
    places _while_ 2s/3s dance out up/down to 1st/4th places
11-12::
    1s/4s drop LH, dance 1/2 RH across, men retain hold of partner with
    RH, turn towards partner, 4s in 2nd place facing up & 1s in 3rd
    place facing down
13-16::
    4s lead up, cross & cast to 2nd place _while_ 1s lead down, cross &
    cast to 3rd place 2 4 1 3
17-24::
    4s+1s dance LH across, men face out, 2s+4s also 1s+3s dance RH
    across
25-32::
    All dance reels of 4 on sides 2 4 1 3

{{explanation}}
Note: at the end of each turn, except last, 4th & 1st Men stay facing out', 0);
INSERT INTO 'dancecrib' VALUES (6774, '2013-08-21 08:31:30.738711+00', '2023-02-04 01:21:48.055436+00', 10757, 3, NULL, 'ace', '1-8::
    1M+3L change places by dancing 3/4 Figs of 8 on own sides (casting
    behind 2s to start) & cross to opposite sides
9-16::
    1L+3M change places similarly
17-24::
    2s dance Diag R&L ending with 1s facing to 2s
25-32::
    1s+2s set, change places with 1s making an arch, 1s+3s set & change
    places with 3s making an arch', 0);
INSERT INTO 'dancecrib' VALUES (8620, '2015-02-13 12:48:07.673448+00', '2023-02-04 01:21:48.20053+00', 15406, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast, turn LH to face 1st corners (2s step up bars
    5-6)
9-16::
    1s turn corner RH, partner LH, 2nd corner RH, partner LH to finish
    in middle, own side, facing up
17-24::
    1s dance up between 2s, cast, dance down between 3s & cast up into
    2nd place own sides
25-32::
    1s+3s dance the Tournée
::
    1s+3s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 3s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (3s RH, 1s LH) & dance
    out to places', 0);
INSERT INTO 'dancecrib' VALUES (6826, '2013-08-21 08:31:31.52607+00', '2023-02-04 01:21:51.604842+00', 13746, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across & LH back
9-16::
    1M also 4L (followed by partners) cast (down/up) 1 place & dance
    up/down between 2s/3s & cast 1 place crossing over to end in 2nd/3rd
    places
17-24::
    1L also 4M (followed by partners) cast (up/down) 1 place & dance
    down/up between 2s/3s & cast to ends crossing over to end in orig
    places
25-32::
    All dance 1/2 RSh reels of 4 on sides, 4s+3s+2s (top 3 couples)
    dance 1/2 reels of 3 on sides.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4149, '2013-08-21 08:30:44.303463+00', '2023-02-04 01:18:37.079318+00', 9543, 3, NULL, 'ace', '1-8::
    All set, 1/2 turn partner RH to Men facing out, all set & 1/2 turn
    partners RH to Ladies facing out
9-16::
    Ladies dance clockwise round outside past partner & loops RSh round
    next Man & dances on 1 more place
17-24::
    All set, 1/2 turn new partner LH to Ladies facing out, all set & 1/2
    turn new partners LH to Men facing out
25-32::
    Men dance anticlockwise round outside past partner & loops LSh round
    next Lady & dances on 1 more place (all in opp places)
33-40::
    3s+1s dance R&L
41-48::
    3s+1s promenade around each other passing LSh back to their ''new''
    places
49-64::
    4s+2s repeat 33-48
65-72::
    All Adv+Ret, set to partner, Men about turn & all chase 1 place
    clockwise
73-80::
    Repeat 65-72
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6775, '2013-08-21 08:31:30.748819+00', '2023-02-04 01:21:48.227574+00', 12796, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, dance 1/2 Figs of 8 (1M round 2s & 1L
    round 3s) & end facing 1st corners
9-16::
    1s+1st corners dance Diagonal Chain:
::
    _9-10_    1s 1/2 turn 1st corners RH
::
    _11-14_   1s chase clockwise 1/2 way round outside of set _while_
    1st corner persons turn LH 1.1/2 times
::
    _15-16_   1s 1/2 turn original 1st corner persons RH to face them
17-24::
    1s dance reels of 3 on own sides (RSh to 3rd corner position) & end
    facing 2nd corners
25-32::
    1s+2nd corners dance Diagonal Chain to end facing 4th corner
    (position)
33-40::
    1s dance reels of 3 across (1L with 3s at top & 1M with 2s giving
    RSh to 4th corner pstn) & end looping round to face 1st corners
    (position)
41-48::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass LSH & dance
    1/2 reel with 2nd corners with 1s end passing RSh to 2nd place own
    side', 0);
INSERT INTO 'dancecrib' VALUES (6777, '2013-08-21 08:31:30.765228+00', '2023-02-04 01:21:48.283205+00', 1429, 3, NULL, 'ace', '1-8::
    1s+2s dance the Tournee :
::
    1s+2s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 2s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (2s RH, 1s LH) & 1s end
    facing 1st crnrs
9-24::
    1s dance Corner Chain with 1st & 2nd corners :
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end turning LH to end side by
    side (LSh to LSh) facing 1st corners
25-32::
    1s dance RH across (1L with 2s & 1M with 3s), pass RSh to dance LH
    across with other couple', 0);
INSERT INTO 'dancecrib' VALUES (11706, '2019-03-18 21:02:41.506708+00', '2023-02-04 01:21:48.313207+00', 5129, 3, NULL, 'ace', '1-4::
    1s lead down to 3rd place, cross & cast up to 2nd pl _while_ 2s set
    & cross RH to 3rd pl _while_ 3s cast up to 1st place & cross RH.
    (3) (1) (2)
5-8::
    3s+1s+2s dance 1/2 reflection reels of 3 on opp sides (3s out/down,
    1s NHJ dance in/up, 2s out/up) 3s end facing out. (2) (1) (3)
9-12::
    1s & 3s dance 1/2 double Fig 8 across (1s cross down, 3s dance up to
    start)
13-16::
    1s NHJ dance up to top, cast to end BtoB in centre in 2nd place
    facing opp sides _while_ 2s dance down sides, dance in/up & cross to
    top place own sides.
17-20::
    1s dance Corner Pass+Turn with 1st corners (position), pull back RSh
    to end BtoB in centre 1L facing up, 1M facing down
21-24::
    1s dance Corner Pass+Turn with 2nd corners (position), pull back RSh
    to end BtoB in centre facing opp sides
25-28::
    1s dance RSh round 1st corners (position), dance down/up middle, 1/2
    turn RH & retain RH facing up _while_ corners advance diagonally,
    briefly form circle & retire to place
29-32::
    1s continue RH turn 1.1/4 to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6779, '2013-08-21 08:31:30.784395+00', '2023-02-04 01:21:48.445273+00', 5136, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, dance down between 3s & cast back to 2nd place
9-16::
    2s+1s dance RH across 1/2 way, cross RH, dance LH across 1/2 way, 2s
    cross back LH as 1s turn LH to face 1st corners
17-24::
    1s set to & turn 1st corners 2H, set & turn 2nd corners 2H
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners &
    cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6780, '2013-08-21 08:31:30.792399+00', '2023-02-04 01:21:48.475372+00', 5137, 3, NULL, 'ace', '1-8::
    1s & 4s 1/2 turn RH times, lead into centre to dance 1/2 RH across &
    chase clockwise 1/2 way to end 1s between 2s & 4s between 3s
9-16::
    1M also 4L followed by partners dance an Alternating Tandem reels of
    3 across with 2s/3s & end between 2s/3s facing up/down
17-24::
    1s+4s set advancing towards each other & dance 1/2 RH across, lead
    out of ends & cast to 2nd/3rd place.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6781, '2013-08-21 08:31:30.800497+00', '2023-02-04 01:21:48.501561+00', 11530, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place, dance LH across 1/2 way & change
    places RH on the sides with 2s/3s.  4 2 3 1
9-12::
    All dance 1/2 RSh reels of 4 on sides,1s+3s (at top) & 2s+4s change
    places RH on sides to 3 1 4 2
13-16::
    1s+4s  dance 1/2 LH across, remaining in middle facing corners (1s
    facing 2s at bottom, 4s facing 3d at top)
17-20::
    1s+4s set as ''Hello-Goodbye''(2 bars), dance 1/2 RH across. 1s face
    new corners (1s facing 3s at top, 4s facing 2s at bottom)
21-24::
    Repeat 17-20 to end 4s facing 3s (at top) & 1s facing 2s
25-32::
    1s & 4s (only) dance RSh round corners to follow track of double
    diagonal reels of 4 & end 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (14126, '2021-07-07 00:20:49.156974+00', '2023-02-04 01:21:48.560772+00', 8069, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s+2s dance RH across & LH across back to place
17-24::
    1s lead down (2s step up 3-4) & back up to 2nd place
25-32::
    2s+1s turn partner RH & turn partner LH', 0);
INSERT INTO 'dancecrib' VALUES (6783, '2013-08-21 08:31:30.814883+00', '2023-02-04 01:21:48.583267+00', 10327, 3, NULL, 'ace', '1-8::
    All Adv+Ret, 1s slip step to bottom
9-16::
    All Adv+Ret, 2s slip step to bottom
17-24::
    3s+4s also 1s+2s circle 4H round & back _while_ 5s+6s dance RH
    across & LH back (ie OXO)
25-32::
    2s slip step to top & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6784, '2013-08-21 08:31:30.822959+00', '2023-02-04 01:21:48.606817+00', 10702, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s circle 4H round & back
9-16::
    1s+2s also 3s+4s dance RH across & LH back
17-24::
    All Adv+Ret & dance DoSiDo
25-32::
    1s cast to 4th place & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (8374, '2014-07-29 12:59:38.209589+00', '2023-02-04 01:23:09.429985+00', 14971, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link. 1s set, turn RH to finish in middle taking promenade
    hold facing 2L
9-12::
    1s dance 1/2 diagonal reel of 3 with 2nd corners passing 2L RSh to
    start. Finish facing 2M
13-16::
    1s dance 1/2 diagonal reel of 3 with 1st corners passing 2M RSh to
    start. Finish on opp. sides  (3) (1) (2)
17-20::
    3s+1s+2s join hands on sides, set, 1/2 turn partners 2H staying in
    middle facing partners
21-24::
    3s+1s+2s join hands & set, cast to own sides  (2M followed by 1M+3M;
    3L followed by 1L+2L)
25-32::
    1s+3s dance all-round (Diamond) poussette', 0);
INSERT INTO 'dancecrib' VALUES (4150, '2013-08-21 08:30:44.313505+00', '2023-02-04 01:18:37.103453+00', 8832, 3, NULL, 'ace', '1-8::
    1s+2s dance 4H round for 3 bars, back for 3 bars & 1s cast to 2nd
    place facing down as 3s dance in to face up making an arch
9-16::
    1s dance down under arch made by 3s, 3s+1s dance out ends turning
    corners with nearer hand, 3s+1s dance across (Ladies under arch made
    by their partners) & turn new corners with nearer hand (similar to
    Posties Jig)
17-24::
    1s dance up under arch made by 3s, 1s+3s dance out ends turning
    corners with nearer hand, 3s+1s dance across (Ladies under arch made
    by their partners) & turn new corners with nearer hand back to
    places
25-32::
    1s dance down & loop into 4th place as 3s+4s step up, 4s & 1s turn
    RH for 4 bars
33-40::
    2s+3s also 4s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4152, '2013-08-21 08:30:44.331539+00', '2023-02-04 01:18:37.163585+00', 7450, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    1s & 4s set then cast to 2nd/3rd places, 1s & 4s dance 1/2 Fig of 8
    round 2s/3s.  2(1)4(3)
9-16::
    1s & 4s 1/2 turn partner RH & dance 1/2 RH across, 1s & 4s turn
    partner RH to end in Prom hold (4s facing up, 1s down)
17-24::
    4s dance reel of 3 across passing 2L RSh as 1s dance reel of 3
    across passing 3L RSh ending 4s on M''s side & 1s end L''s side
25-32::
    1s & 4s set & dance 1/2 LH across, 1s & 4s dance 1/2 Ladies'' Chain
    to end 2 1(4)(3)
33-40::
    4s followed by 1s lead down for 2 & lead up to top, cross & cast 1s
    to 3rd place (opp side) & 4s to 2nd place (own side).  2 4(1)(3)
41-48::
    2s+4s also 1s+3s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (13317, '2020-11-02 01:21:19.705712+00', '2023-02-04 01:21:48.74848+00', 5141, 3, NULL, 'ace', '{{title}}
Part A

1-12::
    1s followed by 2s+3s+4s+5s+6s cast behind own lines, meet partners &
    lead up the middle
13-16::
    All turn partners RH
17-24::
    All set to partners with simple setting steps

{{title}}
Part B

1-12::
    1s take promenade hold & followed by 2s+3s+4s+5s+6s, turn to right
    to dance Fig of 8 down & up the set to places
13-24::
    All repeat bars 13-24 of Part A

{{title}}
Part C

1-12::
    All repeat bars 1-12 of Part B but with hands joined behind their
    backs
13-24::
    All repeat bars 13-24 of Part A

{{title}}
Part D

1-12::
    1s+2s+3s also 4s+5s+6s dance Grand Chain with 2 steps to each hand
    (To start, 1s & 4s face across, 2 & 5s face down, 3s & 6s face up)
13-24::
    All repeat bars 13-24 of Part A

{{title}}
Part E

1-12::
    All dance into middle with each man behind his partner (hands on
    Ladies waist).  1s & 4s face down, others face up. 1s+2s+3s also
    4s+5s+6s dance tandem reels of 3. To start 1s & 2s also 4s & 5s pass
    RSh
13-24::
    All repeat bars 13-24 of Part A

{{title}}
Part F

1-12::
    1s+2s+3s also 4s+5s+6s dance 6H twice to left
13-24::
    All repeat bars 13-24 of Part A', 0);
INSERT INTO 'dancecrib' VALUES (13188, '2020-09-15 00:21:07.995653+00', '2023-02-04 01:21:48.770341+00', 5142, 3, NULL, 'ace', '1-8::
    1s dance down the middle & cast round 3s to original place _while_
    4s cast up to top & dance down middle to original place. 1s & 4s
    set.
9-16::
    1s+2s also 3s+4s dance double Fig of 8 (1s & 3s cross down, 2s & 4s
    cast up)
17-20::
    1s & 3s giving RH cross down thru couple below & cast up to
    partner''s place.
21-24::
    2s & 4s giving LH cross up thru couple above & cast to partner''s
    place. (1) (2) (3) (4)
25-32::
    1s+2s dance 1/2 LH across, 1s+3s dance 1/2 RH across, 1s+4s dance
    1/2 LH across, all set 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14675, '2022-03-07 02:21:09.804307+00', '2023-02-04 01:21:48.790539+00', 20515, 3, NULL, 'ace', '{{explanation}}
2 chords - 3s+4s cross to opp sides on 2nd chord

1-8::
    2s+3s petronella in tandem & set, 2s+3s circle 4H round to left to
    finish back to back in middle facing corners
9-12::
    All set, all change places RH with nearest corner to finish with
    1s+4s in the middle.
13-16::
    1s+4s dance LH across to finish back to back in the middle facing
    same corner position _while_ 2s+3s dance clockwise to next corner to
    face diagonally in, set & finish 2s/3s facing down/up
17-24::
    All dance reels of 4 on the sides (1s & 4s finish on sides) 2 1 (4)
    (3)
25-30::
    2s+3s 1/2 turn partner 2H to face down. 2s dance down into 4th place
    _while_ 3s cast up to 1st place
31-32::
    All set.  3 1 (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (6785, '2013-08-21 08:31:30.831023+00', '2023-02-04 01:21:48.802541+00', 9000, 3, NULL, 'ace', '{{explanation}}
Round the Room dance 2 facing 2

1-8::
    All dance RH across & LH back
9-16::
    Ladies dance DoSiDo, Men dance DoSiDo
17-24::
    Slip step round the room Men passing BtoB & Slip step back Ladies
    passing BtoB
25-32::
    All Adv+Ret & advance to meet next couple (one couple making an
    arch)', 0);
INSERT INTO 'dancecrib' VALUES (14295, '2021-09-08 00:21:13.680314+00', '2023-02-04 01:21:48.81334+00', 20358, 3, NULL, 'ace', '{{title}}
Strathspey

1-4::
    1M+3L dance 1/2 Fig 8 round 2s _while_ 1L+3M dance 1/2 Fig 8 round
    4s
5-8::
    1M+3L dance 1/2 RH across with 2s _while_ 1L+3M dance 1/2 RH across
    with 4s
9-12::
    1s+3s dance 1/2 LH across in centre & end facing 2s & 4s
13-16::
    3L+1M dance 1/2 Fig 8 round 2s _while_ 3M+1L dance 1/2 Fig 8 round
    4s back to original places
17-24::
    All Advance (2 bars), pull back RSh & chase 3/4 clockwise round set.
    2 3 4 1
25-32::
    All circle 8H round & back

{{title}}
Reel

33-64::
    Repeat 1-32 in reel time

{{explanation}}
Repeat Strathspey & Reel', 0);
INSERT INTO 'dancecrib' VALUES (6786, '2013-08-21 08:31:30.839145+00', '2023-02-04 01:21:48.823472+00', 5147, 3, NULL, 'ace', '1-8::
    1s 1/2 turn partner into Prom hold (L on right) to cast behind 2M &
    cross between 2L & 3L, 1s cast behind 3L & dance into centre to face
    up
9-16::
    1s (NHJ) dance up to 1st pl & 1L+2L turn 1.1/2 RH _while_ 1M+2M turn
    1.1/2 LH 1s ending 2nd pl & 2s in 1st pl
17-24::
    2s+1s+3s dance reflection reels of 3 on sides (1s in & down to
    start)
25-32::
    1s cross RH & cast round 1st cnrs into middle, 1s change places LH &
    cast round 3rd corners to 2nd place own sides
33-40::
    1s+2s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6841, '2013-08-21 08:31:31.69374+00', '2023-02-04 01:21:52.919576+00', 5239, 3, NULL, 'ace', '1-16::
    1s dance full petronella back to places
17-24::
    1s lead down the middle & back again
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6787, '2013-08-21 08:31:30.847185+00', '2023-02-04 01:21:48.834403+00', 5151, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & turn LH to end in prom hold facing Ladies
    side (Lady on Man''s left)
9-12::
    1s dance 1/2 reel of 3 with 3s (1s giving RSh to 3L)
13-20::
    1s dance reel of 3 with 2s (1s giving RSh to 2M)
21-24::
    1s dance 1/2 reel of 3 with 3s (1s give RSh to 3L) & end with 1s
    turning RH to 2nd place back-to-back with Lady facing down
25-32::
    1s dance Double Triangles with top & bottom couples & end with a
    petronella turn to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6788, '2013-08-21 08:31:30.85695+00', '2023-02-04 01:21:48.84824+00', 5154, 3, NULL, 'ace', '1-8::
    1s+2s+3s couples dance 6H round & back.
9-16::
    1s dance towards each other & lead down to 3rd place, cross & cast
    up to top followed by 2s+3s who dance up to top & repeat the track
    of the 1s all ending in partner''s place
17-24::
    1s+2s+3s petronella turn into middle & set, petronella turn to
    original places & set
25-32::
    1s+2s dance 1/2 R&L, set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (6789, '2013-08-21 08:31:30.86506+00', '2023-02-04 01:21:48.860249+00', 13727, 3, NULL, 'ace', '{{explanation}}
2s start on opposite sides

1-8::
    1s cross down RH & cast down behind 3s, cross up RH & cast up round
    2s
9-16::
    1s+2s+3s dance Grand Chain, 1M & 2M face out
17-24::
    1s+2s dance Ladies'' Chain
25-32::
    1s+2s dance 1/2 R&L (Men polite turns), 1s+3s dance 1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (11207, '2018-09-30 22:20:21.084462+00', '2023-02-04 01:21:48.902358+00', 18033, 3, NULL, 'ace', '1-8::
    1s cross down into Mirror reels of 3 on opp sides
9-16::
    1s dance 1/2 Fig 8 down round 2s; 1s dance down & cast up round 3s
    to 2nd place own side (2s step up 15-16)
17-20::
    1s+1st corners dance 1/2 R&L (corners end facing out)
21-24::
    3L dances down behind 2 Men, across into place _while_ 2M dance up
    behind 2 Ladies, across into place
25-28::
    1L+2L & 1M+3M dance 1/2 R&L (1M down, 1L up to start)
29-32::
    2L crosses & casts up to 1st place, 3M crosses & casts to 3rd place
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6791, '2013-08-21 08:31:30.881286+00', '2023-02-04 01:21:48.928931+00', 10957, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s dance RH across, 1s & 4s cross RH & cast in 1 place
9-16::
    1s+4s dance LH across, 2s+1s also 4s+3s turn RH (4 bars) on sides to
    end with 2s & 4s facing down & 1s & 3s facing up
17-24::
    All dance reels of 4 on sides (1s & 4s do not fully complete reel
    but turn right about to face other corner)
25-32::
    4s & 1s turn corners RH, 4s+1s dance LH across
33-40::
    4s & 1s dance up/down behind 2s/3s, cross RH & dance down/up behind
    2s/3s & cross RH.  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (13428, '2020-12-02 01:21:13.694416+00', '2023-02-04 01:21:48.959273+00', 19902, 3, NULL, 'ace', '{{explanation}}
For 1 dancer in 1 dancer set. Any number of dancers in their own rooms.  Couch as 1s & coffee table as 3s & beverage as 4s

1-8::
    Dancer casts behind own couch & chases back to place
9-16::
    Dance DoSiDo around coffee table & slip step away from the table &
    back
17-24::
    Dance down the hallway, into the kitchen, grab a beverage & dance
    back to place
25-32::
    Set _while_ placing beverage on table, turn on the spot twice using
    Pas De Basque & retire to the couch, sit & enjoy', 0);
INSERT INTO 'dancecrib' VALUES (13429, '2020-12-02 01:21:13.710112+00', '2023-02-04 01:21:48.980514+00', 19903, 3, NULL, 'ace', '{{explanation}}
No hands are given throughout this dance

1-2::
    1s Petronella turn into centre
3-4::
    1s set _while_ 2s Petronella turn (2L between 1s)
5-6::
    1s Petronella turn to opposite sides _while_ 2s set _while_ 3s
    Petronella turn (3L between 2s)
7-8::
    1s set _while_ 2s Petronella turn to opposite side _while_ 3s set
9-10::
    1s pass LSh back to own side facing out _while_ 2s set _while_ 3s
    Petronella to opposite side
11-12::
    1s start casting into 3rd place _while_ 2s cross up to top place
    facing in _while_ 3s set
13-14::
    1s finish casting into 3rd place, 2s pass LSh to face out & 3s cross
    up to 2nd place facing in
15-16::
    1s set _while_ 2s cast down to 2nd place facing in _while_ 3s pass
    LSh to finish back to back in centre facing opposite sides (3M
    facing 2M & 3L facing 2L)
17-24::
    2s+3s dance a reel of 4 across the dance, to finish shoulder to
    shoulder facing down with Men on the left of their partner, 3s in
    the lead
25-32::
    2s+3s cross down below 1s, cast up & meet in centre to face up. 3s
    cast into 2nd place, 2s finish in 1st place facing in. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (10224, '2017-11-04 01:45:54.238594+00', '2023-02-04 01:21:48.998668+00', 18031, 3, NULL, 'ace', '1-8::
    1s+3s dance RH across, 1M & 3L dance out between 2s _while_ 1L & 3M
    dance out between 4s & all cast back to places
9-16::
    1s in prom hold dance reel of 3 across with 4M+2L (pass 2L RSh)
    _while_ 3s in prom hold dance reel of 3 with 2M+4L (pass 2M RSh)
17-24::
    1s+3s dance Ladies'' Chain .
25-32::
    All Men followed by partners chase 1/2 way round set. All set &
    petronella-in-tandem to next place to right.  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (6119, '2013-08-21 08:31:19.111042+00', '2023-02-04 01:21:49.019406+00', 5160, 3, NULL, 'ace', '1-8::
    1s cast to 2nd place & 1s+3s circle 4H round to left
9-16::
    1s cast up to top & 1s+2s circle 4H round to left
17-24::
    1s lead down for 3 steps, lead up & cast to 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6792, '2013-08-21 08:31:30.911573+00', '2023-02-04 01:21:49.043764+00', 10762, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 3s
9-16::
    1s pass RSh, cast to right _while_ 2s & 3s set & change places RH
    with partners 1M ending between 3s facing up & 1L between 2s facing
    down, 1s pass RSh & cast to right to 2nd place opposite side _while_
    2s & 3s set & change places RH on sides
17-24::
    1s pass RSh, cast to right _while_ 2s & 3s set & change places RH
    with partners, 1M ends between 3s facing down & 1L between 2s facing
    up, 1s pass RSh & cast to right to 2nd place own side _while_ 2s &
    3s set & change places RH on sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12819, '2020-05-14 23:15:45.611139+00', '2023-02-04 01:21:49.065606+00', 19934, 3, NULL, 'ace', '1-8::
    1s+2s set, turn RH (4 bars), petronella turn to line of 4 in centre
    (Ladies facing down / Men up)
9-16::
    1s+2s dance 1/2 RSh reel of 4 (2L+1M pass LSh at end) to end Ladies
    facing up, Men Down; All chase clockwise back to original place
17-24::
    2L followed by 1L dance tandem reel of 3 across with 3s (RSh to 3M).
    End 2L in 1st place, 1L in 2nd place own side
25-32::
    2M followed by 1M dance tandem reel of 3 across with 3s ( LSh to
    3L). End 2M in 1st place, 1M in 2nd place own side.  2 1 3

{{explanation}}
Note:	Bar 17: 3rd woman may begin the tandem reel of three by casting up, thus allowing 2nd and 1st woman time to pass', 0);
INSERT INTO 'dancecrib' VALUES (13318, '2020-11-02 01:21:20.042849+00', '2023-02-04 01:21:49.090438+00', 19177, 3, NULL, 'ace', '1-8::
    All clap, 2s followed by 1s dance Fig 8 round 3s. End 2 1 3
9-16::
    1s pass partner RSh, pull back RSh & retire to opp sides _while_
    2s+3s dance DoSiDo with partners; 1s turn RH end facing each other
    with backs to 1st corners
17-24::
    »Corners Chase & Turn«:
::
    _17-20_   1s followed by corners pass RSh, 1s dance to 3rd corner
    pstn & set _while_ corners pull back RSh, turn RH ending with backs
    to 1s
::
    _21-24_   1st corners followed by 1s pass RSh, dance to original
    corner & set _while_ 1s pull back RSh, turn 3/4 RH ending with backs
    to 2nd corners
25-32::
    Repeat 17-24

{{explanation}}
Note:	2nd time through, bars 31-32: 1s turn RH to bottom of set (4s step up)', 0);
INSERT INTO 'dancecrib' VALUES (7958, '2013-08-21 08:31:51.84783+00', '2023-02-04 01:23:13.750004+00', 7175, 3, NULL, 'ace', '1-8::
    1s cross down (no hands) _while_ 3s dance inwards, 1s turn 3s on
    sides (1s dancing out), 1s dance up _while_ 2s dance in, 1s turn 2s
    (1s dancing out) & end facing 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting & end 1M between 2s, 1L between 3s
17-24::
    1s turn RH 1.1/4 times, lead up, cross & cast to 2nd place own sides
25-32::
    1L+2M also 1M+3L turn RH, 1M+2L also 1L+3M turn LH', 0);
INSERT INTO 'dancecrib' VALUES (13607, '2021-02-04 01:18:25.618957+00', '2023-02-04 01:18:27.289774+00', 15235, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 2s & 4s cross to opp sides

1-8::
    1s+2s & 3s+4s Set+Link; 1L+4M & 1M+4L turn LH. (2) 1 (4) 3
9-16::
    1s+4s dance Ladies'' Chain (across the dance) with an extra 1/2 LH
    turn on bars 15-16 to end (2) 4 (1) 3
17-24::
    Reels of 4 on sides but instead of pass LSh at end 1s+4s dance round
    to right BtoB facing corners (2) 1 (4) 3
25-32::
    »Puffin Reels«:
::
    2s+3s dance diag reel of 4 (LH across in centre) _while_
::
    1s+4s dance 1/2 diag reel round corner, pass LSh, dance 1/2 diag
    reel round next anticlockwise corner, pass LSh to face 3rd corner.
    (2) 4 (1) 3
33-40::
    2s+4s & 1s+3s dance RH across; all turn partner 1.1/2 RH.  End 2 (4)
    1 (3)', 0);
INSERT INTO 'dancecrib' VALUES (8347, '2014-07-29 12:59:22.243324+00', '2023-02-04 01:21:49.115496+00', 15370, 3, NULL, 'ace', '1-8::
    1s dance down the middle & back  to 2nd place (2s step up on bars
    3-4)
9-16::
    2s & 3s  cast into a clockwise chase back to places _while_ 1s cast
    into a clockwise chase 1/2 way, 1s turn RH 1.1/4  to face 1st
    corners.
17-24::
    1s dance Corner Pass+Turn, at the end 1s dance in toward each other,
    pull RSh back to face 1st corners again
25-32::
    Interrupted Hello-Goodbye setting
::
    1s set to 1st corner and partner, turn 3/4 RH  to face 2nd corners;
::
    Repeat with 2nd corner); end on own side in 2nd place, facing down 2
    1 3
33-40::
    1s dance  reels of 3 on the sides, (1s dance out & down to begin)
::
    Second time:  1s & 4s continue reeling for 2 bars (4s to 3rd place,
    1s to 4th place) as new 1s begin.', 0);
INSERT INTO 'dancecrib' VALUES (8067, '2013-10-01 08:47:15.850653+00', '2023-02-04 01:21:49.245667+00', 15131, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s cross LH & turn 3rd corner RH to end
    between 2s/3s
9-16::
    1s dance reels of 3 on own sides & end between 2s/3s
17-24::
    1s, cross LH up/down & turn 4th corner RH & end 2nd place own sides,
    1s turn with left hand
25-32::
    1s dance reels of 3 across (L with 2s, M with 3s) & end 2nd place
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (6794, '2013-08-21 08:31:31.038006+00', '2023-02-04 01:21:49.272688+00', 8521, 3, NULL, 'ace', '1-8::
    All cross RH, set, cross back RH & set
9-16::
    1s+2s dance RH across as 3s+4s dance LH across, 1M followed by 2M
    dance up, cross & dance down Ladies side as 3M+4M dance down, cross
    & up _while_ 2L+1L cross diagonally to bottom of set as 3L+4L cross
    up to top End 2M 1M 4M 3M on Ladies side & 3L 4L 1L 2L on Men''s side
17-24::
    Top couples dance RH across as bottom couples dance LH across, top 2
    Ladies dance up, cross & down own side as bottom 2Ladies dance down,
    cross & up Ladies side _while_ top 2 Men cross diagonally to bottom
    of set as bottom 2 Men cross up to top End 4 3 2 1
25-32::
    Top couples (4s+3s) dance RH across as bottom couples (2s+1s) dance
    LH across, 2s cast up to top as 4s lead down to 3rd place.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6795, '2013-08-21 08:31:31.048173+00', '2023-02-04 01:21:49.306088+00', 5168, 3, NULL, 'ace', '1-8::
    1s cross RH, cast to 3rd place, 3s+1s RH across to end 1L+3M in prom
    hold facing toward 2s & 1M+3L facing toward 4s
9-16::
    1L+3M reel of 3 across with 2s (giving RSh to 2L) _while_ 1M+3L reel
    of 3 with 4s (giving RSh to 4M) to end 2 3(1)4
17-24::
    2s+3s also 1s+4s double Fig of 8 (3s & 1s crossing up/down between
    2s/4s to start)
25-32::
    All dance "Drop Out" Chain i.e. start normally with 2s & 4s crossing
    as 3s+1s change places on sides but 1s stop at 4th place (bar 6), 4s
    at 3rd place (bar 7), 2s at 1st place & 3s at 2nd place (bar 8).  2
    3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13319, '2020-11-02 01:21:20.289597+00', '2023-02-04 01:21:49.332912+00', 19409, 3, NULL, 'ace', '1-8::
    1s+2s dance Tourbillon:
::
    _1-4_   1s & 2s 1/2 turn ptnrs 2H, 1M & 2L lead ptnrs by nearer hand
    1 place cl''wise to end 1s on Ladies side & 2s Men''s side, 1s set to
    2s
::
    _5-8_   1s & 2s 1/2 turn ptnrs 2H & lead ptnrs on 1 place clockwise,
    2s cross RH to own sides, 1s turn 2H to face 1st corners
9-12::
    1s+1s corners dance Modified Corner Pass+Turn (as per Corner
    Pass+Turn except corners 1/2 turn 2H, face each other, pull back RSh
    & dance out to opp corner. 1s pass RSh, pull back RSh to face 2nd
    corners
13-16::
    1s+2nd corners repeat 9-12.  Bars 15-16: 1s meet in centre, pull
    back RSh, dance into 2nd place opp side.  (3) (1) (2)
17-24::
    3s+1s+2s set, dance RSh once round partner to own side.  3 1 2
25-32::
    1s dance »Figure of Love«:
::
    _25-28_   1s dance RSh round 2nd corner (pstn), meet in centre &
    touch 2H
::
    _29-32_   1s pull back RSh & dance RSh round 1st corner (pstn) into
    2nd place own side
33-40::
    3s+1s+2s circle 6H round & back.', 0);
INSERT INTO 'dancecrib' VALUES (13915, '2021-04-05 00:21:14.398467+00', '2023-02-04 01:21:49.344539+00', 19483, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s+4s cross to opp sides

1-4::
    1M+2s & 4M+3s dance 1/2 reels of 3 across (1M+2L & 4M+3L pass LSh).
    1s & 4s finish in prom hold with partner
5-8::
    1s & 4s continue 1/2 reel of 3 across in prom hold. End 1s on Men''s
    side above 2M, 4s on Ladies'' side below 3M
9-16::
    1s & 4s dance in (2s & 3s step up/down), 1s+4s dance 1/2 RH across;
    1s+4s dance LH across once round. 1M+4L & 4M+1L take prom hold &
    face 1st corners (1st corner diagonal)
17-20::
    1M+4L & 4M+1L in prom hold dance Corner Pass+Turn with 1st corners
    (corners - 2M+3M turn RH in middle), 1s+4s take prom hold with own
    partner facing 2nd corners (2nd corner diagonal)
21-24::
    1s & 4s in prom hold dance Corner Pass+Turn with 2nd corners (1s &
    4s pass corners LSh to start, corners turn LH).  End 1s between 2s
    facing down, 4s between 3s facing up
25-32::
    Lines of 4 across set, 1s+4s cross RH up/down; 4s+1s circle 4H round
    to left.  End 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (6796, '2013-08-21 08:31:31.05661+00', '2023-02-04 01:21:49.355843+00', 11639, 3, NULL, 'ace', '1-8::
    1s+2s also 4s+5s dance RH across & LH back _while_ 3s cross RH &
    dance clockwise 1/2 way back to own place
9-16::
    3M dances reel of 3 with 1M+2M giving LSh to 2M _while_ 3L dances
    reel of 3 with 4L+5L giving LSh to 4L
17-24::
    3M dances reel of 3 with 4M+5M (giving RSh to 4M) _while_ 3L dances
    reel of 3 with 1L+2L (giving RSh to 2L)
25-28::
    2s & 3s turn RH moving up 1 place _while_ 1M followed by partner
    casts to 3rd place & crosses over.  2 3 1 4 5
29-32::
    4s & 5s turn RH moving up 1 place _while_ 1M followed by partner
    casts to 5th place & crosses to own side.  2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (6854, '2013-08-21 08:31:31.836066+00', '2023-02-04 01:21:53.81213+00', 10703, 3, NULL, 'ace', '1-8::
    1s+2s+3s turn partners RH & chase clockwise 1/2 way. (3) (2) (1)
9-16::
    3s+2s+1s turn partners LH & chase anticlockwise 1/2 way. 1 2 3
17-24::
    1s dance reels of 3 on sides (LSh to 2s)
25-32::
    1s lead down middle & back then cast to 2nd place (2s step up).  End
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8847, '2015-08-13 20:33:58.613443+00', '2023-02-04 01:21:49.370661+00', 13124, 3, NULL, 'ace', '1-8::
    1s cross, cast (2s step up)  1s+2M+3L (1st corners) dance RH across
    & retain RH
9-12::
    1s+2M+3L set, join LH with opp person on 2nd setting step (retain
    RH) set, release RH on 2nd setting step & all face anticlockwise
13-16::
    1s+3M+3L dance LH across, 1s join RH with 2nd corners, LH with
    partner (2M & 3L return to places)
17-20::
    1s+2nd corners Bal-in-Line. 1s drop LH & 1s+2nd corners set with
    Lady turning under Man''s arm. 1s end facing 2nd corners
21-28::
    1s+2nd corners dance RSh reel of 4. 1s give LH in passing at end of
    reel & retain LH
29-32::
    1s (LH joined) set, take RH with partner on 2nd setting step (retain
    LH), then release LH and turn 3/4 RH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (13430, '2020-12-02 01:21:13.993562+00', '2023-02-04 01:21:49.544174+00', 5174, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd place)
9-16::
    1s cross, pass RSh & cast to their right; 1s cross up/down, pass LSh
    & cast to their left to end in 2nd place own side
17-24::
    1s pass LSh to dance 1/2 diag reel of 4 with 1st corners; 1s pass
    LSh to dance 1/2 diag reel of 4 with 2nd corners.  1s end in 2nd
    place opp sides.  (3) (1) (2)
25-32::
    3s+1s+2s turn partner RH flowing into 6H 1/2 round to left.  End 2 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (13766, '2021-03-02 01:21:21.368095+00', '2023-02-04 01:21:49.567536+00', 13705, 3, NULL, 'ace', '{{explanation}}
3s+4s start on opposite sies.

1-6::
    All clap, 1s+4s dance DoSiDo; 1s cross down 1 place & 4s cross up 1
    place (2s step up & 3s step down 5-6). 2 (1) 4 (3)
7-8::
    1s & 4s advance, join RH with partner & Ladies turn under Mans''s
    right arm to end 1L followed by 1M facing 2M, 4L followed by 4M
    facing 3M (1st corner diagonal)
9-10::
    1s+4s dance Alternating Tandem 1/2 reel of 4 with 2M & 3M (2 bars
    i.e. pass corner and change lead)
11-12::
    1s+4s dance RH across 1/4 round (2 bars), 1s face 3L & 4s face 2L
    (2nd corner diagonal)
13-16::
    1s+4s repeat 9-12, 1s face 2M & 4s face 3M (1st corner diagonal)
17-20::
    1s+4s dance Alternating Tandem Pass+Turn with 2M+3M; 1s+4s dance RH
    across 1/4 round, 1s face 3L & 4s face 2L (2nd corner diagonal)
21-24::
    1s+4s dance Alternating Tandem Pass+Turn with 3L+2L; 1s+4s dance RH
    across 1/4 round & face clockwise
25-28::
    1s+4s dance RH across _while_ 3s+2s chase anticlockwise 1/2 round.
    End 2 4 (1) (3) with 4s+1s BtoB in centre facing corner
29-32::
    All turn corner LH (4M with 2M, 4L with 2L, 1M with 3M, 1L with 3L).
    End in longwise set. 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (10090, '2017-09-03 23:45:13.852055+00', '2023-02-04 01:21:49.586734+00', 17778, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Set & Rotate
9-12::
    1s+4s dance LH across _while_ 2s+3s chase clockwise 1/2 round.  All
    end on sides, 3M,1M, 4L & 2L facing out
13-16::
    3s+1s also 4s+2s dance RH across.  1s+4s end in middle, 1L behind 1M
    facing 2M place, 4M behind 4L facing 3L place
17-24::
    1s & 4s in tandem dance Corner Pass+Turn with 3L & 2M, pass RSh in
    middle, and repeat with 3M & 2L.  Bar 23-24 4L+1M pass LSh, cross to
    opp sides  3 (4) (1) 2
25-32::
    Reel of 4 on sides (3s+4s also 1s+2s pass RSh to start)
33-36::
    3s+4s also 1s+2s circle 4H round to Left
37-40::
    All set to partners.  3s+2s cross RH _while_ 4s+1s dance 1/2 LH
    across.  End 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (10631, '2018-04-16 21:42:24.078976+00', '2023-02-04 01:21:49.60408+00', 17405, 3, NULL, 'ace', '{{explanation}}
Start 5s face each other in centre, 5M with back to 4s, 5L with back to 2s

1-8::
    2s+4s (in prom hold) +5s dance reel of 4 across, 5s pass RSh to
    start then pass 2s/4s RSh.  5s end reel passing LSh
9-16::
    5M dances behind 2s (pass 2L RSh) to between 2M & 3L _while_ 5L
    dances behind 4s (pass 4L RSh) to between 4M & 1L.  Lines of 3
    Adv+Ret
17-20::
    3M+4L also 1M+2L turn RH _while_ 5s 1/2 turn RH (& twirl -
    optional); 5L faces 3M+4L NHJ _while_ 5M faces 1M+2L NHJ & All set
21-24::
    5M+1M+2L also 5L+3M+4L dance RH across, 5s pass RSh
25-32::
    5M followed by 5L dance to 1st place _while_ 1M followed by 1L dance
    to 4th place (pass RSh).  4s+1s repeat (4s to 3rd place), 3s+2s
    repeat (3s to 2nd place).  End 2s in centre facing each other 2M
    with back to 4s, 2L with back to 2s', 0);
INSERT INTO 'dancecrib' VALUES (6798, '2013-08-21 08:31:31.19841+00', '2023-02-04 01:21:49.793055+00', 10483, 3, NULL, 'ace', '1-8::
    1s Advance 1 step (touch RH) & Retire, petronella turn into middle,
    Advance 1 step (touch RH) & Retire & petronella turn to opposite
    sides
9-16::
    1s+2s dance RH across & LH back
17-24::
    1s+2s dance Ladies'' Chain (up/down middle) ending in line up/down
    middle (Lady facing down & Men up)
25-32::
    1s+2s dance HS Poussette:
::
    1s set HS step with both hands joined dance out to Men''s side
    _while_ 2s set & dance out to Ladies'' side both couples end with a
    1/4 turn to right
::
    1s dance HS down Men''s side _while_ 2s dance up Ladies'' side both
    couples end with a 1/4 turn to right
::
    2s+1s dance HS into centre to reform line of 4 in middle
::
    2s+1s 3/4 turn partners with 2H to own sides', 4);
INSERT INTO 'dancecrib' VALUES (13431, '2020-12-02 01:21:14.328266+00', '2023-02-04 01:21:49.939271+00', 19162, 3, NULL, 'ace', '1-8::
    1s 1/2 turn 2H, pull back RSh. 1s cast _while_ 2s cross up RH to 1st
    place opp sides; 1s turn 2H  to end in centre, 1M facing down, 1L up
9-16::
    1L+2s also 1M+3s dance 1/2 reels of 3 across (1L up, 1M down); 1s
    pass LSh to dance 1/2 reel of 3 across with other couple. Bars
    15-16: 1s 1/2 turn 2H to end in centre, own sides facing down
17-24::
    Mirror reels of 3 on sides giving hands (1s in/down to start).
    Corners curve into place at end
25-32::
    1s 1/2 turn 2H, pull back RSh. 1s cast _while_ 3s cross up RH to 2nd
    place opp sides; all 3 couples turn partner 1.1/2 2H.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (10341, '2017-12-22 15:44:52.204027+00', '2023-02-04 01:21:49.958057+00', 5178, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp side

1-4::
    1s+2s also 3s+4s dance RH across.  1L & 4L finish facing out, 2M
    facing down, 3M facing up
5-8::
    2s+3s dance LH across _while_ 1s & 4s chase clockwise 1/2 round to
    opposite end
9-16::
    Parallel RSh reels of 4 on sides. 4 2 (3) (1)
17-24::
    All change places RH on sides retaining hands & all Bal-in-Line.
    1M+4L also 1L+4M turn LH and Men face out.  2 4 (1) (3)
25-32::
    1s+4s dance Ladies'' Chain, Men casting up/down on sides to start.
    Men omit polite turn at end ready for RH across in next time through', 0);
INSERT INTO 'dancecrib' VALUES (13320, '2020-11-02 01:21:20.870445+00', '2023-02-04 01:21:50.147031+00', 16963, 3, NULL, 'ace', '1-8::
    1L+2L+3L set advancing _while_ partners set, Ladies cast right, back
    to place _while_ Men set advancing; Ladies set _while_ Men cast
    right, back to place, all set
9-16::
    1s+3s dance Double Fig 8 (1s cross down, 3s cast up)
17-24::
    2s followed by 1s dance down NHJ, cast up round 3s, dance up NHJ &
    cast into original place, all set
25-32::
    1s+2s dance »La Spirale«:
::
    _25-26_   1s+2s 3/4 turn 2H
::
    _27-28_   1M+2L pull back RSh & cast round each other (1M to 2M''s
    place, 2L to 1L''s place) _while_ 1L & 2M chase clockwise 1/2 round
    to end 2 1 3
::
    _29-32_   2s+1s turn partner 2H', 0);
INSERT INTO 'dancecrib' VALUES (6800, '2013-08-21 08:31:31.290764+00', '2023-02-04 01:21:50.177179+00', 8361, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1L & 4L dance in slightly & followed by partner cast 1 place & 1s+4s
    dance LH across ending in St Andrews cross with corners
9-16::
    All Bal-in-Line (HS), 1s & 4s turn crnrs RH & pass ending - 4M in
    middle at top, 1M in middle at bottom & 1L+4L BtoB facing prtnrs
    (up/down)
17-24::
    4s+1s dance reel of 4 & end in 2nd/3rd place (on original sides)
    facing out.  2 (4) 1 (3)
25-30::
    2s+4s also 1s+3s dance 3/4 double Fig of 8  (2s & 3s cross down/up
    to start).  4 2 (3)(1)
31-32::
    4s+2s also 3s+1s change places on sides (Men RH, Ladies LH) to end 2
    4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (6801, '2013-08-21 08:31:31.298871+00', '2023-02-04 01:21:50.204186+00', 5181, 3, NULL, 'ace', '1-8::
    1s cast 1 place, petronella turn to face own sides, set as in Double
    Triangles & 1s dance round to face opposite side
9-16::
    1s dance 1/2 reels of 3 on opposite sides (RSh to 1st corner) & loop
    round to face up/down, set (as DT) & dance round to face opposite
    direction
17-24::
    1s dance 1/2 reels with 3s/2s giving RSh to 2nd corner (pstn) & loop
    round to face opposite sides, set (as DT) & dance round to face own
    sides
25-32::
    1s dance 1/2 diagonal RSh reel of 4 with 1st corner (pstns), pass
    LSh & dance 1/2 diagonal reel with 2nd corner (pstns).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6802, '2013-08-21 08:31:31.3069+00', '2023-02-04 01:21:50.220881+00', 12614, 3, NULL, 'ace', '1-8::
    1s dance down & lead back to top (2s+3s step in)
9-16::
    1s+2s+3s Promenade 1s+2s remaining in middle
17-24::
    1s cast to 2nd place as 2s dance up, 1s dance 1/2 Fig of 8 round 2s
    & set
25-32::
    2s+1s+3s Adv+Ret, 1s turn LH to face 1st corners
33-40::
    1s turn 1st corner RH, partner LH, 2nd corner RH & 1/2 turn partner
    LH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (8187, '2014-02-10 10:26:51.984943+00', '2023-02-04 01:21:50.242246+00', 14073, 3, NULL, 'ace', '1-8::
    1s & 2s Set+Link; 2s & 1s cross RH with ptnr and set
9-16::
    1s & 3s Set+Link; 3s & 1s cross RH with ptnr and set
17-20::
    1s cast up as 2s & 3s cross down LH; 1s, 2s & 3s set
21-24::
    1s, 2s & 3s turn ptnrs RH to finish ready for…
25-32::
    1s, 2s & 3s Promenade, 1s casting to 2nd place, 2s dancing up to top
    bars 31-32', 0);
INSERT INTO 'dancecrib' VALUES (6803, '2013-08-21 08:31:31.314948+00', '2023-02-04 01:21:50.264943+00', 10329, 3, NULL, 'ace', '1-8::
    All dance 1/2 Grand Chain, Ladies turn left about & dance back to
    places followed by Partners
9-16::
    All dance double reels of 4 giving LH in centre (Ladies start & Men
    cast to right on the spot & follow) & end in each others place Men
    facing out
17-32::
    All dance full Schiehallion Reel (Men following partner) & end in
    partners place
33-40::
    All turn partners RH into Allemande hold, dance 1/2 way round
    anticlockwise & turn LH into place (opposite to original places)', 0);
INSERT INTO 'dancecrib' VALUES (6804, '2013-08-21 08:31:31.32306+00', '2023-02-04 01:21:50.289921+00', 5187, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & 1s followed by 2s+3s cast on own sides, cross LH
    below 3rd place & dance up opposite sides to partner''s original
    place
9-16::
    1s followed by 2s+3s lead down for 4 steps, turn inwards then 3s
    followed by 2s+1s lead up & cross at top casting to original places
    (1s & 3s face out)
17-24::
    1s+2s+3s dance reflection reels of 3 on own sides (1s out/down, 2s
    in/down, 3s out/up to start).  1s & 2s end in middle facing down,
    joining RH with partner (3s in orig places)
25-32::
    2s followed by 1s lead down for 2 bars & 1/2 turn partners RH, 2s+1s
    dance 1/2 RH across & 2s followed by 1s lead up to new places.  2 1
    3 4', 0);
INSERT INTO 'dancecrib' VALUES (12935, '2020-07-01 00:21:00.132552+00', '2023-02-04 01:21:50.31702+00', 13129, 3, NULL, 'ace', '1-4::
    1s & 4s cast down/up 1 place (2s & 3s step up/down), 1s+4s dance 1/2
    RH across
5-8::
    1s+4s Adv+Ret (1 step), Adv (1 step), join NH with partner & Ret (1
    step) remaining in middle
9-16::
    1s+4s Set+Link (4M & 1L omit polite turn); 2s+4s & 1s+3s dance RH
    across ending on sides
17-24::
    All dance RSh reels of 4 on sides.  At end 2L & 3M curve round to
    face clockwise
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6805, '2013-08-21 08:31:31.331153+00', '2023-02-04 01:21:50.338969+00', 12892, 3, NULL, 'ace', '1-8::
    1s set, cast to 2nd place (2s step up), dance down between 3s & cast
    up to 2nd place
9-16::
    1s with 1st corners Adv+Ret;  1s turn 1st corners RH
17-24::
    1s with 2nd corners Adv+Ret; 1s turn 2nd corners RH, 1s pass RSh to
    2nd place own side
25-32::
    2s+1s+3s circle 6H round & back.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6806, '2013-08-21 08:31:31.339263+00', '2023-02-04 01:21:50.362742+00', 5188, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-8::
    1s & 4s 1/2 turn partners RH to 2nd/3rd places (in centre) as 2s &
    3s step up/down, 1s+4s set & cross up/down & cast to 2nd/3rd places.
    2 1(4)(3)
9-16::
    1M+4L also 1L+4M in prom hold dance 1/2 LSh reels of 3 on sides (up
    on L side & down M side), 1/2 RSh reels of 3 across with 2s/3s end 3
    4(1)(2)
17-24::
    3s+4s also 1s+2s turn on sides (Men LH & Ladies RH), 1s & 4s dance
    1/2 Figs of 8 round 2s/3s
25-32::
    1s+4s dance Set & Rotate to end 3 1 (4) (2) :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)', 0);
INSERT INTO 'dancecrib' VALUES (14128, '2021-07-07 00:20:50.841069+00', '2023-02-04 01:21:50.391481+00', 17563, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cast as 2s dance up & face out; 1s+2s turn on side
    (Men LH, Ladies RH) to end in line of 4 across, 2s facing down, 1s
    NHJ between 2s facing up
9-16::
    1s+2s set, 1s+2s turn 3/4 (Men LH, Ladies RH), 1s cross down (no
    hands) to below 3s; 1s+3s turn (1M+3L LH, 1L+3M RH), 1s end in 2nd
    place opp sides. 2 (1) 3
17-24::
    1s cross RH, cast to right round 3rd corner _while_ 2s+3s set &
    cross RH; 1s cross LH up/down & cast to left round 1st corner (pstn)
    to 2nd place opp sides _while_ 2s+3s set up/down & change places LH
    on sides. (3) (1) (2)
25-32::
    1s pass LSh to dance 1/2 diag reel of 4 with 1st corners (3rd corner
    pstn), pass LSh & dance 1/2 diag reel of 4 with 2nd corners (4th
    corner pstn).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12098, '2019-08-30 09:54:46.98167+00', '2023-02-04 01:21:50.414259+00', 19078, 3, NULL, 'ace', '1-8::
    1s+4s set, cast down/up 1 place & dance 1/2 Fig 8 round end couples
    (2s & 3s step up/down bars 3-4)
9-16::
    1s+4s dance RH across & face corners; 1s+4s turn corners 1.1/2 LH
    (or birl) to change places
17-24::
    2s+3s dance RHA, turn corners 1.1/2 LH (or birl) to end 2 (1) (4) 3
25-32::
    1s+4s Set+Link; 1s dance 1/2 Fig 8 down round 3s _while_ 4s dance
    1/2 Fig 8 up round 2s.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9923, '2017-06-05 11:31:36.346317+00', '2023-02-04 01:21:50.441802+00', 14141, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 2L faces out.  2L followed by 2M casts 2 places to
    3rd place opp sides _while_ 3M followed by 3L casts up 2 places to
    1st place opp sides
9-16::
    3s+1s+2s dance »Bottom Open U-Chain«:
::
    _9-10_    3s cross RH _while_ 1s+2s change places RH on sides
::
    _11-14_  Chain continues, each couple arriving at 3rd place set
    _while_ other change places LH.
::
    _15-16_  3s (in 3rd place) set _while_ 2s+1s change places LH to end
    NHJ in centre, ready for …
17-24::
    1s+2s dance Rondel.  1s end in 2nd place facing out
25-32::
    1s+3s change places (1L+3L RH, 1M+3M LH).  1s dance up to top & cast
    to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (6807, '2013-08-21 08:31:31.347268+00', '2023-02-04 01:21:50.477549+00', 9879, 3, NULL, 'ace', '1-8::
    2s+3s dance 1/2 R&L, 1s+3s also 2s+4s dance 1/2 R&L
9-16::
    1s+4s dance 1/2 R&L, 1s+2s also 3s+4s dance 1/2 R&L.  (4)(3)(2)(1)
17-24::
    All dance 1/2 Grand Chain
25-32::
    1s+2s dance 1/2 RH across, 1s+3s dance 1/2 LH across, 1s+4s dance
    1/2 RH across & all turn LH to own side', 0);
INSERT INTO 'dancecrib' VALUES (14565, '2022-01-26 08:54:01.808544+00', '2022-01-26 08:57:44.886234+00', 20641, 1, 202, 'ace', '1--::

  R&L (1,2)

9--::

  1c cross RH | cast off (2c up) ; turn P LH to 2plx. 1M faces out (2,1x)

17--::

  L-Chain (2,1x)

25--::

  1c set | cross RH ; turn P LH (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (14566, '2022-01-26 15:43:08.352481+00', '2022-02-13 16:59:16.512512+00', 15602, 1, 202, 'ace', '1--::

  All set | Petronella turn in tandem ; repeat [1-4] (3,4,1,2)

9--::

  3c+1c L-Chain (3,4,1,2)

17--::

  4c+2c L-Chain (3,4,1,2)

25--::

  All Set to and Turn Corners RH ; repeat [25-28] with P. All M face in, all W face out

33-48::

  Schiehallion Reels (3,4,1,2)', 4);
INSERT INTO 'dancecrib' VALUES (8537, '2015-02-13 12:47:25.096209+00', '2023-02-04 01:18:34.595531+00', 14961, 3, NULL, 'ace', '1-8::
    1L followed by partner casts behind 2L, up round 2M (pass LSh) into
    2L place (1M into 2M place) _while_ 4M followed by partner dance
    similarly, cast behind 3M, down round 3L (pass LSh) into 3M place
    (4L into 3L place)  2s/3s step up/down on bars 7-8
9-16::
    1s+4s dance RH across 1/2 way & set; 2s+4s also 1s+3s dance LH
    across 1/2 way & set
17-20::
    2s+3s dance RH across 1/2 way and all 4 couples set   4 3 2 1
21-24::
    All 4 couples Set+Link with middle dancers linking 2 places; end
    dancers linking 1 place as follows:
::
    _33-34_ All set
::
    _35-36_ 4M dances down to 2nd place, 3M to 4th place, 2M casts up to
    1st place, 1M to 3rd place _while_ 4L casts to 2nd place, 3L to 4th
    place, 2L dances up to 1st place, 1L to 3rd place to end 2 4 1 3
25-32::
    Reels of 4 on sides, 2L and 3M finish facing out', 0);
INSERT INTO 'dancecrib' VALUES (6808, '2013-08-21 08:31:31.355386+00', '2023-02-04 01:21:50.494209+00', 11978, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & cross RH, set & cross back LH
9-16::
    1L+3M chase cl''wise 1/2 way _while_ 2s dance 1/2 Diag R&L with 1st
    crnrs, 1M+3L chase cl''wise 1/2 way _while_ 2s dance 1/2 R&L on other
    diag
17-24::
    1s cross RH & cast 1 place, turn LH to face 1st corners
25-32::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners', 0);
INSERT INTO 'dancecrib' VALUES (6809, '2013-08-21 08:31:31.37307+00', '2023-02-04 01:21:50.622551+00', 5198, 3, NULL, 'ace', '1-8::
    1s cast 1 place & dance 1/2 Fig of 8 round 2s & turn 3/4 LH to face
    1st corners
9-16::
    1s turn 1st corner RH, pass partner RSh & turn 2nd corner LH pass
    partner LSh to face 1st corners
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners & 1/2 diagonal reel
    with 2nd corners to end in centre BtoB facing 3rd corners (1st
    corner persons)
25-32::
    1s set to 3rd corners & dance round one another clockwise to 4th
    corners, set & dance clockwise to face out on opposite sides
33-40::
    1s dance out & cast round 1st corner into centre _while_ 2s & 3s
    dance 1/2 R&L, 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6810, '2013-08-21 08:31:31.381059+00', '2023-02-04 01:21:50.640143+00', 5199, 3, NULL, 'ace', '1-8::
    1s & 3s petronella to opposite sides
9-16::
    2s & 4s petronella to opposite sides
17-24::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L
25-32::
    1s+4s dance 1/2 R&L & all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (14432, '2021-11-06 01:12:42.292396+00', '2023-02-04 01:21:50.774804+00', 17321, 3, NULL, 'ace', '1-8::
    1s+2s dance Bourrel:
::
    1M+2L set advancing & 3/4 turn 2H pivoting right to end BtoB to 2L
    facing up & 1M down _while_ 1L+2M chase anticlockwise & face partner
::
    1s+2s set to partners & turn 3/4 RH, finishing 1s in 2nd place
    facing out, 2s in 1st place facing in/down
9-16::
    2s+1s+3s dance 1/2 reels of 3 on sides, 1s RSh to 3rd corner to
    start (1M up, 1L down); 1s turn 4th corner (pstn) LH to 2nd place
    own side facing out
17-24::
    3s+1s+2s dance 1/2 reels of 3 on sides, 1s RSh to 3rd corner (pstn)
    (1M up, 1L down); 1s turn 4th corner LH to end in 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14913, '2022-06-27 00:21:25.118214+00', '2023-02-04 01:21:50.811442+00', 20885, 3, NULL, 'ace', '1-8::
    1L casts behind Ladies as 1M dances down the middle, 1L dances RSh
    round 3L into 2nd place own side _while_ 1M casts up to 2nd place,
    1s set (2s step up 3-4)
9-16::
    1s lead down (2), set retaining RH, turn RH (moving up) to face 1st
    corners
17-24::
    1s dance corners Pass+Turn with 1st corners, pass RSh; Repeat with
    2nd corners & 1s pass RSh into 2nd place own sides
25-32::
    All circle 6H round & back.', 0);
INSERT INTO 'dancecrib' VALUES (9397, '2016-10-06 07:18:48.12128+00', '2023-02-04 01:21:50.88553+00', 17146, 3, NULL, 'ace', '{{explanation}}
Note:  transcribed by Jimmie Hill into modern terminology from "24 Country Dances for the year 1770" by Longman & Co

1-8::
    1M+2M NHJ dance between partners, separate & cast round partners to
    face them.  1M+2M set to partners, cast away from each other & dance
    back to places
9-16::
    1L+2L repeat bars 1-8
17-24::
    1s cross RH, cast into middle to face 3L with NHJ (2s step up 19-20)
    1s set to 3L then set to 3M
25-32::
    1s dance down below 3s, cast up, cross up between 2s & cast to 2nd
    place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6811, '2013-08-21 08:31:31.389244+00', '2023-02-04 01:21:50.916977+00', 5200, 3, NULL, 'ace', '1-8::
    1s set to 2L & circle 3H round to left, 1s+2s circle 4H round to
    left
9-16::
    1s+2s+3s circle 6H round to left, 1s+2s+3s+4s circle 8H round to
    left 1/2 way
17-24::
    1s (in 4th place) set twice, 1/2 turn RH & lead up to top
25-32::
    1s turn 1.1/2 times _while_ 4s+3s+2s chase clockwise to places, 1s
    turn to end in 4th place', 0);
INSERT INTO 'dancecrib' VALUES (6812, '2013-08-21 08:31:31.397412+00', '2023-02-04 01:21:50.947848+00', 10164, 3, NULL, 'ace', '1-8::
    1s cross down RH to face 2s (BtoB), set cast up (slightly) to join
    nearer hands, dance down to face 3s (BtoB) & set
9-16::
    1s cast up (slightly) to join nearer hands, dance down between 3s,
    cast up to 2nd place own side & turn 2H
17-24::
    All set, circle 6H round to left for 2 bars & Men turn Lady on Right
    & continue circle
25-32::
    1s cross RH to own side, cast to 3rd place & all turn partners 2H', 0);
INSERT INTO 'dancecrib' VALUES (6813, '2013-08-21 08:31:31.406573+00', '2023-02-04 01:21:50.972399+00', 9187, 3, NULL, 'ace', '1-8::
    All dance Grand Chain
9-16::
    1s dance down middle 2 steps & set, 1s 1/2 turn 2H & dance up to end
    BtoB facing opp sides between 2s
17-24::
    1s dance the Spurtle:
::
    1s dance 1/2 reel of 4 with 2s & turn partner RH to face 3s, 1s
    dance 1/2 reel of 4 with 3s & turn partner RH to 3rd place opposite
    sides
25-32::
    2s+3s+1s set on sides & petronella turn into middle, all set to
    partner & petronella turn to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6814, '2013-08-21 08:31:31.416419+00', '2023-02-04 01:21:50.991617+00', 5204, 3, NULL, 'ace', '1-8::
    1s set & cross down RH, cast down behind 3s & dance up to face 1st
    corners
9-16::
    1s set to 1st corners & turn them RH to end facing 4th crnrs, 1s
    dance 1/2 LSh reels of 3 across (1L+2s & 1M+3s) & pass RSh to face
    3rd crnr (pstn)
17-24::
    1s set to 3rd corner & turn them RH to end facing 2nd corner (pstn),
    dance 1/2 LSh reel of 3 across (1L+3s, 1M+2s) & end 1M between 2s
    facing down & 1L between 3s facing up
25-32::
    1s turn LH 1.1/2 times in middle, 1s dance RH across (1L with 2s &
    1M with 3s). End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8538, '2015-02-13 12:47:25.105701+00', '2023-02-04 01:18:34.635364+00', 15606, 3, NULL, 'ace', '1-8::
    1s+2s set & dance 1/2 RH across _while_ 3s set & cross RH, 1s+3s set
    & dance 1/2 RH across _while_ 2s set & cross RH.  2 3 1
9-16::
    1s cross RH & cast up 1 place, 1s cross LH & cast round 4th corners
    to end BtoB facing own sides
17-24::
    1s dance Double Triangles & as 1s dance round each other corners
    dance on 1 place clockwise.  (3)1(2)
25-32::
    1s dance Diag R&L.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6815, '2013-08-21 08:31:31.426299+00', '2023-02-04 01:21:51.027399+00', 13589, 3, NULL, 'ace', '1-8::
    1L+2M pass LSh & dance round partners by the RSh to end BtoB facing
    partners, 1s+2s dance 1/2 Diamond Poussette.  2 1 3
9-16::
    1s dance reels of 3 across giving LSh to 1st corners & end 1L
    dancing up between 2s to face down as 1M dances down between 3s to
    face up as 2s dance in to face up to 1L as 3s dance in to face down
    to 1M
17-24::
    1L+2s also 1M+3s set & circle 3H round to left 1/2 way, 1s set &
    petronella turn to 2nd place own sides _while_ 2s & 3s Set+Link to
    own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6816, '2013-08-21 08:31:31.434448+00', '2023-02-04 01:21:51.048086+00', 14947, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH & cast into middle, 1s turn RH & cast to 1st place
    as 4s+3s dance RH across  (1)2(4)3
9-16::
    All dance Snowball Grand Chain: 1s cross RH & 1s+2s change places LH
    on sides, 2s cross RH as 1s+4s change places RH on sides 2s+4s also
    1s+3s change places LH on sides to end (4)(2)3 1
17-24::
    All dance 8 hands round & back
25-32::
    All Ladies dance 1/2 Diag R&L, All 4 Men dance 1/2 Diag R&L. (1) (3)
    2 4
33-40::
    All dance Snowball Grand Chain: 1s cross RH, 1s+3s change places LH
    on sides, 3s cross RH as 1s+2s change places RH on sides, 3s+2s also
    1s+4s change places LH on sides to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6817, '2013-08-21 08:31:31.44273+00', '2023-02-04 01:21:51.067162+00', 14946, 3, NULL, 'ace', '1-8::
    All dance 8 hands round & back.
9-16::
    1s in prom hold dance reel of 3 with 2s giving RSh to 2M, _while_ 3s
    dance reel of 3 with 4s giving RSh to 4M
17-24::
    1s & 3s dance RH across & LH across back
25-40::
    2s & 4s repeat bars 9-16 (2s reel with 3s, 4s reel with 1s)
41-48::
    1s & 3s dance into centre & change partners, cross out between side
    couples to meet partners & 1/2 turn RH & all change places with
    corners (Men LH, Ladies RH)
49-56::
    New top & bottom ''couples'' repeat bars 41-48
57-64::
    1s making arch change places with 3s & face in. 2s making arch
    change places with 4s & face in
65-80::
    Face partners & dance Grand Chain. Turn partners RH into allemande
    hold & dance clockwise round set', 0);
INSERT INTO 'dancecrib' VALUES (6818, '2013-08-21 08:31:31.452527+00', '2023-02-04 01:21:51.084914+00', 8176, 3, NULL, 'ace', '1-8::
    1s also 3s advance setting to form a line up/down centre (Men with
    Ladies on their Right) & set, petronella back to place & set
9-16::
    1s cross RH, cast 1 place & dance RH across with 3s
17-24::
    1s cross LH & cast up to top & dance LH across with 2s
25-32::
    _1_ dance between 2s & down behind 3s, lead up to top & cast to 2nd
    place', 0);
INSERT INTO 'dancecrib' VALUES (6819, '2013-08-21 08:31:31.462231+00', '2023-02-04 01:21:51.173194+00', 5207, 3, NULL, 'ace', '1-8::
    1s cast 2 places _while_ 3s set & dance (NHJ) up to top. 3s cast 2
    places _while_ 1s set & dance (NHJ) up to top.
9-16::
    1s cross & dance out between 2s & 3s, cast behind 3s on opposite
    sides, lead up to 1st corners, set to 1st corner & set to 2nd corner
17-24::
    1s dance down below 3s cross & cast up behind 3s to 2nd places own
    sides, 2s+1s dance a 1/2 Diamond Poussette
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (6820, '2013-08-21 08:31:31.470354+00', '2023-02-04 01:21:51.197077+00', 9074, 3, NULL, 'ace', '1-8::
    1s giving RH cross down to 2nd places _while_ 2s cast up & 3s set,
    1s dance reflection reels of 3 on opposite sides & end in 2nd place
    opposite sides
9-16::
    1s cast to 3rd place _while_ 3s giving LH cross up to 2nd place & 2s
    set, 3s dance reflection reels of 3 on opposite sides & end in 2nd
    place opp sides
17-24::
    3s+1s dance 1/2 R&L, 2s+1s dance 1/2 R&L
25-26::
    1M+2M adv & 1M passes 2M in front to change pl & dance to own side
    as 1L+2L cross to their own sides (outside Men) & turn to face each
    other
27-32::
    Repeat with Ladies crossing & changing place, 2s giving RH & 1s
    giving LH turn 1.1/2 times to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6822, '2013-08-21 08:31:31.488257+00', '2023-02-04 01:21:51.321174+00', 5209, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place (2s step up 3-4), 1s dance RH across with
    3s.  1s end with Man facing his 1st corner with his partner behind
    him
9-16::
    1s dance Alternating Tandem 1/2 reel of 3 with 1st corners to face
    Man''s 2nd corner, 1s dance Alternating Tandem 1/2 reel of 3 with 2nd
    corners
17-24::
    1s dance Alternating Tandem 1/2 reels of 3 with Ladies'' 1st corner
    (pstn),1s dance Alternating Tandem 1/2 reel with Ladies'' 2nd corner
    (pstn)
25-32::
    1M followed by partner dance into LH across with 2s, 1s retain LH &
    1/2 turn to own sides & 2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (14914, '2022-06-27 00:21:25.674045+00', '2023-02-04 01:21:51.33943+00', 16573, 3, NULL, 'ace', '1-8::
    1s+2s+3s chase clockwise round back to place, 2s to sides _while_
    1s+3s curve into line in centre, Men facing down, Ladies facing up
9-16::
    1s+3s dance RSh reel of 4 up/down centre
17-20::
    All 3 couples set, 1s & 3s Petronella turn to own sides _while_ 2s
    set advancing, pull back RSh to BtoB facing own side
21-24::
    All set as Double Triangles, 1M+2M 1/2 turn RH _while_ 1L+2L 1/2
    turn LH to bring 1s BtoB in centre facing own side
25-28::
    All set as Double Triangles, 1M+3M turn LH once round _while_ 1L+3L
    turn RH once round, 3s end on sides in place.  2 1 3
29-32::
    1s dance up to top & cast to 2nd place.  2 1 3

{{explanation}}
Note:	2nd time through Bars 31-32: 1s cast to 4th pace, bottom couple step up', 0);
INSERT INTO 'dancecrib' VALUES (6823, '2013-08-21 08:31:31.501851+00', '2023-02-04 01:21:51.440724+00', 5213, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & turn RH to face 1st corners
9-16::
    1s giving LSh to corners dance 1/2 reels of 3 on opposite sides,
    pass LSh to face 3rd corner (pstn) & dance 1/2 LSh reels of 3 on own
    side 1s end passing LSh to face 2nd corner (pstns)
17-24::
    1s giving RSh to corners & dance 1/2 reel of 3 across, pass RSh to
    face 4th corner (pstn) & dance 1/2 reel of 3 across
25-32::
    1s cross RH, cast to right & turn RH to 2nd place own sides
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12648, '2020-03-02 01:53:42.861957+00', '2023-02-04 01:21:51.467048+00', 5215, 3, NULL, 'ace', '1-8::
    1s set, 1/2 turn RH to face down;  1s lead down & cast up round 3s
    to 2nd place opp side
9-16::
    _1/2_ Diag R&L (1M up, 1L down); 1/2 Diag R&L (1M up, 1L down).  (3)
    (1) (2)
17-24::
    All set, all turn partner 3/4 RH into line up/down centre & retain
    RH; All set, turn partner 3/4 RH remaining in centre facing up for …
25-32::
    3s+1s+2s dance Allemande.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6824, '2013-08-21 08:31:31.509945+00', '2023-02-04 01:21:51.510188+00', 5217, 3, NULL, 'ace', '1-8::
    1s petronella turn into centre & set _while_ 2s step up & set, 1s+2s
    RH across & end in line across (1s BtoB in the middle facing opp
    partner)
9-16::
    1s+2s reel of 4 across ending on own sides with 1s in 2nd place
17-24::
    1s followed by 2s dance 4 slip steps down middle & set, 1s & 2s
    dance down 1 more step & 2s leading cast up own side
25-32::
    2s+1s R&L', 0);
INSERT INTO 'dancecrib' VALUES (8702, '2015-03-03 08:47:56.179495+00', '2023-02-04 01:21:51.521187+00', 15282, 3, NULL, 'ace', '1-8::
    1s+2s Mirror Set+Link (1s cast, 2s dance up), 1s turn LH to face
    Men''s side NHL with 1L on Right of 1M
9-16::
    1s dance reels of 3 across (1M Lsh to 3M, 1L RSh to 2M to start)
    _while_ 2s+3s dance DoSiDo with Ladies dancing between Men then Men
    dancing between Ladies.  Finish 1L beween 2s, 1M between 3s
17-24::
    1s dance DoSiDo & turn RH 1.1/4 to finish on sides   2 1 3
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (14738, '2022-04-01 00:21:11.608702+00', '2023-02-04 01:21:51.558119+00', 14500, 3, NULL, 'ace', '{{explanation}}
5 couples arranged in pentangle, 1s at top & positions number anticlockwise from top

1-8::
    1s dance down NHJ below 4s/3s, separate & cast round outside to
    place
9-16::
    1s dance DoSiDo with partner; all 5 couples set, 1s cross down LH to
    face out (between 4s/3s) _while_ 2s+3s+4s+5s turn partner RH into
    prom hold all facing in
17-24::
    Reels of 3 on "sides", 1M+2s+3s (1M+3s pass LSh to start) & 1L+4s+5s
    (1L+4s pass RSh to start). Bar 20: 1s pass LSh to swap to other
    reel. All end in original places facing in
25-32::
    All Set+Link twice with partner, Ladies face out
33-40::
    All dance modified 1/2 Schiehallion reels - 2 "loops" to end 1 place
    clockwise round from start
::
    (Each dancer crossing the set must let 2 dancers pass in front from
    their right).
41-48::
    All circle 10H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9398, '2016-10-06 07:18:48.257519+00', '2023-02-04 01:21:51.582668+00', 17234, 3, NULL, 'ace', '1-8::
    1s+2s turn 1.1/2 RH to face down in middle in allemande hold.  1s+2s
    dance down, cross below 3s, cast up on own sides  2 1 3
9-12::
    2s+3s turn RH (2 bars) and set (NHJ with partner) facing down/up
    _while_ 1s cross RH, dance thro'' 1st corner pstn. casting to 2nd
    place own side (1L facing down, 1M facing up)
13-16::
    2s+1s+3s chase clockwise 1/2 way to opp. sides.  Bars 15-16 1s turn
    RH to face 1st corner positions
17-24::
    1s dance 1/2 diag. reel of 4 with 1st corners (pstn), 1s pass RSh,
    dance 1/2 diag. reel of 4 with 2nd corners (pstn) Finish in 2nd
    place own side
25-32::
    2s+1s dance all-round (Diamond) Poussette', 0);
INSERT INTO 'dancecrib' VALUES (11208, '2018-09-30 22:20:21.85601+00', '2023-02-04 01:21:51.62927+00', 9932, 3, NULL, 'ace', '{{explanation}}
Square set, Ladies BtoB in centre facing partners

1-8::
    All set & change places RH with partner; repeat back to places
9-16::
    Men chase clockwise 1/2 round _while_ Ladies set twice; all turn opp
    person 1.1/2 RH (Men now in centre facing in)
17-20::
    Men, join hands & set twice pulling back RSh on bar 20 to face out
    (facing new partner)
21-32::
    Interlocking reels of 4 (couples dance 1/2 LH across in centre).
    End with Men BtoB in centre (facing new partner again)
::
    Repeat from new positions with new partners (Bars 9-12 Men set /
    Ladies chase 1/2 round).  End opp original place. Repeat twice more
    back to original place', 0);
INSERT INTO 'dancecrib' VALUES (6827, '2013-08-21 08:31:31.534171+00', '2023-02-04 01:21:51.653579+00', 7485, 3, NULL, 'ace', '1-8::
    1s lead down, cross below 2s & cast behind 3s+4s to bottom, lead up
    cross above 3s & cast up behind 2s to original places
9-16::
    All dance double pass-thru Promenade: 1s+2s dance up, round & down
    Men''s sides as 4s+3s dance down, round & up Ladies side Men pass Men
    RSh also Ladies pass Ladies RSh back to places
17-24::
    All dance reels on 4 on sides
25-32::
    1s+2s dance 1/2 R&L (2 bars only), 1s+3s dance 1/2 R&L (2 bars),
    1s+4s dance 1/2 R&L (2 bars) & all cross RH to own sides
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6828, '2013-08-21 08:31:31.54804+00', '2023-02-04 01:21:51.791056+00', 5219, 3, NULL, 'ace', '1-8::
    1M+2M also 1L+2L turn RH 1.1/2 times on sides to change places,
    1M+3M also 1L+3L turn LH 1.1/2 times
9-16::
    1M+4M also 1L+4L turn RH 1.1/2 times, 1s turn each other LH 1.1/2
    times to end 4th place opposite sides
17-24::
    1s dance up opposite sides to top (behind 4s, in front of 3s &
    behind 2s), 1s turn RH to end between 2s to Bal-in-Line across
25-32::
    1s+2s Bal-in-Line, 1M turn 2L also 1L turns 2M to end with 1s
    between 3s to Bal-in-Line across, 1s+3s repeat this Fig to end
    between 4s
33-40::
    1s+4s repeat Fig, 1s turn each other RH 1.1/2 times & end by making
    an arch
41-48::
    2s followed by 3s & 4s dance down the middle, under the arch & cast
    up on own sides', 0);
INSERT INTO 'dancecrib' VALUES (6829, '2013-08-21 08:31:31.558136+00', '2023-02-04 01:21:51.957624+00', 7304, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across, 2s & 3s cross LH _while_ 1s+4s
    chase clockwise 1/2 way
9-16::
    4s+2s dance "Mirror Ladies'' Chain" (Men cross RH, Ladies turn Men LH
    on side) _while_ 3s+1s dance (normal) Men''s Chain ending with 4L+2M
    & 3L+1M turning RH 1.1/2 times
17-24::
    All dance RSh reels of 4 on the sides & end with 4s & 1s facing out
25-28::
    All Bal-in-Line, all 3/4 turn RH person on right into lines of 4
    across with 4s & 1s in middle facing up/down
29-32::
    All Bal-in-Line & all 3/4 turn RH person on right onto sides
33-36::
    2s+4s chase clockwise 3/4 round square to end on opposite sides with
    1s+3s dancing likewise
37-40::
    2s+4s also 1s+3s cross (Ladies pass between Men) & Ladies change
    places RH to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6830, '2013-08-21 08:31:31.566132+00', '2023-02-04 01:21:51.979613+00', 14634, 3, NULL, 'ace', '1-8::
    1s & 4s set & cast in, 1s & 4s dance 1/2 Fig of 8 round end couple.
    2(1)(4)3
9-16::
    2s+1s also 4s+3s circle 4H round & back.
17-24::
    1s & 4s 1/2 turn RH in middle to face other couple & set, 1s dance
    down under arch made by 4s to change places & all set.  2 4 1 3
25-32::
    All Adv+Ret & all turn RH.', 0);
INSERT INTO 'dancecrib' VALUES (14676, '2022-03-07 02:21:12.865924+00', '2023-02-04 01:21:52.011226+00', 20658, 3, NULL, 'ace', '{{explanation}}
1 chord: Honour partner then Men face in, Ladies face out

1-8::
    All dance 1/2 Schiehallion reel (2 places round), Ladies face out
9-16::
    3s+1s dance 1/2 Men''s Chain; 4s+2s dance 1/2 men''s Chain.  Men end
    in start places, Ladies opposite to starting places, all facing in
17-24::
    Ladies Petronella turn one place to right & set to new partner; All
    turn partner RH (or birl)
25-32::
    All circle 8H round to left (6 slip steps), pivot & chase
    anticlockwise back to place to end 1M+4L, 2M+1L, 3M+2L, 4M+3L

{{explanation}}
Repeat 3 more times to finish with original partner', 0);
INSERT INTO 'dancecrib' VALUES (9747, '2017-04-06 08:40:07.94203+00', '2023-02-04 01:21:52.044162+00', 16785, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s cross RH, cast, turn 1.1/2 RH to 2nd place own sides
17-24::
    1s dance Fig 8 round 3s
25-32::
    2s+1s circle 4H round to Left.  1s+3s circle 4H round to Right', 0);
INSERT INTO 'dancecrib' VALUES (13328, '2020-11-02 01:21:26.093092+00', '2023-02-04 01:21:56.114446+00', 14445, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s turn 1.3/4 LH
9-16::
    LSh reels of 3 across, 1L LSh to 2M, 1M LSh to 3L.  1s end in 2nd
    place own side
17-24::
    1s turn 1.1/2 RH; 2s+1+3s circle 6H round to left
25-32::
    1s dance Diagl R&L (1M down, 1L up).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4014, '2013-08-21 08:30:41.638842+00', '2023-02-04 01:18:27.561414+00', 14232, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection (mirror) reels of 3 on opposite
    sides & 1s+2s continue the reel to end 2(1)3
9-16::
    2s+1s+3s dance reels of 3 to end 2(1)3:
::
    1s dance out/down & cross up to 2nd pl _while_ 3s cross up to 2nd pl
    & dance out/up to 1st pl _while_ 2s cross down to 2nd pl & dance
    out/dn to 3rd pl
::
    1s dance out/up & cross down to 2nd pl _while_ 3s cross down to 2nd
    pl & dance out/down to 3rd pl _while_ 2s cross up to 2nd pl & dance
    out/up to 1st pl
17-20::
    1s, joining LH with 1st corners, set diagonally & 1s cast round
    corners into middle _while_ 1st corners pass RSh to face 1s (M
    facing M)
21-24::
    1s+1st corner persons dance 1/2 RSh reel of 4 ending with corners in
    original places & 1s joining LH with 2nd corners
25-28::
    1s+2nd corners set diagonally & 1s cast round corners to 2nd place
    _while_ 2nd corners pass RSh to face 1s (M facing M)
29-32::
    1s+2nd corner persons dance 1/2 RSh reel of 4 ending with corners in
    original places & 1s in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4015, '2013-08-21 08:30:41.974025+00', '2023-02-04 01:18:27.599616+00', 155, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret (1 step) & cross RH, repeat back to places
9-16::
    1s cast 1 place into middle (1M facing up, 1L down) & set, 1s 3/4
    turn 2H & face out opposite sides & cast round 2nd corner into
    middle
17-24::
    1s dance reels of 3 across (1M RSh to 2M, 1L RSh to 3L) & pass LSh
    to face 1st corners
25-32::
    1s turn 1st corners 2H & pass RSh to face 2nd corners, turn 2nd
    corners 2H & cross to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6831, '2013-08-21 08:31:31.576252+00', '2023-02-04 01:21:52.150056+00', 5222, 3, NULL, 'ace', '{{title}}
Reel

1-8::
    1s+2s dance RH across & LH back to places
9-16::
    1s lead down the middle & back to face 2nd corners
17-24::
    1s set & turn 2nd corners, set & turn 1st corners to end in lines
    across (1L between 2s & 1M between 3s)
25-32::
    2s+1s+3s set twice, 1s turn 2H twice ending between 2s & 3s

{{title}}
Strathspey

1-8::
    1s change places RH up & down centre, change back LH
9-16::
    2s+1s+3s Adv+Ret twice (up & down set) 1s turning onto sides,
    2s+1s+3s Adv+Ret twice (across dance), 1s end facing 2nd corners
17-24::
    1s set & turn 2nd corners, set & turn 1st corners to end in lines
    across (1L between 2s & 1M between 3s)
25-32::
    2s+1s+3s set twice & 1s turn 2H 1.1/4 times to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6832, '2013-08-21 08:31:31.584301+00', '2023-02-04 01:21:52.180602+00', 14636, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance R&L
9-16::
    1s turn RH & cast 1 place, 1s weave down to 4th place as others step
    up as they are passed
17-24::
    4s+1s dance RH across.  2s+3s+4s+1s Adv+Ret
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14677, '2022-03-07 02:21:13.053956+00', '2023-02-04 01:21:52.213515+00', 20646, 3, NULL, 'ace', '{{explanation}}
2 chords: 2nd chord 3s & 4s cross to opp side

1-8::
    1s & 4s cross RH, cast in 1 place (2s & 3s step up/down); 1s & 4s
    turn partner RH into prom hold, 1s facing up, 4s facing down (Lady
    on Man''s left)
9-16::
    1s+2s also 4s+3s dance LSh reels of 3 across (1s pass 2M LSh, 4s
    pass 3M LSh to start)
17-20::
    1s dance up NHJ & cast to 2nd place _while_ 4s dance down NHJ & cast
    up to 3rd place to end 2 (1) 4 (3)
21-24::
    1s & 4s Set+Link
25-32::
    All circle 8H round & back.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (14678, '2022-03-07 02:21:13.080168+00', '2023-02-04 01:21:52.238228+00', 20647, 3, NULL, 'ace', '1-8::
    All dance RSh reels of 4 on sides
9-16::
    1s+2s also 3s+4s dance Double Fig 8 (1s & 4s cross down/up, 2s & 3s
    dance up/down sides to start)
17-24::
    1s set, cast (2s step up 19-20); 1s dance in front of 3s (3s step up
    21-22), behind 4s (4s step up 23-34).  2 3 4 1
25-32::
    All couples set, all dance DoSiDo with partner, all set.  End 2 3 4
    1', 0);
INSERT INTO 'dancecrib' VALUES (12820, '2020-05-14 23:15:48.040591+00', '2023-02-04 01:21:52.265237+00', 19969, 3, NULL, 'ace', '1-8::
    1s+2s set to each other on sides, change place 2H (skip change); 1s
    set, 3/4 turn 2H (skip change)
9-16::
    Reels of 3 across, 1L+2s (1L RSh to 2L) & 1M+3s (1M RSh to 3M). 1s
    end 2nd place opp sides. 2 (1) 3
17-24::
    1s set, 3/4 turn 2H (skip change); 1s cast (1L down round 3M, 1M up
    round 2L) & cross RH to 2nd place own side.  2 1 3
25-32::
    2s+1s+3s circle 6H round & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14679, '2022-03-07 02:21:13.225035+00', '2023-02-04 01:21:52.322214+00', 16608, 3, NULL, 'ace', '1-8::
    1s lead down for 3 steps, lead up to top & cast to 2nd place (2s
    step up 7-8)
9-16::
    2s+1s+3s dance reels of 3 on sides (2s cast down, 1s in/down, 3s
    out/up to start)
17-24::
    1s turn 3s (Ladies LH, Men RH), 1s turn 2s (Ladies RH, Men LH)
25-32::
    2s+1s+3s Adv+Ret & turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (6834, '2013-08-21 08:31:31.60601+00', '2023-02-04 01:21:52.347516+00', 5224, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    All set, all full turn 2H to 1s facing down to 2s & 3s facing 4s.
    All set & all 3/4 turn facing person 2H to end in lines across,
    Ladies BtoBin centre
9-16::
    1s+2s also 3s+4s dance 3/4 reels of 4 across & all 3/4 turn partner
    RH to end with 1s & 3s on Men''s side & 2s & 4s on Ladies'' side (Lady
    on Man''s left)
17-24::
    1s+2s also 3s+4s dance RH across; 1s+2s also 3s+4s dance 1/2 Ladies''
    Chain
25-32::
    1s+2s also 3s+4s dance 1/2 R&L;  1s+4s dance 1/2 R&L. End 2 (4) 1
    (3)', 0);
INSERT INTO 'dancecrib' VALUES (6835, '2013-08-21 08:31:31.614091+00', '2023-02-04 01:21:52.371904+00', 8338, 3, NULL, 'ace', '1-8::
    1s dance down for 4, 1M dances round partner as she dances under his
    arm & dance up to 2nd place opposite side
9-16::
    1s dance reflection reels of 3 on sides (1s dancing out & up to
    start). 1s cross to own side from 1st place (bar 3) and back to opp
    side from 3rd place (bar 6)
17-24::
    1L+2M turn RH _while_ partners turn LH, 1L+3M turn LH _while_
    partners turn RH
25-32::
    1s dance up to top, cross & cast to 2nd place & 2s+1s+3s Adv+Ret', 0);
INSERT INTO 'dancecrib' VALUES (12737, '2020-04-11 10:52:37.345411+00', '2023-02-04 01:21:52.401876+00', 9540, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on opp side with 2s+3s (1s cross down, 2s
    out/up, 3s in/up). 1s finish in 1st place opp side
9-16::
    1s turn RH and cast one place (2s step up); 1s dance 1/2 Fig 8, 1M
    up round 2s, 1L down round 3s.  2 1 3
17-20::
    1L+2s also 1M+3s, dance RH across
21-24::
    1s+2s+3s chase clockwise 1/2 round to opp side.  (3) (1) (2)
25-32::
    1s+2s+3s Set+Link twice.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6836, '2013-08-21 08:31:31.624729+00', '2023-02-04 01:21:52.441643+00', 10572, 3, NULL, 'ace', '1-8::
    1s cast 1 place _while_ 2s dance up then 2s cast _while_ 1s dance
    up, 1s turn 2H (4 bars)
9-12::
    1s+2s circle 4H round to left 1/2 way, 2s+1s+3s circle 6H round to
    left 1/2 way _while_ 4s cross 2H
13-16::
    3s+1s+2s+4s circle 8H round to left 1/2 way
17-24::
    4s+2s dance RH across _while_ 1s+3s dance LH across once round then
    all change wheels starting with 2M+1M to end 3(1)(2)4
25-32::
    All dance 1/2 Grand Chain, 4s & 3s cross RH _while_ 2s+1s change
    places on sides RH & all set.  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (3983, '2013-08-21 08:30:40.82802+00', '2023-02-04 01:21:52.572742+00', 10484, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, set 1L casts up & 1M down
9-16::
    1s dance reels of 3 across (1L with 2s & 1M with 3s) & 1s end facing
    1st corners
17-24::
    1s set to 1st corners, turn partner RH, set to 2nd corner & turn
    partner RH to face 1st corners
25-32::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    Pass+Turn with 2nd corners & end passing RSh to 2nd places', 3);
INSERT INTO 'dancecrib' VALUES (12468, '2020-01-02 07:01:01.729102+00', '2023-02-04 01:21:52.604235+00', 19797, 3, NULL, 'ace', '1-4::
    "Flirt & Cast":
::
    _1-2_   1L+2M & 4L+5M dance diagonally towards each other (1 step),
    pull back RSh, dance out again to place (1 step) & face out
::
    _3-4_   1L+2M & 4L+5M cast one place to their right, _while_
    partners dance towards the middle & curve right (down/up) into their
    own sidelines 2 1 3 5 4
5-8::
    2s+1s & 5s+4s circle 4H round to the left
9-16::
    Middle 3 couples (1s+3s+5s) dance LH across (4 bars) flowing into a
    chase up/down centre (Ladies up, Men down) casting to the right out
    of ends to finish on the sides 2 5 3 1 4
17-24::
    Bottom 3 couples (3s+1s+4s) Set & Rotate for 3 into lines across
    (Men facing down, Ladies facing up), cross RH with person opposite
    (partner) & chase clockwise to own side 2 5 4 1 3
25-32::
    5s+1s dance 1/2 Fig of 8 (5s up round 2s, 1s down round 3s), cross
    over LH, & all 5 couples set on sides. 2 5 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6837, '2013-08-21 08:31:31.632837+00', '2023-02-04 01:21:52.623629+00', 5232, 3, NULL, 'ace', '1-8::
    1s cross down into dance reels of 3 on opposite sides & end facing
    1st corners
9-12::
    1s set to 1st corners, dance round each other into 3rd corner places
    _while_ 1st corners dance in & twirl to face their original places
13-16::
    1st corner persons set to 1s, dance round each other into 3rd corner
    places _while_ 1s dance into centre & twirl to face 2nd corners
17-24::
    1s repeat 9-16 with 2nd corners & end facing 1st corners (pstn)
25-32::
    1s+1st corners dance 1/2 diagonal reel of 4, pass RSh & dance 1/2
    reel with 2nd corners & end passing RSh to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (15349, '2022-12-19 01:21:28.508927+00', '2023-02-04 01:21:52.642985+00', 21136, 3, NULL, 'ace', '1-8::
    All dance 8H round & back
9-16::
    1s+3s dance the Swirl:
::
    _9_ -10   Turn partner RH into Allemande hold
::
    _11-12_  Dance LSh round other couple 1/2 way, on bar 12 drop right
    hands
::
    _13-16_  1s+3s dance LH across. On bar 16, pull back LSh & dance on
    to face side couples (BtoB with ptnr & Lady facing Man, 1L & 3M face
    2s, 3L & 1M face 4s)
17-24::
    1L+3M+2s also 1M+3L+4s dance RH across & LH across back
25-28::
    1s+3s dance RH across
29-32::
    3M followed by 3L & 1M followed by 1L chase clockwise 1/2 way
    outside the set to original places 1 2 3 4
33-64::
    Repeat bars 1-32 with 2s+4s dancing the Swirl. 1 2 3 4', 0);
INSERT INTO 'dancecrib' VALUES (6838, '2013-08-21 08:31:31.641489+00', '2023-02-04 01:21:52.661671+00', 7486, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All set to partner, turn RH, set to corners & turn LH
17-24::
    1s & 3s pass partner RH, dance behind next corner to meet opp
    partner & turn RH into prom hold & dance in between side couple &
    pass other couple LSh
25-32::
    1M+3L & 3M+1L dance 1/2 reel of 4 with 2M+4M & 1/2 reel of 4 with
    2L+4L. 1s & 3s end facing own partners in centre
33-40::
    1s+3s pass partner RSh & dance out between side couples, cast behind
    corner to meet partner opposite original places & turn partners LH
41-48::
    1s+3s dance 1/2 Ladies'' Chain, 2s+4s dance 1/2 Ladies'' Chain
49-56::
    Ladies dance reel of 4 up/down set (2L+1L & 3L+4L pass RSh to start)
57-64::
    1s+3s dance 1/2 Men''s Chain, 2s+4s dance 1/2 Men''s Chain (All now in
    original places)
65-72::
    2s & 4s pass partner RH, dance behind partner''s corner & turn opp
    partner RH into prom hold & dance in between end couples & pass LSh
73-80::
    2M+4L & 4M+2L dance 1/2 reel of 4 with 1M+3M & 1/2 reel of 4 with
    1L+3L, 2s & 4s end facing own partner in centre
81-88::
    2s & 4s pass partner RSh & dance out between end couples, cast
    behind corner to meet partner opposite original places & turn
    partner RH
89-96::
    2s+4s dance 1/2 Men''s Chain, 1s+3s dance 1/2 Men''s Chain
97-104::
    Men dance reel of 4 across set (1M+4M & 3M+2M pass RSh to start)
105-112::
    2s+4s dance 1/2 Ladies'' Chain, 1s+3s dance 1/2 Ladies'' Chain (All
    now in original places)
113-120::
    All set to corner & turn LH, set to partner & turn RH
121-128::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6839, '2013-08-21 08:31:31.649934+00', '2023-02-04 01:21:52.712006+00', 5236, 3, NULL, 'ace', '1‑8::
    All Adv+Ret, cross passing partner RSh with Men making arches & end
    facing clockwise
9‑16::
    All chase 1/2 way to own sides & dance 1/2 reels of 4 on sides
17‑32::
    Repeat bars 1‑16 but passing LSh & chasing anticlockwise & dancing
    1/2 reel of 4 on own sides note: 3s+2s do not end passing LSh but
    join LH in centre with 1s & 4s on their RH forming a St Andrew''s
    cross
33‑40::
    All set, change places RH with corners, set & change places again RH
    with corners
41‑48::
    3s+2s dance LH across & RH across
49‑56::
    3s & 2s cast up/down, lead down/up to meet in centre & set to other
    couple, 3s+2s set to partners _while_ 1s+4s set advancing to
    partners for ...
57‑64::
    1s+3s also 2s+4s dance Poussette to end 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (6840, '2013-08-21 08:31:31.657948+00', '2023-02-04 01:21:52.751589+00', 5237, 3, NULL, 'ace', '1-8::
    1L+2M advance to give RH & 1L turns under Man''s R arm. 1L curves
    back to place as 2M retires to place; 1L+2M turn RH
9-16::
    1M+2L repeat
17-24::
    1s+2s dance RH across, set facing in diagonally & 1s cast _while_ 2
    dance up
25-32::
    2s+1s dance double Fig of 8 (2s cast to start). 2 1', 0);
INSERT INTO 'dancecrib' VALUES (9221, '2016-06-16 22:42:12.066106+00', '2023-02-04 01:21:52.807056+00', 16867, 3, NULL, 'ace', '1-8::
    1L followed by partner casts & chase round to original positions
    (2s+3s+4s step up & down)
9-16::
    All 1/2 turn RH & 1s+2s also 3s+4s dance 1/2 RH across, 1s+4s 1/2
    turn RH & dance 1/2 RH across.  2 4 1 3
17-24::
    All 1/2 turn RH & 2s+4s also 1s+3s dance 1/2 RH across, 2s+3s 1/2
    turn RH & dance 1/2 RH across.  4 2 3 1
25-32::
    4s+3s+2s dance allemande to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13029, '2020-08-10 00:18:23.912664+00', '2023-02-04 01:18:27.636213+00', 9224, 3, NULL, 'ace', '1-8::
    1M+2L also 3M+4L cross passing RSh, dance LSh round partner, pass
    RSh up/down & dance RSh round standing Man/Lady own side (1M/3M
    round 2M/4M, 1L/3L round 2L/3L)
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1s+2s also 3s+4s set & dance 1/2 RH across; 1s+4s Set+Link.  (2) (4)
    (1) (3)
25-32::
    All set & cross RH with partner; 2s+4s also 1s+3s circle 4H round to
    left.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13030, '2020-08-10 00:18:24.08164+00', '2023-02-04 01:18:27.848639+00', 15338, 3, NULL, 'ace', '1-8::
    1s dance in, touch hands & cast to 2nd place (2s step up); 1s set
    advancing & 1/2 turn 2H, pull back RSh to face 1st corners
9-16::
    1s+1st corners set, 1s dance RSh round partner to face 2nd corner;
    1s+2nd corners set, 1s dance RSh round partner to 2nd place own side
    facing out
17-20::
    1s dance RSh round 3rd corner, pass RSh up/down centre _while_ 3rd
    corners 1/2 turn RH, pull back RSh & dance out to diagonally opp
    place
21-24::
    1s repeat 17-20 with 4th corners ending in 2nd place opp sides  (3)
    (1) (2)
25-32::
    3s+1s+2s chase clockwise 1/2 round to own sides & turn partner 2H.
    End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4153, '2013-08-21 08:30:44.339612+00', '2023-02-04 01:18:37.197895+00', 378, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set, Petronella-in-tandem to right, set &
    Petronella-in-tandem to opposite sides
9-16::
    2s+1s also 4s+3s set, 1/2 turn partners 2H & open out to dance 4H
    round to left.  2 1 4 3
17-24::
    2s+1s also 4s+3s dance RH across 1/2 way, 2s & 3s complete RH across
    back to place _while_ 1M followed by partner dances down to 3rd
    place & crosses to own side as 4L followed by ptnr dances up to 2nd
    place & crosses to own side, 2s+4s also 1s+3s dance LH across.  2 4
    1 3
25-32::
    4s & 3s lead up LH 1place, cross & cast to 2nd/4th place, lead up
    RH, cross & cast 1 place', 0);
INSERT INTO 'dancecrib' VALUES (6842, '2013-08-21 08:31:31.702014+00', '2023-02-04 01:21:52.942321+00', 5243, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    All set, 1s+4s 1/2 turn RH into prom hold _while_ 2s & 3s cast to
    ends, 1s & 4s dance 1/2 reels of 3 across (1s RSh to 2M & 4s RSh to
    3M)
9-12::
    1s+4s dance 1/2 RH across, 1/2 turn partner RH into prom hold to
    face 2nd corner (2L/3L) _while_ 2s+3s set & cross back RH
13-16::
    4s+1s dance 1/2 reel with 2nd crnrs, 4s+1s dance round each other
    RSh 3/4 way to face 1st crnr (2M/3M)
17-24::
    4s+1s dance 1/2 reel with 1st cnrs, 4s+1s pass RSh (1s face up, 4s
    down) & dance out between end cpls & cast to 2nd/3rd places
25-32::
    3s+1s also 4s+2s dance R&L to end 3 1 (4)(2)', 0);
INSERT INTO 'dancecrib' VALUES (9748, '2017-04-06 08:40:08.060124+00', '2023-02-04 01:21:52.97781+00', 17655, 3, NULL, 'ace', '1-8::
    Reels of 3 on sides, 2M+3M also 2L+1L pass RSh to start
9-12::
    2s dance RSh round 4th corner ending BtoB in middle, Man facing
    down, Lady up.
13-16::
    2M+3s & 2L+1s circle 6H round to left, 2s end facing 1st corners
17-24::
    2s dance 1/2 diag reel of 4 with 1st corners, 1/2 diag reel of 4
    with 2nd corners & 1/2 turn LH to face 1st corner position
25-28::
    _1/2_ LSh reels of 3 across. 2s end LSh to LSh in the centre,
    joining LHs facing own sides
29-30::
    2s 3/4 turn LH to face down (1s step up) then …
31-32::
    2s cross down to 3rd place own sides, to end facing out  3 1 2', 4);
INSERT INTO 'dancecrib' VALUES (8848, '2015-08-13 20:33:59.208098+00', '2023-02-04 01:21:53.032318+00', 13125, 3, NULL, 'ace', '1-8::
    2s+3s set, 1/2 turn partner RH & 2s+3s dance RH across  1 (2) (3) 4
9-16::
    2s face 1s, 3s face 4s on sides & all set, 1/2 turn RH.  2s+1s also
    3s+4s dance RH across  (2) 1 4 (3)
17-24::
    Reels of 4 on sides
25-32::
    2s cross down between 1s as 3s cross up between 4s to dance 1/2 Figs
    of 8. All turn on sides (2M+1M, 4L+3L RH, 2L+1L, 4M+3M LH)  2 1 4 3
33-40::
    All 1/2 turn prtnr RH, face, pull back RSh & dance out to prtnr''s
    place. 2s & 3s repeat back to own sides as 4s & 1s (middle couples)
    chase clockwise 1/2 way round inside set to places.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13189, '2020-09-15 00:21:11.486234+00', '2023-02-04 01:21:53.057868+00', 7890, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across for 3 bars, LH across for 3 bars. 1s cast into
    2nd place _while_ 2s dance up & cast into 1st place. At the same
    time 3s+4s do the same beginning with LH across & 4s cast into 3rd
    place, 3s dance down & cast into 4th place 2 1 4 3
9-16::
    1s+4s face diagonally in & set, Petronella turn 1 place
    anticlockwise, set & Petronella turn one more place. To finish 1s &
    4s on opposite sides, 4s facing up, 1s facing down 2 (4) (1) 3
17-20::
    4s turn 2s also 1s turn 3s (on sides) dancing between 2s/3s to start
21-24::
    4s & 1s dance 1/2 Fig of 8 around end couples
25-32::
    All dance 8H round to the left for 6 steps, pivot & chase back to
    places. 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10384, '2018-01-17 20:31:17.966297+00', '2023-02-04 01:21:53.083223+00', 18138, 3, NULL, 'ace', '1-8::
    1s Petronella turn into centre (2s step up), 1s+2s set to partners &
    1s+2s dance RH across.  1L faces Ladies'' side
9-16::
    1L followed by 1M casts behind 2L, crosses over, casts behind 3M,
    dances up middle. 1s remain in centre, 1L facing out between 2M &
    3M, 1M below 3s facing Ladies'' side
17-24::
    1s+3s dance LH across, 1s+3s set & 1s dance Petronella turn to 2nd
    place opp sides
25-32::
    2s+1s+3s Adv (Bar 26: 1s quick 1/2 turn 2H) & Ret.  2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (13321, '2020-11-02 01:21:23.419626+00', '2023-02-04 01:21:53.111653+00', 16661, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s cross RH & cast (1L up, 1M down) into
    lines of 3 across (1L+2s at top, 1M+3s at bottom)
9-16::
    All set, 1s cross LH & cast to left (1M down, 1L up) to 2nd place
    own side & all set
17-20::
    1L+2s & 1M+3s dance RH across
21-24::
    All dance »Snake Pass«:
::
    1L followed by 2s & 1M followed by 3s pass LSh diagonally across
    through 2nd place to change ends, loop round to left, 1s end in 2nd
    place. 3 1 2
25-32::
    3s+1s+2s 1/2 turn partner LH, pull back LSh & dance out to opp side;
    all chase anticlockwise 1/2 round to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4109, '2013-08-21 08:30:43.671299+00', '2023-02-04 01:18:34.670961+00', 314, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp. sides

1-8::
    2s+3s Petronella turn into centre & set to partner (Men BtoB), 2s+3s
    3/4 turn partner RH & dance RH across 1/2 way to change places & end
    with other partner in prom hold (2M+3L facing Men''s side & 3M+2L
    facing Ladies'' side)
9-10::
    1s & 4s Petronella turn into centre _while_ 2M+3L dance out & up on
    Men''s side & 3M+2L dance out & down on Ladies'' side
11-12::
    1s & 4s set to partner _while_ 2M+3L/3M+2L cross to other side
    passing between ''gates'' (1s & 4s)
13-14::
    1s & 4s 1/2 turn RH into prom hold (1s facing Ladies'' side & 4s
    facing Men''s side) _while_ 2M+3L/3M+2L dance down/up sides
15-16::
    All Promenade cl''wise 1 pl to end in square set (1s on Ladies'' side
    facing 4s on Men''s side, 2M+3L in 4th pl face up as 3M+2L in 1st pl
    face down)
17-24::
    1s+4s dance 1/2 Ladies'' Chain (across) , 2s+3s dance 1/2 Men''s Chain
    (up/down). 2s & 3s end with Lady on Man''s left
25-32::
    All set in square set & circle 8H round to left, dance into centre,
    turn right & spiral out to own side lines ending 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (13629, '2021-02-04 01:21:15.848336+00', '2023-02-04 01:21:53.135956+00', 16915, 3, NULL, 'ace', '1-8::
    1s+2s dance 2 couple Bourrel :
::
    1M+2L set advancing, 3/4 turn 2H & twirl to end BtoB (Lady facing up
    & Man down) _while_ partners chase anticlockwise 3/4 way,
::
    set to partners & turn 2H to own sides having changed places
9-20::
    2s+1s+3s dance 3 couple R&L
21-24::
    1s turn RH & cast 1 place (3s step up bar 23-24)
25-32::
    3s+1s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (13322, '2020-11-02 01:21:23.439623+00', '2023-02-04 01:21:53.169241+00', 5252, 3, NULL, 'ace', '1-8::
    All 4 Men Adv+Ret; Men dance RSh round partner & back to place
9-16::
    All Ladies chase anticlockwise down behind Men, across bottom & up
    Ladies'' side back to place
17-24::
    Top 3 Men + bottom 3 Ladies Turn RH; Top 3 Ladies & bottom 3 Men
    turn LH
25-32::
    1s dance DoSiDo; 1s+2s change places RH on side, 1s+3s change places
    LH, 1s+4s change places RH.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8068, '2013-10-01 08:47:16.523019+00', '2023-02-04 01:21:53.196723+00', 15179, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 1M casts up & dances down & Twirls to face 1st
    corners as 1L crosses & casts up then curves round to face 1st
    corner
9-24::
    1s dance Corner Chain with 1st & 2nd corners :
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end passing LH & pivoting left
    into BtoB position (1L facing up & 1M down)
25-28::
    2s+1s+3s set (as in Double Triangles but up/down) 1s PdB out & turn
    Rt about to face in _while_ 2s & 3s PdB in & turn Rt about to face
    out (up/down)
29-32::
    2s+1s+3s set (Inverted Double Triangle formation) 1s PdB in _while_
    2s + 3s PdB out all turning R about & 1s end NHJ facing up on own
    sides
33-40::
    1s dance reflection reels (1s dance up between 2s to start) & all
    end 2 1 3', 4);
INSERT INTO 'dancecrib' VALUES (6844, '2013-08-21 08:31:31.751448+00', '2023-02-04 01:21:53.229514+00', 5256, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH & cast in 1 place, _while_ 2s+3s set & cross
    up/down to end pstns & face out, 2s+1s & 4s+3s dance 1/2 double Fig
    of 8
9-16::
    1s+4s dance RH across once round, set facing diagonally in & dance
    LH across 1/2 way to face corners (1M face 3L, 1L face 3M, 4M face
    2L, 4L face 2M)
17-24::
    1s & 4s dance RSh round corner persons & LSh round next corner
    person clockwise (Figures of 8 round corners - 1M+3s, 1L+3M+2M,
    4M+2L+3L, 4L+2s) Finish  2 (4) (1) 3
25-32::
    1s+4s dance LH across once round ending on opposite sides _while_
    2s+3s set & cross RH, all set & cross back to own sides to end 2 4 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (6845, '2013-08-21 08:31:31.757626+00', '2023-02-04 01:21:53.442216+00', 10009, 3, NULL, 'ace', '1-8::
    1s cast & dance down outside of set to below 3s, dance in & up to
    top, cast to 2nd place own sides
9-12::
    1s cross RH as 1st crnrs dance to 2nd pl, 1s turn 1st crnrs 1/2 LH;
13-16::
    1s dance 1/2 Fig of 8 round partner''s 2nd crnr as 1st crnrs dance to
    2nd pl & cross RH to opp crnr
17-20::
    1s cross LH as 2nd crnrs dance to 2nd pl, 1s turn 2nd crnrs 1/2 RH
21-24::
    1s dance 1/2 Fig of 8 round partners 1st crnr pstn as 2nd crnrs
    dance to 2nd pl, cross LH to opp crnr. End  (3) 1 (2)
25-28::
    1s dance 1/2 diag R&L with 1st corners (1M down, 1L up)
29-32::
    1s dance 1/2 diag R&L with 2nd corners (1M down, 1L up). 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12738, '2020-04-11 10:52:38.087437+00', '2023-02-04 01:21:53.461315+00', 19857, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 (1L down round
    3s, 1M up round 2s) into 2nd place own side
9-16::
    1s dance LSh reels of 3 on opposite sides, LSh to 1st corners
    (Corners dance out/up or out/down & pass RSH bar 2 as 1s join reel).
    1s end in 2nd place opp sides facing 4th corner as corners curve
    into place
17-20::
    1s dance 1/2 diag R&L with 4th corners (1M down, 1L up)
21-24::
    1s dance 1/2 diag R&L with 1st corners (1M down, 1L up).  All now on
    opp sides (3) (1) (2)
25-32::
    3s+1s+2s Set+Link for 3 into lines across; Set+Link for 3 to end 2 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (9034, '2015-11-30 09:00:10.212816+00', '2023-02-04 01:21:53.479722+00', 16615, 3, NULL, 'ace', '1-4::
    1s+4s cross RH, 1s cast off one place as 4s cast up one place. 2s &
    3s step down/up bars 3-4
5-8::
    1s+4s dance 1/2 R&L ending 2 4 1 3.
9-12::
    4s+2s dance Set+Link  _while_ 1s+3s set & dance RH across 1/2 way.
    4 2 (3) (1)
13-16::
    All 4 couples turn partners RH once round & take allemande.hold, 4s
    & 2s couples facing up, 3s & 1s facing down.
17-24::
    All dance interlocking allemandes ending 2 (1) 4 (3).
25-28::
    1s & 3s dance 1/2 Fig 8 through the couple above (1s through 2s, 4s
    through 3s)
29-32::
    1s+4s dance Set+Link.   Finish 2413', 0);
INSERT INTO 'dancecrib' VALUES (6846, '2013-08-21 08:31:31.765977+00', '2023-02-04 01:21:53.4965+00', 7487, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & cross RH, set & 1s & 3s 3/4 turn RH into middle
9-10::
    1s & 3s pass partner RSh & 1M+3L curve to right to face 2s _while_
    2s set
11-12::
    1M+3L pass 2s RSh & 2s curve to right to face 1L/3M in middle
    _while_ 1L+3M set
13-20::
    Repeat bars 9-12 twice more to end with 2s in original places &
    1s+3s having changed ends
21-24::
    3s+2s+1s set to partners & 3s also 1s 3/4 turn RH _while_ 2s cross
    RH to end all on opposite sides.   (3)(2)(1)
25-32::
    3s+2s dance RH across 1/2 way & 3s+1s dance LH across 1/2 way, 1s
    turn LH _while_ 3s turn LH 1.1/2 times.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8530, '2015-02-13 12:47:22.05414+00', '2023-02-04 01:18:25.315097+00', 15602, 3, NULL, 'ace', '1-8::
    All 4 couples set & Petronella in Tandem 1 place to right; all
    repeat to end opposite original position
9-16::
    1s+3s dance Ladies'' Chain
17-24::
    2s+4s dance Ladies'' Chain
25-32::
    All set & turn corner RH; all set & turn partner RH. Ladies face out
33-48::
    All dance Schiehallion reels

{{explanation}}
Repeat from new positions', 0);
INSERT INTO 'dancecrib' VALUES (4016, '2013-08-21 08:30:41.984351+00', '2023-02-04 01:18:27.88066+00', 157, 3, NULL, 'ace', '1-4::
    Ladies circle 4H round to left 1/2 way & turn setting to face out to
    opposite man
5-16::
    All dance double reels of 4
17-24::
    Men dance RH across _while_ Ladies loop into place & set, Men dance
    LH across 1/2 way to meet partner & turn RH to end in opposite pstns
25-28::
    1s form an arch & cross to 1st place & cast (prom hold) to 2nd place
    as 3s Promenade under arch to 3rd place & cast round to 4th place
    _while_ 2s+4s set & 2M+4L turn LH into 1st place & 2L+4M turn LH to
    3rd place
29-32::
    2s+4s dance 1/2 Ladies'' Chain _while_ 1s & 3s Promenade round
    outside of set to opposite sides (All have now moved 1 place
    anticlockwise)', 0);
INSERT INTO 'dancecrib' VALUES (6847, '2013-08-21 08:31:31.774119+00', '2023-02-04 01:21:53.521291+00', 5259, 3, NULL, 'ace', '1-8::
    2s+3s dance RH across, 2s (prom hold) dance LSh round 1M _while_ 3s
    (prom hold) dance LSh round 4L & end on sides (2s on Men''s side & 3s
    on Ladies side)
9-16::
    All dance RSh reels of 4 on sides
17-24::
    2s+3s dance 1/2 R&L, 2M+3L turn RH
25-32::
    2s+3s dance 1/2 R&L & 2L+3M turn RH 1.1/2 times
33-40::
    All turn partners RH, 1s & 3s cast to 3rd/4th place _while_ 2s & 4s
    lead to 1st/2nd places.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8348, '2014-07-29 12:59:22.923563+00', '2023-02-04 01:21:53.562112+00', 15068, 3, NULL, 'ace', '1-8::
    1s+2s dance Chain Progression:
::
    1s+2s turn 3/4 RH, 1M+2L turn LH 1.1/2   _while_ partners chase
    clockwise 1/2 way, 2s+1s turn partners  RH to finish 2s in 1st place
    own sides facing out & 1s in middle ready for..
9-16::
    1s dance Reflection reels of 3 on opp. sides with 1s crossing down
    to 3rd place to start.  1s finish in 2nd place opp. sides
17-24::
    1s dance Reflection reels of 3 on own sides with 1s crossing down LH
    to 3rd place to start.  1s finish in 2nd place own sides
25-32::
    1s dance down middle and back to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6849, '2013-08-21 08:31:31.79055+00', '2023-02-04 01:21:53.611421+00', 7488, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1M followed by partner casts 1 place _while_ 4L followed by partner
    casts up, 1M+4L turn 3/4 RH _while_ partners cast, 1s+4s dance RH
    across to end 1L & 4M on sides & 1M between 3s also 4L between 2s
9-16::
    All set in circle, Adv+Ret 1 step & repeat
17-24::
    All dance Grand Chain (1s & 4s turn right to start)
25-32::
    1L followed by partner dances out between 2M+3M & casts up _while_
    4M followed by partner casts down on Ladies side, all end in
    original places

{{title}}
Reel

1-16::
    As Strathspey
17-24::
    All circle 8H round & back
25-32::
    1s+4s dance RH across but both Men end on Ladies side with partners
    opposite, 4s+1s set & cross RH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6851, '2013-08-21 08:31:31.808361+00', '2023-02-04 01:21:53.636+00', 5262, 3, NULL, 'ace', '1-8::
    1s & 3s dance Figs of 8 round 2s (1s cast to start), 2s step up to
    top place & 1s end in 2nd place BtoB ready for Double Triangles
9-16::
    1s dance Double Triangles _while_ corners set & petronella on 1
    place to right, set & petronella on 1 more place as 1s end facing
    3rd corner (pstn)
17-24::
    1s dance 1/2 diagonal reel of 4 with 3rd corners, pass RSh & repeat
    with 4th corners (pstn)
25-32::
    1L dances a reel of 3 across with 2s as 1M dances reel of 3 across
    with 3s both passing 1st corner LSh & 1s end turn RH to 2nd place on
    own side (facing out ready to cast)', 0);
INSERT INTO 'dancecrib' VALUES (8703, '2015-03-03 08:47:56.450287+00', '2023-02-04 01:21:53.655276+00', 15283, 3, NULL, 'ace', '1-4::
    1s set, cast off (face in) as 2s set & dance up NHJ as 3s set &
    cross RH (face out)
5-8::
    1s+2s+3s dance 1/2 Mirror (»Reflection«) reels of 3 (1s in/down, 2s
    out/down, 3s out/up)  3 1 2
9-12::
    1s set, dance down 1 place (face out) as 2s set, cast up (face in)
    as 3s set, cross RH (face out)
13-16::
    3s+2s+1s dance 1/2 Mirror (»Reflection«) reels of 3 (1s in/up, 2s
    in/up, 3s out/down)  1 2 3
17-24::
    1s set, lead down and back up, stay in middle, 2s step in (bar 24)
    ready for …
25-32::
    1s+2s Allemande  (Alternative:  1s+2s Poussette)
33-40::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (13323, '2020-11-02 01:21:23.929857+00', '2023-02-04 01:21:53.674328+00', 8699, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance, 2 facing 2

1-8::
    All circle 4H round & back
9-16::
    1s+2s dance DoSiDo with person opposite; 1s+2s 1/2 turn person
    opposite RH flowing into 2s+1s dance 1/2 RH across
17-24::
    1s+2s dance DoSiDo with person opposite; 1s+2s 1/2 turn person
    opposite LH flowing into 2s+1s dance 1/2 LH across
25-32::
    1s+2s take Allemande hold & promenade 1.1/2 times round each other
    LSh to meet new couple', 0);
INSERT INTO 'dancecrib' VALUES (6852, '2013-08-21 08:31:31.81674+00', '2023-02-04 01:21:53.698619+00', 9216, 3, NULL, 'ace', '1-8::
    1L+2L+3L Adv+Ret _while_ Men clap, 1M+2M+3M Adv+Ret _while_ Ladies
    clap
9-16::
    1s+2s+3s circle 6 hands round & back
17-24::
    1s+2s set, cross RH & chase 2 places
25-32::
    2s & 3s set & cross RH _while_ 1s (in 2nd place) cross down & cast
    up, 2s & 3s set & cross RH _while_ 1s (in 2nd place) cross up & cast', 0);
INSERT INTO 'dancecrib' VALUES (13324, '2020-11-02 01:21:23.973418+00', '2023-02-04 01:21:53.721476+00', 5264, 3, NULL, 'ace', '1-8::
    1s dance down between 2s, cast up; 1s cross RH & cast (2s step up)
9-16::
    2s+1s dance Ladies'' Chain finishing on sides, Men facing out
17-24::
    1s+2s join NH on sides, set &1/2 turn LH; Repeat (Men polite turn to
    face in)
25-32::
    1s dance 1/2 Fig 8 up round 2s; 1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6919, '2013-08-21 08:31:32.735601+00', '2023-02-04 01:21:59.063055+00', 723, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross LH & cast down below 3s
9-16::
    1s dance up & out between 2L+3L, Man casts up & Lady down, meet in
    middle, dance out between 2M+3M, cross & Lady casts up & Man down to
    meet in middle
17-24::
    1s lead down middle & back to top
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4059, '2013-08-21 08:30:42.878487+00', '2023-02-04 01:18:30.794464+00', 11376, 3, NULL, 'ace', '1-8::
    1s+3s dance RH across, 1s & 3s dance out thru 2s/4s back to places
    (Ladies between & Men round side couples)
9-16::
    1s+3s dance LH across, 1s & 3s dance out thru 4s/2s back to places
    (Men between & Ladies round side couples)
17-32::
    2s+4s repeat bars 1-16
33-40::
    1s & 3s set to partners, change places RH, 1L+3L change places LH,
    1M+3M change places RH (1L & 3L now on partners left)
41-48::
    All Ladies dance R&L (1L+2L also 3L+4L start RH)
49-56::
    All Men dance R&L (1M+4M & 2M+3M start RH)
57-64::
    2s & 4s set to partners, change places RH, 2L+4L change places LH,
    2M+4M change places RH (2L & 4L now on partners left)
65-72::
    All turn partners RH 1.1/4 times (Ladies backs to centre), all set,
    all 3/4 turn partners LH to end facing corners
73-80::
    All dance interlocking reels of 4 (RSh round corner, pass partner
    LSH, RSh round other corner & pass partner LSh to place)
81-88::
    All Ladies dance in front of corner, behind opposite Man to original
    places, Men dance in front of ''new'' corner, behind partner to places
89-96::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8621, '2015-02-13 12:48:08.785583+00', '2023-02-04 01:21:53.747117+00', 15646, 3, NULL, 'ace', '{{explanation}}
6 couples arranged in Triangular Set.

{{title}}
Start

::
    3L··3M··4L·4M
::
    ·2M··········5L
::
    ··2L········5M
::
    ···1M·····6L
::
    ····1L··6M
::
    ·······Top
1-8::
    1s+2s, 3s+4s, 5s+6s dance reels of 4 on sides of triangle
9-16::
    All set to partners, turn RH  to face corner. Set to corner, turn LH
    , take promenade hold with partner (L on Right) 1s face 2s, 3s face
    4s, 5s face 6s
17-24::
    All promenade 4 places,1s+3s+5s clockwise, 2s+4s+6s anticlockwise
    passing couples by Right then Left.  Finish 3 6 5 2 1 4
25-32::
    All circle 12H round and back', 0);
INSERT INTO 'dancecrib' VALUES (6853, '2013-08-21 08:31:31.830296+00', '2023-02-04 01:21:53.786659+00', 5265, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s dance RH across (1L with 2s, 1M with
    3s) & end facing 1st corners
9-16::
    1s dance 1/2 reel of 4 with 1st corners; 1s dance RH across (1M with
    2L/3L, 1M with 2M/3M) & end facing 2nd corners
17-24::
    1s dance 1/2 reel of 4 with 2nd corners; 1s pass LSh, dance out ends
    & cast round 1st corner (pstn) to 2nd place opp sides _while_ 3s+2s
    dance 1/2 L&R (start changing LH on sides).  2 (1) 3
25-32::
    1s dance reels of 3 on sides (RSh to 2nd corner) & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (6855, '2013-08-21 08:31:31.844349+00', '2023-02-04 01:21:53.83943+00', 13460, 3, NULL, 'ace', '1-8::
    1s & 5s Adv+Ret diagonally, 1s cross RH & cast 2 places
9-16::
    3s+1s+4s circle 6H round & back
17-24::
    1s cross LH & cast down 2 places, 2s & 1s Adv+Ret diagonally
25-32::
    All turn partner RH once round, once round LH', 0);
INSERT INTO 'dancecrib' VALUES (6858, '2013-08-21 08:31:31.873146+00', '2023-02-04 01:21:53.893893+00', 5282, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s slip step down for 2 bars & back then cast to 2nd place
17-24::
    1s dance down between 3s & cast to face 1st corners, 1s set to 1st
    corners then 2nd corners & end with 1M pivoting left as 1L pivots
    right to face prtnr
25-32::
    1s dance out Ladies side & cast (1M round 2s, 1L round 3s) cross out
    Mens side & cast (1M round 3M, 1L round 2M) to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6857, '2013-08-21 08:31:31.860837+00', '2023-02-04 01:21:53.908978+00', 11189, 3, NULL, 'ace', '1-8::
    Ladies dance RSh round their corners, dance RH across ending in
    centre
9-16::
    Ladies dance LSh round their partners, dance LH across & back to
    places
17-24::
    Men dance RSh round their partners, dance RH across ending in centre
25-32::
    Men dance LSh round corners, dance LH across & back to places
33-40::
    1s & 3s turn partners RH 1.1/4 times, Men followed by partners dance
    out between side couples & back to places (1M thru 4s & 3M thru 2s)
41-48::
    1s+3s dance R&L
49-56::
    2s & 4s turn partners RH 1.1/4 times, Men followed by partners dance
    out between side couples & back to places (2M thru 1s & 4M thru 3s)
57-64::
    2s+4s dance R&L
65-72::
    Ladies dance in turning right about to dance out, cast clockwise to
    opposite Lady''s place
73-80::
    Men dance in turning left about to dance out, cast anticlockwise to
    opposite places
81-88::
    All turn partners RH 1.1/4 times into prom hold, Promenade
    anticlockwise 1/2 way round to original places', 0);
INSERT INTO 'dancecrib' VALUES (6859, '2013-08-21 08:31:31.881268+00', '2023-02-04 01:21:53.924082+00', 8107, 3, NULL, 'ace', '1‑8::
    1s cast down 1 place & dance 1/2 Fig 8 round 4s _while_ 3s dance 1/2
    Fig 8 round 2s & lead up to top, 3s & 1s cross RH.  3 2 1 4
9‑16::
    2s+1s dance RH across, 3/4 turn partners RH to end in line up/down
    middle (Ladies facing down & Men up)
17‑24::
    2s+1s dance reel of 4 & end on sides
25‑32::
    1s+4s change pl on sides (Ladies RH, Men LH), 2s+4s change pl on
    sides (Ladies LH, Men RH), 3s+4s full turn on sides (Ladies RH, Men
    LH) to end 3 4 2 1', 0);
INSERT INTO 'dancecrib' VALUES (6860, '2013-08-21 08:31:31.889256+00', '2023-02-04 01:21:53.939531+00', 5276, 3, NULL, 'ace', '1-8::
    1s dance reel of 3 across with 2M (1s pass LSh to start) & at end 1M
    crosses RH with 2L who crosses to partner''s place _while_ 2M casts
    up
9-16::
    1s+2s set HS diagonally, 1L+2L dance DoSiDo (or 1s+2s dance double
    DoSiDo)
17-24::
    1s+2s circle 4H round to left, 1s+2L dance RH across 1.1/4 times to
    end with 1s in 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6861, '2013-08-21 08:31:31.897256+00', '2023-02-04 01:21:53.955091+00', 5277, 3, NULL, 'ace', '{{explanation}}
1s & 3s start on opp sides

1-8::
    All set, 1s+2s also 3s+4s circle 4H round to left opening out in
    middle to 1s facing 2s & 3s facing 4s, all set
9-16::
    All petronella turn into lines across (Men BtoB facing other
    partner) & all set, all petronella turn onto sides & set.  2(1)4(3)
17-24::
    All dance Ladies'' Chain & 1s end facing down, 4s facing up
25-32::
    1s+4s dance 1/2 R&L, all set & cross RH.  (2)4(1)3', 0);
INSERT INTO 'dancecrib' VALUES (13432, '2020-12-02 01:21:17.932269+00', '2023-02-04 01:21:53.969275+00', 5279, 3, NULL, 'ace', '1-8::
    1s turn 1.1/2 2H & face out; 1s+2s change places NH on side (2s
    curve into place), 1s+3s change places on sides NH, 1s curve into
    3rd place
9-16::
    1s turn 1.1/2 2H & face out; 1s+3s change places NH on side (3s
    curve into place), 1s+2s change places on sides NH, 1s curve into
    1st place
17-24::
    1s+2s set, turn partner 2H remaining in centre to dance 1/2
    Poussette
25-32::
    1s+3s dance RH across, retain partner''s hand & 1s+3s turn partner
    RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4017, '2013-08-21 08:30:41.992525+00', '2023-02-04 01:18:27.907838+00', 159, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s cross down to 2nd pl as 2s cast up then
    1M+2L turn LH as 1L+2M turn RH into a line across (1s between 2s)
    facing down
9-16::
    1s+2s dance down in line, 1s turn & face up as 2s turn in behind,
    dance up, 1s casting to 2nd place opp sides as 2s dance to 1st place
    own sides
17-24::
    2M+1L also 2L+1M set & Petronella turn-in-tandem into middle, set &
    Petronella turn-in-tandem to sides
25-32::
    1s+2s set, circle 4H round 1/2 way; 1s turn 2H 1.1/2 times to 2nd
    place own side', 0);
INSERT INTO 'dancecrib' VALUES (6862, '2013-08-21 08:31:31.905288+00', '2023-02-04 01:21:53.984+00', 7490, 3, NULL, 'ace', '1-8::
    1s & 3s lead down the middle, cross below next 2s/4s & dance down
    behind 4s/5s, turn LH & cast up 1 place to face 1st corners
9-16::
    1s turn 1st corners RH dance out thru own side & turn 2nd corners LH
    & dance back to 2nd/4th place own sides
17-24::
    1s & 3s dance RH across (Ladies up & Men down), turn partners LH &
    cast 1 place
25-32::
    All circle 10H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12416, '2019-12-05 01:31:31.9792+00', '2023-02-04 01:21:54.21094+00', 5281, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s set,1M casts down round 3M _while_ 1L
    casts up round 2L & to end 1M between 3s facing 3L, 1L between 2s
    facing 2M
9-16::
    1L sets to & turns 2M, sets to & turns 2L _while_ 1M sets to & turns
    3L, sets to & turns 3M
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH, partner LH to end
    in 2nd place own side
25-32::
    2s+1s+3s set twice & turn partner RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6863, '2013-08-21 08:31:31.913589+00', '2023-02-04 01:21:54.375817+00', 10860, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    All set, 1s & 4s cast in 1 place, 1M+4L also 1L+4M turn LH on sides
    ending outside the set (as Sq.Set)
9-12::
    1L+4L change places RH _while_ 2s & 3s change places with partner
    RH, 2M+3M change places LH _while_ 1s+4s change places LH with
    partner
13-16::
    1L+4L change places RH _while_ 2s & 3s change places with partner
    RH, Men dance in & face Lady in a cross formation
17-24::
    All dance Highland setting step (4 bars) & dance 1/2 reels of 4
    (Ladies give LH in centre & Men do not pass each other but turn to
    face clockwise
25-28::
    All Promenade (with partner) clockwise 1/2 way to end in Sq.Set (2s
    at top & 3s at bottom) & set to partner
29-32::
    1s+4s chase clockwise 1/4 way (inside set) _while_ 2s & 3s advance &
    twirl back to place to end in longways set order 2 4(1)(3)

{{explanation}}
Repeat again in Strathspey time then twice in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (12163, '2019-09-04 09:10:47.122127+00', '2023-02-04 01:21:54.399995+00', 19628, 3, NULL, 'ace', '1-8::
    1s+3M (3M casts up) dance (semi-double) Fig 8 round 2s, 5s+3L (3L
    casts down) dance (semi-double) Fig 8 round 4s.
9-16::
    2s+4s dance double Fig 8 round 3s (4s cast to start)
17-24::
    1s+2L, 2M+3s+4L & 4M+5s dance RH across, 2s+4s pass partner RSh &
    all dance LH across
25-32::
    1s cross down between 2s, behind 3s, cross down between 4s & down
    behind 5s', 0);
INSERT INTO 'dancecrib' VALUES (13091, '2020-08-10 00:20:57.008705+00', '2023-02-04 01:21:54.429951+00', 16479, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1L followed by partner casts 1 place &
    crosses over & both end 2nd place opp sides with 1L facing out (2s
    step up 7-8)
9-16::
    1s+3s dance LH across, 1L followed by partner casts up behind 2M to
    face 2L (2s step down 15-16)
17-24::
    1s dance Semi-Alternating Tandem Reel with 2s: 1s+2L pass LSh, 1M
    takes lead on Ladies'' side on bar 19, 1s complete reel with 1M
    leading to end facing 3L, 2s end in top place
25-32::
    1s dance Semi-Alternating Tandem Reel with 3s: 1s+3L pass LSh, 1L
    takes lead on Men''s side on bar 31, 1s end in 2nd place own sides
    with 1L facing out. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6865, '2013-08-21 08:31:31.951818+00', '2023-02-04 01:21:54.519814+00', 13458, 3, NULL, 'ace', '1-8::
    2s passing LSh dance 1/2 diag reel with 1st corners to end facing
    2nd corners, 2s set & turn corners 2H
9-16::
    2s dance 1/2 diag. reel with 2nd corners to end facing 3rd corners,
    2s set & turn 3rd corners 2H ending on sides.  (3) 2 (1)
17-24::
    All chase clockwise 1/2 way, 1s+2s chase clockwise 1/2 way & 1s
    cross to own side.  2 1 3
25-32::
    1s cast to 3rd place & all set, all turn partner 2H.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6866, '2013-08-21 08:31:31.959844+00', '2023-02-04 01:21:54.547344+00', 5291, 3, NULL, 'ace', '1-8::
    1s dance RSh reels of 3 on own sides
9-16::
    1L followed by partner casts 1 place & crosses up between 2s, casts
    down round 2M & end in 2nd place own sides
17-24::
    2s+1s+3s dance Grand Chain
25-32::
    1s dance up between 2s, cast to 2nd places & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (7563, '2013-08-21 08:31:44.698838+00', '2021-04-11 11:33:39.388862+00', 6463, 3, NULL, 'ace', '1-8::

    1s+2s+3s set advancing & 1/2 turn 2H to face up, all dance up & cast

    on opposite sides.  (3)(2)(1)

9-16::

    3s+2s+1s dance DoSiDo, all turn 1.1/2 times into Prom hold facing up

17-20::

    3s+2s+1s dance a 1/2 Peerie Turn: couples in prom hold 1/2 turn

    anticlockwise to face down with Men turning Ladies on to their left

21-24::

    1s followed by 2s+3s dance down & cast to orig places

25-32::

    1s dance down for 2 & set with hands joined & arms spread to form a

    diamond, 1s dance up & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (12936, '2020-07-01 00:21:03.6747+00', '2023-02-04 01:21:54.571678+00', 17603, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels of 3 on sides, each couple crossing down from
    1st place (2s dance out/up, 3s in/up to start)
9-12::
    1s NHJ dance down _while_ 2s dance up sides to 1st place (2 bars),
    1s divide & cast up round 3s to 2nd place
13-16::
    2s+1s+3s 1/2 turn RH, pull back RSh & dance out own side, Men face
    up, Ladies face down
17-24::
    2s+1s+3s chase clockwise 1/2 round, circle 6H round to the right
    back to own sides
25-32::
    2s+1s dance LH across; 1s+3s dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (6867, '2013-08-21 08:31:31.967876+00', '2023-02-04 01:21:54.597317+00', 5296, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH & cast down 1 place, lead down between the couple
    below & cast back to 2nd/4th place (opposite sides)
9-16::
    2s+1s & 4s+3s dance 1/2 R&L & Petronella turn 2 places anticlockwise
    round square (end in same places as at bar 8)
17-24::
    All dance RH across (1M with 2s, 1L+3M with 4s, 3L with 5s) & 1s &
    3s change places with partners to dance LH across
25-32::
    1s & 3s cross RH cast down 1 place & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (15144, '2022-10-05 00:21:25.255655+00', '2023-02-04 01:21:54.632033+00', 10847, 3, NULL, 'ace', '{{explanation}}
The circle to be evenly spaced - not close to your partner

1-8::
    1L dances RSh reel of 3 with 2s (passing 2M RSh to start) _while_ 1M
    dances LSh reel of 3 with 3s (passing 3L LSh)  (1L dances in front
    of 1M)  (reels are danced on the curve)
9-16::
    1M+3s & 1L+2s dance Double Triangles & Petronella turn back to
    places
17-24::
    All turn partner RH (2 bars), Ladies dance LH across (3 bars)
    _while_ Men dance to place & turn partner RH (3 bars)
25-32::
    1s+2s 1/2 R&L; 1s+3s 1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (4111, '2013-08-21 08:30:43.772755+00', '2023-02-04 01:18:34.874702+00', 11904, 3, NULL, 'ace', '{{explanation}}
5s in centre facing 1s

1-8::
    All set. 4s dance 1/2 LH across with 5M, as 2s dance 1/2 RH across
    with 5L. All repeat bars 1-4
9-16::
    5s dance Fig of 8 round 1s & 3s (dancing between 1s to start),
    taking hands when meeting & end facing each other in centre
17-24::
    1s+2s+3s+4s dance crescent reels of 4 on sides (starting BtoB with
    partner) _while_ 5s dance HS for 4 bars & turn RH for 4 bars
25-32::
    1L+5L change places RH then 1M+5M change LH, 1s set & turn RH ready
    to start again (as new 5s) _while_ outside couples join hands with
    partners, set & dance 1 place clockwise', 0);
INSERT INTO 'dancecrib' VALUES (4112, '2013-08-21 08:30:43.780695+00', '2023-02-04 01:18:34.942881+00', 316, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 on own sides (1s in & down to start)
9-16::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L
17-24::
    1s cross RH, cast up to 2nd place & 2s+1s+3s turn RH.  (2)(1)(3)
25-32::
    2s+1s+3s set & petronella turn, set & petronella turn to own sides', 0);
INSERT INTO 'dancecrib' VALUES (14585, '2022-02-05 02:21:09.416824+00', '2023-02-04 01:21:54.66704+00', 20625, 3, NULL, 'ace', '1-8::
    1s lead down, cross RH below 3s & cast up in 2nd place opp sides (2s
    step up 3-4); 1s set & 1/2 turn RH
9-16::
    2s+1s+3s circle 6H 1/2 round to left;  1M+2s also 1L+3s dance LH
    across.  (3) (1) (2)
17-24::
    3s+1s+2s circle 6H 1/2 round to right; 1L+2s also 1M+3s dance RH
    across.  2 1 3
25-32::
    1s Petronella turn & set; 1s Petronella turn to 2nd place opp side &
    1s cross down LH to 3rd place own side (3s step up 31-32).  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (11707, '2019-03-18 21:02:43.147573+00', '2023-02-04 01:21:54.695196+00', 17466, 3, NULL, 'ace', '1-4::
    All set. Ladies pull back RSh & cast to corner place to their Left
    _while_ Men dance in & curve to Right to meet ''new'' partner (on Left
    of Lady) all facing diagonally in
5-8::
    All repeat 1-4 to end in square 1st: 2M+4L, 2nd: 3M+1L, 3rd: 4M+2L,
    4th: 1M+3L with top & bottom couples BtoB with ''new'' partner
9-16::
    Side couples dance in to meet original partners, NHJ with partner
    dance out to original places & turn 2H 1.1/2 _while_
::
    Top & bottom couples dance round towards original places to meet
    partners, NHJ dance into centre & turn inwards to dance back to
    original places & 1/2 turn 2H
17-24::
    All dance Interlocking reels of 4 (pass partner RSh to start).  End
    Ladies facing out, Men facing in
25-32::
    All dance 4 bars Schiehallion reels to end 1 place round
    anticlockwise & all turn partner RH (4 bars)', 0);
INSERT INTO 'dancecrib' VALUES (14129, '2021-07-07 00:20:54.318301+00', '2023-02-04 01:21:54.726867+00', 17345, 3, NULL, 'ace', '{{explanation}}
3s and 4s start on opp sides

1-6::
    1s and 4s Petronella turn & set, Petronella turn to opp sides (no
    polite turn)
7-8::
    1s+2s & 3s+4s chase 1/2 round & join NH with partner facing up and
    down. (2) 1 (4) 3
9-16::
    _9-10_   All couples set advancing to pass next couple LSh 1 (2) 3
    (4)
::
    _11-12_  End couples turn 2H to face down/up _while_ middle couples
    set advancing to pass LSh 1 3 (2) (4)
::
    _13-16_  Repeat 9-12 to end 3 (4) 1 (2)
17-20::
    4s dance 1/2 Fig 8 up round 3s _while_ 1s dance 1/2 Fig 8 down round
    2s.  3 4 (1) (2)
21-24::
    4L+1L change places RH & set _while_ 4M+1M set & change places RH. 3
    1 (4) (2)
25-32::
    All Adv+Ret (1 step each), cross RH with partner; 3s+1s & 4s+2s
    circle 4H round to left.  End 3 1 (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (15350, '2022-12-19 01:21:30.431918+00', '2023-02-04 01:21:54.768099+00', 20665, 3, NULL, 'ace', '1-8::
    1s set, cross down RH to 2nd place (2s step up 3-4); 1s+3s Set+Link
    (at end 1L & 3L face out).  2 3 (1)
9-16::
    3s+1s dance Men''s Chain 2 3 (1)
17-20::
    2s+1s set, cross RH to finish 2s facing out, 1s facing partner (2) 3
    1
21-24::
    2s cast down (3s step up) & turn partner 3/4 LH to face 1st corners
25-32::
    2s dance 6 bars of »Hello-Goodbye« setting. Bars 31-32: 2s turn 3/4
    RH into Allemande hold (1s step in on bar 32)
33-40::
    2s+1s dance Allemande.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (12417, '2019-12-05 01:31:32.4568+00', '2023-02-04 01:21:54.789311+00', 17532, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance down, cast up to 2nd place
9-16::
    1s petronella turn into lines across & 1s set. 1s pass LSh & dance
    1/2 reel with 2nd crnrs to end 2nd place opp sides
17-24::
    1s petronella turn into lines across & 1s set. 1s pass RSh & dance
    1/2 reel with 1st crnrs to end 2nd place opp sides
25-32::
    1L+3s also 1M+2s dance LH across. 1L followed by 3L+3M also 1M
    followed by 2M+2L chase anticlockwise 1/2 way 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6869, '2013-08-21 08:31:31.986349+00', '2023-02-04 01:21:54.864027+00', 10749, 3, NULL, 'ace', '1-12::
    All dance Grand Chain 2 steps & set to next dancer, repeat twice
    ending in original places
13-16::
    All turn partners RH
17-40::
    The Ladies dance The Sheep''s Head Hey:
::
    All Ladies dance up & across the top of the set & weave down the
    Mens line
::
    As 1L dances in front of 3rd man, 3L (passing between 2M & 3M) turns
    up behind 2M to become leader (3 1 2) & leads back to top
::
    3L leads down Mens line weaving & as 2L reaches the gap between 2M &
    3M she turns up behind 2M & leads back to top (2 1 3)
::
    2L leads down Mens line weaving & as 1L reaches the gap between 2M &
    3M she turns up behind 2M & leads back to top (1 2 3)
::
    Then 1L leads the line down behind Men & back to top on own side
41-48::
    All circle (slip step) left & back
49-72::
    Men dance The Sheep''s Head Hey (same pattern through Ladies)
73-80::
    All set advancing & petronella turn to next place anticlockwise, set
    advancing & petronella turn to next place anticlockwise
81-88::
    All set & turn to right, all chase to original places & turn
    partners RH', 0);
INSERT INTO 'dancecrib' VALUES (6871, '2013-08-21 08:31:32.002437+00', '2023-02-04 01:21:55.045502+00', 13469, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-12::
    1L+2M set & cast 1 place (L down, M up) as 1M+2L stand & cross to
    prtnrs place
13-16::
    1M+2L set & cast 1 pl (L up, M dn) as 1L+2M stand & cross to prtnrs
    pl.  (2)(1)
17-24::
    1M+2L turn RH 1.1/2 times, 1L+2M turn LH 1.1/2 times
25-32::
    1s+2s dance Tournee:
::
    _25-28_   1s+2s dance into prom hold (Men with partner on right, 1s
    face Men''s side & 2s face Ladies side), both couples wheel
    anticlockwise 1/2 way & Men turn Ladies into middle
::
    _29-32_   Both couples turn 1.1/2 times (2s RH, 1s LH) & dance out
    to places', 0);
INSERT INTO 'dancecrib' VALUES (4113, '2013-08-21 08:30:43.791104+00', '2023-02-04 01:18:34.972328+00', 12868, 3, NULL, 'ace', '1-8::
    1s set, 1L followed by partner cast 2 places, 1L crosses & dances up
    behind 3M to 2nd place _while_ 1M dances up in front of 3L to 2nd
    place
9-16::
    2s+1s dance Ladies'' Chain
17-24::
    2s+1s+3s Set+Link for 3 once, 2s+3s chase cl''wise 1/2 way as 1s
    cross RH & join chase (1M end b''tw''n 2M+3M, 1L b''tw''n 2L+3L all on
    opp sides)
25-32::
    All set to partners & 3/4 turn RH into centre, repeat to own sides.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4114, '2013-08-21 08:30:43.801046+00', '2023-02-04 01:18:35.031794+00', 14926, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 on own sides (between 2s to start)
9-16::
    1s+2s+3s Adv+Ret & turn RH to end in prom hold facing up
17-24::
    1s+2s+3s Promenade (1s end facing out)
25-32::
    1s+2s turn with nearer hand 1.1/2 times, 1s+3s turn (other hand)
    once round', 0);
INSERT INTO 'dancecrib' VALUES (13034, '2020-08-10 00:18:29.889949+00', '2023-02-04 01:18:35.059498+00', 8111, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left; 1L+2L dance RSh round partner back to
    place
9-16::
    1s+2s dance the Knot
17-24::
    2s+1s circle 4H round to right; 2M+1M dance LSh round partner back
    to place
25-32::
    1s dance up, cast round 2s & turn 2H.  End 2 1', 0);
INSERT INTO 'dancecrib' VALUES (14009, '2021-05-03 00:21:11.114802+00', '2023-02-04 01:21:55.074169+00', 19827, 3, NULL, 'ace', '1-8::
    1s set. 1s cast down 1 place (2s step up), 1s dance 1/2 Fig of 8 up
    round 2s, dance up NHJ to finish back to back between 2s (1L facing
    2M, 1M facing 2L)
9-16::
    1L+2M also1M+2L set & turn RH; 1s pass RSh to change places (1M
    faces 2M, 1L faces 2L). 1M+2M also 1L+2L set & turn RH, 1s pass RSh
    to finish in middle with RH joined, 1L facing up & 1M facing down.
    2s finish in 1st place
17-24::
    1s turn RH moving down the middle to finish in 2nd place on opposite
    sides (2 bars) facing down, 1s dance down NHJ between 3s, cast up
    round 3s & dance down NHJ to finish back to back between 3s (1L
    facing 3M, 1M facing 3L)
25-32::
    1s+3s repeat bars 9-16. At end 1s join RH to finish in middle 1L
    facing up & 1M facing down. 3s finish in 3rd place
33-40::
    1s turn RH to finish on opposite sides facing down (2 bars), 1s
    dance down NHJ, cast up round 3s & cross down to 3rd place on own
    sides. 3s step up bars 35-36.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (9924, '2017-06-05 11:31:37.390747+00', '2023-02-04 01:21:55.243079+00', 16025, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, 1L dances half Fig 8 with 2s _while_ 1M
    dances half Fig 8 with 3s
9-16::
    2s+1s+3s dance Arandel:
::
    _9-12_    All cross RH, 2L+1L also 1M+3M change places on sides LH
    _while_ 2M+3L (1st corner persons in 2nd corner pstn) set to each
    other
::
    _13-16_  All cross RH, 1L+2L also 3M+1M change places on sides LH
    _while_ 2M+3L (1st corner persons in 1st corner pstn) set
::
    1s omit polite turn
17-24::
    2s+1s+3s dance RSh reels of 3 on sidelines 1M+2M & 1L+3L pass RSh to
    start
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6872, '2013-08-21 08:31:32.010526+00', '2023-02-04 01:21:55.26993+00', 9764, 3, NULL, 'ace', '1-8::
    1s & 3s turn RH (2 bars) & lead down 1 place, 1s dance out cast
    behind next couple & dance up 1 pl to face own side BtoB for Double
    Triangles
9-16::
    1s & 3s dance Double Triangles & end turning to right to face 4th
    corners
17-24::
    1s & 3s dance reels across (reels of 3 top & bottom, reel of 4 in
    centre)
25-32::
    1s & 3s 1/2 turn partners RH, Bal-in-Line, turn partners RH & cast
    down on own sides', 0);
INSERT INTO 'dancecrib' VALUES (10091, '2017-09-03 23:45:15.211885+00', '2023-02-04 01:21:55.296143+00', 9486, 3, NULL, 'ace', '1-8::
    1M+2L turn RH (4 bars).  1s+2s circle 4H round to Left
9-16::
    1L+2M turn LH (4 bars).  1s+2s circle 4H round to Right
17-24::
    1s lead down (3 bars), lead up (3 bars) & cast to 2nd place (2s step
    up 23-24)
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6873, '2013-08-21 08:31:32.018488+00', '2023-02-04 01:21:55.323999+00', 11790, 3, NULL, 'ace', '1-8::
    1s dance down middle & cast back to place, 3s dance up middle & cast
    back to place
9-16::
    2s dance RH across (L with 1s & M with 3s), pass RSh & dance LH
    across with other couple
17-24::
    2s dance LSh reels of 3 across (L with 1s & M with 3s),
25-32::
    3s cross RH & cast up to 2nd place, cross RH & cast to top', 0);
INSERT INTO 'dancecrib' VALUES (6875, '2013-08-21 08:31:32.035322+00', '2023-02-04 01:21:55.38812+00', 5308, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH, cast 1 place (2s & 4s step up) & dance 1/2 Fig of
    8 round couple above them
9-16::
    1s & 3s turn RH then turn LH (long turns) to face 1st corners
    _while_ 2s & 5s change places RH & chase clockwise to other end of
    set
17-24::
    1s & 3s dance 1/2 diag reels of 4 with 1st corners, pass partner
    LSh, dance 1/2 diag reels of 4 with 2nd corners
25-32::
    1s & 3s dance 1/2 diag reels of 4 with 3rd corner, turn partner LH &
    cast down 1 place own sides.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (6878, '2013-08-21 08:31:32.059169+00', '2023-02-04 01:21:55.697737+00', 10283, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    1s (facing clockwise) lead forward between 2s & cast back to place,
    2s lead between 1s & cast back to place
9-16::
    1M+2L lead between partners & cast back to place, 2M+1L lead between
    partners & cast back to place
17-24::
    All set twice & turn opposite person RH 1.1/4 times into lines of 4
    (1s facing clockwise, 2s anticlockwise)
25-28::
    All Bal-in-Line twice moving to right (changing places & hands with
    opposite person) & to left back again
29-32::
    All turn opposite person RH 1.1/4 times & turn right about to face
    next couple', 0);
INSERT INTO 'dancecrib' VALUES (6874, '2013-08-21 08:31:32.027242+00', '2023-02-04 01:22:33.509361+00', 11190, 3, NULL, 'ace', '1-8::
    1s cross RH, cast to 3rd place, 2s & 1s set & cross RH
9-16::
    2s+1s dance Men''s Chain (up/down)
17-24::
    3L+1M change places LH, 3M+1L change places RH, 2s+1s+3s set & cross
    RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7882, '2013-08-21 08:31:50.507579+00', '2023-02-04 01:23:09.445543+00', 9902, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 R&L, 2s cross RH _while_ 1s 3/4 turn RH to end
    with 1M facing up between 2s & 1L facing down between 3s
9-16::
    1s dance 1/2 RSh reels of 3 across, pass RSh & 1/2 RSh reels of 3
    with other couples 1s end in 2nd place on own sides
17-24::
    1s cross RH & cast round 1st corners to face in middle _while_ 2s &
    3s cross RH & set, 1s pass RSh & cast to 2nd place on opposite sides
    _while_ 2s+3s change places on side & set
25-32::
    1s dance 1/2 LSh reels of 3 across (Man up & Lady down) & 1/2 RSh
    reel of 3 on own side', 0);
INSERT INTO 'dancecrib' VALUES (8849, '2015-08-13 20:33:59.49838+00', '2023-02-04 01:21:55.730094+00', 14287, 3, NULL, 'ace', '1-4::
    1s cross down RH to 2nd place opp sides as 4s cross up LH to 3rd
    place opp sides (2s & 3s step down/up).  1s & 4s set to partners
5-8::
    1s+4s dance RH across _while_ 2s & 3s set Advancing, 1/2 turn 2H
    (PdeB) to face partners raising arms to make arches
9-12::
    1L followed by 4L casts out & up Men''s side to top & under arch made
    by 2s into 3rd / 2nd place own sides facing down _while_ 4M followed
    by 1M dance similar casting out & down Ladies'' side, under arch made
    by 3s into 2nd / 3rd place own sides (2s & 3s drop hands, remain in
    centre)
13-16::
    1L followed by 4L dance 1/2 tandem reel of 3 on sides with 3M+2M
    (pass 3M RSh) _while_ 4M followed by 1M dance similar with 2L+3L
    (pass 2L RSh)
17-20::
    As bars 5-8 but LH across
21-24::
    As bars 9-12 but 1L+4L cast out & up Ladies side, under arches  made
    by 3s to 3rd / 2nd place opp sides , 4M+1M cast out & down Men''s
    side, under arches made by 2s to 2nd / 3rd place opp sides
25-28::
    As bars 13-16 but passing LSh to start
29-32::
    1s+4s dance 1/2 RH across and set. End 2 4 1 3
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6879, '2013-08-21 08:31:32.067432+00', '2023-02-04 01:21:55.751255+00', 5316, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    1s & 4s cross RH, 1M also 4M followed by partners casts to 4th/1st
    place, cross, Men cast back to place as partner dances up/down
    centre
9-16::
    1s+2s also 3s+4s dance 1/2 Men''s Chain (end facing prtnr on sides),
    all dance 1/2 RSh reel of 4 on sides & end in lines across (Ladies
    face prtnr)
17-24::
    1s+2s also 3s+4s dance 1/2 RSh reels of 4 across, Men followed by
    partners chase clockwise & circle 8H round to left to end on sides
    with 1M in 4M place & 4M in 1M place
25-32::
    All 1/2 turn partners 2H & Lady crosses over to 4 (2) 3 (1) (4s face
    2s & 3s face 1s), all set & dance 4H round 1/2 way to 2 (4) 1 (3) &
    set', 0);
INSERT INTO 'dancecrib' VALUES (13325, '2020-11-02 01:21:25.884249+00', '2023-02-04 01:21:55.772251+00', 15889, 3, NULL, 'ace', '1-8::
    1L followed by 1M dance down, cast up to top on opp sides & 1L
    followed by 1M start to dance down
9-16::
    Hands across (1M+ 2L+3L LH, 1L+2M+3M RH across); 1s NHJ joined dance
    down & cast up into centre 2nd place opp sides facing up
17-24::
    Hands across (1M+ 2L+3L RH, 1L+2M+3M LH across); 1s dance 1/2 Fig 8
    up round 2s to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6880, '2013-08-21 08:31:32.077162+00', '2023-02-04 01:21:55.808182+00', 5320, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H left, 1s+2s set (facing partner) 1s cast 1 place
    _while_ 2s dance up
9-16::
    2s+1s+3s dance reflection reels of 3 on sides (1s down & in to
    start) & 1s ends facing 1st corners
17-24::
    1s change places with 1st corners RH turning to face each other, set
    & change places RH & 1s turn LH 1.1/4 times to face 2nd corners
25-32::
    1s repeat with 2nd corners end turning LH to sides', 0);
INSERT INTO 'dancecrib' VALUES (13433, '2020-12-02 01:21:19.511377+00', '2023-02-04 01:21:55.83987+00', 19163, 3, NULL, 'ace', '{{explanation}}
 On chord form a circle to bow/cursey across set

1-8::
    All circle 8H round & back
9-16::
    All set to partner, Petronella turn & set again, all 1/2 turn
    partner RH ready for …
17-20::
    Men dance 1/2 LH across _while_ Ladies chase clockwise into
    partner''s place, Men 1/2 turn opposite Lady to bring Ladies into
    centre for …
21-24::
    Ladies dance 1/2 LH across _while_ Men chase clockwise into Ladies''
    place, all turn partner RH into square set facing partner
25-32::
    All dance 1/2 Grand Chain; all turn partner 2H, all 1/2 turn corner
    into promenade hold facing anticlockwise
33-40::
    All promenade anticlockwise to Man''s original place (now 1M+2L,
    2M+3L, 3M+4L, 4M+1L)', 0);
INSERT INTO 'dancecrib' VALUES (10838, '2018-06-11 00:36:55.078662+00', '2023-02-04 01:21:55.867486+00', 17465, 3, NULL, 'ace', '1-8::
    1s set and cast (2s step up), turn LH to face 3L, 1L behind 1M
9-16::
    1s dance 1/2 LSh tandem reel on 1st corner diagonal, LSh to 3L to
    begin; dance 1/2 LSh tandem reel on 2nd corner diagonal, 1s LSh to
    3M to begin. 1s end in middle facing up, NHJ with Lady on Man''s Left
17-24::
    Mirror reels of 3 on opp. sides (3s out/down, 1s up, 2s out/up)
    giving hands where possible. 3s & 2s loop at end.  (3)(1)(2)
25-32::
    3M+1M+2M NHJ slip to Right to own side _while_ 3L+1L+2L NHJ slip
    Left to own side, Men passing behind Ladies.  All turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (13326, '2020-11-02 01:21:25.941731+00', '2023-02-04 01:21:55.896353+00', 16478, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+3s+2s+4s dance interlocking Ladies'' Chain (Ladies RH across in
    centre)
9-16::
    All face partner, set & turn RH; all set & turn corner LH. All end
    in place, Ladies facing out
17-24::
    All dance 8 bars Schiehallion Reel (all moved 2 places clockwise
    from start position 3 4 2 1)
25-32::
    All circle 8H round & back

{{title}}
Reel

1-8::
    Repeat 1-32 above in reel time', 0);
INSERT INTO 'dancecrib' VALUES (13327, '2020-11-02 01:21:25.964135+00', '2023-02-04 01:21:55.924802+00', 16906, 3, NULL, 'ace', '1-8::
    1s+2s dance Tourbillon:
::
    _1-4_   1s+2s 1/2 turn ptnrs 2H, 1M & 2L lead ptnrs by nearer hand 1
    place cl''wise to end 2s on Ladies side & 1s on Men''s side, 1s set to
    2s
::
    _5-8_   1s+2s 1/2 turn ptnrs 2H & lead ptnrs on 1 place clockwise &
    1s+2s cross RH to own sides. 3 1 2
9-16::
    2s+1s+3s Set+Link for 3 couples into lines across; all set, 1/2 turn
    person opposite 2H & pull back RSh to face »out«
17-24::
    All chase clockwise 1/2 round into lines of 3 across; All Set+Link
    for 3 couples to end on sides. 3 (1) 2
25-32::
    All circle 6H round & back but Bars 27-28: 1s change places turning
    3/4 RH rejoining circle back to right. 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6881, '2013-08-21 08:31:32.085235+00', '2023-02-04 01:21:55.948365+00', 5326, 3, NULL, 'ace', '1-8::
    1s set & 1/2 turn 2H to face 2s, set & 1/2 turn 2s (1M+2L turn RH,
    1L+2M turn LH) to end in 2nd place on opposite sides. 2 (1) 3
9-16::
    2s+1s+3s Adv+Ret 2 steps & circle 6H round 1/2 way to left. (3) 1
    (2)
17-24::
    1s pass LSh, dance 1/2 RSh reels of 4 with 1st corners; pass LSh,
    dance 1/2 RSh reel of 4 with 2nd corners, end in 2nd place opp
    sides.  2 (1) 3
25-32::
    1s dance 1/2 Fig of 8 round 3s & 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (14680, '2022-03-07 02:21:16.37535+00', '2023-02-04 01:21:55.980579+00', 20400, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link; 2s+1s dance RH across. 2 1 3
9-16::
    2s+1s Set+Link; 1s+2s dance RH across. (1L finishes facing out) 1 2
    3
17-24::
    1L followed by 1M dances behind 2L, up between 2s, behind 2M, across
    to 2nd place own side  2 1 3
25-32::
    2s+1s+3s dance 6 bar reels of 3 on sides (1s RSh to 3s), 1s+3s
    change places RH.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6882, '2013-08-21 08:31:32.093292+00', '2023-02-04 01:21:56.050672+00', 5330, 3, NULL, 'ace', '1-8::
    1s & 4s set & cast in 1 place, 1s & 4s dance 1/2 Figs of 8 round new
    end couples
9-12::
    1M+4M & 1L+4L cross (men making an arch) & turn corners with free
    hand to face up/down
13-16::
    1s+4s dance down/up (couple dancing up make the arch) & turn corners
17-24::
    Repeat bars 9-16 from new positions
25-32::
    1s+4s dance 1/2 R&L, turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (14567, '2022-01-26 17:28:47.2898+00', '2022-01-27 13:12:41.243478+00', 20513, 1, 202, 'ace', '_Strathspey_
1--::
  1c+2c *Rose Progression* : 1W+2M change place RH | chase 1 place clw ; turn BH ½, face and cast away while{8} 1M+2W set | turn BH ½, face and cast away | chase 1 place clw (2,1,3)
9--::
  Circle6 and back (2,1,3)

_Reel_

17--::
  All W Advance | set (P do not set) ; dance RSh round P to places (2,1,3)
25--::
  All M repeat [17-24] (2,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (4018, '2013-08-21 08:30:42.000531+00', '2023-02-04 01:18:27.928012+00', 11156, 3, NULL, 'ace', '1-8::
    1s set advancing, turn 2H, 1s+2s Set+Link
9-16::
    2s+1s+3s dance reels of 3 on sides (1s give LSh to 3s to start)
17-24::
    2s+3s (nearer hands joined with partner facing down/up) set, dance
    RH across & 2s+1s+3s turn partner RH
25-32::
    1s dance Figs of 8 (Man up & Lady down)', 0);
INSERT INTO 'dancecrib' VALUES (13389, '2020-12-02 01:18:34.854336+00', '2023-02-04 01:18:35.082608+00', 19147, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link; 1s+3s Set+Link
9-16::
    3s+1s  dance the Knot
17-24::
    2s+1s dance 1/2 Poussette; 1s dance down between 2s (2s step up
    21-22), cast behind 3s (3s step up 23-24) to 3rd place own side
25-32::
    2s+3s+1s dance DoSiDo with partner; 2s+3s+1s turn partner 2H', 0);
INSERT INTO 'dancecrib' VALUES (6883, '2013-08-21 08:31:32.101477+00', '2023-02-04 01:21:56.079247+00', 8522, 3, NULL, 'ace', '1-8::
    5s dance reel of 4 with 2s & 4s (2s & 4s in prom hold)
9-16::
    1s+5L also 3s+5M dance RH across, 5s pass RSh to dance LH across
    with opposite couple & end passing LSh to original places
17-24::
    4s+5s petronella turn to face partner in line across & set, 4s+5s
    dance 1/2 reel of 4 to end with 5s in 4th places & 4s in centre
    facing each other
25-32::
    4s turn (with suitable Highland steps) _while_ others circle 8H
    round & back

{{explanation}}
4s Repeat with 1s+3s leaving 3s in centre, 3s repeat with 2s+4s leaving 2s in centre, 2s repeat with 1s+3s leaving 1s in centre & 1s repeat with 2s+5s leaving 5s in centre', 0);
INSERT INTO 'dancecrib' VALUES (13092, '2020-08-10 00:20:58.254073+00', '2023-02-04 01:21:56.101695+00', 5332, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+4s dance Fig 8 on own sides round 2s+3s (1s dance in down, 4s
    dance in/up to start)
9-12::
    All dance 2 changes of place (as Grand Chain), 2 steps per hand (1s
    & 4s cross with partner to start). 3 (1) (4) 2
13-16::
    2s turn RH _while_ 3s+1s+4 continue Grand Chain, 1 step to each
    hand. (4s in 3rd place cross, 1s+3s change places on side to start)
    1 4 3 2

{{title}}
Reel

1-8::
    All circle 8H round & back
9-12::
    1s+4s dance LH across _while_ 3s+2s dance RH across once round
13-16::
    Dancers change places in hands across:
::
    _13_    4M & 3M pass to dance in other hands across
::
    _14_    1M & 2M pass to dance in other hands across
::
    _15_    1L & 2L pass to dance in other hands across
::
    _16_    4L & 3L pass to dance in other hands across.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (10092, '2017-09-03 23:45:15.372038+00', '2023-02-04 01:21:56.286552+00', 16190, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast down/up 1 place (2s+3s step down/up 3-4),
    1s+4s dance RH across, pull back RSh to face 1st corners
9-16::
    Diagonal reels of 4:
::
    2s+3s dance 8 bars of diag reel, dancing 1/2 LH across in centre
    instead of passing LSh
::
    1s+4s dance 1/2 diag reel of 4 with 1st corners, pass LSh in centre
    & dance 1/2 diag reel of 4 with 2nd corner pstns
17-24::
    RSh reels of 4 on sidelines (1s+4s start from centre).  All end on
    sidelines, 1s+4s facing out
25-32::
    2s+4s also 1s+3s dance double Figs 8 across (2s+3s cross, 1s+4s cast
    to start)', 0);
INSERT INTO 'dancecrib' VALUES (9925, '2017-06-05 11:31:37.520495+00', '2023-02-04 01:21:56.313072+00', 16492, 3, NULL, 'ace', '1-8::
    2s+3s circle 4H round to Left.  2s dance up, cast to 2nd place
    _while_ 3s dance down, cast up to 3rd place
9-16::
    2s+3s dance RH across.  1s+2s also 3s+4s dance LH across
17-24::
    Reels of 4 on sides (1s+2s & 3s+4s pass LSh to start)
25-32::
    1s+2s change places LH, 1s+3s change places RH, 1s+4s change place
    LH.  All set', 0);
INSERT INTO 'dancecrib' VALUES (6884, '2013-08-21 08:31:32.109608+00', '2023-02-04 01:21:56.342195+00', 12893, 3, NULL, 'ace', '1-8::
    1s advance, touch hands & cast 1 place, 1s dance 1/2 Reel of 3 on
    sides (1s in & down to start)
9-16::
    1s advance, touch hands & cast 1 place, 1s dance 1/2 Reel of 3 on
    sides (1s in & up to start)
17-24::
    1s+2s+3s Promenade finishing with 1s & 2s in centre
25-32::
    1s+2s dance Poussette.  (2nd time through all 3 couples dance
    Poussette)', 0);
INSERT INTO 'dancecrib' VALUES (6885, '2013-08-21 08:31:32.120134+00', '2023-02-04 01:21:56.367904+00', 14707, 3, NULL, 'ace', '1-8::
    All dance interlocking reels of 4 (all pass partner RSh, next person
    LSh & following person RSh) & end with hands joined with corners
9-16::
    All Set+Link with corners, All advance 1 step with corner & retire 1
    step with next person (to end in a square) & set
17-24::
    1s+3s (sides) dance 1/2 R&L, 2s+4s (top & bottom) dance 1/2 R&L
25-32::
    All Set+Link with corners, All advance 1 step with corner & retire 1
    step with partner (to end in a square) & set
33-40::
    Ladies dance in front of partner & behind next Man, then dance 3/4
    RH across & turn partner LH into RH across joined NH with partner
41-44::
    All dance RH across 1/4 way then change places with partner & dance
    another 1/4 RH across (Men in centre)
45-48::
    All dance another 1/4 RH across then Men dance out followed by
    partners to end 1/2 way round set
49-56::
    All dance double Men''s Chain & end Ladies facing out
57-64::
    All dance 1/2 Schiehallion reel & end in original places
::
    Repeat in reel time but in bars 13-16 & 29-32 all advance 2 steps &
    retire 2 steps & omit setting.', 0);
INSERT INTO 'dancecrib' VALUES (8188, '2014-02-10 10:26:52.839549+00', '2023-02-04 01:21:56.396697+00', 15030, 3, NULL, 'ace', '1-8::
    1s cast & dance 1/2 Fig of 8 round 3s
9-16::
    All advance 1 step & set (LF then RF) & retire 1 step, all turn 2H
    to own sides (1s 1.1/2 times) & 1s end facing down as 3s face up
17-24::
    All dance 1/2 Grand Chain (2s cross to start), all chase clockwise
    to own sides
25-32::
    All dance 3 couple knot', 0);
INSERT INTO 'dancecrib' VALUES (6886, '2013-08-21 08:31:32.128211+00', '2023-02-04 01:21:56.416233+00', 10080, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s cross down/up RH, 1M+4L & 1L+4M lead out LH cross & cast to
    4th/1st places, 1s & 4s repeat back to places
9-16::
    1s+2s also 3s+4s dance RH across, 2s+3s dance LH across
17-24::
    All dance reels of 4 on sides
25-28::
    1s & 4s set & cross down/up to 2nd/3rd places _while_ 2s & 3s cross
    RH & cast up/down to 1st/4th places
29-32::
    2s & 3s turn partners 2H 1.1/2 times _while_ centre persons on sides
    (1L+4M & 1M+4L) also turn 2H 1.1/2 times to end 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (6887, '2013-08-21 08:31:32.137927+00', '2023-02-04 01:21:56.431353+00', 12894, 3, NULL, 'ace', '1-8::
    1s set, cast & dance RH across with 3s
9-16::
    1s cross down between 3s, cast up to 2nd place opposite side & turn
    RH 1.1/4 times to 1L facing up with 1M behind her
17-24::
    1L followed by partner dances reel of 3 across with 2s (RSh to 2L)
    to end in 2nd place own sides
25-32::
    1s dance RSh reels of 3 on sides giving RSh to 3s', 0);
INSERT INTO 'dancecrib' VALUES (6888, '2013-08-21 08:31:32.144144+00', '2023-02-04 01:21:56.440127+00', 9880, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s cross RH, cast in 1 place (2s+3s step up/down) & dance 1/2
    Figs of 8 round end couples.  2 1 (4) (3)
9-16::
    1s & 4s dance Ladies'' Chain
17-24::
    1L with 2s & 4L with 3s dance RH across, 1M with 2s & 4M with 3s
    dance LH across
25-32::
    1s+4s dance 1/2 R&L (omit polite turn) & dance 1/2 RSh reels of 4 on
    sides.  (3) (1) 4 2
33-40::
    All set, cross RH & all circle 8H round to left 1/2 way to end  2 4
    (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (4060, '2013-08-21 08:30:42.886569+00', '2023-02-04 01:18:30.827678+00', 221, 3, NULL, 'ace', '1-8::
    1s+2s+3s 1/2 turn RH, twirl & dance out to opposite sides & repeat
    back to place
9-16::
    1s+2s+3s circle 6H round & back (1s end in centre facing down & 3s
    in centre facing up)
17-24::
    1s+3s dance R&L (up & down) & end back on own sides
25-32::
    1s+2s dance the Tournee:
::
    1s+2s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 2s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (2s RH, 1s LH) & dance
    out to places', 0);
INSERT INTO 'dancecrib' VALUES (4061, '2013-08-21 08:30:42.905383+00', '2023-02-04 01:18:30.969872+00', 222, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s set & cast Lady up & Man down to end in
    lines across (1L between 2s facing down & 1M between 3s facing up)
9-16::
    1s+2s+3s Adv+Ret & circle 6H round to the left, 1s end facing 1st
    corners
17-24::
    1s set & turn 1st corners, set to 2nd corners & turn partner 2H to
    end 2nd place own sides
25-32::
    2s+1s circle 4H round to left & 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (9173, '2016-06-16 22:41:29.117772+00', '2023-02-04 01:18:35.112304+00', 16833, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to top, finish facing out
9-16::
    Reflection (Mirror) reels of 3 on sides,  1s out and down, 2s in and
    up, 3s cast to begin. 1s finish facing out
17-24::
    1s+2s dance 3/4 double Fig of 8 1s casting, 2s cross up to start.
    1s cross RH
25-32::
    2s+1s+3s dance circle 6 hands round and back.', 0);
INSERT INTO 'dancecrib' VALUES (6889, '2013-08-21 08:31:32.152337+00', '2023-02-04 01:21:56.456543+00', 12454, 3, NULL, 'ace', '1-8::
    1M crosses down to dance Fig of 8 round 2L+1L _while_ 2M crosses
    down to dance Fig of 8 round 3L+2L _while_ 4L crosses up to dance
    Fig of 8 round 3M+4M _while_ 5L crosses up to dance Fig of 8 round
    4M+5M all returning to places
9-16::
    1M also 3L followed by partners cast down 1 place & cross to
    opposite side, 2s+1s also 3s+5s dance LH across
17-24::
    1s & 3s set advancing & turn right about, 1s & 3s dance 6 bars of
    Double Triangles
25-32::
    1s & 3s dance out own sides & cast 1 place, all set & turn partners
    RH.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (6891, '2013-08-21 08:31:32.275452+00', '2023-02-04 01:21:56.707025+00', 10116, 3, NULL, 'ace', '1-8::
    1s set & cross down to 2nd place opp sides (no hands), 1s+3s dance
    1/2 R&L (RH on sides to start).  2(3)1
9-16::
    3s+1s set (down/up), 1s dance up making an arch & cross as 3s dance
    under & cross to other side & loop round, 1s+3s set (across).  2(1)3
17-24::
    2M+1L & 2L+1M set (across), 2M+1L & 2L+1M dance across with arch
    made by 2L+1M crossing & loop round to 1s facing down 2s up & set 1
    (2)3
25-32::
    1L+2L turn LH1.1/2 times as partners dance cl''wise 1/2 way to line
    up/down (RH to partner), Bal-in-Line & 3/4 turn partner RH.  2(1)3
33-40::
    1s dance round 4th corner to 2nd place own side & 2s+1s+3s Adv+Ret', 0);
INSERT INTO 'dancecrib' VALUES (6892, '2013-08-21 08:31:32.283883+00', '2023-02-04 01:21:56.721208+00', 5345, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+3s dance DoSiDo, all set to corners & turn RH
17-24::
    2s+4s dance DoSiDo, all set to corners & turn RH
25-32::
    1L+3L change places RH, 1s set to new partners HS & turn 2H
33-40::
    1L+3L change back to places, HS to partners & turn 2H
41-56::
    2s+4s repeat bars 25-40
57-64::
    1s+3s dance RH across, 2s+4s dance LH across to end in longwise set
    with corners
65-72::
    All dance reels of 4 to end in original places
73-80::
    All dance Grand Chain', 0);
INSERT INTO 'dancecrib' VALUES (6893, '2013-08-21 08:31:32.291869+00', '2023-02-04 01:21:56.740023+00', 8508, 3, NULL, 'ace', '1-8::
    1L+2M set, 1L casts 1 place, crosses up & casts to 2M place _while_
    2M casts up, crosses down & casts up to 1L place (dancing couple
    pass RSh)
9-16::
    1M+2L set, 1M casts 1 place, crosses up & casts to 2L place _while_
    2L casts up, crosses down & casts up to 1M place (dancing couple
    pass RSh)
17-24::
    2s+1s dance 1/2 R&L & turn partner RH
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6894, '2013-08-21 08:31:32.301561+00', '2023-02-04 01:21:56.85344+00', 5347, 3, NULL, 'ace', '1-8::
    1s cast 1 place, turn 2H, 2s repeat this Fig back to places
9-16::
    1s clap, cast 1 place, 2s+1s cross RH, 2s+1s dance 1/2 R&L with full
    LH turn on sides
17-24::
    2s+1s dance RH across, 1s+3s dance LH across end ready for Grand
    Chain
25-32::
    2s+1s+3s dance Grand Chain', 0);
INSERT INTO 'dancecrib' VALUES (13329, '2020-11-02 01:21:26.895765+00', '2023-02-04 01:21:56.87088+00', 15097, 3, NULL, 'ace', '{{explanation}}
Circle, Man has Lady on his right

1-8::
    All Adv+Ret twice
9-16::
    Ladies dance round partner (retain hands); Men dance round partner
    (retain hands). Couples face anticlockwise, Lady on Man''s right
17-20::
    All dance forward 2 steps, change sides with partner (Lady in front
    of Man)
21-24::
    All change side again (Man in front of Lady), all pull back RSh to
    form circle, Lady on Man''s right
25-32::
    Slip-step to left (3 bars), pull back LSh to join hands in circle
    again; slip-step right (4 bars)

{{explanation}}
Note:	To make dance progressive Bars 23-24: Man finishes with original partner on his left, ready to dance with new partner on his right', 0);
INSERT INTO 'dancecrib' VALUES (11370, '2018-12-10 12:29:18.046909+00', '2023-02-04 01:21:56.893425+00', 5350, 3, NULL, 'ace', '1-8::
    1s set, turn almost 3/4 RH moving down (2s step up 3-4); 1s+3M dance
    RH across. 1s end in 2nd place opp sides
9-16::
    2s set, turn almost 3/4 LH moving down (1s step up 11-12); 1s+3L
    dance LH across. 2s end in 2nd place opp sides.  (1) (2) 3
17-24::
    1s+2s set, 1s dance down in prom hold, cross, cast up round 3s to
    1st place own side _while_ 2s cast up, dance down in prom hold,
    cross & cast up round 3s to 2nd place own side.  1 2 3
25-32::
    1s+2s dance Chain Progression:
::
    _25-26_   1s & 2s 3/4 turn RH
::
    _27-30_   1M+2L turn LH 1.1/2 times _while_ partners chase clockwise
    1/2 way
::
    _31-32_   2s & 1s 3/4 turn RH to end on sides in order 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6895, '2013-08-21 08:31:32.309683+00', '2023-02-04 01:21:57.04598+00', 5351, 3, NULL, 'ace', '1-8::
    1M leads 3L up to top (2L steps down), 1M dances round to place as
    3L casts to 2nd place, 1L with 3M repeat
9-16::
    3s followed by 1s dance down the middle, 1s dance up to top _while_
    3s dance up & turn RH to original places
17-24::
    1s cast 1 place, lead down between 3s & cast up to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4062, '2013-08-21 08:30:42.919368+00', '2023-02-04 01:18:31.136154+00', 223, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s lead down 1 place, cross between 2s & dance down behind 3s, cross
    LH & dance down behind 4s to bottom of set
17-24::
    1s lead up 1 place, cross between 4s & dance up behind 3s, cross LH
    & dance up behind 2s to top places
25-32::
    1s+2s dance R&L
33-40::
    1s+2s dance RH across 1/2 way & set, 1s+3s dance LH across 1/2 way &
    set
41-48::
    1s+4s dance RH across 1/2 way & all 4 couples set, all turn partners
    RH 1.1/2 times to own sides', 0);
INSERT INTO 'dancecrib' VALUES (13035, '2020-08-10 00:18:29.964432+00', '2023-02-04 01:18:35.17169+00', 13709, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up); all 4 couple set, 2s 1/2 turn RH &
    retain hands _while_ 1s+3s+4s cross RH
9-16::
    2s continue turning 1/2 RH to own side, 2s+1s dance 1/2 RH across;
    1s+2s+3s chase clockwise 1/2 round.  3 2 (1) (4)
17-24::
    All circle 8H round & back
25-32::
    2s+1s+4s (bottom 3 couples) chase anticlockwise 1/2 round; 1s+2s
    dance 1/2 LH across, 1s continue 1/2 turn LH to own sides. 3 4 2 1', 0);
INSERT INTO 'dancecrib' VALUES (14915, '2022-06-27 00:21:30.244744+00', '2023-02-04 01:21:57.077875+00', 16576, 3, NULL, 'ace', '1-4::
    1s NHJ dance down (2 steps), face each other & set
5-8::
    1M dances down & casts up to 2nd place own side _while_ 1L dances up
    & casts to 2nd place own side, 1s turn LH to face 2nd corners (2s
    step up 7-8)
9-12::
    1s dance 1/2 RSh reel of 4 with 2nd corners & turn LH to face 1st
    corners
13-16::
    1s dance 1/2 RSh reel of 4 with 1st corners & end 1M between 2s (in
    3rd place) facing up, 1L between 3s (in 1st place) facing down
17-24::
    Lines of 3 across dance Set+Link for 3 twice to end 1M between 2s
    (in 1st place), 1L between 3s (in 3rd place)
25-32::
    1s set advancing, turn 3/4 RH to face down (1L on 1M''s left); 1s+3s
    turn 1.1/2 to change places (1M+3M RH, 1L+3L LH). 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6896, '2013-08-21 08:31:32.472071+00', '2023-02-04 01:21:57.280231+00', 5354, 3, NULL, 'ace', '{{title}}
Part 1

1-8::
    All turn RH 1.1/4 times to form St Andrews Cross with Men in centre
    LH joined & RH with partner, all set, Men drop LH & turn partner
    into middle, Ladies  1/2 LH across _while_ Men dance clockwise to
    meet them
9-16::
    All turn RH to Men in centre & repeat back to places
17-24::
    All turn corners RH, partners LH, corners RH & partners LH
25-32::
    1s+3s dance Ladies Chain
33-40::
    2s+4s dance Ladies'' Chain

{{title}}
Part 2

1-8::
    All 1/2 Grand Chain & set to partner
9-16::
    Repeat back to places
17-24::
    All turn corners, partners, corners & partners
25-32::
    1s & 3s (RH with partner) Adv+Ret & cross (Men pass LSh) to end in
    opposite places with Ladies on Men''s right
33-40::
    All face corners, set, turn 2H, 1s+3s 1/2 R&L back to original
    places
41-56::
    2s & 4s repeat bars 25-40
57-64::
    All turn corners, partners, corners & partners
65-72::
    Al dance 1/2 Grand Chain & set to partner
73-80::
    Repeat back to places

{{title}}
Part 3

1-8::
    All 3/4 turn RH to Ladies in centre LH joined & RH with partner,
    set, turn Men in, set & turn to face partner
9-16::
    1s+3s dance reel of 4 _while_ others turn RH & LH (Tulloch hold)
17-24::
    2s+4s dance reel of 4 _while_ others turn (Tulloch hold)
25-32::
    All turn corners, partners, corners & partners
33-40::
    All Promenade anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (6897, '2013-08-21 08:31:32.480687+00', '2023-02-04 01:21:57.294443+00', 5355, 3, NULL, 'ace', '{{explanation}}
3s and 4s start on opposite sides

1-8::
    1s and 4s set, ½ turn partners LH, 1L followed by partner dances
    down, out between 2M+3L, 1L casts to 4th place as 1M casts back to
    place _while_ 4L followed by partner dances up, out between 2L+3M,
    4L casts up to 1st place as 4M casts back to place
9-16::
    1M+4L double Fig of 8 with 2s at top (1M+4L cross down, 2s dance up)
    _while_ 1L+4M double Fig of 8 with 3s at bottom (1L+4M cross up,3s
    dance down)
17-24::
    1M+4L also 1L+4M set, change places RH, all set, 4L and 1L dance
    across to other side between 2s+3s (who cast up/down to 1st/4th
    place) _while_ 1M and 4M dance across to end BtoB facing partners 1s
    on Men''s side, 4s on Ladie''s side
25-32::
    1s+4s RSh reel of 4 across and end with Men giving RH in passing and
    LH to partner so that 1s face up and 4s down (in line across Men in
    centre)
33-40::
    1s+4s in line rotate clockwise ½ way, 1L dances down between 3s and
    casts up to 3rd place as 4L dances up and casts to 2nd place _while_
    Men continue to rotate to new places (opposite partners)
41-48::
    All circle 8H round and back', 0);
INSERT INTO 'dancecrib' VALUES (6898, '2013-08-21 08:31:32.49038+00', '2023-02-04 01:21:57.370635+00', 5358, 3, NULL, 'ace', '1-8::
    1s set twice to 2L & circle 3H round to left
9-16::
    1s set twice to 2M & circle 3H round to left
17-24::
    1s lead down the middle & back ready for Allemande
25-32::
    1s+2s dance Allemande, 1s end facing 1st corners
33-40::
    1s turn 1st corners RH, partner LH, 2nd corners RH & partner LH to
    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13434, '2020-12-02 01:21:21.098334+00', '2023-02-04 01:21:57.389526+00', 17795, 3, NULL, 'ace', '1-8::
    Ladies dance Fig 8 RSh in front of & round corner, LSh in front of &
    round partner back to place
9-16::
    All Ladies dance LH across & RH across _while_ Men chase
    anticlockwise round back to original places
17-24::
    Men dance Fig 8 LSh in front of & round corner, RSh in front of &
    round partner back to place
25-32::
    All Men dance RH across & LH across _while_ Ladies chase clockwise
    round back to original places
33-48::
    1M+corner NHJ & 3M+corner NHJ Adv+Ret, then they dance R&L; all turn
    partners RH
49-64::
    2M+corner NHJ & 4M+corner NHJ Adv+Ret, then they dance R&L; all turn
    partners RH.  Ladies face out
65-80::
    All dance Schiehallion reel
81-88::
    All circle 8H round & back

{{explanation}}
Note:	No polite turns in R&L', 0);
INSERT INTO 'dancecrib' VALUES (6899, '2013-08-21 08:31:32.498496+00', '2023-02-04 01:21:57.419598+00', 5359, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    All dance RSh reels of 4 on side 1s & 4s omitting last LSh pass &
    curve round to face person just passed.  2 4 1 3
17-24::
    2s+4s also 1s+3s set on sides (HS for Men & Glasgow Highlander step
    for Ladies) & turn twice with 2H
25-32::
    4s & 1s set on sides, petronella turn into centre, 1M & 4M set
    _while_ ptnrs dance round each other to face ptnr & Petronella turn
    to sides.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (6900, '2013-08-21 08:31:32.506526+00', '2023-02-04 01:21:57.439486+00', 10182, 3, NULL, 'ace', '1-8::
    All Adv+Ret & turn partner RH
9-16::
    All dance 4 couple Allemande.  (4 3 2 1)
17-24::
    4s+3s also 2s+1s dance double Fig of 8 (4s & 1s casting down/up to
    start)
25-32::
    All dance 1/2 reel of 4 on sides (4s & 2s in & down to start), 1s
    lead down to 4th place as others step up on last 2 bars', 0);
INSERT INTO 'dancecrib' VALUES (6901, '2013-08-21 08:31:32.516059+00', '2023-02-04 01:21:57.542083+00', 5362, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All Adv+Ret twice
9-16::
    Clap 3 times, beat with heel 3 times, all advance passing opposite
    couple RSh', 0);
INSERT INTO 'dancecrib' VALUES (13330, '2020-11-02 01:21:27.594809+00', '2023-02-04 01:21:57.558582+00', 14720, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance RSh reels of 3 on sides, Bars 7-8: 1L crosses to
    Man''s side through 2M''s place to top, 1M crosses set at top to 1L''s
    place
9-16::
    1s+2s+3s repeat 1-8, all back to original places
17-24::
    1s+2s dance RH across; 1s+2s dance LH across to finish in line,
    facing partner 2H joined (1st corner diagonal, 1L&2M BtoB in centre)
25-32::
    1s+2s dance "Hello-Goodbye Poussette":
::
    _25-26_   All set (start right foot) moving on 2nd step into line
    across (1M+2L BtoB)
::
    _27-28_    Repeat, moving on 2nd step into line on 2nd corner
    diagonal (1L+2M BtoB)
::
    _29-30_    Repeat, moving on 2nd step into line up/down centre
    (2L+1M BtoB)
::
    _31-32_    2s+1s Petronella turn to own side.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14560, '2022-01-22 13:58:32.060027+00', '2022-01-26 16:33:15.294449+00', 20635, 1, 202, 'ace', '1--::
  1c+3c Adv (2 PdB) | Circle4 L | Ret (2 PdB)
9--::
  2c+4c repeat [1-8] (1,2,3,4)
17--::
  All turn P LH and face P BHJ ; *Square Set Poussette Progression* : all starting L foot for M, R foot for W (PdB) are changing one place cclw as follows. 21: one step to square corner, 22: ¼ turn on spot clw. 23: one step to new places. 24: one PdB, M dancing backward, W on spot (2,3,4,1)
25--::
  Gr-Chain, M clw, 1 bar per hand (2,3,4,1)
33--::
  All turn P RH 1½ ; all birl (2,3,4,1)

*Deviser''s note* : bars 3-6 change each time through. 2nd time through: RHA, 3rd time through LHA, 4th time through Circle4 R.', 5);
INSERT INTO 'dancecrib' VALUES (6902, '2013-08-21 08:31:32.524128+00', '2023-02-04 01:21:57.581351+00', 5364, 3, NULL, 'ace', '1-8::
    1s take prom hold, dance down behind 2M+3M, cross the set & dance up
    behind 3L+2L to top, 1M passes partner in front to finish on his
    Left
9-16::
    1s lead down the middle & back to top, 2s step in ready for …
17-24::
    1s+2s dance Allemande, 1s end facing 1st corners
25-32::
    1s 3/4 turn 1st corners RH, set to partner up/down, 3/4 turn 2nd
    corners LH & set to partner up/down
33-40::
    1s lead out between 2L+3L, cross & cast (1L up, 1M down), meet in
    centre & dance out of Men''s side & cast up/down, dancing into 2nd
    place own sides', 0);
INSERT INTO 'dancecrib' VALUES (12418, '2019-12-05 01:31:35.100452+00', '2023-02-04 01:21:57.631367+00', 5374, 3, NULL, 'ace', '1-8::
    1s set twice; turn RH & cast to face 1st corners (2s step  up 7-8)
9-16::
    "St Andrew''s Cross Reels":
::
    1s+1st corners dance RSh diagonal reel of 4 _while_ 2nd corners
    follw path of a reel of 4 on other diagonal passing each other LSh
    in centre (bars 10 & 14). 1s end in 2nd place on opp sides. 2 (1) 3
17-24::
    1s set twice, turn RH twice to face 2nd corners
25-32::
    "St Andrew''s Cross Reels":
::
    1s+2nd corners dance RSh diagonal reel of 4 _while_ 1st corners
    follw path of a reel of 4 on other diagonal passing each other LSh
    in centre (bars 26 & 30). 1s end facing 1st corners
33-40::
    1s set to & turn 1st corners 2H, set to & turn 2nd corners 2H, 1s
    finish between corners
41-48::
    1s dance reels of 3 on opp sides passing 1st corner LSh to start. 1s
    cross to 2nd place own side to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6904, '2013-08-21 08:31:32.542088+00', '2023-02-04 01:21:57.717803+00', 5376, 3, NULL, 'ace', '1-8::
    1s petronella turn into middle & set, petronella turn to 2nd place
    opposite sides & set (2s step up 5-6)
9-16::
    2s+1s+3s circle 6H round & back
17-24::
    2s+1s+3s advance for 2 steps & retire; 1s 1/2 turn RH to own sides &
    2s+1s+3s clap (one, two, three; one, two, three)
25-28::
    2M+1M+3M also 2L+1L+3L circle 3H round to the Left on own sides', 0);
INSERT INTO 'dancecrib' VALUES (6905, '2013-08-21 08:31:32.550072+00', '2023-02-04 01:21:57.741525+00', 14953, 3, NULL, 'ace', '1-8::
    All dance RSh reels of 4 on own sides
9-16::
    1M+2L change places RH & 1L+2M change places LH, 1M+3M change places
    LH & 1L+3L change places RH
17-24::
    1M+4L change places RH & 1L+4M change places LH, all cross RH & set
25-32::
    3s+4s (middle couples) dance R&L ending with 3s facing up & 4s
    facing down', 0);
INSERT INTO 'dancecrib' VALUES (6906, '2013-08-21 08:31:32.55978+00', '2023-02-04 01:21:57.777179+00', 5377, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s set, cast to 4th place & cross LH
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1s lead up to top & cast (4 bars) to 2nd place
25-32::
    1s+3s dance 1/2 R&L, 1s cross RH & cast to bottom', 0);
INSERT INTO 'dancecrib' VALUES (6907, '2013-08-21 08:31:32.567877+00', '2023-02-04 01:21:57.804008+00', 5378, 3, NULL, 'ace', '1-8::
    1s set, cross RH, set to 2s on sides & change places LH & end facing
    1st corners
9-16::
    1s+1st corners Adv+Ret (1 step) passing LSh, repeat passing RSh &
    dance 1/2 RSh reel of 4 ending facing 2nd corners
17-24::
    1s+2nd corners Adv+Ret (1 step) passing LSh, repeat passing RSh,
    dance 1/2 RSh reel of 4 ending 2nd place on opposite sides
25-32::
    3s+1s+2s Adv+Ret (1 step), set & circle 6H round to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6909, '2013-08-21 08:31:32.587295+00', '2023-02-04 01:21:57.867095+00', 11690, 3, NULL, 'ace', '1-16::
    1s dance in & cast 1 place, 2s+1s+3s dance 3 couple R&L
17-24::
    1s dance 1/2 Figs of 8 (1L round 2s, 1M round 3s), 1s dance 1/2 Figs
    of 8 (1M round 2s, 1L round 3s)
25-32::
    1s dance reels of 3 on own sides (1L RSh to 2L, 1M RSh to 3M)', 0);
INSERT INTO 'dancecrib' VALUES (14130, '2021-07-07 00:20:57.109973+00', '2023-02-04 01:21:58.024773+00', 20082, 3, NULL, 'ace', '1-4::
    1s & 3s Petronella turn & set
5-16::
    Dance to Corners & Set (Diamond figure) 12 bars:
::
    1s & 3s pass partner RSh, 3M to face 2L & 1L to face 2M _while_ 2s
    set; repeat twice more to end with 3s & 1s in centre facing partner,
    Men facing down, Ladies facing up
17-24::
    3s+1s dance 1/2 LSh reel of 4 (up/down); 1s+3s turn partner 3/4 LH
    to  own side.  1 (2) 3
25-32::
    1s cross RH, 1s+2s change places LH on sides; 2s+1s cross RH with
    partner, set to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9749, '2017-04-06 08:40:09.141046+00', '2023-02-04 01:21:58.037509+00', 12437, 3, NULL, 'ace', '1-8::
    1s lead down (2s step up 3-4), 1L turns under 1M''s right arm, 1s
    lead up to 2nd place finishing BtoB facing opp sides
9-16::
    Set as in Double Triangles, all advance (PdB) to invert triangle,
    set, invert triangle to end 2s+3s on own sides turning Right about
    to face in _while_ 1s finish BtoB facing out
17-24::
    1s turn 1st corners RH, pass RSh, turn 2nd corner RH, pass RSh to
    end in 2nd place own sides
25-32::
    2s+1s+3s circle 6H round to left (6 steps), bar 28 pass R foot over
    L, pivot and chase anticlockwise to own sides', 0);
INSERT INTO 'dancecrib' VALUES (13435, '2020-12-02 01:21:21.514332+00', '2023-02-04 01:21:58.159825+00', 11661, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s
9-16::
    2s+1s Set+Link twice. 2 (1)
17-24::
    2s+1s dance Men''s Chain
25-32::
    2s+1s face up/down & set (no hands), set diagonally facing in; set
    to partner & 1s cross RH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (6910, '2013-08-21 08:31:32.595261+00', '2023-02-04 01:21:58.17782+00', 9881, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s dance Fig of 8 around 2s
9-16::
    1s dance down the middle & back

{{title}}
Reel

17-24::
    1s cast 1 place, turn RH to face 3L in prom hold, set & turn to face
    3M, set & turn to face 2M
25-32::
    Set & turn to face 2L, set & all turn RH with 1s ending in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (12628, '2020-03-02 01:51:19.306889+00', '2023-02-04 01:18:27.955515+00', 18244, 3, NULL, 'ace', '1-8::
    1s+2s dance "Chain and Turn":
::
    _1-2_    1M+2L 3/4 turn RH unto diag line 1M+2M, 1L+2L facing
::
    _3-4_    1M+2M also 1L+2L 1/2 turn LH, 1M end in 2M place & 2L in 1L
    place
::
    _5-8_    1L+2M turn RH 1.1/4 times to end in 1L in 2L place, 2M in
    1M place.  2 1 3
9-16::
    2s+3s dance R&L crossing RH on the sides to start _while_ 1s dance
    up between 2s & cast to 2nd place, dance down between 3s & cast up
    to 2nd place own sides
17-24::
    2s+3s Adv+Ret _while_ 1s dance RSh right around each other to finish
    back-to-back facing 1st corners; 1s set to 1st corner, set to 2nd
    corner & remain facing 2nd corner
25-32::
    1s dance 6 bar reels of 3 on opposite sides, RSh to 2nd corner to
    start. Bars 31-32 1s cross RH to own side 2nd place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4019, '2013-08-21 08:30:42.01715+00', '2023-02-04 01:18:27.976582+00', 13578, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 on sides (1s in & down to start)
9-16::
    1s dance down middle & back
17-24::
    1s turn 2s 1.1/2 times (Ladies RH, Men LH), all Adv+Ret
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4020, '2013-08-21 08:30:42.117927+00', '2023-02-04 01:18:28.12654+00', 160, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s circle 4H round & back
9-16::
    1s dance down between 4s who dance up to change places & all dance
    1/2 RSh reels of 4 on sides
17-24::
    1s+3s also 2s+4s dance 1/2 RH across, dance 1/2 RSh reels of 4 on
    sides & 2s+4s & 1s+3s dance 1/2 RH across
25-32::
    4s & 1s cast in 1 place, 4s & 1s dance 1/2 Fig of 8 round 2s/3s &
    cross back RH', 0);
INSERT INTO 'dancecrib' VALUES (4154, '2013-08-21 08:30:44.347729+00', '2023-02-04 01:18:37.224228+00', 8998, 3, NULL, 'ace', '1-8::
    1s lead down for 2 steps, 1/2 turn RH, lead up, cross & cast to 2nd
    place
9-16::
    1s 1/2 reel of 3 across (Lady up & Man down passing 1st corner LSh)
    into 1/2 reels of 3 on sides (end 3 1 2 on opp sides 3s facing down
    & 2s up)
17-24::
    2s & 3s Adv+Ret (up/down) _while_ 1s cast to right to end between
    2s/3s, 1s+2s+3s change places with person facing & set
25-32::
    2s & 3s Adv+Ret (across set) _while_ 1s cast to right to 2nd place
    opposite side, 2s+1s+3s cross RH & set', 0);
INSERT INTO 'dancecrib' VALUES (11708, '2019-03-18 21:02:44.132816+00', '2023-02-04 01:21:58.196217+00', 5385, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s+3s dance LH across
9-16::
    1s cross LH, cast up (2s step down); 1s+2s dance RH across
17-24::
    1s set & 1/2 turn 2H & face down on opp sides; 1s+2s set & 1/2 turn
    2H.  2 1 3
25-32::
    2s+1s+3s circle round to left (6 bars), 1s cross RH to end in 2nc
    place own side', 0);
INSERT INTO 'dancecrib' VALUES (6911, '2013-08-21 08:31:32.603293+00', '2023-02-04 01:21:58.223393+00', 5384, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance RSh reels of 3 on own side
9-16::
    1M+2L turn RH, 1L+2M turn LH
17-24::
    1s cross RH, cast down 2 places, cross LH & cast up 1 place (2s step
    up 19-20)
25-32::
    1s+3s dance RH across.  2s+1s dance LH across', 0);
INSERT INTO 'dancecrib' VALUES (6912, '2013-08-21 08:31:32.609497+00', '2023-02-04 01:21:58.246183+00', 10108, 3, NULL, 'ace', '1-8::
    All 1/2 turn partner RH, turn next person LH once round & 1/2 turn
    partner RH
9-16::
    1s+3s dance 1/2 Ladies'' Chain, 1L+3L 3/4 turn RH to face side
    couples & set
17-24::
    1L & 3L dance out through arches made by 2s & 4s back to places
    _while_ 1M & 3M dance into centre & dance out to meet partners
25-32::
    All Promenade anticlockwise 3/4 round to end 4 1 2 3
::
    Repeat with new top couple', 0);
INSERT INTO 'dancecrib' VALUES (6913, '2013-08-21 08:31:32.617902+00', '2023-02-04 01:21:58.277846+00', 5387, 3, NULL, 'ace', '1-8::
    2s set, cross RH & dance 1/2 reels of 3 on sides (2L dance out & up
    _while_ 2M dances out & down to start) ending in triangle formation
    with 1s at bottom, 2M+3L on Ladies side & 3M+2L on Men''s side
9-16::
    All set with Men stepping in to face (triangular) partner, set again
    with Men dancing out to end on right of ''partner'', repeat with
    Ladies dancing in & ending on ''partners'' left
17-24::
    All circle 6H round & back 3s ending in 1st places & 2s in 2nd
    places
25-32::
    3s+1s set to each other (down/up) & 3M+1M also 3L+1L 1/2 turn LH,
    1s+3s dance RH across
33-40::
    All dance Grand Chain (1s cross to start), 2s cross RH _while_ 1s+3s
    change places on sides.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6914, '2013-08-21 08:31:32.625961+00', '2023-02-04 01:21:58.304933+00', 5386, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 3/4 turn RH to end between 2s/3s (1L
    facing up between 2s, 1M down between 3s) & Bal-in-Line across
9-16::
    1s dance reels of 3 across (RSh to 4th corner) & 1s end in diagonal
    line giving RH to 2nd corner LH to partner
17-24::
    Bal-in-Line & turn corners RH, 1s turn 1st corners LH to end in
    diagonal line with 1st corners & Bal-in-Line
25-32::
    1s dance reels of 3 on opposite sides (LSh to 1st corner) & cross RH
    to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6984, '2013-08-21 08:31:34.081962+00', '2023-02-04 01:22:03.381926+00', 9882, 3, NULL, 'ace', '1-8::
    1s & 4s set & cast in 1 place (2s & 3s step up/down), 1s+4s dance
    1/2 R&L
9-16::
    2s & 3s set & cast in 1 place (4s & 1s step up/down), 2s+3s dance
    1/2 R&L. (4) (3) (2) (1)
17-24::
    4s+3s & 2s+1s dance RH across, 3s+2s dance LH across _while_ 4s & 1s
    chase clockwise to other end
25-32::
    1s+3s also 2s+4s set facing on sides & change places RH, turn
    partners 2H to own sides (end couples turn 1.1/2 times).  End 3 1 4
    2', 0);
INSERT INTO 'dancecrib' VALUES (4021, '2013-08-21 08:30:42.137139+00', '2023-02-04 01:18:28.151893+00', 161, 3, NULL, 'ace', '1-8::
    1s+2s 3/4 turn RH, dance 1/2 reel of 4 up/down middle, dance RSh
    round each other to own sides
9-16::
    2s+1s+3s set, cross RH & dance 1/2 reel of 3 on sides, (1s giving
    RSh to 2nd corner pstns)
17-24::
    Repeat (to own sides)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4063, '2013-08-21 08:30:42.929279+00', '2023-02-04 01:18:31.173908+00', 224, 3, NULL, 'ace', '1-8::
    1M+2M+3M turn 2L+3L+4L RH & turn partners LH
9-16::
    1s+2s+3s slip step down for 2 bars & 1/2 turn, slip step up to top &
    1/2 turn to places
17-24::
    1s+2s dance R&L
25-32::
    1M followed by partner casts 1 place & crosses to opposite side to
    dance RH across with 3s
33-40::
    1M followed by partner cast on opposite side to 4th place & crosses
    to own side to dance RH across with 4s', 0);
INSERT INTO 'dancecrib' VALUES (4155, '2013-08-21 08:30:44.355739+00', '2023-02-04 01:18:37.257377+00', 380, 3, NULL, 'ace', '1-8::
    All face corners, set & turn 2H to face partners, set to partners &
    turn 2H end with Ladies facing out
9-24::
    All dance full Schiehallion Reel
25-32::
    All dance Grand Chain
33-40::
    Men Adv+Ret as Ladies cast & dance round clockwise to next Ladies
    place, Ladies Adv+Ret _while_ Men cast clockwise to ptnrs', 0);
INSERT INTO 'dancecrib' VALUES (6915, '2013-08-21 08:31:32.696798+00', '2023-02-04 01:21:58.447059+00', 10388, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 R&L, all chase clockwise 1/2 way.  3 4 1
    2
9-16::
    3s+4s also 1s+2s dance RH across, 4s+1s dance LH across
17-20::
    4M+1M & 4L+1L dance across (Men making an arch), turn corners with
    free hand to face up/down
21-24::
    4s+1s dance down/up (couple dancing up make the arch) & turn corners
25-32::
    Repeat bars 17-24 from new positions
33-40::
    4M+1L change places RH & 1M+4L change place RH, 1s & 4s turn RH
    1.1/2 times.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (6916, '2013-08-21 08:31:32.708688+00', '2023-02-04 01:21:58.476168+00', 8700, 3, NULL, 'ace', '{{title}}
Part 1

1-8::
    1s+3s set advancing, turn 2H, circle left to places
9-16::
    2s+4s repeat bars 1-8
17-24::
    All set to partner, Ladies pass partner LH to face next Man, all set
    & turn 2H to face own partner (on corner)
25-32::
    All set to partner twice & turn RH 1.1/2 times to original places
33-40::
    1s+3s set & slip step across (Men BtoB) to change places, set & slip
    step back to places (Ladies BtoB)
41-48::
    2s+4s repeat bars 33-40
49-56::
    All turn corners RH, partner LH, corner RH & Partner LH

{{title}}
Part 2

1-8::
    1s+3s dance RH across 3/4 way, dance LH across with 4s/2s
9-16::
    1s+3s dance RH across 3/4 way, dance LH across with 2s/4s
17-24::
    All Adv+Ret, set advancing & retire with corners
25-32::
    All dance interlocking reels of 4 (RSh to corner)
33-40::
    1s+3s set & slip step across (Men BtoB) to change places, set & slip
    step back to places (Ladies BtoB)
41-48::
    2s+4s repeat bars 33-40
49-56::
    All circle 8H round & back ending in centre', 0);
INSERT INTO 'dancecrib' VALUES (14538, '2022-01-10 02:20:31.078879+00', '2023-02-04 01:21:58.501381+00', 17462, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1L followed by 2L+3L+4L dance across behind 1M. 1L loops round 1M to
    follow 4L as Ladies dance behind Men & cross back to own side to end
    2 3 4 1
17-24::
    Men repeat figure 9-16 round Ladies to end opposite partner. 2 3 4 1
25-32::
    All dance DoSiDo with partner & turn RH (or birl)', 0);
INSERT INTO 'dancecrib' VALUES (6917, '2013-08-21 08:31:32.717057+00', '2023-02-04 01:21:58.672303+00', 5389, 3, NULL, 'ace', '1-8::
    1s in prom hold (Lady on Man''s Left) dance reel of 3 across with 2s,
    passing 2L LSh to start. 1s end in 2nd place own sides, 2s dance up
    to 1st place
9-16::
    2s+1s+3s dance Grand Chain (2s crossing at top)
17-24::
    1s cross RH to face 1st corner & turn 1st corners LH, turn 2nd
    corners RH & 1/2 turn partner LH ready for …
25-32::
    1L+2s and 1M+3s dance RH across, 1s pass RSh to dance LH across with
    other couple & 1s end in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (10225, '2017-11-04 01:45:56.744156+00', '2023-02-04 01:21:58.700549+00', 17785, 3, NULL, 'ace', '1-8::
    1L+3M set advancing, join LH in middle & RH with partner, all set in
    diag line.  1/2 diag reel of 4, 1L & 3M passing partner RSh to
    start.  1L & 3M pass LSh to face 2s (1L+2L, 3M+2M)
9-12::
    1L+3M dance 1/2 reel of 4 across with 2s, pass LSh to face own
    partner.
13-16::
    1L+3M dance 1/2 diag reel of 4 passing partner RSh to start.  1M &
    3L end in orig places, _while_ 1L & 3M dance across to opp sides
    (each other''s places)
17-24::
    Men at top & Ladies at bottom dance RH across.  2s+1L+3M dance 1/2
    diag R&L to end 1 2 3
25-32::
    1s NHJ dance down cast up round 3s to 2nd place (2s step up 3-4),
    dance up to top & cast to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (10305, '2017-12-11 14:25:34.158408+00', '2022-01-29 00:25:47.604659+00', 18108, 2, NULL, 'ace', '*Couple face couple*   

1-8::

  Four hands round and back

9–16	::

  Four hands across with the right hands  

  Back to back with opposite dancer (pass right shoulder first)

17-24::

  Four hands across with the left hands  

  Back to back with partner (pass left shoulder first)

25-32::

  “Over and under”  

  Clockwise couple walking forward make an arch for the facing couple and go under the next couple’s arch 

  while the anticlockwise couple walk under the facing couple’s arch and make an arch for the next couple.  

  Progress two more couples by passing new opposite dancer right shoulder and the next dancer left 

  shoulder.  ', 5);
INSERT INTO 'dancecrib' VALUES (6918, '2013-08-21 08:31:32.725555+00', '2023-02-04 01:21:58.722177+00', 5390, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across 1/2 way, 1s+3s set & dance LH across 1/2
    way
9-16::
    1s dance reels of 3 on own sides (dance up giving LSh to 3s to
    start)
17-24::
    1s set, cast up 1 place _while_ 3s set & cross down LH, 1s set &
    cast up to top _while_ 2s set & cross down
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14539, '2022-01-10 02:20:31.458398+00', '2023-02-04 01:21:58.959405+00', 14347, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance mirror reels of 3 on sides (1s in/down to start)
9-12::
    1s+2s changsweete places by turning 1.1/2 (Men RH, Ladies LH)
13-16::
    1s+3s turn 1.3/4 (Men LH, Ladies RH). 1s end BtoB in centre ready
    for …
17-24::
    1s dance Double Triangles finishing in 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7959, '2013-08-21 08:31:51.861455+00', '2023-02-04 01:23:13.874937+00', 7178, 3, NULL, 'ace', '1-8::
    1s advance for 1 step & touch RH, retire, cast 1 place & turn LH to
    end in prom hold facing up with 2s & 3s stepping in on last bar
9-16::
    2s+1s+3s dance Allemande, 1s end turning LH & back into prom hold
    facing 3M
17-24::
    1s dance 1/2 RSh reel of 3 on Men''s side & 1/2 reel on Ladies side
    giving RSh to 2L to start
25-32::
    1s dance to top, cast 1 place on own side, dance down between 3s &
    cast up to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (4022, '2013-08-21 08:30:42.147598+00', '2023-02-04 01:18:28.181496+00', 9381, 3, NULL, 'ace', '1-8::
    1s turn 2H, cast 1 place, 1s dance 1/2 Figs of 8 (Lady round 2s &
    Man round 3s) . Order 2 (1) 3
9-16::
    1s dance RH across (Man with 2s & Lady with 3s), 1s dance 1/2 Figs
    of 8 (Lady round 2s & Man round 3s). 2 1 3
17-24::
    1s+3s dance Set & Rotate:
::
    Set, Rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides.  2 3 1
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9035, '2015-11-30 09:00:11.283305+00', '2023-02-04 01:21:59.092904+00', 16111, 3, NULL, 'ace', '1-6::
    1s+2s set advancing to Bal-in-Line & turn partners RH 1/2 way
7-8::
    1M+2L turn 3/4 LH as partners dance 1/4 clockwise round to face
    partners in line across
9-16::
    1s+2s dance reels of 4 across.  Bars 15-16 1L & 2M curve to Right to
    end in middle, 2M at top, 1L at bottom as 1M+2L pass LSh to face
    partners in line up/down middle, Ladies facing up, Men down
17-24::
    2s+1s dance reel of 4 up/down middle
25-32::
    2s+1s set, Petronella turn to own sides & turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (8622, '2015-02-13 12:48:09.605925+00', '2023-02-04 01:21:59.119436+00', 15627, 3, NULL, 'ace', '1-8::
    2s+3s set & dance 1/2 LH across to face corners, 2s+3s change places
    RH with corners & corners dance 1/2 LH across to end on sides
9-16::
    All dance RSh reels of 4 on sides
17-24::
    3s+4s also 1s+2s set & dance 1/2 RH across, 4s+3s+2s set & 1/2 turn
    RH to face down in Allemande hold
25-32::
    4s+3s+2s dance the Knot to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (15145, '2022-10-05 00:21:29.424104+00', '2023-02-04 01:21:59.138862+00', 20789, 3, NULL, 'ace', '1-8::
    3s followed by 1s dance down, cast up round 4s, 3s to 1st place, 1s
    to 3rd place; all 4 couples turn partner RH, 3s & 1s face down, 2s &
    4s face up
9-16::
    All set twice, 2s dance in & cast up to 1s place as 3s dance down to
    2nd place, 1s+4s dance similar, 1s casting to 4th place, 4s dancing
    up to 3rd place, all set
17-24::
    2s+3s also 4s+1s dance R&L
25-32::
    2s+3s also 4s+1s dance Double Figs 8: 2s cast down, 3s cross up
    _while_ 1s cast up, 4s cross down.  End 2  3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6920, '2013-08-21 08:31:32.775538+00', '2023-02-04 01:21:59.15621+00', 9926, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s turn RH, cast in 1 place & turn LH 1.1/2 times to end
    between 2s/3s (Man facing Lady)
9-16::
    1s+2s also 4s+3s dance RSh reel of 4 across
17-24::
    1s & 4s turn corners RH, 1s+4s dance LH across 1/2 way to face other
    corner, turn corners RH & turn partner LH to end between 2s/3s
25-32::
    4s+2s also 1s+3s dance RSh reels of 4 across
33-40::
    1s & 4s dance out ends, cross, cast & turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (15351, '2022-12-19 01:21:34.504079+00', '2023-02-04 01:21:59.169891+00', 20554, 3, NULL, 'ace', '1-4::
    1M followed by 1L, casts down 1 place, dances across to 2L''s place &
    faces out _while_ 2L followed by 2M, casts up, crosses to 1M''s place
    (2) (1) 3
5-8::
    1M followed by 1L, casts down 1 place, dances across to 3M''s place
    _while_ 3M followed by 3L, casts up, crosses to 2L''s place (2) (3) 1
9-12::
    1s dance 1/2 Fig of 8 round up 3s.  (2) (3) (1)
13-16::
    All dance DoSiDo with partner
17-24::
    1s followed by 3s+2s, dance down. On bar 4, all change sides (each
    Lady dances under partner''s right arm as Man crosses behind her to
    face up). 2s followed by 3s+1s dance up to finish 2s face down in
    middle 1st place, 3s in 2nd place & 1s NHJ in middle 3rd place
    facing up. 2 3 1
25-32::
    All circle 6H round & back.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6921, '2013-08-21 08:31:32.783832+00', '2023-02-04 01:21:59.195209+00', 5398, 3, NULL, 'ace', '1-8::
    1L turns 3M RH to end in 2nd place own side, 1M+3L turn RH & return
    to original places
9-16::
    1M+2L & 1L+2M dance Allemande 1s end in lines across 1L between 2s
    facing 1M between 3s
17-24::
    2s+1s+3s set in lines across twice 1s turning onto own sides,
    2s+1s+3s set on sides twice
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6922, '2013-08-21 08:31:32.79208+00', '2023-02-04 01:21:59.223283+00', 12895, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 4s cross to opposite sides

1-8::
    2s turn RH 1.1/2 times to face 1st corners, 2s dance 1/2 diagonal
    reel of 4 with 1st corners & pass RSh to face 2nd corners
9-16::
    2s dance 1/2 reel of 4 with 2nd corners & turn RH to 2nd place
    opposite sides.  (3)2(1)(4)
17-24::
    2s+1s dance 1/2 R&L.  3s+1s also 2s+4s dance 1/2 R&L (giving RH on
    sides to start)  (1)3 4(2)
25-32::
    1s+4s (1st & 3rd places) dance Ladies'' Chain (up/down)
33-40::
    1s+3s set & dance 3/4 double Fig of 8 (3s cross up & 1s cast)
    _while_ 4s+2s dance full double Fig of 8 (2s cross up & 4s cast)  3
    1 4(2)', 0);
INSERT INTO 'dancecrib' VALUES (6923, '2013-08-21 08:31:32.802076+00', '2023-02-04 01:21:59.324903+00', 5402, 3, NULL, 'ace', '1-8::
    1L+2M lead down the middle & back, both ending in 2nd place opposite
    sides facing up to partners (2L steps up 3-4)
9-16::
    1s+2s set twice to partner on sides & turn 2H
17-24::
    1s+2s dance Ladies'' Chain ending with 1s dancing full LH turn, 2s
    dancing 1/2 turn, staying in centre ready for ...
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6924, '2013-08-21 08:31:32.810327+00', '2023-02-04 01:21:59.3475+00', 5403, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, petronella turn, set & petronella turn to opposite
    sides
9-16::
    1s+2s+3s set, cross RH, 1s+2s set facing on sides & turn (Ladies LH
    & Men RH)
17-24::
    1s dance Inveran Reels with 2s+3s
25-32::
    1s+2s dance the Rondel', 0);
INSERT INTO 'dancecrib' VALUES (6925, '2013-08-21 08:31:33.025267+00', '2023-02-04 01:21:59.519836+00', 5404, 3, NULL, 'ace', '1-8::
    All Promenade round anticlockwise 1/2 way, set to partner (Men on
    inside) & 3/4 turn 2H
9-16::
    1s+3s dance Ladies'' Chain _while_ 2s+4s turn partners LH & dance 6
    bars of Ladies Chain. All end facing anticlockwise with Ladies on
    inside
17-24::
    All Promenade round 1/2 way, set to partner (Ladies on inside) & 1/4
    turn 2H to original places
25-32::
    1M+3M cross RH & turn to right, 3M+1L & 1M+3L cross over diagonally
    (3M+1L between 1M+3L) to change places, 2s+4s repeat (2M+1L between
    4M+3L) ending 4 1 2 3 with Ladies on Men''s right
33-36::
    1s+3s, NHJ with partner, cross (pass RSh) with Ladies turning under
    Man''s right arm
37-40::
    1s+3s cast 1 place to left (1s to 3rd place, 3s to 1st place)
    _while_ 2s+4s cross with Ladies turning under Man''s right arm
41-44::
    2s/4s dance out between 1s/3s & cast left (4s to 2nd place, 2s to
    4th place) with Ladies on Men''s left
45-48::
    All turn corners LH
49-56::
    3s+1s cross (1s make arch) & cast away from each other to form lines
    up/down with 4s & 2s. All set & cross RH
57-60::
    2s+4s cross (2s make arch) & cast away from each other to form lines
    across with 1s & 3s
61-64::
    1s+3s set & cross RH _while_ 4s & 2s change places RH with partners
    to form square set in order 3 4 1 2 ready to repeat once more', 0);
INSERT INTO 'dancecrib' VALUES (6926, '2013-08-21 08:31:33.035725+00', '2023-02-04 01:21:59.571788+00', 9296, 3, NULL, 'ace', '{{explanation}}
2s start on opp sides

1-8::
    1L+2M also 2L+3M set & turn RH on sides, 1M+2L also 2M+3L set & turn
    LH on sides
9-16::
    2s set & cross RH, all dance 1/2 reels of 3 on sides (1M+2M also
    2L+3L giving RSh to start)
17-24::
    2s set & cross LH, all dance 1/2 reels of 3 on sides (1M+2L also
    2M+3L giving LSh to start)
25-32::
    All turn partners 2H twice & chase clockwise 2 places to face new
    partners (centre couple 3L & 1M on opp sides)', 0);
INSERT INTO 'dancecrib' VALUES (4023, '2013-08-21 08:30:42.157661+00', '2023-02-04 01:18:28.216712+00', 9838, 3, NULL, 'ace', '1-8::
    All set & cross RH, set & cross back RH
9-16::
    1s lead down (2 steps), set passing LSh to face 1st corners (2s step
    up 9-10), turn crnrs 2H into lines across (1L between 2s & 1M with
    3s). All set
17-24::
    1s set passing LSh to face 2nd corners, turn corners 2H onto sides,
    all set & 1s pass RSh to 2nd place own sides facing out
25-32::
    1s dance 6 bar reels of 3 on own sides (1s out & down to start).
    1s+3s change places on sides (Men LH, Ladies RH)', 0);
INSERT INTO 'dancecrib' VALUES (4024, '2013-08-21 08:30:42.165688+00', '2023-02-04 01:18:28.246418+00', 12665, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s dance 1/2 diag R&L with 1st corners
9-16::
    1s dance 1/2 diag R&L with 4th corners, 1s set & cast to 3rd place
17-24::
    1s cross RH, cast to top, all set & 1/2 turn RH to face up
25-32::
    1s+3s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4025, '2013-08-21 08:30:42.173776+00', '2023-02-04 01:18:28.27672+00', 162, 3, NULL, 'ace', '1-8::
    1s+2s set to each other on sides & change places (Men LH Ladies RH),
    1s+3s set on the sides & change places (Men RH Ladies LH)
9-16::
    1s cross RH, cast up 1 place, set & turn LH to face 1st corners
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & Partner LH to 2nd
    places
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6928, '2013-08-21 08:31:33.052044+00', '2023-02-04 01:21:59.617556+00', 12692, 3, NULL, 'ace', '1-8::
    1s+2s set & 1s cast 1 place as 2s cross up, 1s+3s set & dance 1/2 RH
    across.  (2)(3)(1)
9-16::
    2M+1L change place RH & 2L+1M change places RH, 3s cross RH & all
    set advancing for Allemande
17-24::
    All dance Allemande.  2 3 1
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13190, '2020-09-15 00:21:16.551888+00', '2023-02-04 01:21:59.640663+00', 16063, 3, NULL, 'ace', '1-8::
    All Ladies set, Adv+Ret, cross RH _while_ all Men Adv+Ret, set,
    cross RH
9-16::
    All 1.1/2 turn RH, dance DoSiSo
17-24::
    1s lead down the middle & back to top, finish facing up.
25-32::
    1s followed by 2s,3s & 4s cast to bottom. 1s make an arch as 2s, 3s
    & 4s dance under & up to place. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6929, '2013-08-21 08:31:33.114541+00', '2023-02-04 01:21:59.65436+00', 11105, 3, NULL, 'ace', '1-4::
    1s+3s set advancing & dance LH across 3/4 way, 1s face 2s & 3s face
    4s
5-8::
    1s+2s also 3s+4s dance RH across 1/2 way,1s+3s dance clockwise to
    1st & 3rd places _while_ 2s+4s dance LH across 3/4 way, 2s face 1s &
    4s face 3s        3 4 2 1
9-16::
    All dance reels of 4 up/down
17-24::
    3s+4s also 2s+1s dance 1/2 R&L (polite turns at end), 3s+1s set,
    circle 4H round to left opening out to end 1s in 2nd place & 3s in
    4th place
25-32::
    All dance 8H round & back
::
    Repeat in strathspey then twice in reel time', 1);
INSERT INTO 'dancecrib' VALUES (6930, '2013-08-21 08:31:33.122753+00', '2023-02-04 01:21:59.681257+00', 5407, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance round 1st corners passing corners LSh
9-16::
    1s dance reels of 3 across (1st Man with 2s & 1st Lady with 3s), 1s
    turn LH to face 1st corners
17-18::
    Centre dancers change with 1st corners RH _while_ 2nd corners set
19-20::
    1st corners (in centre) change places LH _while_ new 1st & 2nd
    corners dance clockwise round to next corner place
21-24::
    Repeat the Fig in bars 17-20 from new places
25-32::
    Repeat 17-20 from new places, 1s end by turning LH to 2nd place on
    opposite sides, 2s+1s+3s set on sides & 1s cross back RH', 0);
INSERT INTO 'dancecrib' VALUES (9223, '2016-06-16 22:42:13.423758+00', '2023-02-04 01:21:59.703401+00', 12955, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH, cast to 2nd/4th place (2s & 4s step up)  1s & 3s
    dance 1/2 Fig 8 through end (1s up, 3s down)
9-16::
    1s+4s+3s circle 6H round to Left (3 bars), cross R foot over L &
    chase anticlockwise back.  End 1L following 1M, 3M following 3L into
    ...
17-20::
    2M+1s also 3s+5L dance RH across as 4s slow turn LH
21-24::
    2L+1s also 3s+5M dance LH across as 4s slow turn RH.  End 1M
    followed by 1L just above set facing down, 3L followed by 3M just
    below set facing up
25-28::
    1s dance into 2nd place & turn 3/4 RH to face up NHJ, 3s dance
    similar & face down _while_  4s DoSiDo (pass RSh)
29-32::
    1s dance up, cast to 2nd place opp sides, 3s dance down, cast up to
    4th place opp sides _while_ 4s reverse DoSiDo (pass LSh)
33-40::
    1s+4s & 3s+5s set, dance 3/4 double Fig 8 (1s & 3s cast down, 4s &
    5s cross up)  End  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (1580, '2012-01-20 13:06:12.755312+00', '2022-01-29 00:29:24.354685+00', 12056, 2, 1, 'ace', '1-8::

  1C+2C turn BH, open into Circle4 to left only.

9-16::

  1C lead down {2}, set to P, lead up {2} and cast off (2C up) to

   finish between 2C, 1M facing 2W and 1W facing 2M.

17-24::

  Reel4 across, finishing with 1C in 1pl and 2C in 2pl ready for ...

25-32::

  1C+2C allemande.

', 2);
INSERT INTO 'dancecrib' VALUES (9400, '2016-10-06 07:18:49.795528+00', '2023-02-04 01:21:59.733169+00', 17217, 3, NULL, 'ace', '1-4::
    1s+2s+3s circle left 4 steps & drop hands & set rotating
5-8::
    2s+3s chase clockwise to own side corner positions _while_ 1s turn
    RH in centre to end 2nd place opp sides.  3(1)2
9-16::
    2s+1s+3s dance 1/2 LSh reels on the sides (1L up, 1M down), 1s dance
    1/2 Figs 8 to 2nd place own sides (1M up & 1L down)
17-24::
    1s dance "Goodbye/Hello" setting to change places & set, dance
    "Goodbye/Hello" setting back to 2nd place own sides & 3s+1s+2s set
    advancing into promenade hold facing up
25-28::
    3s+1s+2s dance an accelerated Allemande to end in line on the Mens
    side (drop hands)
29-32::
    2L+1L+3L dance "Goodbye/Hello" setting to own sides, 2s+1s+3s+4s
    join hands & set
::
    Note on bars 31/32 of repeat 1s step out to ends as 4s step up', 0);
INSERT INTO 'dancecrib' VALUES (5352, '2013-08-21 08:31:05.232171+00', '2023-02-04 01:21:59.764976+00', 5409, 3, NULL, 'ace', '1-8::
    1s cross, dance down to 2nd place, cross down to 3rd place & cast up
    to 2nd place _while_ 2s set, cross down to 3rd place, cast up to 2nd
    place & cross down LH to end in 3rd place in centre _while_ 3s lead
    up the dance for 4 casting into 1st place, set facing & set rotating
    to right
9-16::
    3s+1s+2s repeat above from new places
17-24::
    2s+3s+1s repeat from new places except that 3s remain on side lines
    at the end
25-32::
    1s+2s dance the Guillotine: 1s+2s set on side, RH across 1/2 way,
    change places RH on sides & RH across 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (8301, '2014-07-29 12:58:41.984086+00', '2023-02-04 01:18:28.437561+00', 163, 3, NULL, 'ace', '1-4::
    1s+2s also 4s+5s dance RH across once round
5-8::
    1s / 5s cross down / up giving right hands _while_ 2s / 4s cast off
    / up 1 place; 1s & 5s face out, all join hands and set
9-16::
    1s+3s+5s dance reel of 3 on the sides, 3s dancing to right to begin.
    1s / 5s end BtoB facing partner''s side, ready for...
17-24::
    All dance 6 bars of Double Triangles, then 1s / 5s turn 3s / 4s
    halfway on the side to change places to end on the sidelines, facing
    in.
25-32::
    1s cross RH, cast off 1 place (4s step up),1s cross LH, cast off 1
    place (5s step up) 2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (9486, '2016-11-09 08:48:54.04164+00', '2023-02-04 01:21:59.801035+00', 8073, 3, NULL, 'ace', '1-8::
    1L+2M also 3L+4M turn RH.  1M+2L also 3M+4L turn LH
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1s+2s set, dance 1/2 RH across.  1s+3s set, dance 1/2 LH across.
25-32::
    1s+4s set, dance 1/2 RH across. 2s+3s+4s+1s set & cross LH to own
    sides 2 3 4 1

{{explanation}}
Note:  May be danced as Strathspey', 0);
INSERT INTO 'dancecrib' VALUES (6931, '2013-08-21 08:31:33.290354+00', '2023-02-04 01:21:59.829692+00', 5412, 3, NULL, 'ace', '1-8::
    1s cast to meet below 3s then 1s dance up to meet 2s _while_ 2s cast
    up dancing in to face 1s & 1s+2s set
9-16::
    2s+1s circle 4H round & back
17-20::
    1s dance Petronella turn to end middle Lady at top facing down & Man
    facing up as 2s+3s change places RH on the sides, 3s+1s+2s set
21-24::
    1s dance Petronella turn to 2nd place opposite sides as 3s+2s cross
    RH, 3s+1s+2s set
25-28::
    1M+2M change places LH as 1L+2L change RH, 3M+2M change places RH as
    3L+2L change places LH
29-32::
    3M+1M change places LH as 3L+1L change RH, 2s+1s+3s cross RH
1-32::
    Repeat above in reel time', 0);
INSERT INTO 'dancecrib' VALUES (12099, '2019-08-30 09:54:49.659431+00', '2023-02-04 01:22:00.072942+00', 19080, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s & 3s Set+Link, 1L/3L  followed by partner chase 1 place
    clockwise, dance in between 2s/4s into centre, 3s above 1s (1M
    facing 3L, 1L facing 3M 1s facing up, 3s facing down)
17-24::
    1M+3L & 1L+3M dance Poussette within set,1M+3L dance up, 1L+3M dance
    down to begin
25-32::
    1M+3L & 1L+3M cross LH, 1M/3M followed by partners chase 1 place
    anticlockwise & change places LH with partner.  3 2 1 4
33-56::
    2s & 4s repeat bars 9-32.  3 4 1 2
57-60::
    All couples Advance NHJ with partner & Retire NHJ with corner
61-76::
    1L+4M+3L+2M dance R&L ("1st corner diagonal"): 1M+2L+3M+4L dance R&L
    ("2nd corner diagonal")
77-80::
    All couples Advance NHJ with corner & Retire NHJ with partner
81-88::
    All dance 8 bars of Schiehallion reels ending in original places.
89-96::
    All circle 8H round & back.  1 2 3 4', 0);
INSERT INTO 'dancecrib' VALUES (12821, '2020-05-14 23:15:54.185144+00', '2023-02-04 01:22:00.123812+00', 19940, 3, NULL, 'ace', '1-8::
    1s lead down (2 bars), lead up & cast to 4th place into centre &
    join 2H (2s+3s+4s step up 5-6)
9-20::
    1s retire to 4th place (9-10) _while_ 2s+3s+4s dance R&L for 3
    couples.  2 3 4 1
21-24::
    2s+3s+4s turn partner RH, 3s face out
25-32::
    RSh reels of 3 on sides (3M up/out, 3L out/down).  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6936, '2013-08-21 08:31:33.339746+00', '2023-02-04 01:22:00.251464+00', 5421, 3, NULL, 'ace', '1-8::
    1s turn RH;  turn LH into a line across holding 2s by RH
9-16::
    1s+2s Bal-in-Line twice, 1M+2L & 1L+2M turn 2H (4 PdeB), 1s+2s end
    in line facing down
17-24::
    1s+2s dance in line down the middle, pull back RSh to face up,
    rejoin hands & dance back up. Bars 23-24 1s dance in front of 2s
    ready for …
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6937, '2013-08-21 08:31:33.35393+00', '2023-02-04 01:22:00.2751+00', 5422, 3, NULL, 'ace', '{{explanation}}
The Queen

1-8::
    All bow/curtsey to partner, bow/curtsey to corner
9-16::
    1s & 3s Adv+Ret, advance 1M hands 1L over to 3M, 3s+1L retire
    _while_ 1M remains in centre
17-24::
    1M dances a Highland step _while_ other 3 Adv+Ret & advance again
25-32::
    1s+3s circle 4H round 1/2 way & dance 1/2 R&L to places
33-40::
    All set to & turn corners
41-72::
    2s & 4s repeat bars 9-40 with 2M as leading person

{{explanation}}
The Prince

1-8::
    All bow/curtsey to partner, bow/curtsey to corner
9-16::
    1s+3s dance Ladies'' Chain
17-24::
    2s+4s dance Ladies'' Chain to end with all Ladies joining RH in
    centre & LH with partner''s LH
25-32::
    All dance RH across once round with Men dancing backwards on outside
33-40::
    All set to & turn corners
41-72::
    Repeat 9-40 with 2s & 4s starting

{{explanation}}
Salutations to Mrs Cramb

1-8::
    All bow/curtsey to partner, bow/curtsey to corner
9-16::
    All Ladies Adv+Ret 2 steps twice _while_ Men stand for 2 bars then
    Adv+Ret, advance turning to right into prom hold with partner
17-24::
    All Promenade round clockwise to original places (Men on the inside,
    partner on left)
25-32::
    All dance Grand Chain
33-40::
    All set to & turn corners', 0);
INSERT INTO 'dancecrib' VALUES (6938, '2013-08-21 08:31:33.367911+00', '2023-02-04 01:22:00.506903+00', 5426, 3, NULL, 'ace', '1-8::
    All dance reels of 4 on sides
9-16::
    All set (take hands on sides) & cross RH, all set & cross back RH
17-24::
    1s cross RH below 2s, cast to between 3s & 4s, cross LH & cast to
    4th place own side (2s+3s+4s take hands bars 23-24 to step up)
25-32::
    2s+3s also 4s+1s dance RH across & LH back. 1s remain in middle
    facing up
33-40::
    1s dance up to top (2 bars), set, then cast to 4th place _while_
    2s+3s+4s dance down on sidelines (2 steps), set, turn RH & dance up
    to places NHJ (2 steps)  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9926, '2017-06-05 11:31:38.679965+00', '2023-02-04 01:22:00.524752+00', 17740, 3, NULL, 'ace', '1-8::
    1s set, cast & dance 1/2 Fig 8 round 2s to end in centre joining RH
    to partner, LH with 1st corner
9-16::
    Balance in Line, 1s 3/4 RH turn to join LH with 2nd corner, Balance
    in Line, 1s 3/4 RH turn to face 3rd corner
17-24::
    1s dance 1/2 diag RSh reel of 4 with 3rd corners, 1/2 diag RSh reel
    of 4 with 4th corners to end in 2nd place own side
25-32::
    1s dance 1/2 Fig 8 (1L down between 3s, 1M up between 2s) to 2nd
    place opp side & all chase clockwise 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (9762, '2017-04-06 08:40:25.286661+00', '2023-02-04 01:23:09.46272+00', 17647, 3, NULL, 'ace', '1-4::
    1s+3s turn corners 1.1/4 (Men LH, Ladies RH) to end 1M+ 3L (3M+ 1L)
    in centre NHJ facing 2s (4s)
5-8::
    1M+3L (3M+1L) dance out between 2s (4s), separate and cast away to
    meet own partner _WHILE_
::
    2s (4s) dance into centre, join nearer hands with partner & then
    dance out to place, separate and loop round to face partners on
    sides
9-16::
    1s & 3s in promenade hold dance reels of three on sides, 1s+4s &
    3s+2s giving LSh to 4L (2L) to start
17-20::
    1s+3s dance RH across in centre ending in original positions, all
    face partners
21-24::
    All set to partners and turn 3/4 RH
25-26::
    Ladies dance 1/2 LH across in centre _WHILE_ Men chase one place
    round outside clockwise
27-28::
    All turn new partner1/2 RH
29-30::
    Men dance 1/2 LH across in centre _WHILE_ Ladies chase one place
    round outside clockwise (to own partner)
31-32::
    All turn partners 3/4 RH
33-40::
    All circle 8H round to the left & back', 4);
INSERT INTO 'dancecrib' VALUES (7435, '2013-08-21 08:31:40.918557+00', '2022-08-03 07:17:33.117722+00', 5831, 3, NULL, 'ace', '1-8::

    1s cross RH & cast 1 place, dance 1/2 Figs of 8 round 2s

9-16::

    1L+2s also 1M+3s dance RH across, 1s pass RSh to dance LH across

    with other couple & 1s end facing 1st corners

17-24::

    1s set & turn 1st corners 2H, set & turn 2nd corners 1s ending in

    2nd place opposite sides

25-32::

    2s+1s+3s dance reflection reels of 3 on sides (1s dancing in & down

    to start) & crossing to own side on bar 29 to complete the reels', 0);
INSERT INTO 'dancecrib' VALUES (14639, '2022-03-07 02:18:31.015228+00', '2023-02-04 01:18:37.352006+00', 20403, 3, NULL, 'ace', '1-8::
    2s also 4s pass partners LSh & 1st corners RSh to dance diagonal
    reels of 4 on 1st corner diagonal. Bar 8:  2s also 4s 1/2 turn
    partner LH to face 2nd corners
9-16::
    2s also 4s repeat dancing diagonal reels of 4 on 2nd corner
    diagonals 1 2 3 4 5
17-24::
    1s set advancing and turn 2H opening to face down NHJ; 1s dance down
    & cast up into 5th place (2s+3s+4s+5c step up 23-24).  2 3 4 5 1
25-32::
    All dance the »Centenary formation«:
::
    ''2s 1/2 turn 2H opening to face down NHJ  and set,  2s Set+Link to
    own sides
::
    ''_while_ 3s+4s circle 4H round and back
::
    ''_while_ 5s+1s circle 4H round and back.  2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (6939, '2013-08-21 08:31:33.376751+00', '2023-02-04 01:22:00.543655+00', 11370, 3, NULL, 'ace', '{{explanation}}
 8 Bar intro - All bow & curtsey to partners, all bow & curtsey to corners

1-8::
    All circle 8H round & back
9-16::
    All with partners set, advance, acknowledge opposite couple &
    turning inwards dance out to places
17-24::
    1s+3s set, advance turning right cast & dance clockwise behind
    2s/4s, Men dance on to opposite places _while_ Ladies dance between
    side couples into centre to form line of 4 up/down facing opposite
    partner
25-32::
    1s+3s dance RSh reel of 4 & end in prom hold with ''new'' partner
    facing clockwise (Ladies end reel passing RSh)
33-40::
    All promenade round clockwise
41-48::
    2s+4s set, advance turning left cast & dance anticlockwise behind
    standing couples, Ladies dance on to opposite places _while_ Men
    dance between standing couples into centre to form line of 4 across
    facing opposite partner
49-56::
    2s+4s dance LSh reel of 4 & end in prom hold with other partner
    facing anticlockwise (Men end reel passing LSh)
57-64::
    All promenade round anticlockwise
65-72::
    All Ladies dance LH across 1/2 way, turn own partners RH, dance LH
    across 1/2 way & turn ''new'' partner RH
73-80::
    1s+3s dance 1/2 Men''s Chain, 2s+4s dance 1/2 Ladies'' Chain (all back
    to original pstns)
81-88::
    1M+3M dance RSh round partners _while_ 2L+4L dance LSh round
    partners to face corner person & pivot turn (waist hold) 3 times
    round with corners to end in diagonal lines of 4 facing 4
89-96::
    All Adv+Ret & turn partners LH to end in original places
97-112::
    2s+4s repeat bars 81-96 forming lines on other diagonal
113-120::
    All repeat bars 9-16
121-128::
    All repeat bars 1- 8', 0);
INSERT INTO 'dancecrib' VALUES (6940, '2013-08-21 08:31:33.384855+00', '2023-02-04 01:22:00.560757+00', 7563, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 double Fig of 8 (1s crossing down to start), 1s
    dancing between 2s give nearer hand to 2s & turn once round
9-16::
    1s dance Inveran reels with 2s+3s (1s cross to own sides to start)
17-24::
    1s+2s dance 1/2 double Fig of 8 (1s crossing down to start), 1s
    dancing between 2s give nearer hand to 2s & turn 1.1/2 times to end
    in centre BtoB for Double Triangles
25-32::
    1s dance Double Triangles ending in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6942, '2013-08-21 08:31:33.408683+00', '2023-02-04 01:22:00.676287+00', 5436, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across (3 bars) & LH back (5 bars) 1s ending on Men''s
    side & 2s on Ladies side
9-16::
    1s lead down the middle & back to Men''s side but with Lady on Mans
    left
17-24::
    1s+2s dance R&L
25-32::
    1s+2s set to partners twice & turn 2H to own sides with 1s in 2nd
    place', 0);
INSERT INTO 'dancecrib' VALUES (12100, '2019-08-30 09:54:49.964022+00', '2023-02-04 01:22:00.705515+00', 19082, 3, NULL, 'ace', '1-4::
    1M dances across passing 1L RSh as 1L dances in, pulls back RSh to
    follow 1M who dances behind 2L+3L & across towards own side for…
5-8::
    3s+1s dance RH across, retain RH briefly but join LH with corners
9-16::
    3s+1s turn corners LH to end in 2nd/3rd place own sides; All 4
    couples turn partner RH. 3s+1s+4s finish facing up in allemande
    hold, 2s end in 1st place own side
17-24::
    3s+1s+4s dance allemande
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6943, '2013-08-21 08:31:33.416832+00', '2023-02-04 01:22:00.737484+00', 5437, 3, NULL, 'ace', '1-8::
    1s & 3s set & 3/4 turn RH into middle & dance 1/2 reel of 4 up/down
    ending with 1M+3L turning LH 3/4 to face 2s (Man facing Lady)
9-16::
    1M+3L+2s dance 1/2 reel of 4 across & end by turning LH to face
    partners, 3s+1s dance 1/2 reel of 4 in centre
17-24::
    1s & 3s set to prtnrs & 3/4 turn 2H to opp side, 1s remain in middle
    facing down NHJ; 1s+2s change places on sides (1s dance b''tw''n 2s),
    1s+3s change places with 3s (3s b''tw''n 1s) (All now on opp sides)
25-32::
    Reels of 3 on opp sides. Each couple crosses up RH from bottom place
    (starting with 1s) 3s cast down, 2s dance down NHJ to start.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6944, '2013-08-21 08:31:33.480377+00', '2023-02-04 01:22:00.933217+00', 7494, 3, NULL, 'ace', '{{explanation}}
Each couple dance 64 bars. A New Couple starts after 32 bars (ie on bars 1, 33, 65 & 97)

1-8::
    1s set, lead into the centre, passing Lady in front dance out sides
    (L between 2s & M between 4s) back to places & 1/2 turn LH
9-16::
    1s+3s in prom hold Adv+Ret 2 steps & dance to right behind side
    couples to opposite places
17-24::
    1s+3s dance Men''s Chain
25-32::
    All circle 8H round & back
33-40::
    (New Couple starts as at bar 1) as original 1s+3s dance R&L (RH to
    opp partner to start)
41-48::
    1s+3s in prom hold advance, 1/2 turn partner RH, dance 1/2 Diamond
    Poussette (to change places) & 1/2 turn RH back to original places
49-56::
    1s+3s dance interlocking Men''s Chain (all Men giving LH across in
    centre)
57-64::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6945, '2013-08-21 08:31:33.490296+00', '2023-02-04 01:22:00.968185+00', 14414, 3, NULL, 'ace', '1-4::
    1s+2s set & 1s cast 1 place _while_ 2s dance up 1 place
5-8::
    1s+2s set & 1s dance up 1 place into middle _while_ 2s cast down 1
    place into middle as 3s step into middle
9-16::
    1s+2s+3s dance Poussette to end  2 3 1 4
17-20::
    1s dance 1/2 Fig of 8 round 3s
21-28::
    All dance reflection reels of 4 on sides (2s & 1s dance in & down to
    start)
29-32::
    1s & 4s turn 1.1/2 times on sides (LH Ladies side & RH Mens side
    RH).  2 3 4 (1)', 0);
INSERT INTO 'dancecrib' VALUES (6946, '2013-08-21 08:31:33.498385+00', '2023-02-04 01:22:01.005465+00', 10023, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 on own sides (in & down to start)
9-16::
    3s dance Figs of 8 on own sides (in & up to start)
17-24::
    2s dance Figs of 8 on own sides (out & up to start)
25-32::
    1s+2s+3s dance mirror reels of 3 on own sides (1s in & down to
    start)
33-40::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of 8 up round 2s. End
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6947, '2013-08-21 08:31:33.506369+00', '2023-02-04 01:22:01.03312+00', 5441, 3, NULL, 'ace', '1-8::
    1s set twice to 2L & 1s turn 2H twice
9-16::
    1s set twice to 2M & 1s turn 2H twice
17-24::
    1s lead down the middle for 3 steps, back to top & cast to 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6948, '2013-08-21 08:31:33.51441+00', '2023-02-04 01:22:01.068483+00', 5440, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s set, cast 1 place & dance 1/2 reel of 3 on own sides (between 3s
    to start) to end facing 1st corners (pstn)
9-16::
    1s dance 1/2 reels of 4 with 1st corners, pass RSh & dance 1/2 reel
    with 2nd corners ending 2nd place opposite sides.  (2)(1)(3)

{{title}}
Reel

1-8::
    2s+1s+3s set, 1s dance 1/2 reels of 3 across (Lady with 2s & Man
    with 3s), 1s petronella turn to face own sides
9-16::
    1s dance Double Triangles ending in 2nd places own sides', 0);
INSERT INTO 'dancecrib' VALUES (15076, '2022-09-05 00:21:28.15839+00', '2023-02-04 01:22:01.095838+00', 20913, 3, NULL, 'ace', '{{explanation}}
2 chords: 2nd chord 1s & 4s cross to opp side

1-8::
    2s+3s dance RH across, retain RH & join LH with corners; all dance
    1/2 RH across. 2s & 3s end BtoB in centre facing corners
9-16::
    All set & 2s+3s dance La Baratte with corner person to change
    places.  1s+4s end BtoB in centre facing out nearest end
17-24::
    1s+4s dance out of ends, separate & cast in 1 place; 1L+4L also
    1M+4M turn 1.1/2 LH on sides. 1s face 3s at top, 4s face 2s bottom
25-32::
    All dance RSh reels of 4 on sides.  End (3) 1 4 (2)

{{explanation}}
Repeat Strathspey then twice in Reel time  
Note: recorded music 2x(S32+R32)', 0);
INSERT INTO 'dancecrib' VALUES (6949, '2013-08-21 08:31:33.522467+00', '2023-02-04 01:22:01.125628+00', 5443, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s set & dance RH across, 1s & 3s cast 1 place as 2s & 4s
    dance up 1 place
9-16::
    1s+4s+3s (middle 3 couples) dance reflection reels of 3 on sides
    with 1s dancing in & down to start
17-24::
    2s+1s & 3s+5s dance double Fig of 8 across with 2s & 5s casting to
    start
25-32::
    1s & 3s 1/2 turn RH to end in middle (1s facing down & 3s up), 1s &
    3s Set+Link & cast down 1 place on own sides.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (6950, '2013-08-21 08:31:33.530612+00', '2023-02-04 01:22:01.155462+00', 5444, 3, NULL, 'ace', '1-8::
    1s+2s set, 1/2 turn on sides & dance RH across all the way round
9-16::
    1s+2s dance 1/2 R&L & chase clockwise back to new places _while_
    3s+4s dance full R&L & turn last person to end 2 1 4 3
17-24::
    1s+4s+3s dance reel of 3 on sides (1s pass 4s RSh) ending with 1s &
    4s changing places RH to end 2 4 1 3
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10020, '2017-07-23 15:58:49.019476+00', '2023-02-04 01:22:01.187319+00', 15439, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels of 3 on sides, each couple crossing to opp side
    from top place (2s out/up, 1s cross down, 3s in/up to start)
9-12::
    2s dance up to 1st place as 1s cross down LH & cast to Right (1L
    down round 3L place, 1M up round 1M place)
13-16::
    1s cross RH up/down middle, cast to Right (1L round 1L place, 1M
    round 3M place).  End joining LH with partner facing 1st corner
    positions
17-24::
    1s dance Corner Targe :
::
    _17-20_   corners chase clockwise to next corner _while_ 1s 3/4 turn
    LH.  1s turn 3rd corner pstn RH (1M+3L, 1L+2M) _while_ 2nd corners
    set
::
    _21-24_   corners chase clockwise to next corner _while_ 1s 3/4 turn
    LH.  1s turn 2nd  corners pstn RH (1M+3L, 1L+2M ) to end in 2nd
    place opp sides  _while_ 2nd corners set.  End 3 (1) 2
25-28::
    1s dance 1/2 LSh reels of 3 on opp sides (1M down, LSh to 2L, 1L up,
    LSh to 3M)
29-32::
    1s dance 1/2 Fig 8, 1M up round 2s, 1L down round 3s to end in 2nd
    place own side', 0);
INSERT INTO 'dancecrib' VALUES (13916, '2021-04-05 00:21:24.123279+00', '2023-02-04 01:22:01.216158+00', 12375, 3, NULL, 'ace', '{{explanation}}
5 couple square set, 5s in centre, 5M facing 2s above 5L facing 4s

1-8::
    5s set, 1/2 turn RH; 5M+3s & 5L+1s dance LH across
9-16::
    5s turn 1.3/4 RH; 5M+2s & 5L+4s dance LH across
17-24::
    Reels of 3 up/down:  5M+3L+1M & 5L+1L+3M dance RSh reels of 3 (5s
    pass 3L/1L RSh to start)
25-32::
    5s dance La Barratte:
::
    _25-26_  5s set to partner
::
    _27-28_  5M 1/2 turns 5L RH & retains hand but at arm''s length from
    each other
::
    _29-30_  5M retraces steps with Lady turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies'' original
    place) & releasing Ladies'' RH she turns under Man''s left arm until
    almost in original places
::
    _31-32_  Couple change places LH to opposite places retaining LH
33-40::
    5s set, 3/4 turn LH; 5M+4s & 5L+2s dance RH across
41-48::
    5s turn 1.3/4 LH; 5M+1s & 5L+3s dance RH across
49-56::
    Reels of 3 across:  5M+4M+2L & 5L+2M+4L dance RSh reels of 3 (5s
    pass 4M/2M RSh to start). 5s end facing 1s, all 5 couples take
    allemande hold
57-64::
    5s+1s change places passing LSh, 1s+2s repeat; 2s+3s repeat, 3s+4s
    repeat. 4M turns 4L under raised right arm to end 4M facing 2s above
    4L facing 4s.  End 5 1 2 3 4', 0);
INSERT INTO 'dancecrib' VALUES (6952, '2013-08-21 08:31:33.54678+00', '2023-02-04 01:22:01.263273+00', 5446, 3, NULL, 'ace', '1-4::
    1s cross down below 2s & behind 3s to 4th place _while_ 4s cross up
    above 3s & behind 2s to 1st place (1s passing through sides before
    4s)
5-8::
    End couples change places RH or LH with next person on sides by
    dancing in & 2s & 3s out, all set on sides
9-16::
    Repeat bars 1- 8 with new end couples End 4 3 2 1
17-24::
    All cross RH & 1s & 3s face up, 2s & 4s down, all set & dance 1/2
    Reels of 4 on sides
25-32::
    1s cast 1 place, meet in middle & lead down to 4th place, all turn
    partner RH', 0);
INSERT INTO 'dancecrib' VALUES (6953, '2013-08-21 08:31:33.556516+00', '2023-02-04 01:22:01.408682+00', 9108, 3, NULL, 'ace', '1-8::
    1L followed by 2nd, 3rd & 4th Lady dances across, down behind Men &
    back to places
9-16::
    All Men repeat above Fig
17-24::
    All Ladies dance round their partners RSh & back to place, all Men
    repeat
25-32::
    1s lead down to 4th place & all clap 8 times', 0);
INSERT INTO 'dancecrib' VALUES (6954, '2013-08-21 08:31:33.564496+00', '2023-02-04 01:22:01.438536+00', 5450, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back ending with 1M between 2L+3L facing
    out & 1L between 2M+3M also facing out
9-16::
    2s+1s+3s Bal-in-Line on sides twice, 1s turn _while_ 2s step down &
    in to centre for Poussette
17-24::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6955, '2013-08-21 08:31:33.572594+00', '2023-02-04 01:22:01.459983+00', 5448, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s petronella turn & set, turn partners RH into prom hold
    facing 2M/3M (2s & 3s having stepped up/down)
9-16::
    1s+4s dance 1/2 RSh diagonal reel of 4 with 2M/3M & end facing other
    couple, 1s+4s set & turn other partner RH to face 2L/3L
17-24::
    1s+4s dance 1/2 RSh diagonal reel of 4 with 2L/3L & end on sides in
    order 3 4(1)(2), 1s+4s dance 1/2 R&L to end 3 1(4)(2)
25-32::
    All set forming a circle, cast (2 PdB) & chase clockwise 1/2 way.  2
    4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (4026, '2013-08-21 08:30:42.181751+00', '2023-02-04 01:18:28.449723+00', 164, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s set, cast 1 place, set advancing & turn 2H 1.1/4 times to lines
    across (1L facing 3M, 1M facing 2L)
17-24::
    1s dance reels of 3 across (1M with 2s & 1L with 3s giving RSh to
    2nd corner)
25-32::
    1s advance down/up & pivot to right, dance out ends (Man up, Lady
    down), cast right to 2nd place opp sides, 2s+1s+3s turn 2H (1s 1.1/2
    times)', 4);
INSERT INTO 'dancecrib' VALUES (12937, '2020-07-01 00:21:09.002539+00', '2023-02-04 01:22:01.491386+00', 17604, 3, NULL, 'ace', '1-8::
    1M followed by 1L casts behind 2M, crosses set, casts behind 3L &
    crosses to 3M''s place (2s+3s step up 7-8)
9-16::
    2s+3s+1s circle 6H round & back
17-20::
    2M+1L (1st corners pstns) change places RH, 1L curves into 1L place
    & 2M curves into 3M place _while_
::
    2L casts to 3rd place & 1M casts up to 1st place. 1 3 2
21-24::
    1s+3s+2s set, 1/2 turn partner RH remaining in middle facing down
    ready for…
25-32::
    1s+3s+2s dance 6 bars Allemande down, release RH & cross LH to own
    sides.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (12649, '2020-03-02 01:53:50.311344+00', '2023-02-04 01:22:01.533064+00', 18022, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate with 1s dance RSh round each other to face 1st
    corners
9-16::
    1s+1st corners dance Corner Pass+Turn, 1s pass RSh to face 2nd
    corners; 1s+2nd corners dance 1/2 diag reel of 4, 1s pass RSh to
    face 3rd corner
17-24::
    1s+3rd corners dance 1/2 diag reel of 4, 1s pass RSh to face 4th
    corners & dance Corner Pass+Turn.  1s end BtoB in centre facing own
    side
25-32::
    Modified Double Triangles:
::
    _25-28_   3s+1s+2s set as Double Triangles, 3s+2s change places RH
    on sides (with polite turn) as 1s rotate round to face opp side
::
    _29-30_   2s+1s+3s set as Double Triangles, 2s+3s cross RH to own
    side as 1s petronella turn to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6956, '2013-08-21 08:31:33.586993+00', '2023-02-04 01:22:01.572121+00', 5451, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All set & change places RH with corners, repeat back to place
17-24::
    All set NHJ & Ladies dance RH across & turn partners LH to places
25-32::
    Men cast round partner & dance anticlockwise 1 place, dance LH
    across & turn new partner RH to places
33-48::
    All dance Schiehallion Reel to end facing partner (on corner)
49-56::
    All dance La Baratte with partner:
::
    _49-50_  Man 1/2 turns partner RH & retains hand but at arm''s length
    from each other
::
    _51-52_  Man retraces steps, taking LH, with Lady turning right
    under Man''s arm briefly into Allemande hold (Man behind Lady facing
    Lady''s original place) & releasing Lady''s RH she turns under Man''s
    left arm until almost in original places
::
    _53-54_  All couples change places LH to opposite places
::
    _55-56_  All set ending ready for…
57-64::
    All poussette right round

{{explanation}}
Repeat in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (14010, '2021-05-03 00:21:16.252416+00', '2023-02-04 01:22:01.597763+00', 19829, 3, NULL, 'ace', '1-8::
    1s set. 1s dance 1/2 Fig of 8 down round 2s & 1/2 turn RH to finish
    in middle facing down with RH joined _while_ 2s set & turn RH to
    finish in middle facing up NHJ
9-16::
    1s+2s dance modified 1/2 Rondel:
::
    _9-10_  1s lead under arch made by 2s _while_ 2s dance up
::
    _11-12_ Men pass partner across in front & all cast to meet on
    opposite sides
::
    _13-14_ 2s+1s set NHJ on the sides
::
    _15-16_ 2s cross RH _while_ 1s turn LH to face 1st corners
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh & dance
    1/2 reel with 2nd corners to finish in 2nd place on opposite sides
    (3) (1) (2)
25-32::
    All chase 1/2 way round set, all turn RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8349, '2014-07-29 12:59:24.410961+00', '2023-02-04 01:22:01.826951+00', 15429, 3, NULL, 'ace', '{{explanation}}
Start all facing partners  
Chorus 1

1-8::
    All dance 1/2 Grand Chain (NO hands) & turn partners RH once round
9-16::
    Repeat 1-8 back to places, all turning RH into waltz hold facing
    centre
17-24::
    1s+3s slip step up/down to change places (Men pass BtoB) and slip
    step back to places (Ladies pass BtoB)
25-32::
    2s+4s repeat 17-24

{{title}}
Dance

1-8::
    1M+3M in centre dance own choice/style _while_ others circle Left (3
    bars), pivot R foot over L and chase back to places
9-16::
    1s+2L+4M & 3s+2M+4L (top/bottom 4 dancers) dance LH across, RH back,
    2M+4M finish in centre
17-24::
    Repeat 1-8 with 2M+4M in centre
25-32::
    4s+1L+3M & 2s+1M+3L (4 dancers each side) dance LH across, RH back,
    1L+3L finish in centre
33-48::
    Repeat 1-16 with 1L+3L in centre
49-64::
    Repeat 1-16 with 2L+4L in centre, all finish in waltz hold facing
    centre

{{explanation}}
Chorus 2

1-8::
    1s+3s slip step up/down to change places (Men pass BtoB) and slip
    step back to places (Ladies pass BtoB)
9-16::
    2s+4s repeat 1-8
17-24::
    All dance 1/2 Grand Chain (NO hands) & turn partners RH once round
25-32::
    Repeat 17-24 back to places, all turn RH into waltz hold facing
    centre', 0);
INSERT INTO 'dancecrib' VALUES (10530, '2018-03-20 06:27:12.574628+00', '2023-02-04 01:22:01.896668+00', 14418, 3, NULL, 'ace', '1-8::
    1s+2s dance Chain Progression :
::
    1s+2s 3/4 turn partner RH, 1M+2L turn LH 1.1/2 times as partners
    chase clockwise 1/2 way, 2s+1s turn partners 3/4 RH
9-16::
    2L+1M cross RH _while_ 1L+2M set, 1s+2s change places on sides
    passing RSh;  All chase 2 places clockwise round
17-24::
    2M+1L cross RH _while_ 1M+2L set, 1s+2s change places on sides
    passing RSh;  All chase 2 places clockwise round
25-32::
    2s followed by 1s dance down, end of bar 4 Ladies turn under Man''s
    arm & 1s & 2s dance up, remaining in centre ready for …
33-40::
    1s+2s Poussette', 0);
INSERT INTO 'dancecrib' VALUES (14586, '2022-02-05 02:21:15.353399+00', '2023-02-04 01:22:01.93489+00', 5455, 3, NULL, 'ace', '1-8::
    1s+4s Petronella turn to centre (2s & 3s step up/down) & all set;
    1s+2s also 3s+4s dance 1/2 RH across
9-16::
    1s+4s dance 1/2 reel of 4 up/down centre; 1s & 4s turn partners 3/4
    2H, 4s cast down to 2nd place _while_ 1s cast up to 3rd place. (2)
    (4) (1) (3)
17-24::
    All set on sides, 2s+4s also 1s+3s dance 1/2 RH across, all set on
    sides
25-32::
    All dance 1/2 reels of 4 on sides; all chase clockwise 1/2 round to
    end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6958, '2013-08-21 08:31:33.603486+00', '2023-02-04 01:22:01.952709+00', 12017, 3, NULL, 'ace', '1-8::
    1s lead down middle, cross over & cast up to 2nd pl _while_ 2s set &
    cross RH to 3rd pl _while_ 3s cast up to 1st place & cross RH, all
    turn RH  (3)(1)(2)
9-16::
    All Set+Link for 3 once, Men dance RH across _while_ Ladies also
    dance RH across
17-24::
    2L+1L+2M also 3L+1M+3M dance 1/2 reel of 3 across (1L RSh to 2L & 1M
    RSh to 3M to start), all Set+Link for 3 onto sides
25-32::
    1s dance Diag R&L (M down) to end 3 1 2 4

{{explanation}}
2nd time through, ends 3 4 1 2, 1s step to bottom & 3s become new 1s', 0);
INSERT INTO 'dancecrib' VALUES (10843, '2018-06-11 00:37:18.486787+00', '2023-02-04 01:23:09.503004+00', 12724, 3, NULL, 'ace', '{{explanation}}
Round the Room - 3 facing 3

1-8::
    All Adv+Ret, circle 6H 1/2 round
9-16::
    All Adv+Ret, circle 6H 1/2 round back to original places
17-24::
    Reels of 3, middle person RSh  to person on Right to start
25-32::
    All set twice, pulling back RSh 1/4 turn on last step & lines of 3
    chase to right passing opp line LSh to face new line of 3

{{explanation}}
Note: dancers at ends of lines have changed places to be on a different side of the middle person on each progression', 0);
INSERT INTO 'dancecrib' VALUES (13331, '2020-11-02 01:21:30.878+00', '2023-02-04 01:22:01.975718+00', 18380, 3, NULL, 'ace', '1-8::
    1s/3s cross partner NH into 1/2 Fig 8 (1M/3L round 4s, 1L/3M round
    2s) End in lines across (3M+1L facing 2s, 3L+1M facing 4s) & all set
9-12::
    2s/4s make arch & change places with facing couple who change
    places, Lady dancing under Man''s arm _while_ 2s+4s change places RH
13-16::
    2s/4s dance under arches made by side couples & change places, Lady
    dancing under Man''s arm _while_ 1s/3s change places RH with partner
17-24::
    4s+1M+3L also 2s+1L+3M circle 4H round to left opening out into 8H
    round to left. 3 2 1 4
25-48::
    2s & 4s repeat 1-24 from new places to end 3 4 1 2
49-56::
    3s+1s (at top/bottom) dance 1/2 R&L; 4s+2s (side couples) dance 1/2
    R&L. 1 2 3 4
57-64::
    All NHJ with partner set advancing (little) to form circle & all
    set; all dance 4 Spring Points & set turning to face partner
65-72::
    All birl with partner, ending back in square set, Men face in,
    Ladies face out
73-80::
    All dance interlocking Men''s Chain (Men LH across in centre).  End
    Men facing in, Ladies facing out
81-96::
    All dance Schiehallion reel, end facing partner', 0);
INSERT INTO 'dancecrib' VALUES (12873, '2020-06-03 16:27:28.212283+00', '2023-02-04 01:22:01.999627+00', 13923, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1M+2L set, 1M casts to 2nd place (2M steps up); 1L+2M set, 1L casts
    to 2nd place (2L steps up)
17-24::
    1s cross RH, 1s+3s change places LH on side; 1s cross RH, 1s+4s
    change places LH on side. 2 3 4 1
25-28::
    4s+1s set advancing & join hands in centre to form line
    (4M+4L+1M+1L) _while_ 3M/3L set advancing & 1/4 turn L/R _while_
    2M/2L set moving slightly L/R to form »Y« shape & all set
::
    …………2L
::
    ……………3L
::
    ………………...4M 4L 1M 1L
::
    ……………3M
::
    …………2M
29-32::
    2s set to partner _while_ 3s+4s+1s set retiring to places, all set.
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12419, '2019-12-05 01:31:38.327099+00', '2023-02-04 01:22:02.039356+00', 17529, 3, NULL, 'ace', '1-8::
    1s set, lead down (4 bars), set turning inward to face each other
9-16::
    1s lead up, cross & cast & turn LH to face 1st corners (2s step up
    13-14)
17-24::
    1s set to & turn 1st corner 2H, set to & turn 2nd corner 2H, finish
    in 2nd place opp sides
25-32::
    2s+1s+3s Adv+Ret; all turn RH to own side (1s turn 1.1/2 RH). 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9401, '2016-10-06 07:18:50.316753+00', '2023-02-04 01:22:02.065921+00', 17274, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s dance RH across (1L with 2s, 1M with
    3s)
9-16::
    1s dance reels of 3 on own sides (1M LSh to 2M, 1L LSh to 3L)
17-24::
    2s & 3s dance Double Figs of 8 round 1s (3s cross up as 2s cast to
    start)
25-32::
    1s+3s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (6959, '2013-08-21 08:31:33.738849+00', '2023-02-04 01:22:02.10288+00', 8339, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s dance between 3s & cast back to 2nd place
    as 2s+3s set & cross
9-16::
    Set+Link for 3, 1s dance round each other RSh to 1M facing down, 1L
    facing up & turn R about about to end BtoB (1M facing 3s at top, 1L
    facing 2s in 3rd place)
17-24::
    All set as Double Triangles, 1s petronella turn to end 1L between 3s
    (at top)/1M between 2s & all Set+Link for 3 to end 3 1 2
25-32::
    All set & cross RH & chase 1/2 way.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6960, '2013-08-21 08:31:33.74741+00', '2023-02-04 01:22:02.134652+00', 5458, 3, NULL, 'ace', '{{title}}
Strathspey

1-4::
    All Adv+Ret 1 step, turn partners RH (1s+2s to face up & 3s+4s to
    face down)
5-8::
    In Allemande hold 1s & 4s dance round to left onto sides facing in
    as 2s & 3s dance up/down to right & dance round to left to form Sq.
    Set
9-16::
    All Adv+Ret 1 step, turn partners RH, Ladies dance LH across once
    round as Men dance round clockwise 1/2 way
17-24::
    Repeat bars 9-16 & end facing own partner in diagonal lines
    (original 1L+2L also 3L+4L BtoB)
25-32::
    All set Highland step (or as Glasgow Highlanders)
33-40::
    All dance diagonal reels of 4 & end with Ladies on right of partners
41-48::
    All circle 8H round & back (ending in Sq. Set)

{{title}}
Reel

1-16::
    All dance full Schiehallion Reels
17-24::
    All set to partners & turn RH, Ladies dance LH across once round as
    Men dance round clockwise 1/2 way
25-32::
    Repeat bars 17-24 & Ladies end BtoB in centre facing partner
33-40::
    All set Highland step (Ladies 2 PdB+Spring points & Men High Cuts),
    right arm pivot turn to Ladies on partners right
41-48::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6961, '2013-08-21 08:31:33.755561+00', '2023-02-04 01:22:02.15623+00', 12027, 3, NULL, 'ace', '1-8::
    1s cross down to dance reels of 3 on opposite sides 1s end on
    opposite sides
9-16::
    5s cross up to dance reels of 3 on opposite sides 5s end on opposite
    sides _while_ 1s dance 1/2 Fig of 8 round 2s & 1.1/2 turn RH to face
    out
17-24::
    1s also 5s dance Figs of 8 on opposite sides (1s dancing out & down,
    5s dancing in & up)
25-32::
    1s cast to 5th place as others step up on bars 27/28, 5s+1s 1.1/2
    turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6962, '2013-08-21 08:31:33.763747+00', '2023-02-04 01:22:02.181659+00', 5460, 3, NULL, 'ace', '1-8::
    1s set & cast below 2s, turn 2H & dance up to top places
9-16::
    2s in prom hold dance reel of 3 across (RSh to 1L as 1s cast to
    start) & end in 1st places as 1s cast to 2nd places
17-24::
    1s prom hold dance reel of 3 across (RSh to 2L as 2s cast to start)
    & end in original places as 2s cast to places
25-28::
    1s cast 1 place _while_ 2s 1/2 turn 2H & dance up, 2s cast 1 place
    _while_ 1s 1/2 turn 2H & dance up
29-32::
    Original version - 1s cast 1 place _while_ 2s turn 2H moving up & 2s
    also 1s cross RH to own sides
::
    Later version     - 1s cast 1 place _while_ 2s 1/2 turn 2H & dance
    up & 1s cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6964, '2013-08-21 08:31:33.77978+00', '2023-02-04 01:22:02.227192+00', 10165, 3, NULL, 'ace', '1-8::
    1s+2s+3s petronella turn into centre, set & turn partner 1.1/4 times
    back to places
9-16::
    1s+2s+3s circle 6H round & back
17-24::
    1s+2s+3s advance, raise hands & retire, repeat
25-32::
    1s+2s 1/2 turn RH, twirl & dance out to opposite sides & chase
    clockwise to own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6965, '2013-08-21 08:31:33.787799+00', '2023-02-04 01:22:02.250415+00', 5463, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance RSh reels of 3 on own sides
9-16::
    1s lead down the middle & back to top
17-24::
    1s+2s dance Allemande 1s end facing 1st corners
25-32::
    1s turn 1st corners RH & turn partner LH, turn 2nd corners RH & pass
    partner RSh to end in Double Triangle position
33-40::
    1s dance Double Triangles', 0);
INSERT INTO 'dancecrib' VALUES (11465, '2019-01-01 01:57:43.756218+00', '2023-02-04 01:22:02.273344+00', 18972, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, turn LH to face 1st corners
9-16::
    1s dance 1/2 reel of 4 with 1st corners, pass LSh to dance 1/2 reel
    with 2nd corners & end BtoB in middle (1M facing up)
17-24::
    1s dance double triangles (up/down) & end with a petronella turn to
    2nd place opposite sides
25-32::
    1s dance 1/2 reel of 3 on opposite sides (RSh to 2nd corner
    position), all set & cross RH
33-40::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6966, '2013-08-21 08:31:33.908173+00', '2023-02-04 01:22:02.297311+00', 10166, 3, NULL, 'ace', '1-8::
    1s dance Inveran Reels with 2s+3s
9-16::
    1s cross RH, cast 1 place & turn RH to face 1st corners
17-24::
    1s dance RSh round 1st corner, pass RSh & dance RSh round 2nd corner
    to end 2nd place opposite side _while_ 1st corners dance in, 1/2
    turn RH, twirl & dance out to each others place, 2nd corners dance
    similarly.  (3)(1)(2)
25-32::
    1s dance 1/2 LSh reels of 3 across (Man at top with 3s & Lady at
    bottom with 2s), 1s dance 1/2 RSh reels of 3 on own sides (Man Down,
    Lady up)', 0);
INSERT INTO 'dancecrib' VALUES (6967, '2013-08-21 08:31:33.916264+00', '2023-02-04 01:22:02.332741+00', 5465, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on own sides (1s in & down to
    start)
9-16::
    1L followed by 1M dances Tandem Fig of 8 round 2s & ends crossing to
    opposite sides but with nearer hands joined.
17-24::
    1s dance down middle & 1/2 turn (1L under 1M''s arm) to own sides &
    dance up to the top
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11209, '2018-09-30 22:20:25.191098+00', '2023-02-04 01:22:02.383609+00', 18579, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s turn RH, cast right (1L to 3rd place,
    1M to top) 3L & 2M step up/down bars 7-8.  [Men''s side 1 2 3,
    Ladies'' side 2 3 1]
9-16::
    Top 3 couples dance 3 Couple Bourrel:
::
    _9-12_    1M+3L also 2M+1L set advcg & 3/4 turn 2H to line up/down
    middle then pull back RSh turning to face own prtnrs as 3M & 2L
    chase anticl''wise to face them
::
    _13-16_   All set & turn 2H to own sides, Men facing up, Ladies
    facing down.  3 1 2
17-24::
    3s+1s+2s chase 1/2 clockwise round, set; all pass partner RSh (Men
    make arches) & pull back RSh to face partner.  2 1 3
25-32::
    Reels of 3 across  (1L+3M at bottom & 1M+2L at top pass RSh).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13630, '2021-02-04 01:21:23.420202+00', '2023-02-04 01:22:02.425287+00', 16476, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate. 1M & 2L face out
9-16::
    2s+1s+3s dance 6 bar reel of 3 on sides (1s pass 2s RSh to start),
    Bars 15-16: 1s cross LH to take RH with 1st corner, LH with partner
17-24::
    1s+1st corners Bal-in-Line, 1s turn 1.1/4 LH to join RH with 2nd
    corner, 1s+2nd corners Bal-in-Line
25-32::
    1M+2s & 1L+3s dance 6 bar reels of 3 across (1s pass 3rd corner LSh
    to start), 1s cross to 2nd place own side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6969, '2013-08-21 08:31:33.93252+00', '2023-02-04 01:22:02.451444+00', 11874, 3, NULL, 'ace', '1-8::
    1s+2s dance La Girandole:
::
    _1-4_  1s+2s join hands & set, 1L+2M 3/4 turn RH _while_ 1M+2L cast
    up/down
::
    _5-8_  1s+2s dance RH across 3/4 way & turn partner RH 2s to own
    sides & 1s face 1st corners
9-16::
    1s dance 1/2 Reel of 4 with 1st crnrs & turn right about to face 4th
    crnrs, 1s dance 1/2 Reel of 4 with 4th crnrs & turn right about to
    face 3rd crnrs
17-24::
    1s dance 1/2 Reel of 4 with 3rd crnrs & turn right about to face 2nd
    corners, 1s dance 1/2 Reel of 4 with 2nd crnrs & pass RSh to own
    sides.
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13767, '2021-03-02 01:21:31.601734+00', '2023-02-04 01:22:02.480821+00', 11873, 3, NULL, 'ace', '1-8::
    1s+2s dance La Girondole:
::
    _1-4_ 1s+2s join hands & set, 1L+2M 3/4 turn RH _while_ 1M+2L cast
    up/down.
::
    _5-8_ 1s+2s dance RH across 3/4 way & turn partner RH. 2s back to
    own sides & 1s finish facing 1st corners.
9-16::
    1s+1st corners dance DoSiDo; 1s dance 1/2 diag reel of 4 with 1st
    corners. 1s pull back RSh to face 4th corner
17-24::
    1s+4th corners dance DoSiDo; 1s dance 1/2 diag reel of 4 with 4th
    corners. 1s pull back RSh to end BtoB in the centre, 2nd place
    facing own side.
25-32::
    1M+3s (at top) & 1L+2s (at bottom) dance RH across; 2s+1s+3s circle
    6H 1/2 round to left.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6970, '2013-08-21 08:31:33.940716+00', '2023-02-04 01:22:02.510477+00', 13466, 3, NULL, 'ace', '1-4::
    1s cross down to dance 1/2 Figs of 8 round 2s & 1s dance into middle
    (2nd place) as 2s step up
5-8::
    1L+2M+3M dance RH across as 1M+2L+3L dance LH across & end in Prom
    hold facing 3M
9-16::
    1s dance RSh reel of 3 across with 3s ending in 2nd pl & 1s facing
    4M
17-24::
    1s dance reel of 3 with 4s into middle with 4s ending in 3rd place &
    1s end in middle in 4th place
25-28::
    1L dances RH across with 4M+5M as 1M dances LH across with 4L+5L;
29-32::
    1s cast up round 5s & cross down to 5th place own sides (5s step Up)', 0);
INSERT INTO 'dancecrib' VALUES (9225, '2016-06-16 22:42:14.216009+00', '2023-02-04 01:22:02.540255+00', 5473, 3, NULL, 'ace', '1-4::
    1s 1/2 turn RH moving down to end in middle in 2nd place & set (2s
    step up 1-2)
5-8::
    1s cast and dance round 1st crnrs (1M round 3L, 1L round 2M) to end
    in middle LSh to LSh, 1M facing up & 1L facing down
9-16::
    1s dance RH across (1M+2L+3L & 1L+2M+3M), 1s pass RSh and dance LH
    across on other sides, pass LSh to face 2nd crnrs.
17-24::
    1s set to 2nd crnrs, change places RH with crnrs who turn LH in
    middle while1s set, 1s pass 2nd crnrs RSh & pull back RSh to end
    back to back facing 1st crnrs.
25-32::
    Repeat bars 17-24 with 1st crnrs with 1s dancing to 2nd place own
    side on bars 31-32.', 0);
INSERT INTO 'dancecrib' VALUES (6972, '2013-08-21 08:31:33.956967+00', '2023-02-04 01:22:02.568879+00', 5474, 3, NULL, 'ace', '{{explanation}}
2 Ch - 1M & 3M stand as 1L & 3L cross down to 2M/4M place who cross over to partners place as 2L/4L step up (Ladies on right of partners)

1-8::
    1M+2M also 3M+4M 3/4 turn RH & dance RSh round partner to places,
    1L+2L also 3L+4L repeat LSh
9-16::
    1s+2s also 3s+4s set & circle 4H round to left 1/2 way, set &
    petronella-in-tandem.  (1)2(3)4
17-24::
    1s & 4s  Set+Link twice & end on sides _while_ 2s+3s Set+Link with
    partner rotating to face partner then Set & Rotate with other prtnr
    to end (1)3(2)4
25-32::
    3s & 1s dance out between end cpls & cast back to place, all set &
    Men cast 1 pl clockwise as Ladies cross to end 3s+4s M side & 1s+3s
    L side', 0);
INSERT INTO 'dancecrib' VALUES (6973, '2013-08-21 08:31:33.965056+00', '2023-02-04 01:22:02.581889+00', 11980, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 R&L, 2nd+3rd place couples also bottom
    couples dance 1/2 R&L
9-16::
    Top couples also 3rd+4th place couples dance 1/2 R&L, 2nd+3rd place
    couples also bottom couples dance 1/2 R&L
17-24::
    1s (at bottom) cross RH, cast up _while_ others set & cross down 1
    place, 1s continue to top & cross RH to own sides
25-32::
    1s 1/2 turn next person on sides (dance out), 1/2 turn next person
    (dance in), 1/2 turn next person (dance out) & 1/2 turn bottom
    person, end 4 5 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4027, '2013-08-21 08:30:42.191548+00', '2023-02-04 01:18:28.462228+00', 4279, 3, NULL, 'ace', '1-8::
    1s+2s set & dance RH across 1/2 way, set & 1s turn LH to face 1st
    corners _while_ 2s cross RH
9-16::
    1s dance 1/2 reel of 4 with 1st corners, 1s turn LH to face 4th
    corners _while_ all 4 corners chase clockwise 1/2 way
17-24::
    1s dance 1/2 reel of 4 with 4th corners, 1L dances down between 3s &
    casts up to 2nd place _while_ 1M dances up & casts to 2nd place own
    sides
25-32::
    2s+1s+3s Adv+Ret & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6974, '2013-08-21 08:31:33.973906+00', '2023-02-04 01:22:02.60005+00', 10590, 3, NULL, 'ace', '1-8::
    1L+2L Set+Link _while_ 1M+2M Reverse Set+Link & 2s+1s+3s dance 1/2
    reels of 3 on own sides (1s in & down to start) 3 1 2
9-16::
    3L+1L Set+Link _while_ 3M+1M Reverse Set+Link & 1s+3s+2s dance 1/2
    reels of 3 on sides (3s in & down to start) 2 3 1
17-24::
    3s+1s 1/2 turn (Men RH, Ladies LH), 2s+1s 1/2 turn (Men LH, Ladies
    RH), 1s+2s dance 1/2 double Fig of 8 (1s cast, 2s cross up to start)
    (1) (2) 3
25-32::
    1s+2s turn RH into allemande hold facing up (as in The Knot) & dance
    Allemande', 0);
INSERT INTO 'dancecrib' VALUES (6975, '2013-08-21 08:31:33.981968+00', '2023-02-04 01:22:02.621409+00', 11286, 3, NULL, 'ace', '1-8::
    1s cross down to dance reels of 3 on opposite sides
9-16::
    1s on opp sides lead down middle & back ending 2nd pl for double
    triangles
17-24::
    1s dance Double triangles ending 2nd place opp sides
25-32::
    1s turn RH, dance half Fig of 8 (Lady round 2s & Man round 3s)', 0);
INSERT INTO 'dancecrib' VALUES (6976, '2013-08-21 08:31:33.990021+00', '2023-02-04 01:22:02.690186+00', 5476, 3, NULL, 'ace', '1-8::
    1s & 3s petronella turn into middle, 1/2 turn partners RH retaining
    hands set, 3/4 turn partners RH back to original places facing out
9-16::
    1s dance reels of 3 on own sides dancing out to start & end facing
    out
17-24::
    1s cast behind 2s as 2s dance lead up for 2 couple Promenade & end
    with 2s dancing out to top place _while_ 1s remain in middle
25-32::
    1M+2M turn LH _while_ 1L+2L turn RH, 1M+3M turn RH _while_ 1L+3L
    turn LH & 1s end 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6977, '2013-08-21 08:31:33.998123+00', '2023-02-04 01:22:02.715197+00', 10773, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig of 8 (1s cross down & 2s dance up to start -
    no cast)
9-16::
    1s cross down to dance reflection reels of 3 on opposite sides & end
    in centre at top facing down (Lady on Man''s right), 2s facing out
17-24::
    1s (Lady leading) dance an Alternating Tandem RSh reel of 3 across
    with 2s (RSh to 2M) & end in centre facing down, 2s in 1st place own
    side
25-32::
    1s dance down between 3s, cast up to 2nd place (opp sides), lead up
    between 2s, cross & cast to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6978, '2013-08-21 08:31:34.006299+00', '2023-02-04 01:22:02.740431+00', 5480, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    1s & 4s cross RH, cast in 1 place & dance 1/2 Figs of 8 round end
    couples
9-16::
    1s+4s dance 1/2 R&L, all dance 1/2 reels of 4 on sides
17-24::
    3s+1s also 4s+2s dance Men''s Chain
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15077, '2022-09-05 00:21:29.44911+00', '2023-02-04 01:22:02.932414+00', 20801, 3, NULL, 'ace', '{{explanation}}
Square set with 5s in centre, 5M back to 4s, 5L back to 2s

1-8::
    1s+2s+3s+4s chase clockwise round back to place _while_ 5s turn RH &
    turn LH finishing facing 1s
9-16::
    5s dance out between 1s, separate & cast, dance through centre,
    round 3s (1L RSh round 3L, 1M LSh round 3M) & into centre again
17-20::
    5L+2s dance RH across, 5M+4s dance LH across _while_ 1s & 3s turn
    partner RH
21-24::
    5L+1s & 5M+3s dance RH across _while_ 2s & 4s turn partner RH.  End
    5s facing 1s, all 5 couples take prom hold
25-32::
    5s+1s change places passing RSh, 1s+4s, 4s+3s, 3s+2s change places
    similarly.  End 2s in centre facing new top couple', 0);
INSERT INTO 'dancecrib' VALUES (14802, '2022-05-05 00:21:21.974229+00', '2023-02-04 01:22:02.990205+00', 17109, 3, NULL, 'ace', '{{explanation}}
2 Chords: 2nd chord 1M/3M stand as 1L crosses to 2M pl, 2M crosses to partners pl, 2L steps up, 3L crosses to 4M pl, 4M crosses to partners pl, 4L steps up

1-8::
    1s & 4s Set & Rotate, chase (Men leading) 1/2 round to change places
    _while_ 2s & 3s set, Adv+Ret, set
9-16::
    2s+4s also 1s+3s dance R&L all finishing with dancer opposite ready
    for …
17-24::
    All dance Poussette
25-32::
    All Set+Link with partner; 1s+3s also 2s+4s dance RH across
33-40::
    Repeat bars 1-8 to return to start positions (as Bar 1)
41-48::
    All circle 8H round & back

{{explanation}}
Repeat 1-48 with 2s & 3s leading', 0);
INSERT INTO 'dancecrib' VALUES (6979, '2013-08-21 08:31:34.014568+00', '2023-02-04 01:22:03.008529+00', 10008, 3, NULL, 'ace', '1-8::
    2s+3s+4s circle 6H round & back _while_ 1s & 5s wait for 4 bars then
    turn RH for 4 bars
9-16::
    1s & 3s dance Fig of 8 round couples below them
17-24::
    1s & 3s dancing between couple below turn them with nearer hand
    1.1/2 times, cast down behind next couple & lead up LH to face 1st
    corners
25-32::
    1s & 3s dance 1/2 diag reel of 4 with 1st corners, pass RSh & dance
    1/2 diagonal reel of 4 with 2nd corners, 1s pass RSh to face 3rd
    corners
33-40::
    1s & 3s dance 1/2 diag reel with 3rd crnrs & pass RSh to face
    partner in centre (Ladies face down & Men up) & dance 1/2 reel of 4
    in up/down
41-48::
    3s & 1s turn RH 1.1/4 times to 2nd/4th places (opp side). 3s+1s
    dance 1/2 Figs 8 across (Ladies dance up, Men down,3M+1L pass RSh)
    End 5 3 4 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6980, '2013-08-21 08:31:34.022616+00', '2023-02-04 01:22:03.019335+00', 5493, 3, NULL, 'ace', '1-8::
    1s dance DoSiDo, set & cast 1 place
9-16::
    1s dance 1/2 reels of 3 across (1M with 2s, 1L with 3s), 1s dance
    1/2 reels of 3 across with other couple
17-24::
    1s dance DoSiDo, set & cast 1 place
25-32::
    1s dance 1/2 reels of 3 across (1M with 3s, 1L with 4s), 1s dance
    1/2 reels of 3 across with other couple
33-40::
    1s set & cast 1 place, all turn partners RH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6981, '2013-08-21 08:31:34.032556+00', '2023-02-04 01:22:03.033629+00', 5495, 3, NULL, 'ace', '1-16::
    1s+2s+3s dance Grand Chain with turn on each LH & 1s end by turning
    RH
17-24::
    1s lead down the middle, cast up on opposite sides to 2nd places &
    turn 2H to face 2L (Lady on Man'' right)
25-32::
    1s set to 2L, turn inwards & set to 3M, set to 3L, turn inwards &
    set to 2M. 1s in middle face up
33-40::
    Mirror reels of 3 on sides, 1s dance up, 2s cast down & 3s cast up
    to start.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12650, '2020-03-02 01:53:54.593222+00', '2023-02-04 01:22:08.680252+00', 17044, 3, NULL, 'ace', '1-8::
    All set, 2L+1s (at top) & 2M+3s (at bottom) dance RH across, all set
9-16::
    All circle 6H round & back
17-24::
    1s+2s dance R&L (1 bar each hand); 2s+3s dance R&L starting RH on
    side (1 bar each hand)
25-32::
    1s+2s dance 1/2 Poussette; 1s+3s dance 1/2 Poussette.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4158, '2013-08-21 08:30:44.379924+00', '2023-02-04 01:18:37.3818+00', 9288, 3, NULL, 'ace', '1-8::
    1s+2s set advancing, 1s+2s NHJ slip step down below 3s, 2s followed
    by 1s cast up, 2s into 1st place, 1s into middle giving RH to 1st
    corner & LH to partner
9-16::
    1s+1st corners Bal-in-Line, 1s turn 1st corners RH to finish between
    corners. 1s dance 1/2 reel of 3 on opp sides (LSh to 2nd corner) &
    end with LH joined with ''new'' 1st corner person & RH with partner
17-24::
    1s+1st corners Bal-in-Line, 1s turn 1st corners LH & dance 1/2 reel
    of 3 across (RSh to 4th corners) 1s end 2nd place own sides
25-32::
    1s+person on left set & dance 1/2 RH across, 1s+person on right set
    & dance 1/2 LH across to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8176, '2014-02-10 10:26:15.957403+00', '2023-02-04 01:22:03.051255+00', 8514, 3, NULL, 'ace', '1-8::
    1s set,1M advancing as 1L turns about, 1L followed by 1M (in Tandem)
    cast 1 place, dance into centre as 2s step up.  1s+2s dance RH
    across
9-16::
    1s dance Tandem (1L leading, 1M following) reel of 3 with 2M+3M
    giving LSh to 3M & 1s end in centre
17-24::
    1s dance Tandem reel of 3 with 2L+3L giving RSh to 3L & 1s end in
    centre side by side, above 2s, facing down
25-32::
    1s cross below 2s to own sides, cast up round 3s to finish BtoB
    between 3s (1M facing 3M, 1L facing 3L), set, 1s 3/4 turn 3s (Men
    RH, Ladies LH, dancing down between 3s to end in 2nd place own side
::
    NB: At end 2nd time through, 1s+3s 3/4 turn with other hand (Men LH,
    Ladies RH) to finish in 4th place own side', 0);
INSERT INTO 'dancecrib' VALUES (9226, '2016-06-16 22:42:14.421788+00', '2023-02-04 01:22:03.256677+00', 12956, 3, NULL, 'ace', '1-8::
    1s+2s dance LH across & RH across. 1L face out
9-16::
    1L, followed by partner, casts, crosses above 2M, casts to 2nd place
    opp sides then crosses to 2nd place own side.  1s turn Right about
    ready for ...
17-24::
    1M, followed by partner, repeats 9-16 in reverse to original places
25-32::
    1s+2M dance 6 bar reel of 3 on Men''s side (1M+2M pass LSh as 1L
    crosses to bottom of reel). 1M+2M pass LSh as 1L crosses to top)
33-40::
    1s+2L dance 6 bar reel of 3 on Ladies'' side (1L+2L  pass RSh as 1M
    crosses to bottom of reel). 1L+2L pass RSh as 1M crosses to 2nd
    place)', 0);
INSERT INTO 'dancecrib' VALUES (6986, '2013-08-21 08:31:34.099629+00', '2023-02-04 01:22:03.433023+00', 5499, 3, NULL, 'ace', '1-8::
    1s+3s cross (1s under 3s arch), repeat back to place (3s under 1s
    arch)
9-16::
    2s+4s repeat
17-24::
    All Ladies dance Figs of 8 round partner & corner (in front of
    partner to start)
25-32::
    All Men dance Figs of 8 round partners & corners (in front of
    partner to start)
33-40::
    All Adv+Ret (1 step) & promenade anticlockwise 3/4 way round set', 0);
INSERT INTO 'dancecrib' VALUES (9227, '2016-06-16 22:42:14.459961+00', '2023-02-04 01:22:03.470009+00', 5500, 3, NULL, 'ace', '1-8::
    1s+2s+3s petronella turn into centre, set to partners & turn
    partners RH 1.1/4 times back to place
9-10::
    1s+2s set
11-16::
    1s lead down, cross below 3s & cast up to 2nd place opp sides, turn
    1/2 RH moving up to original places _while_ 2s cast up, follow 1s
    leading down, cross below 3s & cast up to 2nd place opp sides
17-24::
    1s+2s dance »The Whirligig«:
::
    _17-18_    1s+2s turn RH to line up/down middle, 1s facing Men''s
    side, 2s facing Ladies'' side, in promenade hold (Men LSh to LSh)
::
    _19-22_    1s+2s promenade anticlockwise nearly once round, then
::
    _23-24_    Dropping RH 2M passes 2L across to own side & 2s cast up
    to 1st place own sides _while_ 1s dance down, drop RH & 1M pass 1L
    across & 1s dance into 2nd place own sides & face out
25-30::
    Reels of 3 across:  3M+3L pass RSh as 1M casts down to enter reel
    _while_ 2L+2M pass RSh as 1L casts up to enter reel
31-32::
    1s turn RH to end in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (14011, '2021-05-03 00:21:17.532273+00', '2023-02-04 01:22:03.497757+00', 5502, 3, NULL, 'ace', '1-4::
    All 4 Ladies advance (2 skip change), join RH with partners, all set
    & end facing down in Promenade hold on Men''s side
5-8::
    All dance last 4 bars of Promenade (i.e. 4s followed by 3s+2s+1s
    dance up middle to end on sides 4 3 2 1)
9-16::
    All set to partner, 1s face 2s & 3s face 4s on sides & all set once;
    1/2 RSh reels of 4 on sides. All end in original places
17-24::
    1s+4s Petronella turn & set (4 bars); 1s+4s dance 1/2 RSh reel of 4
    finishing in middle (4M 4L 1M 1L)
25-32::
    4s+2s & 1s+3s dance RH across and LH back, 1s+4s remaining in middle
    ready for …
33-40::
    1s+4s dance 1/2 RSh reel of 4; 1s+4s set to partners & turn partners
    LH to original places
41-48::
    1s cross RH, cast; cross LH & cast to 4th place (2s+3s+4s step up
    7-8)', 0);
INSERT INTO 'dancecrib' VALUES (6987, '2013-08-21 08:31:34.107792+00', '2023-02-04 01:22:03.519783+00', 5503, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place & dance 1/2 Fig of 8 round 3s to end 2nd
    place on opposite sides
9-16::
    1s dance RH across (M with 2s, L with 3s), 1M followed by 2L also 1L
    followed by 3M pass RSh to change ends for LH across 2M/3L, 1M
    followed by 2L ends top of Ladies side & his partner at bottom of
    Men''s side
17-24::
    1s turn partner LH, 1st corner RH, 2nd corner LH, partner RH to face
    2nd corner
25-32::
    1s dance RSh reels of 3 on opposite sides & cross RH to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (12101, '2019-08-30 09:54:50.659475+00', '2023-02-04 01:22:03.552659+00', 19061, 3, NULL, 'ace', '1-8::
    Ladies dance RH across, dance LSh round partner to place & all set
9-16::
    Men dance LH across, dance RSh round partner to place & all set
17-24::
    Ladies petronella turn 1 place to right (anticlockwise) & all set ;
    Men petronella turn 1 place to right & all set.
25-32::
    All circle 8H round & back.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6988, '2013-08-21 08:31:34.115859+00', '2023-02-04 01:22:03.58202+00', 5504, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s set & cast in 1 place, cross RH & cast to ends to form lines
    across (1s between 2s & 4s between 3s)
9-16::
    1s+2s also 3s+4s Adv+Ret up/down, 1s+4s dance 1/2 R&L _while_ others
    turn RH on sides, all now in square set & facing corners
17-24::
    All set HS to corners & all turn corners 2H twice to end on
    sidelines
25-32::
    All set to partners, 4s+2s also 3s+1s dance 3/4 Fig of 8 (end
    couples cast to start) to end 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (10521, '2018-03-20 06:26:07.240077+00', '2023-02-04 01:18:31.370482+00', 12073, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig of 8 (1L up round
    2s, 1M down round 3s) to end facing 1st corners
9-16::
    1s dance diag reel of 4 with 1st corners
17-24::
    1s pass 1st corner RSh, dance across set, RSh round 4th corner, in
    through 2nd place own side & turn 1.1/4 RH to face 2nd corners
25-32::
    1s dance diag reel of 4 with 2nd corners, finishing in 2nd place own
    side
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10993, '2018-08-17 07:51:47.466873+00', '2023-02-04 01:18:35.206851+00', 14401, 3, NULL, 'ace', '1-8::
    1s lead down, on bar 4 1M crosses partner in front & 1L followed by
    1M cast up behind 4M & 3M & across into 2nd place facing  3L (2s
    step up 3-4)
9-16::
    1s (1L leading) dance 1/2 alternating tandem reel with 1st corners;
    1M continues reel with corners passing 3L LSh _while_ 1L+3M turn LH
    to face 2L
17-24::
    1s (1M leading) dance 1/2 alternating tandem reel with 2nd corners;
    1L continues reel with corners passing 2L LSh _while_ 1M+3L turn LH.
    1s end in 2nd place opp sides, 1L facing out
25-32::
    1s dance up, round 2s by RSh (1L behind 2M, 1M in front 2L) & 1M
    followed by 1L cast 1 place, across set to end in 2nd place own side
    (6 bars). All 3 couples set', 0);
INSERT INTO 'dancecrib' VALUES (4116, '2013-08-21 08:30:43.817095+00', '2023-02-04 01:18:35.236148+00', 11991, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    All dance 1/2 reels of 3 on sides, 1s & 3s pass LSh to start, all
    set & 2s cross RH as 3s+1s dance RH across 1/2 way
17-24::
    Set+Link for 3 twice ending 2 3 1
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6989, '2013-08-21 08:31:34.124519+00', '2023-02-04 01:22:03.620666+00', 9883, 3, NULL, 'ace', '{{explanation}}
5 couples arranged in circle

1-16::
    1s set to each other & 1M dances across between 3s/4s & casts into
    2M place, 1M joins hands with 2L & they set as  2M dances between
    4s/5s & casts into 3M place & sets with 3L as 3M repeats the figure…
    & so on until 5M sets with 1L
17-32::
    Repeat with top couple setting & 1L crossing between 3s & 4s pstns &
    casting into 5Ls place who crosses & casts into 4L etc…
33-40::
    All circle 10H round & back
41-48::
    Men cast 1 place anticlockwise _while_ Ladies dance into centre to
    form circle, all set Ladies turning out to face new partner, all
    change pl RH & set
49-56::
    Ladies cast 1 place clockwise to face original partner, all set &
    Men dance out & round partner back to original pstns
57-72::
    All set, dance 4 hands of Grand Chain, set, dance 6 hands of Grand
    Chain (1 bar to each hand) & set
73-80::
    Ladies cast 1 place clockwise _while_ Men dance into centre to form
    circle, all set & Men turn to face out, change places RH & set
81-88::
    Men cast 1 place anticlockwise to face new partner, set, Ladies
    dance to right & around new partner to end beside them
89-96::
    All circle 10H round & back
97-112::
    Repeat bars 17-32 beginning with 2M+5L (in 1st place) setting, then
    5L crosses & casts into her own place as 4L leaves for 4th place
    etc…
113-128::
    Repeat bars 1-16 beginning with 2M+1L setting, then 2M dances
    crosses & casts into 2M place 3M leaves for 3M place etc… back to
    orig pl', 0);
INSERT INTO 'dancecrib' VALUES (13631, '2021-02-04 01:21:24.219137+00', '2023-02-04 01:22:03.632881+00', 10783, 3, NULL, 'ace', '{{explanation}}
5 couple set in circle

1-16::
    1s set to each other & 1M dances across between 3s/4s & casts into
    2M place, 1M turns 2L RH as  2M dances between 4s/5s & casts into 3M
    place & turns with 3L as 3M repeats 5 couple set in circle the
    figure… & so on until 5M turns 1L
17-32::
    Repeat with top couple setting & 1L crossing between 3s/4s pstns &
    casts into 5L place & turns as 5L crosses & casts into 4L etc…
33-40::
    Men cast 1 place anticl''wise _while_ Ladies dance into centre to
    form circle, all set Ladies turning out to face new partner, all
    change pl RH & set
41-48::
    Ladies cast 1 place clockwise to face original partner, all set &
    Men dance out & round partner back to original pstns
49-56::
    All dance interlocking reels of 4 (RSh to partner)
57-64::
    All circle 10H round & back

{{explanation}}
Deviser states may be danced as Strathspey, Reel or Medley as desired', 0);
INSERT INTO 'dancecrib' VALUES (15421, '2023-02-04 01:22:03.655899+00', '2023-02-04 01:22:03.657171+00', 21339, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels of 3 on opposite sides, each couple crossing
    from top place. (1) (2) (3)
9-16::
    1s lead down (2 bars) & set; lead up (2 bars) & cast to 2nd place
    opp side (2s step up 15-16)
17-24::
    2s+1s+3s turn partner 2H (4 bars), dance RSh 1/2 round partner to
    face, pull back RSh & dance out to own side.  2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6990, '2013-08-21 08:31:34.140416+00', '2023-02-04 01:22:03.832637+00', 13606, 3, NULL, 'ace', '1-8::
    1s set & cross RH, 1s set to 2s on sides & 1/2 turn LH
9-16::
    1s+2s dance Ladies'' Chain & end with 1s facing 1st corners
17-24::
    1s set to 1st corners & turn 2H, 1s set to 2nd corners & turn 2H
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corner cross
    to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8350, '2014-07-29 12:59:24.883088+00', '2023-02-04 01:22:03.857854+00', 15456, 3, NULL, 'ace', '1-8::
    1s 3/4 turn RH to dance Crown Triangles & end facing 2nd corners
9-16::
    1s dance RSh reels of 3 on opposite sides & end turning LH to face
    1st crnrs
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    Pass+Turn with 2nd corners & end facing 1st corners
25-32::
    1s dance LSh reels on the side & cross over to own sides', 0);
INSERT INTO 'dancecrib' VALUES (4028, '2013-08-21 08:30:42.201773+00', '2023-02-04 01:18:28.475146+00', 13079, 3, NULL, 'ace', '1-4::
    1L+3M also 3L+5M set to each other & cast 1 place (Ladies down, Men
    up)
5-8::
    1L & 3L dance LSh round Lady below & in to face 2nd corner (pstn)
    _while_ 3M & 5M dance LSh round Man above & in to face 2nd corner
9-16::
    1L+3M also 3L+5M turn 2nd corners RH, each other LH, 1st corners RH
    & each other LH to face 4th corners (pstn)
17-24::
    1L+3M also 3L+5M dance diagonal reels of with 4th corners & end
    facing 3rd corners (pstn)
25-32::
    1L+3M also 3L+5M dance diagonal reels of with 3rd corners & end
    facing 2nd corners (pstn)
33-40::
    1L+3M also 3L+5M set to 2nd corners & turn right about to face each
    other (up/down) & set, turn RH 1.1/4 times to face 1st corners
    (pstn)
41-48::
    1L+3M also 3L+5M set to 1st corners & turn right about to face each
    other & set (across), cross RH & cast 1 place (Ladies down, Men up)
::
    to end: -    Ladies'' side:  2L    4L    1L    5L    3L  Men''s side:
    3M   1M   5M   2M   4M', 0);
INSERT INTO 'dancecrib' VALUES (4064, '2013-08-21 08:30:42.939079+00', '2023-02-04 01:18:31.394959+00', 228, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance 1/2 Grand Chain (1s cross to start) & dance 1/2 reel
    of 3 on opposite sides (2s out & up to start) end 1 2 3 on opp sides
9-16::
    1s+2s+3s dance 1/2 Grand Chain (1s cross to start) from new pstns &
    dance 1/2 reel of 3 on own sides to end in original places
17-24::
    1s dance down centre & cast up round 3s & in to face 1st corners, 1s
    dance 1/2 diagonal reel of 4 with 1st corners & pass LSh to face 2nd
    corners
25-32::
    1s dance 1/2 diagonal reel of 4 with 2nd corners ending in 2nd place
    opposite sides & 2s+1s+3s circle 6H round to left 1/2 way to end on
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (8624, '2015-02-13 12:48:10.769581+00', '2023-02-04 01:22:03.997108+00', 11894, 3, NULL, 'ace', '1-8::
    1s set, dance down, cast round 3s into 2nd place own sides and set
    (2s step up 5-6)
9-16::
    1s 1/2 turn RH, pull back RSh to face 1st corner (twirl). 1s dance
    1/2 reel of 4 with 1st corners. Finish 1L at top between 2L+3L, 1M
    between 2M+3M and 1s set
17-24::
    Repeat bars 9-16 with 2nd corners with 1s finishing in 2nd place
    opp. sides and 1s set
25-32::
    1s petronella turn and set, dance 1/2 reels of 3 across (man at top,
    lady at bottom) RSh to person on R to start
33-40::
    1s petronella turn to 2nd place own side, set, dance 1/2 reels of 3
    on sides, RSh to person on right to start', 0);
INSERT INTO 'dancecrib' VALUES (6991, '2013-08-21 08:31:34.153743+00', '2023-02-04 01:22:04.009966+00', 8075, 3, NULL, 'ace', '1-8::
    All Adv+Ret, All dance DoSiDo
9-16::
    1s+2s dance R&L
17-24::
    3s+4s dance RH across & LH back
25-32::
    1s cast to 4th place, 1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6992, '2013-08-21 08:31:34.168685+00', '2023-02-04 01:22:04.023297+00', 9884, 3, NULL, 'ace', '1-8::
    All dance 1/2 Grand Chain & set to partner
9-16::
    Repeat
17-24::
    1s+3s dance Ladies'' Chain
25-32::
    2s+4s dance Ladies'' Chain
33-40::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L
41-48::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L
49-56::
    1s+2s+3s set & turn partners, 1M+2L also 2M+3L set & turn
57-64::
    1M passes partner RSh to dance reel of 3 with partner & corner
    _while_ 3L dances likewise
65-72::
    1s+3s circle 4H round & back
73-80::
    1L dances Fig of 8 round 2s _while_ 1M dances round 4s
81-88::
    1M sets in turn to 2s, 3s, 4s & partner (They do not set back but
    clap in time to the music)', 0);
INSERT INTO 'dancecrib' VALUES (14132, '2021-07-07 00:21:01.957675+00', '2023-02-04 01:22:04.198628+00', 12594, 3, NULL, 'ace', '1-8::
    1s cross down RH (2s step up) & dance behind 3s; 1s meet & dance up
    between 3s & turn LH to face 1st corner
9-16::
    1s turn 1st corner RH, partner LH, turn 2nd corner RH & cross LH to
    2nd place own side
17-24::
    2s+1s+3s set & cross RH with partner; all set & turn partner 1/2 LH
    into prom hold facing up
25-32::
    2s+1s+3s Promenade. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6993, '2013-08-21 08:31:34.176951+00', '2023-02-04 01:22:04.21175+00', 13594, 3, NULL, 'ace', '1-8::
    1s & 3s dance 1/2 Fig of 8 down round 2s/4s, 1s+2s also 3s+4s turn
    1.1/2 times on sides (LH Ladies side, RH Mens side)  2(1)4(3)
9-16::
    All dance reflection reels of 4 on sides (LSh on Ladies side, RSh on
    Mens side)
17-24::
    1s & 4s dance out ends & cast in to places, 1s & 4s turn RH.
    2(1)4(3)
25-32::
    1s+4s set & dance 1/2 RH across, 4s & 3 s dance 1/2 Fig of 8 up
    round 2s/1s.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6994, '2013-08-21 08:31:34.185061+00', '2023-02-04 01:22:04.231451+00', 8509, 3, NULL, 'ace', '1-8::
    2s+3s circle 4H round to left, set, 2L casts & 2M dance down to 4th
    places _while_ 3M casts up & 3L dances up to 1st place
9-16::
    All dance 1/2 reel of 4 on sides, all set, 2s+4s also 1s+3s 1/2 turn
    RH on sides. 4 2 3 1
17-24::
    4s+2s also 3s+1s dance 1/2 R&L, 2s & 3s cross RH _while_ 4s+1s
    change places RH on sides, 2s+1s also 4s+3s dance full turn LH on
    sides
25-32::
    1s+4s dance RH across, 1L+4L dance up to top & cast on own side to
    3rd/2nd place _while_ Men dance down & cast up to 2nd/3rd place. 2 4
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (6995, '2013-08-21 08:31:34.202426+00', '2023-02-04 01:22:04.461309+00', 13827, 3, NULL, 'ace', '1-8::
    1s+2s set twice, face 2s & set twice
9-16::
    1s dance RSh reels on sides
17-24::
    1s set & cast to 2nd place, 1s turn RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7067, '2013-08-21 08:31:35.095295+00', '2023-02-04 01:22:09.664355+00', 5618, 3, NULL, 'ace', '1-8::
    All set on sides, 1s+2s & 3s+4s dance 1/2 RH across & all circle 8H
    1/2 way round to the left
9-16::
    All set, 1s+2s & 3s+4s dance 1/2 LH across & all circle 8H round to
    the right
17-24::
    1s dance down to 4th place own sides & turn to face 4s, also 2s face
    3s & all set HS
25-32::
    All dance reel of 4 on sides', 0);
INSERT INTO 'dancecrib' VALUES (4159, '2013-08-21 08:30:44.389917+00', '2023-02-04 01:18:37.412177+00', 385, 3, NULL, 'ace', '1-8::
    1s & 3s dance 1/2 Figs of 8 round couples below them & dance RH
    across with same couples
9-16::
    1s followed by 2s also 3s by 4s, lead down & 2s & 4s lead back;
    1s/3s end in lines across BtoB with ptnrs facing 2s/4s (Men face
    Men)
17-24::
    All dance RSh reels of 4 across dance; 1s & 3s end in a line down
    centre of dance (Men face up & Ladies down)
25-32::
    1s+3s dance 1/2 RSh reel of 4; turn partners 3/4 RH, 1s cast round
    4s to 4th place as 3s cast round 2s to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (12938, '2020-07-01 00:21:10.761421+00', '2023-02-04 01:22:04.475665+00', 5511, 3, NULL, 'ace', '1-4::
    1M followed by 1L & 4L followed by 4M cast to opposite ends _while_
    2M+3L turn RH to end in middle
5-8::
    4s+2M & 3L+1s dance LH across to end 1M & 4L facing out
9-16::
    Repeat bars 1-8 to finish in original places, 1M & 4L facing out
17-22::
    1L+4M pass LSh in the middle & cast up/down own side back to place
    _while_ 1M+4L cast down/up own side pass LSh in the middle back to
    place to end facing out
23-24::
    1s & 4s dance into the middle to join RH across _while_ 2s & 3s pass
    LSh on own sides to end of set, giving LH to 1s & 4s to form St
    Andrew''s Cross formation:
::
    ·2L···········2M
::
    …..4L··4M
::
    …..1L··1M
::
    ·3L···········3M
::
    ·······Top
25-28::
    All set. Drop hands in the middle, all turn 1/2 LH to bring 2s+3s
    into the centre
29-32::
    2s+3s join RH in centre, all set. All turn with left hand to finish
    in order 3 1 4 2 with 3M & 2L facing out, ready to start as new
    1st/4th couples. 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (15352, '2022-12-19 01:21:38.925897+00', '2023-02-04 01:22:04.517825+00', 21137, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place (2s step up); 1s dance 1/2 Fig 8 (1M up
    round 2s, 1L down round 3s) & pass LSh to face 1st corners
9-16::
    1s dance »Hello-Goodbye« setting to end facing 3rd corners
17-24::
    1s dance RSh diagonal reel of 4 with 3rd corners & end passing RSh
    to face 2nd corners
25-32::
    1s dance »Corners Pass and Turn Reel«
::
    _25-28_  1s & 2nd corners dance Corner Pass+Turn. On bar 28 1s pass
    LSh to face 4th corners
::
    _29-32_  1s & 4th corners dance Corner Pass+Turn. 1s finish in 2nd
    place own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12132, '2019-09-01 23:30:47.818554+00', '2023-02-04 01:22:04.539228+00', 19591, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place & 1s+4s dance LH across
9-16::
    2s+1s also 4s+3s dance RH across, 1s & 4s cross RH & cast back to
    places
17-24::
    1s+2s also 3s+4s dance double Fig of 8  (1s & 4s cross up/down to
    start)
25-32::
    1s dance down to bottom & cast into 4th place & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6997, '2013-08-21 08:31:34.243719+00', '2023-02-04 01:22:04.55642+00', 11708, 3, NULL, 'ace', '1-8::
    1s & 3s set, turn RH, 1L also 3M followed by partner casts down/up
    on own side & crosses to opposite side
9-16::
    3s+2s+1s circle 6H round & back
17-20::
    3s+1s set & petronella-in-tandem _while_ 2s set & petronella turn.
21-24::
    Repeat 17-20
25-32::
    1s+3s set & dance RH across _while_ 2s cross RH & chase clockwise
    1/2 way, 1s cast to 2nd place _while_ 2s cross up to 1st place. End
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6998, '2013-08-21 08:31:34.252153+00', '2023-02-04 01:22:04.577467+00', 13624, 3, NULL, 'ace', '1-8::
    1s set & cross RH, cast 1 place & set advancing turning right about
    to face 1st corner
9-16::
    1s dance 1/2 reel of 4 with 1st corners & pass RSh to face 2nd
    corner, dance 1/2 reel of 4 with 2nd corners & pass RSh to face 3rd
    corner (pstn)
17-20::
    1s dance 1/2 reel of 4 with 3rd corners & pass RSh to face 4th
    corner (pstn)
21-24::
    1s dance 1/2 reel of 4 with 4th corners & 1s turn RH to end Man
    facing Ladies side with partner behind him
25-32::
    1M followed by partner cast to 4th place (3s+4s step up) & cross
    over to end on own sides & all 4 couples clap, 4s+1s circle 4H round
    to left', 0);
INSERT INTO 'dancecrib' VALUES (15146, '2022-10-05 00:21:33.64928+00', '2023-02-04 01:22:04.606352+00', 21103, 3, NULL, 'ace', '1-8::
    1s+2s+3s+4s set, 1/2 turn partners RH flowing into 1s+2s also 3s+4s
    dance 1/2 RH across. 2s & 4s finish on sides, 1s & 3s turn partner
    RH to face 1st corners
9-16::
    1s & 3s dance Corners Pass+Turn with 1st corners, 1s+3s pass RSh &
    dance Corner Pass+Turn with 2nd corners. 1s & 3s finish in middle,
    Men facing up, Ladies facing down
17-24::
    All dance reels up/down:
::
    1s+3s reel of 4 in centre, Men''s side: 2M+4M+5M reel of 3 (4M RSh to
    5M), Ladies'' side: 2L+4L+5L reel of 3 (4L RSh to 2L).  2s, 4s & 5s
    end on sides in original places _while_ 1s & 3s remain in middle
    facing partner (Men facing up, Ladies facing down)
25-32::
    1s & 3s set twice; 1s & 3s turn partner 2H moving down to 3rd/5th
    place (4s & 5s step up 31-32).  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (12939, '2020-07-01 00:21:10.844431+00', '2023-02-04 01:22:04.619596+00', 9331, 3, NULL, 'ace', '1-8::
    1s+2s cross RH & dance 1/2 RH across to end 2M facing out; 1s+2s
    turn on sides (Ladies RH & Men LH) 2 1 3
9-16::
    2s+1s+3s dance reels of 3 on sides (1s in/down, 2s out/down & 3s
    out/up to start) 3s end facing out
17-24::
    1s & 3s dance double figs of 8 (1s cross down, 3s cast up to start)
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14681, '2022-03-07 02:21:23.847063+00', '2023-02-04 01:22:04.82884+00', 20656, 3, NULL, 'ace', '1-8::
    1s & 4s turn partner RH & cast in 1 place (2s & 3s step down/up
    3-4); 1s+4s dance LH across. 2 1 4 3
9-16::
    RSh reels of 4 on sides
17-24::
    1s+4s dance Espagnole:
::
    _17-18_   1s+4s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _19-20_   1s+4s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _21-24_   4s turn RH as 1s turn LH to end 2 4 1 3
25-32::
    All circle 8H round to left (6 slip steps), pivot & chase
    anticlockwise back to own sides. 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8351, '2014-07-29 12:59:25.065444+00', '2023-02-04 01:22:04.851368+00', 15062, 3, NULL, 'ace', '1-16::
    1s cross RH, cast, 2s+1s+3s dance R&L for 3 couples.  1s finish
    facing 4th corners RH joined
17-24::
    1s set to 4th corner, turn in, set to 2nd corner, 1s dance LSh round
    2nd corner, finish facing 1st corners RH joined
25-32::
    1s set to 1st corner, turn in, set to 3rd corner, 1s dance LSh round
    3rd corner, 1M casts down, 1L up into 2nd place own sides
33-40::
    1s dance RSh Reels of 3 on own sides (1M RSh to 3M, 1L RSh to 2L)', 0);
INSERT INTO 'dancecrib' VALUES (4065, '2013-08-21 08:30:42.948831+00', '2023-02-04 01:18:31.428543+00', 11800, 3, NULL, 'ace', '1-8::
    1s 1/2 turning 2s on sides (Men RH, Ladies LH) & dance Double
    Triangles, 1s end facing out on opposite sides retaining hands with
    2s
9-16::
    1s turn 2s, dance down to 3s, joining hands set in line & turn 3s
    into…
17-24::
    1s dance reflection reels of 3 on opposite sides (dancing between 2s
    to start)
25-32::
    1s dance 1/2 Fig of 8 round 2s to 2nd place own sides & 2s+1s+3s
    turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (11742, '2019-03-26 02:05:55.601843+00', '2023-02-04 01:22:04.87229+00', 15371, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up); 1s lead down, cross below 3s & cast
    up into 2nd place opp sides facing up
9-16::
    2s+1s+3s dance mirror reels of 3 on sides (2s out/down , 1s in/up,
    3s out/up)
17-24::
    1sd lead up to top, cross & cast to 2nd place own side; 1s turn RH
    to face down
25-32::
    2s+1s+3s dance mirror reels of 3 on sides (2s out/down, 1s in/down,
    3s out/up)
33-40::
    2s+1s+3s circle 6H round & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12739, '2020-04-11 10:52:46.248989+00', '2023-02-04 01:22:04.883898+00', 9654, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 (1L up between
    2s, 1M down between 3s) into 2nd place own side
9-16::
    2s+1s+3s turn partners RH; 1s turn LH 1.1/4 times to face 1st
    corners (position) _while_ 2s+3s dance clockwise 1/2 round
17-24::
    1s+1st corners dance 1/2 diag reel of 4, 1s pass LSh; 1s dance 1/2
    diag reel of 4 with 2nd corners (position), 1s 1/2 turn LH to end in
    centre facing up retaining LH
25-32::
    1s lead to top, cross to opp sides and cast one place; 1s cross RH
    to own side & cast to 3rd place (3s step up 31-32).  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (8352, '2014-07-29 12:59:25.072906+00', '2023-02-04 01:22:04.90316+00', 15073, 3, NULL, 'ace', '1-8::
    1s turn 1/2 RH, dance down, cast up round 3s into 2nd place opp.
    sides facing in.  Bars 7-8 2s dance up, face out as 3s dance down,
    face out, ready for..
9-12::
    2s+1s+3s dance 1/2 Reflection Reels of 3 on sides, (1s in & up,
    2s+3s casting into reels).  1s finish in middle NHJ facing 2s (in
    3rd place)
13-16::
    1s set to 2s, pivoting to right to face Men''s side, 1s set to 3M+2M
17-20::
    1M+2M turn LH and face each other as 1L+3M turn RH and face each
    other
21-24::
    1s dance 1/2 reels across (Man LSh to 2M & Lady RSh to 3M).  1s
    finish in middle NHJ facing Ladies'' side
25-28::
    1s set to 3M+2M, pivoting to right to face 2s (in 3rd place), 1s set
    to 2s
29-32::
    1M+2L turn RH and face each other as 1L+2M turn LH and face each
    other
33-36::
    3s+1s+2s dance 1/2 Reflection reels of 3 on side (1s in & down to
    start) 1s finish in middle, NHJ facing up
37-40::
    1s dance up to top, cast to 2nd place own sides as 2s+3s set and
    cross to own sides.', 0);
INSERT INTO 'dancecrib' VALUES (9229, '2016-06-16 22:42:14.740216+00', '2023-02-04 01:22:05.116602+00', 16285, 3, NULL, 'ace', '1-4::
    1s+2s cross RH with partner & set
5-8::
    1s+2s turn partners RH, 1s end in centre facing down (1L on 1M
    Right) in promenade hold.  1s+2s set
9-16::
    1s walk first 8 bars of "Gay Gordons" finishing at top facing down,
    2s step in (bar 16) also facing down (2L on 2M Right)
17-24::
    2s+1s dance inverted Allemande (2s lead down Men''s side to start).
    Bars 23-24 1s+2s turn partners 1/2 RH to own sides  2 1 3
25-32::
    2s+1s+3s circle 6H round to Left, step over, pivot and chase
    anticlockwise to place', 0);
INSERT INTO 'dancecrib' VALUES (7000, '2013-08-21 08:31:34.268209+00', '2023-02-04 01:22:05.136239+00', 13924, 3, NULL, 'ace', '1-8::
    1s set, cross RH & cast (2s step up), 1s turn 3/4 LH to give RH to
    1st corner
9-12::
    1s+1st corners Bal-in-Line, change places RH
13-16::
    1s set _while_ 1st corners turn LH once round, 1s+1st corners change
    places RH to end 1s joining LH with partner, RH with 2nd corner
17-24::
    1s+2nd corners repeat 9-16.  End 1s facing own side LH joined
25-32::
    1s 3/4 turn LH, dance out opp sides, chase anticlockwise to 2nd
    place own side _while_ 2s+3s dance R&L (change places RH on side to
    start). 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7001, '2013-08-21 08:31:34.278017+00', '2023-02-04 01:22:05.16076+00', 5518, 3, NULL, 'ace', '1-8::
    1M+3L also 2M+4L set & change places RH, 1L+3M also 2L+4M set &
    change places RH
9-16::
    1L+4L cross (between partners) & cast back to place as 1M+4M cross &
    cast inwards back to places, 1s & 4s turn corners (dancing out
    sides) to BtoB diagonally facing corners
17-24::
    All dance double diagonal reels of 4 giving LH in centre & 2s+1s
    also 4s+3s 1/2 turn RH on sides to end in original places
25-32::
    1s+2s set & dance 1/2 RH across; 1s+3s set & dance 1/2 LH across
33-40::
    1s+4s set & dance 1/2 RH across, all turn partners LH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (14803, '2022-05-05 00:21:24.155786+00', '2023-02-04 01:22:05.189311+00', 17110, 3, NULL, 'ace', '1-8::
    2s dance LSh round 1s _while_ 4s dance LSh round 5s; 2s+4s dance RH
    across
9-16::
    2L followed by 2M dance tandem reel of 3 on Ladies'' side (LSh to 1L)
    _while_ 4M followed by 4M dance tandem reel of 3 on Men''s side (LSh
    to 5M)
17-24::
    2s dance tandem reel of 3 on Men''s side (RSh to 1M) _while_ 4s dance
    tandem reel of 3 on Ladies'' side (RSH to 5L).  2s & 4s finish in
    original places
25-28::
    Top 3 Men (1M+2M+3M) also bottom 3 Ladies (3L+4L+5L) dance Set+Link
    for 3
29-32::
    Top 3 Ladies (1L+2L+5L) also bottom 3 Men (1M+4M+5M) dance Set+Link
    for 3, End Ladies'' side: 5L 1L 2L 3L 4L, Men''s side: 2M 3M 4M 5M 1M
33-40::
    All set, all turn new partner RH & set

{{explanation}}
Repeat with new partner', 0);
INSERT INTO 'dancecrib' VALUES (7002, '2013-08-21 08:31:34.286062+00', '2023-02-04 01:22:05.235106+00', 10782, 3, NULL, 'ace', '1-8::
    1M casts 1 pl as 2L casts up & pass RSh to change pls, 1M casts down
    on Ladies side as 2L casts up Men''s side & 1s+2s chase cl''wise to 2
    1 3
9-16::
    1M dances reel of 3 with 3s giving LSh to 3M, on bar 13 1M picks up
    partner in prom hold to complete reel & 1s end in 2nd place facing
    up
17-24::
    2s+1s+3s dance reflection reels of 3 on sides (1s dancing up between
    2s to start)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15422, '2023-02-04 01:22:05.26211+00', '2023-02-04 01:22:05.26323+00', 19639, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s to finish BtoB by curving in to face 2s
    in line across
9-16::
    1s+2s dance RSh reel of 4 across. Bars 15-16: 1s pass RSh to finish
    in 2nd place facing out, 2s finish in 1st place.  2 1 3 4
17-20::
    2s+1s+3s dance 1/2 reels of 3 on the sides (1s out & down to start)
    3 1 2 4
21-24::
    All dance 1/2 reels of 4 on the sides (3s+2s in & down to start).  4
    2 1 3
25-28::
    4s+2s also 1s+3s turn 1.1/2 times on sides (Ladies LH, Men RH).  2 4
    3 1
29-32::
    4s+3s turn 1.1/2 times on sides (Men LH, Ladies RH).  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7003, '2013-08-21 08:31:34.297483+00', '2023-02-04 01:22:05.299747+00', 14682, 3, NULL, 'ace', '1-8::
    1M+4L set & change places RH, 1L+4M set & change places LH
9-16::
    2s+3s dance 1/2 R&L, all set & cross RH
17-24::
    4s (at top) set & cast to 3rd place (3s+2s up), 3s+2s Set+Link
25-32::
    All circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4067, '2013-08-21 08:30:42.966864+00', '2023-02-04 01:18:31.643208+00', 231, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opp sides. 1s end in
    centre (2nd place) facing down (Lady on Man''s right), 2s in 1st
    place, 3s facing up
9-12::
    1s in centre & 3s on sides Adv+Ret 1 step, 1s turn 3s on sides (LH
    Ladies'' side & RH Men''s). 1s end in centre facing up, 2s face down
13-16::
    1s in centre & 2s on sides Adv+Ret 1 step, 1s turn 2s on sides (RH
    Ladies'' side & LH Men''s). 1s end facing 1st corners
17-24::
    1s set to 1st corners, dance clockwise round each other to face 2nd
    corners. 1s set to 2nd corners, dance clockwise round each other to
    2nd place own sides
25-32::
    1s dance reels of 3 on own sides, 1M+2M also 1L+3L passing RSh to
    start.', 0);
INSERT INTO 'dancecrib' VALUES (7004, '2013-08-21 08:31:34.306409+00', '2023-02-04 01:22:05.332133+00', 13682, 3, NULL, 'ace', '1-16::
    1s+2s+3s dance Dunans Reel of 3:
::
    1s dance out & down then cross down to 3rd place opp side (each
    subsequent dancer cross similarly) to dance reflection reels of 3 on
    opp sides
::
    1s dance out & down then cross down to 3rd pl own side (each
    subsequent dancer cross similarly) to dance remaining part of reel
    of 3 on own sides
17-24::
    1s cast down to 2nd place & cross RH to face 1st corners, 1s set to
    1st corners & set to 2nd corners
25-32::
    1s dance reels of 3 on opposite sides passing corners RSh 1s end
    crossing RH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (7005, '2013-08-21 08:31:34.316192+00', '2023-02-04 01:22:05.457582+00', 5519, 3, NULL, 'ace', '{{explanation}}
4 Ladies in diamond formation with 1 Man in middle

{{title}}
Strathspey

1-8::
    Man dances a reel of 3 with 1L+3L _while_ 2L+4L dance clockwise
    round outside 1/2 way & back to places
9-16::
    All set with Man facing 1L & turning in centre to end facing 4L
17-24::
    Man dances a reel of 3 with 4L+2L _while_ 1L+3L dance clockwise
    round outside 1/2 way & back to places
25-32::
    All set with Man facing 4L & turning in centre to end facing 3L

{{explanation}}
Reel	Repeat bars 1-32 but Man reels with 3L+1L & after setting faces 2L on bar 16, then reels with 2L+4L & after setting faces 1L', 0);
INSERT INTO 'dancecrib' VALUES (7006, '2013-08-21 08:31:34.322331+00', '2023-02-04 01:22:05.477074+00', 9885, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place & dance RH across (1s end facing
    up & 4s down) _while_ 2s & 3s set & cross over. (2) (1) (4) (3)
9-16::
    1s dance 1/2 Fig of 8 up round 2s as 4s dance 1/2 Fig of 8 down
    round 3s All set, 2s & 3s cross LH as 1s+4s change pl LH on sides. 2
    4 1 3
17-24::
    2s+4s+1s+3s dance full reel of 4 on sides
25-32::
    All circle 8H round & back to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7007, '2013-08-21 08:31:34.340031+00', '2023-02-04 01:22:05.528368+00', 5522, 3, NULL, 'ace', '1-8::
    1s cross RH, cast to 2nd place (2s step up), 2s+1s dance RH across
9-16::
    1s cross LH, cast to 3rd place (3s step up), 3s+1s dance LH across
17-24::
    1s dance up to top, cast 1 place on own side, dance down between 3s
    & cast up to face 1st corners (3s step down)
25-32::
    1s dance reel of 4 with 1st corners & dance round each other passing
    RSh to end facing 2nd corners
33-40::
    1s dance reel of 4 with 2nd corners & end in 2nd places own sides
41-48::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7008, '2013-08-21 08:31:34.353415+00', '2023-02-04 01:22:05.681624+00', 5525, 3, NULL, 'ace', '1-8::
    1s set & cast below 3s, lead up to face 1st corners
9-16::
    1s set & turn 1st corners RH to balance in diagonal line, set & 1s
    turn LH to face 2nd corners
17-24::
    1s set & turn 2nd corners RH to Bal-in-Line, set & 1s turn LH to 2nd
    place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7009, '2013-08-21 08:31:34.361473+00', '2023-02-04 01:22:05.712137+00', 10333, 3, NULL, 'ace', '1-8::
    4s cast up round 3s & dance up between 2s, cast up round 1s & dance
    down to 4th places
9-16::
    1s cast down round 2s & dance down between 3s, cast down round 4s &
    dance up to 1st places
17-24::
    2s+3s dance RH across, 2s dance up between 1s & cast back to places
    _while_ 3s dance down between 4s & cast back to places
25-32::
    All circle 8H round & back
33-40::
    All dance 1/2 reels of 4 on sides, top 3 couples dance 1/2 reel of 3
    on sides to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7010, '2013-08-21 08:31:34.369556+00', '2023-02-04 01:22:05.746088+00', 8088, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Figs of 8 (Lady round 2s & Man
    round 3s) to end 2nd place on own sides
9-16::
    1s dance reels of 3 on sides giving LSh to 3rd corner & ending in
    diagonal line RH joined & LH to 3rd corners
17-24::
    1s dance the Spoke - Bal-in-Line, 1s move clockwise to 2nd corner,
    repeat with 1st corner & 4th corner, 1s ending in 2nd place
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7011, '2013-08-21 08:31:34.377623+00', '2023-02-04 01:22:05.779042+00', 8956, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s cross RH & cast in 1 place to join hands to form a circle,
    set twice turning right about to face nearest corner
9-16::
    2s & 3s dance full diagonal RSh reels of 4 giving LH in centre
    _while_ 1s & 4s dance 1/2 diagonal RSh reel & pass LSh in centre to
    face next corner anticl''wise; dance 1/2 RSh reel with that corner &
    pass LSh in centre to face next corner anticlockwise
17-24::
    4s & 1s turn corners RH & dance LH across 1/2 way, turn diagonally
    opposite corners RH & 1s+4s change places LH on the sides
25-32::
    All dance RSh reels of 4 on sides.  2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (7012, '2013-08-21 08:31:34.385651+00', '2023-02-04 01:22:05.815097+00', 5529, 3, NULL, 'ace', '1-8::
    1s 1/2 turn 2s on sides (1M RH - 1L LH) to face out, 2s+1s+3s set,
    1s 1/2 turn 3s on sides (1M LH - 1L RH) end 3s facing out & 2s+3s+1s
    set
9-16::
    1s followed by 3s dance up between 2s, cast down 1 place, dance in &
    1s cast up to 2nd place 3s end in 3rd place
17-24::
    1s turn 1st corners RH, pass partner RSh turn 2nd corners RH & cross
    passing partner RSh to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13632, '2021-02-04 01:21:25.929907+00', '2023-02-04 01:22:05.854492+00', 5530, 3, NULL, 'ace', '1-8::
    1s cast (2s step up) & set; 1s cast up (2s step down) & set
9-16::
    1s dance Fig 8 on own sides (in front of 2s to start)
17-24::
    1s+2s dance RH across; 1s set to 2s (1 step to R), 1M+2L & 1L+2M set
    (1 step to left), 1s+2s set advancing into centre ready for …
25-32::
    1s+2s dance Poussette.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7015, '2013-08-21 08:31:34.411674+00', '2023-02-04 01:22:06.204922+00', 13467, 3, NULL, 'ace', '1-8::
    1s dance RSh reels of 3 on sides. 1L ends facing out with partner
    behind her
9-16::
    1L followed by partner casts 2 places & cross to opp sides, 3L+1M
    also 3M+1L change pls RH then 2L & 1M also 2M & 1L change pls LH.
    (1)2 3 4
17-24::
    1s dance LSh reels of 3 on sides & 1L ends facing out.
25-32::
    1L followed by partner casts 2 places & cross to own sides, 1L+4L
    also 1M+4M turn RH 1.1/2 times.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12102, '2019-08-30 09:54:51.350785+00', '2023-02-04 01:22:06.237052+00', 19059, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Inveran reels (6 bars), 1s pass RSh to face 1st
    corners as 2s dance up to 1st place
9-16::
    1s turn 1st corner RH, pass RSh; 1s+2nd corners dance 1/2 diag reel
    of 4. 1s pass RSh to face 3rd corner
17-24::
    1s turn 3rd corner RH, pass RSh; 1s+4th corners dance 1/2 diag reel
    of 4.  1s end in 2nd place own side
25-32::
    1s dance 1/2 Fig 8 down round 3s, cross down & 1/2 turn 4s (Ladies
    RH, Men LH). 3s step up bars 29-30
33-40::
    All circle 8H round & back.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13633, '2021-02-04 01:21:26.386649+00', '2023-02-04 01:22:06.497796+00', 5534, 3, NULL, 'ace', '1-8::
    1L dances between 2s & leads 2s down centre followed by 1M; all turn
    right about & 1M leads 1L+2s back up, 1M casts to 2nd place own
    side, 1L dances into 2nd place own side & 2s dance up to 1st place
9-16::
    2s+1s+3s circle 6H round & back
17-24::
    2s+1s+3s Adv+Ret; 1L cast up, 1M casts down to end 1L between 2s
    facing down, 1M between 3s facing up
25-32::
    1s turn RH & face down; 3s+4s make arches (2 bars) & dance up 1
    place (2 bars) _while_ 1s dance under arches to 4th place
33-40::
    2s+3s & 4s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7819, '2013-08-21 08:31:49.111988+00', '2021-04-05 21:55:25.900252+00', 6899, 3, NULL, 'ace', '1-8::

    1s+2s also 3s+4s circle 4H round & back with 1s ending in prom hold

    facing Men''s side

9-16::

    1s cast down behind 2M, cross, cast down behind 3L, lead down &

    cross to 4th place own side

17-24::

    3s petronella turn into lines of 3 across (L between 2s & M between

    3s), set, petronella turn onto opposite sides & set on sides

25-32::

    3s face persons on right & dance 1/2 RSh reel of 3 on sides, 1/2

    reel of 3 across (3M in 1st pl & 3L in 3rd pl) to end 2nd place on

    own sides (2s & 4s dance complete reels of 3 on own sides)

33-40::

    2s cast 1 place, turn RH for 4 bars & cast on own side to 3rd place.

    (3 4 2 1)

41-64::

    Repeat bars 17-40 (4s starting) to end 4 2 3 1

65-88::

    Repeat bars 17-40 (2s starting) to end 2 3 4 1

89-96::

    4s followed by 3s+2s lead down between 1s & cast up on own side to

    end 4 3 2 1', 0);
INSERT INTO 'dancecrib' VALUES (12557, '2020-02-02 02:49:19.206215+00', '2023-02-04 01:22:06.520452+00', 19798, 3, NULL, 'ace', '1-8::
    1s lead down (3 bars), lead up, cross & cast (2s step up 7-8)
9-16::
    _1/2_ Diag R&L (1M up, 1L down to start) _while_ 2L & 3M chase
    clockwise half way to change places. 1s dance RH across (1L with 3s
    in 1st place, 1M with 2s in 3rd place)
17-24::
    LSh reels of 3 across (Man down, Lady up). 1s pass LSh to face 1st
    corners (pstn)
25-32::
    1s+1st corners dance 1/2 diag reel of 4, 1s pass LSh & 1s+2nd
    corners (pstn) dance 1/2 diag reel of 4, 1s pass RSh to end 2nd
    place own side
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10093, '2017-09-03 23:45:18.272005+00', '2023-02-04 01:22:06.53913+00', 17782, 3, NULL, 'ace', '{{explanation}}
Round the Room, 2 facing 2

1-8::
    All dance DoSiDo with partner, all couples Adv+Ret
9-16::
    Interlocking reels of 4, all pass opp person RSh to start
17-24::
    All circle 4H round & back
25-32::
    All dance 1/2 RH across with opp couple, 1/2 LH across with next
    couple, then RH across (4 bars) with couple after next', 0);
INSERT INTO 'dancecrib' VALUES (15353, '2022-12-19 01:21:40.700465+00', '2023-02-04 01:22:06.569159+00', 21164, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate. 1s finish facing 1L''s 1st corner, 1 M leading
9-12::
    1s RSh Alternating Tandem 1/2 diag reel of 3 with 1st corners. 1s
    finish facing 1L''s 2nd corner, 1L now leading
13-16::
    1s RSh Alternating Tandem 1/2 diag reel of 3 with 2nd corners
17-20::
    3s+1s+2s dance 1/2 reels of 3 on sides(1s pass 2s in 3rd place RSh
    to begin). 1s finish facing 1M''s 1st corrner, 1M leading
21-28::
    Repeat bars 9-16. 1s end in 2nd place own sides facing up
29-32::
    3s+1s+2s dance 1/2 reels of 3 on sides (1s pass 3s in 2nd place RSh
    to begin)
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7016, '2013-08-21 08:31:34.419671+00', '2023-02-04 01:22:06.594709+00', 5536, 3, NULL, 'ace', '1-8::
    1s dance in & cast off behind own lines for 4 bars, 1s cast back up
    to place
9-16::
    1s+2s circle 4H round to left, 1s turn 2H as 2s step up & all set in
    line of 4 with 1s advancing to pass each other LSh
17-24::
    1s+2s dance reel of 4 across
25-32::
    All set, 1M+2L turn 3/4 RH as 1L+2M turn 3/4 LH to end with 1s in
    2nd place on opp. sides; 1s dance 1/2 Fig 8 round 2s into 2nd place
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (9230, '2016-06-16 22:42:14.91256+00', '2023-02-04 01:22:06.710851+00', 17026, 3, NULL, 'ace', '{{explanation}}
Round the Room dance with 2 couples facing 2 couples (Men between partners)

1-8::
    All circle 8H round & back
9-16::
    All set to partners & turn RH, Men dance 1/2 RSh reels of 4 with
    partners
17-24::
    All set to partners & turn RH, Men dance 1/2 RSh reels of 4 with
    partners
25-32::
    All dance 1/2 Grand Chain (start RSh to partner) & end facing next 2
    couples', 0);
INSERT INTO 'dancecrib' VALUES (7017, '2013-08-21 08:31:34.455763+00', '2023-02-04 01:22:06.741043+00', 8172, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance 1/2 reflection reels of 3 on own sides (1s dancing in
    between 2s to start), 3s+2s+1s set & cross RH
9-16::
    3s+2s+1s dance 1/2 reflection reels of 3 (all on opposite sides),
    1s+2s+3s set, 3s cross back RH as 1s+2s turn RH ready for Poussette
17-24::
    1s+2s dance Poussette
25-32::
    1s dance reels of 3 across (M with 2s & L with 3s) giving RSh to 2nd
    corners
33-40::
    1s dance RH across (M with 3s & L with 2s), 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (11743, '2019-03-26 02:05:56.060792+00', '2023-02-04 01:22:06.766197+00', 19236, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up) and finish in prom hold facing 2L; 1s
    dance 1/2  diag reel with 2nd corners (RSh to 2L to start)
9-12::
    1L dances 1/2 RSh reel of 3 with 1st corners (RSh to 2M to start)
    _while_ 1M dances down & casts up round 3L to 2nd place on opp side
13-16::
    1s take prom hold & dance 1/2 RSh reel of 3 with 2nd corners (RSh to
    2L in 3M''s place to start)
17-20::
    1M dances 1/2 LSh reel of 3 with 1st corner positions (LSh to 3L in
    1M''s place to start) _while_ 1L dances down & casts up into 2nd
    place own side
21-24::
    1L+2s (at top) & 1M+3s (at bottom) dance RH across, 1s finish in 2nd
    place own side.
25-32::
    1s & 3s dance The Bourrel:
::
    _25-28_   1M+3L set advancing, 3/4 turn 2H & twirl to end BtoB (Lady
    facing up & Man down) _while_ partners chase anticlockwise to face
    partner
::
    _29-32_   1s & 3s set to partners & turn 2H to own sides having
    changed places.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (11466, '2019-01-01 01:57:45.049273+00', '2023-02-04 01:22:06.783705+00', 18973, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 on own sides (down between 2s to start)
9-16::
    2s dance Figs of 8 on own sides (out & up behind 1s to start)
17-24::
    3s dance Figs of 8 on own sides (up between 2s to start)
25-32::
    1s dance reflection reels of 3 on own sides (down between 2s to
    start)
33-40::
    1s dance down (2 bars) & back, 1s cast to bottom as 2s+3s+4s step up', 0);
INSERT INTO 'dancecrib' VALUES (13031, '2020-08-10 00:18:27.479451+00', '2023-02-04 01:18:31.659316+00', 232, 3, NULL, 'ace', '1-8::
    1L+2M turn 1.1/2 RH to change places; 1s+2s set to partners on sides
    & turn RH
9-16::
    RSh reels of 3 on sides, 1s+2s pass partner RSh to start
17-24::
    1M+2L turn 1.1/2 LH to change places; 1s+2s set to partners & cross
    RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7018, '2013-08-21 08:31:34.476171+00', '2023-02-04 01:22:06.846069+00', 12957, 3, NULL, 'ace', '1-8::
    1s+2s set to partner & cross RH.  1s+2s set on sides, then 1s+2s
    change places (Men RH, Ladies LH) 1s face out
9-16::
    2s+1s+3s dance mirror reels of 3 (2s cross down, 1s out/up, 3s in
    up) 1s face up  2 (1) 3
17-24::
    1M+2L+3L dance RH across as 1L+2M+3M dance LH across, 1s pass RSh
    1M+2M+3M dance LH across as 1L+2L+3L dance RH across.  1s finish
    BtoB facing own sides ready for ...
25-32::
    Double Triangles, 1s finish in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (14376, '2021-10-11 22:41:37.640517+00', '2023-02-04 01:22:07.032759+00', 17150, 3, NULL, 'ace', '1-8::
    1s set, turn 1/2 2H to finish in middle facing down NHJ. 1s dance
    down for 2 steps, turn 2H (no extra turn) to face 1st corners (2s
    step up bars 5-6)
9-16::
    1s set to & turn 1st corners, 1s set to & turn 2nd corners finishing
    in lines across, 1L between 3s & 1M between 2s all facing down
17-24::
    Both lines dance down for 4 steps, pull back RSh & dance back up. On
    bar 24 1M pulls back RSh to face down
25-30::
    1s dance reel of 3 across, 1s giving RSh to person on their right
    (1M RSh to 2M, 1L RSh to 3L)
31-32::
    1s dance a Petronella turn to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7020, '2013-08-21 08:31:34.498252+00', '2023-02-04 01:22:07.050929+00', 5542, 3, NULL, 'ace', '1-8::
    1s cast 1 place, cross passing LSh & dance RSh round 1st corner,
    meet in middle & 3/4 turn RH to face 1st corners
9-16::
    1s dance reel of 4 with 1st corners as 2s+3s dance interlocking
    reels of 3 on sides with 1s, 1s end facing 1st corners
17-24::
    1s dance "Hello-Goodbye" setting, 1s advance towards each other &
    turn right about, Man facing up & Lady down
25-32::
    1s dance Double Triangles up/down & petronella turn to 2nd places
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (12740, '2020-04-11 10:52:47.789434+00', '2023-02-04 01:22:07.08024+00', 19858, 3, NULL, 'ace', '1-8::
    Ladies advance to centre & retire; Men repeat
9-16::
    All dance DoSiDo with partner; All turn partner 2H skip change (or
    birl) ending with Ladies in centre with partner on their Left,
    couples facing clockwise
17-24::
    All dance RH across, Ladies on inside, Men on outside; all turn Men
    into centre to dance LH across back to places
25-28::
    All set to partner, turn partner 3/4 LH into promenade hold, Men in
    centre, couples facing anticlockwise
29-32::
    All Promenade anticlockwise 2/3 way round to new positions.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7021, '2013-08-21 08:31:34.509819+00', '2023-02-04 01:22:07.114272+00', 5543, 3, NULL, 'ace', '1-8::
    1M followed by 2M dances a Fig of 8 round 2L & 1L (RSh to 2L) 1M
    crosses to 2nd place own side & 2M to 1st place
9-16::
    1L+2L (facing across) set twice & 1s+2s circle 4H round to left to
    face partner diagonally
17-24::
    1s+2s Adv+Ret diagonally, 1s+2s Advance, 2s Retire as 1s 3/4 turn RH
    to end BtoB facing opposite partner
25-32::
    1s dance diagonal LSh reel of 4 with 2s, 1M ends in 2nd place as 1L
    turns 2L LH to end in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (9402, '2016-10-06 07:18:51.235938+00', '2023-02-04 01:22:07.143912+00', 17053, 3, NULL, 'ace', '1-8::
    1s & 3s lead down the middle & back crossing to partners place
9-16::
    All dance reflection reel of 4 on sides (1s & 3s dance out & down to
    start)
17-24::
    1s+2s also 3s+4s Set & Rotate:
::
    Set, Rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl).  2(1)4(3)
25-32::
    4s dance Diag R&L (4M down, 4L up) to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7022, '2013-08-21 08:31:34.604366+00', '2023-02-04 01:22:07.182803+00', 9184, 3, NULL, 'ace', '1-8::
    1s turn RH 1.1/2 times, cast 1 place on opposite sides (2s step up)
    & turn 3/4 LH to join RH with 1st corners
9-16::
    1s+1st corners Bal-in-Line, 1s turn 1.1/4 LH & join RH with 2nd
    corners & Bal-in-Line. 1s cross LH to 2nd place own side
17-24::
    2s+1s+3s Set+Link for 3 twice to end 3 1 2 on opposite sides
25-32::
    3s+1s+2s set on side, petronella turn to face partner in middle, set
    & turn partner RH
33-40::
    3s+1s+2s dance Allemande

{{explanation}}
Note:	Strathspey Balance in Line: Those with left hands joined in the middle drop left hands and all execute a »Common Schottische« step to the right, joining left hands under right hands and then dropping right hands.  Those moving into the middle of the line join right hands.  Repeat to left.', 0);
INSERT INTO 'dancecrib' VALUES (7023, '2013-08-21 08:31:34.613342+00', '2023-02-04 01:22:07.215159+00', 7293, 3, NULL, 'ace', '1-8::
    1s & 4s turn RH & cast in 1 place, dance RH across to end facing
    corners (Men facing Men)
9-16::
    1s+4s dance double ''Hello-Goodbye'' setting to end facing 1st corners
    (Lady facing Man)
17-24::
    1s & 4s 1/2 turn corners RH to form St Andrews cross & set,  2s+3s
    dance LH across _while_ 1s+4s chase 1/2 way to all end in orig
    places
25-32::
    1s cross down & cast behind 3s, cross LH & cast into 4th place', 0);
INSERT INTO 'dancecrib' VALUES (7024, '2013-08-21 08:31:34.621359+00', '2023-02-04 01:22:07.343633+00', 9886, 3, NULL, 'ace', '1-8::
    All dance reels of 3 on sides, 2s cross up to dance round 1st pl opp
    side & crossing down to dance round 3rd pl (own side) ending in 2nd
    pl
9-16::
    2s dance RH across (Lady with 1s & Man with 3s) pass RSh to dance LH
    across with other couple
17-24::
    All 3 couples set, turn twice & set
25-32::
    1M+2L also 2M+3L dance 1/2 Diag R&L, all dance on clockwise 2 places
    to end with new partners (3M,1M,2M with 2L,3L,1L)', 0);
INSERT INTO 'dancecrib' VALUES (13333, '2020-11-02 01:21:33.727225+00', '2023-02-04 01:22:07.355249+00', 17304, 3, NULL, 'ace', '1-8::
    1s turn 1.1/2 RH; 1s+2s dance Set+Link.  2 (1) 3
9-16::
    2s+1s dance Men''s Chain
17-24::
    2s+1s+3s dance reels of 3 on sides, 1s pass 3s LSh to start. 1s end
    facing 1st corner (1M pulls back RSh to face 3L)
25-32::
    1s dance ''Hello-Goodbye'' setting, clap & petronella turn to 2nd
    place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7025, '2013-08-21 08:31:34.632342+00', '2023-02-04 01:22:07.381401+00', 5547, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, turn LH & end on own sides
9-16::
    1s dance reels of 3 across (Lady with 2s & Man with 3s)
17-24::
    1s dance 3H round to left (Lady with 2s & Man with 3s) & open into
    6H round to left
25-32::
    1s dance reels of 3 across (Man with 2s & Lady with 3s) & cross RH
    to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (14216, '2021-08-14 00:21:34.988262+00', '2023-02-04 01:22:07.406601+00', 17255, 3, NULL, 'ace', '1-8::
    1s lead down middle & back to finish facing 1st corners (2s step up
    3-4)
9-16::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh & dance 1/2
    diag reel of 4 with 2nd corners. 1s pass LSh to face 3rd corners
    (pstn)
17-24::
    1s dance ''Hello-Goodbye'' setting with 3rd & 4th corners (pstn) &
    finish in centre, 1L facing up, 1M facing down
25-32::
    1L+3s (at top) & 1M+2s dance RH across; 1s turn 2H to 2nd place own
    side _while_ 3s+2s chase 1/2 round clockwise.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4117, '2013-08-21 08:30:43.825467+00', '2023-02-04 01:18:35.265612+00', 13080, 3, NULL, 'ace', '1-4::
    1s+3s advance into middle & 1M+3L crossing LH dance out between 2s
    as 1L+3M crossing LH b''tw''n 4s to end on side lines either side of
    2s/4s
5-8::
    All Adv+Ret
9-16::
    All dance RSh reels of 4 up/down but on bar 14 1s+3s give LH in
    passing & turn into prom hold facing centre & pass LSh to face other
    couple _while_ 2s/4s continue their reels but on bar 16 give turn LH
    into prom hold facing in.  (All Ladies on Man''s Right)
17-24::
    All in prom hold dance reel of 4 across but on bar 24 1s+3s do not
    pass LSh but curve round to finish 1L+3M facing 4s & 1M+3L facing 2s
25-28::
    1s+3s dance RH across with 2s/4s
29-32::
    1s+3s dance LH across in centre & Men follow their partners to
    original places
33-40::
    All set to partners & turn 2H once round into 8H round to left 1/2
    way to end opposite original positions

{{explanation}}
Repeat with 2s & 4s as dancing couples', 0);
INSERT INTO 'dancecrib' VALUES (7026, '2013-08-21 08:31:34.640398+00', '2023-02-04 01:22:07.419641+00', 5549, 3, NULL, 'ace', '1-8::
    1s cross down to dance mirror reels of 3 on opposite sides & end
    facing 1st corners
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners & 1/2 diagonal reel
    with 2nd corners
17-18::
    1M+3s (at top) & 1L+2s (at bottom) dance 1/2 RH across
19-20::
    2s+3s dance 1/2 LH across (just touch hands) _while_ 1s cast (1M
    down, 1L up) into 2nd place opp sides.  End (2) (1) (3)
21-24::
    1s turn partner LH, turn 1st corner (position) RH
25-32::
    1s turn partner LH, turn 2nd corner (position) RH; 1M+2s & 1L+3s
    dance 1/2 reels of 3 across (LSh to 3rd corner position)  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7027, '2013-08-21 08:31:34.650101+00', '2023-02-04 01:22:07.564497+00', 5552, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, cross LH & cast (Lady up & Man down) to
    meet 1st corners in prom hold
9-16::
    1s+1st corner dance 1/2 way round behind 2nd corner to 3rd corner
    _while_ 2nd corners Adv+Ret diagonally;
::
    1s leave 1st corners &  turn 1.3/4 LH to meet 2nd corners in prom
    hold (1st corners now in diag opp place)
17-24::
    1s dance with 2nd corner person 1/2 way round to 4th corner _while_
    1st corners Adv+Ret;
::
    1s leave 2nd corners & turn 1.1/4 LH to face 1st corner (position)
25-32::
    1s dance 1/2 diag Reel of 4 with 1st corners, pass RSh & dance 1/2
    diag Reel with 2nd corners to end on own sides 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (7028, '2013-08-21 08:31:34.658411+00', '2023-02-04 01:22:07.588148+00', 13609, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 2nd place, 1M+3M turn RH as 1L+3L turn LH & 1s
    end facing 1st corners
9-12::
    1s set to 1st corners & change places RH with 1st corner persons
    (2M/3L), corners moving in passing LSh to face next corners (2M face
    3M, 3L face 2L)
13-16::
    2s+3s dance 1/2 diagonal reels of 4 with corners on 2nd corners
    diagonal as 1s chase clockwise to opposite corner
17-20::
    2M & 3L set to 2nd corners (pstn) & change places RH with corner
    persons (3M/2L), corners moving in passing LSh to face next corners
    (3M face 1M, 2L face 1L)
21-24::
    2L+3M dance 1/2 diagonal reels of 4 with corners (1s) on 1st corners
    diagonal as 2M+3L chase clockwise to opposite corner
25-28::
    2L & 3M set to corners (1s) & change places RH _while_ 1s dance in
    to face each other up/down set (L facing down, man facing up)
29-32::
    1s turn RH 1.1/4 times to 2nd place own sides _while_ 2s & 3s set
    facing in diagonally & cast to dance round 1/4 clockwise to next
    corner.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14217, '2021-08-14 00:21:35.221891+00', '2023-02-04 01:22:07.610872+00', 12377, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on the side (1s in & down, 2s
    out & up, 3s in & up to start). 2s finish in place, 1s+3s finish NHJ
    with partner facing down & up in the middle of the set
9-12::
    1s+3s set & retire (PdeB) to side & join hands with 2s
13-16::
    1s+2s+3s NHJ Adv+Ret (Advance to form a circle, hands joined briefly
    & raised, retire to place) to finish 1s facing down, 2s facing up
17-24::
    1s+2s dance L&R (1s & 2s change places LH on sides to start)
25-32::
    1s cast to bottom & turn twice with hands crossed (or elbow grip)
    into 4th place. 2s+3s+4s step up on bars 25-26', 0);
INSERT INTO 'dancecrib' VALUES (9231, '2016-06-16 22:42:15.087943+00', '2023-02-04 01:22:07.632042+00', 7316, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to Left then 1s+2s dance RH across back to
    places
9-16::
    1s+2s set, dance 3/4 L&R (cross LH with partner, RH on side, cross
    LH with partner) all face anticlockwise
17-20::
    2M+1L turn 1.1/2 RH to change places & face clockwise as partners
    chase anticlockwise 1/2 round & face in
21-24::
    2L+1M turn 1.3/4 LH to face partner on "1st corner diagonal"  as
    partner chase clockwise 1/2 round to face partner
25-32::
    1s+2s dance diagonal reel of 4 (on"1st corner diagonal") At end
    2L+1M do not pass LSh but curve right , polite turn to face partner

{{explanation}}
Deviser''s note: When danced as a 4 couple set, it is recommended that both 1s & 3s start the two couple dance sequence', 0);
INSERT INTO 'dancecrib' VALUES (13335, '2020-11-02 01:21:33.949183+00', '2023-02-04 01:22:07.656545+00', 15866, 3, NULL, 'ace', '1-8::
    1s & 4s dance Fig 8 round 2s+3s (1s & 4s dance in/ down & in/up to
    start - touching hands when meeting partner)
9-16::
    2s+3s dance Tourbillon:
::
    _1- 4_  2s+3s  1/2 turn ptnrs 2H, 2M & 3L lead ptnrs by nearer hand
    1 place cl''wise to end 2s on Ladies'' side & 3s on Men''s side, 1s set
    to 2s
::
    _5- 8_  2s+3s  1/2 turn ptnrs 2H & lead ptnrs on 1 place clockwise &
    3s+2s cross RH to own sides. 1 3 2 4
17-24::
    1s face 3s, 2s face 4s & all set, all turn 3/4 RH into lines across;
    1/2 RSh reels of 4 across
25-32::
    Middle couples face end couples & all set, turn 3/4 RH into lines on
    side (1) (3) (2) (4);  1/2 RSh reels of 4 on sides
33-40::
    4s+2s & 3s+1s dance RH across; 4s+2s & 3s+1s chase clockwise 1/2
    round (2 bars) & all set.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7030, '2013-08-21 08:31:34.674879+00', '2023-02-04 01:22:07.683023+00', 14496, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig of 8 (1s cross down to start)
9-16::
    1s dance Inveran reels with 2s+3s
17-24::
    1s turn 2H & cast 1 place, cross RH & cast round 1st corner into
    line across
25-32::
    1s dance Diag R&L (up/down) going to right to start
33-40::
    All Set+Link for 3, turn partner 2H.  3 1 2
41-48::
    1s+2s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (4118, '2013-08-21 08:30:43.854932+00', '2023-02-04 01:18:35.431071+00', 324, 3, NULL, 'ace', '1-8::
    1s set & turn 2H, 1s cast 1 place & cross RH
9-16::
    1s dance reels of 3 on opposite sides
17-24::
    2s+1s+3s set & 2s also 3s 1/2 turn partners 2H as 1s turn once, 1s
    dance 1/2 reels of 3 across (1L with 2s, 1M with 3s) all end on own
    sides
25-32::
    1s lead down & cast up round 3s, 1s lead up & cast round 2s.  2 1 3', 4);
INSERT INTO 'dancecrib' VALUES (11210, '2018-09-30 22:20:26.582305+00', '2023-02-04 01:22:07.698851+00', 17776, 3, NULL, 'ace', '{{explanation}}
Round the Room, 2 facing 2 [1s face clockwise, 2s face anticlockwise]

1-8::
    All pass opp person RSh, dance LH across with next couple (to face
    back to start place) & pass original opp person RSh
9-16::
    1M followed by 1L dances clockwise round 2s, pull back LSh (bar 12)
    & 1L followed by 1M dance anticlockwise back to place
17-24::
    2s repeat 9-16
25-32::
    All turn opp person 1/2 LH, face each other, pull back LSh & dance
    out to opp place.  All circle 4H round to Left with next couple', 0);
INSERT INTO 'dancecrib' VALUES (9232, '2016-06-16 22:42:15.104975+00', '2023-02-04 01:22:07.718945+00', 16284, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 3/4 R&L.  1s face out, 2s face in
9-16::
    2s+1s+3s dance reels of 3 on sides (1M+2M & 1L+3L pass RSh). 1s end
    in centre 2nd place
17-20::
    1s turn 1.1/4 LH _while_ 2s+3s chase clockwise round (2L & 3M turn
    Left about to enter chase).  1s end in centre facing own sides
21-24::
    1M+3s (at top) & 1L+2s dance RH across
25-28::
    1s turn 1.1/2 LH _while_ 2s+3s chase clockwise 1/2 way round.  1s
    end in centre facing opp sides
29-32::
    1L+2s (at top) & 1M+3s dance RH across   End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7032, '2013-08-21 08:31:34.692893+00', '2023-02-04 01:22:07.741973+00', 5555, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
    ending in partners place
9-16::
    1s dance 1/2 Fig of 8 round 2s, meet & dance 4 slip steps down
    middle to 3rd place & set 2H joined (Man sets to Left, Lady to Right
    to start) 2s+3s step up, 4s step in bars 15-16.
17-24::
    1s+4s dance Poussette
25-32::
    2s+3s & 4s+1s dance RH across once round & turn partner LH', 0);
INSERT INTO 'dancecrib' VALUES (7033, '2013-08-21 08:31:34.699503+00', '2023-02-04 01:22:07.770379+00', 14604, 3, NULL, 'ace', '1-8::
    1s dance fig 8 round 2s crossing down between 2s to start
9-12::
    1s dance down between 2s & 3s & cast up to 2nd place
13-16::
    2s+1s+3s set then 1s set advancing, pull back RSh to face own sides
    _while_ 2L also 3M petronella turn into middle, 2M casts to 2nd
    place (facing 1M) & 3L casts up to face1L (now in a ''diamond'' shape)
17-28::
    Dance to Each Point & Set (as per Dance to Corners & Set:) (12
    bars);
::
    Couple in middle change places with points passing RSh, points pass
    RSh in middle with a 1/4 turn to right to face next point _while_
    supporting points set (2 bars).  Repeat 5 more times to end with
    points in diagonally opposite place and 1s meet again in the middle.
    Bars  27-28, 2M & 3L set turning to face clockwise, 2L & 3M dance
    out from centre to face clockwise
29-32::
    1s turn RH 1.1/4 to end in 2nd place own side _while_ 2s+3s chase
    round clockwise to end 2 1 3 ready for…
33-40::
    2s+1s+3s circle 6H round & back', 1);
INSERT INTO 'dancecrib' VALUES (7035, '2013-08-21 08:31:34.732701+00', '2023-02-04 01:22:07.937115+00', 11928, 3, NULL, 'ace', '1-8::
    1L+2L Set+Link _while_ 1M+2M reverse Set+Link (1s cast, 2s dance
    up), 1s dance 1/2 Fig of 8 round 2s
9-16::
    1s dance RH across (Man with 2s & Lady with 3s), 1s dance 1/2 Fig of
    8 round 3s
17-24::
    1s followed by 2s dance down for 3 bars, dance up (2s divide) to top
    & cast to 2nd place
25-32::
    1s dance reels of 3 on sides (1s in & down to start) & end facing
    1st corners
33-40::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners ending 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7036, '2013-08-21 08:31:34.742486+00', '2023-02-04 01:22:07.958978+00', 13604, 3, NULL, 'ace', '1-12::
    1s+2s+3s dance R&L for 3 couples
13-16::
    1s set (1M to right but 1L to left) & cast to 2nd place
17-24::
    2s+1s dance a Diamond poussette
25-32::
    1s dance Fig of 8 round 2s with 3s stepping up on bar 31 as 1s dance
    into 3rd place

{{explanation}}
Note: 1L leads with Left foot throughout bars 13-24', 0);
INSERT INTO 'dancecrib' VALUES (10094, '2017-09-03 23:45:18.637744+00', '2023-02-04 01:22:07.975367+00', 16186, 3, NULL, 'ace', '1-8::
    1s dance down, face, set (2s step up 1-2).  1s dance RSh round
    partner out to 2nd place own side
9-16::
    2s+1s+3s set, 1/2 turn partner LH, face, pull back LSh & dance out
    to opp side. 2s+1s+3s cross to own side passing partner LSh
17-24::
    1s dance DoSiDo, turn 2H _while_ 2s+3s chase round clockwise
25-32::
    1s+2s dance all round (diamond) poussette', 0);
INSERT INTO 'dancecrib' VALUES (7037, '2013-08-21 08:31:34.750544+00', '2023-02-04 01:22:07.993818+00', 12014, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, dance down between 3s & cast up to 2nd place
9-16::
    1s cross RH, cast to right & dance 3/4 way round set to end 1M
    between 2s facing down &1L between 3s facing up _while_ 2s+3s dance
    R&L
17-28::
    2s+1s+3s dance 3 couple R&L (start by changing place RH up/down)
29-32::
    All set & 1s petronella turn to 2nd place own sides _while_ 2s & 3s
    cross RH
33-40::
    1s dance diag R&L with 2s+3s to end 3 1 2 4
::
    2nd time through, ends 3 4 1 2, 1s step to bottom & 3s become new 1s', 0);
INSERT INTO 'dancecrib' VALUES (7038, '2013-08-21 08:31:34.758727+00', '2023-02-04 01:22:08.017149+00', 9164, 3, NULL, 'ace', '1-8::
    1s cast 1 place, dance 1/2 Fig of 8 round 1st corners LSh & 1s turn
    LH 1.1/4  to end in middle (1M up, 1L down)
9-16::
    1s dance RH across (1M with 2s & 1L with 3s), 1s with same couples
    circle 3H round to right for 2 bars release RH & lead couple along
    their own side (1M down, 1L up) to end 2L+2M+1M on Men''s side &
    1L+3L+3M on Ladies side
17-24::
    Dancers in top 2 places on Men''s side change places RH with dancers
    in 2nd & 3rd place Ladies side, all cross LH, dancers in top 2
    places on Men''s side & 2nd & 3rd places Ladies side change RH, 2s &
    3s cross LH _while_ 1s turn LH to face 3rd corner (pstn)
25-32::
    1s dance 1/2 diagonal reel of 4 with 3rd corners, pass LSh to dance
    1/2 reel with 4th corners & dance round prtnr LSh to 2nd pl own side
    (face out)', 0);
INSERT INTO 'dancecrib' VALUES (7039, '2013-08-21 08:31:34.766787+00', '2023-02-04 01:22:08.042633+00', 5564, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s.  1M+2L turn LH _while_ 1L+2M turn RH
    (4 bars)
9-16::
    1s dance reflection reels of 3 on opposite sides (1s in/down, 2s
    out/up to start)
17-24::
    1s dance down below 3s (2s step up 17-18), cast up on opposite sides
    to 2nd place & turn LH to face 1st corners
25-32::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partner LH to
    2nd places own sides', 0);
INSERT INTO 'dancecrib' VALUES (9233, '2016-06-16 22:42:15.179543+00', '2023-02-04 01:22:08.073468+00', 16277, 3, NULL, 'ace', '1-4::
    1s+2s dance RH across
5-8::
    1s cast (2s step up) & dance RSh round each other finishing BtoB
    ready for ...
9-16::
    2s+1s+3s dance Double Triangles.  1s end in 2nd place own sides
17-20::
    2s+1s+3s 1/2 turn partners RH, pull back RSh & dance out to opp
    sides
21-24::
    Repeat bars 17-20
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7040, '2013-08-21 08:31:34.774889+00', '2023-02-04 01:22:08.103665+00', 7565, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, set to partners & 1s cast 1 place, 2s dance
    up & face out bars 7-8
9-16::
    2s+1s+3s dance RSh reels of 3 on sides with 1L dancing up & 1M down
    1s end holding LH facing 1st crnrs with 2L/3M on their RH
17-24::
    1s Bal-in-Line with 2nd crnrs, 1s turn 1st corners RH retain hands
    to face 2nd corners & Bal-in-Line with 1st corners, 1s turn 2nd
    crnrs
25-32::
    1s dance reels of 3 across (1M with 2s & 1L with 3s) & cross to new
    places', 0);
INSERT INTO 'dancecrib' VALUES (13635, '2021-02-04 01:21:27.699633+00', '2023-02-04 01:22:08.168228+00', 16477, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link; 2s+1s dance RH across
9-16::
    1s dance up NHJ, cast round 2s, meet & dance down between 3s & cast
    up to 2nd place
17-24::
    1s+3s Set+Link; 3s+1s dance RH across
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7042, '2013-08-21 08:31:34.790962+00', '2023-02-04 01:22:08.191846+00', 5569, 3, NULL, 'ace', '1-8::
    1s dance Inveran reels with 2s+3s. 2s end facing out
9-16::
    Reels of 3 across: 1M+2s & 1L+3s. To start 1s cross down, 2s dance
    up sides, 3s pass RSh then 1M passes 2L LSh, 1L passes 3L LSh. 1s
    end passing RSh to face 1st corners
17-24::
    1s dance diag reel of 4 with 1st corners & pass RSh to face 2nd
    corners
25-32::
    1s dance diag reel of 4 with 2nd corners & pass RSh to face 2nd
    corners again
33-40::
    1s dance 6 bar reels of 3 on opposite sides (RSh to 2nd corners) &
    1s cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7043, '2013-08-21 08:31:34.799024+00', '2023-02-04 01:22:08.217343+00', 5571, 3, NULL, 'ace', '{{explanation}}
1s & 2s start on opp sides

1-8::
    1s & 4s set & cross RH into prom hold facing out of ends, 1s & 4s
    dance round to right round corner & pass LSh to face 3M/2M
9-16::
    4s+1s dance 1/2 diagonal reel of 4 with 2M/3M, 4s & 1s pass LSh to
    face 3L/2L & dance 1/2 diagonal reel of 4 to end on sides (3)(1)4 2
17-20::
    3s facing 1s & 4s facing 2s on sides & set HS
21-24::
    All pass facing person RSh & loop round to left (1s & 4s round
    dancer in next set or no-one, 3s & 2s round each other) to (1)(3)2 4
25-32::
    All dance 1/2 reel of 4 on sides, 4s+2s & 3s+1s set facing on sides
    & dance RH across 1/2 way to end (2)(4)1 3', 0);
INSERT INTO 'dancecrib' VALUES (8353, '2014-07-29 12:59:25.545027+00', '2023-02-04 01:22:08.241819+00', 15372, 3, NULL, 'ace', '{{explanation}}
2 chords, 3s+4s cross to opp. sides on 2nd chord

1-8::
    1s (in prom hold) dance RSh reel of 3 across with 2s as 4s (in prom
    hold) dance RSh reel of 3 across with 3s
9-16::
    1s, followed by 2s, lead down the middle, 2s divide, 1s lead to top
    followed by 2s
17-20::
    1L+3M set & change places RH _while_ 1M+3L change places & set    3
    2 (1) (4)
21-24::
    All couples set, turn partner 2H, finish nearer hands joined, 3s and
    1s facing down, 2s and 4s up
25-32::
    Mirror Rondel: 3s dance down under arch made by 2s, 4s dance up
    under arch made by 1s to start.  End 2 3 (4) (1)', 0);
INSERT INTO 'dancecrib' VALUES (13917, '2021-04-05 00:21:30.166313+00', '2023-02-04 01:22:08.435383+00', 5573, 3, NULL, 'ace', '1-8::
    1M+2M Adv+Ret, 1L+2L Adv+Ret
9-16::
    1s cross down below 2s, cast down round 3s, dance up behind 2s &
    cross to original places
17-24::
    1s lead down & back to top in the centre facing partner. 2s step in
    ready for
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7044, '2013-08-21 08:31:34.808654+00', '2023-02-04 01:22:08.599467+00', 5574, 3, NULL, 'ace', '1-8::
    1s cross RH & cast down on opposite sides, turn in & dance up to 2nd
    place & dance in to form line across with 2s
9-16::
    1s+2s dance down in line & back (1s to 2nd place opposite side)
17-24::
    2s+1s dance R&L
25-32::
    1s set twice & cross to own sides', 0);
INSERT INTO 'dancecrib' VALUES (7045, '2013-08-21 08:31:34.899589+00', '2023-02-04 01:22:08.617912+00', 5576, 3, NULL, 'ace', '1-8::
    1s followed by 2s (who dance up) cast & dance down outside, turn in
    & 2s followed by 1s dance up to top to places (2s dance down to 2nd
    place)
9-16::
    1s+2s dance double Fig of 8
17-24::
    1s followed by 2s (who dance up) dance down the middle, 2s divide &
    follow 1s up to places
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (8625, '2015-02-13 12:48:11.490674+00', '2023-02-04 01:22:08.646925+00', 12693, 3, NULL, 'ace', '1-8::
    1s cross, cast off 2 places (2s+3s step up). 2s+1s Advance on
    diagonal & Retire up/down remaining in centre
9-16::
    2s+1s dance R&L up/down centre. Bars 15-16 1s omit cross LH but cast
    up (3s step down), 2s finish facing out   2 1 3
17-24::
    2s+1s+3s dance mirror (reflection) reels of 3 (1s in/up).  1s finish
    facing 2nd corners
25-32::
    1s set to 2nd corner, set to 1st corner, swivel to Right & dance
    into 2nd place own sides.  All set', 0);
INSERT INTO 'dancecrib' VALUES (10095, '2017-09-03 23:45:18.76841+00', '2023-02-04 01:22:08.699481+00', 5579, 3, NULL, 'ace', '1-8::
    All circle 6H round & back
9-16::
    1s set, cast 1 place (2s step up 3-4). 2s+1s+3s turn RH
17-24::
    2s+1s+3s Adv+Ret; 2s+1s+3s cross RH
25-32::
    2s+1s+3s Adv+Ret, 2s+1s+3s chase clockwise 1/2 way round. 3 1 2

{{explanation}}
Note: unusual progression.  Could »and set« have been forgotten in the original description for [23-24]?', 0);
INSERT INTO 'dancecrib' VALUES (7046, '2013-08-21 08:31:34.907725+00', '2023-02-04 01:22:08.721199+00', 10774, 3, NULL, 'ace', '1-8::
    1s turn 2H, dance down into centre of set, 1M dances LH across with
    2s & 1L RH across with 4s
9-16::
    2s+1s+4s in prom hold dance reel of 3 across (1s give RSh to 4s to
    start)
17-24::
    1s dance out between 3s, divide & cast back to centre, turn RH & 1M
    dances out between 2s as 1L dances out between 4s, back to places
25-32::
    All dance Grand Chain (1 bar per hand)

{{explanation}}
Repeat with 2s, 3s then 4s leading', 0);
INSERT INTO 'dancecrib' VALUES (7048, '2013-08-21 08:31:34.924213+00', '2023-02-04 01:22:08.779432+00', 5584, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH to face 2nd corners
9-16::
    1s 1/2 diagonal reel with corners & pass RSh to repeat with 1st
    corners & end facing 4th corners
17-24::
    1s pass corners RSh & set _while_ crnrs turn 1.1/2 times to face own
    places, 2nd crnrs pass 1s RSh & set _while_ 1s turn 1.1/2 to face
    3rd crnrs
25-32::
    Repeat with 1st corners 1s ending in 2nd place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (7049, '2013-08-21 08:31:34.943112+00', '2023-02-04 01:22:08.825188+00', 10405, 3, NULL, 'ace', '1-8::
    All advance 1 step & retire, cross RH, advance for 1 step, retire
    (slightly) Ladies turning anticlockwise under partners arm
9-16::
    1s+2s also 3s+4s dance Poussette
17-24::
    2s+1s also 3s+4s dance RH across 1/2 way, centre cpls LH across 1/2
    way, end cpls RH across & centre couples LH across to end
    (3)(4)(1)(2)
25-32::
    2M+1L change places RH, 2M+4M also 2L+1M change places LH, 2M+3L
    also 2L+4L change RH & 2L+3M change LH to 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7050, '2013-08-21 08:31:34.951153+00', '2023-02-04 01:22:08.861238+00', 9217, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s dance 1/2 figs of 8 (1M up round 2s, 1L
    round 3s)
9-16::
    1s+2nd corners dance RH & LH across
17-24::
    1s+2nd corners dance diagonal reel of 4 ending facing out 2nd place
    opposite sides
25-32::
    1s+1st corners dance a diagonal ''Mixed'' Chain (as Men''s Chain with
    corners passing LH in middle)
33-40::
    1s cast round 1st corners & cross diagonally to 2nd place own sides,
    2s+1s+3s turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (13878, '2021-04-05 00:18:32.778296+00', '2023-02-04 01:18:35.472202+00', 19973, 3, NULL, 'ace', '1-8::
    1M+2L cross RH, 1L+2M cross RH; 1M+3M cross RH, 1L+3L cross RH.  (2)
    (3) 1
9-16::
    1s set, lead up to top, cross & cast to 2nd place opp sides (3s step
    down 15-16).  (2) (1) (3)
17-24::
    1L+2s (at top) & 1M+3s dance reels of 3 across (1L+2M & 1M+3L pass
    RSh to start)
25-32::
    All Adv+Ret; all turn partner 1.1/2 RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4119, '2013-08-21 08:30:43.864983+00', '2023-02-04 01:18:35.564627+00', 326, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, 1s turn 3s on sides (1M - LH & 1L - RH)
    _while_ 2s set & cross RH
9-16::
    1s dance reflection reel of 3 on opposite sides (1s in & up to
    start)
17-24::
    1s turn 2s on sides (1L - LH, 1M - RH) _while_ 3s set & cross RH,
    1s+3s dance 1/2 double Fig of 8 (1s cross down to start),
25-32::
    2s+1s dance 1/2 double Fig of 8 (1s cross up to start) & 1s cross RH
    & set', 0);
INSERT INTO 'dancecrib' VALUES (7051, '2013-08-21 08:31:34.96077+00', '2023-02-04 01:22:09.003083+00', 5591, 3, NULL, 'ace', '1-8::
    1M+2L change places RH, 1L+2M change places RH
9-16::
    1s+2s advance for 2 steps & retire, dance 1/2 R&L
17-24::
    1s lead down the middle & back to top
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (9234, '2016-06-16 22:42:15.317943+00', '2023-02-04 01:22:09.05729+00', 16852, 3, NULL, 'ace', '1-8::
    1s cast, followed by 2s+3s (NHJ as they dance up), meet in 3rd
    place, dance up and cast to original places
9-16::
    All set, all 1/2 turn partner 2H, turn Right about and dance out to
    partner''s place & all set (1) (2) (3)
17-24::
    Mirror (reflection) reels of 3 starting  on opposite sides, each
    couple crosses to own side from top place. End in centre, 1s at top
    facing down,  2s facing up NHJ    1 2 3
25-32::
    1s+2s dance Rondel.  1s end in 2nd place facing out ready to start
    again', 0);
INSERT INTO 'dancecrib' VALUES (7053, '2013-08-21 08:31:34.978757+00', '2023-02-04 01:22:09.092531+00', 5593, 3, NULL, 'ace', '1-8::
    1s dance down between 2s, cast up on own sides into centre & curve
    out to places
9-16::
    1s+2M & 4s+3M Advance diagonally to join hands in triangle, drop
    hands, Retire & repeat
17-24::
    1s dance down between 3s & cast back to places
25-32::
    4s cross RH & cast up 1 place, cross RH & cast up 1 place (3s, 2s &
    1s step down as 4s cast behind them).  (4) 1 2 3
33-40::
    4s set & turn 2H moving down to 4th place (1s+2s+3s step up 35-36)
41-48::
    1s dance down making an arch as 2s+3s+4s dance up (2 bars for each
    couple to dance under arch & up 1 place) & all turn RH. End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7054, '2013-08-21 08:31:34.986889+00', '2023-02-04 01:22:09.117741+00', 13448, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s 1/2 turn (M RH, L LH) on sides (1s & 3s end BtoB
    facing own sides) & dance Double Triangles (6 bars) 1s/3s end facing
    1st crnrs
9-16::
    1s & 3s dance Pass+Turn with 1st corners & pass RSh to face 2nd
    corners, 1s & 3s dance Pass+Turn with 2nd corners & end facing 4th
    corner
17-24::
    1s & 3s dance RSh reels across (1L+2s, 1M+4s+3L, 3M+5s) with 1s & 3s
    ending in line up/down middle facing partner (Men face up)
25-32::
    1s & 3s 3/4 turn RH & cast 1 place on opposite sides then turn RH
    1.1/2 times to end 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (7055, '2013-08-21 08:31:34.994851+00', '2023-02-04 01:22:09.149432+00', 9760, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, dance RH across (Lady with 2s & Man with 3s) &
    end facing 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting ending BtoB (Man facing up & Lady
    down)
17-24::
    1s dance reels of 3 across (Man with 2s & Lady with 3s giving RSh to
    2nd corners) & pass RSh to face 1st corners
25-32::
    1s turn 1st corners RH, partner LH, 2nd corners RH & partner LH to
    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7056, '2013-08-21 08:31:35.002966+00', '2023-02-04 01:22:09.182803+00', 9887, 3, NULL, 'ace', '1-8::
    1s lead down below 3s & cast up one place on own sides, cross RH &
    cast down to 3rd place on opposite sides
9-16::
    2s+3s+1s set & cross RH, change places on sides LH (as in 3 couple
    R&L) & cross RH
17-24::
    Dancers in 2, 3 & 4 pstns set & cross RH, change places on sides (as
    in 3 couple R&L) & cross RH
25-32::
    Dancers in 1st place set & cross RH _while_ those in 3rd & 4th place
    set & dance 1/2 RH across, the top 3 Ladies (on Men''s side) & bottom
    3 Men dance 1/2 reel of 3 Persons in 2nd & 3rd place starting Reels
    LSh
33-40::
    All dance 1/2 reel of 4 on sides, all set & cross over RH', 0);
INSERT INTO 'dancecrib' VALUES (7057, '2013-08-21 08:31:35.012742+00', '2023-02-04 01:22:09.21587+00', 5619, 3, NULL, 'ace', '1-8::
    1s+2s+3s+4s dance 1/2 reels of 4, 4s+3s also 1s+5s dance RH across
    1/2 way then cross RH.  3 4 2 5 1
9-16::
    4s+2s+5s+1s dance 1/2 reels of 4, 3s+1s also 2s+4s dance RH across
    1/2 way then cross RH.  1 3 5 4 2
17-24::
    1s cross down to 2nd place opposite sides & set to 5s (in 3rd place)
    , 1M turn 5L 1.1/2 times RH as 1L turns 5M 1.1/2 times
25-32::
    1s cross down to 4th place own side & set to 2s (in 5th place), 1M
    turn 2M 1.1/2 times as 1L turns 2L 1.1/2 times.  3 5 4 2 1', 0);
INSERT INTO 'dancecrib' VALUES (7058, '2013-08-21 08:31:35.020677+00', '2023-02-04 01:22:09.242413+00', 10958, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 R&L, 1s+4s dance 1/2 R&L _while_ 2s & 3s
    cross RH & set
9-16::
    2s+4s also 1s+3s dance Double Fig of 8 (2s & 1s cross down to start)
17-24::
    2s+4s+1s dance reels of 3 on sides (2s in & down to start)
25-32::
    1s dance reels of 3 across with next couple (Lady up & Man down)
    with 2s standing', 0);
INSERT INTO 'dancecrib' VALUES (13768, '2021-03-02 01:21:36.648566+00', '2023-02-04 01:22:09.262024+00', 12354, 3, NULL, 'ace', '1-8::
    1s & 3s set, cast 1 place (2s & 4s step up); 1s & 3s turn partner LH
    into promenade hold (1s face 2L, 3s face 4L)
9-16::
    1s/3s dance 1/2 RSh reels of 3 across the dance with 2s/4s; 1s & 3s
    NHJ dance up, 1s cast down round 2s _while_ 3s cast down round 4s
    (2) 1 (4) 3
17-24::
    1s & 3s dance 1/2 Fig of 8 round couple above them. All set twice.
    On 2nd setting step 1s turn to face down _while_ 4s+3s turn to face
    up
25-32::
    1s+4s+3s dance RSh parallel 1/2 reels of 3 on the side (1s RSh to 4s
    to start); All turn partner 1.1/2 RH 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7059, '2013-08-21 08:31:35.028786+00', '2023-02-04 01:22:09.345616+00', 5609, 3, NULL, 'ace', '1-8::
    All dance RSh reels of 3 on sides 1s face down
9-16::
    All set, 1s cast 1 place & 1/2 Fig of 8 around 2s
17-24::
    1s in prom hold dance down to bottom & cast round 3M, dance across &
    cast up round 2L to face 1st crnrs _while_ 2M+3L cross RH & cross
    back RH
25-32::
    1s set & turn 1st corners 2H, set & turn 2nd corners 2H
33-40::
    1s in prom hold (M on right) dance up, cast round 2M, cross & cast
    down round 3L _while_ 3M+2L cross RH & cross back RH
41-48::
    All set, 1s cast to 3rd place, 1s 1/2 Fig of 8 round 3s to end in
    3rd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4068, '2013-08-21 08:30:42.981672+00', '2023-02-04 01:18:31.695421+00', 235, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s set, cross RH; 1s+2s set & turn partners LH & retain hands
9-16::
    1s+2s dance the Tournee:
::
    Bar 9: 1s+2s continue turning into prom hold (Men with prtnr on
    right, 1s face Men''s side & 2s Ladies'' side), couples 1/2 wheel
    anticl''wise & Men turn Ladies into middle, both couples turn 1.1/2
    times (2s RH, 1s LH) & 1s end facing 1st corners, 2s on sides

{{title}}
Reel

17-24::
    1s set to 1st corners & turn 2H, 1s set to 2nd corners & turn 2H
25-32::
    1s dance reels of 3 on opposite sides & cross to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8395, '2014-08-31 14:43:59.490296+00', '2023-02-04 01:18:35.586775+00', 15595, 3, NULL, 'ace', '1-8::
    1L also 4M followed by partners cast to other end & turn RH into
    prom hold to face down/up (Lady facing Lady) as 2s+3s step back to
    form
9-16::
    4s dance reel of 3 across with 2s (RSh to 2M) _while_ 1s dance reel
    of 3 across with 3s (RSh to 3L)
17-24::
    4s+1s dance LH across, 4s+2s also 3s+1s dance RH across
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7060, '2013-08-21 08:31:35.036829+00', '2023-02-04 01:22:09.360218+00', 10754, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place, 1s turn RH 1.1/2 times to face 1st
    corner pstns _while_ 2s+3s chase clockwise 1/2 way
9-16::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners;
    1s dance Pass+Turn with 2nd corners & 1s end 2nd place opposite
    sides
17-24::
    1s+2s+3s Set+Link for 3 twice
25-32::
    1s dance reels of 3 on sides (1s give LSh to person on their left to
    start). 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7061, '2013-08-21 08:31:35.046871+00', '2023-02-04 01:22:09.390471+00', 11981, 3, NULL, 'ace', '1-2::
    1L casts down 2 places _while_ 3M casts up 2 places _while_ 1M+3L
    pass RSh to end 3Ms & 1Ls place.  3 2 1
3-4::
    1L & 3M cross to opposite sides _while_ 1M & 3L cast back to
    original places
5-6::
    1M & 3L cross to opposite sides _while_ 1L & 3M cast up/down 2
    places
7-8::
    1s & 3s cross RH to places.  1 2 3
9-16::
    1s+2s RH across & dance 1/2 diamond Poussette with 1s ending between
    1st corners but facing partner
17-20::
    1s set adv (pass LSh) to 1st corners, turn corners 2H & end between
    2nd corners (facing partner)
21-24::
    1s set adv to 2nd corners & turn 2H to end in centre on opp sides
    (1L facing down on Mans side & 1M facing up on Ladies side)
25-32::
    1s 1/2 RH across with corners, 1s dance round each other RSh 1.1/2
    times & dance LH across 1/2 way on own sides to end in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (7062, '2013-08-21 08:31:35.055011+00', '2023-02-04 01:22:09.421515+00', 5612, 3, NULL, 'ace', '1-8::
    Dancers in 2nd & 3rd places dance RH across, then top 3 Men & bottom
    3 Ladies dance 1/2 reel of 3 on sides (1M+2M also 3L+4L pass LSh to
    start)
9-16::
    Dancers in 2nd & 3rd places dance LH across, then top 3 Ladies also
    bottom 3 Men dance 1/2 reel of 3 on sides (1s+4s pass RSh to start).
    3 4 1 2
17-24::
    Couples in 2nd & 3rd places (4s+1s) dance 1/2 R&L _while_ end
    couples chase clockwise 1/2 way, 2s+1s & 4s+3s dance 1/2 R&L to end
    in orig places
25-32::
    All dance 1/2 RSh reels of 4 on sides, top 3 couples (4s+3s+2s)
    dance 1/2 reel of 3 on sides to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9892, '2017-05-29 09:18:36.860985+00', '2023-02-04 01:22:09.438289+00', 16774, 3, NULL, 'ace', '1-8::
    1s & 3s dance down NHJ, turn 2H, dance up NHJ, turn 2H to end in
    original places facing out
9-16::
    Reels of 4 on sides, 1s & 3s out/down, 2s & 4s in/up to start
17-24::
    1s+2s also 3s+4s Set+Link.  1s & 3s petronella turn & set
25-32::
    1s+3s dance 1/2 reel of 4 up/down centre.  3s & 1s turn partners 3/4
    RH to end in 2nd/4th place own sides.  2s+3s+4s+1s set.', 4);
INSERT INTO 'dancecrib' VALUES (12103, '2019-08-30 09:54:52.111616+00', '2023-02-04 01:22:09.469573+00', 19426, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All set to partner & turn 1.1/4 LH. Ladies dance RH across & dance
    out through their own place _while_ men dance anticlockwise 1/2 way
    round the set to opposite man''s place
9-16::
    Men dance LH across _while_ ladies dance clockwise 1/2 way round the
    set to meet partner in promenade hold (lady on right). All promenade
    anticlockwise 1/2 way round the set to original places & face
    corners..
17-24::
    All Petronella with corners to form St Andrews Cross (men back to
    back in the middle, ladies on diagonal out of set). All set. All
    Adv+Ret for 1 step, all turn corners LH to original places facing
    partner
25-32::
    All dance interlocking RSh reels of 4.
33-40::
    All dance double men''s chain giving LH in the middle. Ladies finish
    facing out
41-56::
    All dance full Schiehallion reel
57-64::
    All circle 8H round & back

{{explanation}}
Reel:-	Repeat bars 1-64 above, except

17-24::
    All Petronella turn with corners to join RH with corners (St Andrews
    Cross), all set & turn inwards & join LH & all set.  All turn LH to
    original place facing partner', 0);
INSERT INTO 'dancecrib' VALUES (7063, '2013-08-21 08:31:35.063099+00', '2023-02-04 01:22:09.500066+00', 12381, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s dance dance round each other RSh, cast down/up 1 place &
    dance LH across 1.1/4 times to face corners
9-16::
    1s & 4s turn corners RH, dance LH across 1.1/4 times & turn next
    corner RH to end 2 4 (1)(3)
17-24::
    All dance RSh reels of 4 on sides
25-32::
    All set, 4s & 1s dance 1/2 Figs of 8 round end couples & cross RH to
    sides to end 2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (13336, '2020-11-02 01:21:34.857153+00', '2023-02-04 01:22:09.524043+00', 5615, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1L+2s & 1M+3s dance RH across
9-16::
    1s dance RSh round 1st corner, approach partner in centre, pull back
    RSh & dance RSh round 4th corner into 2nd place own side (1M face
    down, 1L face up)
17-24::
    2s+1s+3s dance 6 bar reels of 3 on sides (1s RSh to 4th corner), 1s
    turn LH to face 3rd corner
25-32::
    1M+2s & 1L+3s dance 6 bar reels of 3 across (1s LSh to 3rd corner),
    1s cross down RH to 3rd place own side (3s dance up). 2 3 1

{{explanation}}
Note:	If danced in 4C set, Bars 31-32: 1s cross to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8355, '2014-07-29 12:59:25.834425+00', '2023-02-04 01:22:09.543018+00', 15412, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance RH across and chase clockwise 1/2 way.
9-16::
    4s+3s & 2s+1s dance R&L (retain LH to lead into reels)
17-24::
    All dance LSh reels of 4 on the sides
25-32::
    4s+3s & 2s+1s dance LH across & chase anticlockwise back to places.
33-34::
    1s+2s dance LH across 1/2 way
35-36::
    1s+3s dance RH across 1/2 way
37-38::
    1s+4s dance LH across 1/2 way
39-40::
    All cross RH (retain RH to move into RH across)', 0);
INSERT INTO 'dancecrib' VALUES (8356, '2014-07-29 12:59:25.841602+00', '2023-02-04 01:22:09.556655+00', 15284, 3, NULL, 'ace', '1-8::
    1s+2s+3s cross RH, set, cross LH, set
9-16::
    1s turn RH, cast off 1 place (2s step up), cross LH and cast to
    Left, 1L down, 1M up, to finish BtoB in centre facing opp. sides
17-24::
    All set as in Double Triangles, 1s turn 1st crnrs RH to finish BtoB
    again, facing opp. sides; set as in Double Triangles, 1s turn 2nd
    crnrs LH.  Finish 1L between 3s, 1M between 2s
25-32::
    1s dance RSh Reels of 3 across (1M with 2s, 1L with 3s), 1s pass LSh
    to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (7066, '2013-08-21 08:31:35.087187+00', '2023-02-04 01:22:09.619716+00', 5617, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, turn 1st corner LH into 2nd place in prom
    hold with 1st corner
9-16::
    1s+1st Corners dance reel of 4 with 2nd corners (passing RSh to 4th
    corners) to end 1s in 2nd place opposite sides facing 1st corners
17-24::
    1s set to 1st corner, turning about set to 2nd corner & turn RH to
    end BtoB Man facing up & Lady down
25-32::
    1s dance Crown Triangles to end 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8189, '2014-02-10 10:26:56.341963+00', '2023-02-04 01:22:09.640143+00', 14075, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, cross RSh (no hands); 1L & 2M turn 3/4 with RH
    as 1M & 2L turn 3/4 LH; end 2s in 1st place, 1s takePromenade hold
    between 2s
9-16::
    1s dance 1/2  Reel of 3 on Ladies side (1s pass 3L RSh start);  1s
    dance 1/2 Reel of 3 on Mens side (1s pass 2M RSh to start); finish
    in middle at top facing down with LH joined
17-20::
    1s lead down, cross out on own side, dance down behind 3rd place
    _while_ 3s & 2s cross RH with ptnr and set
21-24::
    1s cross LH cast up to 2nd place opp sides _while_ 3s & 2s change
    places RHon sides; 2s, 1s & 3s set
25-32::
    2s, 1s & 3s Adv+Ret, 2s, 1s & 3s turn ptnr RH 1.1/2 times to own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (7068, '2013-08-21 08:31:35.103457+00', '2023-02-04 01:22:09.691641+00', 5621, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross RH & cast (Man up & Lady down) into
    centre, 1M between 2s, 1L between 3s
9-16::
    1s+2s+3s circle 6H round & back (1s end in centre)
17-24::
    1s change places RH & dance out of ends to their right, into Figs of
    8 (Lady round 2s as 1M dances round 3s)
25-32::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corners &
    cross RH to places', 0);
INSERT INTO 'dancecrib' VALUES (7069, '2013-08-21 08:31:35.11138+00', '2023-02-04 01:22:09.723813+00', 8033, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig of 8
9-16::
    1s+2s+3s dance reflection reels of 3 on own sides
17-24::
    1s turn RH & cast down 2 places, 3s+1s set advancing to partners
25-32::
    3s+1s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7070, '2013-08-21 08:31:35.11966+00', '2023-02-04 01:22:09.753903+00', 5623, 3, NULL, 'ace', '1-8::
    1s set & turn RH, 1s cast to 4th place _while_ 3s set & turn RH
9-12::
    1s dance up between 4s & 3s, out & up behind 2s to 1st place _while_
    3s cast round 4s & back to 3rd place _while_ 2s set & turn RH
13-16::
    1s+2s+3s dance 1/2 reel of 3 on sides (2s out & down to start)
    _while_ 4s set & turn RH to face out
17-24::
    3s+2s+1s+4s dance reflection reels of 4 on sides (3s & 1s in & down
    to start)
25-32::
    3s & 1s set twice & turn RH moving down 1 place _while_ 2s & 4s cast
    up 1 place, cross down, cast up 1 place & cross RH.  2 3 4 1', 4);
INSERT INTO 'dancecrib' VALUES (7071, '2013-08-21 08:31:35.129428+00', '2023-02-04 01:22:09.904825+00', 5624, 3, NULL, 'ace', '1-8::
    1s followed by 2s lead down, 2s+1s dance 1/2 R&L (in middle at
    bottom of set)
9-16::
    1s followed by 2s (on opposite sides) lead up to top, 1s+2s dance
    1/2 R&L (1L omit polite turn), 1s end facing 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7072, '2013-08-21 08:31:35.137533+00', '2023-02-04 01:22:09.936375+00', 8510, 3, NULL, 'ace', '1-8::
    1s+2s+3s turn partners RH, Men dance up for 2 bars as Ladies dance
    down & retire back to places facing in
9-16::
    1s+2s+3s advance with joined hands, touch hands, retire & turn
    partner RH
17-24::
    1L followed by 1M+2M+3M chase round clockwise
25-32::
    1M followed by 1L+2L+3L chase round anticlockwise On last 2 bars 1s
    cast as 2s dance up', 0);
INSERT INTO 'dancecrib' VALUES (7073, '2013-08-21 08:31:35.145544+00', '2023-02-04 01:22:09.963963+00', 7499, 3, NULL, 'ace', '1-8::
    1s & 3s in prom hold dance reels of 3 across set giving RSh to 2M/4M
    to start
9-16::
    1s & 3s dance down the middle & back
17-24::
    1s+2s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
25-32::
    1s dance in & cast 2 places, all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (15423, '2023-02-04 01:22:09.993979+00', '2023-02-04 01:22:09.99581+00', 20773, 3, NULL, 'ace', '1-8::
    1s set, dance »Tom Bombadil« turn:
::
    1s 1/2 turn RH (1M dances above 1L _while_ lady dances under arch
    made by the joined hands, 1M curves clockwise _while_ 1L curves
    anticlockwise to finish next to each other in middle in 1st place
    facing up), 1s cast to face 3rd corners (2s step up bars 5-6)
9-16::
    1s dance »Hello-Goodbye« setting to finish facing 1st corners
17-24::
    1s dance 1/2 diagonal reel of 4 giving RSh to 1st corners & pass RSh
    to dance 1/2 diagonal reel of 4 with 2nd corners (1s finish 2nd
    place on opposite sides) 3 (1) 2
25-32::
    1s dance 1/2 diagonal R&L with 1st corners (Man up, Lady down). 1s
    dance 1/2 diagonal R&L with 2nd corners (Man up, Lady down)
33-40::
    1s+3s set advancing, 1s cross up RH & cast to 3rd place _while_ 3s
    NHJ follow 1s & cast to 2nd place 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7074, '2013-08-21 08:31:35.22989+00', '2023-02-04 01:22:10.0247+00', 11919, 3, NULL, 'ace', '1-8::
    2s followed by 1s dance down below 3s, cross & cast up - 2s to top &
    cross (no hands) to 1st pl as 1s cast up to 2nd pl & turn LH to face
    1st crnrs
9-16::
    1s dance ''Hello-Goodbye'' setting & end BtoB in middle (Man facing
    up)
17-24::
    1s dance RH across (1M with 2s & 1L with 3s), pass RSh & dance LH
    across with other couple
25-32::
    1L followed by partner dance up, cast on opposite sides & dance 1/2
    Fig of 8 round 2s', 0);
INSERT INTO 'dancecrib' VALUES (7075, '2013-08-21 08:31:35.237982+00', '2023-02-04 01:22:10.053631+00', 5630, 3, NULL, 'ace', '1-8::
    1s lead down for 4 bars, up for 2 & cast up behind 2s to place
9-16::
    1L crosses down to cast up behind 2M into centre facing down _while_
    1M crosses & casts down behind 2L into centre, pass partner RSh
    turning to face partner & 3/4 turn LH to face 2s in line across
17-24::
    1s+2s dance reel of 4 across ending ready for Allemande
25-32::
    1s+2s Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4120, '2013-08-21 08:30:43.901739+00', '2023-02-04 01:18:35.715318+00', 327, 3, NULL, 'ace', '{{explanation}}
Special set: 1M with 2M on R stand BtoB with 4M+3M respectively; all Ladies face Partners The Ladies are »outers« & the Men »inners«

1-8::
    All set
9-16::
    All dance 1/2 reel of 4 passing LSh, Men to partners'' (»outer«)
    pstns, 1L & 3L turning left to 2M & 4M pstns, 2L+4L straight ahead
    to 3M & 1M pstns Repeat 3 times from new pstns all ending diagonally
    opposite starting pstns
17-24::
    All set to partners
25-32::
    Repeat bars 9-16 to original pstns', 0);
INSERT INTO 'dancecrib' VALUES (4121, '2013-08-21 08:30:43.909986+00', '2023-02-04 01:18:35.736314+00', 328, 3, NULL, 'ace', '{{explanation}}
 3s & 4s start on opp. sides

1-8::
    1s+2s also 3s+4s Set+Link, 1s+2s also 3s+4s set & change places on
    sides LH into…
9-16::
    All dance interlocking reels of 4 round the set (end couples
    crossing RSh & side couples pass RSh) & last LSh pass 2H into
    circle,
17-24::
    All circle 8H round to left for 2 bars, set, drop hands & dance on 1
    step & cast back to original places
25-32::
    1M & 4M followed by ptnr cast 2 pls & cross to 2 4 (1)(3), 2L & 3L
    step to ends bar 25 & 2M & 3M step to ends bar 27, 2s+4s & 1s+3s RH
    across', 0);
INSERT INTO 'dancecrib' VALUES (9037, '2015-11-30 09:00:14.015696+00', '2023-02-04 01:22:10.085988+00', 12004, 3, NULL, 'ace', '1-8::
    All clap (2 bars, 4 claps), all clap hands with prtnr (2 bars), all
    clap hands with neighbour (2 bars), all stamp 1 foot (2 bars, 4
    stamps)
9-16::
    1s cast to 4th place as 2s+3s+4s turn RH moving up 1 place, all turn
    LH
17-24::
    1s followed by 4s, 3s & 2s march or dance down middle and back to
    places
25-32::
    All circle 8H round and back', 0);
INSERT INTO 'dancecrib' VALUES (15078, '2022-09-05 00:21:34.704223+00', '2023-02-04 01:22:10.121001+00', 20912, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s cross LH & cast to left to end 1L
    between 2s facing down, 1M between 3s facing up
9-16::
    1s dance 1/2 diag R&L (1s go to right up/down); 1s dance 1/2 RSh
    reel of 3 across (1M at top facing own side, 1L at bottom facing own
    side to start)
17-24::
    1s repeat 9-16. End 1L between 2s at top, 1M between 3s at bottom
25-32::
    All chase clockwise 1/2 round; 1s Petronella turn to 2nd place own
    side & all 3 couples set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7076, '2013-08-21 08:31:35.246105+00', '2023-02-04 01:22:10.144253+00', 7501, 3, NULL, 'ace', '1-8::
    1s & 5s cross & cast, 1s+3s+5s set & circle 6H round to left 1/2 way
9-16::
    5M dances reel of 3 with 2s as 1L reels with 4s also 5L+1M pass LSh
    to dance RSh reel of 4 with 3s (1s & 5s end facing 1st crnr pstns)
17-24::
    1s & 5s turn corner, partner, corner & turn partner to end on own
    sides
25-32::
    All set, 2s+5s & 1s+4s turn 2H to own sides as 3s 1/2 turn 2H, 1s+3s
    (facing on sides), set & change places RH.  2 5 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (15236, '2022-11-03 01:21:29.673187+00', '2023-02-04 01:22:10.170759+00', 20444, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link (2L & 1M face out); 2s+1s+3s dance 1/2 reels of 3 on
    sides (1s pass 3s LSh to start) 3 1 2
9-16::
    3s+1s+2s set, dance DoSiDo & set
17-24::
    1s dance 1/2 Fig 8 (1M up round 3s, 1L down round 2s); 1s turn 1.1/2
    RH to 2nd place own side
25-32::
    Promenade (Chaperoned) Chain progression:
::
    _25-26_    3s & 2s 3/4 turn partner RH into middle _while_ 1s dance
    clockwise 1/4 round the set picking up 3M/2L …
::
    _27-30_    who promenade 1/2 way clockwise _while_ middle people
    (3M+2L) turn LH 1.1/2
::
    _31-32_    2s & 3s turn partner RH 3/4 to own sides _while_ 1s dance
    clockwise 1/4 round to end in 2nd place. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7078, '2013-08-21 08:31:35.360434+00', '2023-02-04 01:22:10.236643+00', 5637, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All Ladies dance RH across 1/2 way & turn opposite Man LH, all
    Ladies dance 1/2 RH across & turn partner LH
17-24::
    1s+3s dance reel of 4 (Ladies start by passing LSh as Men set)
25-32::
    All set (HS) to corners, turn 2H twice
33-40::
    2s+4s dance reel of 4 (Ladies start by passing LSh as Men set)
41-48::
    All set (HS) to corners, turn 2H twice
49-56::
    All Ladies circle left to face partners (Ladies BtoB), set to & turn
    partners 2H
57-64::
    All Men circle right to face partners (Men BtoB), set to & turn
    partners 2H
65-72::
    All dance Grand Chain
73-80::
    All take allemande hold & dance anticlockwise once round set,
    bringing Ladies into centre for bow/curtsey', 0);
INSERT INTO 'dancecrib' VALUES (7079, '2013-08-21 08:31:35.370405+00', '2023-02-04 01:22:10.380682+00', 5641, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, 1/2 turn LH & lead (LH) up to top,
    staying in middle facing down
9-16::
    1s+2s circle 4H round & back
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (7080, '2013-08-21 08:31:35.378493+00', '2023-02-04 01:22:10.408809+00', 7911, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance double Fig of 8 (1s & 3s start by crossing
    down)
9-16::
    All dance reflection reels of 4 on sides 1s & 3s dancing in to start
17-24::
    1s cross RH, cast 1 place, cross down below 3s & cast to bottom
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7081, '2013-08-21 08:31:35.38701+00', '2023-02-04 01:22:10.44015+00', 9888, 3, NULL, 'ace', '1-8::
    1s & 3s Adv+Ret & dance 1/2 R&L
9-16::
    2s & 4s repeat
17-24::
    All couples set NHJ, petronella-in-tandem 1 place to right.  Each
    couple, with M leading, chase back 1 place & 1/2 turn RH
25-32::
    All Ladies dance LH across once round _while_ Men dance round 1/2
    way clockwise, Ladies face out & set to opposite Man & 1/2 turn RH
33-40::
    Men dance LH across once round _while_ Ladies dance 1/2 way
    clockwise to original places, set to partners & turn RH to original
    places
41-48::
    All circle 8H round 1/2 way to Left; set, pull back LSh & cast 1
    place.  End having progressed 1 place round the set clockwise. 4 1 2
    3
::
    Repeat as a Jig, then as a Strathspey & finally as a Jig.  Each time
    starting from new places', 0);
INSERT INTO 'dancecrib' VALUES (7082, '2013-08-21 08:31:35.397105+00', '2023-02-04 01:22:10.585625+00', 5643, 3, NULL, 'ace', '1-8::
    1L+2M set & turn RH, 1M+2L set & turn RH
9-16::
    1s+2s dance R&L
17-24::
    1s lead down the middle, back to top, cross & cast to 2nd place
25-32::
    2s+1s Adv+Ret, 1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (9054, '2015-11-30 09:00:28.809137+00', '2023-02-04 01:23:13.899877+00', 10879, 3, NULL, 'ace', '{{explanation}}
Square set - All face partner for bow/curtsey & remain facing

1-8::
    Men pass prtnrs LSh, chase round outside of set back to place
9-16::
    Ladies repeat bars 1-8 passing prtnrs RSh
17-24::
    Men dance RH across, LH across back to place
25-32::
    Ladies repeat bars 17-24
33-40::
    1s lead across between 3s, cast away from each other round outside
    of set, back to place.       All couples face partners ready for
    repeat

{{explanation}}
Bars 33-40 2nd time 2s lead thro'' 4s, 3rd time 3s lead thro'' 1s, 4th time 4s lead thro'' 2s', 0);
INSERT INTO 'dancecrib' VALUES (13337, '2020-11-02 01:21:35.807369+00', '2023-02-04 01:22:10.613853+00', 5644, 3, NULL, 'ace', '1-8::
    1s+2s turn partner 2H, face up, 1s followed by 2s cast, dance down
    between 3s & cast back up to original places
9-16::
    1s+2s dance Tourbillon:
::
    _9-12_   1s & 2s 1/2 turn ptnrs 2H, 1M & 2L lead ptnrs by nearer
    hand 1 place cl''wise to end 1s on Ladies side & 2s Men''s side, 1s
    set to 2s
::
    _13-16_ 1s & 2s 1/2 turn ptnrs 2H & lead ptnrs on 1 place clockwise
    & 2s+1s cross RH to own sides
17-24::
    2s+1s+3s set & 1/2 turn RH to face down in Allemande hold, all set
    (HS)
25-32::
    All dance down (Allemande hold), couples change side (Ladies turning
    under Man''s arm) & all lead back to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7083, '2013-08-21 08:31:35.405536+00', '2023-02-04 01:22:10.644004+00', 11397, 3, NULL, 'ace', '1-8::
    Ladies dance in for 2 bars, turn right about & dance out (2 bars),
    chase clockwise 1/2 way to opp place
9-16::
    Ladies dance Fig of 8 round in front of new partner, behind new
    partner & in front & behind corner to place
17-24::
    Men dance in for 2 bars, turn left about & out 2 (2 bars), chase
    anticlockwise 1/2 way
25-32::
    Men dance Fig of 8 round own partner & corner
33-40::
    1s+3s dance R&L (end facing anticlockwise)
41-48::
    1s chase anticlockwise 1/4 way & then "loop" LSh round side person
    (1L around 4L, 1M around 4M in 2nd place) & chase on to place. 3s
    dance similar, looping around 2s in 4th place
49-64::
    2s+4s repeat bars 33-48
65-72::
    Ladies dance RH across & LH across back
73-80::
    Men dance LH across & RH across (end facing corners)
81-88::
    All set to corners, set to partners & turn RH into prom hold
89-96::
    All Promenade anticlockwise to place', 0);
INSERT INTO 'dancecrib' VALUES (8626, '2015-02-13 12:48:12.032068+00', '2023-02-04 01:22:10.67746+00', 12449, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s turn RH, cast down/up (2s+3s step up/down bars 3-4); 1s+4s
    set, dance 1/2 RH across to face out and to right (1M+4L out/down on
    Ladies'' side, 4M+1L out/up on Men''s side)
9-16::
    4M+1L also 1M+4L dance alternating RSh tandem reels of 3 on sides
    (dance to Right to start)
17-24::
    1s+4s dance RH across &  LH back, to face out and to left (1L+4M
    out/down on Men''s side, 4L+1M out/up on Ladies'' side)
25-32::
    1L+4M also 4L+1M dance alternating LSh tandem reels of 3 on sides
    (dance to Left to start).  End 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (7084, '2013-08-21 08:31:35.413626+00', '2023-02-04 01:22:10.704794+00', 9674, 3, NULL, 'ace', '1-8::
    All Adv+Ret twice
9-16::
    1s lead down the middle & back
17-24::
    1s+2s dance RH across & LH back
25-32::
    1s followed by 2s+3s+4s cast, 1s make arch & 2s+3s+4s dance under to
    top', 0);
INSERT INTO 'dancecrib' VALUES (7085, '2013-08-21 08:31:35.421819+00', '2023-02-04 01:22:10.732336+00', 14951, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels of 3 on sides, 2s giving RSh to person on their
    right
9-16::
    2s+3s dance 1/2 LH across & in prom hold with corners dance
    anticlockwise 3 places round set
17-24::
    The 2 couples in 1st & 2nd places also the 2 couples in 3rd & 4th
    places dance RH Spiral Progression:
::
    All turn RH & giving LH all Bal-in-Line, on 2nd setting step all
    turn to left to face clockwise
25-32::
    The 2 centre couples dance LH Spiral Progression
33-40::
    All dance modified La Barette to end 3L+4M in 1st place, 4L+3M in
    2nd place, 2L+1M in 3rd place, 1L+2M in 4th place', 0);
INSERT INTO 'dancecrib' VALUES (7086, '2013-08-21 08:31:35.42988+00', '2023-02-04 01:22:10.792575+00', 10931, 3, NULL, 'ace', '1-8::
    1s & 4s turn RH, cast in 1 place & dance LH across
9-16::
    2s+1s also 3s+4s dance RH across & dance 1/2 reels of 4 on sides
17-24::
    3s+4s also 1s+2s dance RH across ending in lines across (3M+4L also
    1M+2L BtoB, Man facing Man) & dance 1/2 reel of 4 across but centre
    persons end same place (beside partner 4 facing 4)
25-32::
    All Set+Link in tandem (each couple dancing as one) on to sides to
    (4) 3 2 (1), 1s+4s dance RH across _while_ 3s+2 chase 1/2 way to 2 4
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (7087, '2013-08-21 08:31:35.437869+00', '2023-02-04 01:22:10.820745+00', 12615, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, petronella turn into middle, set & middle 4 persons
    set turning to face other partner
9-16::
    1M+2L+2M+3L dance reel of 4 up/down & end facing own partners
17-24::
    1s+2s+3s set, petronella turn to opposite sides, set & 1s+2s dance
    1/2 RH across _while_ 3s cross RH
25-32::
    2s+1s+3s dance Grand Chain with 3s crossing to start', 0);
INSERT INTO 'dancecrib' VALUES (7088, '2013-08-21 08:31:35.445833+00', '2023-02-04 01:22:10.844981+00', 14535, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place; 1s dance down between 3s & cast up to 2nd
    places
9-16::
    1s dance Diag R&L.  (3)1(2)
17-24::
    All Set+Link for 3 twice.  2(1)3
25-32::
    1L dances 1/2 Fig of 8 round 2s as 1M dances 1/2 Fig of 8 round 3s
    (1L up, 1M down); all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (7089, '2013-08-21 08:31:35.453882+00', '2023-02-04 01:22:10.869359+00', 5648, 3, NULL, 'ace', '1-8::
    1M sets to 2L & cast 1 place, 1L sets to 2M & casts 1 place
9-16::
    2s+1s+3s Adv+Ret, 1s dance 1/2 reel of 4 with 1st corners & end 1L
    between top cpl facing down 1M between bottom cpl facing up
17-24::
    All Adv+Ret (up/down), 1s dance 1/2 reel of 4 with 2nd corners
    ending 2nd place opposite sides.  (3)(1)(2)
25-28::
    3L+1M also 1L+2M cross RH, 3M+2M also 3L+2L cross LH
29-32::
    1M+2L also 3M+1L cross LH, all cross LH to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7090, '2013-08-21 08:31:35.46202+00', '2023-02-04 01:22:10.89703+00', 359, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 LSh reels of 3 across (Man
    with 2s & Lady with 3s)
9-16::
    1s dance 1/2 reel of 3 with other couple, cross RH & cast up to
    original places
17-24::
    1s+3s dance 1/2 R&L _while_ 2s set & 1/2 RH turn to face down, 3s
    set _while_ 1s dance up under 2s arch (2s down), 2s set _while_ 1s
    dance up making an arch for 3s who dance down.  1 3 2
25-32::
    1s set _while_ 3s dance down making an arch as 2s dance up, 3s set
    _while_ 2s dance up making an arch as 1s dance down, all set & cross
    RH', 0);
INSERT INTO 'dancecrib' VALUES (14296, '2021-09-08 00:21:31.649819+00', '2023-02-04 01:22:10.936291+00', 20352, 3, NULL, 'ace', '1-8::
    1s cross RH & cast (2s step up); 1s cross RH & cast,1M up to beween
    2s facing down, 1L down to between 3s facing up
9-16::
    Lines of 3 across Adv+Ret, turn opposite dancer RH & finish in line
    of 3 across again, all facing down
17-24::
    All dance down & back. 1s end facing 3rd corner
25-28::
    1s dance 1/2 reels of 3 across, RSh to 3rd corner to start, 1s turn
    3/4 RH to face 4th corners (pstn)
29-32::
    1s dance 1/2 reels of 3 across, RSh to 4th corner pstn to start.
    End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7091, '2013-08-21 08:31:35.46997+00', '2023-02-04 01:22:10.954308+00', 5650, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on opposite sides dancing out between 2s & 3s to
    start
9-16::
    1s dance reels of 3 on own sides dancing out between 2s & 3s to
    start
17-24::
    1s+2s dance R&L ending with 3/4 LH turn into line across with 1M &
    2L on outside facing in & 1L+2M pass LSh to face own partner
25-32::
    1s+2s dance reel of 4 across 1s ending 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (9403, '2016-10-06 07:18:52.017577+00', '2023-02-04 01:22:10.977874+00', 17211, 3, NULL, 'ace', '1-8::
    1L+2M set & cast clockwise to change places, 1s+2s dance RH across
    1/2 way & 1L+2M turn RH back to original places
9-16::
    2L+1M set & cast anticlockwise to change places, 1s+2s dance LH
    across 1/2 way & 1L+2M set advancing turning right about to sides as
    2L+1M turn LH to face partners
17-24::
    1s+2s dance reel of 4 across ending with 1L+2M dancing clockwise
    into middle as 1M+2L on bar 23 turn LH 1.1/4 times to face partner
    for…
25-32::
    1s+2s dance reel of 4 up/down middle & 1L+2M dance on clockwise to
    own sides as 1M+2L on bar 31 turn LH to own sides.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (13338, '2020-11-02 01:21:36.245242+00', '2023-02-04 01:22:11.148376+00', 17700, 3, NULL, 'ace', '1-8::
    1s cross down RH, cast up round 2s & cross RH back to own side. All
    4 couples set
9-16::
    1s & 4s turn partner LH _while_ 2s+3s dance LH across; 1s+2s & 3s+4s
    dance RH across
17-24::
    All circle 8H round to left; Ladies circle back to right _while_ Men
    continue circle to left outside Ladies. All end on own sides in
    original places
25-32::
    All set, Adv+Ret, drop hands, set turning so 1s face 2s, 3s face 4s
33-40::
    Mirror reels of 4 on side (Men pass RSh, Ladies pass LSh to start)
41-48::
    1s NHJ dance down middle (4 bars); 1s NHJ dance up to 3rd place
    (2s+3s step up), 1s+4s change places on sides (Men LH, Ladies RH).
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7092, '2013-08-21 08:31:35.508023+00', '2023-02-04 01:22:11.198009+00', 11228, 3, NULL, 'ace', '1-8::
    1s dance between 2s, behind 3s, between 4s & cast back to places
9-16::
    1s turn RH, turn 2s LH on sides, turn each other RH & turn 3s LH on
    sides
17-24::
    1s turn RH, turn 4s LH on sides & turn each other RH (4 bars)  [Bars
    9-24 as in Strip the Willow]
25-32::
    1s dance up & back to 4th place _while_ others clap
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13339, '2020-11-02 01:21:36.344138+00', '2023-02-04 01:22:11.248078+00', 16894, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 2s+1s dance 1/2 Men''s Chain
9-16::
    1s+2s dance 1/2 reels of 3 on sides, 1s & 2s pass partner RSh to
    start; 1s face 2s, set & circle 4H 1/2 round to left
17-24::
    2L followed by 2M also 1L followed by 1M dance reels of 3 across (2s
    RSh to 3s at top, 1s RSh to 4s). End 1s on Ladies'' side, 2s on Men''s
    side in prom hold
25-32::
    1s+2s dance dance Tournée (1s+2s dance in to meet LSh to LSh to
    start)
33-40::
    1s & 3s dance in, cast (2s & 4s step up); 2s+3s+4s+1s turn partner
    2H.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7094, '2013-08-21 08:31:35.525929+00', '2023-02-04 01:22:11.282478+00', 5654, 3, NULL, 'ace', '1-8::
    1s+2s turn RH to face each other & set, 1s+2s dance RH across
9-16::
    1M+2L cross RH & 1L+2M cross RH, 1s+2s dance 1/2 R&L.  1 2
17-24::
    All set & circle 4H round to left then set advancing for Allemande
25-32::
    1s+2 dance Allemande.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (9404, '2016-10-06 07:18:52.056515+00', '2023-02-04 01:22:11.302481+00', 17235, 3, NULL, 'ace', '1-8::
    1s+2s 1/2 turn 2H (2 bars), cast, pulling back RSh into centre
    facing partner (M face up/ L down).  1s+2s dance 1/2 reel of 4,
    finish in centre
9-16::
    2s+1s set, petronella turn to own sides.  1s+3s 4H round to Left
    finishing in centre, 1s facing down, 3s facing up for…
17-24::
    1s+3s dance Rondel. 1s finish in middle 3rd place facing down, 3s in
    2nd place facing out
25-32::
    3s+1s+4s dance 6 bar mirror (reflection) reels of 3 on sides (4s
    cast up, 1s in/down, 2s out/down). 1s+4s 1/2 turn (Men RH, Ladies
    LH)  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9405, '2016-10-06 07:18:52.064114+00', '2023-02-04 01:22:11.320402+00', 17218, 3, NULL, 'ace', '1-2::
    In 2 couple groups Ladies set rotating and dance to next place
    clockwise as 1M/3M 3/4 turn 2M/4M with 2H into 1L/3L places (1M/3M
    pivoting & 2M/4M turning past & rotating)
3-4::
    All dance a little more than 1/2 RH across to end with 1s+3s in line
    up/down middle (Men facing up)
5-8::
    1s+3s dance 1/2 reel of 4 with 1s & 3s ending in line up/down middle
    (Men face Ladies side, Ladies Mens side)
9-12::
    3s+1s Bal-in-line as 2L & 4M set, 3L+1M (middle couple) 3/4 turn LH
    as 2L/4M (pivoting) turn 3M/1L 2H (passing & rotating) to end in
    lines across
13-16::
    3s+1s Bal-in-line & 3L+1M (middle couple) 3/4 turn LH as 2M/4L
    (rotating) turn 1L/3M 2H (passing & rotating) in lines up/down
17-24::
    Repeat bars 9-16
25-32::
    3s & 1s 3/4 turn RH moving down to 2nd/4th places then 2s+3s also
    4s+1s dance RH across & all set.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7095, '2013-08-21 08:31:35.578028+00', '2023-02-04 01:22:11.492643+00', 5658, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret; 1s+2s cross over Ladies dancing under arch made by
    Men, 1s turn under 2s to 2nd place
9-16::
    2s+1s Adv+Ret; cross Men dancing under Ladies arch & 1s turn under
    2s to original places
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (7096, '2013-08-21 08:31:35.58615+00', '2023-02-04 01:22:11.52557+00', 9944, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    All dance Grand Chain
9-16::
    1s & 4s cross RH, cast in 1 place, dance RH across & 1/2 turn RH
    into prom hold (1s facing Men''s side & 4s facing Ladies side)
17-24::
    1s & 4s dance reels of 3 on sides (LSh to Lady on left) & end in
    middle 1s facing 4s
25-32::
    1s+4s set to each other, set advancing to pass LSh to face corners,
    4s & 1s turn corners (nearer hand) as they dance out between ends.
    2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (13436, '2020-12-02 01:21:31.61271+00', '2023-02-04 01:22:11.557201+00', 20146, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across, 1s cast to 2nd place as 2s dance up to
    top & face out
9-16::
    Mirror reels of 3 on sides (1s in/down, 2s out/down, 3s out/up to
    start). 2 1 3
17-24::
    1s dance 1/2 Fig 8 down round 3s; 1s dance 1/2 Fig 8 up round 2s
25-32::
    1s+3s dance »Rose Progression«:
::
    _25-26_   1M+3L set as 1L+3M change places RH
::
    _27-28_   1M+3L 1/2 turn RH, pull back RSh as 1L & 3M dance into
    partner''s place
::
    _29-30_   1M+3L cast into each others place as 1L+3M 1/2 turn RH,
    pull back RSh
::
    _31-32_   1M & 3L dance into 2nd/1st places own side as 1L & 3M cast
    to right to new places   2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (10096, '2017-09-03 23:45:19.544586+00', '2023-02-04 01:22:11.589174+00', 17775, 3, NULL, 'ace', '1-8::
    1s+2s dance Rose Progression:
::
    _1- 2_     1M+2L set as 1L+2M change places RH
::
    _3- 4_     1M+2L 1/2 turn 2H as 1L & 2M dance into partners place
::
    _5- 6_     1M+2L cast into each other''s place as 1L+2M 1/2 turn 2H
::
    _7- 8_     1M & 2L dance into 2nd/1st places own side as 1L & 2M
    cast to right to new places
9-16::
    2s+1s+3s dance reels of 3 on sides (1s pass 3rd corners RSh)
17-24::
    1s turn RH (4 bars), 2s+1s+3s set, drop hands & set Advancing, pass
    partner LSh , pull back RSh to face partner in middle
25-28::
    2s+1s+3s turn partner 3/4 2H into line up/down middle, drop hands &
    continue to dance round 3/4 round partner into line up/down middle
    facing partner again
29-32::
    2s+1s+3s set. All cast Right & dance out to own sides', 0);
INSERT INTO 'dancecrib' VALUES (7097, '2013-08-21 08:31:35.595966+00', '2023-02-04 01:22:11.649034+00', 8576, 3, NULL, 'ace', '1-8::
    2s followed by 1s lead down middle for 2 bars, 1s followed by 2s
    lead up to top, 1s cast to 2nd pl _while_ 2s loop round to 1st pl &
    2s+1s cross RH
9-12::
    2s+1s set advancing into middle passing partners LSh & turn right
    about to face partner, turn partners 2H back to own sides
13-16::
    2s facing 1s set advancing (up down) passing LSh & turn right about
    to face other person & turn 2H back to original places
17-24::
    1s+2 dance 4H round to left & dance 1/2 Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (4123, '2013-08-21 08:30:43.928079+00', '2023-02-04 01:18:35.798866+00', 9082, 3, NULL, 'ace', '1-8::
    1s+3s cross RH, cast 1 place, cross LH, cast (Lady up & Man down) &
    end in the middle (1M & 3L having passed LSh)
9-16::
    Reels across: 1M+3L+4s reel of 4 in centre _while_ 1L+2s & 3M+5s
    reels of 3, all giving RSh to 1cnr
17-24::
    1s+3s turn 1st corner, partner, 2nd corner & partner into…
25-32::
    All dance RH across (2s+1L & 1M+4s+3L & 3M+5s), 1s & 3s turn
    partners LH & cast down 1 place on own side (to end 2 4 1 5 3)', 0);
INSERT INTO 'dancecrib' VALUES (4124, '2013-08-21 08:30:43.937925+00', '2023-02-04 01:18:35.820437+00', 9076, 3, NULL, 'ace', '1-8::
    1L dances RH across with 1M+2M _while_ 3M dances RH with 2L+3L, 1s
    circle 3H round to left with same dancers
9-16::
    1L & 3M dance out between 1M+2M/2L+3L, cast to left, 3/4 turn LH to
    face opposite sides & dance RH across all end in original places
17-24::
    1L also 3M followed by ptnrs chase cl''wise 1/2 way to 3s facing down
    & 1s up in centre, 3s+1s dance 1/2 R&L & 1s end turning LH to face
    1st crnrs
25-32::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partner LH to
    2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (8627, '2015-02-13 12:48:12.250282+00', '2023-02-04 01:22:11.668885+00', 11316, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All dance circle 8 hands round and back
9-16::
    All dance Interlocking Reels of 4.  Pass partner RSh to begin
17-24::
    1s+3s dance 1/2 R&L, then 2s+4s dance 1/2 R&L
25-32::
    All dance Interlocking Reels of 4.  Pass partner LSh to begin
33-40::
    All join nearer hands with partner, set, Petronella-in-tandem one
    place to the right.  Repeat, but Ladies omit end of petronella turn
    to face out
41-56::
    All dance Schiehallion Reels, finish facing partners
57-64::
    All set to partners, turn partners RH to face corner, set to corner,
    turn corner LH

{{title}}
Jig

65-120::
    Repeat bars 1-56
121-128::
    All turn partner RH, turn corner LH', 0);
INSERT INTO 'dancecrib' VALUES (9038, '2015-11-30 09:00:14.484776+00', '2023-02-04 01:22:11.695458+00', 11703, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s with 2s stepping up bars 3-4.  1s finish
    B-to-B, 1M facing 2L, 1L facing 2M
9-16::
    1s+2s dance RSh reel of 4 across, 1s pass LSh to finish in 2nd
    place, opp sides, facing out
17-24::
    Mirror (reflection) reels of 3 on sides (1s out/down, 3s in/up, 2s
    in/down to start)  1s end in middle NHJ facing down
25-32::
    1s cross below 3s, cast up, meet, lead up to top & cast to 2nd place
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (14218, '2021-08-14 00:21:38.684237+00', '2023-02-04 01:22:11.718644+00', 19129, 3, NULL, 'ace', '1-8::
    1s cross down to dance mirror reels of 3 on opp side (2s out/up, 3s
    in/up to start)
9-16::
    1s cross down to dance mirror reels of 3 on own side
17-24::
    1s dance down NHJ (2 steps), turn 2H; dance up & turn 2H back to
    place
25-32::
    1s+2s dance Rose Progression:
::
    _25-26_   1M+2L set as 1L+2M change places RH
::
    _27-28_   1M+2L 1/2 turn 2H as 1L & 2M dance into partners place
::
    _29-30_   1M+2L cast into each others place as 1L+2M 1/2 turn 2H
::
    _31-32_   1M & 2L dance into 2nd/1st places own side as 1L & 2M cast
    to right to new places. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7099, '2013-08-21 08:31:35.612852+00', '2023-02-04 01:22:11.76568+00', 5667, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+3s Set+Link, 1M & 3M pass partners to right, 1L followed closely
    by 3M dance out between 4s _while_ 3L followed by 1M dance out
    between 2s, Ladies dance to their right & Men to left to join ends
    of line of 4 with 2s/4s
9-16::
    All set in lines of 4 on sides, 1M & 3 M cast to opposite ends of
    lines _while_ partners dance into centre & pirouette (BtoB), Men
    dance into centre & pirouette _while_ Ladies dance right to end of
    side lines facing out, Men dance out to right to ends of line facing
    out _while_ partners cast to opposite ends of line
17-24::
    All dance full reels of 4 on sides
25-32::
    Middle couples turn dancers at ends once round, finish in lines of 4
    all facing across set (3M+2L+2M+1L facing 3L+4M+L+1M).  All set,
    3s+1s advancing towards partners whlst 2s+4s turn to face partners;
    all 3/4 turn partners to end in prom hold facing clockwise (Men on
    outside), all Promenade on 1 place & face in.  4 3 2 1

{{title}}
Reel

1-8::
    4s & 2s (top & bottom couples) Set+Link, Men pass partners in front
    as 4s & 2s cross to face side couples who dance away from partners
    towards corner positions, Ladies turn Men by LH _while_ Men turn
    Ladies by RH to finish in Sq.Set
9-16::
    4s & 2s with 2H joined set & pass each other couple (Men BtoB), set
    & pass back (Ladies BtoB)
17-24::
    All joining RH with partners set, Men set again as Ladies turn right
    under partners arm, 1.1/4 turn to end in prom hold facing
    anticlockwise
25-32::
    All Promenade round
::
    Repeat Strathspey & Reel again to end in original pstns', 0);
INSERT INTO 'dancecrib' VALUES (7101, '2013-08-21 08:31:35.628987+00', '2023-02-04 01:22:11.818287+00', 10147, 3, NULL, 'ace', '1-8::
    1s dance down & back to top
9-16::
    1s+2s set. 1s+2s change places RH on sides _while_ 3s set, 1s+3s
    change places LH on sides _while_ 4s set & 1s+4s change places RH on
    sides
17-24::
    All dance reels of 4 on side
25-32::
    2M+3L+4M+1L dance reel of 4 in middle _while_ partners chase
    clockwise once round
33-40::
    All circle 8H round & back. End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7102, '2013-08-21 08:31:35.637083+00', '2023-02-04 01:22:11.836207+00', 5671, 3, NULL, 'ace', '1-4::
    1s lead down below 3s, cross & cast up to 2nd place on opposite side
5-16::
    2s+1s+3s dance 3 couple R&L, 1s end facing 1st corners
17-24::
    1s set to & turn 1st corner 2H, set to & turn 2nd corner 2H. 1s
    finish BtoB in centre, 1M facing up, 1L facing down
25-32::
    1M+2s & 1L+3s circle 3H round to left & on bar 4 1s pull back RSh to
    face each other & set; 1s Petronella turn to 2nd place own side.  2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (7103, '2013-08-21 08:31:35.645074+00', '2023-02-04 01:22:11.85314+00', 5677, 3, NULL, 'ace', '1-8::
    1s & 3s lead down between 2s/4s & cast back to place, 1s+2s also
    3s+4s dance LH across
9-16::
    1s+2s also 3s+4s dance R&L ending in middle
17-24::
    1s+2s also 3s+4s dance the Rondel
25-32::
    1s+4s+3s dance 1/2 reel of 3 on sides (1s out & down to start), all
    turn partners RH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14433, '2021-11-06 01:13:00.108511+00', '2023-02-04 01:22:11.875188+00', 5680, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up 3-4); 1s set advancing & turn RH to face
    1st corners
9-16::
    1s dance RSh reels of 4 with 1st corners, 1st turn RH to face 2nd
    corners
17-24::
    1s dance LSh reels of 4 with 2nd corners ending in the centre facing
    each other.
25-28::
    1s set, 1s turn RH
29-36::
    1s dance RSh reels of 3 with 2s & 3s on opposite sides
37-40::
    1s dance RH across (Lady with 2s & Man with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (12459, '2020-01-02 06:58:44.359193+00', '2023-02-04 01:18:35.846149+00', 16680, 3, NULL, 'ace', '1-8::
    1s cross down RH (2s step up) to BtoB in centre facing opp sides &
    2s+1s+3s dance 6 bars Double Triangles
9-16::
    1s dance out of own side, cast left round 4th corner, dance up/down
    set & turn LH to face 1st corners _while_ corners Advance diag to
    centre, pull back RSh & chase clockwise 1/2 round
17-24::
    1s dance 1/2 diag reel of 4 with 1st corners (pstn), pass RSh, dance
    1/2 diag reel of 4 with 2nd corners (pstn). 1s pass RSh to 2nd place
    own side
25-32::
    2s+1s+3s Adv+Ret, all clap; all turn partner RH (or birl). 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11690, '2019-03-18 21:01:44.733635+00', '2023-02-04 01:18:35.870437+00', 19134, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 2 places (2s+3s step up on bars 3-4); 1s cross LH
    & set
9-16::
    2s repeat bars 1-8.  End 3 1 2
17-24::
    1s turn 1st corners RH, pass partner RSh to turn 2nd corners RH &
    cross passing partner RSh to 2nd place own sides (corners dance 4
    bars)
25-32::
    3s+1s+2s chase clockwise 1/2 way round to opposite sides, set &
    cross RH', 0);
INSERT INTO 'dancecrib' VALUES (14413, '2021-11-06 01:09:54.120793+00', '2023-02-04 01:18:35.898417+00', 20539, 3, NULL, 'ace', '1-4::
    1s cross down RH to 2nd place opp side _while_ 2s step up, 2s+1s+3s
    set.  2 (1) 3
5-8::
    1s cross down LH, cast up round 3s to 2nd place own side
9-16::
    2s+1s+3s Set+Link for 3 into lines of 3 across; line at top & bottom
    dance RH across back into lines of 3 across
17-24::
    Lines across Set+Link for 3; 1s turn 2H to 2nd place opp sides
    _while_ 3s & 2s chase clockwise 2 places to own sides.  2 (1) 3
25-28::
    1s dance down NHJ (2 bars), face each other & set advancing passing
    LSh & face up NHJ (3s step up 27-28)
29-32::
    1s dance up to 3rd place own side facing out & change places with 4s
    (Ladies RH, Men LH). 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7104, '2013-08-21 08:31:35.65481+00', '2023-02-04 01:22:11.897298+00', 9563, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on sides (1s dance in & down to
    start) & end with 1s in 2nd pl BtoB facing own sides & 2s in 1st pl
9-16::
    2s+1s+3s set, 1s 1/4 turn to right & set with 2s+3s (as Crown
    Triangles), 1s dance RSh round RH crnr into middle BtoB facing opp
    sides
17-24::
    Repeat from new positions 1s ending in 2nd place own sides
25-32::
    1s dance reels of 3 across (Lady with 2s & Man with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (12127, '2019-09-01 22:10:38.899202+00', '2023-02-04 01:22:11.917878+00', 19589, 3, NULL, 'ace', '1-8::
    Circle 8H round and back
9-16::
    All 4 Men dance LH across; dance LSh round partner, into centre and
    curve round into place & face out
17-24::
    All 4 couples dance Ladies'' Chain, dancing 1/2 RH across in centre
    to pass
25-28::
    All 4 couples Adv+Retire
29-32::
    All 4 couples Adv again and Retire with corner (on diag)
33-40::
    All set, finish facing corner, all dance DoSiDo with corner & all
    set facing corner
41-44::
    All dance 1/2 Interlocking Reels of 4 (pass corner RSh, next person
    LSh, the next RSh)
45-48::
    Meet partner and turn RH and face in (Lady on partner''s left)
49-72::
    Repeat 25-48
73-80::
    All 4 Ladies dance RH across, dance RSh round partner, into centre
    and curve round into place & face out
81-88::
    All 4 couples dance a Men''s Chain, dancing 1/2 LH across in centre
    to pass, all end in original places
89-96::
    Circle 8H round to the Left and finish by dancing into the circle
    with a ''Whoop''', 0);
INSERT INTO 'dancecrib' VALUES (7105, '2013-08-21 08:31:35.732205+00', '2023-02-04 01:22:12.106518+00', 5685, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & face 1st corners, 1s dance 1/2 reel of 4 with
    1st corners & end facing 2nd corners
9-16::
    1s dance 1/2 reel of 4 with 2nd corners, pass RSh to 2nd place own
    sides, set & cast up to top
17-24::
    1s dance down below 3rd place, cast up behind couple in 3rd place,
    dance up between top couple & cast to 2nd place own sides
25-32::
    1s dance modified Diag R&L: 1st+2nd persons on Men''s side & 2nd+3rd
    persons on Ladies side change places RH on sides then LH diagonally
    followed by 2nd+3rd persons on Men''s side & 1st+2nd persons on
    Ladies side change places RH then LH diagonally to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7106, '2013-08-21 08:31:35.740343+00', '2023-02-04 01:22:12.132896+00', 10380, 3, NULL, 'ace', '1-8::
    2s set advancing to setting 2nd corners to dance a diagonal reel of
    4 with 2nd corners & end in orginal places
9-16::
    1L & 3M cast up/down 2 places & dance towards each other then turn
    right about to end BtoB & dance into each others place _while_
    partners dance towards each other & turn right about then all set
17-24::
    3s & 1s 3/4 turn 2H into a line up/down middle & dance 1/2 reel of
    4, 3/4 turn 2H to opposite sides
25-32::
    1s+2s dance R&L 1/2 way, 2s+3s dance R&L 1/2 way _while_ 1s turn 2H
    twice', 0);
INSERT INTO 'dancecrib' VALUES (10452, '2018-02-24 07:53:13.186152+00', '2023-02-04 01:22:12.249504+00', 17472, 3, NULL, 'ace', '1-4::
    1M+2L also 3M+4L turn 2H 1.1/2 times to change places
5-8::
    1L+2M also 3L+4M turn 2H 1.1/2 times to change places (2)(1)(4)(3)
9-16::
    1s & 4s (middle couples) dance Fig 8 around nearest end couple (1s
    round 2s at top, 4s round 3s at bottom)
17-24::
    All dance NHJ down for 2 steps, turn 2H 1.1/2 times (4 bars) & dance
    up, ending on own sides 2 1 4 3
25-32::
    1s+4s+3s (bottom 3 couples) dance the Knot, to finish 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7109, '2013-08-21 08:31:35.76612+00', '2023-02-04 01:22:12.280318+00', 5691, 3, NULL, 'ace', '1-8::
    1M+2M dance across between partners & cast round partners back to
    places, 1L+2L repeat
9-16::
    1s+2s dance double Fig of 8
17-24::
    1s+3s dance double Fig of 8
25-32::
    1s+3s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4126, '2013-08-21 08:30:43.960373+00', '2023-02-04 01:18:36.0928+00', 8702, 3, NULL, 'ace', '1-8::
    1s+2s set & dance 6 bars of R&L
9-16::
    2s+1s+3s dance Allemande 1s end facing 1st corner pstns
17-24::
    1s 1/2 RH turn corners, 1s followed by corners dance into line of 4
    up/down centre (M face down & L up) & dance 1/2 RSh reel of 4, 1s
    end facing 2nd corners
25-32::
    Repeat bars 17-24 with 2nd corners but 1/2 LH turn and 1/2 LSh reel
    of 4 to end (2) 1 (3)
33-40::
    1s dance Diag R&L to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (11467, '2019-01-01 01:57:46.792021+00', '2023-02-04 01:22:12.309903+00', 18969, 3, NULL, 'ace', '1-8::
    1s+2s set & dance 1/2 RH across, set & dance 1/2 LH across
9-16::
    1s cross RH & cast 1 place, cross LH & cast to meet below 3s then
    lead up to face 1st corners
17-24::
    1s set & turn 1st corners 2H to face 2nd corners, set & turn 2nd
    corners 2H ending 2nd place opp sides
25-32::
    2s+1s+3s Adv+Ret, 1s turn RH 1.1/2 times to own sides.', 0);
INSERT INTO 'dancecrib' VALUES (7110, '2013-08-21 08:31:35.897247+00', '2023-02-04 01:22:12.502504+00', 12671, 3, NULL, 'ace', '1-8::
    1s cross down to dance reels of 3 on opposite sides & end with 1s
    dancing to face 1st corners as 2s dance up to 1st place
9-16::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners ending 2nd place opposite sides
17-24::
    1s dance 1/2 Figs of 8 1M round 2s & 1L round 3s, 1s+3s Set+Link
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7111, '2013-08-21 08:31:35.90725+00', '2023-02-04 01:22:12.536728+00', 5696, 3, NULL, 'ace', '1-8::
    All set, Ladies (NHJ with partner on left) dance RH across for 2
    places & all set.  2 3 1
9-16::
    All turn partner 2H & circle 6H round for 2 places & turn partner
    2H.  3 1 2
17-24::
    Men dance Fig 8, dancing in front of partner, behind next lady (on
    right, passing LSh), round partner (passing RSh) & take prom hold
    with partner
25-32::
    All dance reel of 3 across (3s in 1st place pass 2s on right RSh)  3
    1 2', 0);
INSERT INTO 'dancecrib' VALUES (7112, '2013-08-21 08:31:35.915287+00', '2023-02-04 01:22:12.568588+00', 5697, 3, NULL, 'ace', '1-8::
    1s set & change places RH, 1s+2s set to & change places RH with
    partners.  1 (2) 3
9-16::
    1s+2s+3s set to & change places RH with partners, 1s+2s+3s advance
    setting & 1/2 turn partner 2H.  1 (2) 3
17-24::
    1s+2s+3s dance Grand Chain (1s cross to start)
25-32::
    1s+2s dance 1/2 R&L, 1s 1/2 turn RH', 0);
INSERT INTO 'dancecrib' VALUES (11468, '2019-01-01 01:57:46.89743+00', '2023-02-04 01:22:12.604223+00', 18946, 3, NULL, 'ace', '1-16::
    1s+2s dance "The Rosss":
::
    _1-4_     1M+2L cross RH, cast to their Left _while_ partners step
    up/down & face out bars 3-4
::
    _5-8_     1M+1L also 2L+2M turn LH on sides
::
    _9-12_   1M+2L cross RH, cast to their Right _while_ partners step
    up/down & face out bars 11-12
::
    _13-16_ 1M+1L also 2L+2M turn RH on sides
17-24::
    1s+2s+3s dance "Rosss''s Reel":
::
    RSh reels of 3  except 1M dances 1/2 reel on own side, crosses set
    from 3rd place to briefly follow 1L (she frowns) & then crosses back
    & up to top place own side & 1s face out (2M+3M dance normal reel of
    3 shape)
25-32::
    1s cast round 2s (2s step up 27-28), cross down between 3s, cast up
    to 2nd place & cross LH to own sides

{{explanation}}
Note:  End of 2nd time through 1s remain in 3rd place, stepping down (bars 3-4) as new top couple start', 0);
INSERT INTO 'dancecrib' VALUES (7113, '2013-08-21 08:31:35.92322+00', '2023-02-04 01:22:12.638754+00', 7296, 3, NULL, 'ace', '1-8::
    All set & cross RH, set & circle 6H round to left 1/2 way
9-16::
    2s+1s set, dance RH across & 2s cast _while_ 1s dance up to change
    places
17-24::
    1s dance reflection reels of 3 on own sides dancing out & up to
    start, 1s & 3s continuing reel to change places
25-32::
    1s+3s+2s dance the Knot.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7114, '2013-08-21 08:31:35.931393+00', '2023-02-04 01:22:12.662024+00', 8363, 3, NULL, 'ace', '1-8::
    1s set, cast below 4s & lead up to top
::
    _while_ 2s stand for 2 bars then set, cast to bottom & lead up
::
    _while_ 3s stand for 4 bars then set, cast to bottom & lead up
9-16::
    1s+2s+3s Promenade & 1s cross & cast to 2nd place opp side as 2s
    dance up to 1st place & 3s dance to own places
17-24::
    1s turn 3s 1.1/2 times on sides (1L turns 3M RH, 1M turns 3L LH), 1s
    cast to 4th place & cross RH to own sides
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7115, '2013-08-21 08:31:35.941071+00', '2023-02-04 01:22:12.773367+00', 5702, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to top
9-16::
    1s set, 1/2 turn 2H to face 2s on sides, turn 2s RH 1.1/2 times
    ending in 2nd place opposite sides & 2s in 1st places
17-24::
    2s+1s dance R&L
25-32::
    2s+1s dance 1/2 Ladies'' Chain, 1s & 2s turn partners RH back to
    original places
33-40::
    1s+2s circle 4H round & back
41-48::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (7116, '2013-08-21 08:31:35.949036+00', '2023-02-04 01:22:12.798119+00', 5703, 3, NULL, 'ace', '1-8::
    All 1/2 turn partners RH, retain hold & give LH to next person & all
    set (M facing out), 1/2 turn next person LH & all set end Ladies
    turning inwards
9-16::
    1s+3s (in 2nd & 4th places) dance 1/2 Ladies'' Chain & 1/2 R&L
17-24::
    2s+4s dance 1/2 Ladies'' Chain & 1/2 R&L
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7117, '2013-08-21 08:31:36.039114+00', '2023-02-04 01:22:12.991161+00', 5704, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, dance DoSiDo & set
9-16::
    2s turn once & cast up to 1st place _while_ 1s & 3s turn 2H twice &
    1s end 2nd place, 1s set & cast 1 place (Lady up & Man down)
17-24::
    1s dance reels of 3 across (RSh to 2nd corners) & end facing 1st
    corners
25-32::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (7119, '2013-08-21 08:31:36.057674+00', '2023-02-04 01:22:13.201532+00', 5707, 3, NULL, 'ace', '1-8::
    1M+2L also 3M+4L change places passing RSh, 1L+2M also 3L+4M repeat
9-16::
    1M+2L also 3M+4L turn RH 1.1/2 times to original places, 1L+2M also
    3L+4M repeat but end in the middle, BtoB, facing partners
17-24::
    All dance diagonal reels of 4 ending in original places
25-32::
    1s+2s also 3s+4s Adv+Ret 1 step & circle 4H round to left to end in
    lines of 4 facing down with Ladies in middle, 1M & 3M in own places
    & 2M & 4M on Ladies side
33-40::
    "Winding up" Keeping nearer hands joined 1M followed by partner & 2L
    dance under arms of 2s back into a line across all facing down (with
    LH in partners RH resting on their RSh), 1M dance in front of his
    partner & under arch made by Ladies to end facing down _while_ 3s+4s
    dance similarly
41-48::
    All dance down for 4 steps, turn about holding hands above heads &
    dance up with crossed arms held out in front
49-56::
    "Unwind" 2M turns L about as 2L turn L about under her arm followed
    by 1L+1M to end in a line across as at beginning of Winding Up
    _while_ 3s+4s dance similarly, all dance to L for 4 steps with 3M &
    4M rotating their line cl''wise to join hands with 1s+2s to form in
    large circle (2M+3M also 1M+4M join hands)
57-64::
    All circle 8H round to left
65-72::
    1s make an arch & 4M leads others (with hands joined) under arch, 1M
    being last through & (if possible) all dance out of room', 0);
INSERT INTO 'dancecrib' VALUES (7121, '2013-08-21 08:31:36.085139+00', '2023-02-04 01:22:13.405602+00', 5708, 3, NULL, 'ace', '{{explanation}}
Couples in circle around room Men facing anticlockwise, Ladies clockwise

1-8::
    All set to partners 4 times
9-16::
    All Tulloch turn 1.1/2 to right, all Tulloch turn twice round to
    left ending BtoB with partner facing next person
17-32::
    Repeat bars 1-16 with new partner', 0);
INSERT INTO 'dancecrib' VALUES (4127, '2013-08-21 08:30:43.96863+00', '2023-02-04 01:18:36.128871+00', 338, 3, NULL, 'ace', '1-8::
    1s & 3s set, cast 1 place & dance 1/2 Figs of 8 (Lady round cpl
    above & Man round cpl below)
9-16::
    1s & 3s dance RH across (Lady with cpl below & Man with cpl above)
    to end facing 2nd corners & dance 1/2 diag reels of 4 with 2nd crnrs
17-24::
    1s & 3s dance LSh round partner to 1st corner (pstn) & turn corner
    RH, dance LSh round partner to face 4th crnr (pstn) & turn crnr RH
    into prom hold
25-32::
    1s & 3s with corners cross diagonally (pass RSh & 1s & 3s end
    2nd/4th places opp side), cross LH & cast 1 place', 0);
INSERT INTO 'dancecrib' VALUES (7122, '2013-08-21 08:31:36.099955+00', '2023-02-04 01:22:13.564092+00', 9889, 3, NULL, 'ace', '1-8::
    All Ladies dance in to face out between Man on right & Opposite Man,
    all set (circle), Ladies cast round Man on left to face in & all set
9-16::
    Ladies repeat back to original places
17-24::
    All circle 8H round & back
25-40::
    All dance Grand Chain (2 bars per hand)
41-48::
    All Men dance in to face out between Lady on left & opposite Lady,
    all set (circle), Men cast round Lady on right to face in & all set
49-56::
    Men repeat, casting RSh round partner back to original places in a
    cicle all facing in & all set
57-64::
    All circle 8H round & back
65-68::
    Ladies dance RH across
69-72::
    Men dance LH across
73-80::
    All Promenade round anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (7123, '2013-08-21 08:31:36.113695+00', '2023-02-04 01:22:13.586323+00', 10081, 3, NULL, 'ace', '1-8::
    All Set+Link & Set+Link again to face corners
9-16::
    All dance round corners LSh & dance round partners RSh 1.1/4 times
    to Men facing out to partners
17-32::
    All dance Triangular reel of 6 (as Schiehallion reel but with 3
    corners) & turn partners RH to original places
33-40::
    All Men dance RSh round partner & LH across in centre back to places
41-48::
    All Ladies dance LSh round partner & RH across in centre back to
    places
49-56::
    All pass partners RSh, dance round next person LSh & pass partner
    RSh back to places
57-64::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7124, '2013-08-21 08:31:36.128662+00', '2023-02-04 01:22:13.603339+00', 5711, 3, NULL, 'ace', '1-8::
    Ladies Adv+Ret, Adv+Ret _while_ Men dance Fig of 8 round partners &
    crnrs (dance behind ptnrs to start & end in centre facing ptnrs)
9-12::
    All change places with partners RH, Ladies dance LH across 1/2 way
    _while_ Men chase 1 place clockwise
13-16::
    All change places with new person RH, Men dance LH across 1/2 way
    _while_ Ladies  1 place clockwise to face own partner
17-20::
    All change places with partners RH. Ladies dance LH across 1/2 way
    _while_ Men chase to 1 place clockwise to face ''new'' partner
21-24::
    All turn new partner RH 1.1/2 times into fin in prom hold facing
    anticlockwise
25-32::
    All Promenade once round

{{explanation}}
Repeat with new partner', 0);
INSERT INTO 'dancecrib' VALUES (7125, '2013-08-21 08:31:36.143662+00', '2023-02-04 01:22:13.732561+00', 5713, 3, NULL, 'ace', '1-16::
    All Ladies cast & dance clockwise round outside of set back to
    place, Men repeat Fig but cast & dance anticlockwise round set
17-32::
    All dance Grand Chain 1/2 way (6 bars) & set to partner, continue
    Chain back to place (6 bars) & set to partner
33-40::
    1s+3s change places, 1s dancing between 3s (3 bars), repeat back to
    places, 3s dancing between 1s, 1s+3s turn RH into Allemande hold
41-48::
    1s+3s dance round inside of set anticlockwise in Allemande hold
49-64::
    2s+4s repeat Fig bars 33-48 with 2s dancing between 4s to start
65-88::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L, repeat back to places, all
    circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7126, '2013-08-21 08:31:36.159603+00', '2023-02-04 01:22:13.900067+00', 5717, 3, NULL, 'ace', '1-8::
    1L+2M change places RH & 2L+3M change places LH, 1M+2M+3M also
    1L+2L+3L dance LH across (All end as bar 4)
9-16::
    1s+2s+3s circle 6H round to left & partly back to end in order 1 2 3
    on opposite sides
17-24::
    1s cross down (each couple cross down as they reach top place) to
    dance reflection reels of 3 on sides & all end in original places
25-32::
    1s+2s dance Chain Progression :
::
    1s+2s 3/4 turn RH, 1M+2L turn LH 1.1/2 times as partners chase
    clockwise 1/2 way, 2s+1s turn RH to sides', 0);
INSERT INTO 'dancecrib' VALUES (7127, '2013-08-21 08:31:36.178964+00', '2023-02-04 01:22:13.938419+00', 5719, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All Promenade round clockwise
17-24::
    1L+3L cross RH, dance RSh round opposite partner, cross LH & dance
    LSh round partner _while_ 2M+4M cast round partner, cross RH, dance
    RSh round opposite partner & cross LH back to places
25-32::
    2L+4L & 1M+3M repeat
33-40::
    All Men dance 1/4 LH across, dance round RSh Lady on right & turn
    that Lady RH (4 bars)
41-64::
    Men repeat with each Lady in turn back to places
65-72::
    All Ladies dance 1/2 LH across, turn opposite Man, dance 1/2 LH
    across & turn partner RH
73-80::
    All Promenade round anticlockwise
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7128, '2013-08-21 08:31:36.193483+00', '2023-02-04 01:22:13.968933+00', 5721, 3, NULL, 'ace', '1-8::
    1s turn RH with Lady ending in original place & Man in 2nd place,
    1M+2L turn RH with Lady ending in original place & Man in 3rd place
9-16::
    1L+2M also 1M+3L cross RH & 1L+3M also 1M+2L change places on sides
    LH, 1s petronella turn into lines across (1M at top) & all set
17-24::
    All change places with partners RH & chase clockwise to own sides (3
    1 2), turn partner RH in centre for Allemande
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7129, '2013-08-21 08:31:36.2272+00', '2023-02-04 01:22:14.001162+00', 5723, 3, NULL, 'ace', '1-8::
    1M dances a Fig of 8 round 1L & 2L passing 2L by RSh to start,2L
    turns right about bars 1-4 & 1L turns left about bars 5-8
9-16::
    1M+2L lead down the middle & back to top (1L dances down 1 place)
17-24::
    1M+2L also 2M+1L dance Allemande
25-32::
    1M+2L turn RH, 1M+1L turn LH to 2nd places (2L steps up)', 0);
INSERT INTO 'dancecrib' VALUES (7130, '2013-08-21 08:31:36.235337+00', '2023-02-04 01:22:14.026923+00', 5726, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    1M+2M also 3M+4M turn RH 1.1/2 times, 1L+2L also 3L+4L repeat
9-16::
    2s+1s also 4s+3s reel of 4 across (Men & Ladies pass RSh on sides to
    start & 2s/4s end 1st/3rd place, 1s/3s in 2nd/4th place (opp sides
    to start)
17-24::
    2s+1s+4s+3s dance reels of 4 on sides (1s+4s -middle couples- pass
    LSh to start)
25-32::
    1s set, 1s lead up crossing, cast to bottom & cross RH _while_ 3s
    set, lead up crossing to top, cast to 2nd place & cross RH.  2
    (3)4(1)', 0);
INSERT INTO 'dancecrib' VALUES (12651, '2020-03-02 01:54:02.762389+00', '2023-02-04 01:22:20.020853+00', 5902, 3, NULL, 'ace', '1-8::
    1L+2L dance RSh round their partners, into centre facing partner;
    set to partners, pull back RSh & dance out to place
9-16::
    1M+2M repeat
17-24::
    1s lead down the middle & back, remaining in centre facing up, 2s
    step in behind 1s ready for …
25-32::
    1s+2s dance Allemande.  End 2 1', 0);
INSERT INTO 'dancecrib' VALUES (14493, '2021-12-18 01:46:10.333076+00', '2023-02-04 01:22:14.050901+00', 15529, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH & cast (2s & 4s step up); 1s dance up to top & cast
    to 3rd place opp sides _while_ 3s dance up to 1st place opp sides &
    face out
9-16::
    3s+2s also 1s+4s dance 1/2 Double Fig 8 (3s cast down, 4s cast up to
    start); 2s+1s (middle couples) dance 1/2 R&L.  3 (1) 2 (4)
17-20::
    All 4 couples Set+Link with middle dancers linking 2 places; end
    dancers linking 1 place as follows:
::
    All set
::
    3L casts down to 2nd place as 3M dances down to 2nd place : 1M casts
    to 4th place as 1L dances down to 4th place
::
    2L dances up to 1st place as 2M casts up to 2nd place : 4M dances up
    to 3rd place as 4L casts up 3rd place.  2 3 (4) (1)
21-24::
    2s+3s also 4s+1s circle 4H round to left
25-32::
    4s+1s 1/2 turn partner RH, dance RH across remaining in centre, pull
    back RSh & dance out to own side. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7131, '2013-08-21 08:31:36.245001+00', '2023-02-04 01:22:14.159394+00', 5731, 3, NULL, 'ace', '1-8::
    1s+2s chase clockwise round square (1st & 2nd positions) to places.
9-16::
    1s+2s dance RH across & LH across back to places.
17-24::
    1s lead down the middle & back to top.
25-32::
    1s+2s dance Poussette.', 0);
INSERT INTO 'dancecrib' VALUES (7132, '2013-08-21 08:31:36.269602+00', '2023-02-04 01:22:14.19459+00', 8106, 3, NULL, 'ace', '1‑8::
    All Adv+Ret (setting) twice
9‑16::
    1L followed by partner casts behind 2L & crosses to opposite side,
    3M followed by partner casts up behind 1L & crosses to opposite side
17‑24::
    3s dance under 2s arch & cast back to 2nd place on opp sides _while_
    1s dance under 4s arch & cast up to 3rd pl opp sides, 3s+1s set &
    cross RH
25‑32::
    1s+4s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (7133, '2013-08-21 08:31:36.285832+00', '2023-02-04 01:22:14.315115+00', 5734, 3, NULL, 'ace', '1-8::
    1s+2L dance RH across & LH back to end with 1M between 1L+2L facing
    down & 2M steps in to face up
9-16::
    2M (dancing backwards) followed by 1s+2L dance down, 1M (dancing
    backwards) followed by 2s+1L dance back to top, 1s end facing down &
    2s up
17-24::
    1s+2s dance Ladies'' Chain up/down set, 1s turning LH once round at
    end, ready for…
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7134, '2013-08-21 08:31:36.30369+00', '2023-02-04 01:22:14.332565+00', 10066, 3, NULL, 'ace', '1-8::
    All set, 1/2 turn partners 2H, continue to turn individually & dance
    out to opposite sides & set. (1) (2) (3) (4)
9-16::
    1s+2s also 3s+4s dance RH across; 1M+2L also 3M+4L change places RH
    to face partner on sides & all 1/2 turn partner 2H
17-24::
    All dance 1/2 RSh reels of 4 on sides, 3L+4M also 1L+2M change
    places RH & all set.  4 3 2 1
25-32::
    4s+3s+2s (top 3 couples) dance the Knot to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7135, '2013-08-21 08:31:36.316083+00', '2023-02-04 01:22:14.350633+00', 9110, 3, NULL, 'ace', '1-8::
    1s cross down (no hands) below 3s, cast up 1 place opposite sides &
    dance in to face 2L, 1s+2L dance RH across
9-16::
    1s+2M dance LH across & end 1L (with partner behind her) in centre
    facing up, 1s dance up & cast 1 place on own sides & face 3M
17-24::
    1s+3M dance RH across, 1s+3L dance LH across & end 1L (with partner
    behind her) in centre facing down
25-32::
    1s dance down below 3s & cast up on own sides to 2nd place, 2s+1s+3s
    turn RH', 0);
INSERT INTO 'dancecrib' VALUES (10839, '2018-06-11 00:37:01.330873+00', '2023-02-04 01:22:14.432015+00', 15956, 3, NULL, 'ace', '1-8::
    1s+2s dance the Tourbillon:
::
    1s & 2s turn partners 2H 1/2 way, 1M & 2L lead partners on 1 place
    clockwise to end 1s on Ladies side & 2s on Men''s side, 1s set to 2s
::
    1s & 2s 1/2 turn partners 2H, 1L & 2M lead partners on 1 place to
    end 2s in 1st place & 1s in 2nd place. 2s cross RH to own side
    _while_ 1s pass RSh on bars 7+8 to face out.
9-16::
    2s+1s+3s reel of 3 on the sides (1M RSh to 2M, 1L RSh to3L to start)
17-28::
    2s+1s+3s dances R&L for 3 couples
29-32::
    2s+1s circle 4H round to the Left', 0);
INSERT INTO 'dancecrib' VALUES (7137, '2013-08-21 08:31:36.347001+00', '2023-02-04 01:22:14.451352+00', 5744, 3, NULL, 'ace', '1‑8::
    1s+2s+3s set twice, 1s cross RH _while_ 2s+3s dance LH across 1/2
    way, 1s+3s dance RH across 1/2 way _while_ 2s cross LH
9‑16::
    3s cross RH _while_ 1s+2s dance LH across 1/2 way, 3s+2s dance RH
    across 1/2 way _while_ 1s cross LH, 2s cross RH _while_ 3s+1s dance
    LH across 1/2 way, 2s+1s dance RH across 1/2 way _while_ 3s cross LH
    (all now in original places)
17‑24::
    1s+2s+3s dance RSh reels of 3 on sides
25‑32::
    1s+2s set to each other on sides & change places RH, 2s+1s circle 4H
    round to left', 0);
INSERT INTO 'dancecrib' VALUES (7138, '2013-08-21 08:31:36.363702+00', '2023-02-04 01:22:14.480682+00', 10521, 3, NULL, 'ace', '1-8::
    All dance RSh reels of 4 on sides
9-16::
    1L followed by partner also 3L followed by partner dance down Ladies
    side, across bottom & up Men''s side _while_ 2M followed by partner
    also 4M followed by partner dance up Men''s side, across top & down
    Ladies side (6 bars), 4L+3M also 2L+1M cross RH diag to end
    (3)(4)(1)(2) opp sides
17-24::
    3s+4s dance 1/2 R&L, 3s+4s complete R&L _while_ 1s+2s cross RH &
    dance RH across 1/2 way.  (3)(4)(2)(1)
25-32::
    All 1/2 Petronella back to own sides to end 3 4 2 1', 0);
INSERT INTO 'dancecrib' VALUES (7139, '2013-08-21 08:31:36.381156+00', '2023-02-04 01:22:14.501768+00', 14532, 3, NULL, 'ace', '1-4::
    1L cast 2 places & 1M crosses & casts 1 place
5-8::
    1L crosses below 3s & casts up round 3M to end between 3s _while_ 1M
    crosses below 2s & casts up round 2M to end between 2s all facing
    down
9-16::
    1L+3s & 1M+2s dance down & all turn to right, 2s+3s dance up _while_
    1s 1.1/4 turn RH moving up to end between 3s facing opp sides
17-24::
    3s+1s dance 1/2 RSh reel of 4, 1s turn LH 1.1/2 moving up to end
    between 2s facing own sides _while_ 3s set & cross RH
25-32::
    2s+1s dance 1/2 LSh reel of 4, 1s turn LH moving down to 2nd place
    (4 bars) _while_ 2s set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (4128, '2013-08-21 08:30:43.978732+00', '2023-02-04 01:18:36.16419+00', 11216, 3, NULL, 'ace', '1-8::
    1s dance DoSiDo, turn RH & cast to 2nd place
9-16::
    1s dance DoSiDo, turn RH 1.1/2 times to end 2nd place opposite sides
    facing 1st corner
17-24::
    1s dance RSh reels of 3 on opposite sides _while_ 2s+3s dance DoSiDo
    on sides (pass RSh) & dance DoSiDo on sides (pass LSh)
25-28::
    1s turn 1st corner RH to end BtoB facing opposite sides & all set in
    double triangle position
29-32::
    1L dances up between 2s & casts to 2nd place own side _while_ 1M
    dances down between 3s & casts up to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (7140, '2013-08-21 08:31:36.395523+00', '2023-02-04 01:22:14.525842+00', 13439, 3, NULL, 'ace', '1-8::
    4s followed by 3s+2s+1s dance up to top, 4s & 3s cast to orig places
    as 2s loop round into 1st place _while_ 1s end between 2s facing 2L
9-16::
    1s in Tandem dance RH across with 2L & LH across with 3M
17-24::
    1s dance RH across with 3L & LH across with 2M ending in 2nd place
25-32::
    1s+3s dance RH across for 3 bars then LH across & 1s cast to 3rd
    place
33-40::
    1s+4s Set+Link & dance 4H round to left
41-48::
    2s+3s also 4s+1s dance R&L.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7141, '2013-08-21 08:31:36.410047+00', '2023-02-04 01:22:14.546295+00', 10046, 3, NULL, 'ace', '1-8::
    All Men dance in to centre, pull back RSh to face partner & set; All
    turn partner RH to original places & 1/2 turn corner LH to finish
    facing coner (all on ''diagonals'' between original place & corner
    place)
9-16::
    All dance interlocking reels of 4 passing corner LSh (pass 3
    persons, turn about, continue reel back to place) & on bar 14 turn
    partner RH into original place but with Lady on Man''s left, all
    facing in
17-24::
    All Ladies dance 1/2 LH across (slow) to face opposite Man; All set
    & turn new partners 2H to reform square, Lady on Man''s left
25-32::
    Top & bottom couples advance for 2 steps & retire to sides with own
    partner _while_ side couples (facing ''new'' partner) retire
    individually to top/bottom & dance to meet own partner;  All
    Set+Link (all now 1 place on clockwise).  4 1 2 3

{{explanation}}
Note:	Bars 1-2 on 2nd, 3rd & 4th repeats, the Ladies dance out, turning to face in', 0);
INSERT INTO 'dancecrib' VALUES (7142, '2013-08-21 08:31:36.422267+00', '2023-02-04 01:22:14.570443+00', 5752, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s
9-16::
    1s dance reels of 3 on own sides (Down between 2s to start) 1s+s
    continue reel to end 2 1 3 (1s BtoB facing own sides)
17-24::
    1s dance Double Triangles ending in 2nd places own sides
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7143, '2013-08-21 08:31:36.438122+00', '2023-02-04 01:22:14.65623+00', 5754, 3, NULL, 'ace', '1-8::
    1s set twice & turn RH 1.1/2 times
9-16::
    1s set twice on sides to 2s & 1s turn 2s LH 1.1/2 times
17-24::
    1L+2L cross giving RH then turn partners 1/2 round LH.  1s+2s turn
    partners 1.3/4 RH into position ready for...
25-32::
    1s+2s dance Poussette.', 0);
INSERT INTO 'dancecrib' VALUES (7144, '2013-08-21 08:31:36.453221+00', '2023-02-04 01:22:14.68467+00', 5755, 3, NULL, 'ace', '1-8::
    1s set, turn 2H, dance down to 2nd place & turn 2H to face 1st
    corner
9-16::
    1s turn 1st corner RH to end between 2s/3s, set advancing to 2nd
    corner _while_ corners set, turn 2nd corner RH to between corners,
    set advancing to 3rd corner _while_ corners set
17-24::
    1s dance 1/2 reels of 4 with 3rd corners, pass LSh & face 4th
    corner, dance 1/2 reel with 4th corners, pass LSh to end between 2s
    & 3s on opposite sides)
25-32::
    All chase clockwise 1/2 way & turn partner 2H', 0);
INSERT INTO 'dancecrib' VALUES (7145, '2013-08-21 08:31:36.467164+00', '2023-02-04 01:22:14.710227+00', 11369, 3, NULL, 'ace', '1-8::
    1s set, dance down to 2nd place & out own side, cast round to left &
    into middle (2nd place) LSh to LSh (on opposite sides)
9-16::
    1s dance RH across (Lady with 2M+3M & Man with 2L+3L) & LH across
    with 2s+3s on own sides 1s end passing LSh to face 1st corners
17-24::
    1s set to 1st corners, 1s dance RSh round each other to face 2nd
    corners, set & dance round each other to 2nd place own side facing
    out
25-32::
    2s+1s+3s dance reels of 3 on own sides (1s giving RSh to person on
    their right)
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7146, '2013-08-21 08:31:36.481812+00', '2023-02-04 01:22:14.731551+00', 5757, 3, NULL, 'ace', '1‑8::
    (Middle 3 cpls start) 2s+4s (in a square) set & petronella turn 1
    place on right _while_ 3s petronella turn into middle & 3/4 turn RH
    to opp sides, 2s+4s set & pet turn to next place to right _while_ 3s
    pet turn into middle & 3/4 turn RH to own sides _while_ 1s & 5s set
    & cross RH.  (1)(4)3(2)(5)
9‑16::
    1s+4s also 2s+5s (both end cpls) dance RH across, 4M & 2L leading
    chase 1/2 way round set, _while_ 3s set twice & turn LH 1.1/4 times
17‑24::
    3s dance LSh reels of 3 across (Man with 2s & Lady with 4s) & end in
    own places.  5 2 3 4 1
25‑32::
    5s+3s 3/4 turn RH into middle, dance 1/2 reel of 4 up/down, 3/4 turn
    RH & end in 2nd/4th place.  2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (7147, '2013-08-21 08:31:36.496053+00', '2023-02-04 01:22:14.748415+00', 9890, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance 4H round, 2s lead up & 3s down, cross & cast, to
    form a St Andrews Cross with corners all facing clockwise
9-16::
    All dance round in St Andrews Cross formation back to places
17-24::
    2s & 3s dance RH across, set & cross to own sides
25-32::
    1s cross RH, turn 2s LH, turn each other RH & turn 3s LH (similar to
    Strip the Willow)
33-40::
    1s turn each other RH, turn 4s LH & all turn partners with kilt grip', 0);
INSERT INTO 'dancecrib' VALUES (7148, '2013-08-21 08:31:36.510136+00', '2023-02-04 01:22:14.778908+00', 5759, 3, NULL, 'ace', '1-8::
    All circle 6H round & back
9-16::
    1s+2s set, 1/2 RH across, all set, 2s & 3s cross RH _while_ 1s 1/2
    turn RH to face 2nd corner pstns
17-24::
    Reel of 3 on sides (1s RSh to crnrs), 1s 1/2 turn RH to face up in
    prom hold _while_ 2M+3L cast to meet M''s side in prom hold & ptnrs
    meet L''s side
25-32::
    All reel of 3 across in prom hold (1s pass 3M+2L RSh to start)
33-40::
    1s followed by 3M+2L & 2M+3L) Promenade once round to end but 3M
    casts & 2M dances up to join partners
41-48::
    1s+2s+3s dance Poussette to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13340, '2020-11-02 01:21:39.516233+00', '2023-02-04 01:22:14.81551+00', 19187, 3, NULL, 'ace', '1-8::
    1s+3s Petronella turn & set; Petronella turn & set. (1) 2 (3)
9-16::
    2s dance Diagonal R&L (2M down, 2L up). 3 2 1
17-24::
    2s+1    s dance Bourrel:
::
    _1- 4_  2M+1L set advancing, 3/4 turn 2H & twirl to end BtoB (Lady
    facing up & Man down) _while_ partners chase anticlockwise to face
    partner
::
    _5- 8_  Set to partners & turn 2H (sometimes RH) to own sides having
    changed places
25-32::
    3s+1s+2s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7230, '2013-08-21 08:31:37.497684+00', '2023-02-04 01:22:21.361259+00', 5939, 3, NULL, 'ace', '1-8::
    1s & 4s set, cast & circle 4H round in centre ending in 2nd/3rd
    places own sides
9-16::
    2s & 3s set, cast & dance RH across in centre ending in 2nd/3rd
    places own sides
17-24::
    1s lead down the middle & back
25-32::
    All dance 4 couple Poussette', 0);
INSERT INTO 'dancecrib' VALUES (4129, '2013-08-21 08:30:43.98671+00', '2023-02-04 01:18:36.190715+00', 7348, 3, NULL, 'ace', '1-8::
    1s+2s+3s 1/2 turn partners 2H, hesitate & cast round to right into
    partners place, all turn partners RH
9-16::
    All advance setting turning to right to end BtoB with partner, dance
    out turning to right & turn partner RH
17-24::
    All dance reels of 3 on sides 1s casting to start & end with 1s
    casting to face 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (14683, '2022-03-07 02:21:32.189461+00', '2023-02-04 01:22:14.831748+00', 20655, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up); 2s+1s+3s set, 1/2 turn partner RH to
    face down in middle
9-16::
    2s+1s+3s dance Allemande. 2s end in 3rd place & 3s in 1st place on
    opp side _while_ 1st end facing 1st corner pstn
17-24::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh to face 2nd
    corners (pstn); 1st dance 1/2 diag reel of 4 with 2nd corners & end
    in 2nd place own side
25-32::
    All 1/2 turn partner RH, pull back RSh & dance out to opp sides; all
    chase clockwise 1/2 round to own sides 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (9040, '2015-11-30 09:00:15.290917+00', '2023-02-04 01:22:14.858477+00', 16527, 3, NULL, 'ace', '1-8::
    1s+2s set, pull back RSh, dance 2 places clockwise, cross RH to own
    sides. 1s face out
9-12::
    2s+1s+3s dance 1/2 reels of 3 on sides (1M+2M also 1L+3L pass RSh)
    Bars 11-12: 1L (from 3L place) & 1M (from 1M place) dance across to
    2nd place opp sides & face out
13-16::
    3M+1L also 1M+2L turn RH
17-20::
    3s+1s+2s dance 1/2 reels of 3 on sides (1L+2M also 1M+3L pass LSh)
    Bars 19-20: 1L (from 3M place) & 1M (from 1L place) dance across to
    2nd place own sides & face out
21-24::
    2L+1L also 1M+3M turn LH, 1s passing LSh to B-to-B facing opp sides
    (2L+3M dance 4 bars)
25-32::
    2s+1s+3s set as Double Triangles.  All set again as 1s turn Right
    about to face & turn RH 1.1/2 to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7149, '2013-08-21 08:31:36.525156+00', '2023-02-04 01:22:14.885854+00', 14122, 3, NULL, 'ace', '1-8::
    1s & 3s turn RH & cast 1 place, all set then 1s & 3s turn 2H to face
    1st corners
9-12::
    1s+3s set to 1st corners & dance round partner out to 3rd corner
    (pstn) _while_ 1st corner persons dance in & turn about to face
    their original corners
13-16::
    Original 1st corner persons set to corners & dance round each other
    out to each others corner _while_ 1s+3s dance in & twirl to face 2nd
    corners
17-24::
    1s+3s repeat bars 9-16 with 2nd corners to end 1s+3s facing 2nd
    corner (pstn) & 2nd corner persons in each others corner
25-32::
    1s+3s dance 1/2 diagonal reels of 4 with 2nd corner (pstn), pass LSh
    & dance 1/2 reels with 1st corner (pstn) ending on own sides  2 1 4
    3 5
33-40::
    1s+4s+3s (middle 3 couples) dance 1/2 reels of 3 on sides (1M give
    LSh to 4M & 3L LSh to 4L), 1s cast to 5th place & all set', 0);
INSERT INTO 'dancecrib' VALUES (8226, '2014-03-31 14:06:07.308501+00', '2023-02-04 01:22:15.082318+00', 15410, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    1s set, turn RH, cast 1 place & turn LH to end between 2s (Man
    facing Lady)
9-16::
    1s+2s dance reel of 4 across & end in original places _while_ 3s+4s
    circle 4H round & back
17-20::
    1L+2L also 3L+4L change places RH & set _while_ 1M+2M also 3M+4M set
    & change places RH
21-24::
    1L+4L change places RH & set _while_ 1M+4M set & change places RH
25-32::
    All circle 8H round to left for 6 steps, pivot left & chase back to
    places', 0);
INSERT INTO 'dancecrib' VALUES (7151, '2013-08-21 08:31:36.546518+00', '2023-02-04 01:22:15.095641+00', 12898, 3, NULL, 'ace', '1-8::
    1s cast 2 pls & dance up to 2nd pl _while_ 2s set & cast to 3rd pl
    _while_ 3s dance up & loop into 1st place, all set & petronella turn
    into middle
9-16::
    All dance 1/2 reel of 6, 2s & 3s 3/4 turn RH to own sides _while_ 1s
    turn RH to face 1st corners
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners ending 2nd place own sides
25-32::
    2s+1s dance double Fig of 8 (2s cross down) & end 1s turning RH to
    face down
33-40::
    1s lead down & back to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7152, '2013-08-21 08:31:36.554786+00', '2023-02-04 01:22:15.139659+00', 5764, 3, NULL, 'ace', '1-8::
    1s+2s+3s set,1s dance down to 3rd place _while_ 2s+3s cast up 1
    place, 3s+1s+4s dance 1/2 reel of 3 on sides (1s out & down to
    start).  2 4 1 3
9-16::
    2s+4s+1s set, 2s dance down to 3rd place _while_ 4s+1s cast up 1
    place, 1s+2s+3s dance 1/2 reel of 3 on sides (2s out & down to
    start).  4 3 2 1
17-24::
    All set, circle to left 1/2 way & 1/2 turn partner 2H ready for…
25-32::
    1s+2s also 3s+4s dance 1/2 diamond Poussette, 1s+4s dance 1/2
    Poussette.  2 4 1 3
33-40::
    2s+4s also 1s+3s dance 1/2 Poussette, 2s+3s dance 1/2 Poussette.   4
    3 2 1
41-48::
    4s+3s+2s dance Allemande.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7153, '2013-08-21 08:31:36.56293+00', '2023-02-04 01:22:15.186857+00', 8177, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 2s+1s dance RH across
9-16::
    1s+3s set, turn partners 2H & circle 4H round
17-24::
    All circle 8H round & back
25-32::
    1s set, cast to 4th place & all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (7154, '2013-08-21 08:31:36.571073+00', '2023-02-04 01:22:15.251111+00', 11154, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, 1L dances up between 2s & casts round 1st
    corner _while_ 1M dances down between 3s & casts up round 1st corner
9-12::
    1s with 1st corners (prom hold Lady on left) dance round clockwise
    to change places _while_ 2nd corners Adv+Ret
13-16::
    1s turn RH & end in prom hold with 2nd corners (Lady on left)
    _while_ corners set
17-20::
    1s+2nd corners dance round clockwise to change places _while_ 1st
    corners Adv+Ret
21-24::
    1s turn RH to end facing down in 2nd place (in middle) _while_
    corners set
25-32::
    1s cross down into 1/2 reels of 3 on opposite sides with 2s+3s & all
    turn partners RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (12940, '2020-07-01 00:21:17.620877+00', '2023-02-04 01:22:15.283759+00', 9064, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp side

1-8::
    1s+2s & 3s+4s set, dance 1/2 double Fig 8 ( 1s/4s cross down/up,
    2s/3s dance up/down to start)
9-16::
    1s/4s cross RH with partner, cast down/up (2s/3s step up/down);
    1s+4s dance RH across
17-20::
    1L followed by 1M casts up behind 2M, finishing between 2s _while_
    4L followed by 4M casts behind 3M finishing between 3s
21-24::
    1L followed by 1M dance 1/2 tandem reel of 3 with 2s (RSh to 2L)
    _while_ 4s dance similar (RSh to 3L)
25-32::
    1L followed by 1M dance down Ladies'' side & curve into 3rd place own
    side _while_ 4L followed by 4M dance up men''s side & curve into 2nd
    place own side; all turn partner RH.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (7240, '2013-08-21 08:31:37.5947+00', '2023-02-04 01:22:22.226339+00', 5964, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH into centre to Bal-in-Line across with 2s, 1/2 turn
    2s into centre LH & Bal-in-Line
9-16::
    1s 1/2 turn 2s LH & again Bal-in-Line across, 1s turn RH & to places
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (4130, '2013-08-21 08:30:43.994896+00', '2023-02-04 01:18:36.214239+00', 340, 3, NULL, 'ace', '1-8::
    3s followed by 1s dance down for 2 steps & set to partners, 1s dance
    up & cast to 3rd place _while_ 3s dance up to 1st place
9-16::
    3s+2s+1s dance Reverse Snowball Grand Chain for 3 cpls to end 1 (2)
    3:
::
    1s cross RH & change places LH on side with 2s
::
    1s change places RH with 3s _while_ 2s cross RH
::
    1s cross LH _while_ 3s & 2s change places LH.  1 (2) 3
17-24::
    1s+2s set advancing into circle (hands joined) & petronella turn 1
    place to right, set in circle (hands joined) & petronella turn to
    end on sides
25-32::
    1L dances 1/2 Fig of 8 round 2s & 1M dances 1/2 Fig of 8 round 3s,
    2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (9927, '2017-06-05 11:31:42.581855+00', '2023-02-04 01:22:15.306593+00', 8201, 3, NULL, 'ace', '1-8::
    1s cross down to dance mirror reels of 3 on opp sides (3s in/up, 2s
    in/down).  2s end in 1st place, 1s in prom hold face 2M
9-12::
    1s (in prom hold) dance 1/2 diag RSh reel of 3 with 2M+3L.  1s end
    facing 2L
13-16::
    1s (in prom hold) dance 1/2 diag LSh reel of 3 with 2L+3M.  1s end
    in 2nd place NHJ facing down
17-24::
    1s dance down, cast up round 3s to 2nd place opp sides.  3s+1s+2s
    turn 2H 1.1/2 finishing in centre, facing up, ready for …
25-32::
    3s+1s+2s dance Allemande

{{explanation}}
Note: At end of 2nd time, 1s end in 3rd place, 4s start reel from 4th place (dancing in/up) as original 1s step down', 0);
INSERT INTO 'dancecrib' VALUES (9041, '2015-11-30 09:00:15.339721+00', '2023-02-04 01:22:15.42527+00', 16566, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s+4s cross to opp sides

1-8::
    1s+4s set, cast down/up to 2nd/3rd places (2s+3s step up/down bars
    3-4).  1s+4s turn 1/2 LH & dance 1/2 LH across to 1M facing 3L,
    1L+3M, 4M+2L, 4L+2M
9-16::
    4s+1s dance diagonal interlocking reels of 4 with corner positions
    (LH across 1/2 way in middle) _while_ 2s (in 1st place) & 3s (in 4th
    place) dance reels of 4 across.  End with 4s+1s facing each other,
    NHJ with partner, (4s face down, 1s face up)
17-24::
    4s+1s Set+Link & dance circle 4H round to Left
25-32::
    2s+4s also 1s+3s dance Poussette    2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (12421, '2019-12-05 01:31:49.26106+00', '2023-02-04 01:22:15.659267+00', 10747, 3, NULL, 'ace', '1-8::
    1M+2L change places LH, dance behind partner back to place; 1s+2s
    dance LH across
9-16::
    1L+2M change places RH, dance behind partner back to place, 1s+2s
    dance RH across, 2s face out
17-24::
    1s+2s dance double Fig 8 (1s cross down, 2s cast up)
25-32::
    1s+2s turn 3/4 RH into line up down middle (Men face up, Ladies
    down), 1s+2s dance 1/2 reel of 4 & turn partners 3/4 RH to own side.
    End 2 1', 0);
INSERT INTO 'dancecrib' VALUES (7155, '2013-08-21 08:31:36.579168+00', '2023-02-04 01:22:15.671617+00', 5765, 3, NULL, 'ace', '1-8::
    1L+2L set advancing, turn partner 2H & retire
9-16::
    1M+2M repeat above Fig
17-24::
    1M+2L set & change places RH, 2L+2M set & change places LH on side
25-32::
    1s+2s dance Ladies'' Chain
33-40::
    2s followed by 1s dance down, 1/2 turn (Lady under Man''s arm) &
    1s+2s lead back
41-48::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7156, '2013-08-21 08:31:36.588822+00', '2023-02-04 01:22:15.782744+00', 5766, 3, NULL, 'ace', '1-8::
    1L+2L+3L circle 3H round to left, 1M+2M+3M circle 3H round to left
9-16::
    1s cast to 3rd place, cast back to top & turn 2H
17-24::
    1s cast 1 place, lead down between 3s & cast to 2nd places
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (13341, '2020-11-02 01:21:40.147856+00', '2023-02-04 01:22:15.811662+00', 13278, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to top, remaining in centre facing
    up,  2s step up Bars 3-4 & face down (1s now between 2s)
9-16::
    1s+2s turn 3/4 NH (Ladies RH, Men LH), 1s+3s turn (Ladies LH, Men
    RH); 2s+1s+3s Adv+Ret
17-24::
    2s+1s+3s set, cross RH & chase 1/2 round back to own side
25-32::
    3s+1s+2s set, cross LH & chase 1/2 round back to own sides.  End 2 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (7157, '2013-08-21 08:31:36.59685+00', '2023-02-04 01:22:15.840124+00', 8938, 3, NULL, 'ace', '1‑8::
    1s cross down RH, dance down behind 3s, cross up RH & dance up
    behind 2s to places
9‑16::
    1s turn RH 1.3/4 times to face 1st crnrs, set to 1st corners & set
    to 2nd corners
17‑24::
    1s dance reels of 3 on opposite sides (RSh to 2nd corner to start) &
    end BtoB facing own sides
25‑32::
    1s dance Double Triangles with 2s+3s & end in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7158, '2013-08-21 08:31:36.606702+00', '2023-02-04 01:22:15.873998+00', 5768, 3, NULL, 'ace', '{{explanation}}
1s & 3s start on opp sides

1-8::
    1s+4s dance RH across (2s & 3s step up/down), 2s+3s dance RH across
    (1s & 4s step up/down) all end in original places
9-16::
    1s+2s & 3s+4s dance 3/4 RH across & chase (2M leading down Ladies
    side & 3M leading up on Men''s side), 1s+2s & 3s+4s dance 1/4 RH
    across to end 4 3 2 1 with 4s & 2s on opp sides
17-20::
    1s & 4s set advancing & turn right about to face corners (3s & 2s
    having stepped up/down)
21-32::
    All dance double diagonal reels of 4 & 1s, 4s end by curving back to
    sides to end 3 (4) 1 (2)
33-48::
    All dance Grand Chain (2 bars per hand)', 0);
INSERT INTO 'dancecrib' VALUES (9039, '2015-11-30 09:00:14.995498+00', '2023-02-04 01:22:15.892099+00', 13648, 3, NULL, 'ace', '1-8::
    1s dance in, cast (2s step up) & turn RH
9-12::
    1s set advancing to face 1st corners (2s+3s set facing diag in). 2nd
    corners set as 1s 1/2 turn 1st corners 2H to 1L between 2s, 1M
    between 3s
13-16::
    1s+2s+3s circle 6H round to Left
17-24::
    Repeat 9-16 with 1s setting to 2nd corners.  1s finish in 2nd place
    opp sides
25-32::
    2s+1s+3s dance Circulating Knot:
::
    _25-26_     All turn RH into allemande hold, 2s+3s face down, 1s
    face up
::
    _27-29_     All dance 1/2 way round set (1s+2s start to Right, 3s
    curve to Left) Bar 29:- all release Right hands
::
    _30-32_     Men pass partners in front & all continue LH turn to own
    sides.   3 1  2', 0);
INSERT INTO 'dancecrib' VALUES (14377, '2021-10-11 22:41:45.183381+00', '2023-02-04 01:22:15.940481+00', 5773, 3, NULL, 'ace', '1-8::
    1s lead down & back up, crossing on bars 7-8 into 1st place opp
    sides facing out
9-16::
    1s+2s dance double Fig 8 giving hands (1s cast, 2s cross up),
    _while_ 3s 1/2 turn RH to face up & lead up to top (following 1s),
    cast & cross to 3rd place own side facing out
17-20::
    2s+3s dance 1/2 double Fig 8 giving hands (3s cast up, 2s cross
    down), _while_ 1s set & dance down middle (following 3s)
21-24::
    1M dances LH across with 2M+3M on Ladies'' side _while_ 1L dances RH
    across with 2L+3L on Men''s side
25-28::
    Ladies cross in front of partner (1s, then 2s then 3s) to dance into
    other hands across & dance up own sides (1s face out, 2s dance in
    slightly)
29-32::
    1s+2s turn 1.1/2 times to change places (Men LH, Ladies RH).  End 2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (7159, '2013-08-21 08:31:36.669927+00', '2023-02-04 01:22:16.085425+00', 5775, 3, NULL, 'ace', '1-8::
    1s & 4s set (Highland Setting), 1s lead up & cast to 2nd place
    _while_ 4s lead down & cast up to 3rd place
9-16::
    1s+4s dance 1/2 RH across, 1s cast down behind 3s on opp side
    _while_ 4s cast up behind 2s, 4s dance down making an arch & cross
    to original places _while_ 1s dance up under arch & cross to place
17-24::
    1M followed by partner casts behind 2M & 3M, crosses, down behind 4L
    & crosses to own side to end 2 3 4 1
25-32::
    All circle 8H round to left', 0);
INSERT INTO 'dancecrib' VALUES (6007, '2013-08-21 08:31:17.938941+00', '2023-02-04 01:22:16.180992+00', 3561, 3, NULL, 'ace', '1-8::
    With setting steps all pass partners RH to face partners corner
    position & set, all turn corners 2H to end facing own partner
9-16::
    All set to partners twice & turn 2H 1.1/2 times to end in original
    places
17-24::
    1slead RH round inside of set anticlockwise greeting each couple
25-32::
    1s dance Poussette round inside of set
33-40::
    1s+3s cross (1s dancing between 3s) & cross back to places (3s
    dancing between 1s)
41-48::
    1s+3s repeat above Fig
49-56::
    All circle 8H round to left
57-64::
    All Ladies join RH in centre with partners on their left & dance
    once round clockwise to places
::
    Repeat with 2s, 3s & 4s leading', 0);
INSERT INTO 'dancecrib' VALUES (7160, '2013-08-21 08:31:36.689257+00', '2023-02-04 01:22:16.197232+00', 9572, 3, NULL, 'ace', '1-8::
    1s & 5s set, cast in 1 place & dance 1/2 Figs of 8 round end couples
9-16::
    1s+3s+5s dance reflection reels of 3 on sides 1s dancing in to start
17-24::
    2s+1s also 5s+4s dance RH across, 1s & 5s chase 1/2 way round
    anticlockwise to change places
25-32::
    2s+5s also 3s+1s dance 1/2 R&L & set, 5s & 3s cross RH to own sides
    _while_ 2s+1s dance 1/2 RH across to end 5 1 2 3 4', 0);
INSERT INTO 'dancecrib' VALUES (7161, '2013-08-21 08:31:36.697288+00', '2023-02-04 01:22:16.214732+00', 9194, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s turn LH 1.1/2 times to face 1st corners
9-12::
    1s dance 1/2 diag reel of 4 with 1st corners & pass LSh to face 2nd
    corners
13-16::
    1s dance 1/2 diag reel of 4 with 2nd corners 1s ending in middle 1M
    facing down & 1L up
17-24::
    1s turn LH 1.1/2 times _while_ corners chase clockwise 1/2 way, 1s
    dance RH across (1L with 2s, 1M with 3s)
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7162, '2013-08-21 08:31:36.705282+00', '2023-02-04 01:22:16.234831+00', 11016, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 R&L, 1s+4s dance RH across 1/2 way &
    cross RH
9-16::
    All circle 8H round & back
17-24::
    2s+4s also 1s+3s dance 1/2 R&L, 2s+3s dance RH across 1/2 way &
    cross RH
25-32::
    3s+2s+1s (bottom 3 couples) dance the Knot to end 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (7163, '2013-08-21 08:31:36.713838+00', '2023-02-04 01:22:16.258703+00', 7504, 3, NULL, 'ace', '1-8::
    1s in prom hold dance reel of 3 with 4M+2L giving RSh to Man _while_
    3s dance similarly with 2M+4L
9-16::
    1s+3s dance RH across & chase clockwise 1/2 way round outside set to
    opposite places
17-24::
    1s+4s & 3s+2s dance 1/2 R&L. 1s+4s & 3s+2s dance LH across all
    ending in Sq.Set, 1 place to right of start
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7164, '2013-08-21 08:31:36.721805+00', '2023-02-04 01:22:16.277291+00', 8839, 3, NULL, 'ace', '1-8::
    1s set, 1s+2s set, 1s+2s+3s set & set advancing to meet partner in
    prom hold
9-16::
    1s+2s+3s Promenade & 1s end casting to 2nd place
17-24::
    2s+1s+3s circle 6H round & back
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7165, '2013-08-21 08:31:36.731691+00', '2023-02-04 01:22:16.29939+00', 14548, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place (2s step up); 1s cross down between 3s & cast
    up to 2nd place opposite sides
9-16::
    1s+2s dance Ladies'' Chain & end 1s facing down
17-24::
    Reels of 3 on sides, 1s giving RSh to 3s (6 bars) & 1s+3s change
    places RH  2 3(1)
25-32::
    3s+1s dance Men''s Chain & end 1L facing out with partner ready to
    follow her
33-40::
    1L followed by partner casts up & crosses to own side to end with
    1s in 2nd place own sides; 1s+3s circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (8629, '2015-02-13 12:48:13.089963+00', '2023-02-04 01:22:16.323424+00', 13163, 3, NULL, 'ace', '1-4::
    1M+2s dance 1/2 reel of 3 across (1M+2L pass LSh). 1M finishes
    between 2s facing down
5-8::
    1M+3s dance 1/2 reel of 3 across (1M+3M pass RSh), 1M finishes
    between 3s facing down _while_ 1L+2s dance 1/2 reel of 3 across
    (1L+2L pass RSh).  2L finishes between 2s facing down.  2s finish in
    1st place
9-12::
    1M+4s, 1L+3s repeat bars 5-8 (1M+4L, 1L+3M pass LSh).  3s finish in
    2nd place
13-16::
    1M+5s, 1L+4s repeat bars 5-8 (1M+5M, 1L+4L pass RSH).  4s finish in
    3rd place
17-20::
    1M dances out of end, casts round 5L place, crossing to 4M place
    _while_ 1L+5s dance 1/2 reel of 3 across (1L+5M pass LSH). 1L
    finishes in 4L place, 5s in 5th place
21-24::
    1s+5s dance 1/2 LH across, cross LH with partner
25-32::
    All couples set, cross RH with partners, all set, cross RH with
    partners   2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (12874, '2020-06-03 16:27:37.757638+00', '2023-02-04 01:22:16.348229+00', 13925, 3, NULL, 'ace', '1-4::
    1s turn 2H, dance down NHJ 2 steps (2s step up); Bar 4: 1M dances
    below 1L who dances under 1M''s arm to change sides & 1s face up
5-8::
    1s dance up to end BtoB between 2s facing opp sides, all set
9-16::
    1s+2s dance reel of 4 across finishing in same places
17-24::
    All set, 1s face up, briefly touch NH & cast to 2nd place opp sides;
    1s dance 1/2 Fig 8 round 2s.  2 1
25-32::
    2s+1s set, turn partner RH flowing into 2s+1s dance RH across. 2 1', 0);
INSERT INTO 'dancecrib' VALUES (7166, '2013-08-21 08:31:36.740008+00', '2023-02-04 01:22:16.371452+00', 5786, 3, NULL, 'ace', '1-8::
    1s+2s cross RH & dance 1/2 RH across, repeat LH
9-16::
    1s set & cast 2 places, 3s+1s set & turn 2H to end in line up/down
    set (Men BtoB)
17-24::
    1s+3s dance HS Poussette :
::
    1s set HS step with both hands joined dance out to Men''s side
    _while_ 3s set & dance out to Ladies side both couples end with a
    1/4 turn to right
::
    1s dance HS down Men''s side _while_ 3s dance up Ladies side both
    couples end with a 1/4 turn to right
::
    3s+1s dance HS into centre to reform line of 4 in middle
::
    3s+1s 3/4 turn partners with 2H, 3s to own sides & 1s end facing 1st
    corners
25-32::
    1s dance LSh reels of 3 on opposite sides & 1s cross RH to 2nd place
    own side', 0);
INSERT INTO 'dancecrib' VALUES (7167, '2013-08-21 08:31:36.749787+00', '2023-02-04 01:22:16.399026+00', 10457, 3, NULL, 'ace', '1-8::
    1L+2M 3/4 turn RH & join partner LH & rotate 3/4 clockwise to 1M in
    2nd place & 2L in 1st pl own sides, 1L+2M continue RH turn to
    2nd/1st pl
9-16::
    2s+1s+3s turn RH, 2s+3s set & cross RH _while_ 1s turn LH
17-24::
    1s continue turning LH & cast round 2nd corner pstns, pass partner
    LSh & dance round 1st corners into…
25-32::
    1s dance reels of 3 with corners (RSh to 2nd corners)', 0);
INSERT INTO 'dancecrib' VALUES (7168, '2013-08-21 08:31:36.757831+00', '2023-02-04 01:22:16.418776+00', 9561, 3, NULL, 'ace', '1-8::
    1L+2L cross passing partner LSh & cast down 2 places as 3M+4M cross
    & cast up 2 places, top 4 Men also bottom 4 Ladies dance LH across.
9-16::
    1M+2M cross passing opp dancer RSh & cast down 2 places as 3L+4L
    cross & cast up 2 places, top 2 cpls also bottom 2 cpls dance RH
    across.
17-24::
    3s+4s+1s+2s dance 1/2 RSh reels of 4 on sides, 1s+4s+3s (bottom 3
    couples) dance 1/2 reels of 3 on sides.
25-32::
    All set, cross RH, 2s+3s also 4s+1s circle 4H round to left.', 0);
INSERT INTO 'dancecrib' VALUES (7169, '2013-08-21 08:31:36.765987+00', '2023-02-04 01:22:16.445535+00', 5788, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set twice, cross RH & dance RH across 1/2 way
9-16::
    1s & 3s set, petronella turn into centre & turn partner RH
17-24::
    1s+3s dance RSh reel of 4 ending 1s in 2nd place & 3s in 4th place
25-32::
    1s+4s also 3s+5s set twice, cross LH & dance LH across 1/2 way.  2 4
    1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (7170, '2013-08-21 08:31:36.774169+00', '2023-02-04 01:22:16.470715+00', 8140, 3, NULL, 'ace', '1-8::
    1s+2s dance a double Fig of 8 (1s cross down to start)
9-16::
    1s+2s+3s dance Grand Chain
17-24::
    2s+3s dance a double Fig of 8 (2s cross down to start) to end 2s
    facing up
25-32::
    1s followed by 2s dance down the middle & up (with 2s leading)
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7171, '2013-08-21 08:31:36.782402+00', '2023-02-04 01:22:16.500775+00', 14233, 3, NULL, 'ace', '1-4::
    1s & 3s set & change places RH on sides _while_ 2s cross RH & cast
    round 1st corners into middle (2M below 2s & 2L above 3s)
5-8::
    2s dance RH across 1/2 way (2L+3s & 2M+1s), 2s turn partner 1.1/2
    times into prom hold facing 1M (in 3L place) _while_ 3s & 1s set
    bars 7-8
9-12::
    2s dance 1/2 reel of 3 on sides (RSh to 1M in 3L place) & face 3L
    (in 1M place)
13-16::
    2s dance 1/2 reel with Ladies (RSh to 3L). Bar 16 1L & 3L curve in,
    partners step in to meet & take prom hold (1L on 1M''s right, 3L on
    3M''s left), End all in middle, 2s facing down to 3s
17-20::
    All dance 1/2 promenade reel of 3 in middle, 2s giving LSh to 3s to
    start, ending all in middle with 3s at top facing down & 2s+1s
    facing up
21-24::
    All set & 3s turn inwards to face up & cast to 2nd place _while_ 2s
    dance up to 1st place & 1s cast to 3rd place
25-32::
    All circle 6H round & back.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13437, '2020-12-02 01:21:35.289871+00', '2023-02-04 01:22:16.558921+00', 17796, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across; 1s cast to 4th place _while_ 4s
    dance up to 1st place
9-16::
    2s+3s dance Poussette
17-20::
    4s cast to 4th place _while_ 1s dance up to 1st place. 1s & 3s face
    down, 2s & 4s face up
21-24::
    1s+2s also 3s+4s set advancing & pass each other; 1s+4s set
    advancing & pass each other _while_ 2s & 3s dance up/down slightly
    turning inwards & curving into 1st/4th place
25-32::
    Reel of 4 on sides.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13192, '2020-09-15 00:21:29.149953+00', '2023-02-04 01:22:16.618526+00', 18504, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on own sides touching hands
    when possible (1s in/down, 2s out/up, 3s in/up to start)
9-16::
    1s slip step down the middle & back to place
17-24::
    1s 1.1/2 turn 2s (1L+2L LH, 1M+2M RH), 1s 1.1/2 turn 3s (with other
    hand)
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7173, '2013-08-21 08:31:36.800247+00', '2023-02-04 01:22:16.719568+00', 5794, 3, NULL, 'ace', '1-8::
    1s cross down RH to face out between 2s & 3s giving hands to each
    corner & set, 1s cast round 1st corner to form lines of 3 across
    with 2s/3s & 2s+1s+3s set
9-16::
    1s (turning to right) dance RSh reels of 3 across & 1s end passing
    LSh to 2nd place on opposite sides
17-24::
    1s lead down for 2 bars & lead up, cross at the top & cast to 2nd
    place on own sides
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7174, '2013-08-21 08:31:36.808321+00', '2023-02-04 01:22:16.760458+00', 5795, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, dance 1/2 reels of 3 across (Lady with 2s
    & Man with 3s) & 1s end facing 1st corners
9-16::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partner LH to
    face Lady''s 1st corner (Man behind Lady)
17-24::
    1s dance Alternating Tandem diagonal 1/2 reel of 3 with 1st corners
    & Alternating Tandem diagonal 1/2 reel with 2nd corners
25-32::
    1s dance up to top (Lady on Man''s right), cast to 2nd place own side
    & dance 1/2 mirror reels of 3 on sides (1s in/down to start).  End 2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (7413, '2013-08-21 08:31:40.492658+00', '2023-02-04 01:22:16.870044+00', 5800, 3, NULL, 'ace', '1-8::
    1s, followed by 2s, cast on own sides below 3s, meet & lead up to
    top, 1s cast, pass LSh to face 1st corners _while_ 2s dance up to
    top
9-16::
    1s dance round 1st corners (RSh), pass LSh in centre, dance round
    3rd corner RSh, pass partner LSh to face 2nd corners
17-24::
    1s repeat above Fig round 2nd corners & 4th corners to end BtoB
    facing corners (1M facing Ladies'' side, 1L facing Men''s side)
25-32::
    1M with 2L+3L also 1L with 2M+3M circle 3H round to left (4 bars), &
    dance 1/2 Double Triangles & petronella turn to end in 2nd place own
    side', 0);
INSERT INTO 'dancecrib' VALUES (14378, '2021-10-11 22:41:46.095567+00', '2023-02-04 01:22:16.895502+00', 5818, 3, NULL, 'ace', '1-8::
    1s set, cross down RH (2s step up 3-4), 1s set, turn 3/4 LH to face
    1st corners
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners, 1s pass LSh to
    dance 1/2 diagonal reel of 4 with 2nd corners. 1s finish between end
    couples facing 3rd corners (1M between 2s, 1L between 3s)
17-24::
    1s dance LSh reels of 3 across, 1s finish in centre facing each
    other, 1M below 1L
25-32::
    1s set to partner, turn RH to 2nd place opposite sides, 2s+1s+3s set
    & cross RH. End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7430, '2013-08-21 08:31:40.805127+00', '2023-02-04 01:22:17.288321+00', 8939, 3, NULL, 'ace', '1-8::
    All Adv+Ret & turn partner LH into…
9-16::
    All dance double Ladies'' Chain (Ladies dancing 1/2 RH across in
    centre)
17-24::
    1s Promenade round in allemande hold acknowledging each couple in
    turn
25-32::
    1st Lady changes place RH with corner, then 2nd Lady changes place
    RH with corner, then 3L & then 4L
33-40::
    All with new partner Promenade clockwise (Men on outside) once round', 0);
INSERT INTO 'dancecrib' VALUES (7431, '2013-08-21 08:31:40.815356+00', '2023-02-04 01:22:17.323608+00', 5829, 3, NULL, 'ace', '1-4::
    1L followed by partner casts 1 place, crosses, casts down behind 3rd
    Man
5-8::
    1L followed by partner crosses, casts behind 4th Lady & 1L crosses
    to 4th place opposite sides
9-16::
    1s dance up 1 place under 4s arch (2 bars), turn 2H 1.1/2 times (4
    bars), dance up under 2s arch to original places
17-20::
    1s followed by 2s+3s+4s lead down the middle (2s, 3s & 4s dance up
    sides to start)
21-24::
    When 4s meet at top they touch hands  & then 4s followed by 3s, 2s &
    1s cast back to places
25-32::
    All dance DoSiDo with partners, 1s change places on sides with 2s
    RH, with 3s LH & 4s with RH', 0);
INSERT INTO 'dancecrib' VALUES (7446, '2013-08-21 08:31:41.219699+00', '2023-02-04 01:22:17.38748+00', 13867, 3, NULL, 'ace', '{{explanation}}
2 chords: On 2nd chord 3s & 4s cross to opp sides

1-8::
    1L+2M also 3M+4L set & cast 1 place, (1L & 3M down, 2M & 4L up) into
    line up/down centre of set. 2M+1L also 4L+3M turn LH 1.1/2 to face
    partners
9-16::
    1s+2s also 3s+4s dance diagonal reels of 4 across (on 1st corner
    diagonals) to end all back in original places 1 2 (3) (4)
17-24::
    2s+3s set & Petronella-in-tandem twice to end 1 3 (2) (4)
25-32::
    1s+3s also 2s+4s dance ''Double Knot'', figure similar to normal 2
    couple Knot but at the end of 2nd bar 1s+3s face down (between
    middle of set & Men''s side) as 2s+4s face up (between middle of set
    & Ladies'' side), 3s followed by 1s dance down to 4th/3rd places as
    2s+4s dance up to 1st/2nd places & all turn LH to places 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (15148, '2022-10-05 00:21:44.866119+00', '2023-02-04 01:22:17.416031+00', 20784, 3, NULL, 'ace', '1-8::
    1M followed by 2M+3M also 1L followed by 2L+3L dance in, cast on own
    side to 3rd place then dance up centre NHJ to top & all couples take
    prom hold
9-16::
    1s+2s+3s dance ''Promenade Pass'':
::
    _9-12_   All dance 4 bars of Promenade (all now on Men''s side 3 2 1)
::
    _13-16_ 2s+1s dance up 1 place in centre _while_ 3s dance down to
    3rd place. 2s & 3s dance out to sides as 1s pass by left to finish
    BtoB facing opp sides
17-24::
    2s+1s+3s dance Double Triangles, Bars 23-24: 1s Petronella turn to
    2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4160, '2013-08-21 08:30:44.400739+00', '2023-02-04 01:18:37.454337+00', 12518, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All change place RH with partner & full turn LH next person, change
    places RH with partners & turn corners LH
17-24::
    1M+3L dance Fig of 8 round 2s _while_ 1L+3M dance Fig of 8 round 4s
25-32::
    2L+4M dance Fig of 8 round 1s _while_ 2M+4L dance Fig of 8 round 3s
33-40::
    1s+3s dance 1/2 R&L & all dance Grand Chain (starting RH with
    corner-2 bars/hand)
41-48::
    2s+4s repeat bars 33-40 to all end in original places
49-56::
    All Ladies dance RH across, LSh round partner & LH across back to
    places
57-64::
    All Men dance LH across, RSh round partner & RH across back to
    places
65-80::
    All in circle Adv+Ret for 1 step, Ladies dance in front Man on right
    to next Ladies place, Adv+Ret & Ladies dance on 1 place & repeat
    twice more back to places', 0);
INSERT INTO 'dancecrib' VALUES (7176, '2013-08-21 08:31:36.825418+00', '2023-02-04 01:22:17.460252+00', 8365, 3, NULL, 'ace', '1-8::
    1s slip step down for 4 steps & set, slip step up to top & cast to
    2nd place
9-16::
    2s+1s+3s dance reels of 3 on sides with 1s crossing down between 3s
    to start.  2(1)3
17-24::
    2L+1M also 2M+1L slip step across for 4 (Men BtoB) & set, slip step
    back (Ladies BtoB) & set
25-32::
    1s dance RH across (1M with 2s, 1L with 3s), 1L dances up between 2s
    & casts to 2nd pl own side as 1M dances down & casts up to 2nd pl', 0);
INSERT INTO 'dancecrib' VALUES (7178, '2013-08-21 08:31:36.860502+00', '2023-02-04 01:22:17.710784+00', 5858, 3, NULL, 'ace', '1-8::
    1s lead down the middle for 3 steps, back to top & cast to 2nd place
9-16::
    1s lead down the middle for 3 steps, back to 2nd place & cast to 3rd
    place
17-24::
    2s+3s+1s circle 6H round to left, 1s dance up to top & cast to 2nd
    place
25-32::
    2s+1s+3s turn RH & turn LH', 0);
INSERT INTO 'dancecrib' VALUES (7179, '2013-08-21 08:31:36.86857+00', '2023-02-04 01:22:17.730682+00', 8970, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, turn LH into double triangle positions facing
    own sides
9-16::
    2s+1s+3s set, 1s turn to face 1st crnrs & dance 1/2 diaig reel of 4
    with 1st crnrs, 1s turn right about into triangle position Man
    facing down & Lady up
17-24::
    2s+1s+3s set, 1s turn to face 2nd corners & dance 1/2 reel of 4 with
    2nd corners & 1s end 2nd place opposite sides
25-32::
    3s+1s+2s Set+Link for 3 twice
33-40::
    2s+1s+3s circle 6H round 1/2 way & chase back anticlockwise', 0);
INSERT INTO 'dancecrib' VALUES (7180, '2013-08-21 08:31:36.876677+00', '2023-02-04 01:22:17.753393+00', 14471, 3, NULL, 'ace', '1-4::
    1s cross RH & cast to 3rd place _while_ 2s+3s set & cross up 1 place
5-8::
    2s cast down 2 places _while_ 1s dance up to top & 1s+3s change
    places on sides (LH Mens side, RH Ladies side).  (3) (1) (2)
9-16::
    3L+1L also 1M+2M set & dance 1/2 RH across; 1M dances 1/2 Fig of 8
    round top couple _while_ 1L dances 1/2 Fig of 8 round bottom couple
17-24::
    3M+1M also 1L+2L set & dance 1/2 LH across; 1L dances 1/2 Fig of 8
    round top couple _while_ 1M dances 1/2 Fig of 8 round bottom cpl.  2
    (1) 3
25-32::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corners to
    start & cross RH to 2nd places own sides', 0);
INSERT INTO 'dancecrib' VALUES (7181, '2013-08-21 08:31:36.885012+00', '2023-02-04 01:22:17.776128+00', 9088, 3, NULL, 'ace', '{{explanation}}
Square Set with 4 Ladies at corners & 2 Men BtoB in centre, one facing up and other facing down

{{title}}
Strathspey

1-8::
    Men turn 1st corners RH, pass RSh, turn 3rd corner LH & pass LSh to
    face own 2nd corner
9-16::
    Men turn 2nd corners RH, pass RSh, turn 4th corner LH & dance LSh
    round each other to face 3rd corners (Hazel Tree Corners)
17-24::
    Men change places RH with 3rd crnrs, 3rd crnrs turn LH in centre &
    return to places giving RH to Men who turn LH in centre to face 4th
    crnrs
25-32::
    Men repeat with 4th corners & end facing 1st corners (Corner Chain)
33-40::
    Men 1/2 diagonal Reel of 4 with 1st corners, pass LSh & dance 1/2
    diagonal reel of 4 with 2nd corners
41-48::
    Men 1/2 diagonal Reel with 3rd corners then with 4th corners & end
    facing 1st corners (Mairi''s Wedding reels)

{{title}}
Reel

1-32::
    As Bars 1-32 above
33-48::
    Ladies dance double diag reels of 4 twice (giving LH in centre) as
    Men dance 1/2 reels with 1st, 2nd, 3rd & 4th corners & passing LSh
    in centre', 4);
INSERT INTO 'dancecrib' VALUES (7182, '2013-08-21 08:31:36.893113+00', '2023-02-04 01:22:17.799849+00', 5860, 3, NULL, 'ace', '1-8::
    1s cross down & dance out between 2s+3s turning 3s by near hand to
    meet ptnr, dance up & turn 2s by nearest hand to 2nd place opp sides
9-16::
    1s cross down to 3rd pl & dance reel of 3 own side (2s dance
    out/down as 3s dance out/up b''tw''n 2s), 1s end (hold LH) facing 1st
    crnrs
17-24::
    1s set to 1st crnrs, turn inwards & set to 3rd corner as 3rd crnrs
    set adv to dance RH across with 1s, 1s end turning to face 2nd crnrs
25-32::
    1s repeat bars 17-24 with 2nd/4th corners but dancing LH across', 0);
INSERT INTO 'dancecrib' VALUES (7183, '2013-08-21 08:31:36.902907+00', '2023-02-04 01:22:17.844314+00', 10381, 3, NULL, 'ace', '1-8::
    1M+2L also 3L+4M turn 2H 1.1/2 times to change places, all Men dance
    LH across & end facing anticlockwise giving RH to partners
9-16::
    All Set+Link with partners & Set+Link again to end on sides (1s+4s
    Ladies side & 2s+3s Mens side with Ladies on line ends)
17-24::
    All dance RSh reels of 4 on sides
25-32::
    1L+2M also 3M+4L turn 2H 1.1/2 times to (2)(1)(4)(3), end couples
    (2s & 3s) cross RH _while_ centre cpls dance LH across 1/2 way & all
    set.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13193, '2020-09-15 00:21:30.308346+00', '2023-02-04 01:22:17.866317+00', 18505, 3, NULL, 'ace', '1-8::
    1s dance down for 3 bars, on bar 4 Man dances below partner as she
    dances under his arm to face up, dance up to top & cast to 2nd place
    opposite side
9-16::
    1s dance 1/2 LSh reels of 3 across (Lady with 3s, Man with 2s). 1s
    pass LSh to dance 1/2 reels across with other couple.
17-20::
    All 1/2 turn RH to face partner in centre, pull back RSh & curve by
    right to opposite side.
21-24::
    2s & 3s 1.1/2 turn 2H to own side _while_ 1s turn 2H to own side
25-28::
    1s+2s+3s set (Glasgow Highlanders setting)
29-32::
    1s 1.1/2 turn 3s on the sides (Ladies RH, Men LH) 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (9235, '2016-06-16 22:42:17.435758+00', '2023-02-04 01:22:17.899281+00', 16834, 3, NULL, 'ace', '1-8::
    All set, circle 6 hands round to the left
9-16::
    All set, Reels of 3 across, 2L with 1s and 2M with 3s (2L+1M, 2M+3L
    pass LSh to start)
17-20::
    1s turn RH, cast off.  2s cross up LH on bars19-20
21-24::
    1s cross RH, cast off.  3s cross up LH on bars 23-24 3s face out
    (2) (3) (1)
25-32::
    Reflection (mirror) reels of 3 on sides.  2s cross down to begin, 3s
    cross bars 27-28 and 1s cross bars 29-30. Finish 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7960, '2013-08-21 08:31:51.869506+00', '2023-02-04 01:23:13.935159+00', 8112, 3, NULL, 'ace', '1-8::
    1s cross down to dance reels of 3 on opposite sides & end 1st place
    opposite sides
9-16::
    1s lead down & back crossing to end facing Ladies side (1M behind
    1L)
17-24::
    1s dance Tandem reel of 3 across with 2s (RSh to 2L). 1s end in
    middle at top with 2s stepping in behind them ready for …
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4161, '2013-08-21 08:30:44.410516+00', '2023-02-04 01:18:37.544887+00', 389, 3, NULL, 'ace', '1-8::
    1L+2M cross RH, 1s+2s 1/2 turn ptnr LH on side to prom hold, 2s
    dance to 1st pl as 1s to 2nd pl, set, turn to face each other 2s end
    opp side
9-16::
    1s+2s in prom hold turn to sides (1s to L''s & 2s to M''s), 1s+2s set
    & turn to face each other, 1M+2L cross RH & Men change pl on the
    side LH
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (4162, '2013-08-21 08:30:44.420262+00', '2023-02-04 01:18:37.643612+00', 392, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s cast on own sides & cross RH below 3rd place &
    dance up other side
9-16::
    1s+2s+3s Adv+Ret, cross RH & set
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance the Rondel', 0);
INSERT INTO 'dancecrib' VALUES (4164, '2013-08-21 08:30:44.520881+00', '2023-02-04 01:18:37.756222+00', 7605, 3, NULL, 'ace', '1-8::
    1s cast 1 place & dance 1/2 diamond Poussette with 3s
9-16::
    1s cast up 1 place & dance 1/2 diamond Poussette with 2s
17-24::
    1s set, cross RH, cast 1 place & 1L dances up between 2s & casts to
    2nd place _while_ 1M dances down between 3s & casts up
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7185, '2013-08-21 08:31:36.933083+00', '2023-02-04 01:22:17.936664+00', 5865, 3, NULL, 'ace', '1-8::
    2s followed by 1s lead down, 2s lead up to top _while_ 1s separate &
    dance up behind 2s to end BtoB in middle, 1L facing up to 2s & 1M
    down to 3s
9-12::
    All set as double triangles, all set advancing pulling back RSh to
    invert Triangle
13-16::
    All set, 1s pass LSh & dance out opposite sides (skip change)
    _while_ 2s & 3s set & dance back to place (PdeB)
17-24::
    1s dance reels of 3 on sides giving LSh to 2nd corners 1s ending in
    diagonal line between 1st corners joining RH with corner, LH with
    partner
25-32::
    1s+1st corners Bal-in-Line, 1s 3/4 turn LH, Bal-in-Line with 4th
    corners & 1s turn LH to 2nd place opposite sides
33-40::
    1s cast round 2nd corners, 3/4 turn RH to 2nd place own sides & cast
    to 3rd place. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (15354, '2022-12-19 01:21:50.993756+00', '2023-02-04 01:22:18.073886+00', 19848, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance R&L
9-16::
    1M & 3M, followed by partners, cast, dance up between couple above,
    cast off on opp side & dance across to 2nd/4th place own sides &
    face up
17-24::
    All dance reels of four on sidelines. 1s & 4s omit final LSh pass.
    2413
25-28::
    3M casts up 2 places as 3L dances up centre to 2nd place own side
    (4s+1s step down 27-28)
29-32::
    2s+3s dance LH across as 4s+1s dance RH across.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7186, '2013-08-21 08:31:36.941108+00', '2023-02-04 01:22:18.090966+00', 8809, 3, NULL, 'ace', '1-8::
    1s+2s set advancing, dance 1/2 Diamond Poussette, 2s+1s+3s set
9-16::
    2s+1s+3s dance the Knot.  1s finish facing 1st corners
17-24::
    1s+1st corner pstns dance 1/2 reel of 4, 1s pass LSh & dance 1/2
    reel with 2nd corner pstns. All on opp sides (2) (1) (3)
25-32::
    2s+1s+3s Set+Link for 3 once, 1s turn 2H 1.1/4 times to 2nd place
    own side _while_ 3s & 2s dance clockwise 1/2 way round to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12822, '2020-05-14 23:16:07.202986+00', '2023-02-04 01:22:18.258817+00', 18232, 3, NULL, 'ace', '1-8::
    2s cross down RH, cast up round 3s; cross up RH & cast round 1s to
    end facing 1st corners
9-16::
    2s set to & turn 1st corners 2H; set to & turn 2nd corners 2H,
    ending between corners. 2 (1) 3
17-24::
    Mirror reels of 3 on sides (2s cross down, 1s out/down, 3s out/up to
    start).  1 2 3
25-32::
    1s+2s+3s dance the Slip Knot:
::
    _25-30_   All 3 couples dance first 6 bars of standard Knot.  (3)
    (2) (1)
::
    _31-32_   1s (at bottom) turn LH to own side _while_ 3s+2s dance 1/2
    LH across to end on own side.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (8357, '2014-07-29 12:59:27.268984+00', '2023-02-04 01:22:18.281143+00', 14563, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s cast to 2nd place, 2s dance up to 1st
    place; 1s set advancing, finish BtoB in centre, 1L facing up, 1M
    facing down
9-16::
    1s dance out of ends of set & dance clockwise round set to finish 1M
    between 3s at top all facing down, 1L between 2s in 3rd place all
    facing up as 2s+3s set to each other on sides & change places RH &
    cross giving RH to partner; all set
17-24::
    1s petronella to 2nd place own sides, all set, 1s turn RH 1.1/2
    times  (3) (1) (2)
25-32::
    3s+1s+2s Set+Link for 3 twice     2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7187, '2013-08-21 08:31:36.949121+00', '2023-02-04 01:22:18.302348+00', 5868, 3, NULL, 'ace', '1-8::
    1s & 2s turn RH, lead down (2s leading) & cast up behind 3s (2s to
    top place, 1s to 2nd place)
9-16::
    1L dances RH across with 2s & 1M with 3s, 1s turn LH 1.1/2 times to
    end facing out in 2nd place on opposite sides
17-24::
    1s dance reels of 3, 1L with 2M+3M (LSh to 3M) & 1M with 2L+3L (LSh
    to 2L) 2s end facing down, 3s up & 1s in 2nd place own sides
25-32::
    2s+1s+3s set & dance RH across 1/2 way, 2s+1s+3s chase clockwise to
    place', 0);
INSERT INTO 'dancecrib' VALUES (14012, '2021-05-03 00:21:28.821831+00', '2023-02-04 01:22:18.335188+00', 19789, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection (mirror) reels of 3 on opposite
    sides. On bars 7-8 1s & 2s continue reel & 1s finish in 2nd place
    facing out 2 (1) 3
9-12::
    1s turn 3s on sides (LH on Men''s side, RH on Ladies'' side) & 1s
    cross up to 2nd place own side facing out
13-16::
    1s turn 2s on sides (LH on Ladies'' side, RH on Men''s side) & 1s
    cross down to 2nd place opposite side facing out 2 (1) 3
17-24::
    1s cast down round 3s, lead up to top, cross & cast to 2nd place 2 1
    3
25-32::
    All circle 6H round & back 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7188, '2013-08-21 08:31:36.957185+00', '2023-02-04 01:22:18.363991+00', 8912, 3, NULL, 'ace', '1-8::
    1s dance  Figures of 8 on sides round 2s+3s (RSh to 2s to start)
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1s+2s also 3s+4s dance RH across & LH back
25-32::
    1s 1/2 turn LH, dance in prom hold to bottom (2s+3s+4s step up bars
    27-28) & turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (12823, '2020-05-14 23:16:07.45645+00', '2023-02-04 01:22:18.554384+00', 19935, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH, lead down, cast up round 3s to 2nd place opp sides
    (2s step up 3-4). All set advancing (no hands) into prom hold with
    partner, 2s & 3s facing up, 1s facing down
9-16::
    2s+1s+3s dance "Circulating Allemande":
::
    2s & 3s dance normal Allemande, ending in 3rd/1st place as 1s
    Allemande (down) & end pulling back RSh (PdB) to BtoB facing 2nd
    corner pstn
17-24::
    1s turn 2nd corner (pstn) RH, partner 3/4LH, 1st corner (pstn) RH,
    partner LH to end LSh to LSh in middle (Lady facing up / Man down)
25-28::
    1s dance out of & cast to 2nd place opp sides _while_ all 4 corners
    set advancing, dance 1/2 RH across to opp sides (2) (1) (3)
29-32::
    2s+1s+3s cross RH with partner & set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4165, '2013-08-21 08:30:44.528901+00', '2023-02-04 01:18:37.786671+00', 397, 3, NULL, 'ace', '1-8::
    1s+2s set & dance 1/2 RH across; 1s+2s 1/2 turn partner RH, 2s end
    in 1st place own side _while_ 1s continue to turn RH to end 1L
    between 2s facing 2L, 1M between 3s facing 3M
9-16::
    1s dance RSh reels of 3 across (Lady with 2s & Man with 3s). 1s end
    in 2nd place opposite sides
17-24::
    2s+1s+3s set, 1s turn 3/4 RH to end 1M between 2s facing down, 1L
    between 3s facing up;  all set, 1s 3/4 turn RH to end in 2nd place
    own side, 1L facing down, 1M facing up
25-32::
    2s+1s+3s  dance reels of 3 on sides (1M RSh to 2M & 1L RSh to 3L).
    End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7189, '2013-08-21 08:31:36.966945+00', '2023-02-04 01:22:18.57395+00', 5872, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH & cast in 1 place, 1s & 4s dance 1/2 Figs of 8
    round end couples
9-16::
    1s & 4s in prom hold dance reel of 3 across with end couples giving
    RSh to 2L/3M ending with 1s on Men''s side facing 4s on Ladies side
17-24::
    1s+4s in prom hold dance LSh round each other 1.1/4 times (1s face
    down, 4s up), lead out thru end couples, cross & cast in 1 place.  2
    4 1 3
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7190, '2013-08-21 08:31:36.97487+00', '2023-02-04 01:22:18.609666+00', 13689, 3, NULL, 'ace', '1-8::
    1s set & turn RH, 1s lead down between 3s & cast up to 2nd place
9-16::
    1s dance Diag R&L.  (3)1(2)
17-24::
    1s Set+Link for 3 twice.  2(1)3
25-32::
    1s dance 1/2 Fig of 8 round 2s, all turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (14816, '2022-05-07 22:38:11.56658+00', '2023-02-04 01:22:18.716288+00', 20805, 3, NULL, 'ace', '1-8::
    1L+2M set & change places RH _while_ 1M+2L change places RH & set;
    repeat back to place
9-12::
    2s followed by 1s lead down (2 bars) then dance 1/2 RH across
13-16::
    2s followed by 1s dance up NHJ & out to opp sides, 2s face out,
    2s+1s turn NH (Ladies LH, Men RH)
17-24::
    2s+1s set & dance »La Baratte«:
::
    _19-20_  Man 1/2 turns opposite Lady RH & retains hand but at arm''s
    length from each other
::
    _21-22_  Man retraces steps with Lady turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies'' original
    place) & releasing Ladies'' RH she turns under Man''s left arm until
    almost in original places
::
    _23-24_  Couple change places LH to opposite places.  2 1
25-32::
    2s+1s dance R&L.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (12824, '2020-05-14 23:16:07.53841+00', '2023-02-04 01:22:18.754536+00', 19924, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All set, Ladies change places RH, turn opposite Man twice 2H (4
    bars)
9-16::
    All set, Men change places LH, turn partner twice 2H (4 bars)
17-24::
    All dance RH across; circle 4H round to left 1.1/2 times to end in
    original places
25-32::
    All Grand Chain (2 bars to each hand) starting with opposite person
    (i.e. 2 parallel grand chains).  Finish facing new couple', 0);
INSERT INTO 'dancecrib' VALUES (7191, '2013-08-21 08:31:37.071946+00', '2023-02-04 01:22:18.791311+00', 12059, 3, NULL, 'ace', '1-8::
    1s turn 2H, cast & face 1st corners, 1s dance 1/2 reel of 4 with 1st
    corners & pass RSh to face 2nd corners
9-16::
    1s dance 1/2 reels of 4 with 2nd corners & dance round each other
    RSh to 2nd place opposite sides, 2s+1s+3s Set+Link for 3 into lines
    across
17-28::
    2s+1s+3s dance 3 couple R&L (up/down)
29-32::
    2s+1s+3s Set+Link for 3 to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7192, '2013-08-21 08:31:37.081673+00', '2023-02-04 01:22:19.054785+00', 5878, 3, NULL, 'ace', '1-8::
    1s+2s set twice & dance RH across
9-16::
    1s+2s repeat above Fig but dance LH across
17-24::
    1s+2s+3s dance RSh reels of 3 on own sides
25-32::
    1s cross, cast 1 place & dance 1/2 Fig of 8 round 3s end BtoB facing
    own sides for Double Triangles
33-40::
    1s dance Double Triangles
41-48::
    1s dance full Figs of 8 round 2s ending in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (13438, '2020-12-02 01:21:37.486433+00', '2023-02-04 01:22:19.080555+00', 17794, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round to left (4 bars), pull back RSh to spiral
    out & chase clockwise back to place
9-16::
    1s+2s+3s dance the Knot omitting final 1/2 LH turn to all end on opp
    sides (3) (2) (1)
17-24::
    3s+2s+1s Set+Link for 3 couples twice. 1 2 3
25-32::
    1s cross RH, cast (2s step up); 1s cross LH, cast (3s step up)', 0);
INSERT INTO 'dancecrib' VALUES (7194, '2013-08-21 08:31:37.099437+00', '2023-02-04 01:22:19.091503+00', 7506, 3, NULL, 'ace', '{{explanation}}
Round the room dance 2 facing 2

1-8::
    All circle 4H round & back
9-16::
    All dance R&L (RH to opposite partner to start) into…
17-24::
    All dance Ladies'' Chain, Men end facing anticlockwise
25-28::
    Men chase anticlockwise 1/2 way to change places _while_ Ladies
    advance setting, 1/2 turn 2H & pull back RSh to end facing partner
    (all now in one big circle)
29-32::
    All set to partners, turn 2H opening up to face new couple', 0);
INSERT INTO 'dancecrib' VALUES (12422, '2019-12-05 01:31:52.10453+00', '2023-02-04 01:22:19.108136+00', 19414, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig 8 round 2s; 1s cross RH & cast (2s step up 7-8)
9-16::
    2s+1s+3s set, circle 6H 1/2 round to left & all set. (3) (1) (2)
17-24::
    1s change places RH with person diagonally to right, new centre
    couple LH with person diagonally left; new centre couple RH with
    person diagonally right, 2s+3s cross LH _while_ 1s turn 3/4 RH
    remaining in centre…
25-32::
    1M+2s also 1L+3s dance LH across, 1s pass LSh & dance RH across with
    other couple.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7195, '2013-08-21 08:31:37.109076+00', '2023-02-04 01:22:19.121513+00', 14103, 3, NULL, 'ace', '1-8::
    1s set & cross RH, cast 1 place & turn LH to end facing 1st corners
9-16::
    1s dance 1/2 reel of 4 with 1st corners & end facing 2nd corners, 1s
    dance 1/2 reel of 4 with 2nd corners & turn LH 1/2 way
17-24::
    1s dance RH across (1L with 3s & 1M with 2s), 1s dance LH across (1L
    with 2s, 1M with 3s) & 1s end 2nd place own sides
25-32::
    1s dance Diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (7196, '2013-08-21 08:31:37.117173+00', '2023-02-04 01:22:19.178698+00', 11398, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H to left, set facing in, 1s cross down to 2nd place
    facing out _while_ 2s cast up
9-16::
    1s turn 1st corners RH, turn partner LH 3/4  & dance RH across (Lady
    with 2s & Man with 3s) end passing LSh to face 2nd corners
17-24::
    1s turn 2nd corners LH, turn partner RH 3/4  & dance LH across (Man
    with 2s & Lady with 3s) end 2nd place own sides
25-28::
    1s+3s set, 1L dances down & curves left to 3rd place as 1M casts
    down to 3rd place _while_ 3L casts up & 3M dances up 1 place
29-32::
    3s+1s circle 4H round to right', 0);
INSERT INTO 'dancecrib' VALUES (4166, '2013-08-21 08:30:44.538686+00', '2023-02-04 01:18:37.81034+00', 398, 3, NULL, 'ace', '1-8::
    All dance 8H round to left 1/2 way, set & cross RH
9-16::
    Repeat above Fig from new places
17-24::
    1s cast 1 place & meet holding RH as 2s 3/4 turn RH moving up & form
    a line up/down centre of dance, 2s+1s Bal-in-Line, 1s cast down 1
    place on opposite sides & meet holding RH as 2s 1/2 turn RH & 3s 3/4
    turn RH to form line of 6 in centre, 2s+3s+1s Bal-in-Line
25-32::
    1s cast down 1 place & meet RH as 2s & 3s 1/2 turn RH & 4s 3/4 turn
    RH to form line of 8, all Bal-in-Line & turn partners RH to own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (7197, '2013-08-21 08:31:37.125273+00', '2023-02-04 01:22:19.20624+00', 5885, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s giving hands when possible
9-16::
    1s dance reflection reels of 3 on own sides (1s dance down between
    2s to begin)
17-24::
    1s turn 2H & dance down middle to 3rd pl as 2s+3s continue reel &
    dance down behind 1s, all set  & 1s followed by 2s+3s cast up to
    orig pls
25-32::
    1s+2s dance the Tourbillon :
::
    1s & 2s turn partners 2H 1/2 way, 1M & 2L lead partners on 1 place
    clockwise to end 1s on Ladies side & 2s on Men''s side, 1s set to 2s
::
    1s & 2s 1/2 turn partners 2H, 1L & 2M lead partners on 1 place to
    end 2s in 1st pl & 1s in 2nd pl & 2s+1s cross RH to own sides.  2 1
    3', 3);
INSERT INTO 'dancecrib' VALUES (7198, '2013-08-21 08:31:37.13344+00', '2023-02-04 01:22:19.231542+00', 12825, 3, NULL, 'ace', '1-8::
    1s+2s set & 3/4 turn RH, 1M+2L change places LH _while_ prtnrs dance
    clockwise 1/2 way & 3/4 turn prtnr RH (2s to 1st pl & 1s to face 1st
    crnrs
9-16::
    1s dance 1/2 reel of 4 with 1st corners & turn LH to face 1st crnrs
    (pstn), 1s dance 1/2 reel of 4 with 1st corners & pass LSh to face
    2nd crnrs
17-24::
    1s repeat bars 9-16 with 2nd crnrs & end dancing to & turning right
    about in lines across (1M b''tw''n 2s facing dn & 1L b''tw''n 3s facing
    up)
25-32::
    2s+1s+3s set, 1s petronella turn to own sides _while_ ws+3s continue
    setting; all turn partners 2H. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7199, '2013-08-21 08:31:37.141455+00', '2023-02-04 01:22:19.280935+00', 9891, 3, NULL, 'ace', '1-8::
    Men dance RSh reel of 4 on side, _while_ Ladies dance 1/2 RSh reel
    of 4 on side & set twice
9-16::
    1M+1L face diagonally, set & cast in 1 place, 4M+4L face diagonally,
    set & cast in 1 place
17-24::
    Men set twice _while_ Ladies dance 1/2 RSh reel of 4 on side to face
    partner (2 1 4 3), 2s+1s & 4s+3s dance 1/2 R&L
25-32::
    1s turn RH & cast to 4th place on opposite side, all turn partners
    2H 1.1/2 times.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7200, '2013-08-21 08:31:37.149558+00', '2023-02-04 01:22:19.311805+00', 7935, 3, NULL, 'ace', '1-8::
    1s lead down to bottom & cast up on own sides back to place
9-16::
    4s cast up behind own sides to top & lead down to places
17-24::
    2s+3s circle 4H round & back
25-32::
    1s & 4s turn RH (4 bars), turn LH (4 bars)
33-40::
    2s & 3s dance Figs of 8 round end couples
41-48::
    1s cross RH, cast 1 place, cross LH & cast to bottom', 0);
INSERT INTO 'dancecrib' VALUES (7201, '2013-08-21 08:31:37.157584+00', '2023-02-04 01:22:19.329397+00', 5888, 3, NULL, 'ace', '1-8::
    1s & 3s set & cross RH, 2s dance RH across (Man with 1s & Lady with
    3s)
9-16::
    Continue RH across 3/4 round to end 1 2 3 on opposite sides,
    1s+2s+3s turn partners RH 1.1/2 times to end in centre facing down
17-24::
    1s+2s+3s lead down middle for 2, 3/4 turn partners RH, set with
    Ladies turning under Mans arm to face up & dance up in line - M
    following L
25-32::
    1s cast to 2nd place own side _while_ 2s lead to top & cast _while_
    3s dance to own place & all dance reel of 3 on own side to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7202, '2013-08-21 08:31:37.16734+00', '2023-02-04 01:22:19.420924+00', 5889, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back to places
9-16::
    1s+2s set; cross RH, set & cross back RH
17-24::
    1s followed by 2s lead down, 2s divide & 1s followed by 2s lead back
    to top
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7203, '2013-08-21 08:31:37.175384+00', '2023-02-04 01:22:19.44592+00', 5893, 3, NULL, 'ace', '1-4::
    1L sets to 2L & turns RH _while_ 1M sets to 2M & change places RH
5-8::
    2L sets to 3L & turns LH _while_ 1M sets to 3M & turns LH.  (1M now
    in 2nd place own side, 1L in 1st place own side)
9-16::
    1s dance reels of 3 on own sides giving RSh to 2s to start (1L
    dances down, 1M up)
17-24::
    1s+2s dance a reel of 4 across (2s pass LSh to start) & 1s end
    turning LH to face 1st corners
25-32::
    1s turn 1st corner RH, partner LH, 2nd corner RH, & cross LH with
    partner to end in 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (7204, '2013-08-21 08:31:37.183506+00', '2023-02-04 01:22:19.467878+00', 14243, 3, NULL, 'ace', '1-8::
    All circle 6H round & back
9-16::
    1s dance down middle & set, dance up & cast to 2nd place
17-24::
    1s dance Pass+Turn with 1st corners (corners turn RH) & pass RSh to
    face 2nd corners, dance Pass+Turn with 2nd corners (corners turn RH)
    to end 2nd place own sides
25-32::
    Promenade (Chaperoned) Chain progression:
::
    _25-26_    2s & 3s 3/4 turn partner RH into middle _while_ 1s dance
    clockwise 1/4 round the set picking up 2L/3M …
::
    _27-30_    who promenade 1/2 way clockwise _while_ middle people (2M
    + 3L) turn LH 1.1/2.
::
    _31-32_    2s & 3s turn partner RH 3/4 to own sides _while_ 1s dance
    clockwise 1/4 round to end in 2nd place. 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (9406, '2016-10-06 07:18:53.640944+00', '2023-02-04 01:22:19.490433+00', 16613, 3, NULL, 'ace', '1-8::
    1s set. 1L followed by 1M cast behind 2L & 3L, dance up middle to
    below 2M (2s step up)
9-16::
    1s+2M+3M dance Alternating Tandem Reel of 3 (1s+2M pass RSh).  1L
    followed by 1M ends below 2L
17-24::
    1s+2L+3L dance Alternating Tandem Reel of 3 (1s+2L pass LSh).  1s
    end in middle facing up, 1L followed by 1M
25-32::
    1s dance up, cast to 2nd place own sides.  2s+1s+3s turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (7205, '2013-08-21 08:31:37.191467+00', '2023-02-04 01:22:19.51003+00', 14697, 3, NULL, 'ace', '1-8::
    All set & 1s+2s also 3s+4s dance RH across, 1s & 4s cast in 1 place.
    2 4 1 3
9-16::
    4s+1s set & turn 2H, 4s+1s circle 4H round to left
17-24::
    1s+4s+3s dance the Knot.  2 3 4 1
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7206, '2013-08-21 08:31:37.199442+00', '2023-02-04 01:22:19.540202+00', 10763, 3, NULL, 'ace', '1-8::
    1s+3s dance petronella turn into centre, 1/2 turn partner RH & dance
    1/2 reel of 4 in centre
9-16::
    3s+1s 1/2 turn partner RH, petronella turn to own side, 1s lead up
    to top & cast to 2nd place
17-24::
    3s+1s+2s circle 6H round & back
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7207, '2013-08-21 08:31:37.207384+00', '2023-02-04 01:22:19.561658+00', 10067, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up) & dance 1/2 Fig of 8 round 2s
9-16::
    2s+1s+3s set & dance reels of 3 across (1L with 2s & 1M with 3s)
17-24::
    1s+2s dance Ladies'' Chain
25-32::
    2s+1s+3s set, cross RH, 2s+3s dance 1/2 double Fig of 8 round 1s (2s
    cast to start)', 0);
INSERT INTO 'dancecrib' VALUES (7208, '2013-08-21 08:31:37.215361+00', '2023-02-04 01:22:19.761337+00', 10861, 3, NULL, 'ace', '1-8::
    1s+2M dance RH across, 1s+2L dance LH across
9-16::
    1s+3M dance RH across, 1s+3L dance LH across
17-24::
    1s cross down below 3s & cast up on own sides, up between 2s & cast
    to 2nd place
25-32::
    1s dance RH across (Lady with 2s & Man with 3s), pass RSh & dance LH
    across with other couple', 0);
INSERT INTO 'dancecrib' VALUES (11709, '2019-03-18 21:02:50.343172+00', '2023-02-04 01:22:19.783734+00', 17464, 3, NULL, 'ace', '1-8::
    1s dance down between 3s & 3/4 turn 3s, Men RH, Ladies LH (2s step
    up 3-4).  1s dance up between 2s & 3/4 turn 2s, Men LH, Ladies RH
9-16::
    1s cross down (no hands) to between 3s, 3/4 turn 3s, 1M+3L LH, 1L+3M
    RH. 1s dance up & cast to 2nd place opp sides
17-24::
    1s pass LSh to dance 1/2 diag reel of 4 with 3rd corners, pass LSh,
    dance 1/2 diag reel of 4 with 4th corners.  1s pass RSh to 2nd place
    opp sides
25-32::
    3s+1s+2s dance 1/2 round clockwise to own sides & all turn partners
    RH', 0);
INSERT INTO 'dancecrib' VALUES (7209, '2013-08-21 08:31:37.223586+00', '2023-02-04 01:22:19.815693+00', 5897, 3, NULL, 'ace', '1-8::
    1s & 3s cross LH, 1s+2s & 3s+4s turn 3/4 RH on sides to end with
    2M+1M & 4M+3M in line up/down centre of set, all set twice
9-16::
    Ladies dance all the way round clockwise as Men dance a Reel of 4
17-24::
    1s+2s & 3s+4s dance RH across & LH back to pstns with Men in centre
25-32::
    2s+1s & 4s+3s turn LH to end (1) 2 (3) 4, 1s 1/2 turn RH as 3s cross
    RH, 1s cast to bottom (2s+3s+4s dance up) & all set. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7210, '2013-08-21 08:31:37.231706+00', '2023-02-04 01:22:19.841382+00', 5898, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s petronella turn into centre (2s & 3s step down/up slightly),
    all set (in diamond formations), 1s+2s also 3s+4s dance RH across
9-16::
    1s+4s dance 1/2 reel of 4 in centre; pass partner RSh & curve to
    right to turn Lady/Man on side 2H to end BtoB facing opp sides (4s
    between 2s & 1s between 3s)
17-20::
    4s+2s also 1s+3s dance 1/2 reels of 4 across
21-24::
    2s & 3s dance in (passing 4s/1s) RSh, pass partner RSh to end in
    1st/3rd place of a square set, 2s facing down, 3s facing up, Lady on
    Man''s Left, _while_
::
    1s & 4s dance out to sides - 1M+4L to 2nd place, 4M+1L to 4th place
    (Lady on Man''s Right). All set NHJ with "new partners"
25-32::
    All advance 1 step, pivot right about on spot & chase clockwise (2
    bars), flowing into 8H round 1/2 way into longwise set (4 bars)
    2.4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (7211, '2013-08-21 08:31:37.318747+00', '2023-02-04 01:22:19.871204+00', 14589, 3, NULL, 'ace', '1-8::
    1s+2s dance the Knot
9-16::
    1s cross up between 2s & cast to 2nd place, 1s+3s dance RH across
17-24::
    2s+1s dance Ladies'' Chain
25-32::
    1s cross down between 3s & cast up to 2nd place, 2s+1s dance LH
    across', 0);
INSERT INTO 'dancecrib' VALUES (14587, '2022-02-05 02:21:29.594052+00', '2023-02-04 01:22:20.034384+00', 20615, 3, NULL, 'ace', '{{explanation}}
Round the Room, 2 facing 2, 1s facing clockwise, 2s facing anticlockwise

1-8::
    All circle 4H round & back
9-16::
    1s NHJ dance between 2s, divide & cast back to place; 2s repeat
17-24::
    1s+2s dance RH across & LH across back to place
25-32::
    Joining NH with partner, all Adv+Ret then Adv (4 steps), couples
    passing RSh to meet new couple', 0);
INSERT INTO 'dancecrib' VALUES (7212, '2013-08-21 08:31:37.335681+00', '2023-02-04 01:22:20.05144+00', 5904, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back (end facing down)
9-16::
    1s+2s dance the Rondel
17-24::
    2s+1s Adv+Ret 1 step, turn partners 2H & circle 4H round to left
25-32::
    2s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7213, '2013-08-21 08:31:37.34917+00', '2023-02-04 01:22:20.081318+00', 5905, 3, NULL, 'ace', '1-8::
    1s Adv+Ret & turn partner RH
9-16::
    1s dance down for 3 steps, back to top & cast to 2nd place
17-24::
    1s+3s dance RH across & LH back
25-32::
    1s+3s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (12741, '2020-04-11 10:52:57.202562+00', '2023-02-04 01:22:20.116718+00', 19950, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret 2 steps; 2s dance RSh round each other (Gypsy turn)
    to end BtoB in centre facing own side _while_ 1s and 3s dance 2
    places round clockwise
9-16::
    All 3 couples dance inverting double triangles to finish in same
    places (3) 2 (1)
17-22::
    3s+2s+1s dance  6-bar reel on sides, 2s giving RSh to person on
    Right (2M up, 2L down) 2s finish in 2nd place own sides
23-24::
    3s cross RH to own sides _while_ 2s turn RH once round & 1s turn 1/2
    RH (2s+1s remain in middle)  3 2 1
25-32::
    1s+2s dance poussette.  3 1 2
33-40::
    3s+1s dance L&R (3M/1M and 3L/1L change LH on sides, RH across, LH
    on sides, RH across). Finish 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (10097, '2017-09-03 23:45:21.871776+00', '2023-02-04 01:22:20.139929+00', 17893, 3, NULL, 'ace', '1-8::
    1s+2s set, turn partner 2H finishing NHJ facing up.  1s cast, 2s
    dance up to top place & 2s+1s set
9-16::
    1s pass LSh to dance RSh round 1st corner to 1M between 3s, 1L
    between 2s.  Lines of 3 across Adv+Ret.  2s+3s face in
17-24::
    1s pass LSh to dance RSh round 2nd corner to end in 2nd place opp
    sides.  2s+1s+3s turn partner RH (1s turn 1.1/2) All end on own
    sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13342, '2020-11-02 01:21:43.981781+00', '2023-02-04 01:22:20.303044+00', 16676, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s Petronella turn, pass RSh up/down
    _while_ 2s+3s chase clockwise 1 place into lines of 3 across & set,
    pulling back RSh to face up/down
9-12::
    Lines of 3 Adv (2 steps), 1s pull back RSh to face 1M down/1L up
    _while_ 2s+3s turn inwards to reform lines across & all Adv (2
    steps)
13-16::
    1s pass RSh down/up _while_ 2s+3s set, 3M & 2L pull back RSh & all
    chase clockwise 1 place round to sides.  (3) (1) (2)
17-24::
    Set+Link for 3 twice
25-32::
    2s+1s+3s dance reels of 3 on own sides, 1s pass 3rd corner LSh to
    start (1M up, 1L down).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7215, '2013-08-21 08:31:37.368132+00', '2023-02-04 01:22:20.34039+00', 5911, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & turn 4th corner RH, pass LSh to face 1st
    corner
9-16::
    1st corners dance full diagonal reel of 4 _while_ 1s pass corner RSh
    & dance 1/2 way round clockwise, pass approaching corner person RSh
    into middle, pass partner LSh to face 4th corner (pstn) _while_ 2nd
    corners dance on 1 place clockwise, dance into diagonal reel to
    opposite corner & then dance on 1 place clockwise (to starting
    place)
17-24::
    Repeat with 2nd corners
25-32::
    1s RH across (Lady with 2s & Man with 3s), pass RSh for LH across
    with other couple', 0);
INSERT INTO 'dancecrib' VALUES (8359, '2014-07-29 12:59:27.818126+00', '2023-02-04 01:22:20.351641+00', 14711, 3, NULL, 'ace', '1-8::
    1s+2s dance the Knot to end with 1s turning to face 1st corners.
9-16::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners & pass RSh to 2nd places own side
17-24::
    2s+1s+3s set & cross RH, all circle 6H round 3/4 way to left & end
    in lines of 3 across (Men face down & Ladies face up)
25-32::
    All set & cross LH, all dance 6H round 3/4 way to right & end on own
    sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11211, '2018-09-30 22:20:30.497301+00', '2023-02-04 01:22:20.368132+00', 18593, 3, NULL, 'ace', '1-8::
    All change places RH with partner & chase clockwise 1/2 round,
    change places RH with partner & Ladies face out
9-16::
    _1/2_ Schiehallion reels (8 bars) back to original places, Ladies
    facing out
17-24::
    Double Men''s Chain (LH across in centre)
25-32::
    1s+3s dance 1/2 R&L; turn partners RH
33-40::
    2s+4s dance 1/2 R&L; turn partner RH. All face partners
41-56::
    Grand Chain 1/2 way, set; Grand Chain back to places & set using 2nd
    setting to face in
57-64::
    1s+3s dance 1/2 R&L; turn partners RH
65-72::
    2s+4s dance 1/2 R&L; turn partner RH. All Ladies face out
73-80::
    Double Men''s Chain (LH across in centre) All Ladies face out
81-88::
    _1/2_ Schiehallion reels (8 bars) to place opposite start position &
    face partner
89-96::
    All change places RH with partner, chase clockwise back to original
    position & change places RH with partner', 0);
INSERT INTO 'dancecrib' VALUES (8691, '2015-03-03 08:47:17.737551+00', '2023-02-04 01:18:37.848237+00', 16126, 3, NULL, 'ace', '1-8::
    1s turn RH, cast. 2s+1s+3s set, 1/2 turn partners LH into allemande
    hold facing down
9-16::
    2s+1s+3s dance reverse allemande
17-24::
    3s+1s+2s set, 3s cross LH _while_ 1s 1/2 turn LH & dance up, cast to
    3rd place _while_ 2s cross LH & cast up to 2nd place   3 2 1
25-28::
    3s turn RH _while_ 2s+1s change places RH on sides, 2s turn LH
    _while_ 3s+1s change places LH on sides
29-32::
    1s turn RH _while_ 3s+2s change places RH on sides, 3s turn LH
    _while_ 1s+2s change places LH on sides    2 1 3
33-40::
    2s+1s+3s circle 6H round and back', 4);
INSERT INTO 'dancecrib' VALUES (7216, '2013-08-21 08:31:37.376449+00', '2023-02-04 01:22:20.384607+00', 7295, 3, NULL, 'ace', '1-8::
    1s cast behind 2s & dance down between 3s, cast up to 2nd place &
    2s+1s+3s set
9-12::
    1s 3/4 turn LH to face up/down _while_ 2s & 3s petronella turn to
    next corner to right & 1s set in double triangle pstn (1M with 2L+3L
    &1L with 2M+3M)
13-16::
    1s dance clockwise round 2nd corner (pstn) to 2nd place opposite
    sides _while_ 2s+3s dance LH across 1/2 way & all set
17-20::
    1s 3/4 turn LH to face up/down _while_ 2s & 3s petronella turn to
    next corner to right, 1s set in double triangle pstn (1L with 2s at
    top &1M with 3s)
21-24::
    1s dance clockwise round 4th corner (pstn) to 2nd place own sides
    _while_ 2s+3s dance LH across 1/2 way & all set,  (3) 1 (2)
25-32::
    1s (prom hold) dance 1/2 diag reel of 3 giving RSh to 3M (1st place
    Ladies side) & give RSh to 3L to dance 1/2 reel with other corners &
    cross to 2nd pl', 0);
INSERT INTO 'dancecrib' VALUES (7217, '2013-08-21 08:31:37.384779+00', '2023-02-04 01:22:20.402401+00', 5915, 3, NULL, 'ace', '{{title}}
Strathspey

1-16::
    All dance Chorus: Grand Chain 1/2 way, set HS, Grand Chain 1/2 way &
    set HS & Men end BtoB in the middle facing partners
17-24::
    Men set (rocking step) as Ladies petronella turn & set, petronella
    turn & set to move 1/2 way round set
25-32::
    Ladies change pl RH with opp Man, Ladies dance LH across 1/2 way &
    turn partners RH
33-48::
    Repeat bars 1-16 (Chorus)
49-56::
    All dance RH across 1/2 way (Men on outside), all change places with
    prtnrs advancing 1place & change places again advancing 1 more pl
57-64::
    All repeat bars 49-56 back to places

{{title}}
Reel

1-16::
    All dance Chorus: Grand Chain 1/2 way, turn partner with R arms
    twice, Grand Chain 1/2 way & turn partner R arms twice
17-32::
    1s+3s set advancing, turn opposite dancer & circle 4H round to left,
    2s+4s repeat
33-48::
    Repeat bars 1-16 (Chorus)
49-64::
    All dance full Schiehallion Reels (Men start by crossing to the
    right, Ladies cast & cross (following partner))', 0);
INSERT INTO 'dancecrib' VALUES (14434, '2021-11-06 01:13:06.226131+00', '2023-02-04 01:22:20.561549+00', 18696, 3, NULL, 'ace', '1-8::
    1s & 3s Petronella turn & set; 1s & 3s turn partner RH to end 1L &
    3M facing clockwise, 1M & 3L facing anticlockwise
9-12::
    1M+3L turn LH 1.1/2 _while_ 1L+2s+3M chase anticlockwise 1/2 round,
    1s & 3s face partner in line up/down, 2s end in 2nd place opp sides
13-16::
    All set to partner, 3s & 1s turn partner RH 3/4 _while_ 2s turn RH
    1/2 round, all 3 couples in centre facing up ready for …
17-22::
    3s+2s+1s dance Allemande, bar 22 1s & 2s face up, 3s face down
23-24::
    1s cast to 2nd place facing in _while_ 2s dance up to top & face out
    _while_ 3s cast to 3rd place facing out (3M pull back RSh, 3L LSh)
25-32::
    2s+1s+3s dance mirror reels of 3 on sides (1s in/down, 2s out/down,
    3s out up to start).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8630, '2015-02-13 12:48:13.873806+00', '2023-02-04 01:22:20.798989+00', 14966, 3, NULL, 'ace', '1-8::
    1s lead down, bar 5 1L turns under 1M R arm, 1s lead up to 2nd place
    opp. sides (2s step up bars 3-4)
9-16::
    1L with 2s, 1M with 3s dance RH across, 1s pass RSh to dance LH
    across with other couples.  1s take promenade hold facing 2L
17-24::
    1s+2L+3L dance reel of 3 (1s pass 2L LSh to start) 1s finish in 2nd
    place own sides
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (7218, '2013-08-21 08:31:37.394482+00', '2023-02-04 01:22:20.91327+00', 5921, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    Couples Adv+Ret, circle 4H round to left
9-16::
    Couples dance Ladies'' Chain
17-24::
    All set to partners twice & turn RH 1.1/2 times
25-32::
    Dancers set to opposite partner; change places RH, set to partners &
    change places LH to face next couple', 0);
INSERT INTO 'dancecrib' VALUES (13194, '2020-09-15 00:21:32.870164+00', '2023-02-04 01:22:20.929111+00', 19997, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s+3s dance RH across
9-16::
    1s+2s dance LH across; 1s & 3s set, 1/2 turn partner RH into
    allemande hold remaining in centre, 1s facing up, 3s facing down
17-24::
    1s+3s dance Mirror Allemande to end 2 (3) 1
25-32::
    3M+2s & 3L+1s dance RH across, 3s pull back RSh to face each other;
    3s set & petronella turn to 2nd place own side.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7219, '2013-08-21 08:31:37.402705+00', '2023-02-04 01:22:20.955232+00', 5927, 3, NULL, 'ace', '1-4::
    1s & 3s cross RH & cast down 1 place, dance into centre Men facing
    up, Ladies down
5-8::
    1st Man with 2s, 1st Lady & 3rd Man with 4s, 3rd Lady with 5s, all
    circle left & 1s & 3s end facing 2nd corners
9-12::
    Dance Pass+Turn with 2nd corners, 1s & 3s turn partners RH to face
    1st corners
13-16::
    Dance Pass+Turn with 1st corners, 1s & 3s turn partners RH to end in
    centre Ladies facing up & Men down
17-24::
    1s+3s dance reel of 4 in up/down middle, (1s end in 2nd place, 3s in
    4th place both on opposite sides)
25-28::
    1st Lady with 2s, 1st Man & 3rd Lady with 4s, 3rd Man with 5s, all
    dance RH across once round, 1s & 3s ending where they began the
    reel, in middle Man above Lady
29-32::
    1s & 3s 3/4 turn partners RH & cast down on own sides to 3rd & 5th
    places', 0);
INSERT INTO 'dancecrib' VALUES (7220, '2013-08-21 08:31:37.408883+00', '2023-02-04 01:22:20.975942+00', 14809, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All circle 4H round & back
9-16::
    All dance RH across & LH back
17-24::
    All dance DoSiDo with partner, turn opposite partner RH ending in
    prom hold
25-32::
    In prom hold with new partner dance round room to find new couple', 0);
INSERT INTO 'dancecrib' VALUES (7221, '2013-08-21 08:31:37.417202+00', '2023-02-04 01:22:21.012902+00', 5928, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance R&L (starting on sides)
9-16::
    1s+2s also 3s+4s dance a Half Rondel :
::
    1s/3s dance down under arch made by 2s/4s (who dance up), Ladies
    cross in front of Men & all cast to meet the other Lady or Man on
    the opposite side & join nearer hands, set on opposite sides of the
    dance & cross LH back to own sides.  2 1 4 3
17-22::
    1L+2M also 3L+4M dance LSh round each other & Men dance up through
    1L/3L places & down to 2L/4L places as Ladies dance down through
    2M/4M places & up to 1M/3M places _while_ 1M/3M dance up 1 place as
    2L/4L dance down 1 place & then 1M+2L also 2M+4L dance round each
    other LSh to end Men in 1L/3L place & Ladies in 2M/4M place
23-24::
    All cross RH (to original places)
25-32::
    All set, 1s cast to 4th place & all set.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7223, '2013-08-21 08:31:37.433322+00', '2023-02-04 01:22:21.061571+00', 11185, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back
9-16::
    1s cast & cross down into reels of 3 on the opposite side ending
    (1) 2 3
17-24::
    1s cast below 3s & dance up into double triangle position, 1s set
    with corners & rotate 1/4 right to face up/down & set (1L with 2s,
    1M with 3s)
25-32::
    1s dance reels of 3 across (1L with 2s & 1M with 3s) giving RSh to
    4th corners & cross RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7224, '2013-08-21 08:31:37.441511+00', '2023-02-04 01:22:21.075724+00', 13760, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s cross down LH & cast to 2nd places
    own sides
9-16::
    1s turn RH to face 1st corners & turn corners LH, 1s 1/2 turn
    partner RH to face 3rd corners & turn corners LH
17-24::
    1s turn LH to face 2nd corners & turn corners RH, 1s 1/2 turn
    partners LH to face 4th corners & turn corners RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7225, '2013-08-21 08:31:37.453626+00', '2023-02-04 01:22:21.212275+00', 5934, 3, NULL, 'ace', '1-8::
    1s turn 2s on sides RH & dance DoSiDo with partners.
9-16::
    1s+2s turn partners RH & dance DoSiDo on sides.
17-24::
    1M+2M dance across above/below partners, cast in to meet & dance
    b''tw''n partners back to pl, Men set to each other & change pl LH on
    sides.
25-32::
    Ladies repeat above figure.', 0);
INSERT INTO 'dancecrib' VALUES (7226, '2013-08-21 08:31:37.462203+00', '2023-02-04 01:22:21.234248+00', 10780, 3, NULL, 'ace', '1-8::
    1L cast to 2nd place & crosses to opposite side _while_ partner
    crosses & casts to 2nd place, 1s turn RH (4 bars)
9-16::
    2s+1s+3s set, cross RH, set & 2s+3s cross to own sides _while_ 1s
    turn RH to face 1st corners
17-24::
    2s+1s+3s dance Saltire Formation:
::
    1s dance out to 1st corner places _while_ 1st corners cross to
    partners place _while_ 3M+2L dance in & turn LH to face 3rd corner
    (pstn)
::
    3M+2L dance out to corners _while_ 1s cross to own sides _while_
    2L+3M dance in & turn LH to face 1st corner (pstns)
::
    2L+3M dance out to corners _while_ 2M+3L cross to opposite sides
    _while_ 1s dance in & turn LH to face 3rd corners
::
    1s dance out to corner _while_ 2M+3L cross to own sides _while_
    2L+3M dance to 2nd place opposite sides
25-32::
    1s+2s+3s circle 6H round to left for 2 steps (until 2s & 3s are on
    own sides) & all turn 2H (1s turn 1.1/2 times) to 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7227, '2013-08-21 08:31:37.470249+00', '2023-02-04 01:22:21.248361+00', 5936, 3, NULL, 'ace', '1-8::
    1s dance RSh reels of 3 on sides
9-16::
    1s turn 2s RH on sides 1.1/2 times, 1M casts up on own side followed
    by partner & dances down centre to pick up 3s as 1L picks up 2s
17-24::
    1s with 2s & 3s dance down the middle & back to top with 1L+2s
    turning to face down
25-32::
    All set, 2s+3s set as 1s petronella turn to opposite sides; all set
    & 1s cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7228, '2013-08-21 08:31:37.480066+00', '2023-02-04 01:22:21.261183+00', 13219, 3, NULL, 'ace', '1-8::
    All facing top Adv+Ret, all turn to face partner & Adv+Ret
9-16::
    all circle 8H round & back
17-24::
    4L & 4M followed by 3s+2s+1s dance down & cross over to dance up opp
    sides (Men passing Ladies LSh), all dance Grand Chain back to places
25-32::
    All turn partners RH, 1s dance down to 4th place', 0);
INSERT INTO 'dancecrib' VALUES (7229, '2013-08-21 08:31:37.489716+00', '2023-02-04 01:22:21.347854+00', 5937, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s lead down the middle & back
17-24::
    1s cast, cross RH, cast down behind 3s & lead up to Bal-in-Line with
    2s (Men face down)
25-32::
    1s+2s Bal-in-Line across, 1/2 turn opposite partners LH to put 2s in
    centre, Bal-in-Line, 2s dance up to 1st place as 1s cross to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (7231, '2013-08-21 08:31:37.518137+00', '2023-02-04 01:22:21.477064+00', 8175, 3, NULL, 'ace', '1-8::
    1s also 2s 3/4 turn 2H to end in line of 4 up/down set, dance 1/2
    reel of 4 & 3/4 turn partners to sides
9-16::
    1L dances reel of 3 with 2s & 1M with 3s, 1s ending facing 1st
    corners
17-24::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7232, '2013-08-21 08:31:37.526151+00', '2023-02-04 01:22:21.486897+00', 5945, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance full reels of 4 across.  2 1 4 3
9-16::
    1s+4s dance RH across, 2s+1s also 4s+3s dance LH across
17-24::
    1s+4s+3s set, cross RH, set & circle 6H round 1/2 way
25-32::
    All circle 8H round', 0);
INSERT INTO 'dancecrib' VALUES (7233, '2013-08-21 08:31:37.534167+00', '2023-02-04 01:22:21.507519+00', 10920, 3, NULL, 'ace', '1-8::
    1s cross RH & cast to 2nd place, 1s dance 1/2 Fig of 8 round 2s
9-16::
    1s+3s dance RH across, LH back
17-24::
    1L followed by 3L dance Tandem reel of 3 across with 2s (LSh to 2M)
    & 1s end 3rd pl _while_ 3M followed by 1M dance reel of 3 with 4s
    (LSh to 4L) & 3s end in 2nd pl  2 3 1 4
25-32::
    1s+4s dance 1/2 R&L, turn partners RH 1.1/2 times  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14221, '2021-08-14 00:21:47.077039+00', '2023-02-04 01:22:21.525254+00', 12387, 3, NULL, 'ace', '1-8::
    All dance R&L
9-16::
    All dance diagonal reel of 4. Ladies pass LSh to start _while_ Men
    set for 2 bars then give RSh to other Lady. All finish in original
    places
17-24::
    All set (rocking step)
25-40::
    All Petronella to next position on right & set. Repeat 3 times to
    finish back in place
41-48::
    All dance diagonal reel of 4. Men pass RSh to start _while_ Ladies
    set for 2 bars then give LSh to other Man. All finish in original
    places
49-56::
    All set (cross-over step)
57-64::
    All dance Ladies'' Chain at end finish in Waltz hold with partner,
    Men with backs to audience
65-72::
    All set (Highland Schottische), starting with couples moving away
    from each other, turn 2H, opening up into line facing audience', 0);
INSERT INTO 'dancecrib' VALUES (7316, '2013-08-21 08:31:38.853671+00', '2023-02-04 01:22:27.500458+00', 7946, 3, NULL, 'ace', '1‑8::
    All Ladies Adv+Ret _while_ Men set & advance, Men dance RSh round
    partner & end facing them in middle _while_ Ladies set turning (4
    bars)
9‑16::
    All Promenade
17‑24::
    1s dance in between 2s, behind 3s, between 4s & turn RH at bottom
25‑32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15424, '2023-02-04 01:22:21.699978+00', '2023-02-04 01:22:21.70134+00', 21138, 3, NULL, 'ace', '1-8::
    1s+4s set, cast down/up (2s+3s step up/down bars 3-4), cross RH,
    cast up/down (2s+3s step down/up) (1s/4s finish facing down/up) (1)
    2 3 (4)
9-16::
    »Best Set in the Hall« figure but on the sides, not on the diagonal.
::
    _9-10_    1L+2M, 1M+2L, 3M+4L also 3L+4M set to each other
::
    _11-12_  2M+3M also 2L+3L pull back RSh to dance round each to ends
    of the set _while_ 1L+4L also 1M+4M dance towards each other, pull
    back RSh to finish BtoB facing partners'' original places. 3 (1) (4)
    2
::
    _13-14_  All set
::
    _15-16_  1L+4L also 1M+4M pull back RSh & dance round each other to
    the ends of the set _while_ 3M+2M also 3L+2L dance towards each
    other, pull back RSh to finish BtoB.  (4) 3 2 (1)
17-24::
    All dance RSh reels of 4 on the sides
25-28::
    4M followed by 4L also 1L followed by 1M dance 1/2 way clockwise
    round the set to own sides
29-32::
    1s+3s also 4s+2s dance 1/2 RH across, retain RH with partner & turn
    1.1/2 times to finish 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (7235, '2013-08-21 08:31:37.550403+00', '2023-02-04 01:22:21.758678+00', 5952, 3, NULL, 'ace', '1‑8::
    All set, Petronella-in-tandem 1 place to right, repeat to finish
    opposite original places
9‑16::
    1s+3s in prom hold dance back to original places (Ladies passing
    RSh), 2s+4s repeat
17‑24::
    Men dance LH across 1/2 way & loop round opposite Lady''s place
    _while_ Ladies set & cast into partners place, Ladies repeat _while_
    Men set & cast
25‑32::
    All repeat back to original places
33‑40::
    Men dance LH across with partners on right 1/2 way, Men drop left
    hands & all Set+Link
41‑48::
    Ladies dance LH across with partners on right, all Set+Link & Men
    end in middle facing partners
49‑56::
    All dance DoSiDo with partners (Ladies briefly join hands a circle
    in centre), all set to partner & change places RH
57-64::
    All dance DoSiDo with partner (Men briefly making a circle in
    centre), all set & turn RH to end Ladies in centre (bow & curtsey)', 0);
INSERT INTO 'dancecrib' VALUES (10226, '2017-11-04 01:46:02.903118+00', '2023-02-04 01:22:21.79141+00', 18024, 3, NULL, 'ace', '1-8::
    1s lead down below 4s, turn outwards & cast up to places
9-16::
    1s set HS & turn partners 2H
17-24::
    1s+2s dance R&L
25-32::
    1s dance Fig 8 round 2s
33-40::
    1s set, cross RH, set & cross back RH
41-48::
    1s 1/2 turn 2s with 2H to change places (Men''s side anticlockwise,
    Ladies'' side clockwise).  Repeat, 1s crossing to turn 3s, then
    crossing to turn 4s', 0);
INSERT INTO 'dancecrib' VALUES (7236, '2013-08-21 08:31:37.558409+00', '2023-02-04 01:22:21.813941+00', 8465, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s & 1s+2s turn RH
9-16::
    1s dance 1/2 Fig of 8 round 2s & 1s+2s turn LH
17-24::
    1s cast to 4th place & all dance DoSiDo
25-32::
    All circle 8H round & back', 4);
INSERT INTO 'dancecrib' VALUES (7237, '2013-08-21 08:31:37.566387+00', '2023-02-04 01:22:21.83076+00', 5960, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All circle 4H round & back
9-16::
    1s (Facing anticlockwise) dance Fig of 8 round 2s (dancing between
    them to start)
17-24::
    2s dance Fig of 8 round 1s (dancing between them to start)
25-32::
    All Adv+Ret, 1s make an arch & dance forward to meet new couple', 0);
INSERT INTO 'dancecrib' VALUES (7238, '2013-08-21 08:31:37.57519+00', '2023-02-04 01:22:21.848907+00', 5961, 3, NULL, 'ace', '{{explanation}}
Round the room dance, 2 facing 2

1-8::
    All circle 4H round & back
9-16::
    Men turn RH & turn LH
17-24::
    Ladies turn RH & turn LH
25-32::
    All advance for 8 steps with clockwise couple first making an arch
    then dancing under an arch made by the next couple & repeat passing
    4 couples', 0);
INSERT INTO 'dancecrib' VALUES (7239, '2013-08-21 08:31:37.584882+00', '2023-02-04 01:22:21.986139+00', 5963, 3, NULL, 'ace', '1-8::
    1s cast down below 3s & lead up to top, cross & cast to 2nd place on
    opposite sides
9-16::
    1s circle 4H round to the left with 3s & dance full R&L with 2s (1
    place to each bar) to face 1st corners
17-24::
    1s set to & turn 1st corner; set to & turn 2nd corner
25-32::
    1s dance 6 bar reels of 3 on sides with 2s & 3s (LSh to 1st corners)
    & cross to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (12173, '2019-09-04 22:08:25.587261+00', '2023-02-04 01:22:22.259505+00', 19578, 3, NULL, 'ace', '1-8::
    1s cross & cast 1 place, 1s cross & cast another space.  2 3 1
9-16::
    1s cross (each couple cross down as they reach top place) to dance
    reflection reels of 3 on sides.  (2)(3)(1)
17-28::
    All dance 3 couple R&L
29-32::
    All set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (14222, '2021-08-14 00:21:47.470945+00', '2023-02-04 01:22:22.284672+00', 16460, 3, NULL, 'ace', '{{explanation}}
2 circles, Men on outside facing in, Ladies inside facing out

1-8::
    All circle left to face new partner
9-16::
    All turn new partner RH; turn LH
17-24::
    All turn 2H; all dance DoSiDo
25-32::
    Men form arches & dance in, Ladies dance out passing Men RSh, all
    set turning about to face each other; all repeat 25-28', 0);
INSERT INTO 'dancecrib' VALUES (12558, '2020-02-02 02:49:31.162596+00', '2023-02-04 01:22:22.320208+00', 5966, 3, NULL, 'ace', '1-8::
    1s cast & dance down behind own line; turn out & dance up back to
    place
9-16::
    1s+2s dance RH across & LH back
17-24::
    1s lead down the middle & back (stay in middle)
25-32::
    1s cast to 3rd place (2s+3s step up 27-28); 1s turn RH.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (12742, '2020-04-11 10:52:58.98155+00', '2023-02-04 01:22:22.543849+00', 19948, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast off one place (2s step up) & turn LH to face
    1st corners
9-16::
    1s dance Corner Pass+Turn with 1st corners, pass RSh & dance Corner
    Pass+Turn with 2nd corners, finish in 2nd place, opp side
17-24::
    _1/2_ Fig 8 (1M down through 3s, 1L up through 2s); All three
    couples turn RH to own sides
25-32::
    All dance 6H round and back. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12743, '2020-04-11 10:52:59.005976+00', '2023-02-04 01:22:22.571892+00', 15316, 3, NULL, 'ace', '1-8::
    1s cross RH, cast, cross RH & cast up, back to place
9-16::
    _6_ bar mirror reel (1s in/down, 2s out/down, 3s in/up). Bar 15-16
    2s+3s pass again RSh to change places _while_ 1s set.  1 3 2
17-24::
    1s+3s Set & Rotate
25-32::
    3s+1s+2s Set & Rotate for 3 couples. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7242, '2013-08-21 08:31:37.643986+00', '2023-02-04 01:22:22.623302+00', 5972, 3, NULL, 'ace', '1-8::
    1s+3s turn RH & cast 1 place, cross LH & cast (Men up, Ladies down)
    to end facing 3rd corners
9-16::
    All dance RSh reels across (reel of 3 at top & bottom with reel of 4
    in centre) 1s & 3s end in 2nd/4th places own sides facing out
17-24::
    1s+3s chase anticlockwise 1/2 way to 4th/2nd places opposite sides
25-32::
    2s+3s also 1s+5s (end cpls) dance 1/2 R&L _while_ 4s set & cross RH,
    2s+4s+5s (middle cpls) circle 6H round to left 1/2 way to end 3 5 4
    2 1', 0);
INSERT INTO 'dancecrib' VALUES (7325, '2013-08-21 08:31:38.933674+00', '2023-02-04 01:22:27.890617+00', 6104, 3, NULL, 'ace', '1-8::
    1s & 2s dance the Tourbillon :
::
    1s & 2s turn partners 2H 1/2 way, 1M & 2L lead partners on 1 place
    clockwise to end 1s on Ladies side & 2s on Men''s side, 1s set to 2s
::
    1s & 2s 1/2 turn partners 2H, 1L & 2M lead partners on 1 place to
    end 2s in 1st pl & 1s in 2nd pl & 2s+1s cross RH to own sides
9-16::
    1s dance 1/2 Figs of 8 (Man round 2s & Lady round 3s), 1s dance 1/2
    reels of 3 (Man with 3s & Lady with 2s)
17-24::
    1s dance Diag R&L to end 3 1 2
25-32::
    All set & 3s+1s dance RH across 1/2 way _while_ 2s cross RH, all
    chase clockwise 1/2 way to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4167, '2013-08-21 08:30:44.548894+00', '2023-02-04 01:18:37.85914+00', 399, 3, NULL, 'ace', '1-8::
    1s+4s dance R&L _while_ 2s+3s dance RH across & LH back
9-16::
    4s cross RH & cast up round 3s & dance up between 2s then 4s cast &
    cross down to original places _while_ 1s dance down (to follow 4s)
    to end in 2nd places own sides
17-24::
    1s+3s dance 1/2 R&L, 1s+4s dance 1/2 R&L.  2 (3)(4) 1
25-32::
    1s followed by 4s+3s (who begin by dancing down) dance up to top
    (4s+3s cross to own sides at top) & cast down round 2s (1s to
    bottom, 4s to 3rd pl & 3s to 2nd pl)  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4169, '2013-08-21 08:30:44.700924+00', '2023-02-04 01:18:38.029936+00', 407, 3, NULL, 'ace', '1-8::
    1s+2s set, turn 2H once round; 1s+2s circle to the left 1/2 way &
    cross RH to own side
9-16::
    2s+1s+3s set, circle 6H round to the left & set
17-24::
    1s dance reels of 3 across (Lady with 2s & Man with 3s), pass LSh to
    end facing 2nd corner
25-32::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corner &
    cross RH to own side', 0);
INSERT INTO 'dancecrib' VALUES (11212, '2018-09-30 22:20:31.129811+00', '2023-02-04 01:22:22.645954+00', 18667, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All face partners to dance Interlocking Reels of 4, all change
    places RH with partner bars 7 & 8.
9-12::
    All Set+Link, Men finish facing out.
13-16::
    Ladies dance LH across _while_ Men dance clockwise 1/2 way round.
    Ladies dance out _while_ Men dance in, passing LSh.
17-24::
    Men dance RH across _while_ Ladies dance anticlockwise 1/2 way
    round.  Finish facing partners opposite original places, men with
    backs to the centre.  All turn partners LH.
25-32::
    All dance Double LSh Reels of 4 (RH across 1/2 way in middle),
    finish Men retaining RH across in the centre joining NH with
    partners, all facing clockwise.
33-36::
    All dance 1/2 way round, Men bringing partners round to face in
    original positions, with partner on the left.
37-40::
    All set to partners and change places RH.  (All dancers in original
    places)
41-48::
    Circle 8 hands round and back.
49-96::
    Repeat bars 1-48 in Reel or Hornpipe time.', 0);
INSERT INTO 'dancecrib' VALUES (7243, '2013-08-21 08:31:37.652068+00', '2023-02-04 01:22:22.66704+00', 5976, 3, NULL, 'ace', '1-8::
    1s lead down, 1/2 turn RH, lead up & 1/2 turn RH
9-16::
    1s+2s dance RH across, dance LH across for 2 bars & 2M+1M also 2L+1L
    1/2 turn LH on sides
17-24::
    1s+2s set, turn partner 2H; 1s+2s circle 4H round to left
25-32::
    1s+2s face in diagonally, Petronella turn 1 place to right & dance
    RH across 1/2 way; Petronella turn to right 1 place & dance 1/2 LH
    across.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (14133, '2021-07-07 00:21:16.782248+00', '2023-02-04 01:22:22.692601+00', 5978, 3, NULL, 'ace', '1-8::
    1s+3s dance down 1 place & cast up back to place; 1s+3s set & cross
    RH with partner
9-16::
    1s+2s also 3s+4s set & dance 1/2 RH across; 1s+4s set & dance 1/2 LH
    across. (2) 4 (1) 3
17-24::
    2s+1s lead down 1 place, cross to own side & cast up 1 place, all
    dance DoSiDo with partner to end 2 4 1 3
25-32::
    2s+4s also 1s+3s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7244, '2013-08-21 08:31:37.660159+00', '2023-02-04 01:22:22.712772+00', 5980, 3, NULL, 'ace', '1-8::
    All set, 1M & 3L petronella turn into centre (BtoB position), dance
    out thru partner''s place & cast to R into each others place _while_
    1L & 3M cast down/up to opp end, petronella turn into centre (BtoB
    position) & dance out to opp sides (3) 2 (1)
9-16::
    All set, circle 6H round to left for 3 steps, dance in on 4th step &
    turn to right to dance round clockwise to (3) 2 (1)
17-24::
    Repeat bars 1- 8 with 1s+3s changing back to original places  1 2 3
25-32::
    2s followed by 1s dance down between 3s, cast up (2s to top & 1s to
    2nd pl), 1s followed by 3s dance up between 2s & cast (1s to bottom
    & 3s to 2nd place)  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (14435, '2021-11-06 01:13:07.473449+00', '2023-02-04 01:22:22.84001+00', 20543, 3, NULL, 'ace', '1-8::
    1L+3M advance towards partner, pull back RSh to face own side (2
    bars), 1L & 3M followed by partners chase clockwise 1/2 round
    (behind 2s) to end in line of 4 up/down centre, 3s at top, 1s at
    bottom, Men facing up, Ladies facing down
9-14::
    3s+1s dance a modified 1/2 reel of 4 (6 bars) : as normal reel but
    when 1M reaches top & 3L reaches bottom they curve into their
    partners'' places, partners follow to finish opposite
15-16::
    1s+3s 1/2 turn partner RH back to original places
17-24::
    1s+2s Set+Link (1M no polite turn but faces out/down); 1s+3s turn
    LH.  2 1 3
25-32::
    1s set & cast to 4th place (3s+4s step up 27-28);  All 4 couples
    turn RH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7246, '2013-08-21 08:31:37.679654+00', '2023-02-04 01:22:23.034993+00', 5982, 3, NULL, 'ace', '1-8::
    1s cast & dance down behind own lines, turn outwards & dance back to
    top
9-16::
    1L+2M set & change places RH _while_ 1M+2L change places RH & set;
    repeat
17-24::
    1s lead down for 2 steps, turn RH, lead up to top & cast to 2nd
    place
25-32::
    2s+1s set & turn partner 2H opening out to circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (7247, '2013-08-21 08:31:37.687776+00', '2023-02-04 01:22:23.052108+00', 8523, 3, NULL, 'ace', '1-8::
    1s dance Inveran Reels with 2s+3s
9-16::
    2s dance RH across (Lady with 1s & Man with 3s), 2s pass RSh & dance
    LH across with other couple
17-24::
    All chase anticlockwise 1/2 way, all set & cross RH with 2s & 1s
    remaining in centre for…
25-32::
    2s+1s dance Poussette.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (13093, '2020-08-10 00:21:18.089876+00', '2023-02-04 01:22:23.077416+00', 5984, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    1s dance Fig 8 round 2s (1s lead down & cross to start) _while_ 3s
    dance similar Fig 8 round 4s
9-16::
    1s+3s  dance R&L (across) _while_ 2s+4s set to partners & dance 3/4
    L&R (left hand cross to start). 1 (4) 3 (2)
17-20::
    1s+4s & 3s+2s turn RH on side, 4s+3s turn LH on sides _while_ 1s+2s
    turn partners LH. 1s face 4s & 3s face 2s on sides
21-24::
    1s+4s+3s+2s dance Grand Chain 1/2 round (1 step per hand). 2 (3) 4
    (1)
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15237, '2022-11-03 01:21:38.933864+00', '2023-02-04 01:22:23.148659+00', 5986, 3, NULL, 'ace', '1-4::
    1s+2s set and dance RH across 1/2 way
5-8::
    1s+3s set and dance LH across 1/2  way
9-12::
    2s+3s+1s set and cross RH (1s finish facing out)
13-16::
    1s cast up and cross LH (finish facing out)
17-24::
    1s dance mirror Fig 8 on own sides (dance behind 2s to start, take
    hands where possible) _while_ 2s and 3s dance R&L (no polite turn
    for 2M)
25-32::
    1s+2s Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7961, '2013-08-21 08:31:51.879297+00', '2023-02-04 01:23:13.963694+00', 12718, 3, NULL, 'ace', '1-8::
    1s cross down RH to dance 6 bars Double triangles & end in middle
    facing own sides
9-16::
    1s dance reels of 3 across giving RSh to 3rd corner & end 2nd place
    facing out opposite sides
17-24::
    1s dance reels of 3 on opposite sides giving LSh to 2nd corner & end
    crossing to 2nd place own sides
25-32::
    2s+1s+3s circle left for 6 steps, pivot left & chase back to places', 0);
INSERT INTO 'dancecrib' VALUES (7249, '2013-08-21 08:31:37.70432+00', '2023-02-04 01:22:23.168084+00', 10083, 3, NULL, 'ace', '1-8::
    All turn partners 2H, 2s dance 1/2 Figs of 8 (Man up & Lady down)
9-16::
    All set on side, circle 6H round to left for 2 steps, Men turn Lady
    on his right & continue circle back to place
17-24::
    2s 1/2 turn 2H & twirl & dance back to original place, 2s cast to
    left & cross to partners place facing out
25-32::
    2s dance reels on sides (2s give LSh to 2nd corners to start), 2s
    cross to own side (2L down from 1st place, 1M up from 3rd place) as
    1s+3s finish reels
33-40::
    1s dance 1/2 Fig of 8 up round 2s, cross down & dance out behind 3s
    to 3rd place (3s step up 39-40).  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (8069, '2013-10-01 08:47:22.166337+00', '2023-02-04 01:22:23.184096+00', 15057, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 (1s dance between 2s to start)
9-16::
    1s+2s dance 1/2 Poussette, 1s+3s dance 1/2 Poussette
17-24::
    All pass partner RSh & turn right about then cast to opposite sides,
    all turn 2H 1.1/2 times
25-32::
    3s+1s dance Tournée', 0);
INSERT INTO 'dancecrib' VALUES (8360, '2014-07-29 12:59:28.119615+00', '2023-02-04 01:22:23.199881+00', 5989, 3, NULL, 'ace', '{{explanation}}
Round the room, 1s face clockwise, 2s face anticlockwise

1-8::
    All dance RH across & LH back
9-16::
    1s dance between 2s, separate & cast back to places, 1s turn RH
17-24::
    2s repeat bars 9-16 dancing between 1s
25-32::
    All Adv+Ret & pass opposite dancer RSh to meet next couple', 0);
INSERT INTO 'dancecrib' VALUES (7250, '2013-08-21 08:31:37.714131+00', '2023-02-04 01:22:23.216018+00', 548, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set+Link, 1L+2M also 3L+4M advance, join RH & the
    Lady dances under the right arm all returning to places (ie
    ''Allemande Right'') _while_ 1M+2L dance round clockwise to change
    places as 3M+4L dance similarly
9-16::
    All Set+Link with ptnrs on sides, 1M+2L also 3M+4L ''Allemande Right''
    as others dance cl''wise to change pl (All on opp sides 2 1 4 3)
17-24::
    All set, cross to own sides RH & turn partners RH with 2s ending in
    top place & 1s+4s+3s in centre for Allemande
25-32::
    1s+4s+3s dance Allemande to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7251, '2013-08-21 08:31:37.723957+00', '2023-02-04 01:22:23.233891+00', 13313, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate:
::
    Set (facing diagonally opp dancer), rotate singly & dance on 1 place
    clockwise, change places RH on sides & dance on 1 place to own sides
    (1s in 2nd pl)
9-16::
    1s dance reels of 3 on own sides giving LSh to 3s to start & 1s end
    facing 1st corners
17-24::
    1s turn corners RH & pass RSh to face 3rd corners, turn 3rd corner
    LH & pass LSh to face 2nd corners
25-32::
    1s turn 2nd corners RH & pass RSh to face 4th corners, turn 4th
    corners LH & loop into 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7252, '2013-08-21 08:31:37.732148+00', '2023-02-04 01:22:23.255489+00', 12651, 3, NULL, 'ace', '1-8::
    Ladies dance clockwise in front of partner behind next Man & round
    next Man LSh to end on his right
9-16::
    Men dance anticlockwise in front of new partner behind next Lady &
    round next Lady RSh to end on her left
17-20::
    Men petronella turn into centre _while_ Ladies dance on 1 place
    clockwise & all 1/2 turn RH facing person to change places
21-24::
    Ladies set _while_ Men dance on 1 place clockwise & Men set _while_
    Ladies dancing to left loop round to right to original places with
    new partner
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13918, '2021-04-05 00:21:41.496229+00', '2023-02-04 01:22:23.285539+00', 12388, 3, NULL, 'ace', '1-8::
    1M+2L dance RSh round partner, meet in centre & turn 1.1/2RH back to
    places
9-16::
    1L+2M dance LSh round partner, meet & turn 1.1/2 LH back to places
17-24::
    1s long cast to dance behind own lines & cast up back to places
25-28::
    »The Diddle«: 1M+2L set, cross to partner''s place _while_ 1L+2M set
    advancing diagonally, meet & turn RH to face partner on 2nd corner
    diagonal.
29-32::
    1M+2L dance 1/2 diagonal reel of 4 _while_ 1L+2M dance RSh round
    partner to next place clockwise on own sides 2 1', 0);
INSERT INTO 'dancecrib' VALUES (10098, '2017-09-03 23:45:23.057154+00', '2023-02-04 01:22:23.317235+00', 5995, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 on own sides dancing between 2s to start
9-16::
    1s dance down for 3 bars, dance back to top & cast to 2nd place (2s
    step up 7-8).  End 2s facing 1s on sides, couples NHJ.
17-24::
    1s form arch & dance up, 2s dance under. 1s+2s turn toward partner
    to change direction. Repeat arches & changes 3 more times, the
    couple in 2nd place making the arch.
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7253, '2013-08-21 08:31:37.74016+00', '2023-02-04 01:22:23.343622+00', 5996, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s
9-16::
    3s dance Fig of 8 round 2s
17-24::
    All men cross & dance RSh round partner back to places, all Ladies
    repeat
25-32::
    2s dance Fig of 8 round 1s+3s (down between 3s to start)
33-40::
    1s dance down for 2 & back to top, 1s cast to bottom', 0);
INSERT INTO 'dancecrib' VALUES (7254, '2013-08-21 08:31:37.748109+00', '2023-02-04 01:22:23.367242+00', 5998, 3, NULL, 'ace', '1-8::
    1L+3L set advancing, turn RH back to place, 1M+3M set advancing &
    turn RH back to places
9-16::
    1s+3s dance RH across & LH back
17-24::
    1s in prom hold dance reel of 3 with 2s (LSh to 2L to start) _while_
    3s dance reel with 4s (LSh to 4L to start)
25-32::
    All circle 8H round & back
33-64::
    Repeat bars 1-32 with 2s+4s as dancing couples

{{explanation}}
Repeat in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (7255, '2013-08-21 08:31:37.756319+00', '2023-02-04 01:22:23.397926+00', 14237, 3, NULL, 'ace', '{{explanation}}
5s in middle facing each other,  5M with back to 4s & 5L back to 2s

1-8::
    1s+2s+3s+4s circle 8H round & back _while_ 5s set & change places
    RH, set & 3/4 turn LH to 5L facing 1s & 5M facing 3s
9-16::
    5L turns 1M RH _while_ 5M turns 3L RH, 5s pass RSh to turn 3M/1L LH
    & pass LSh to face 1s/3s
17-20::
    5L dances 1/2 RSh reel of 3 with 1s+4s (in prom hold) _while_ 5M
    dances 1/2 reel of 3 with 3s+2s & 5s end facing side couples
21-24::
    5L dances 1/2 RSh reel of 3 with 1M+3L (in 4th/2nd places) _while_
    5M dances 1/2 reel of 3 with 3M+1L
25-28::
    5s dance LH across 1/2 way (5L with 1s in 2nd pl & 5M with 3s in 4th
    pl), 5s dance in between 1s/3s as 1s/3s turn left about to face in
29-32::
    5s dance out between top/bottom couples casting to right & turn RH
    to face 4s (at top), 5s+4s dance RH across 1/2 way

{{explanation}}
Suggestion for the less agile: Bars 29-32:  5s turn RH to face 4s (at top) & 5s+4s dance RH across 1/2 way. End 5 1 2 3 4', 0);
INSERT INTO 'dancecrib' VALUES (5285, '2013-08-21 08:31:03.988994+00', '2023-02-04 01:22:23.433806+00', 11808, 3, NULL, 'ace', '1-8::
    1s cross RH, cast down 1 place into centre, pivot to right to dance
    RH across (Lady with 2s & Man with 3s) & end facing 1st corners
9-24::
    1s dance Corner Chain with 1st & 2nd corners:
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s cross to 2nd places own sides
25-32::
    1s dance 1/2 reel of 3 across (Lady with 2s & Man with 3s) & 1s pass
    LSh to dance 1/2 reel of 3 with other couple', 0);
INSERT INTO 'dancecrib' VALUES (4170, '2013-08-21 08:30:44.797055+00', '2023-02-04 01:18:38.059354+00', 9710, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, 2s+1s+3s set & 1s turn LH to face 1st
    corners
9-16::
    1s turn 1st corners RH, passing RSh dance 1/2 reels of 4 with 2nd
    corners & end passing RSh to face 3rd corners
17-24::
    1s turn 3rd corners RH, passing RSh dance 1/2 reel of 4 with 4th
    corners & end in middle (Lady above Man)
25-32::
    1s dance RH across (Lady with 2s & Man with 3s), 1s set advancing &
    turn 2H to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7256, '2013-08-21 08:31:37.766216+00', '2023-02-04 01:22:23.459102+00', 9282, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH
9-16::
    1s dance 1/2 Fig of 8 round 2s, 2s dance 1/2 Fig of 8 round 1s
17-24::
    2s+1s dance 1/2 R&L & circle 4H round to left
25-32::
    1s lead down for 2, turn RH, lead to top & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (15425, '2023-02-04 01:22:23.472091+00', '2023-02-04 01:22:23.472814+00', 21139, 3, NULL, 'ace', '1-8::
    1s+2s Mirror Set+Link (1s cast, 2s dance up), 1s cross passing RSh,
    cast off round 3s to 2nd place facing up
9-14::
    2s+1s+3s dance 6 bar mirror reels of 3 on the sides (1s out & up, 2s
    in & down)
15-16::
    2s+1s continue the reel to change places (2s finish facing out).
    (1) 2 3
17-18::
    1s+2s change places on sides (1M+2L LH, 1L+2M RH) (2s finish facing
    out) 2 (1) 3
19-20::
    1s cast up to 1st place _while_ 2s cross down to 2nd place on opp
    sides facing out (1) (2) 3
21-24::
    1s dance down for 2 steps, turn 1/2 way 2H to 2nd place _while_ 2s
    cast up & cross RH 2 1 3
25-32::
    1s+3s dance Espagnole:
::
    _25-26_   1s+3s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _27-28_   1s+3s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _29-32_   3s turn RH _while_ 1s turn LH', 0);
INSERT INTO 'dancecrib' VALUES (13533, '2021-01-09 01:21:34.298134+00', '2023-02-04 01:22:23.490911+00', 17694, 3, NULL, 'ace', '1-8::
    1s+2 dance Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH to face 4th corners
9-16::
    1s dance 1/2 diagonal reel of 4 with 4th corners, at end 1s pass RSh
    to finish in centre facing each other (Man facing up, Lady down). 1s
    turn 3/4 2H, 1s set advancing, pass LSh to face 1st corners
17-22::
    Dance to Corners & Set: (6 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 2 more times to end
    with corners in diagonally opposite place and 1s meet in the middle
    again & pass RSh with a 1/4 turn to right to face 2nd corner (pstn)
    as orig 1st corners set
23-24::
    1s turn 1/2 RH, pull back RSh to finish in centre facing opposite
    sides _while_ 2s+3s set diagonally
25-32::
    1s dance the Snake:
::
    1s dance RH across (1M with 2s & 1L with 3s), 1M followed by 2s & 1L
    followed by 3s cross diagonally passing LSh to change ends & loop
    round so that 1s finish in 2nd place  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9562, '2017-01-25 23:58:02.007232+00', '2023-02-04 01:22:23.507849+00', 17528, 3, NULL, 'ace', '1-8::
    All face partners, set, turn 3/4 RH so Ladies in centre facing
    corners.  Ladies dance RSh round corners to end BtoB with partners
9-16::
    Reels of 4 across, 1s+2L+4M & 3s+2M+4L.  All end facing partners
17-24::
    All set, turn 3/4 LH so Men in centre facing corners.  Men dance LSh
    round corners and back to places
25-28::
    All set, pull back RSh and dance 1 place round to Left, 1s+3s in
    middle facing each other, 2s in 3rd place, 4s in 1st place
29-32::
    1s+3s dance RH across to end 1s in 2nd place, 3s in 4th place', 0);
INSERT INTO 'dancecrib' VALUES (15355, '2022-12-19 01:21:55.850754+00', '2023-02-04 01:22:23.522285+00', 20775, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH; 1s+2s dance RH across.  (1) (2) 3
9-16::
    1s+2s set, cross LH; 1s+2s dance LH across. 1 2 3
17-24::
    1s dance down 2 steps (2s step up 19-20), 1s turn inwards to face,
    retain hands & set; 1s dance down, cast up round 3s to 2nd place own
    side
25-32::
    1L+2s (at top) & 1M+3s dance RH across, pass RSh to dance LH across
    with other couple.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7257, '2013-08-21 08:31:37.775229+00', '2023-02-04 01:22:23.541633+00', 14950, 3, NULL, 'ace', '1-8::
    1s set, cross then cast 1 place (2s step up). 1s dance 1/2 reels of
    3 across (1L with 2s, 1M with 3s)
9-16::
    1s dance RH across (1L with 2s, 1M with 3s), 1s change ends & dance
    LH across with other couple
17-24::
    1s set, cross then cast 1 place (3s step up). 1s dance 1/2 reels of
    3 across (1L with 3s, 1M with 4s)
25-32::
    1s dance RH across (1M with 4s, 1L with 3s), 1s change ends & dance
    LH across with other couple
33-40::
    1s turn RH 1.1/4 times & 1M followed by 1L (in tandem) dance RSh
    round 3L to 3rd place own sides _while_ 3s dance to opposite sides
    (2)(3)1(4)
41-48::
    All set, all cross RH, 1s set, cross then cast to 4th place own side
    (4s step up)  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7258, '2013-08-21 08:31:37.860193+00', '2023-02-04 01:22:23.780155+00', 6010, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place (2 step up), dance down between 3s (3s
    step up) & cast down behind 4s to 4th place (4s step up)
9-16::
    1s dance reflection reels of 3 on opposite sides (1s in/up, 4s
    out/down)
17-24::
    1s cross RH & cast up 1 place, lead up between 3s & cast up behind
    2s to 1st place own sides
25-32::
    1s dance reflection reels of 3 on own sides (1s in down, 2s out/up)
33-40::
    1s cross RH & cast down 1 place (2 step up) 1s give RH to partner &
    LH to 1st corners, Bal-in-Line & turn partner RH to give LH to 2nd
    corners
41-48::
    Bal-in-Line & 1s dance out & cast down behind 3s, meet & lead up to
    top crossing to 1st place own sides (2s step down)
49-60::
    1L+2L & 1M+2M change places RH on sides & 2s+1s cross over LH,
    repeat with 3s & 4s until reaching the bottom of the set
61-64::
    All turn partners RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (7259, '2013-08-21 08:31:37.872485+00', '2023-02-04 01:22:23.810565+00', 7311, 3, NULL, 'ace', '1-4::
    1s+2s dance RH across 1/2 way _while_ 3s 1/2 turn LH, 1s+3s dance LH
    across 1/2 way _while_ 2s 1/2 turn RH
5-8::
    2s+3s dance RH across 1/2 way _while_ 1s 1/2 turn LH, 2s+1s dance LH
    across 1/2 way _while_ 3s 1/2 turn RH.  3 1 2
9-16::
    1s set, 1s dance 1/2 LSh reels of 3 across (1L+3s at top & 1M+2s),
    1/2 RSh reels on opp side (Man up, Lady down) & end facing Mans 2nd
    crnr (pstn) Lady on Mans Left
17-24::
    1s set to 2nd crnr (2M), turn inwards & set to 4th crnr (3L), set to
    1st crnr (3M), set to 3rd crnr (2L) & 1s turn right about to face
    1st crnr (1L behind 1M)
25-32::
    1s dance diag Alternating Tandem 1/2 reel with 1st corners & 1/2
    Alternating Tandem reel with 2nd corners ending 2nd place own sides.
    3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7260, '2013-08-21 08:31:37.882249+00', '2023-02-04 01:22:23.841191+00', 7941, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels of 3 on the sides (1s in & down to start)
9-16::
    1s dance down between 2s+3s & cast up to 2nd place, 1L+3L turn LH
    1.1/2 times _while_ 1M+3M turn RH 1.1/2 times
17-24::
    1s+4s+5s dance reels of 3 on sides (1s out & down to start)
25-32::
    1s cast below 5s & dance up middle to 4th place, 1L+5L turn RH 1.1/2
    times _while_ 1M+5M turn LH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (14436, '2021-11-06 01:13:08.249193+00', '2023-02-04 01:22:23.870354+00', 15728, 3, NULL, 'ace', '1-8::
    All circle 8 hands round to left & back
9-16::
    1s+3s dance Ladies'' Chain
17-24::
    2s+4s dance Ladies'' Chain
25-32::
    Men dance RH across & LH across back, join RH with original partner,
    retaining LH in centre
33-48::
    All dance Modified Spoke:
::
    _33-36_   Men balance with partner (2 bars) & set advancing to next
    Lady
::
    _37-48_   Repeat with next 3 Ladies working anticlockwise round to
    return to partner
49-56::
    All promenade anticlockwise round back to place
57-64::
    1s+3s dance R&L
65-72::
    2s+4s dance R&L
73-80::
    Ladies dance LH across & RH across back, join LH with partner,
    retaining RH in centre
81-96::
    All dance Modified Spoke:
::
    _81-84_   Ladies balance with partner (2 bars) & set advancing to
    next Man
::
    _85-96_   Repeat with next 3 Men working clockwise round to return
    to partner
97-104::
    All promenade clockwise round back to place
105-112::
    2s+4s dance Men''s Chain
113-120::
    1s+3s dance Men''s Chain
121-128::
    All circle 8H round to right & back', 0);
INSERT INTO 'dancecrib' VALUES (9408, '2016-10-06 07:18:54.304808+00', '2023-02-04 01:22:23.898401+00', 17144, 3, NULL, 'ace', '1-4::
    1s turn 1.1/4 LH moving down to 2nd place facing Men''s side, 1L on
    1M''s Right (2s step up 3-4)
5-8::
    1L+2s RH across, 1M+3s LH across ending in centre, all Men behind
    partners, 2s & 3s facing Ladies'' side, 1s facing Men''s side
9-16::
    Couples in tandem dance reel of 3 (2s+1s pass RSh to start). 2s+3s
    finish on own sides, 1s on opp sides 1L facing out  2 (1) 3
17-20::
    _1/2_ reels of 3 on sides, 2M+1L & 2L+1M pass RSh to start
21-24::
    3s+1s+2s set, 1s cross RH
25-32::
    3s+1s+2s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15079, '2022-09-05 00:21:46.446082+00', '2023-02-04 01:22:23.920364+00', 20920, 3, NULL, 'ace', '1-8::
    1s+2s set, turn partners 2H once round, open out to circle 4H round
    to left
9-16::
    1s+2s dance »Shadow Progression«:
::
    1L+2M Adv (1 bar), 1/2 turn 2H (1 bar), 1L dances out thru 1M''s
    place, & dances clockwise 2 places as 2M dances out thru 2L''s place
    & clockwise 2 places _while_ 2L+1M cast 1 place up/down (2 bars) &
    then follow what 1L / 2M danced (but 2 bars behind them) to end 2 1
    3
17-24::
    1s dance 1/2 Fig 8, 1M up between 2s, 1L down between 3s, pass RSh
    in centre & dance 1/2 Fig 8 1M down between 3s, 1L up between 2s. 1s
    meet in centre facing down, 3s step in & face up ready for …
25-32::
    1s+3s dance Rondel.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7261, '2013-08-21 08:31:37.890637+00', '2023-02-04 01:22:23.95526+00', 7943, 3, NULL, 'ace', '1-8::
    1s & 5s cross RH (2s/4s step up/down), cast in 1 place & dance 1/2
    Fig of 8 round end couples
9-16::
    1L with 2s & 5M with 4s dance reels of 3 across _while_ 1M+5L dance
    reels of 4 across with 3s, 1s & 5s end facing 1st corners
17-24::
    1s & 5s turn 1st corners RH, partners LH, 2nd corners RH & 3/4 turn
    partner LH
25-32::
    1L with 2s & 5M with 4s dance RH across _while_ 1M+5L dance RH
    across with 3s, 1s & 5s swap to dance LH across with other couple &
    end in middle (Man above Lady)
33-40::
    1s+5s dance 1/2 reels of 4 up/down middle, 5s turn 1.1/4 times to
    sides _while_ 1M+3M also 1L+3L turn 1.3/4 times to end 2 5 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (7262, '2013-08-21 08:31:37.898625+00', '2023-02-04 01:22:23.984762+00', 6018, 3, NULL, 'ace', '1-8::
    1s set, cross RH, set, turn LH moving down & face 1st corners
9-16::
    1s turn 1st corners RH pass RSh to dance LH across with 2s+3s on own
    sides & pass LSh to face 2nd corners
17-24::
    1s turn 2nd corners RH pass RSh to dance LH across 1L with 2s & 1M
    with 3s, pass LSh to face out between 2s & 3s on own sides
25-32::
    1s dance full Figs of 8 on own sides dancing round 3rd corner to
    start _while_ 2s+3s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (14297, '2021-09-08 00:21:42.199491+00', '2023-02-04 01:22:24.016515+00', 20356, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd place)
9-16::
    2s+1s+3s circle 6H round (4 bars); drop hands, pull back LSh & chase
    anticlockwise back to place. 1s end slightly in from sidelines
    facing 1st corners
17-24::
    1s set to & turn 1st corner, set to & turn 2nd corner finishing
    between corners
25-32::
    1L dances up & casts to 2nd place own side _while_ 1M dances down &
    casts up round 3s to 2nd place; 2s+1s+3s turn partner 2H', 0);
INSERT INTO 'dancecrib' VALUES (7263, '2013-08-21 08:31:37.906647+00', '2023-02-04 01:22:24.043386+00', 7513, 3, NULL, 'ace', '1-8::
    All set, 1s & 4s cast in 1 place & dance RH across
9-16::
    All set, 2s & 3s cast in 1 place & dance LH across
17-24::
    All dance RSh reels of 4 on sides
25-32::
    All Adv+Ret, 1s cast to bottom _while_ others set & step up', 0);
INSERT INTO 'dancecrib' VALUES (7264, '2013-08-21 08:31:37.914761+00', '2023-02-04 01:22:24.066967+00', 6020, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s circle 4H round to left, 3s followed by 1s lead
    down to bottom & cast up own side (3s to 1st place & 1s to 3rd
    place)
9-16::
    All dance reflection reels of 4 on own sides (RSh on Men''s side &
    LSh on Ladies side)
17-24::
    3s & 1s dance full Figs of 8 round couple below them
25-32::
    3s+2s also 1s+4s dance 1/2 Diamond Poussette & all turn 2H.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (15426, '2023-02-04 01:22:24.096298+00', '2023-02-04 01:22:24.09771+00', 20929, 3, NULL, 'ace', '1-8::
    1s set, dance down between 2s, cast down behind 3s, dance up the
    middle (1L in front of 1M) to face 2M (Ladies'' 1st corner) (2s step
    up 3-4)
9-16::
    1s & 1st corners dance 1/2 Alternating Tandem diagonal LSh reel of
    3. Bar 12: 1M pulls LSh back & turns partner LH to face 2L (Man''s
    2nd corner) (1L behind 1M)
17-24::
    1s & 2nd corners dance 1/2 Alternating Tandem diagonal LSh reel of
    3. Bar 20: 1L pulls LSh back & turns partner LH to finish in 2nd
    place own sides.  3 1 2
25-32::
    1s dance diagonal R&L.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13439, '2020-12-02 01:21:41.788663+00', '2023-02-04 01:22:24.124897+00', 12516, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 2s+1s dance RH across
9-16::
    2s+1s circle 4H round & back
17-24::
    2s+1s Petronella in Tandem & set; repeat
25-32::
    1s+2s dance 1/2 R&L; 1s dance up, cross & cast to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (7265, '2013-08-21 08:31:37.922784+00', '2023-02-04 01:22:24.136394+00', 6025, 3, NULL, 'ace', '1-8::
    All dance 1/2 RSh reels of 4 on sides, 2s+1s set & dance 1/2 RH
    across.  4 3 (1) (2)
9-16::
    4s & 2s cast in 1 place to dance 1/2 Fig of 8 round 3s/1s & 4s+2s
    dance 1/2 LH across.  3 (2) 4 (1)
17-24::
    2s & 4s turn corner RH & 2s+4s dance 1/2 LH across, 2s & 4s turn
    corner RH & 2s+4s dance 1/2 LH across.  3 (2) 4 (1)
25-32::
    3s+2s dance 1/2 R&L, 3s & 1s turn 1.1/2 times.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7266, '2013-08-21 08:31:37.930949+00', '2023-02-04 01:22:24.149009+00', 13753, 3, NULL, 'ace', '1-8::
    1M+3L also 2M+4L 1/2 turn & twirl & dance out to change places,
    1L+3M also 2L+4M repeat.  (3)(4)(1)(2)
9-16::
    3s+4s (at top) also 1s+2s circle 4H round to left opening out into
    8H round to left 1/2 way.  2 1 4 3
17-24::
    1s+4s dance Alternating Tandem reels of 3 on own sides (Men LSh to
    2M, Ladies LSh to 3L)
25-32::
    1s+4s dance the Celtic Cross Progression:
::
    _25-28_  1M+4L turn RH as 1L+4M chase anticlockwise 1/2 way into a
    line of 4 across & 1/2 turn partner LH
::
    _29-32_  1L+4M 3/4 turn RH as 1M+4L chase 1/4 way anticlockwise into
    a line up/down middle & 3/4 turn partner LH to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15427, '2023-02-04 01:22:24.161078+00', '2023-02-04 01:22:24.161825+00', 19641, 3, NULL, 'ace', '1-8::
    1s cast 2 places, cross RH (2s step up); cast up to 2nd place & turn
    RH to face 1st corners
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh 1s dance
    1/2 diagonal reel with 2nd corners, pass RSh
17-24::
    1s dance 1/2 diagonal reel with 3rd corner (pstns), pass RSh, 1/2
    diagonal reel with 4th corner (pstns) pass RSh to 2nd place own
    sides
25-32::
    1L+2s also 1M+3s dance RH across; 1s turn RH & face out to repeat
    (or dance to bottom as new top couple begin)', 0);
INSERT INTO 'dancecrib' VALUES (7267, '2013-08-21 08:31:37.939006+00', '2023-02-04 01:22:24.174261+00', 6029, 3, NULL, 'ace', '1-8::
    1s set twice to 2L & circle 3H round to left
9-16::
    1s+2L set twice to 2M & circle 4H round to left
17-24::
    1s followed by 2s & 3s lead down; cross below 3rd place & cast up on
    opposite sides
25-32::
    All set; 1s cast _while_ 2s dance up & 3s set; 2s+1s+3s turn 2H
    1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (9768, '2017-04-06 09:57:53.499391+00', '2023-02-04 01:22:24.52313+00', 8155, 3, NULL, 'ace', '{{explanation}}
One circle, Lady on Man''s Right, all facing in. Walking step

1-4::
    All join hands, Advance (4 steps) & Retire (4 steps)
5-8::
    Repeat bars 1-4
9-12::
    Men Advance to centre (4 steps) & Retire to place
13-16::
    Ladies repeat bars 9-12 finishing in place, facing partner
17-24::
    Grand Chain (7 bars - 7 hands). Join hands in promenade hold with
    new partner
25-32::
    All promenade anticlockwise & open out to circle again', 0);
INSERT INTO 'dancecrib' VALUES (9928, '2017-06-05 11:31:44.903698+00', '2023-02-04 01:22:24.547594+00', 16493, 3, NULL, 'ace', '{{explanation}}
2 chords - on 2nd chord 3s & 4s cross to opp sides

1-8::
    Double-ended Snowball (Pickup) Chain, 1s & 4s cross RH with partners
    to start.  End Men facing out  4 (2) 3 (1)
9-16::
    4s+2s also 3s+1s dance Ladies'' Chain. Men face out
17-20::
    4M & 1M followed by partners, chase anticlockwise 1/2 round _while_
    2s+3s dance RH across.  Men face out
21-24::
    1s+2s also 3s+4s dance 1/2 LH across. 1s+4s dance 1/2 RH across
25-28::
    4s+1s circle 4H round to left
29-32::
    4s+1s 1/2 turn partners RH, face, pull back RSh & dance out to
    sides.   2 4 (1) (3)

{{explanation}}
Repeat in Strathspey then twice in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (15080, '2022-09-05 00:21:47.135118+00', '2023-02-04 01:22:24.614776+00', 20910, 3, NULL, 'ace', '{{explanation}}
2 chords: 2nd chord 2s & 4s cross to opp side

1-8::
    1s+2s also 3s+4s Set & Rotate for 6 bars (set, cast 1 place round &
    change places RH with partner) & all set on sides.  Men''s side: 2M
    2L 4M 4L, Ladies'' side: 1L 1M 3L 3M
9-24::
    All dance Interlocking Ladies'' Chains:
::
    _9-12_    Ladies dance 1/2 RH across (Men dance into partner''s
    place), 1L+4M, 2L+3M, 3L+2M & 4L+1M turn LH
::
    _13-16_ 1/2 Ladies'' Chain across: 1L+2L also 3L+4L change places RH
    (Men dance into place beside them) Ladies turn Man they meet
::
    _17-24_  Repeat bars 9-16 back to position at bar 8
25-32::
    All join hands on side, set & circle 8H 1/2 round, Bars 31-32:
    Ladies set _while_ 1M+2M also 3M+4M change places RH
33-40::
    4s+3s+2s dance Circulating Knot:
::
    _33-34_     All turn RH into allemande hold, 4s+2s face down, 3s
    face up
::
    _35-37_     All dance 1/2 way round set (4s+3s start to Right, 2s
    curve to Left) Bar 29:- all release Right hands
::
    _30-32_     Men pass partners in front & all continue LH turn to
    sides.   End 2 (3) 4 (1)', 0);
INSERT INTO 'dancecrib' VALUES (7270, '2013-08-21 08:31:38.228577+00', '2023-02-04 01:22:24.638297+00', 13502, 3, NULL, 'ace', '1-8::
    1s set & cross RH, 1s+2s change places LH on sides & set facing
    down/up
9-16::
    2s+1s dance Ladies'' Chain
17-24::
    1s lead down (2 steps) & back up above 2s, cross & cast 1 place
25-32::
    2s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7271, '2013-08-21 08:31:38.236649+00', '2023-02-04 01:22:24.657526+00', 6035, 3, NULL, 'ace', '1-8::
    1s+3s dance 1/2 Ladies'' Chain (polite turn for M at end), 1s+3s turn
    partner RH to end with 1s facing 2s & 3s facing 4s
9-16::
    Reels of 4 across set
17-24::
    All set & change places RH with person facing, 1s & 3s set to
    partner & change places RH _while_ 2s & 4s dance 1/4 way round set
    clockwise
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7272, '2013-08-21 08:31:38.24642+00', '2023-02-04 01:22:24.797535+00', 6036, 3, NULL, 'ace', '1-8::
    1s lead down 1 place & turn LH as 2s make an arch & dance up, 1s
    lead down to 3rd place & turn LH as 3s make an arch & dance up
9-16::
    1s lead up 1 place & turn LH as 3s make an arch & dance down, 1s
    lead up to top & turn LH as 2s make an arch & dance down
17-24::
    1s cast below 3s & lead up to top
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7273, '2013-08-21 08:31:38.256352+00', '2023-02-04 01:22:24.989494+00', 6037, 3, NULL, 'ace', '{{explanation}}
Line of three ‑ Man between 2 Ladies

1‑8::
    All turn right about to face the opp direction, dance away for 4
    steps, turn right about to face the other way & dance forward for 4
    steps
9‑16::
    All set (e.g. »Rocking Step«) for 8 bars
17‑24::
    Dance the "Shepherd''s Crook" ‑ Lady on the Man''s right dances round
    under the arch made by Man & the other Lady, Man follows under the
    arch _while_ the other Lady turns under her own right arm. Repeat
    with Lady on the Man''s left leading
25‑40::
    Man sets HS (starting left foot) with Lady on right (ballroom hold)
    & turns her RH. Man repeats with Lady on left
41‑48::
    All dance a reel of 3 ‑ Man starts by passing LSh with Lady on right
49‑56::
    All facing the top set (e.g. »Crossover« [Huntly] step) for 8 bars
57‑64::
    All circle round left for 4 bars & back to right ending in line
    across facing the top
65‑72::
    All dance the final step of the ''Highland Fling''. Bar 68: M turns
    Right about, Ladies pivot right about. Bars 71-72: M dances double L
    turn about, Ladies turn L about with 4 walking steps.', 0);
INSERT INTO 'dancecrib' VALUES (12559, '2020-02-02 02:49:33.378489+00', '2023-02-04 01:22:25.128763+00', 18597, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s+4s cross to opp side

1-8::
    1s+4s set, cast down/up 1 place (2s+3s step up/down). 1s+4s in prom
    hold dance out of ends (1s up, 4s down) & cast right. 1s end in 2L''s
    place facing down, 4s in 3M''s place facing up
9-16::
    4s (prom hold)+2s also 1s (prom hold)+3s dance 1/2 RSh reels of 3
    across; 1s+4s pass RSh to repeat 1/2 RSh reels at other end (1s up,
    4s down). 1s & 4s finish side-by-side with partner, (Lady on Man''s
    right) [Men''s side 2 4 (4) (3): Ladies''s side 2 1 (1) (3)]
17-24::
    1s+4s set, dance 1/2 RH across; 1M+4M set advancing & change places
    RH _while_ 1L+4L Adv+Ret
25-32::
    All 4 couples circle 8H round & back.  End 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (14589, '2022-02-05 02:21:33.640333+00', '2023-02-04 01:22:25.154568+00', 20616, 3, NULL, 'ace', '1-8::
    1L+2M change places RH, 1s+2s circle 4H 1/2 round to left; 1M+2L
    change places RH, 1s+2s circle 4H 1/2 round to left.  (2) (1) 3
9-16::
    1s followed by 2s dance down middle, 2s followed by 1s dance back
    up, couples crossing back to own side. 2 1 3
17-24::
    2s+1s+3s join hands on sides, set & cross RH; set & cross RH
25-32::
    2L+1L also 1M+3M Set+Link; 1L+2L also 3M+1M Set+Link.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4171, '2013-08-21 08:30:44.803222+00', '2023-02-04 01:18:38.077031+00', 9170, 3, NULL, 'ace', '1-8::
    All set, turn partner 2H twice round & all set
9-16::
    2s & 4s dance RH across (L up & M down to give wheels of 3, 4 & 3),
    2s & 4s change wheels for LH back
17-24::
    1s dance Fig of 8 round 2s _while_ 3s dance round 4s, 1s+2s also
    3s+4s end ready for Poussette
25-32::
    1s+2s also 3s+4s dance 1/2 Diamond Poussette, 1s+4s also 3s+5s dance
    1/2 Poussette.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (7274, '2013-08-21 08:31:38.264597+00', '2023-02-04 01:22:25.18315+00', 6044, 3, NULL, 'ace', '1-8::
    1s petronella turn & set as 2s move up & set, 1s+2s RH across 1s end
    BtoB facing 2s
9-16::
    1s+2s dance reel of 4 across 1s end passing RSh to face out on
    opposite sides (1s in 2nd place & 2s in 1st place)
17-20::
    1s+3s 1/2 turn on sides with nearer hand to change places, 1s dance
    round each other LSh to face out opposite sides (1s in 3rd pl)
21-24::
    1s+4s 1/2 turn on sides with nearer hand to change places, 1s cross
    RH to 4th place own sides
25-32::
    4s+1s dance Double Fig of 8 (4s in & down to start)', 0);
INSERT INTO 'dancecrib' VALUES (8631, '2015-02-13 12:48:14.656606+00', '2023-02-04 01:22:25.212107+00', 14025, 3, NULL, 'ace', '1-8::
    1s dance down between 2s, cast back to places.  1s dance 1/2 Fig. 8
    round 2s
9-16::
    1s+2s+3s dance mirror (reflection) reels of 3 on sides (1s cross to
    2nd place own sides to begin, 2s out & up, 3s in & up).  2s finish
    facing out
17-20::
    1s+2s change places on sides (Men RH, Ladies LH), 1s+3s turn on
    sides (Men LH, Ladies RH) 1s ending in middle facing up, 3s in
    original places
21-24::
    1s dance up to top and cast to 2nd place
25-32::
    2s+1s+3s Adv+Ret, all clap end bar 28.  2s+1s+3s turn partners RH
    once round', 0);
INSERT INTO 'dancecrib' VALUES (7275, '2013-08-21 08:31:38.27265+00', '2023-02-04 01:22:25.235362+00', 9403, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp sides

1-8::
    1s & 4s cross RH & cast in 1 place (2s & 3s step up/down); 1L+4M
    also 1M+4L turn RH 1.1/2 times into prom hold
9-16::
    1L+4M dance reel of 3 across with 3s (LSh to 3M) _while_ 1M+4L reel
    with 2s (LSh to 2M)
17-24::
    1L+4M & 1M+4L set advancing to partners, 1s face down & 4s face up,
    4s & 1s set to end couples & turn corners dancing between end
    couples
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12652, '2020-03-02 01:54:06.455979+00', '2023-02-04 01:22:25.281362+00', 6047, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance 1/2 Fig 8 (1L round 2s, 1M round
    3s) _while_ 2s+3s set & cross RH with partner. 2M & 3L face out
9-12::
    2M+3L chase clockwise 1/2 round _while_ 2L+1M & 1L+3M set & cross RH
    (diagonally to Right)
13-16::
    1M+1L chase anticlockwise 1/2 round _while_ 3L+3M & 2L+2M set &
    cross RH (diagonally to Left)
17-20::
    3M+2L chase clockwise 1/2 round _while_ 1L+2M & 3L+1M set & cross RH
    (diagonally to Right). 2 1 3
21-24::
    All turn partners RH into Allemande hold ready for …
25-32::
    All dance 3 couple Allemande.  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7277, '2013-08-21 08:31:38.288676+00', '2023-02-04 01:22:25.306457+00', 6048, 3, NULL, 'ace', '1-8::
    1s cross RH to double triangle position with 2s+3s & set, 1s cast up
    to top & dance down until they are between 2s & 3s
9-16::
    1L dances RH across with 2M+3M _while_ 1M dances LH across with
    2L+3L, 1s followed by 2s+3s dance down centre
17-24::
    3s followed by 2s+1s dance up & 3s+2s cast down to places, 1L dances
    LH across with 2M+3M _while_ 1M dances RH across with 2L+3L
25-32::
    1s dance up to top & cast down to 2nd place opposite side, 1s dance
    1/2 Fig of 8 around 2s to end in 2nd place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (14437, '2021-11-06 01:13:09.243071+00', '2023-02-04 01:22:25.331123+00', 15729, 3, NULL, 'ace', '1-8::
    1s+2s+3s turn partner RH; 1s cast, 2s step up bars 5-6 & face down
    _while_ 1s cross LH & face up, 2 (1) 3
9-16::
    1s+2s set & turn RH on the sidelines; 1s+3s set & turn LH on the
    sidelines.  1s end facing up 2 (1) 3
17-24::
    1s dance 6 bar RSh reels of 3 on opp sides. 1s cross RH _while_ 2s &
    3s dance in, all end in centre facing up in Promenade hold
25-32::
    2s+1s+3s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (15149, '2022-10-05 00:21:51.605668+00', '2023-02-04 01:22:25.36446+00', 21025, 3, NULL, 'ace', '1-4::
    1s dance in & cast 1 place, dance in to end facing each other in the
    middle,1L facing down, 1M facing up (2s step up 3-4)
5-8::
    1s set, pull back RSh, cast out to 2nd place own sides _while_ 2s+3s
    chase 1/2 way clockwise (3) 1 (2)
9-12::
    1M+3L & 1L+2M Set+Link. 3L & 2M finish facing out
13-14::
    1s dance round each other RSh _while_ 1st corners (3L & 2M) cast 1
    place clockwise (3L up, 2M down)
15-16::
    1s dance to 2nd place own sides _while_ 3L &2 M finish in the middle
    (3L in 1st place, 2M in 3rd place). Then 1s, 3L & 2M pull back RSh
    to face anti-clockwise (LSh to centre of set)
17-18::
    1s+1st corners set _while_ 2nd corner (3M & 2L) change places
    passing RSh to end facing out
19-20::
    1s+1st corners dance into centre passing LSh, curve out to next
    place round clockwise, pull RSh back to face anti-clockwise _while_
    2nd corners chase 1/4 way clockwise to next corner place
21-24::
    1s+1st corners & 2nd corners repeat bars 17-20 to finish 1s in 2nd
    place opposite sides, 2M in middle in 1st place facing down, 3L in
    middle in 3rd place facing up, 2L in 1st place own side & 3M in
    original place
25-28::
    2M+1s+3L set, 2M & 3L Petronella turn to own sides _while_ 1s
    Petronella turn into middle
29-32::
    1s set & Petronella turn to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4465, '2013-08-21 08:30:49.160639+00', '2023-02-04 01:22:25.394553+00', 13136, 3, NULL, 'ace', '1-8::
    1s+3s dance Double Fig of 8 round 2s
9-16::
    1s set, dance down middle, cast up round 3s into middle & dance up
    to places (face out) _while_ 2s stand for 2 bars, set, dance down
    middle & cast up round 3s to places _while_ 3s stand for 4 bars,
    set, dance into middle (face down) & cast back to places
17-24::
    1s+2s+3s dance reels of 3 on sides (1s out & down to start)
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (14438, '2021-11-06 01:13:09.272713+00', '2023-02-04 01:22:25.424502+00', 15730, 3, NULL, 'ace', '1-8::
    1s cast & dance 3/4 Fig 8 round 2s (who step up Bars 5-6). Bars 7-8
    1s cross LH to 2nd place own side
9-16::
    1s dance LSh reels of 3 across (1M+3M & 1L+2L pass LSh)
17-24::
    Grand Chain (2s cross, 1s+3s change place RH on side to start)
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7278, '2013-08-21 08:31:38.30457+00', '2023-02-04 01:22:25.446799+00', 6051, 3, NULL, 'ace', '1-2::
    1s & 3s cross down 1 place RH (1M/3M face down to next Lady & 1L/3L
    face up to Man above _while_ 2L faces 5M)
3-6::
    All set, 2L/5M stand as others 3/4 turn RH to lines across (1L
    b''tw''n 2s face down, 3M b''tw''n 5s face up, 1M+3L b''tw''n 4s)
7-8::
    Top & bottom lines set as centre 4 Bal-in-Line
9-16::
    1s & 3s turn to right & dance reels across (reels of 3 at ends &
    reel of 4 in middle), 1s & 3s end facing their 2nd corners (LSh to
    LSh)
17-24::
    1s & 3s set to 2nd corner & turn inwards to face partners 2nd crnr &
    set, rotate clockwise to face ptnrs 1st crnr & set & turn about to
    set to own 1st crnr
25-32::
    All dance RH across (1L with 2s, 1M+3L with 4s & 3M with 5s), 1s &
    3s turn partners LH & cast down 1 place', 0);
INSERT INTO 'dancecrib' VALUES (7279, '2013-08-21 08:31:38.314589+00', '2023-02-04 01:22:25.475376+00', 6052, 3, NULL, 'ace', '1-8::
    1s dance down the middle & back up on own sides
9-16::
    All dance a Grand Chain
17-24::
    1s+2s & 3s+4s set & dance RH across 1/2 way, set & dance LH across
    back to places, 1s facing down, 2s+3s+4s face up

{{title}}
Authentic version

25-32::
    1s make arch & dance down 1 place 2s dance under & up, repeat with
    3s then 4s then 4s+1s turn LH
33-40::
    1s & 4s lead up to top, 1s casting to 4th place & 4s casting to 3rd
    place

{{title}}
Popular variation

25-32::
    1s dance set advancing to right & in to 2nd place as 2s dance out to
    their right & up to 1st place, repeat with 3s then 4s, all turn RH
33-40::
    1s lead up to top followed by 4s+3s+2s (who start by dancing down to
    follow 1s) & cast back to places.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7280, '2013-08-21 08:31:38.347509+00', '2023-02-04 01:22:25.531764+00', 6053, 3, NULL, 'ace', '1-8::
    1s cast & turn RH, 2s cast & turn RH
9-16::
    1s lead up for 2 steps & back _while_ 2s lead down & back to face
    1s, 1L+2L also 1M+2M dance out on own side, turn inwards & dance
    back
17-24::
    1s+2s circle 4H round to Left, set to partners & 1s cast 1 place as
    2s step up
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (8361, '2014-07-29 12:59:28.685385+00', '2023-02-04 01:22:25.565828+00', 15035, 3, NULL, 'ace', '1-4::
    1s cross down RH to face 3s on diagonal (2 step up), 1s turn (1M+3L
    RH, 1L+3M LH) 3s end in 3rd place
5-8::
    1s lead up, cross RH to face 2s on diagonal. 1s turn 2s (1M+2M RH,
    1L+2L LH), 1s end 2nd place facing out. 2 1 3
9-16::
    1s dance reflection reels of 3 on the sides, men passing LSh, ladies
    passing RSh. At end 1s+3s continue reel to change places _while_ 2s
    set. 2 3 1
17-24::
    2s+3s+1s dance Grand Chain
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7281, '2013-08-21 08:31:38.356045+00', '2023-02-04 01:22:25.590979+00', 6055, 3, NULL, 'ace', '1-8::
    1s set, cross down RH & dance down behind 3s, meet & dance up to 2nd
    place opposite sides
9-16::
    2s+1s+3s dance reels of 3 on the sides (1s out & up to start}
17-24::
    2s+1s dance Ladies'' Chain
25-32::
    2L+1L 3/4 turn RH into diagonal line with partners (Ladies LH to
    partner''s RH), Ladies drop RH & advance PdB with partner into line
    up/down, set. Bar 28 Ladies loop round to left as Men loop round to
    right to face partners.  2s+1s turn 2H to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7282, '2013-08-21 08:31:38.36415+00', '2023-02-04 01:22:25.61452+00', 13352, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s set & cross RH, cast 1 place & set
9-16::
    2s+1s+3s set, Adv+Ret & set

{{title}}
Reel

17-24::
    1s 3/4 turn RH & dance reels of 3 across (1M with 2s, 1L with 3s) to
    end 2nd place own sides
25-32::
    2s+1s+3s (in circle formation) Adv+Ret & turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (7283, '2013-08-21 08:31:38.372131+00', '2023-02-04 01:22:25.637369+00', 6057, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 3rd place, 2s repeat
9-16::
    3s+1s+2s dance the Knot, 1s end facing 1st corners
17-24::
    1s set to 1st corners & dance by the right round each other to face
    2nd corners, 1s set to 2nd corners & dance round each other to 2nd
    place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12104, '2019-08-30 09:54:56.92305+00', '2023-02-04 01:22:25.661491+00', 19234, 3, NULL, 'ace', '1-8::
    1s+2s, 3s+4s & 5s+6s dance R&L
9-16::
    1s cast to 5th place & turn RH _while_ 2s dance down middle (4 bars)
    & back up to 1st place (3s+4s+5s step up 3-4)
17-24::
    Repeat 9-16 with 2s casting & 3s dancing down & up.  3 4 5 6 1 2
25-32::
    3s+4s, 5s+6s & 1s+2s dance RH across & LH across.', 0);
INSERT INTO 'dancecrib' VALUES (7284, '2013-08-21 08:31:38.380183+00', '2023-02-04 01:22:25.69512+00', 6058, 3, NULL, 'ace', '1-8::
    1s set, cast to 2nd place, set & cast back to top
9-16::
    1s dance down (1 step) & back to top, cast 1 place, set to 1st
    corners & set to 2nd corners
17-24::
    1s lead down below 3s, cross RH, cast up on own side, dance up to
    top & cast to 2nd places
25-32::
    1s+3s dance RH across, 2s+1s dance LH across
33-40::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7286, '2013-08-21 08:31:38.396516+00', '2023-02-04 01:22:25.750492+00', 10351, 3, NULL, 'ace', '1-8::
    Top 2 Men & bottom 2 Ladies change places RH _while_ 1L+3M set diag
    & all chase 1 place clockwise, 1s+2M also 3s+2L dance RH across
9-16::
    Top 2 Ladies side & bottom 2 Men''s change LH _while_ 1M+3L set diag
    & all chase 1 place anticl''wise, 1s+2L also 3s+2M dance LH across
17-24::
    All set, circle 6H round to left & set (all in original places)
25-32::
    1s & 2s turn partner RH & face up, 1s cast as 2s dance to top, 1s &
    3s turn partner RH & face down, 1s dance down as 3s cast to 2nd
    place', 0);
INSERT INTO 'dancecrib' VALUES (7287, '2013-08-21 08:31:38.406305+00', '2023-02-04 01:22:25.781762+00', 13690, 3, NULL, 'ace', '1-8::
    _1_ turn RH & cast 1 place, 2s+1s+3s set & 2s & 3s cross LH _while_
    1s turn LH to face 3rd corner pstn
9-16::
    1s dance Hello-Goodbye setting & 1s petronella turn to 2nd place
    opposite sides
17-24::
    1s dance 1/2 reels of 3 across (1L with 2s, 1M with 3s), 1s dance
    1/2 reels across with other couple
25-32::
    2s+1s+3s Set+Link for 3 twice
33-40::
    3s+1s+2s chase clockwise 1/2 way, all set & cross RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7288, '2013-08-21 08:31:38.414495+00', '2023-02-04 01:22:25.808477+00', 10681, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, 2s+1s+3s Set+Link for 3 once (note LH
    person dances to right & turns left about)
9-16::
    1s dance reels of 3 on own sides giving LSh to 4th corner (pstn) &
    1s end between 3s/2s
17-24::
    1s cross LH down/up, cast round 1st corner (pstn) to 2nd place
    opposite sides, 3s+1s+2s Set+Link for 3 once (variation as above)
25-32::
    1s dance reels of 3 on opposite sides giving LSH to 2nd corner & 1s
    pass RSh to 2nd place (or start to turn RH)', 0);
INSERT INTO 'dancecrib' VALUES (7289, '2013-08-21 08:31:38.424275+00', '2023-02-04 01:22:25.895821+00', 6061, 3, NULL, 'ace', '1-8::
    1s turn RH, turn LH
9-16::
    1s lead down the middle & back to top & 1s+2s form line up/down
    centre with Men BtoB
17-24::
    1s+2s set twice & turn partners 2H
25-32::
    1s+2s dance reel of 4 up/down middle
33-40::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (13594, '2021-01-28 23:37:44.480517+00', '2021-12-07 15:58:35.007642+00', 11693, 1, 202, 'ace', '1--::

  1c cross down into DTr position (2c up) | all set ; 1c dance RSh round 1cnrs to 2pl (2,1,3)

9--::

  All chase clw ½ (to 3x,1x,2x) ; all turn P RH. 1c face 1cnrs[pos]

17--::

  ½ Reel4 on 1diag, pass RSh ; ½ Reel4 on 2diag (2,1x,3)

25--::

  Reels3 across {6}, 1c LSh to 3cnrs | 1c pass RSh to 2pl (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (14298, '2021-09-08 00:21:43.87198+00', '2023-02-04 01:22:26.084765+00', 20216, 3, NULL, 'ace', '1-8::
    3s dance up & cast round 2s back to place; 2s dance up & cast round
    1s back to place
9-16::
    Reels of 3 on sides (1s out/down, 2s in/down to start). 1 2 3
17-20::
    1s dance out/up & curve in to middle, top place
21-24::
    1s+2s change places on sides (Ladies RH, Men LH), 1s+3s change
    places other hand
25-32::
    2s+3s+1s set twice; 2s turn partner RH _while_ 1s+3s turn RH on
    sides', 0);
INSERT INTO 'dancecrib' VALUES (12825, '2020-05-14 23:16:13.523748+00', '2023-02-04 01:22:26.202388+00', 19936, 3, NULL, 'ace', '1-8::
    All Set+Link, end Men facing out, Ladies in; All dance 4 bars of
    Schiehallion reel. Men face out.  2 3 4 1
9-16::
    All dance Double Ladies'' Chain (Ladies dance 1/2 LH across in
    centre).
17-24::
    1s & 3s continue to turn 3/4 RH (2 bars), 1L+3L dance clockwise 1/2
    round set _while_ 1M+3M turn 1.1/2 LH in centre (4 bars), 1s & 3s
    turn partner 3/4 RH to sides (Lady on Man''s right).  2 1 4 3
25-32::
    2s & 4s turn partner 3/4 LH (2 bars), 2M+4M  dance anticlockwise 1/2
    round set _while_ 2L+4L turn 1.1/2 RH in centre (4 bars), 2s & 4s
    turn partner 3/4 LH to sides (Lady on Man''s right). End 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (4172, '2013-08-21 08:30:44.814126+00', '2023-02-04 01:18:38.099837+00', 13149, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s dance 1/2 Fig of 8 (1M round 2s, 1L round
    3s)
9-16::
    2s+1s+3s set & 1s cross passing RSh, 2M+1M also 1L+3L turn RH 1.1/2
    times on sides
17-24::
    1s+2s+3s dance 3 couple Bourrel:
::
    _17-20_   1M+3L also 2M+1L set advcg & 3/4 turn 2H to line up/down
    middle then 1/2 turn single to face own prtnrs as 3M & 2L chase
    anticl''wise to face them
::
    _21-24_   All set & turn 2H to own sides.  3 1 2
25-32::
    All chase clockwise 1/2 way, all 1/2 turn partners RH & twirl to
    places.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15150, '2022-10-05 00:21:52.014592+00', '2023-02-04 01:22:26.221839+00', 20788, 3, NULL, 'ace', '1-8::
    2s+3s dance RH across finishing BtoB on sides, 3s face down, 2s face
    up; all set, 1s+2s also 3s+4s change places RH on sides
9-16::
    All dance RSh reels of 4 on sides.  2 1 4 3
17-24::
    1s+4s dance the Chain Progression:
::
    1s+4s 3/4 turn RH, 1M+4L turn LH 1.1/2 times as partners chase
    clockwise 1/2 way, 4s+1s turn partner 3/4 RH to sides
25-32::
    4s set & cast to 4th place _while_ 3s set & dance up to 2nd place;
    1s+4s Set+Link to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (15356, '2022-12-19 01:21:58.059299+00', '2023-02-04 01:22:26.24372+00', 21184, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate. (Set, rotate singly & dance on 1 pl clockkwise,
    change places RH on sides & dance on 1 place to own sides)  2 1 3
9-16::
    1s+3s Set & Rotate. (Set, rotate singly & dance on 1 pl clockkwise,
    change places RH on sides & dance on 1 place to own sides)  2 3 1
17-24::
    2s+3s+1s dance RSh reels of 3 on sides, 3M+1M & 3L+1L pass RSh to
    begin.
25-28::
    1M followed by 1L casts up 1 place and crosses to opp side (3s step
    down 27-28)  2 (1) 3
29-32::
    1s turn 2H 1.1/2 to own sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14684, '2022-03-07 02:21:41.193028+00', '2023-02-04 01:22:26.272208+00', 16612, 3, NULL, 'ace', '1-4::
    All Men dance RSh round the next Lady on their right to finish in
    her partner''s place. (1M round 3rd Lady, 2M round 1st Lady, 3M round
    2L)
5-8::
    All Men repeat bars 1-4 to finish 1M in 2M''s place, 2M in 3M''s
    place, 3M in 1M''s place
9-16::
    All face new partner & dance Interlocking reels, passing new partner
    RSh. At end all turn 3/4 RH to finish Men facing in & Ladies out
17-18::
    Men dance 2/3 LH across _while_ Ladies dance clockwise 1 place to
    meet new partner.
19-20::
    All turn new partner RH (1M turning 2L in 1st place, 2M & 3L in 2nd
    place, 3M & 1L in 3rd place)
21-24::
    All repeat bars 17-20 to finish 1M & 2L in 1st place, 2M & 3L in 2nd
    place, 3M & 1L in 3rd place
25-32::
    All dance 6H round & back

{{explanation}}
Repeat twice more to bring each couple back to original place with their original partner', 0);
INSERT INTO 'dancecrib' VALUES (7291, '2013-08-21 08:31:38.448133+00', '2023-02-04 01:22:26.299054+00', 9334, 3, NULL, 'ace', '1-8::
    1M+2L 1/2 turn RH & cast to right (1M round 2M, 2L round 1L) back to
    places, 1L+2M 1/2 turn LH & cast left (1L round 2L, 2M round 1M) to
    places
9-16::
    1s+2s dance the Bourrel :
::
    1M+2L set advancing, 3/4 turn 2H & turn right about to end BtoB
    (Lady facing up, Man down) _while_ prtnrs chase anticl''wise 1/2 way,
::
    set to partners & turn RH to own sides facing out.   2 1 3
17-24::
    1s dance reels of 3 on sides giving RSh to person on their right, 1s
    end side by side facing 1st corners
25-32::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners 1s end passing RSh to 2nd pl on own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (14685, '2022-03-07 02:21:41.21899+00', '2023-02-04 01:22:26.332948+00', 16611, 3, NULL, 'ace', '1-4::
    All set. 1s turn 2H moving into middle of triangle _while_ 2s turn
    LH & 3s turn RH
5-8::
    1M+2s dance LH across _while_ 1L+3s dance RH across. All finish in
    promenade hold
9-16::
    1s+2s+3s dance reel of 3 (1L & 3L pass RSh to start) 2s & 3s finish
    in original places while1s finish in the middle facing down
17-22::
    1s dance down, separate, 1L dances behind 3s & 1M dances behind 2s
    back to place
23-24::
    All turn RH to finish shoulder to shoulder Men facing in & Ladies
    facing out
25-32::
    All dance 8 Bar Schiehallion reels to finish 1s in 2nd place, 2s in
    3rd place & 3s in 1st place.  3 1 2
33-34::
    All set
35-36::
    All turn partner 2H
37-38::
    All dance 6H round 1 place to left.  2 3 1
39-40::
    All turn 2H.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7292, '2013-08-21 08:31:38.45803+00', '2023-02-04 01:22:26.368799+00', 10470, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 1s turn 2H 1.1/2 times to face 1st corners
9-24::
    1s dance Corner Chain with 1st & 2nd corners :
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end turning LH to end 1M
    between 2s facing down & 1L between 3s facing up
25-32::
    All 3 couples Adv+Ret 2 steps & 1s turn 2H to 2nd place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (7293, '2013-08-21 08:31:38.466203+00', '2023-02-04 01:22:26.396978+00', 10445, 3, NULL, 'ace', '1-8::
    2s dance 1/2 diag reel with 1st corners, pass RSh & 1/2 reel with
    2nd crnrs, pass LSh to end BtoB (2M facing up, 2L down in double
    triangle position)
9-12::
    3s+2s+1s set (as in Double Triangles), 2s dance up/down & turn right
    about to face in _while_ 3s & 1s dance in & turn right about to face
    up/down
13-16::
    3s+2s+1s set (Inverted Triangle formation), 2s dance in _while_ 3s &
    1s dance out all turning R about for RH across
17-20::
    2s dance RH across (2M with 3s & 2L with 1s) 2s end in 2nd place.
    (3)(2)(1)
21-24::
    All set, 3s+2s dance RH across 1/2 way _while_ 1s cross RH
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8633, '2015-02-13 12:48:14.84578+00', '2023-02-04 01:22:26.424747+00', 6073, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, set advancing, turn partners 2H 3/4 round (line
    up/down middle), and dance out to places, face clockwise
9-16::
    1M leading, all chase clockwise round finishing in middle with
    partner ready for…
17-24::
    1s+2s+3s promenade, 2s dance to top as 1s cast & meet in middle in
    2nd place taking prom. hold facing 2M
25-32::
    1s+2M+3L dance 1/2 diag. reel of 3 (1s pass 2M RSh), 1s+3M+2L dance
    1/2 diag. reel of 3 (1s pass 3M RSh)
33-40::
    1s dance out between 2M & 3M (ladies'' side), 1M cast up, 1L down to
    2nd place own sides _while_ 2s+3s dance 1/2 R&L.  2s+1s+3s turn RH.
    2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (4173, '2013-08-21 08:30:44.832956+00', '2023-02-04 01:18:38.249661+00', 410, 3, NULL, 'ace', '1-8::
    All Adv+Ret & cross over (Men making arches)
9-16::
    All Adv+Ret & cross (Ladies making the arches)
17-24::
    1s turn RH 1.1/2 times, turn 2s LH on sides, 1s turn RH in middle
25-32::
    1s turn 3s LH on sides, 1s turn RH in middle, 1s turn 4s LH on sides
    & 1s 1/2 turn RH in middle & form arch
33-40::
    2s followed by 3s & 4s, cast to bottom & lead up under arch to end 2
    3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12105, '2019-08-30 09:54:57.045008+00', '2023-02-04 01:22:26.444676+00', 19428, 3, NULL, 'ace', '1-4::
    1s+3s dance in & cast to 2nd/4th place (briefly touching hands). 2s
    & 4s step up bars 3-4
5-8::
    1s+3s dance 1/2 Fig 8 around the couple above them.  End facing down
    in 2nd/4th place on opposite sides. 2 (1) 4 (3) 5
9-12::
    1s+3s turn the couple below them once round on the side (Ladies RH,
    Men LH)
13-16::
    1s+3s turn the couple above them once round on the side (Ladies RH,
    Men LH)
17-20::
    1s+3s dance 1/2 Fig 8 round the couple below, meet in middle facing
    up NHJ.
21-24::
    1s+3s dance up between the couple above them & cast down one place
    to end  in 2nd/4th place on own side. 2 1 4 3 5
25-28::
    1s+3s dance in & cast to 3rd/5th place (briefly touching hands). 4s
    & 5s step up bars 27-28
29-32::
    All 5 couples turn RH once round.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (7294, '2013-08-21 08:31:38.474171+00', '2023-02-04 01:22:26.461755+00', 8511, 3, NULL, 'ace', '{{explanation}}
5 couples in circle

1-8::
    All set to partners, dance Grand Chain 2 places set & dance Grand
    Chain 2 places (all now face person who was next to them originally)
9-16::
    All turn LH 1.1/4 times & Ladies dance RH across _while_ Men dance
    round anticlockwise all to original places
17-24::
    Holding nearer hands with partner Adv+Ret, advance 1 step drop
    hands, 1/2 turn RH & dance on 1 place clockwise
25-32::
    All circle 10H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7295, '2013-08-21 08:31:38.482254+00', '2023-02-04 01:22:26.493467+00', 6077, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s in prom hold dance reel of 3 across with 2s giving RSh to 2M, 2s
    dance into 1st place as 1s turn LH to face 1st corners
17-24::
    1s turn 1st corner RH, turn partner LH, turn 2nd corner RH, 1/2 turn
    partner LH to end 1L facing 2s & 1M facing 3s
25-32::
    1s dance RH across (Lady with 2s & Man with 3s), pass RSh & dance LH
    across with other couple', 0);
INSERT INTO 'dancecrib' VALUES (9237, '2016-06-16 22:42:18.947042+00', '2023-02-04 01:22:26.521852+00', 16891, 3, NULL, 'ace', '{{explanation}}
2s & 5s are dancing couples (representing "25")

1-8::
    2s dance 1/2 Fig of 8 round 1s _while_ 5s cross RH & cast up 1
    place, 2s & 5s turn LH to face 2nd corners (4s step down 3-4)
9-16::
    2s & 5s dance reels of 4 with 2nd corners, pass RSh to face 1st
    corners
17-24::
    2s & 5s dance reels of 4 with 1st corners, pass RSh to face 4th
    corners
25-32::
    2s & 5s dance Pass+Turn with 4th Corners, 2s & 5s twirl to face 3rd
    corners & dance Pass+Turn with 3rd corners
33-34::
    2s & 5s turn ptnrs RH to end in middle facing up on opp sides
35-40::
    2s followed by 5s lead up crossing at top & cast 2s to 3rd place &
    5s cast to 1st place & all set.  5 1 2 3 4', 0);
INSERT INTO 'dancecrib' VALUES (7296, '2013-08-21 08:31:38.514834+00', '2023-02-04 01:22:26.547583+00', 6081, 3, NULL, 'ace', '1-8::
    All cross RH & set, 1s & 3s turn 2H, open out to face down & turn
    next couple (pass between them & end with 2s & 4s facing out)
9-16::
    1s +2s & 3s+4s dance double Fig of 8
17-24::
    1s lead down the middle in Allemande hold followed by 2s, 3s & 4s,
    cross over at bottom & dance up to original places
25-32::
    1s cross RH, cast 1 place, cross LH & cast to bottom', 0);
INSERT INTO 'dancecrib' VALUES (7297, '2013-08-21 08:31:38.522874+00', '2023-02-04 01:22:26.567855+00', 7517, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, set & cross back RH
9-16::
    1s+2s+3s circle 6H round & back, 1s & 3s remaining in the middle
    facing up/down
17-24::
    1s+3s dance 3/4 R&L, 1s cast to 2nd place opposite sides as 3s cross
    over LH
25-32::
    1s dance 1/2 Fig of 8 round 3s, 1s followed by 3s dance up between
    2s & cast, 1s to 3rd place & 3s to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (7298, '2013-08-21 08:31:38.531281+00', '2023-02-04 01:22:26.595555+00', 13138, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 double Fig of 8  (1s & 3s cross down to
    start), all set & turn partner 2H
9-16::
    1s+2s also 3s+4s dance 1/2 diamond Poussette, 1s+4s dance 1/2
    diamond Poussette.  2 4 1 3
17-24::
    2s+4s also 1s+3s circle 4H round to left, 2s+4s also 1s+3s set
    facing up/down & turn other person (Ladies LH & Men RH)
25-32::
    All dance reflection reels of 4 on sides (2s & 1s dancing in & down
    to start)', 0);
INSERT INTO 'dancecrib' VALUES (7299, '2013-08-21 08:31:38.539394+00', '2023-02-04 01:22:26.620089+00', 9898, 3, NULL, 'ace', '1-8::
    1s+3s dance Progressive Fig 8: 1s cross RH, cast to 3rd place, cross
    up & cast to 3rd place _while_ 3s set cross up to 1st place opp
    sides, cast to 3rd place & cross up to 1st place own side facing out
9-16::
    3s (at top) cast 1 place, dance down the middle, set & lead up LH to
    face 1st corners (pstn)
17-24::
    Set to corners, dance round each other RSh to face 2nd corners, set
    & dance round each other to 2nd place own sides
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7300, '2013-08-21 08:31:38.54748+00', '2023-02-04 01:22:26.650896+00', 8836, 3, NULL, 'ace', '1-8::
    1s & 3s set, 3/4 turn RH & dance 1/2 reel of 4 up/down middle end on
    own sides.  3 2 1
9-16::
    3s+2s+1s dance reels of 3 on sides (2s give LSh to person on left to
    start)
17-24::
    3s & 1s set, 3/4 turn & dance 1/2 reel of 4 in middle end on own
    sides.  1 2 3
25-32::
    1s+2s+3s dance reel of 3 on sides (2s give LSh to person on left to
    start)
33-40::
    1s lead down the middle & back to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (12941, '2020-07-01 00:21:26.646931+00', '2023-02-04 01:22:26.679716+00', 17605, 3, NULL, 'ace', '1-8::
    1s+3s set, cast off (2s & 4s step up); All turn partner RH.  2 1 4 3
    5
9-16::
    1s+4s also 3s+5s Set+Link; 4s+1s also 5s+3s dance RH across. 2 4 1 5
    3
17-24::
    4s+1s+5s+3s dance RSh reels of 4 on sides
25-32::
    All circle 10H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13769, '2021-03-02 01:21:50.360685+00', '2023-02-04 01:22:26.704338+00', 12355, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig of 8 (1s cross down to start)
9-16::
    1s followed by 2s dance down for 4 bars, turn inwards & 2s followed
    by 1s dance up, 2s curve out to finish in top place facing down, 1s
    finish in centre in 2nd place
17-24::
    1L dances RH across with 2L+3L _while_ 1M dances LH across with
    2M+3M; 1s NHJ dance up to & cast to 2nd place
25-32::
    1s dance 6 bar reel of 3 on the sides dancing in & down to start,
    2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (7301, '2013-08-21 08:31:38.616166+00', '2023-02-04 01:22:26.860648+00', 6085, 3, NULL, 'ace', '1-8::
    All set HS, 1s+2s also 3s+4s dance R&L (1 bar per hand)
9-16::
    All dance RSh reels of 4 on sides
17-24::
    All Petronella to opposite sides
25-32::
    1s+2s Petronella to own sides
33-48::
    All set, all set advancing for special Allemande, 1s+2s Allemande up
    _while_ 3s+4s Allemande down - 2s end normally in 1st place - 1s &
    4s pass RSh (to change places) 1s & 3s crossing to own sides, 4s+1s
    circle 4H round to left
49-56::
    4s+1s dance RH across 1/2 way, 2s+1s also 4s+3s dance LH across 1/2
    way, 2s & 3s cross RH to own sides & all set
57-64::
    All dance 8H round & back
65-80::
    Repeat bars 1-16
81-96::
    All Petronella all Round', 0);
INSERT INTO 'dancecrib' VALUES (7302, '2013-08-21 08:31:38.625181+00', '2023-02-04 01:22:26.895377+00', 8524, 3, NULL, 'ace', '1-8::
    1s cross down RH & cast behind 3s, dance up between 3s & cast up
    behind 2s to 1st place opposite sides
9-16::
    1s & 2s turn partners RH 1.1/4 times to end in centre with Men BtoB
    for 1/2 reel of 4 in centre _while_ 3s turn RH 1.1/4 times
17-24::
    1s+3s dance 1/2 reels of 4 _while_ 2s turn RH 1.1/4 times into top
    place on own side, 1s & 3s turn RH 1.1/4 times to own sides
25-32::
    2s+3s+1s circle 6H round & back.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7303, '2013-08-21 08:31:38.633557+00', '2023-02-04 01:22:26.940579+00', 9219, 3, NULL, 'ace', '1-8::
    All set & Petronella-in-tandem on 1 place to right & repeat to end
    on opposite sides
9-16::
    2s+4s dance RH across 1/2 way, turning to right dance back & turn
    into original place, 1s+3s dance 1/2 R&L retaining LH with partner
17-24::
    1M & 3M pass partners to the right, give RH to opposite Lady & lead
    out left through sides, cross & cast to opp place Repeat back to
    orig pl
25-32::
    1s & 3s prom hold dance RSh reels of 3 with corners (going to right
    to start), 1s & 3s end between side couples all facing out
33-40::
    All set HS (1M & 3M + crnrs start with left foot & change hands as
    they pass), all turn crnrs (1M+3M give LH & 1L+3L give RH) to face
    ptnr
41-48::
    Set & turn partners 2H, open up to 4H once round to left (1s with 4s
    & 3s with 2s)
49-56::
    Open out to 8H round to left, dancing for two steps, set for 2 &
    dance on for 4 steps
57-64::
    All Promenade anticlockwise back to original places
::
    Repeat dance with 2s & 4s leading, 2s+1s & 4s+3s dancing 4H round', 0);
INSERT INTO 'dancecrib' VALUES (7304, '2013-08-21 08:31:38.64347+00', '2023-02-04 01:22:26.974102+00', 6087, 3, NULL, 'ace', '{{explanation}}
 1st Figure

1-8::
    All petronella turn to end Men facing in & Ladies out, set & dance
    1/2 double RSh reels (giving LH in centre)
9-16::
    All set, petronella turn to face partner & dance 1/2 Grand Chain.
17-24::
    Men give RH in centre & LH to partner dance once round clockwise
    finishing with Men turning partners RH into place
25-32::
    All circle 8H round & back.

{{explanation}}
2nd Figure

33-48::
    Men pass LSh advancing to next Lady on right & turn RH, repeat with
    each Lady in turn, back to places.
49-64::
    Ladies repeat, passing RSh & advancing to next Man on left & turning
    LH, repeat with each Man in turn, back to places

{{explanation}}
3rd Figure

65-96::
    Repeat bars 1-32', 0);
INSERT INTO 'dancecrib' VALUES (9409, '2016-10-06 07:18:55.037875+00', '2023-02-04 01:22:26.996084+00', 17327, 3, NULL, 'ace', '1-8::
    1s lead down & turn 1.1/2 times RH to end 2nd place (in middle
    facing opp sides), 1s dance LH across (1L with 2M+3M, 1M with 2L+3L)
9-16::
    1s dance RH across with other side, 1s turn LH & cast left on own
    side to face 1st corners
17-24::
    1s dance reels of 3 across (1L with 2s, 1M with 3s) & end in
    diagonal line with 1st corners
25-32::
    1s dance the Spoke 3/4 way & turn LH into 2nd place own side
33-40::
    All circle 6H round to left for 4 steps & Ladies continue to circle
    left as Men circle to right (outside Ladies), all circle 6H round to
    right', 0);
INSERT INTO 'dancecrib' VALUES (7305, '2013-08-21 08:31:38.751695+00', '2023-02-04 01:22:27.024701+00', 12123, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, 1s dance 1/2 Fig of 8 round 2s
9-16::
    1s+2s change places on sides with nearer hand (1s dance between 2s),
    1s+3s change places with other hand, 2s+3s+1s dance 1/2 reel of 3 on
    sides (1s in & up to start)
17-24::
    1s lead down, 1/2 turn RH (Lady under Mans arm) & dance up to end
    with 1M facing 3M (at top Ladies side) with his partner behind him
25-32::
    1s dance diag Alternating Tandem 1/2 reel of 3 with 2nd corners  &
    Alternating Tandem 1/2 reel with 3rd crnrs', 0);
INSERT INTO 'dancecrib' VALUES (7306, '2013-08-21 08:31:38.762407+00', '2023-02-04 01:22:27.049791+00', 6490, 3, NULL, 'ace', '{{explanation}}
5 couple square set, 5s in centre facing 1s

1-8::
    5s dance RSh parallel reels of 3 with 1s+3s, 5s end facing 4s
9-16::
    5s with 4s+2s (each couple dancing as 1 person with 4L, 5M & 2M
    leading) dance Tandem LSh reel of 3.  5s end facing 1s
17-24::
    1s+5s dance 1/2 R&L, 1s+5s circle 4H round to left 1s ending in
    centre
25-32::
    1s turn RH & LH _while_ others circle 8H round 1/2 way, set, pull
    back RSh & chase 1 place clockwise. 1s (in centre) end facing 2s in
    top place', 0);
INSERT INTO 'dancecrib' VALUES (7307, '2013-08-21 08:31:38.7709+00', '2023-02-04 01:22:27.068412+00', 7944, 3, NULL, 'ace', '1-8::
    All Men dance LH across & dance RSh round partner back to places
9-16::
    All Ladies dance RH across & dance LSh round partner into centre for
    RH across with partner on left (St Andrews Cross)
17-24::
    All dance round for 2 bars, Ladies pass in front of partner to
    change places continuing forward for 2 bars, repeat to pstn level
    with orig pl
25-32::
    All dance Allemande clockwise back to places with Ladies in centre
    facing partners
33-40::
    All set, 1/2 turn RH, set & 3/4 turn back to original places
41-48::
    All dance interlocking reels of 3 with partner & corner
49-56::
    All Men dance in front of partner to next place anticlockwise,
    couples in 1st & 3rd places dance 1/2 R&L
57-64::
    All Ladies dance in front of "new" partner to next place clockwise
    to meet own partner, couples in 2nd & 4th places dance 1/2 R&L
65-72::
    All Ladies dance RH across & dance LSh round partner to places
73-80::
    All Men dance LH across & dance RSh round partner into centre for LH
    across with partner on right (St Andrews Cross)
81-88::
    Repeat bars 17-24 (anticlockwise)
89-96::
    All dance Allemande anticlockwise back to places ending with Ladies
    in centre facing partners', 0);
INSERT INTO 'dancecrib' VALUES (7309, '2013-08-21 08:31:38.787998+00', '2023-02-04 01:22:27.113551+00', 11487, 3, NULL, 'ace', '1-8::
    All set to partners & 3/4 turn RH, Ladies dance LH across & end in
    partners place _while_ Men dance clockwise 1/2 way to opp Lady''s
    place
9-16::
    All set to opp partner & 3/4 turn RH, Men dance LH across & end BtoB
    in centre facing own partner who has danced clockwise 1/2 way
17-24::
    Men dance ''Hello-Goodbye'' setting to end facing opp partner
25-32::
    All dance double reels of 4 giving LH in centre
33-40::
    All set HS to opp partner & 2H 1.1/2 times
41-48::
    Ladies dance ''Hello-Goodbye'' setting to end facing own partner
49-56::
    All set HS to own partner & 2H 1.1/4 times to original places
57-64::
    1s & 3s in prom hold dance RSh round couple to right, LSh round each
    other in centre back to places
65-72::
    2s & 4s repeat above figure
73-80::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7312, '2013-08-21 08:31:38.816749+00', '2023-02-04 01:22:27.207505+00', 11970, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, 3/4 turn LH  & cast to left to 2nd place
    own side
9-16::
    1s dance LSh Pass+Turn with 1st corners (cnrs also turn LH), turn LH
    & dance LSh Pass+Turn with 2nd cnrs & pass LSh to 2nd places
17-24::
    1s+3s Set+Link, 3M+2s (at top) also 3L+1s circle 3H round to left
25-32::
    2s+3s+1s dance reflection reels of 3 on own sides (3s out & up to
    start)', 0);
INSERT INTO 'dancecrib' VALUES (9174, '2016-06-16 22:41:29.296109+00', '2023-02-04 01:18:36.237651+00', 16856, 3, NULL, 'ace', '{{explanation}}
3s + 4s start on opp sides

1-4::
    1s+4s set, cast to 2nd/3rd place (2s+3s step down/up bars 3-4).
5-8::
    1s+4s dance 1/2 RH across, then take promenade hold, 1M+4L facing
    out on Men''s side & 4M+1L facing out on Ladies'' side
9-12::
    1M+4L (out/up) & 4M+1L (out/down) dance 1/2 RSh Diag reel of 3 with
    2M+3M then pass RSh in middle ready for...
13-16::
    1M+4L (pass 3L RSh) & 4M+1L (pass 2L RSh) to dance 1/2 RSh Diag reel
    of 3 with 2L+3L. End 4L facing up followed by 1M, 1L facing down
    followed by 4M in the middle
17-24::
    4L+1M pass 3L RSh (at top) also 1L+4M  pass 2L RSh (at bottom) to
    dance alternating tandem reels of 3 across. (Lead changes bar 19 &
    23). At end Ladies followed by Men dance down/up sides
25-28::
    _4_ Men dance 1/2 Diag R&L with 3M+4M & 1M+2M crossing RH to start
    (top 2 places Men''s side, bottom 2 places Ladies'' side)
29-32::
    _4_ Ladies dance 1/2 Diag R&L (top 2 places Ladies'' side, bottom 2
    places Men''s side)   End  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (7313, '2013-08-21 08:31:38.826608+00', '2023-02-04 01:22:27.228701+00', 11484, 3, NULL, 'ace', '1-8::
    1M also 3M set to 2L/4L & change places RH, 1L also 3L set to 2M/4M
    & change places RH
9-16::
    2s+1s also 4s+3s circle 4H to left ending 1s+3s facing up & 2s+4s
    facing down in middle, all Set+Link & end on sides
17-24::
    1s+4s (middle cpls) 3/4 turn 2H, dance 1/2 reel of 4 in middle & 3/4
    turn 2H to own sides.  2 4 1 3
25-32::
    2s & 3s cast in 1 place, dance RH across & all set
33-40::
    4s+2s (top cpls) also 3s+1s dance the Tournee :
::
    4s+2s also 3s+1s dance into prom hold (Men with prtnr on right,
    4s/3s face M''s side & 2s/1s L''s side), couples 1/2 wheel anticl''wise
    & Men turn Ladies into middle, both couples turn 1.1/2 times (2s/1s
    RH, 4s/3s LH) & dance out to places to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7314, '2013-08-21 08:31:38.834916+00', '2023-02-04 01:22:27.247808+00', 13456, 3, NULL, 'ace', '1-16::
    All Adv+Ret, Ladies dance RH across.  All Adv+Ret, Men dance LH
    across
17-24::
    1s+3s dance 1/2 Ladies'' Chain.  2s+4s dance 1/2 Ladies'' Chain
25-32::
    1s+3s dance 1/2 Men''s Chain.  2s+4s dance 1/2 Men''s Chain
33-36::
    Men petronella into centre to face partner & all set
37-40::
    All couples 3/4 turn 2H & Men dance on 1 place anticlockwise into
    centre to face out as Ladies dance on 1 place clockwise
41-48::
    All set & 3/4 turn 2H, Men dance on 1 place anticlockwise into
    centre to face out as Ladies dance on 1 pl clockwise to meet own
    prtnr & all 3/4 turn 2H
49-56::
    2s (prom hold) also 4s (prom hold) dance reels of 3 on sides (RSh to
    1M/1L)
57-64::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7315, '2013-08-21 08:31:38.845707+00', '2023-02-04 01:22:27.439872+00', 6094, 3, NULL, 'ace', '1‑8::
    1s & 5s advance diagonally to end  between 2s/4s, 1s+3s+5s set &
    circle 6H round to right
9‑16::
    2s+3s+4s dance reels of 3 on sides (2L+3L & 3M+4M pass LSh to start)
    _while_ 1s set to 5s & dance RH across & out to original places
17‑24::
    All set, 1s+2s also 3s+4s dance RH across 1/2 way _while_ 5s cross
    RH, all set, 2s cross LH _while_ 1s+4s & 3s+5s dance 1/2 LH across
    2 4 1 5 3
25‑32::
    1s dance Figs of 8 round 5s & 4s on own sides (in between 5s to
    start)', 0);
INSERT INTO 'dancecrib' VALUES (12744, '2020-04-11 10:53:02.666004+00', '2023-02-04 01:22:27.568791+00', 9659, 3, NULL, 'ace', '1-8::
    Ladies Adv to centre, turn right about to face partners & set;
    Ladies dance RH across and return to own places
9-16::
    Men repeat bars 1-8, but dance LH across
17-20::
    1s+3s Adv to centre NHJ, finish BtoB, facing sides with 1M+3L also
    3M+1L joining NH to set to side couples
21-24::
    1M+3L also 3M+1L NHJ turn side couples with free hand (2 steps),
    divide and dance to original places. Side couples meet partners in
    centre & dance to place NHJ
25-32::
    2s+4s repeat bars17-24
33-36::
    All face partner and set right only (Highland Schottische), and turn
    partner LH to face corner
37-40::
    All set left only (Highland Schottische), and turn corner RH to
    original places
41-48::
    All circle 8H round and back

{{explanation}}
Repeat in Reel time but coupé pas de basque (Right) or Left) instead of Highland Schottische.  Turns are skip change', 0);
INSERT INTO 'dancecrib' VALUES (13094, '2020-08-10 00:21:21.800188+00', '2023-02-04 01:22:27.604161+00', 6093, 3, NULL, 'ace', '1-8::
    1s cross down to dance reels of 3 on opp sides (2s out/up, 3s in/up
    to start)
9-16::
    1s+2s+3s set, pass partner RSh, pull back RSh remaining in centre
    facing partner; 2s+3s make arch & 1s lead down under arches & cast
    up into 3rd place facing up (2s+3s step up 15-16)
17-24::
    2s+3s+1s dance Grand Chain, 2s crossing to start (1 step each hand)
    to finish back in original places.1 2 3
25-32::
    1s turn 2s 1.1/2 times (Men RH, Ladies LH); 1s turn 3s 1.1/2 times
    (Men LH, Ladies RH).  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7318, '2013-08-21 08:31:38.869775+00', '2023-02-04 01:22:27.627963+00', 10759, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s dance RH across; 1s & 4s cast in 1 place (2s & 3s
    step down/up), 1M+4L also 1L+4M 3/4 turn LH into prom hold
9-16::
    1L+4M dance LSh reel of 3 across with 2s (LSh to 2M) _while_ 1M+4L
    dance LSh reel of 3 across with 3s (LSh to 3M)
17-24::
    1L+4M dance LSh reel of 3 on Ladies'' side (LSh to 3M) _while_ 1M &
    4L dance LSh reel of 3 on Men''s side (LSh to 2M)
25-32::
    1s+4s dance RH across & dance 1/2 R&L. 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (14916, '2022-06-27 00:21:55.223384+00', '2023-02-04 01:22:27.656343+00', 16463, 3, NULL, 'ace', '{{title}}
Part 1

1-8::
    All circle 8H round & back
9-16::
    Ladies cast behind partner, into centre & dance RH across 1.1/2
    times dancing out to opp Ladies'' place
17-24::
    Men cast behind partner, into centre & dance LH across 1.1/2 times
    dancing out to opp Man''s place, rejoining partner
25-32::
    1s+3s dance 1/2 R&L; 2s+4s dance 1/2 R&L

{{title}}
Part 2

1-8::
    All promenade anticlockwise back to place
9-16::
    All set & turn partner RH; all set & turn corner LH
17-20::
    Couples NHJ (Lady on Man''s right) face anticlockwise & dance 1 place
    round, Ladies turn under Man''s arm & couples face clockwise
21-24::
    All dance 2 places round clockwise & face partner.  4 1 2 3
25-28::
    All dance 1/2 Grand Chain.  2 3 4 1
29-32::
    All turn partner RH, face clockwise & Men followed by partners chase
    clockwise 1 place (back to original place)

{{title}}
Part 3

1-8::
    2s+4s dance 1/2 R&L; 1s+3s dance 1/2 R&L
9-16::
    Men cast behind partner, into centre & dance LH across 1.1/2 times
    dancing out to opp Man''s place
17-24::
    Ladies cast behind partner, into centre & dance RH across 1.1/2
    times dancing out to opp Ladies'' place, rejoining partner in
    original place
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9929, '2017-06-05 11:31:45.560756+00', '2023-02-04 01:22:27.703293+00', 16494, 3, NULL, 'ace', '{{explanation}}
2 chords - on 2nd chord 2s & 4s cross to opp sides

1-4::
    _1/2_ RSh reels of 4 on sides.  4M & 1M face out
5-8::
    4M dances down behind Ladies, across to 4M place as 1M dances up
    behind Men, across to 1L place _while_ other dancers set twice
9-12::
    _1/2_ RSh reels of 4 on sides.  1L & 4L face out
13-16::
    1L dances down behind Ladies, across to 4M place as 4L dances up
    behind Men, across to 1L place _while_ other dancers set twice
17-20::
    4s+2s also 3s+1s dance 1/2 Men''s Chain
21-24::
    4s & 2s chase clockwise 1 place at top _while_ 3s & 1s dance
    similarly at bottom.  All cross RH with partner
25-32::
    All circle 8H round and back.  End  2 (4) 1 (3)', 0);
INSERT INTO 'dancecrib' VALUES (14686, '2022-03-07 02:21:42.368378+00', '2023-02-04 01:22:27.733298+00', 20649, 3, NULL, 'ace', '1-8::
    All 4 couples Adv+Ret; 2s dance 1/2 Fig 8 up round 1s _while_ 3s
    dance 1/2 Fig 8 down round 4s
9-16::
    1s & 4s set, cast in 1 place (2s & 3s step up/down 11-12); 1s+4s
    dance 1/2 LH across to end all on opp sides, 2s & 1s facing down, 3s
    & 4s facing up & all set. (2) (4) (1) (3)
17-24::
    Reels of 4 on sides, 2s+4s & 1s+3s pass RSh to start
25-32::
    All couples set twice; all turn partner 1.1/2 RH to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7319, '2013-08-21 08:31:38.88308+00', '2023-02-04 01:22:27.750106+00', 9405, 3, NULL, 'ace', '1-8::
    All Ladies Advance (2 steps) & ladies set to partners (who set);
    Ladies clap & dance round partners RSh back to place
9-16::
    Men repeat bars 1- 8
17-24::
    All circle 8H round & back
25-32::
    1s lead down to bottom & turn RH (long turn) 2s+3s+4s step up 27-28', 0);
INSERT INTO 'dancecrib' VALUES (7320, '2013-08-21 08:31:38.891286+00', '2023-02-04 01:22:27.76606+00', 6098, 3, NULL, 'ace', '1-8::
    1M+2L set advancing, turn 2H, 1L+2M repeat
9-16::
    1s lead down, cross below 3s & cast up to 2nd place opposite sides
    dance R&L (1 bar per hand) to end facing 1st corners
17-24::
    1s set & turn 2H with 1st corners & 2nd corners ending in middle
    facing Ladies side Lady on Mans Left
25-28::
    1s dance out between 2L & 3L cast round nearest Lady to meet in the
    middle, turn 2H to end facing Men''s side Lady on Mans right
29-32::
    1s dance out between 2M & 3M cast round nearest Man to meet in the
    middle, turn LH to places', 0);
INSERT INTO 'dancecrib' VALUES (7321, '2013-08-21 08:31:38.899645+00', '2023-02-04 01:22:27.783556+00', 9111, 3, NULL, 'ace', '1-8::
    1M followed by partner weaves around set dancing between each couple
    beginning with 2s
9-16::
    All circle 8H round & back
17-32::
    2s repeat bars 1- 8, all circle 8H round & back
33-48::
    3s repeat bars 1- 8, all circle 8H round & back
49-64::
    4s repeat bars 1- 8 & all circle 8H round & back
65-72::
    1s+3s Adv+Ret for 2 steps, advance & change places RH
73-80::
    2s+4s repeat this Fig
81-96::
    All repeat bars 65-80 back to places
97-104::
    1s+3s advance for 2 steps, clap 3 times, retire & clap
105-112::
    2s+4s repeat this Fig
113-120::
    All joining hands advance for 2 steps, clap 3 times, retire & clap
121-128::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7322, '2013-08-21 08:31:38.907672+00', '2023-02-04 01:22:27.802591+00', 8566, 3, NULL, 'ace', '1-8::
    2s petronella turn to 2M between 3s, 2L between 1s. All set, 2s
    petronella to opp sides & all set
9-16::
    2s dance reels of 3 on sides giving RSh to 2nd corner, finish in 2nd
    place opp sides
17-24::
    2s dance reels of 3 across, LSh to 3rd corner (Lady down - Man up)
    2s finish in 2nd place opp sides
25-32::
    All circle 6H round to left 1/2 way, 3s+2s dance 1/2 RH across,
    2s+1s cross RH.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (12875, '2020-06-03 16:27:46.424612+00', '2023-02-04 01:22:27.823982+00', 13926, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s+2s dance 6 bars of R&L ending with 1s turning RH to
    face 1st corners
9-16::
    1s dance 4 bars ''Hello-Goodbye'' setting (set to 1st corners, set to
    partner); face 2nd corners & dance 1/2 diag RSh reel of 4. 1s pass
    LSh to face 3rd corners
17-24::
    1s dance 4 bars ''Hello-Goodbye'' setting (set to 3rd corners, set to
    partner); face 4th corners & dance 1/2 diag RSh reel of 4. 1s pass
    LSh to face 1st corners
25-32::
    1s+1st corners dance Corner Chain with setting:
::
    _25-28_   1s change places RH with 1st corners who turn LH in centre
    _while_ 1s set facing each other diagonally
::
    _29-32_   1s change places RH with 1st corners & 1s turn 3/4 LH to
    2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7323, '2013-08-21 08:31:38.915718+00', '2023-02-04 01:22:27.843387+00', 6101, 3, NULL, 'ace', '1-4::
    1s+2s+3s petronella turn into centre & set
5-8::
    1s+3s turn RH into line up/down middle (M face up) _while_ 2s turn
    RH 1.1/4 times to own sides
9-16::
    1s+3s dance reel of 4 & end in original places
17-24::
    2s dance RH across (2L with1s & 2M with 3s), 2s dance LH across with
    other couple
25-32::
    1s+2s dance 3/4 double Fig of 8  (2s cross up to start) & 1s cross
    RH _while_ 2 set turning about', 0);
INSERT INTO 'dancecrib' VALUES (7324, '2013-08-21 08:31:38.925462+00', '2023-02-04 01:22:27.869984+00', 11290, 3, NULL, 'ace', '1-8::
    1s set & 1M casts 1 place, 1s+2s set & 1s each cast 1 place
9-16::
    1s+3s set & 1s each cast 1 place, 1M sets advancing as 1L casts to
    bottom to meet partner in prom hold
17-32::
    1s dance 1/2 reel of 3 with 4s (LSh to 4M to start), 1/2 reels with
    3s, 1/2 reel with 2s & 1s cast to bottom _while_ 2s+3s+4s cross RH
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15239, '2022-11-03 01:21:48.925455+00', '2023-02-04 01:22:35.4735+00', 20433, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate. 2s face down, 1s face up
9-16::
    2s+1s+3s dance Grand Chain (3s cross, 2s+1s change place RH to
    start)
17-28::
    2s+1s+3s dance R&L for 3 couples
29-32::
    All turn partner 2H
33-40::
    1s+3s Set+Link; 3s+1s dance RH across.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13343, '2020-11-02 01:21:50.21578+00', '2023-02-04 01:22:27.914269+00', 15951, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s dance down (4 bars)
9-16::
    1s dance up to 2nd place in centre facing opp sides; 1M+2L+3L dance
    RH across _while_ 1L+2M+3M dance LH across. 1s face 1st corners
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh to dance
    1/2 reel with 2nd corners & pass RSh to 2nd place opp sides. (3) (1)
    (2)
25-28::
    1s cross RH & cast right into lines of 3 across _while_ 3s+2s set &
    cross RH
29-32::
    1s cross RH up/down & cast right into 2nd place own side _while_
    2s+3s set & cross RH.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13534, '2021-01-09 01:21:37.612708+00', '2023-02-04 01:22:27.957381+00', 19968, 3, NULL, 'ace', '{{explanation}}
3 dancers arranged in triangular set

1-8::
    Reel of 3, Dancer 1 passes 2 RSh to start
9-16::
    Dancers 1+3 Adv+Ret & turn RH; 1+2+3s dance RH across
17-24::
    Dancers 1+2 Adv+Ret & turn LH; 1+2+3 dance LH across
25-32::
    All Petronella turn 1 place & set; Petronella turn & set.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7326, '2013-08-21 08:31:38.941884+00', '2023-02-04 01:22:27.971088+00', 13517, 3, NULL, 'ace', '1-12::
    1L followed by 2L+3L+4L cross & cast behind 1M, in front of 2M+3M &
    behind 4M, cross & dance up to original places
13-16::
    1L & 3L turning right about & turn 2L & 4L RH (4 bars) _while_ 1M+2M
    & 3M+4M turn LH
17-28::
    4M followed by 3M+2M+1M cross & cast behind 4L, dance in front of
    3L+2L & behind 1L, cross & dancing down to places
29-32::
    2M & 4M turn left about & turn 1M & 3M LH _while_ 1L+2L & 3L+4L turn
    RH
33-40::
    1s lead down middle & turn RH (4 bars)ending in 4th place (2s+3s+4s
    step up on bars 35-36)
41-48::
    All circle 8H round & back (after last circle all with hands joined
    dance into centre with hands in the air & shout Hooray)', 0);
INSERT INTO 'dancecrib' VALUES (7327, '2013-08-21 08:31:38.949993+00', '2023-02-04 01:22:27.984165+00', 6112, 3, NULL, 'ace', '1-8::
    1M+2L turn 2H 1.1/2 times to end at top on opposite sides, 1s+2s
    turn LH 1.1/2 times on sides
9-16::
    1L+2L change places RH, 2s+1s Adv+Ret for 1 step diagonally, 1s
    dance 1/2 Fig 8 round 2s
17-20::
    1s cross RH, cast RSh round 1st corner to end 1L between 2s & 1M
    between 3s _while_ 2s+3s Adv+Ret & cross RH
21-24::
    1s change places RH & cast RSh round 2nd corner to 2nd place
    opposite sides, _while_ 2s+3s Adv+Ret & change places on sides RH
25-32::
    All chase clockwise to own sides, 2s+1s+3s advance to end in line
    up/down (RSh to partner) & face partner to turn 2H to own sides', 0);
INSERT INTO 'dancecrib' VALUES (7328, '2013-08-21 08:31:38.9581+00', '2023-02-04 01:22:27.995536+00', 6116, 3, NULL, 'ace', '1-8::
    1s lead down the middle for 2 steps, turn RH & lead back up to top
9-16::
    1L+2L+3L set diag to 2M+3M+4M & change places LH, top 3 dancers on
    Men''s side set to bottom 3 dancers on Ladies side & cross diag RH
17-24::
    All Men (at top) dance RH star & all Ladies LH star, continue stars
    as 1M then 234 take partners hand & lead down, 1s make arch at
    bottom
25-32::
    2s+3s+4s dance down under arch, divide & cast up on own sides (to 2
    3 4 1), 2s+3s & 4s+1s circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (7329, '2013-08-21 08:31:38.966104+00', '2023-02-04 01:22:28.011887+00', 10522, 3, NULL, 'ace', '1-8::
    1s & 4s dance 1/2 Figs of 8 round 2s/3s, 2s & 3s dance 1/2 Figs of 8
    round 1s/4s
9-16::
    All cross RH, set, 1s+2s also 3s+4s change places on sides LH & set
    facing on sides
17-24::
    All dance reels of 4 on sides
25-32::
    1s+4s+3s dance the Knot.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9410, '2016-10-06 07:18:55.262722+00', '2023-02-04 01:22:28.218088+00', 10708, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 on own sides round 2s & 3s (1s in/down to start)
9-16::
    1s+2s+3s dance DoSiDo with partner & turn partner RH
17-24::
    1s lead down middle and back remaining in middle, 2s step in ready
    for…
25-32::
    1s+2s dance poussette', 0);
INSERT INTO 'dancecrib' VALUES (10632, '2018-04-16 21:42:34.57583+00', '2023-02-04 01:22:28.293959+00', 12099, 3, NULL, 'ace', '{{explanation}}
Note:	This dance is a 6 couple version of "The Belle of Bon Accord" devised by John Drewry

1-8::
    1L, 3L & 5L cross down 1 pl & cast up on opp side into centre as 1M,
    3M & 5M dance across & cast down into centre; 1s+2s, 3s+4s, 5s+6s
    dance RH across
9-16::
    1s+3s+5s dance 1/2 reel of 6 up/down centre (6 bars), ending 5M 5L
    3M 3L 1M 1L (Men facing down, Ladies up).  5s+3s+1s pass partner RSh
    to end facing partner (Men facing up, Ladies down)
17-24::
    5s, 3s & 1s turn 3/4 RH to face up NHJ _while_ 2s, 4s & 6s dance up
    on sides & turn in to face down NHJ, all set; 2s+5s, 4s+3s, 6s+1s
    circle 4H round to Left to end 2 (5) 4 (3) 6 (1)
25-30::
    5s, 3s & 1s dance 1/2 Fig of 8 up round couples above & turn
    partners 2H
31-32::
    5s turn 2H _while_ 3s lead down to 6th place & 1s cast up to 4th
    place.  Oder:  2 5 4 1 6 3', 0);
INSERT INTO 'dancecrib' VALUES (8362, '2014-07-29 12:59:29.222577+00', '2023-02-04 01:22:28.328266+00', 14545, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s & 4s dance in & cast off 1 place, 1s RH 1/2 turn, Lady turning to
    left under Man''s arm & 1/2 turn RH back to original places _while_
    4s dance similarly LH
9-16::
    1M & 4M cast up/down into centre of set as 1L & 4L dance in NHJ,
    drop hands to face partners; 1s+2s+3s+4s set, 1s+2s also 3s+4s dance
    RH across
17-24::
    1s+4s dance reel of 4 up & down centre finishing on opposite sides
    2 (1) (4) 3
25-32::
    2s+1s also 4s+3s circle 4H round to Left; 4s dance 1/2 Fig 8 round
    3s 2 (1) 4 3

{{title}}
Reel

1-8::
    1s+4s dance double Fig 8, start 1s casting as 4s cross up, 1M+4L
    (facing down) and 1L+4M (facing up) take promenade hold,
9-24::
    All dance 4x1/2 Reels of 3 on sides (to right to start, then left,
    right & left) with 1s+4s changing partners in centre at end of each
    1/2 Reel to progress Men clockwise & Ladies anticlockwise.  End in
    centre 1s facing down & 4s facing up
25-32::
    1s dance down between 4s, turning 4s with nearer hand 1.1/2 times
    (4s end 2nd place); 1s dance 1/2 Fig 8 round 3s   2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7331, '2013-08-21 08:31:38.986022+00', '2023-02-04 01:22:28.461508+00', 6130, 3, NULL, 'ace', '{{explanation}}
2 cpls each side of the square, RH cpl (odd numbers) are called "inside" & LH cpls (even numbers) are called "outside" cpls.

{{title}}
Introduction

1-8::
    All circle 16H round & back
9-16::
    "Inside" Ladies dance RH across (partners on their left) in St
    Andrews Cross formation with "outside" Ladies giving RH to "inside"
    Men to form large cross & all dance round clockwise & finish in a
    double circles
17-24::
    All set to partners twice & all turn 2H.
25-40::
    All dance Grand Chain (2 bars per hand) in 2 concentric circles
    ending in original square set places.

{{explanation}}
Dance: -	8 times through firstly with 1L+5L, then 2L+6L,3L+7L,4L+8L,1M+5M, 2M+6M, 3M+7M, 4M+8M  
"Inside" Ladies (1L & 2L) in centre & in bars 1- 8, Set to each other for 4 & Turn for 4, (Reel of Tulloch), as other 14 all take hands & Dance around them:

1-8::
    With 1L+5L in centre of dance set 4 Bars & turn RH (as Reel of
    Tulloch) _while_ the others dance 14H round & back.
9-16::
    1L & 5L set to & turn partners 2H, set to & turn opposite Man 6M/2M
17-24::
    Dance LSh reels of 3 (1L with 6M+1M & 5L with 2M+5M) 1L & 5L both
    end in centre as before.
25-32::
    1L & 5L set & turn each other LH in centre _while_ others circle 14H
    round & back
33-40::
    1L & 5L set to & turn nearest corner Man (8M/4M), set to & turn
    opposite Man 3M/7M
41-48::
    Dance LSh reels of 3 (1L with 3M+8M & 5L with 7M+4M) & 1L & 5L
    retire to places as "outside" Ladies 2L & 6L go into centre.

{{title}}
Finale

1-40::
    Repeat Introduction', 0);
INSERT INTO 'dancecrib' VALUES (8985, '2015-11-30 08:59:27.950622+00', '2023-02-04 01:18:36.264603+00', 10910, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, set, cross RH
9-16::
    1s lead down (3 steps), lead up & cast to 2nd place
17-24::
    1s pass LSh to turn 1st corner RH, partner LH, corner RH, cross LH
    to place
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9411, '2016-10-06 07:18:55.296938+00', '2023-02-04 01:22:28.484432+00', 16570, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across.  1s cast to 2nd place as 2s (NHJ) dance
    to 1st place
9-16::
    1s turn 1st corners RH (corners dance for 4 bars), pass RSh, turn
    2nd corners RH retaining hands so 1s end BtoB in middle, 1M facing
    up, 1L facing down
17-24::
    1s dance Double Triangles (6 bars) then turn 1st corner LH finishing
    in 2nd place opp sides (1M facing up, 1L facing down) _while_ 2nd
    corners set
25-32::
    1s dance reels of 3 on opp sides (1M+2L & 1L+3M pass RSh)
33-40::
    1s dance 1/2 Fig 8 (1M up round 2s, 1L down round 3s).  2s+1s+3s
    dance Petronella turn into centre & set in line up/down middle
41-44::
    2s (at top) turn 1.1/2 RH _while_ 1s+3s dance 1/2 reel of 4.  All
    finish in line up/down middle
45-48::
    All set & dance Petronella turn to own side End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13535, '2021-01-09 01:21:38.110499+00', '2023-02-04 01:22:28.692404+00', 8271, 3, NULL, 'ace', '{{explanation}}
Round the room, 3 facing 3

1-8::
    All set & circle 1/4 left; all dance DoSiDo with opp dancer
9-16::
    Repeat 1-8
17-24::
    Centre dancers cast to right & chase clockwise 1/2 round to change
    places, set & cross RH to face out  _while_
::
    Corners set advancing diagonally, dance RH across , face centre,
    pull back RSh & dance out to place
25-32::
    Reels of 3 with partners, centre dancer RSh to partner on right to
    start, corners loop into place so lines of 3 face new lines of 3', 0);
INSERT INTO 'dancecrib' VALUES (7332, '2013-08-21 08:31:38.994142+00', '2023-02-04 01:22:28.711312+00', 10523, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place turn 2H twice to end facing 1st crnrs
9-16::
    1s dance 1/2 reel of 4 with 1st corners, pass LSh & dance 1/2 reel
    of 4 with 2nd corners ending BtoB in middle Man facing up & Lady
    down
17-24::
    1s dance 3H round to right (Man with 3s at top) 1/2 way to end
    facing up/down in lines across, all set twice & 1s petronella turn
    to end in 2nd place
25-32::
    All dance reels of 3 on the sides (1 dance out & down to start)', 0);
INSERT INTO 'dancecrib' VALUES (7333, '2013-08-21 08:31:39.002199+00', '2023-02-04 01:22:28.74336+00', 11267, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-8::
    1s & 4s set, cast in 1 place & dance RH across ending in prom hold
    facing 1st corner pstns
9-16::
    1s+4s dance 1/2 reel of 4 with 1st corners then 2nd corners
17-24::
    1s+4s dance 1/2 reel of 4 with 3rd corners then 4th corners & pass
    RSh to end on sides.  2 4(1)(3)
25-32::
    2s+4s also 1s+3s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (11213, '2018-09-30 22:20:32.668262+00', '2023-02-04 01:22:28.979661+00', 18528, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    2s+1s also 4s+3s dance RH across, 1s+4s dance LH across
17-24::
    All Adv+Ret for 1 step twice, set & 1s+4s+3s turn RH to face up in
    middle
25-32::
    1s+4s+3s dance Allemande.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12106, '2019-08-30 09:54:57.831952+00', '2023-02-04 01:22:29.138276+00', 19060, 3, NULL, 'ace', '1-8::
    1s dance in & cast 2 places (2s+3s step up 3-4); 2s+1s turn partners
    RH to end in middle, 2s facing down, 1s facing up
9-16::
    2s+1s dance R&L up/down set
17-24::
    All dance 6H round & back
25-32::
    3M+2s (at top) & 3L+1s (at bottom) dance reels of 3 across (3M+2L &
    3L+1M pass RSh). 3s curve into centre BtoB, 3M facing up, 3L down
33-40::
    3s dance Crown Triangles with 2s+1s, 3s petronella turn to 2nd place
    own side.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7336, '2013-08-21 08:31:39.032179+00', '2023-02-04 01:22:29.176599+00', 7950, 3, NULL, 'ace', '{{title}}
Strathspey

1‑8::
    1s turn RH, cast 1 place, 1s 1/2 turn LH to face 1st corners
9‑16::
    1s set & turn 1st corners, set & turn 2nd corners ending in 2nd
    place opposite sides

{{title}}
Jig

1‑8::
    2s+1s dance Ladies'' Chain
9-16::
    1s dance down between 3s, cast up round 3s on opposite sides, cross
    up to top & cast to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7337, '2013-08-21 08:31:39.045927+00', '2023-02-04 01:22:29.417481+00', 6135, 3, NULL, 'ace', '{{title}}
FIG 1

1-8::
    All circle 8H round & back
9-16::
    1s+2s also 3s+4s dance RH across & LH back
17-24::
    All set to partners & dance 1/2 Grand Chain to meet partners (1/2
    way round set)
25-32::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L

{{title}}
FIG 2

1-8::
    1s+3s advance & turn opposite person 2H to end BtoB with partner
    facing side couples & set twice
9-16::
    1s & 3s dance reels of 4 with 2s & 4s across set ending in original
    places in Sq.Set
17-24::
    2s & 4s advance & turn opposite person 2H to end BtoB with partner
    facing top/bottom couples & set twice
25-32::
    2s & 4s dance reels of 4 with 1s & 3s ending in original place in
    Sq.Set

{{title}}
FIG 3

1-8::
    Ladies circle 4H round & back ending in centre facing partners
9-16::
    All set twice & turn with 2H to places
17-24::
    Men dance RH across & LH back to places
25-32::
    All set twice & turn with 2H to place

{{title}}
FIG 4

1-8::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L
9-16::
    All set to partners & dance 1/2 Grand Chain to meet partners (1/2
    way round set)
17-24::
    1s+2s also 3s+4s dance RH across & LH back
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13919, '2021-04-05 00:21:46.157894+00', '2023-02-04 01:22:29.44112+00', 19494, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    Ladies dance Fig 8 round opp Man & partner (RSh round opp Man, LSh
    round partner.  Ladies pass LSh in middle)
9-16::
    Men repeat (LSh round opp Lady, RSh round partner.  Men pass RSh in
    middle)
17-24::
    All turn opp dancer RH, turn partner LH
25-28::
    All set advancing to opp dancer & 1/2 turn them RH to finish in prom
    hold with new partner, facing Men''s starting place (Men shoulder to
    shoulder)
29-32::
    Couples dance round each other & dance on in direction Men
    originally facing to meet next couple', 0);
INSERT INTO 'dancecrib' VALUES (7338, '2013-08-21 08:31:39.054103+00', '2023-02-04 01:22:29.47202+00', 6136, 3, NULL, 'ace', '1-8::
    4s dance up to 3rd place _while_ 3s cast & dance back to places, 4s
    followed by 3s+2s dance up to 2nd place & cast to original places
9-16::
    4s followed by 3s+2s+1s dance up & cast to original places, 1s+2s
    also 3s+4s change places on sides (Men LH & Ladies RH)
17-24::
    2s+1s also 4s+3s dance 1/2 Figs of 8 (1s & 3s cross up to start),
    2s+1s also 4s+3s turn on sides (Men RH & Ladies LH)
25-32::
    2s+1s also 4s+3s dance 1/2 double Fig of 8  across (2s & 4s cross
    down) & 1s+4s+3s dance reels of 3 on sides (1s in & down to start)', 0);
INSERT INTO 'dancecrib' VALUES (7445, '2013-08-21 08:31:41.211329+00', '2023-02-04 01:22:36.83597+00', 5842, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across, all set to partners & 1s+2s also
    3s+4s set facing on sides
9-16::
    All dance reels of 4 on sides
17-24::
    1L followed by partner cast to bottom & turn RH 1.1/2 times
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (3887, '2013-08-21 08:30:38.625526+00', '2023-02-04 01:18:16.723852+00', 12732, 3, NULL, 'ace', '{{explanation}}
2 Chords: 1st Chord  All bow/curtsey to partner,  2nd Chord  1s+2s also 3s+4s bow/curtsey to each other on sides

1-8::
    All dance RSh reels of 4 on sides
9-16::
    All circle 8H round & back
17-24::
    1s+2s also 3s+4s Set+Link, 2s+1s also 4s+3s dance RH across
25-32::
    2s+1s also 4s+3s Set+Link, 1s+2s also 3s+4s dance RH across
33-40::
    1s cast to bottom, 2s+3s also 4s+1s turn RH on sides', 0);
INSERT INTO 'dancecrib' VALUES (4131, '2013-08-21 08:30:44.005855+00', '2023-02-04 01:18:36.294691+00', 343, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, set & turn LH to face 1st corners
9-16::
    1s dance full diagonal reel with 1st corners & pass LSh to face 2nd
    corners
17-24::
    1s dance full diagonal reel with 2nd corners & pass LSh to BtoB
    position Man facing up
25-32::
    1s dance up/down & cast round 2nd corner to 2nd place opposite
    sides, 1s cross RH & set', 0);
INSERT INTO 'dancecrib' VALUES (11336, '2018-11-10 19:59:47.201964+00', '2023-02-04 01:18:38.302378+00', 19050, 3, NULL, 'ace', '1-8::
    2s dance reels of 3 on sides, RSh to dancer on right to start
9-16::
    2s dance reels of 3 across, LSh to 1st corner to start (1s & 3s cast
    into reels). 2s finish in 2nd place own sides
17-24::
    1s+2s change places (Ladies RH, Men LH) & 2s+1s+3s set; All turn
    partner RH remaining in centre ready for …
25-32::
    2s+1s+3s dance allemande.  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (11469, '2019-01-01 01:57:52.997249+00', '2023-02-04 01:22:29.491958+00', 18959, 3, NULL, 'ace', '{{explanation}}
Start with 2 Chords - Acknowledge Partner then opposite Dancer

1-8::
    All 3/4 turn partners RH & set advcg (pass partner LSh), all dance
    on 1 place (Ladies cl''wise, Men anticl''wise) to meet next person &
    turn RH
9-16::
    All dance Double Men''s Chain
17-24::
    All 3/4 turn RH & set advcg (pass RSh), all dance on 1 pl (Ladies
    cl''wise, Men anticl''wise) meet partner & turn RH into prom hold to
    face in
25-32::
    All dance diagonally to right & turn clockwise to face, all turn
    corners LH to end beside partners 1 place clockwise from original
    places

{{explanation}}
Dance ends with 2 chords - Acknowledge Partner then opposite Dancer', 0);
INSERT INTO 'dancecrib' VALUES (9043, '2015-11-30 09:00:17.751978+00', '2023-02-04 01:22:29.538233+00', 16112, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up) & dance 1/2 Fig 8 round 3s
9-12::
    1M+3s & 1L+2s dance RH across.  1s end in middle LSh to LSh facing
    opp sides
13-16::
    1s+2s+3s dance the "Snake":
::
    1M followed by 3s also 1L followed by 2s pass LSh dancing diagonally
    across through 2nd place opp sides & chase clockwise to 3 1 2 (Men
    face down Ladies face up)
17-24::
    All chase anticlockwise round set & into middle ready for ...
25-32::
    3s+1s+2s dance allemande', 0);
INSERT INTO 'dancecrib' VALUES (7339, '2013-08-21 08:31:39.078619+00', '2023-02-04 01:22:29.566745+00', 12720, 3, NULL, 'ace', '1-8::
    All circle 6H round & back
9-20::
    All dance 3 couple R&L
21-24::
    All dance DoSiDo
25-32::
    1s set advg & turn about (Lady left about & Man right), 3/4 turn 2s
    (Men LH & Ladies RH), 1s set advg & turn about to repeat with 3s.  2
    3 1', 0);
INSERT INTO 'dancecrib' VALUES (9752, '2017-04-06 08:40:15.534849+00', '2023-02-04 01:22:29.598038+00', 17576, 3, NULL, 'ace', '1-8::
    1s set advancing, turn 2H 1/2 way to face up, cast off one place and
    turn LH to give RH to 1st corners
9-12::
    Highland Schottische Bal-in-Line with 1st corners _while_ 2nd
    corners Highland Schottische set
::
    _9_          With hands joined as normal Bal-in-Line all dance 1st
    bar of HS pointing with right foot and weight on Left foot
::
    _10_        Centre couple drop LH & all move to right joining LH
    with corners (under their RH) then drop RH & corners join RH in
    centre
::
    _11-12_  All repeat HS with left foot & drop hands in centre, all
    move to left to bring original centre couple into centre to join LH
    again & face 2nd corners
13-16::
    1s dance 1/2 fig of 8 round 2nd corners passing LSh, turn LH to give
    RH to 2nd corners
17-20::
    Highland Schottische Bal-in-Line with 2nd corners _while_ 1st
    corners Highland Schottische set
21-24::
    1s dance 1/2 fig of 8 passing 3rd corners LSh to finish 1M between
    2s facing down, 1L between 3s facing up
25-32::
    In lines of 3 across, advance (1 step) and retire (1 step) twice, 1s
    turn 2H 3/4 and twirl out to own sides 2nd place.', 0);
INSERT INTO 'dancecrib' VALUES (7340, '2013-08-21 08:31:39.086699+00', '2023-02-04 01:22:29.611092+00', 6143, 3, NULL, 'ace', '{{explanation}}
2s start on opp sides

1-8::
    Ladies set twice & dance LH across _while_ Men cast & chase
    clockwise all back to places
9-16::
    Men set twice & dance RH across _while_ Ladies cast & chase
    anticlockwise to places
17-24::
    All dance reels of 3 on sides 2s giving RSh to 3s
25-32::
    1s+2s set, dance RH across 1/2 way, 1s+3s set & dance LH across 1/2
    way.  2 (3) 1', 0);
INSERT INTO 'dancecrib' VALUES (7341, '2013-08-21 08:31:39.094947+00', '2023-02-04 01:22:29.631349+00', 6148, 3, NULL, 'ace', '1-8::
    1s & 3s dance out between side couple on Left (Man leading) onto
    opposite place, all circle 8H round to Left 1/2 way
9-16::
    2s & 4s dance out between side couple on Right (Lady leading) onto
    opposite place & all circle 8H round to Right 1/2 way
17-24::
    Ladies dance RH across, set & turn partner RH into middle
25-32::
    Men dance LH across, set & turn partner RH into prom hold
33-40::
    1s & 3s Promenade 1/2 way clockwise _while_ 2s & 4s Adv+Ret, 2s & 4s
    Promenade 1/2 way clockwise _while_ 1s & 3s Adv+Ret
41-48::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L
49-56::
    1s & 3s dance out between side couple on Right (Lady leading) onto
    opposite place & all circle 8H round to Right 1/2 way
57-64::
    2s & 4s dance out between side couple on Left (Man leading) onto
    opposite place & all circle 8H round to Left 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (7342, '2013-08-21 08:31:39.10329+00', '2023-02-04 01:22:29.805701+00', 6150, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    1s & 4s set & cross RH, all set to ptnrs & 1/2 turn RH ending ready
    for Allemande (1s & 2s facing up & 3s & 4s down, Ladies on partner''s
    right)
9-16::
    All dance Interlocking Allemandes:
::
    1s+2s dance normal Allemande but end in 3rd/1st place _while_ 3s+4s
    Allemande down & end in 4th/2nd places 2 (4) 1 (3)
::
    Optional:  Bars 15-16:  4s & 1s turn partners LH once round & remain
    in centre ready for...
17-24::
    1s+4s dance LH across once round, 2s+4s also 1s+3s dance RH across
    once round & open out for -
25-32::
    All circle 8H round & back end 2(4)1(3)', 0);
INSERT INTO 'dancecrib' VALUES (12905, '2020-07-01 00:18:32.328067+00', '2023-02-04 01:18:38.336234+00', 19985, 3, NULL, 'ace', '1-8::
    1s cross down to dance mirror reels of 3 on opp sides (3s in/up, 2s
    out/up to start). (1) 2 3
9-16::
    3s cross up to dance mirror reels of 3 on opp sides (1s continue on
    opp sides).  (1) 2 (3) 4
17-24::
    All Ladies set advancing, Bal-in-Line, then dance below and around
    partner to place
25-32::
    All Men set advancing, Bal-in-Line, dance below and around partner
    to place
33-40::
    3s+4s (bottom 2 couples) dance 1/2 R&L;  2s+4s (middle 2 couples)
    dance 1/2 R&L
41-48::
    1s+4s (top 2 couples) dance 1/2 R&L;  4s & 2s dance 1/2 Fig 8 round
    couple below them.  End 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (14280, '2021-09-08 00:18:35.092085+00', '2023-02-04 01:18:38.370185+00', 20436, 3, NULL, 'ace', '1-8::
    1s & 3s set & cast (2s & 4s step up 3-4); 2s+1M, 4s+1L+3M and 5s+3L
    dance LH across
9-16::
    Double Figures of 8 Across:
::
    _9-10_     2L+1L cross RH between Men _while_ 2M+1M dance across to
    opp side & face (4s+3s dance similar)
::
    _11-12_   2M+1M cross RH between Ladies _while_ 1L+2L dance across
    to own side & face
::
    _13-16_   Repeat 9-12 but crossing LH.  Finish 2L facing 1L, 4L
    facing 3L on Ladies'' side, 1M facing 4M, 3M facing 5M on Men''s side
17-24::
    Diagonal R&L starting LH on sides (1s+2L+4M, 3s+4L+5M).  2M & 5L
    stand (or set to each other). 2 1 4 3 5
25-32::
    All 5 couples set, 1s & 3s cast (4s+5s step up 27-28); all 5 couples
    turn partner RH.  End 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (2632, '2012-01-22 19:29:50.806438+00', '2021-12-05 22:14:34.439444+00', 3672, 2, NULL, 'ace', '1–::

  1c set, cast off one place (2c up), ½ Fig8 up round 2c (2,1x,3)

9–::

  Repeat with 3c (2,3,1)

17–::

  1c lead to above top (in{1}, up{2}, out{1}) ; set to P | cast off (3c down) (2,1,3)

25–::

  2c+1c R&L



{{explanation}}

If there is lack of space, 2c+3c may step down on [19-20], and 2c step up on [23-24].

NB this is now in the revised version of Book 14 and the above crib for 17-24 is superceded.', 3);
INSERT INTO 'dancecrib' VALUES (14475, '2021-12-05 22:08:31.042815+00', '2021-12-05 22:14:34.449365+00', 3672, 1, 1645, 'ace', '1-::

  1c set, cast off one place (2c up), ½ Fig8 up round 2c (2,1x,3)

9-::

  Repeat with 3c (2,3,1)

17-::

  1c lead to top: in{1}, up{2}, out{1}, 2c+3c up on [19-20] ; set to P | cast off (2c up)

25-::

  2c+1c R&L (2,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (10432, '2018-02-16 09:38:43.70551+00', '2021-12-05 23:05:12.914286+00', 18017, 2, 202, 'ace', '1-8::

  1st and 2nd couples set and dance ½ right hands across. Set again and 2nd couple cross left back to own side as 1st couple turn left to face 1st corners ready for . . .

9-16::

  1st couple turn 1st corners right hand, pass right shoulder as 1st corners loop into place, turn 2nd corners right hand, and dance round partner by the right shoulder to face 1st corners again as 2nd corners loop into place (twirling to face 1st corners is accepted).

17-24::

  1st couple set to 1st corners, dance round partner to face 2nd corners, set to 2nd corners, and dance round partner to own sides flowing into...

25-32::

  2nd, 1st and 3rd couples dance six hands round and back

', 2);
INSERT INTO 'dancecrib' VALUES (10433, '2018-02-16 09:51:50.96261+00', '2021-12-05 23:05:12.916478+00', 18017, 1, 202, 'ace', '1--::

  1c+2c set | ½ RHA ; set | 2c cross LH _while{2}_ 1c turn LH to face 1cnrs

9--::

  1c turn 1cnrs RH, pass P Rsh ; turn 2cnrs RH, dance round P Rsh to face 1cnrs (corners loop into place)

17--::

  1c+1cnrs set, dance round P Rsh to face 2cnrs ; 1c+2cnrs set, dance round P Rsh to (2,1,3)

25--::

  Circle6 and back



Note from deviser:



*on [15-16] twirling to face 1cnrs is accepted.*', 2);
INSERT INTO 'dancecrib' VALUES (14329, '2021-09-19 18:22:33.738981+00', '2021-12-06 12:31:15.07198+00', 20492, 1, 202, 'ace', '1--::

  3C Allemande. On [1] all M dance diagonally across with flight _as_ all W dance up slightly. As 1c meet, they rotate to face Mside into allemande hold (3,2,1)

9--::

  1c lead up to top, cast off (2c down), turn P RH and face out (3,1,2)

17--::

 3C Chain Progression (2,1,3)

25--::

  Circle6 and back (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (7343, '2013-08-21 08:31:39.173614+00', '2023-02-04 01:22:29.936987+00', 12018, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s, 1s complete Fig of 8 round 2nd pstns
    as 2s dance 1/2 Fig of 8 round 3s & all end in prom hold (1s/3s face
    up & 2s dn)
9-16::
    All dance Allemande with 1s & 3s dancing up & 2s down to end 3 (2) 1
17-24::
    2L dances up, casts on own side & turns 1L LH 1.1/2 times to end in
    3rd pl _while_ 2M dances down casts up on own side & turns 3M 1.1/2
    times to 1st pl
25-32::
    All (facing new partners) petronella turn into middle, set, dance
    round new partner RSh to opposite sides & 1/2 turn RH to own sides

{{explanation}}
Repeat with new partners', 0);
INSERT INTO 'dancecrib' VALUES (9413, '2016-10-06 07:18:55.529519+00', '2023-02-04 01:22:29.962185+00', 17237, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up), 2s+1s+3s turn RH once round
9-16::
    1s cross LH, cast (3s step up), 2s+3s+1s turn LH once round
17-24::
    1s followed by 3s+2s lead down (2 steps), 3s+2s divide, 1s followed
    by 2s+3s lead up, staying in middle for…
25-32::
    1s+2s+3s dance Allemande
33-40::
    3s+2s also 1s+4s dance R&L with 4s+1s turning LH once round on bars
    39-40 to finish  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13374, '2020-11-13 10:53:54.317187+00', '2021-12-07 01:55:21.832654+00', 20131, 1, 202, 'ace', '1--::
  1c (+ 2c who dance up to follow) dance down ; 2c+1c dance back to places (1,2)
9--::
  1c+2M *Red House Reel3 on Mside* : 1M+2M pass LSh while 1W enters the Reel below them. 1M & 2M continue the Reel to exchanged places, 1W back to original place
17--::
  1c+2W *Red House Reel3 on Wside* : 1W+2W pass RSh while 1M enters the Reel below them. 1W & 2W continue the Reel to exchanged places, 1M back to 2pl. 1M faces out (2,1)
25--::
  1c (1M leading) dance RSh round 2M down to 2pl midline and face P up/down ; 1c turn P BH 1¼ (2,1)', 4);
INSERT INTO 'dancecrib' VALUES (14466, '2021-11-25 13:05:29.011605+00', '2021-12-09 01:13:25.969456+00', 20315, 1, 202, 'ace', '1--::

  1c & 4c set | cast inwards (2c & 3c step out) ; RHA, 1M (4M following) & 4W (1W following) facing 3cnrs

9--::

  *Dolphin Corners Pass and Turn* with lead change : same as Corners Pass and Turn except dancing couples change lead on [10], pass RSh to face new leader''s 4cnrs. Dancing couples change lead on [14] and finish, 1c in 2pl centre & 4c in 3pl centre, BHJ with P (2,1,4,3)

17--::

  1c+4c Poussette (2,4,1,3)

25--::

  Circle8 and back (2,4,1,3)', 5);
INSERT INTO 'dancecrib' VALUES (14479, '2021-12-12 12:27:54.719833+00', '2022-08-15 13:31:48.929269+00', 19785, 2, 602, 'ace', '1-8::

  1s+2s, also 3s+4s, circle 4H round and back

9-12::

  2s+1s, also 4s+3s, set.  Ends cast to middle as middles dance to nearest end & face out (2,1,4,3)

12-16::

  2M+1M, also 4L+3L turn LH once round, while 2L+1L, also 4M+3M, turn RH once round. New ends all face out

17-24::

  Mirror reels of 3 in tandem (lead change optional) on sidelines. To begin, 1s+4s in tandem in & up, 2s out & down, 3s out & up.

25-32::

  2s+3s cross over RH, then chase clockwise to other end (3,1,4,2)

', 5);
INSERT INTO 'dancecrib' VALUES (14476, '2021-12-09 07:59:18.210291+00', '2021-12-09 08:03:53.982122+00', 17239, 1, 202, 'ace', '1--::

  All set | cross RH ; chase clw ½ (3,2,1)

9--::

  All set | cross LH ; chase cclw ½ (1,2,3)

17--::

  1c turn RH | cast off (2c up) ; dance down between 3c and cast up to 2pl (2,1,3)

25--::

  2c+1W & 1M+3c RHA to sides ; all turn P RH



*Deviser''s note* : After second time through the original first couple stay in 3rd place and move down on bars 3&4 of the second repeat.  Fourth couple start by setting and crossing up into third place to begin the dance.', 2);
INSERT INTO 'dancecrib' VALUES (8531, '2015-02-13 12:47:23.591045+00', '2023-02-04 01:18:28.488396+00', 15309, 3, NULL, 'ace', '1-4::
    1M, 2L, 3M, 4L dance across passing partner by Right, cast to Right
    to end by partner (1M & 3M ptnr on Right, 2M & 4M ptnr on Left)
5-8::
    All cross RH with person opposite, all set
9-16::
    1L, 2M, 3L, 4M repeat bars 1-4 to end opposite partner, all on opp
    sides  (2) (1) (4) (3).  All cross RH with partner, all set
17-24::
    1s+4s NHJ dance out of ends, separate, cast back to places.  1s+4s
    turn RH 1/2 way & dance RH across 1/2 way  (2) (4) (1) (3)
25-32::
    All 4 couples set & dance »La Baratte«
::
    _27-28_   Man 1/2 turns opposite Lady RH & retains hand but at arm''s
    length from each other
::
    _29-30_   Man retraces steps with Lady turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies original
    place) & releasing Ladies RH she turns under Mans left arm until
    almost in original places
::
    _31-32_   Couple change places LH to opposite places facing
    anticlockwise
33-40::
    All chase anticlockwise 1/2 round set, take hands, circle 8H round
    to Right to places  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14481, '2021-12-12 19:55:41.666091+00', '2022-06-03 09:31:58.121351+00', 16191, 2, 1645, 'ace', '*In bars 3-24 Ladies dance as Men in 1-22, starting 2 bars later and without setting on 23-24.*
1-8::
  1M set, dance down two places, cast up into 2nd place (2M step up on 5&6). All three men set.
9-12::
  2nd and 1st M cast into a line across 1s position (1M facing up 2M down)
  2M sets rotating while touching raised hands with 2L and 1M as they change places clw.
13-16::
  1M and 2M chase one place clw ending 213 on opposite sides, all M set.
17-20::
  1M and 3M men cast into a line across 3s position (1M facing down 3M up).
  3M sets rotating while touching raised hands with 3L and 1M as they change places clw.
21-24::
  1M and 3M chase one place clw ending 213 on own sides, all M set.
25-32::
  All cross R shoulder (M arches) all set then cross back R shoulder (L arches) all set.
::
  *Crib provided by the deviser.*
', 2);
INSERT INTO 'dancecrib' VALUES (14477, '2021-12-10 02:16:54.349717+00', '2021-12-10 15:27:48.46507+00', 338, 1, 202, 'ace', '1--::
  1c & 3c set | cast off (2c & 4c up) ; 1c & 3c ½ Fig8 R to midline, LSh round 1cnrs, 1M+4W passing LSh
9--::
  2c+1M & 1W+4c+3M & 3W+5c RHA into Reels4 position on 2diag ; ½ Reels4 on 2diag. 1c & 3c finish on midline, LSh to P facing own sides
17--::
  1c & 3c dance LSh round P and face 1cnrs[pos] | turn that cnr RH ; dance LSh round P and face 4cnrs[pos] | turn that cnr RH into promhold
25--::
  These pairs change places RSh to sides where they face each other on sides | 1M+2W & 3M+4W change places RH on Wside _while{2}_ 4M+1W & 5M+3W change places RH on Mside (to 2,1x,4,3x,5) ; 1c & 3c cross LH | cast off (4c & 5c up) (2,4,1,5,3)', 2);
INSERT INTO 'dancecrib' VALUES (8302, '2014-07-29 12:58:42.014796+00', '2023-02-04 01:18:28.500062+00', 14546, 3, NULL, 'ace', '1-8::
    All circle 6H round and back
9-16::
    All set twice, turn partner 2H twice
17-24::
    1s cross down (1M between 3s, 1L between 2s), meet & cross up (1M
    between 2s, 1L between 3s) back to places; All change place RH with
    partner to face corners
25-32::
    All set to corners, turn LH 1.1/2 times, Men dance anticlockwise
    round other Lady to meet partner  3 1 2
33-48::
    Repeat bars 17-32 (3s as dancing couple)
49-64::
    Repeat bars 17-32 (2s as dancing couple)
65-72::
    All set twice, turn partner 2H twice
73-80::
    All circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (14480, '2021-12-12 14:22:39.859465+00', '2021-12-12 14:57:32.937511+00', 9579, 1, 202, 'ace', '1--::

  1c+2c Poussette (1,2)

9--::

  1c Fig8 down round 2c (1,2)

17--::

  Circle4 L ; Petronella turn to midline | set to P

25--::

  ½ Reel4 on midline ; Petronella turn to sides | set (2,1)', 2);
INSERT INTO 'dancecrib' VALUES (3031, '2012-01-22 19:30:07.600661+00', '2021-12-12 23:55:58.589428+00', 5308, 1, NULL, 'ace', '1–::

  1c & 3c cross | cast off (2c & 4c up) ; ½ Fig8 up round 2c/4c (2,1,4,3,5)

9–::

  1c & 3c turn P RH ; turn P LH to face 1cnrs _while{8}_ 2c & 5c cross RH and chase clw to other end of set, 2M & 5W leading P  (5,1,4,3,2)

17–::

  1c & 3c diag. ½Reels4 with 1cnrs (1diags), pass Lsh ; repeat on 2diags

25–::

  Repeat with 3cnrs (1diags) ; 1c & 3c turn LH | cast off on own side (4c & 5c up) to (2,4,1,5,3)', 3);
INSERT INTO 'dancecrib' VALUES (2488, '2012-01-22 19:29:44.568157+00', '2021-12-13 01:21:52.395291+00', 3172, 1, NULL, 'ace', '1–::

  1M+2W set advancing and turn RH ; 1W+2M repeat

9–::

  1c set advancing | turn BH and open upwards ; cast off one (2c up), Petronella Turn to: 1M between 3c and 1W between 2c

17–::

  1c set, turn ¾ RH, set, turn ¾ RH, _while{8}_  2c+3c pass RH on the sides, set, cross RH, set

25–::

  1c set | pass RH ; cast R into 2pl, _while{6}_   2c+3c pass RH on the sides | set ; cross RH | all set. (2,1,3)



{{explanation}}

Notes: In [17-32] traditionally the corners set R to the person just passed, then L to the next person to pass.   

In a variant for [19-24] 1c turns BH in PdB.', 3);
INSERT INTO 'dancecrib' VALUES (8980, '2015-11-30 08:59:26.300049+00', '2023-02-04 01:18:28.544041+00', 16724, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round and back.
9-16::
    1s set and cast off, 1s turn LH to face 1st corners.
17-24::
    1s set and turn 1st corner, set and turn 2nd corner to finish in 2nd
    place opposite side.
25-28::
    2s+1s+3s set. 1s cross RH to 2nd place own side.
29-32::
    1s+3s set and link.', 0);
INSERT INTO 'dancecrib' VALUES (4029, '2013-08-21 08:30:42.222965+00', '2023-02-04 01:18:28.650723+00', 170, 3, NULL, 'ace', '1-8::
    1s cross down & turn 3s (dancing between 3s) into 2nd place opposite
    sides & 1s turn RH
9-16::
    1s+2s dance Ladies'' Chain
17-24::
    1s+3s dance RH Men''s Chain
25-32::
    2M+1L+3M set twice _while_ partners Adv+Ret & turn partners RH to
    own sides', 4);
INSERT INTO 'dancecrib' VALUES (4030, '2013-08-21 08:30:42.233154+00', '2023-02-04 01:18:28.663424+00', 171, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH, lead down for 2 in prom hold, up to top & 1/2 turn
    LH
9-16::
    1s+2s dance Poussette & 1s end BtoB for…
17-24::
    1s dance Double Triangles, 1L ends between 2s & 1M between 3s in
    lines across facing down/up
25-32::
    1s+2s+3s set, 1s turn 1st corner RH, partner LH to 2nd place own
    sides & all set', 0);
INSERT INTO 'dancecrib' VALUES (14478, '2021-12-11 03:00:17.315959+00', '2021-12-13 02:18:47.022254+00', 729, 1, 202, 'ace', '1--::

  1c lead down between 2c, cross and cast off behind 3c ; meet and lead up between 3c, cross and cast up behind 2c to 1pl (1,2,3)

9--::

  All set | {meanwhile 6} [1M+2M & 2W+3W Petronella turn in tandem ; set | Petronella turn in tandem to sides]  [3M & 1W cast clw to 2pl ; cross RH to 2plx | chase clw ¼ to midline, 1W in 1pl facing 3M in 3pl]

17--::

   1M+2M & 2W+3W set _as_ 1W+3M cross RH | Circle6 L ½ (to 1,2,3) | all turn P BH into promhold facing up

25--::

  3C Promenade. On [31-32] 1c cast off _as_ 2c dance up to 1pl (2,1,3)



*Deviser''s note* : At the end of their second turn, 1c cast off into 4pl while 3c+4c dance up one place.', 2);
INSERT INTO 'dancecrib' VALUES (13344, '2020-11-02 01:21:51.822969+00', '2023-02-04 01:22:29.988651+00', 17384, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s+4s cross to opp side

{{title}}
Strathspey

1-8::
    All dance the ''Slip Knot'':
::
    1s+2s dance Knot (normal) _while_ 3s+4s dance Knot starting down
    set. On Bar7-8: 1s+4s dance 1/2 LH across.  2 (4) 1 (3)
9-16::
    4s+1s set across, 1/2 turn partner 2H flowing into circle 4H round
    to left. 1s & 4s end in centre, 4s facing up, 1s down, facing
    corners

{{title}}
Reel

1-8::
    4s+1s dance double ''Hello-Goodbye'' setting. 1s & 4s end in prom
    hold, 1s in centre 2nd place facing up, 4s in 3rd place facing down
9-12::
    1s+2s also 4s+3s dance 1/2 reels of 3 across (1s RSh to 2L, 4s RSh
    to 3L) On meeting in centre 1s & 4s swap partners
13-16::
    1L+4M & 1M+4L in prom hold dance 1/2 reels of 3 across (LSh to
    2M/4M). End on sides  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (7344, '2013-08-21 08:31:39.181947+00', '2023-02-04 01:22:30.020709+00', 8647, 3, NULL, 'ace', '1-8::
    1s petronella turn into centre & set, turning to right
    (individually) & cast round 4th corner to 2nd place own side
9-12::
    1s set as 2s & 3s 3/4 turn RH, 1s+2M+3L (centre 4) dance LH across
    1/2 way _while_ 2L & 3M dance round clockwise to sides
13-16::
    3L+2M set holding LH as 1s 1/2 turn 2L/3M, 3s+2s (centre 4) dance LH
    across 1/2 way as 1s dance round clockwise to centre
17-20::
    2L+3M set holding LH as 1L+2M also 3L+1M 1/2 turn RH, 1s+2L+3M
    (centre 4) dance LH across 1/2 way _while_ 2M & 3L dance round
    cl''wise to sides
21-24::
    2s & 3s turn partners 1.1/4 times (on sides) _while_ 1s set & change
    places passing RSh to form a circle (Ladies at top & Men at bottom)
25-32::
    1s+2s+3s circle 6H round to left to end all on opposite sides, all
    set & cross back RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9239, '2016-06-16 22:42:19.791036+00', '2023-02-04 01:22:30.047924+00', 16282, 3, NULL, 'ace', '1-4::
    1s set, cast 2 places as 2s set
5-8::
    1s lead up, cross & cast to 2nd place _while_ 2s cast below 3s,
    meet, dance up, cross to 1st place opp sides facing out _while_ 3s
    set, cast (in place) & cross passing LSh  (2)(1)(3)
9-16::
    Mirror reels of 3 on sides (1s in/down to start)
17-24::
    LSh reels of 3 across 1L+3s (LSh to 3M) & 1M+2s (LSh to 2L) (2) (1)
    (3)
25-30::
    2s+3s cross RH with partners (1 bar), chase clockwise all round
    _while_ 1s turn RH 1.1/4 (4 bars) to join in chase (1L between
    2L+3L, 1M between 2M+3M)
31-32::
    2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (7345, '2013-08-21 08:31:39.191681+00', '2023-02-04 01:22:30.071252+00', 10286, 3, NULL, 'ace', '1-8::
    1s cross RH, cast to 2nd place (2s step up), turn LH & cast down to
    3rd place (3s step up)
9-16::
    1s dance reflection reels on opposite sides (1s in/up, 3s out/down,
    2s in/down to start)
17-24::
    1s dance up to top, cast to 2nd place _while_ 3s continue reel to
    3rd place; 1s dance 1/2 Fig of 8 round 3s
25-32::
    1s turn 1st corner RH, pass RSh, turn 2nd corner RH & pass RSh to
    2nd place own sides (corners turn for 4 bars)', 0);
INSERT INTO 'dancecrib' VALUES (7347, '2013-08-21 08:31:39.207716+00', '2023-02-04 01:22:30.28247+00', 10084, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance RH across (Lady with 2s & Man with 3s)
9-16::
    1s dance reels of 3 across (Man with 2s & Lady with 3s) & end BtoB
    Lady facing up
17-24::
    1s circle 3H round (Lady with 2s & Man with 3s), 1M dances up
    between 2s & casts to 2nd place opp sides _while_ 1L crosses down &
    casts up
25-32::
    1s dance reels of 3 on sides giving LSh to 1st corner & end crossing
    RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7348, '2013-08-21 08:31:39.215948+00', '2023-02-04 01:22:30.311345+00', 6153, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All turn RH & Ladies cast behind partner to dance RH across in
    centre & back to places
17-24::
    All turn LH & Men cast behind partners to dance LH across in centre
    & back to places
25-32::
    1s+2L+4M also 3s+2M+4L dance reel of 4 across (1s & 3s pass partners
    LSh to start)
33-40::
    2s+1M+3L also 4s+1L+3M dance reels of 4 up/down (2s & 4s pass
    partners LSh to start)
41-48::
    All set to & turn corners RH & dance 1/2 Chain commencing RH to
    corner
49-56::
    All turn corners RH & turn partners LH & dance 1/2 Chain commencing
    LH to partners
57-64::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7962, '2013-08-21 08:31:51.887404+00', '2023-02-04 01:23:13.99423+00', 7180, 3, NULL, 'ace', '1-8::
    1s cross over (Man between 3s, Lady between 2s) & dance Fig of 8 &
    end turning RH 1/2 way to face partner in original places
9-16::
    All dance interlocking RSh reels of 4 & end by turning RH to bring
    Men into centre
17-24::
    Men dance LH across in centre 2 places _while_ Ladies dance
    clockwise 1 place, turn partner RH & repeat ending in triangular set
    order 2 3 1
25-32::
    All set & circle 6H round for 2 steps, turn partner 2H & continue to
    circle 6H round to pstns.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (14471, '2021-12-03 19:43:04.006913+00', '2022-05-24 20:45:21.214416+00', 20565, 1, 1645, 'ace', '1-::
  1W loops LSh round 2W | crosses above P & 1c clap LH ; 1c, 1W leading, cast off behind 2M (2c up) into centre line, 1W facing down, 1M up
9-::
  *Modified H&G setting:* 1c set to P | set to 1cnr & clap RH ; 1c+1cnrs set on sides, end side by side facing 2cnrs | set to 2cnrs, 1cnrs giving RH clap to 2cnrs to end in lines across (2W,3W,1M facing down to 1W,2M,3M)
17-::
  All set | advance & clap BH ; retire | set
25-::
  4 bars of R&L for 3C starting RH up/down ; &frac12; Reels3 across, 1c start RSh to 1cnrs & end in 2pl own sides (2,1,3)
33-::
  All chase clw ; all LHA back extending R arm (2,1,3)
::
  *Variation for [1-8]: 1c exchange roles (1M loops RSh round 2M, crosses above P & casts)*
', 5);
INSERT INTO 'dancecrib' VALUES (3882, '2013-08-21 08:30:38.222363+00', '2023-02-04 01:18:16.298922+00', 10310, 3, NULL, 'ace', '1-8::
    1s Petronella to opposite sides
9-16::
    1s+2s dance RH across & LH back
17-24::
    1s+2s dance Poussette.  2 1 3
25-28::
    1s turn LH 1.1/2 times
29-32::
    1s dance RH across (Lady with 2s & Man with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (2736, '2012-01-22 19:29:55.342128+00', '2021-12-15 12:06:43.19379+00', 4102, 1, NULL, 'ace', '1–::

  1c turn RH | cast (2c up) ; turn LH to face 1cnrs

9–::

  1c ½Reel4 with 1cnrs (pass P Lsh) ; Repeat with 2cnrs

17–::

  Repeat with 3cnrs (1cnr person) ; Repeat with 4cnrs (2cnr person)

25–::

  1W+2c & 1M+3c Reels3 across, Lsh to 1cnr

33–::

  2c+1c+3c circle6 and back



{{explanation}}

Note: Cosh explicitly tells 1c to pass Lsh in [9-24]; however the Rsh pass is quite common, and sometimes nicknamed »Mairi''s Divorce«.', 3);
INSERT INTO 'dancecrib' VALUES (3883, '2013-08-21 08:30:38.291971+00', '2023-02-04 01:18:16.488702+00', 9106, 3, NULL, 'ace', '1-8::
    All set on sides & cross RH, all set & cross back RH
9-16::
    1s dance down to meet 4s who dance up & 1L+4L also 1M+4M dance out
    own sides, cast back to places & 1s lead down to 4th place (2s+3s+4s
    step up 15-16)
17-24::
    3s+4s (middle couples) dance R&L
25-32::
    2s+3s also 4s+1s dance RH across & LH back', 0);
INSERT INTO 'dancecrib' VALUES (8484, '2015-01-13 12:18:32.196914+00', '2022-01-29 00:32:09.334574+00', 14583, 2, 1007, 'ace', '{explanation}

2 chords; 3C and 4C cross on 2nd chord



1-8::   1C and 4C fig of 8 through 2C and 3C 

	(1C cross through 2C cast round 3C, cross up through 3C, cast up round 2C. 4C 	cross up through 3C cast up round 2C, cross down through 2C, cast down round 	3C. W in front of M.)



9-16:: 	1C+2C and 3C+4C Slip Knot



17- 24::	1C and 4C Petronella Turn (finish 1M & 4M B to B in middle of set) and Set 

	(2C+3C square off diamond on 19-20);

	1C+2C and 3C+4C RHA



25-32:: 	All Weasel Reels (at end of reel 1M+4M 1/2 LH turn to finish 1M facing 2Ms place 	and 4M facing 3Ws place)



33-40:: 	1C+4C dance Rsh round the next person in their diamond to chance place with 		Partner (1M round 2M, 1W round 2W, 4M round 3M, 4W round 3W);

	1C and 4C turn RH 1 1/4 (finish 4W+1M facing down on W side, 1W+4M facing up 	on M side, M are behind W), 2C+3C step up/down on 39-40



41-48:: 	4W & 1M Rsh Tandem reel of 3 with 2W & 3M while 1W & 4M Tandem reel of 3 with 	2M & 3W (finish 4W+1M and 1W+4M on side face P NH joined) 



49-56:: 	1C+4C dance set and link  	(M finish on ends of line of 4 across dance, W dance 1/2 LH turn to finish facing P 	in middle of set, 1W & 4W BtoB);

	1C+4C 1/2 reel of 4 (W looping to finish opposite P across set. Order 2143)



57-64:: 	Circle 8H round to the left for 6 steps, pivot & chase back to places.





_Weasel Reels:_



1W+4W 1/2 reel 4, then chase back CW to where started reel.  

3M+2M chase CW to end of reel, 1/2 reel 4, then chase back CW to where started.  

3W+2W chase CW to end of reel, 1/2 reel 4, then chase back CW to where started.  

1M+4M pass Rsh with Partner, chase CW to other end of reel, enter reel passing Rsh at end, then 1M+4M pass Lsh in middle.



(People leaving reel dance out in front of people joining)', 0);
INSERT INTO 'dancecrib' VALUES (12626, '2020-03-02 01:51:11.7395+00', '2023-02-04 01:18:16.523757+00', 17372, 3, NULL, 'ace', '1-8::
    1L+3M set, cast 2 places (1L down, 3M up); 1L+3M cross RH back to
    original places
9-16::
    1M+3L repeat, crossing LH to place to finish facing down/up
17-24::
    2L+1s & 2M+3s dance RH across, 2s face 1st corners; 2s+1st corners
    dance 1/2 RSh diag reel of 4, 2s pass RSh into …
25-32::
    2M+1L+3L (at top) & 2L+1M+3M (at bottom) dance RH across, 2s end
    facing 2nd corners; 2s+2nd corners dance 1/2 diag reel of 4.  2s end
    2nd place opp sides.  (3) (2) (1)
33-40::
    3s (at top) set, cross RH _while_ 2s+1s dance 1/2 R&L; 3s turn RH.
    End 3 1 2

{{explanation}}
Note: If danced as 4C set (J8x40,) at end of 2nd turn 1s+2s cross RH with partner, turn person on side LH once round & all 3 couples turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4031, '2013-08-21 08:30:42.241331+00', '2023-02-04 01:18:28.673764+00', 13625, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH & cast to other end (pass RSh) _while_ 2s set & 3/4
    turn 2H, 2s dance RH across (2L with 3s at top & 2M with 2s)
9-16::
    3s & 1s cast to other end & cross RH _while_ 2s set & change places
    2H, 2s dance RH across (2M with 2s & 2L+3s) 2s end facing 4th crnr
    (pstn)
17-24::
    2s dance 1/2 RSh reels of 3 on own sides, 3s turn LH _while_ 2s+1s
    turn RH
25-32::
    3s+2s dance the Tournee:
::
    3s+2s dance into prom hold (Men with prtnr on right, 3s face M''s
    side & 2s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (2s RH, 3s LH) & dance
    out to places', 0);
INSERT INTO 'dancecrib' VALUES (9082, '2016-01-21 21:42:31.69066+00', '2022-01-29 00:33:49.351689+00', 213, 2, 1007, 'ace', '1-8:: 1s & 3s dance 1/2 L&R (start by crossing with partners), while 2s pass Lsh dance Rsh round 1st corner positions and pass Lsh to face 1st corners in partners 1st corner pos, 2nd corners set x2 facing diagonally in, while 2s and 1st corners 1/2 reel of 4, at end 2s pass Lsh to face 2nd corner positions.



9-16:: 1s & 3s dance 1/2 L&R (start by changing places on the sides), while 2s dance Rsh round 2nd corner positions and pass Lsh to face partners 2nd corners position, 1st corners set x2 facing diagonally in, while 2s and 2nd corners 1/2 reel of 4, at end 2s finish own place, 1st corners pull Lsh back as if casting.



17-20:: 1/2 reels of 3 on sides (2C dance 1/2 reel by XL up through 1place and casting into 2nd place opposite sides)



21-24:: 2M + 1s and 2L + 3s 1/2 reel of 3 across (to start 2W and 3M, 2M and 1W pass Lsh)



25-32:: 1s & 2s dance Knot', 0);
INSERT INTO 'dancecrib' VALUES (13382, '2020-12-02 01:18:20.266745+00', '2023-02-04 01:18:17.213012+00', 20141, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s+2s dance RH across & LH across back to place
17-24::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s
25-32::
    2s+1s dance R&L.  2 1

{{explanation}}
Note:	May also be danced as a reel', 0);
INSERT INTO 'dancecrib' VALUES (11001, '2018-08-17 07:52:58.816946+00', '2023-02-04 01:22:30.342245+00', 17460, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link; circle 4H round to Left  2 1 3
9-16::
    1s pull back RSh & cast round 3rd corner (Man up/Lady down), pass
    LSh in centre & dance LSh round 1st corner (6 bars) 1s turn 3/4 LH
    to end in centre 1M below 1L, facing opp sides
17-20::
    1L+2s & 1M+3s dance RH across
21-24::
    "Snake Pass": 1L followed by 2L & 2M, 1M followed by 3M & 3L, pass
    LSh in the middle, dance out to the side, down to 3rd/up to 1st
    place, cross to own side and cast up/down to 2nd place in middle,
    RSh to RSh facing opp sides
25-28::
    1M+3s (at top) & 1L+2s (at bottom) dance LH across
29-32::
    Repeat "Snake Pass" with dancers passing RSh in middle & all finish
    on sides 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7349, '2013-08-21 08:31:39.225831+00', '2023-02-04 01:22:30.376923+00', 10575, 3, NULL, 'ace', '1-8::
    2s & 4s dance Figs 8 across round couple on their right & end facing
    1st corners _while_ 1s+3s+5s set, cross RH, set & cross back RH
9-16::
    2s & 4s dance a Spoke: Bal-in-Line with corners, drop RH & move
    anticlockwise to repeat with 2nd, 3rd & 4th crnrs & end facing 1st
    crnrs
17-24::
    2s & 4s dance diagonal reels of 4 with 1st crnrs to finish in
    original places.
25-32::
    1s dance down to 5th pl _while_ 2s+3s+4s+5s set & cast up 1 place,
    all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (7350, '2013-08-21 08:31:39.23388+00', '2023-02-04 01:22:30.399748+00', 9892, 3, NULL, 'ace', '1-8::
    1s set, cross (no hands) to 2nd place facing out (2s step up) & 1s
    turn 2s with nearer hand
9-16::
    1s dance reflection reels of 3 on opposite sides (1s dancing out &
    up to start, 1s end facing 1st corner
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass LSh & dance
    1/2 diagonal reel of 4 with 2nd corners. All end on opp side (3) (1)
    (2)
25-32::
    3s+1s+2s circle 6H round to left 1/2 way, clap & turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (14569, '2022-01-29 08:09:11.364867+00', '2022-01-29 08:20:32.122884+00', 20642, 1, 202, 'ace', '1--::

  1c pass P RSh | turn 2c EH ½ on sides ; ½ Fig8 R round 3cnrs ending LHJ with P on 1diag

9--::

  1c turn P LH ¾  _while{2}_ all cnrs chase clw one place | BiL on 2diag as cnrs on 1diag set ; all repeat [9-12] with BiL on 1diag as cnrs on 2diag set (3x,1,2x)

17--::

  Reels3 on sides, 1c LSh to 4cnrs[pos]. 1c finish LHJ with P on 2diag

25--::

  All repeat same pattern [9-16] with Bil on 1diag first then Bil on 2diag (2,1,3)

33--::

  1c turn LH, dance RSh to 2cnrs to 2plx | pass P RSh (2,1,3)



*Deviser''s note* : bars [9-16] and [25-32] are a variation of Corner Targe.', 2);
INSERT INTO 'dancecrib' VALUES (3005, '2012-01-22 19:30:06.571025+00', '2022-01-29 10:14:48.239532+00', 5222, 1, NULL, 'ace', '{{title}}

Reel  

1–::

  1c+2c RHA, LHA

9–::

  1c down the middle (2c up) and up to face 2cnrs

17–::

  Set to and turn 2cnrs ; set to and turn 1cnrs, finish 1W (1M) between 2c (3c) facing P

25–::

  1c set twice ; turn BH twice, to finish between the end couples again



{{title}}

Strathspey  

33–::

  1c change places touching RH and turn R about to face P ; repeat with LH, turning L about

41–::

  In lines of 3 across A&R (1+1 step) twice, finish between own corners ; A&R across (1+1 step) twice, finish facing 2cnrs

49–::

  Set to and turn 2cnrs ; set to and turn 1cnrs, finish in middle between end couples

57–::

  1c set twice, turn 1¼ BH to (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14439, '2021-11-06 01:13:12.952259+00', '2023-02-04 01:22:30.427683+00', 19118, 3, NULL, 'ace', '1-4::
    1s & 2s cross RH with partner & set
5-6::
    1s+2s dance Modified Set+Link on sides (as normal Set+Link but
    ending 2s in 1st place facing down, 1s in 2nd place facing up on opp
    sides NHJ)
7-12::
    2s+1s Set+Link across facing up/down to finish NHJ on the sides,
    facing partners. 2s+1s set to partners
13-16::
    1s NHJ dance up between 2s & cast to 2nd place
17-24::
    1s lead down the middle & back, finishing in 2nd place facing up
25-32::
    Modified reel of 3 on sides:
::
    1s dance out/up, 2s in/down, 3s in up to start.
::
    Bar 3-4:  On reaching 1st place, 1s cross down RH to continue reel
    on opp side
::
    Bar 7-8:  1s cross up RH to end in 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7351, '2013-08-21 08:31:39.242006+00', '2023-02-04 01:22:30.493748+00', 6158, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s set, dance 1/2 RH across, rotate & dance 1/2 LH across
9-16::
    1s+2s circle 4H round & back

{{title}}
Reel

1-8::
    1s+2s set, dance 1/2 RH across, set & 3/4 turn partner RH to end in
    centre
9-16::
    2L+1M 3/4 turn LH _while_ partners chase 1/4 round clockwise to form
    line of 4 across, change places RH with partner, 1L+2M 3/4 turn LH
    _while_ partners chase 1/4 round clockwise to end in line of 4 in
    centre, 1s+2s 3/4 turn in centre
17-24::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7352, '2013-08-21 08:31:39.250056+00', '2023-02-04 01:22:30.529263+00', 9161, 3, NULL, 'ace', '1-8::
    1M+2L turn RH, dance RSh round own partner (to change places) &
    circle 4H round to left
9-16::
    1s+2s (facing in diagonally) set, dance RH across 1/2 way & Set+Link
    with partner on sides
17-24::
    1L+2M turn RH, dance RSh round their own original place (to change
    places) & 2s+1s circle 4H round to left
25-32::
    2s+1s (facing in diagonally) set, dance RH across 1/2 way (end with
    partner facing the other couple), set & dance LH across 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (13346, '2020-11-02 01:21:52.140267+00', '2023-02-04 01:22:30.557727+00', 13164, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 (1M round 2s, 1L
    round 3s). 1s end LSh to LSh in centre facing opp sides.  2 1 3
9-12::
    1L+2s & 1M+3s dance RH across
13-16::
    All dance »Snake Pass«:
::
    1L followed by 2s & 1M followed by 3s pass LSh diagonally across
    through 2nd place to change ends, loop round to left, 1s end in 2nd
    place. 3 1 2
17-24::
    1M+3s (at top) & 1L+2s (at bottom) dance LH across; All dance »Snake
    Pass« (dancers pass RSh in centre).  2 1 3
25-32::
    2s+1s+3s Adv+Ret; All dance DoSiDo', 0);
INSERT INTO 'dancecrib' VALUES (8525, '2015-02-13 12:47:20.088964+00', '2023-02-04 01:18:18.071835+00', 15591, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of 8 round 2s _while_
    3s dance 1/2 Fig of 8 round 4s.  2 1(3)4
9-16::
    1s+3s dance RH across, 1s+3s dance LH across
17-24::
    1L followed by 3M dance Tandem reel of 3 with 2s (LSh to 2M) _while_
    3L followed by 1M dance Tandem reel of 3 with 4s (LSh to 4L) ending
    2(3)1 4
25-32::
    3s & 1M+4M also 1L+4L Set+Link, 3s+4s+1s circle 6H round to left to
    end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (2678, '2012-01-22 19:29:52.749262+00', '2022-01-29 00:34:07.546802+00', 11284, 1, NULL, 'ace', '1–::

  1c set | cast off (2c up), cross Lsh and cast R round 1cnr to face 1cnr

9–::

  SetH&G , at end pass Rsh to face out in 2pl

17–::

  [Chaperoned Chain Progression] 1c cast ¼ clw round set _while{2}_ 2c & 3c Turn RH ¾ | 2M+3W turn 1½ LH _while{4}_ the others promenade ½ clw round set | 3c+2c turn RH ¾ and face up _while{2}_ 1c cast ¼ clw to meet in 2pl, for

25–::

  3c+1c+2c Allemande (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (9716, '2017-04-06 08:39:24.581684+00', '2023-02-04 01:18:18.133728+00', 17656, 3, NULL, 'ace', '1-8::
    1s lead down for 4 bars. Bar 5: Lady turns under Man''s arm to change
    places & 1s lead up to face 1st corners (2s step up 3-4)
9-12::
    1s dance 1/2 diag reel of 3, LSh to 1st corner to start. 1s finish
    facing 4th corners across set
13-16::
    1s dance 1/2 reels of 3 across, LSh to 4th corner corner.  1s pass
    LSh to 2nd place opp sides facing out
17-20::
    _1/2_ dance 1/2 diag reel of 3, LSh to 2nd corner (pstn) to start.
    1s finish facing 3rd corner (position) across set
21-24::
    1s dance 1/2 reels of 3 across, RSh to to 3rd corner (pstn).  Finish
    1L between 3s facing up, 1M between 2s facing down
25-28::
    1s 1/2 turn RH and twirl (pull back RSh) so 1L faces up, 1M down
29-32::
    1s turn 4th corner 1.3/4 RH (1L+2L & 1M+3M) to finish in 2nd place
    own side', 0);
INSERT INTO 'dancecrib' VALUES (14568, '2022-01-27 18:30:50.091167+00', '2022-01-29 08:20:32.121544+00', 20642, 2, 963, 'ace', '1-4::  

  1C pass Rsh to opp side & face out|with handy hand change places with 2C  

5-8::  

  1M up thru 2C, 1W down thru 3C 1/2 figure of 8 to finish LH joined on 1st corner diag  

9-16::  

  As corners chase cw one place, 1C turn LH 3/4 to give RH to 1st corner in 4th corner position |1C and 1st corners bal in line as 2nd corners set | repeat 9-10 to bal in line on 1st corner diag as 2nd corners set  

17-24::  

  1W up, 1M down, Lsh R3 on the sides.  1C finish LH joined on 2nd corner diag  

25-32::  

  As corners chase cw one place, 1C turn LH 3/4 to give RH to 2nd corner in 3rd corner position | 1C and 2nd corners bal in line as 1st corners set | repeat 25-26 to bal in line on second corner diag as 1st corners set  

33-40::  

  1C 1/2 turn LH | 1W dances up btwn 2C, 1M down btwn 3C and casts left to 2nd place opp sides|1C pass Lsh to their own sides  

  Note: bars 9 -16 and 25 - 32 are a variation on the corner targe', 5);
INSERT INTO 'dancecrib' VALUES (4174, '2013-08-21 08:30:44.841281+00', '2023-02-04 01:18:38.398518+00', 413, 3, NULL, 'ace', '1-8::
    1s+3s turn partners RH & Men followed by Ladies chase clockwise 1/2
    way round set
9-16::
    1s+3s dance RH across in centre & LH back to »new« places
17-32::
    2s+4s repeat bars 1-16
33-40::
    1s+3s turn partners LH & Ladies followed by Men chase anticlockwise
    1/2 way round set
41-48::
    1s+3s dance R&L
49-64::
    2s+4s repeat bars 33-48
65-72::
    All dance into centre & return with corners, Ladies dance round
    corners passing in front to begin & back to place
73-80::
    All with corners dance into centre & return with partners, Men dance
    round partners passing in front to begin & back to place
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7353, '2013-08-21 08:31:39.258177+00', '2023-02-04 01:22:30.577224+00', 6161, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L; 1s+3s dance 1/2 R&L
9-16::
    1s cross RH, cast up to 2nd place & dance 1/2 Figs of 8 round 3s to
    end facing 1st corner positions
17-24::
    1s dance 1/2 diag  reel with 1st corners, pass LSh & dance 1/2 diag
    reel with 2nd corners ending with quick LH turn, 1L facing 3s at
    top, 1M facing 2s in 3rd place
25-32::
    1s dance the Snake Pass:
::
    1s dance RH across (1L with 3s & 1M with 2s), 1L followed by 3s also
    1M followed by 2s pass LSh diagonally across through 2nd place to
    change ends & loop round to left to end in 2nd place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15238, '2022-11-03 01:21:44.978873+00', '2023-02-04 01:22:30.592801+00', 6162, 3, NULL, 'ace', '1-8::
    1s leads down below 5th place, cross, cast up to 1st place and cross
    RH to original place as 5s cross RH, cast up to 1st place and lead
    down crossing over to original place
9-16::
    1s+2s dance RH across and LH across _while_ 4s+5s dance RH across
    and LH across _while_ 3s turn RH (4 bars) and LH (4 bars)
17-20::
    1s and 2s cross RH and circle 1/2 way to the left
21-24::
    1s and 3s cross LH and circle 1/2 way to the right
25-28::
    1s and 4s repeat 17-20
29-32::
    1s and 5s repeat 21-24', 0);
INSERT INTO 'dancecrib' VALUES (7354, '2013-08-21 08:31:39.268201+00', '2023-02-04 01:22:30.624087+00', 6163, 3, NULL, 'ace', '1‑8::
    1s cross RH, cast 1 place & turn LH to face 1st corners
9‑16::
    1s set to 1st corners, set to partners, set to 2nd corners & set to
    face 1st corners
17‑24::
    1s dance 1/2 reel of 4 with 1st corners, pass RSh to dance 1/2 reel
    of 4 with 2nd corners & end Lady between 3s at top & Man between 2s
    up
25‑32::
    1L+3s facing 1M+2s set twice, 1s turn LH into 2nd place _while_
    3s+2s change places RH on sides & cross LH', 0);
INSERT INTO 'dancecrib' VALUES (8501, '2015-01-25 16:49:21.943163+00', '2022-01-29 00:36:46.772018+00', 11685, 2, 160, 'ace', '1–::

 1C turn BH (face up), cast 1pl ; 1C turn BH 1-1/2 to end on opposite sides.

9–::

 2 1 3 all set, 2C3C B-to-B prtnr *while* 1C dance rnd ptnr by R (gypsy) to face out, 1C cast rnd 1cnr *while* 2C 3C adv 1 step+ret 1 step (on diagonal). 

 Now in lines of 3 across the dance.

17–::

 All set, 2M3M+2L3L dance B-to-B *while* 1C dance rnd ptnr by R (gypsy) to face out, 1C cast right to 2pl own sides *while* 2C 3C adv+ret on diagonal (1 in -1 out). 

25–::

 Six hands round & back.', 0);
INSERT INTO 'dancecrib' VALUES (3015, '2012-01-22 19:30:06.971125+00', '2022-01-29 14:21:02.951925+00', 5260, 1, NULL, 'ace', '1–::

  1c cross RH, cast (2c up) ; ½ Fig8 L (W up, M down) finishing LHJ facing own 1cnr

9–::

  1c set to 1cnr, swivel inwards into RHJ | set to 3cnr ; then to 2cnr and swivel into LHJ | set to 4cnr, advancing into

17–::

  1W+2c & 1M+3c RHA ; 1c turn LH 1½ _while{4}_ corners chase clw ½

25–::

  Repeat the figure (with same couple)

33–::

  Lsh Reels3 across with same couple (to 2,1,3)

41–::

  Circle6 and back.', 2);
INSERT INTO 'dancecrib' VALUES (10622, '2018-04-16 21:41:19.702563+00', '2023-02-04 01:18:19.149729+00', 13870, 3, NULL, 'ace', '1-8::
    1s NHJ dance down under arch made by 4s who dance up, 1s cast up
    round 3s as 4s cast round 2s (2s & 3s step up/down) & all set
9-16::
    2s+4s also 1s+3s dance R&L
17-24::
    Reels of 4 on sides
25-32::
    All circle 8H round & back.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12520, '2020-01-22 12:32:55.821968+00', '2022-01-29 20:47:18.537644+00', 6012, 1, NULL, 'ace', '*Start (1,2,3x,4x)*

1--::

  1c+4c set | 1c/4c cross inwards into ½ Fig8 round 2c/3c | 1c+4c lead in RHJ and meet (2c+3c to ends) (2,1x,4,3x)

9--::

  1c+4c ½ RHA | On sidelines all middles turn ends LH ;4c+1c ½ RHA |  On sidelines all middles turn ends LH and finish in a diagonal cross, middles facing ends (2,1x,4,3x)

17--::

  Double H&G setting, finish in diagonal cross, middles facing opposite corner (2,4x,1,3x)

25--::

  All middles turn corner RH, to sidelines ; All A&R, 4c+1c turning BH ½ to retire to the other side (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (11279, '2018-10-20 07:29:37.122596+00', '2022-01-30 00:04:27.697472+00', 18517, 1, 202, 'ace', '1--::

  All W RHA to places facing out ; all 4 bars of Schiehallion Reel (2,3,4,1)

9--::

  All M loop RSh round P to places ; all 4 bars of Schiehallion Reel (3,4,1,2)

17--::

  All W loop RSh round P to places ; all 4 bars of Schiehallion Reel (4,1,2,3)

25--::

  All M(W) chase cclw(clw) inside(outside) the square set (4,1,2,3)

33--::

  All M LHA to places facing out ; all 4 bars of »reverse Schiehallion Reel« [same as Schiehallion Reel except that M follows W who dances to the next M place to the L] (3,4,1,2)

41--::

  All W loop LSh round P to places ; all 4 bars of »reverse Schiehallion Reel« (2,3,4,1)

49--::

  All M loop LSh round P to places ; all 4 bars of »reverse Schiehallion Reel« (1,2,3,4)

57--::

  All M(W) chase cclw(clw) outside(inside) the square set (1,2,3,4)

65--::

  All Intersecting M-Chain (M give quick LHA in the middle, polite turn for W)

73--::

  All Intersecting La-Chain (W give quick RHA in the middle)

81-96::

  »Reverse Schiehallion Reel« (1,2,3,4)  



*Deviser''s notes:  

1. As an option for energetic dancers, women can dance four turning pas de basque on the spot to follow their partners as they dance around them, and men can do the same as women dance around them (pulling back right shoulders on bars 9-12 and 17-20, and pulling back left shoulders on bars 41-44 and 49-52).  

2. As an alternative for the transition between the two chains (which is uneasy), on bars 71-72, all couples can turn both hands and open out to face in. It avoids taking right hands twice for women (before and after changing direction).*', 5);
INSERT INTO 'dancecrib' VALUES (11098, '2018-09-12 10:59:14.032374+00', '2022-01-30 13:34:13.034574+00', 18581, 1, 202, 'ace', '1--::
  All set advancing | turn P BH opening to face down NHJ ; All S&Link across 1W+2M & 2W+3M & 3W+4M passing RSh when changing places with P
9--::
  All dance down. On [12] all change sides and face up, W passing under joined arms ; all dance up (1,2,3,4)
17--::
  1c+2c ½ R&L ; 2c cross RH and stand still _while{4}_ 1c+3c ½ R&L (to 2,3x,1,4)
25--::
  3c cross RH and stand still {4} _while{6}_ 1c+4c ¾ R&L | all set (2,3,4,1)

*Deviser''s note:  No polite turns on [17-30]*', 4);
INSERT INTO 'dancecrib' VALUES (12294, '2019-10-17 23:07:21.587032+00', '2022-01-30 18:40:36.403088+00', 16792, 1, NULL, 'ace', '1-16::

  "Modified Sheepskin Hey":  The line of W weave around the M, first down, then up, then down, and back to own side, as follows: 1W, with 2W+3W following, cross, cast behind 1M, in front of 2M, and behind and Lsh round 3M except that the trailing W (3W), on arriving below 2M casts up, taking the lead in front of 1W+2W. The line of W weave up  (Rsh to 2M, Lsh round 1M), but again the trailing W (2W) having arrived above 2M dances down, taking the lead in front of 3W+1W.  All pass 3M Lsh, cross and dance up own side to (2W,3W,1W)

17-32::

  The M repeat the figure round the W (2,3,1)  

33--::

  2c+3c RHA ; 3c+1c LHA  

41--::

  Parallel Reels3 on the sides, 3c Rsh to 2c (2,3,1)  

::

  *Note: 1-32 requires fast dancing*', 3);
INSERT INTO 'dancecrib' VALUES (11785, '2019-04-13 01:05:00.444862+00', '2022-01-30 20:15:50.350738+00', 6774, 1, NULL, 'ace', '*Start (1x,2,3x,4)*

1--::

  All set | turn P RH ½, all W pivoting R to face out ; All W, P following, cast one place L and cross (2,1x,4,3x) 

9--::

  2M+1c (in tandem, starts up)+4c (in tandem, starts down)+3M ½ Diag. Reel4, at the end 1W & 4W pass Lsh and  veer L to follow the other M ; 1M+4M continue the next ½ diag Reel4, at the end 1M & 4M veer L to follow own P again

17--::

  2W+4c (in tandem, starts up)+1c (in tandem, starts down)+3W repeat [9-16] (2W & 3W no polite turn) 

25--::

  1c+4c LHA _while{4}_ 2c+3c cross LH and set ; 1c (down)+4c(up) dance (W leading) out the ends and cast 2 places cclw to (2x,4,1x,3)



', 3);
INSERT INTO 'dancecrib' VALUES (3810, '2013-07-13 15:56:12.227358+00', '2022-01-30 22:40:54.7527+00', 14651, 1, NULL, 'ace', '1–::

  1c set  | cross down RH (2c up) ; 1c set | cross RH and face out (2,1,3)

9–::

  Opposing Reels3 on the sides, 1c start Rsh to 3cnr (2,1,3)

17–::

  All cross RH | chase ¼ clw into lines across ; Cross RH up/down | chase ¼ round (to 3x,1x,2x), joining P and facing down for

25–::

  3c+1c+2c Allemande starting downwards, on [31-32] all cross LH to (2,1,3)

33–::

  1c+3c Bourrel (2,3,1)

', 2);
INSERT INTO 'dancecrib' VALUES (4133, '2013-08-21 08:30:44.024046+00', '2023-02-04 01:18:36.338629+00', 350, 3, NULL, 'ace', '1-8::
    1s set advancing, turn partner 2H, set facing up & cast to 2nd place
    own sides
9-12::
    1s dance DoSiDo _while_ 2s & 3s set advancing & turn 2H & cast back
    to places with 2s facing down & 3s up
13-16::
    1s turn RH 1.1/2 times to face 1st corners _while_ 2s+3s set
    advancing (up/down sides), turn to face out & cast back to places
17-24::
    2s+1s+3s dance reels of 3 on sides 1s giving RSh to 1st corners
25-32::
    1s dance out round 1st corner cross to own side & cast to 2nd places
    _while_ 2s & 3s dance DoSiDo & all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (11047, '2018-08-28 10:09:22.179797+00', '2022-01-29 00:44:15.451121+00', 680, 2, 2401, 'ace', '1- 8::
  1s cross, cast, ½ figure of 8 - M up L down, 2s step up 3&4
9-16::
  1M w 3s ‘circle and turn’ while 1L w 2s ‘circle and turn’   ({2},1,{3})  
  1m w 2s ‘circle and turn’ while 1L w 3s ‘circle and turn’   (2,{1},3)
17-24::
  2s,1s,3s, set and cross  
  2s,1s,3s set, 2s & 3s cross and face out. 1s turn RH and finish facing down RHs joined
25-32::
  ‘Reels of 3 on the sides with crossing’  
  1s cross down, 2s and 3s cast out, 3s pass through 2nd place before the 2s  
  all couples cross RH out the top/foot when they meet
', 2);
INSERT INTO 'dancecrib' VALUES (3032, '2012-01-22 19:30:07.640036+00', '2022-01-29 14:28:13.778341+00', 5316, 1, NULL, 'ace', '{{explanation}}

2c & 4c start on opposite sides (1,2x,3,4x)



1–::

  1c+4c cross RH, W staying in middle behind P | dance{4} clw, M leading, to diag. opposite places | 1M+4M cross and cast to own places _while{2}_ the W dance to own place giving RH (1,2x,3,4x)

9–::

  1c+2c & 3c+4c ½ M-Chain (all finish facing P) ; ½Reels4 on the sides, moving ¼ turn extra at the end to form lines across (from W side, at top: 3M,3W,4W.4M, and at bottom: 1M,1W,2W,2M), all facing P

17–::

  ½Reels4 across, merging with all M leading their W into ; ¾ circle8 L (finish 2c above 1c on L side, 4c above 3c on M side)

25–::

  All C turn BH ½ opening (L leading) into C NHJ facing C (4,2x,3,1x) | set up/dn ; 4c+2c & 3c+1c ½ circles4 L | set to P (2,4x,1,3x)', 2);
INSERT INTO 'dancecrib' VALUES (10327, '2017-12-22 15:43:53.024246+00', '2023-02-04 01:18:28.68592+00', 173, 3, NULL, 'ace', '1-8::
    1s lead down to 4th place & cast up behind own line to place _while_
    4s cast up to top & lead back down to bottom
9-16::
    Reels of 4 on sides (Ladies pass LSh, Men pass RSh to start) 2s & 3s
    omit final loop
17-20::
    1M+2L also 3M+4L change places passing LSh, 2L+4L cast down 1 place
    on opp sides _while_ 1M+3M cast up 1 place opp sides (1L+3L & 2M+4M
    step up/down bars 19-20)
21-24::
    1s+2s also 3s+4s dance LH across 1.1/4 round to end in original
    places
25-28::
    1L casts to bottom & partly across, 1M casts up to top and partly
    across _while_ 1M+4L change places RH to end 1s at bottom facing up
    (1L on 1M''s Left), 4s at top facing down (4L on 4M''s Right)
29-32::
    1s+4s advance to dance 1/2 RH across back to original places
33-40::
    1s cast, cross below 3s, cast up round 3s, then lead down crossing
    into 4th place own side (2s+3s+4s step up bars 39-40). End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (3256, '2012-01-22 19:30:17.806605+00', '2022-01-29 20:54:32.264414+00', 9501, 1, NULL, 'ace', '1–::

  1c set | lead down, cross below 3c {3} and cast up to top {3} _while_{8} 2c wait {2} | set ; lead down between 3c and cast up (1x,2,3)

9–::

  1c+2c Chain Progression: 1c+2c turn RH ¾ | 1W+2W turn LH 1½ _while_{2} 1M+2M chase clw ½ | 2c turn RH ¾ to top _while_{2} 1c turn RH 1½ to face 2cnr

17–::

  1c+2cnrs ½ Reel4, at end, 1c quick turn LH to face 1cnr ; ½ Reel4 with 1cnrs, 1c finish between end Couples

25–::

  3c+1W & 2c+1M in lines across set | 3c+2c change place on side RH _while_{2} 1c turn RH ¾ (2x,1x,3x) ; in lines set, all cross RH (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3465, '2012-01-22 19:30:26.624364+00', '2022-01-30 18:45:56.164009+00', 13582, 1, NULL, 'ace', '1–::

  1c set | Turn BH and face down, NHJ ; dance to bottom and cast up (2c up) to (2,1,3)

9–::

  2c+1c DblFig8 (1c cross up), 1c finish facing 1cnr

17-20::

  1c+1cnrs set _while{2}_ 2cnrs set diagonally | 1c dance round P by the R to face 1cnr position again _while{2}_ all cnrs chase 1 place clw

21-24::

  1c+facing corners set _while{2}_ other corners set diagonally | 1c dance round P by the R to 2plx _while{2}_ all cnrs chase 1 place clw  (3x,1x,2x)

25–::

  All C turn RH ½ and face P close by | set in lines of 3 (join H) and all face up; all C dance to top, casting off (2c looping) into (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (4032, '2013-08-21 08:30:42.251134+00', '2023-02-04 01:18:28.697835+00', 174, 3, NULL, 'ace', '1-4::
    1s+2s also 3s+4s dance RH across
5-12::
    1s+2s also 3s+4s dance diagonal reels of 4 across, 1M+2L pass LSh,
    1L+2M dance to left to start (3s+4s dance similar)
13-16::
    1s+2s also 3s+4s dance LH across
17-24::
    1s & 4s set, cast in 1place (2s+3s step up/down);  1s+4s+3s turn RH
    remaining in middle ready for …
25-32::
    1s+4s+3s dance Allemande.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9141, '2016-05-01 22:42:09.61462+00', '2022-01-30 20:17:58.848839+00', 16939, 1, NULL, 'ace', '1--::

  1c+4c dance to midline and (1M+4W pivoting) take promhold, W on the R, 1c facing M side and 4c facing W side (like start of Tournee) | dance out and cast L (2c+3c step to end) into ; 1c (promhold, down)+4c (promhold, up) ½ Lsh Fig8 through end couple 

9--::

  1c(promhold) on W side & 4c(promhold) on M side ½ Rsh Reels3 on the sides with their cnrs ; ½ Lsh Reels3 across: 1c(promhold)+3c at top & 4c (promhold)+2c below, finish (3x, 1c on M side , 4c on W side, 2x)

17--::

  All set | Circle8 L ½ all facing P | All turn P RH, 2c+3c to 1pl +4pl, and 1c (W side)+4c (M side) into promhold facing in

25--::

  1c+4c (dance in from sidelines) Tournee (2,4,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (10127, '2017-09-15 07:34:42.602971+00', '2022-01-31 09:38:59.864813+00', 6360, 2, NULL, 'ace', '*Note: in this dance, whenever two persons from different couples come face to face with each other, they dance part or all of a "tandem back-to-back" movement; for this both hands are joined as for a quick-time poussette, but skip-change step must be used, not pas-de-basque.*
1-8::
  1s set, cast 1 place (2s step up), 1s dance back-to-back
9-16::
  2s & 1s set NHJ on sides, 1s dance back-to back & cast back up to top places WHILE 2s cast and dance back-to-back (2 bars tandem back-to-back as 1s retire & 2s advance)
17-24::
  1s, 2s & 3s set NHJ on sides, 1s cross down (w/o hands) to back-to-back positions between 2nd places facing  opp. sides and dance inverted back-to-back, retiring first and ending back-to-back again, WHILE 2s & 3s cast up 1 place and dance back-to-back, 2s at top, 3s entirely (4 bars) in tandem with 1s
25-32::
  1s dance ½ figure of 8 crossing up RH between 2s (at top) & casting to 2nd places own sides WHILE 3s set & cast back down to 3rd places; then 1s & 3s dance 4-person diagonal back-to-back
', 3);
INSERT INTO 'dancecrib' VALUES (12378, '2019-12-03 18:08:14.963622+00', '2022-01-29 00:45:32.697524+00', 8500, 2, 160, 'ace', '1-8::
  1s cross down RH, cast behind 3s; dance up to 2place, Set as in DT. (2, 1x, 3)
9-12::
  1s turn 1cor RH - 1s pass Rsh as 1cor dance into place & face cw.
  *Meanwhile* 2cor dance a petronella  turn into the center + set.
13-16::
  1s and 2cor dance half reel of 4 on the centerline *while* 1cor chase half round the outside. 1s pass Lsh & end in middle - lady up, man down (3x 1 2x)
17-24::
  Teapots: 1W up with 3C, 1M down with 2C dance RH Across - 1s pass by Rsh - 1W down, 1M up dance LHA. (3x 1 2x)
25-32::
  Diagonal R&L - to begin dance 1W up, 1M down.', 3);
INSERT INTO 'dancecrib' VALUES (3105, '2012-01-22 19:30:11.463703+00', '2022-01-29 16:15:23.414353+00', 5552, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; cross LH and cast L round 4cnr to take 1cnr on R in promhold

9–::

  Promenade ½ round cclw and drop 1cnr at opposite corner _while{4}_ 2cnrs A&R diagonally ; 1c turn 1¾ LH to 2cnrs

17–::

  Repeat with 2cnrs _while{4}_ 1cnrs A&R ; 1c turn 1¼ LH to face 1cnr pos

25–::

  ½Reel4 with 1cnrs, pass Rsh ; ½Reel4 with 2cnrs, crossing Rsh to 2pl



{{explanation}}

This follows the original instructions. Those who find the time short for crossing on [31-32] can try an easier choreography, also flowing better into 2nd turn, as follows:



17–::

  Repeat with 2cnrs _while{4}_ 1cnrs A&R ; 1c turn 1¾ LH to face 3cnr (= 1cnr person)

25–::

  ½Reel4 with 1cnrs, pass Rsh and face 4cnr ; ½Reel4 with 2cnrs, finish in 2pl', 3);
INSERT INTO 'dancecrib' VALUES (14570, '2022-02-01 00:27:51.759179+00', '2023-01-13 23:20:54.142851+00', 20541, 1, 202, 'ace', '1--::

  1c cross down to 2plx (2c up) | set advancing into BtoB facing own sides ; 1c chase clw ½ to 2plx passing through setting couples then face clw _while{4}_ 2c & 3c Petronella turn to midline | set

9--::

  *Weasel Reel* : All continuously dance ½ Reel4 on midline, dancers who reach the end cast clw on sides and rejoin the reel at the other end. All finish as on [9]. Dancers entering and leaving the reel pass RSh.

17--::

  2c & 3c Petronella turn to opposite sides | 2c+1c+3c set ; all cross RH | set retaining hands (2,1,3)

25--::

  Circle6 L {4}, dance into centre, pivot R and chase back to places (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (3267, '2012-01-22 19:30:18.243398+00', '2022-01-29 20:59:50.999257+00', 9111, 1, NULL, 'ace', '{{explanation}}

First figure



1–::

  1M, 1W following dance between 2c, behind 2M, between 3c, behind 3M, between 4c, behind 4M, to places

9–::

  All circle8 and back

17-32::

  Repeat [1-16], 2c leading, and starting between 3c

33-48::

  Repeat [1-16], 3c leading, and starting between 4c

49-64::

  Repeat [1-16], 4c leading, and starting between 1c



{{explanation}}

Second figure



1–::

  1c+3c A&R ; Change places with opposite RH

9–::

  2c+4c A&R ; Change places with opposite RH

17-32::

  Repeat [1-16] to places



{{explanation}}

Third figure



1–::

  1c+3c advance | all clap 3 times ; 1c+3c retire | all clap 3 times

9–::

  2c+4c repeat [1-8]

17–::

  Joining hands in circle repeat [1-8]

24–::

  Circle8 and back, finish by advancing into centre raising hands with loud »Hooch«', 3);
INSERT INTO 'dancecrib' VALUES (3456, '2012-01-22 19:30:26.264837+00', '2022-01-30 18:49:49.614153+00', 10578, 1, NULL, 'ace', '1–::

  1c+2c+3c set | cross RH ; set | Turn P LH ½ into promhold facing up

9–::

  1c+2c+3c Allemande (3,2,1,4)

17–::

  All set | turn P RH ½ into ; 3c+2c & 1c+4c circle4 L (3x,2x,1x,4x)

25–::

  Parallel Reels4 on the sidelines (to 3x,2x,1x,4x)



{{explanation}}

For the next round top and bottom are interchanged.', 3);
INSERT INTO 'dancecrib' VALUES (9348, '2016-10-06 07:18:03.623861+00', '2023-02-04 01:18:28.829711+00', 17221, 3, NULL, 'ace', '1-8::
    1s turn RH & cast to 2nd place, turn LH 1.1/2 to end facing 1st
    corners
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh to face
    2nd corners, 1s dance 1/2 diagonal reel of 4 with 2nd corners (1s
    face out)
17-24::
    1s cast to their right _while_ corners dance DoSiDo; 1s dance around
    set to 2nd place on opposite sides
25-36::
    3s+1s+2s dance R&L for 3 couples (3) (1) (2)
37-40::
    3s+1s+2s chase 1/2 way clockwise   2 1 3
41-48::
    1s set, petronella into centre of set (3s step up); 3s+1s dance RH
    across with1L casting into 3rd place at end   2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (9557, '2017-01-25 03:35:59.948201+00', '2022-01-31 09:41:58.465551+00', 10963, 2, 940, 'ace', '1-8:: 1st couple lead down the middle and back to top place

9-12:: 1st couple, giving right hands, cross over and cast off 1 place (2''s stepping up)

13-16:: 1st couple, giving left hands, cross over and cast, woman up around 2nd woman and man down around 3rd man to finish approaching 1st corners

17-20:: 1st couple dance half reels of three across the dance begin by giving right shoulder to 1st corner. At end of reel 1st couple curves right to finish facing 1st corner positions on the diagonal

21-24:: 1st couple dance a half reel of four with persons now in 1st corner positions (2nd woman and 3rd man). At end of reel, 1st couple do not pass each other with left shoulder, but curves right to finish in 2nd place on opposite sides.

25-32:: All three couples dance "George''s cross": *All three couples dance petronella turn and set to bring everyone back to own sides in progressed positions. For 1st couple, 2nd man and 3rd woman this is a ''normal'' petronella turn and set pattern. 2nd woman and 3rd man do an extra quarter turn on bars 25-26 so they are positioned behind their own sidelines facing inwards to each other for setting on bars 27-28. Similarly they do an extra quarter turn on bars 29-30 so that they are in new positions on own sides facing partners for setting on bars 31-32*.', 0);
INSERT INTO 'dancecrib' VALUES (14564, '2022-01-26 01:32:48.293101+00', '2022-01-31 17:06:21.917508+00', 17826, 1, 202, 'ace', '1-12::
  3C R&L (1,2,3)
13-16::
  1c dance down between 3c | cast up (2c up). On [15-16] 2c dance up and face out (2,1,3)
17--::
  Mirror Reels3 on sides, 1c in and up, 3c in then casting up. 1c & 3c loop to places at end (2,1,3)
25--::
  3C Knot (3,1,2)', 2);
INSERT INTO 'dancecrib' VALUES (7355, '2013-08-21 08:31:39.276324+00', '2023-02-04 01:22:30.653137+00', 14698, 3, NULL, 'ace', '1-8::
    1s & 4s chase clockwise back to places _while_ 2s+3s dance Tournee:
::
    _1- 4_  2s+3s dance into prom hold (Men with partner on right, 2s
    face Men''s side & 3s face Ladies side), both couples wheel
    anticlockwise 1/2 way & Men turn Ladies into middle
::
    _5- 8_  Both couples turn 1.1/2 times (3s RH, 2s LH) & dance out to
    places.  1 3 2 4
9-16::
    1M face 3M also 2M face 4M & 3L face 2L set & turn 2H, 1L face 3L
    also 2L face 4L & 3M face 2M set & turn 2H
17-24::
    All set & 1s+3s also 2s+4s dance 3/4 R&L.  3 1 4 2
25-32::
    All circle 8H round to left & pivot left & continue circle left back
    to places', 0);
INSERT INTO 'dancecrib' VALUES (14571, '2022-02-01 16:48:21.434224+00', '2022-02-01 16:49:03.034384+00', 17964, 1, 202, 'ace', '1--::

  1c+2c *Rose Progression* : 1W+2M change place RH | chase 1 place clw ; turn BH ½, face and cast away _while{8}_ 1M+2W set | turn BH ½, face and cast away | chase 1 place clw] (2,1,3)

9--::

  Reels3 on sides, 1c RSh to 2c. 1c face 1cnrs

17--::

  SetH&G. On [23-24] Petronella turn to 2pl (2,1,3)

25--::

  1c+3c The Tournée (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (7356, '2013-08-21 08:31:39.284335+00', '2023-02-04 01:22:30.683496+00', 9239, 3, NULL, 'ace', '1-4::
    1L+2M also 1M+2L turn RH, 1s pass RSh to face 2s (in line across, 1L
    facing 2L, 1M facing 2M)
5-8::
    1s turn 2s LH & pass LSh to end 1M facing 2L, 1L facing 2M
9-16::
    1s+2s dance reel of 4 across. At end 1s meet facing up, 2s curve in
    behind ready for …
17-24::
    1s+2s dance Allemande
25-32::
    1s cross down b''tw''n 3s & cast up 2nd place _while_ 2s & 3s set &
    cross RH, 1s cross up & cast to 2nd place own sides _while_ 2s & 3s
    set & cross RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14331, '2021-09-20 10:05:13.954765+00', '2022-01-29 00:51:20.827497+00', 14481, 2, 2697, 'ace', '1-8::
  W Adv+Ret twice (join and raise up hands in the middle like trees and
  release slowly while retiring, making an arch as long as it is comfortable))  
  _while{8}_ M stand still 2 bars, Adv (through the releasing arches) + Retire
  (like the ladies before), stand still 2 bars
9-12::
  All set (HS) to P
13-16::
  All turn P RH 1½ (M finish facing out)
17-24::
  All dance interlocking reels of 4 across (W start immediately with a quick ½ LHA in the middle)
25-32::
  All ½ "Wasabi” reel
33-40::
  All turn BH 1½ ; All circle left one place, all cast on the spot left about

Wasabi reel: almost like a Schiehallion reel but ladies lead and men follow their partners', 2);
INSERT INTO 'dancecrib' VALUES (9240, '2016-06-16 22:42:19.893973+00', '2023-02-04 01:22:30.880341+00', 16832, 3, NULL, 'ace', '1-4::
    1s lead down middle & cross over & cast up to 2nd place _while_ 2s
    set & cross RH to 3rd place _while_ 3s cast up to 1st place & cross
    ("Muirland Willie" Figure)
5-8::
    All set & cross RH to own side
9-16::
    Repeat bars 1- 8 from new positions   2 3 1
17-24::
    All petronella turn and set.  All turn partners 2H once round
25-32::
    Circle 6 hands round and back', 0);
INSERT INTO 'dancecrib' VALUES (12704, '2020-04-06 23:08:32.7335+00', '2022-01-29 16:17:49.468372+00', 15866, 1, NULL, 'ace', '1--::

  1c+4c (start inwards) Fig8 round nearest two dancers on own side, touch NH when meeting P (1,2,3,4)

9--::

  2c+3c Tourbillon (1,3,2,4)

17--::

  1c facing 3c & 2c facing 4c Set and turn opposite RH ¾ into lines across ; on both lines ½ Reels4 across 

25--::

  In both lines, outers facing middles set and turn RH ¾ ; ½ Reels4 on the sides (4x,2x,3x,1x)

33--::

  4c+2c & 3c+1c RHA ;  4c+2c & 3c+1c  chase ½ clw | All set  (2,4,1,3) 

', 2);
INSERT INTO 'dancecrib' VALUES (8634, '2015-02-13 12:48:15.685922+00', '2023-02-04 01:22:30.903839+00', 15570, 3, NULL, 'ace', '1-4::
    1s cross over RH and cast off one place, _while_ 2s move up [3-4]
    and face out.
5-8::
    1M and 2L turn RH, _while_ 1L and 2M turn LH. 1s finish the turn
    side by side facing up, _while_ 2s, turning towards each other,
    finish side by side at the top, facing down.
9-16::
    All set, circle 4 hands once round to the left finishing on the
    sidelines, and set facing across. (2,(1))
17-24::
    2s and 1s dance »The Swirl«:
::
    _17-18_: 2s and 1s dance 1/2 RH turn with partner, finish in
    Allemande hold facing the other couple up (1s) or down (2s).
::
    _19-20_: Both couples set advancing, passing each other, to finish
    back to back with the other couple. Keeping left hands joined, they
    release right hands and, turning towards partner, form a left hand
    wheel. (1,(2))
::
    _21-24_: LHA.
::
    (Note: The two couples finish the swirl having changed places and
    sides.)
25-32::
    Half R&L, then 2s stand, _while_ 1s turn BH 1.1/2 to own sides.', 0);
INSERT INTO 'dancecrib' VALUES (12569, '2020-02-07 16:14:46.986108+00', '2022-01-29 21:14:31.496541+00', 12805, 1, NULL, 'ace', '1--::

  1c long cast to 2pl (2c up) ; Turn LH to face 1cnr 

9--::

  2c+1W & 1M+3c ½ Lsh Reel3 across ; 2c+1M & 1W+3c ½ Lsh Reel3 across, 1c finish in middle, Lsh to Lsh, facing 4cnr

17--::

  2c+3c R&L starting up/down _while{8}_ 1c fig8 round end cpl positions (Rsh round 4cnr, Lsh round 1cnr), finish on midline for

25--::

  2c+1M & 1W+3c RHA ; LHA (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (3448, '2012-01-22 19:30:25.936924+00', '2022-01-30 19:03:15.023245+00', 6798, 1, NULL, 'ace', '{{explanation}}

Square 4C set, 5c in middle facing 1c ; 6c facing 3c



1–::

  1c+2c+3c+4c ½ circle8 left ; set advancing (keep hands) and cast R out to new places _while{8}_ 5c+6c set to P | set diagonally to centre ; LHA

9–::

  3c+5c+6c+1c parallel Reels4, 5c+6c do not pass last Lsh but swivel R to face nearest side couple

17–::

  2c+5c+6c+4c parallel Reels4 across, 5c+6c do not pass last Lsh (5c+6c have now changed places)

25–::

  Each centre person (5M, 5W, 6M & 6W) RHA with their nearest two corners ; 5c+6c ½ LHA _while{2}_ others chase ¼ clw, 1c+3c (on sides) RH turn _while{2}_ 2c+5c & 4c+6c (top/bottom) ½ RHA (5,3,6,1,2,4)

', 2);
INSERT INTO 'dancecrib' VALUES (12424, '2019-12-05 01:32:01.854622+00', '2023-02-04 01:22:30.93472+00', 17531, 3, NULL, 'ace', '1-8::
    1s cross down RH, cast up behind 2s to 1st place, 1M+2L turn 1.1/2
    LH _while_ 1L+2M turn 1.1/2 RH touching hands when possible 2 (1) 3
9-16::
    1M+3L turn 1.1/2 RH _while_ 1L+3M turn 1.1/2 LH. 1s cross up RH
    between 3s & cast down to 3rd place 2 3 1
17-24::
    3s+1s set,1s cast up to 2nd place _while_ 3s dance down to 2nd
    place. 2s+1s repeat bars 17-20. 1 2 3
25-32::
    1s turn RH cast 1 place, 2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (12262, '2019-10-01 18:48:07.052308+00', '2022-01-30 20:26:10.609778+00', 17848, 1, NULL, 'ace', '1--::

  1c set and cross RH ; All chase clw ½ round (3x,2x,1)

9--::

  2c+3c set and cross RH ; All chase clw ½ round (1x,2x,3x) 

17--::

  [Variation of 3C set & rotate]  All set | All cast (or cross) to next position clw in the 6 places of the set ; All cross the set RH | All chase one place clw as before (1,2,3)

25--::

  1c+2c set and ½ RHA ; 1c+2c set and cross RH (2,1,3)

', 4);
INSERT INTO 'dancecrib' VALUES (7357, '2013-08-21 08:31:39.377907+00', '2023-02-04 01:22:30.95542+00', 6167, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & LH across back to place
9-16::
    1s turn RH & cast 1 place, cross RH & cast right round 1st corners
    to end in lines of 3 across
17-24::
    1L+2s & 1M+3s turn opposite dancers RH & circle 6H round to left 1/2
    way 1s end facing 3rd corner (pstn)
25-32::
    1s dance 1/2 diagonal reels of 4 with 3rd corners & 1/2 reel with
    4th corners (pstn)
33-40::
    1s turn 1st corners RH & partner LH, 2nd corner RH & pass partner
    LSh to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (10394, '2018-01-19 02:16:22.915308+00', '2022-02-01 16:49:03.0315+00', 17964, 2, 963, 'ace', '1-8::

       1c+2c dance Rose Progression

9-16::

     2c+1c+3c R3 on sides, 1c Rsh to 2c. At the end of the reel, 1c pass Lsh to face 1st cnrs (1W thru 2nd place, 1M up btwn 3s)

17-24::

   1c dance Hello/Goodbye with petronella turn to 2nd place own side

25-32::

   1c+3c dance the tournee          2,3,1', 3);
INSERT INTO 'dancecrib' VALUES (7358, '2013-08-21 08:31:39.482734+00', '2023-02-04 01:22:31.1917+00', 12532, 3, NULL, 'ace', '1-8::
    1s cross RH, cast to 2nd place & dance 1/2 Fig of 8 (1L round 2s &
    1M round 3s) ending BtoB facing own sides (2s up)
9-16::
    2s+1s+3s dance Petronella Double Triangles :
::
    1s dance normal Double Triangles & end BtoB Lady facing up & Man
    down _while_ corners set, petronella on 1 place anticlockwise, set &
    petronella on 1 place anticlockwise
17-24::
    1L+3s (at top) dance RH across _while_ 1M+2s dance RH across, 3M
    followed by 3L+1L also 2L followed by 2M+1M chase clockwise 1/2 way
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9753, '2017-04-06 08:40:15.857465+00', '2023-02-04 01:22:31.212072+00', 16567, 3, NULL, 'ace', '1-8::
    1s cast 1 place, turn 3/4 RH & dance LH across (1L+2s & 1M+3s) to
    end facing each other just inside 2nd place on opposite sides
9-16::
    1s set, turn 2H & dance 1/2 fig 8, 1L round 2s (pass 2L RSh) & 1M
    round 3s (pass 3M RSh) to end 2 1 3
17-24::
    1L+2M & 1M+3L dance 1/2 way round each other RSh, pull back RSh &
    dance out into each other''s places. All cross RH & set
25-32::
    1L+2M & 1M+3L dance 1/2 way round each other RSh, pull back RSh &
    dance out into each other''s places.  All cross RH then1s+3s cross LH
    on sides.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (11349, '2018-11-25 13:39:55.361423+00', '2022-01-29 00:52:45.187425+00', 18407, 2, 2697, 'ace', '1-8::
  1s dance in | cast to 2nd place; 2s, 1s and 3s ½ turn RH | 2s and 3s twirl to
  opposite sides, as 1s twirl to face 1st corners.
9-16::
  1s dance Pass and Turn with 1st corners, pass with right shoulder to face 2nd corners; 1s dance Pass and Turn with 2nd corners, pass with right shoulder, ending on 2nd place own sides facing 3s.
17–24::
  2s, 1s and 3s dance Grand Chain, end with 1L and 2L facing out.
25–32::
   2s and 1s dance Ladies'' Chain (M dance like L crossing by the right hand).
33–40::
   2s, 1s and 3s dance Set and Rotate for 3 couples. The finishing order is (3x, 1, 2x).
41–48::
   1s dance RH across (1L with 3s and 1M with 2s); 3s and 2s turn RH 1½, _while{4}_ 1s turn RH once round.', 2);
INSERT INTO 'dancecrib' VALUES (12225, '2019-09-16 09:30:36.166893+00', '2022-01-29 16:28:29.35614+00', 19647, 1, 202, 'ace', '1--::

  1c set | 1W followed by 1M casts off 2, 1W crosses below 3c and casts up Mside _while_ 1M dances up the middle, 1c to 2plx (2c up on [7-8]) (2,1x,3)

9--::

  Parallel Reels3 on sides, 1c LSh to 2c. 1c in 2pl centre face up (no hands) (2,1x,3)

17--::

  1c dance up (no hands), turn 2c EH ¾ to 2plx _as_ 3c pivot towards top and face out ; 1c turn 3c EH (polite turn) (2,1x,3)

25--::

  All A&R ; 1c turn P RH 1½ (2,1,3)', 4);
INSERT INTO 'dancecrib' VALUES (3305, '2012-01-22 19:30:19.798871+00', '2022-01-29 21:18:54.782237+00', 8709, 1, NULL, 'ace', '{{explanation}}

5c (dancing couple) stands facing 1c in centre of square set, numbered clw as usual.



1–::

  5c parallel Lsh Reels3 with 1c+3c

9–::

  5M+4c LHA _while{4}_ 5W+2c RHA ; 5c dance (NHJ) between 1c, divide, 5M(5W) casting left(right) round 1W(1M) back into the centre for

17–::

  5M+4c RHA _while{4}_ 5W+2c LHA ; 5c dance (NHJ) between 3c, divide, and cast back round 3M(3W), into the centre

25–::

  5c with RH elbow-grip (Kilt grip) make any (eg. tulloch) turn {4} ; 5c face 1c and set, ½ LHA to finish with 5c in 1pl and 1c in the middle facing 2c (i.e. next couple clw) to start again.



{{explanation}}

After 5 times through, 5c finish in the middle, all other C have moved one place clw', 2);
INSERT INTO 'dancecrib' VALUES (4033, '2013-08-21 08:30:42.25927+00', '2023-02-04 01:18:28.842046+00', 178, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L+4L dances across & down Men''s side, across at
    bottom & back to place _while_ 1M followed by 2M+3M+4M cross above
    Ladies, down Ladies'' side, across & back to place (each Man crosses
    behind his partner but in front of the next Lady)
9-16::
    All dance reels of 4 on sides (1s & 3s dancing in & down to start)
17-24::
    1s+2s also 3s+4s dance the Rondel ending 1s+4s+3s facing down with
    nearer hands joined
25-32::
    1s+4s+3s dance down for 3 steps, 3s turn & dance up to 2nd place as
    1s & 4s divide & 1s dance down to bottom.  2 3 4 1', 4);
INSERT INTO 'dancecrib' VALUES (3445, '2012-01-22 19:30:25.824163+00', '2022-01-30 19:16:16.532514+00', 6792, 1, NULL, 'ace', '1--::

  1M+2c Reel3 (Lsh to 2W), picking up 1W in promhold on [5].

9--::

  1c (opp. side) dance down, change side, W passing under M’s arm ; dance up (1,2,3)

17--::

  1c set | dance down 2 places ; cast up one | dance up and face out _while{8}_

::

  2c wait{2} | set ; dance down 1 place | cast up and face in _while{8}_

::

  3c wait{4} ; set | touch hands facing down and face out (1,2,3)

25--::

  Reels3 on the sides, (2c in and up) (1,2,3) 

33--::

  1c+2c Half Rondel (3 bars of Rondel in {4} ; set to P | cross LH) (2,1,3)

', 3);
INSERT INTO 'dancecrib' VALUES (11261, '2018-10-12 20:18:37.297449+00', '2022-01-30 20:53:34.912516+00', 18951, 1, NULL, 'ace', '1--::

  All interlocking Reels4

9--::

  All M dance to next M place R | All Rotate clw on the spot (PdB) ; All W dance to next W place L | All rotate on the spot

17--::

   Cpls in 1pl & 3pl ½ L-Chain ; cpls in 2pl & 4pl ½ L-Chain

25-40::

  All balance* to P RHJ | ¼ Gr-Chain ; repeat [25-28] 3 times (2,3,4,1)  



*Balance is danced with the rhythm of a pas de Basque:  

Bar 1: Leap forward on to right foot, bring left foot to 3rd position rear, step again on right foot.  

Bar 2: Leap back on to left foot, bring right foot to 3rd position, step again on left foot.*   

', 3);
INSERT INTO 'dancecrib' VALUES (4034, '2013-08-21 08:30:42.345569+00', '2023-02-04 01:18:29.010333+00', 189, 3, NULL, 'ace', '1-8::
    1s cast 1 place, cross RH, cast round 1st corner & pass RSh round
    partner to face 1st corner
9-16::
    Set to & turn 1st corner 2H, turn partner LH 1.1/4 times to face 2nd
    corner
17-24::
    Set to & turn 2nd corner 2H, turn partner LH 1.1/2 times to 2nd
    place own side
25-32::
    1s dance reel of 3 on own sides (LSh to 4th corner)
33-64::
    Repeat above Figs in Reel time with 3s+4s', 0);
INSERT INTO 'dancecrib' VALUES (2383, '2012-01-22 19:29:34.656345+00', '2022-02-01 20:43:39.378353+00', 9862, 1, NULL, 'ace', '1–::

  1c cross RH and face down | 1c+2c ½ LH turn on the sides ; all chase cclw one place | all turn P ¾ LH into a line across (W BtoB)

9–::

  Gypsy Poussette, as follows.

9-12::

  (Box setting) All set R and swivel R ¼ »on the hop« to face away from P, all set L and swivel R ¼. to face in | all set R (M passing BtoB) and swivel R ¼, all set L and do not swivel. Partners finish facing away from each other but are not lined up BtoB.

13-16::

  (Gypsy turn) All starting to their own R, dance around P halfway and melt into turn ¾ BH to finish facing P in a line across, M in the middle.

17–::

  Reel4 across the dance. On [24] the M dance ¼around each other, Lsh to Lsh, _while_ the W extend the loops to join P in promhold, all forming a line across, 1c facing up, 2c down.

25–::

  [25] 1c+2c Promenade ¼ around each other (M staying Lsh to Lsh), into the last 7 bars of the Tournée.



{{explanation}}

Notes: In [9-12] each C follows the edges of a square

', 2);
INSERT INTO 'dancecrib' VALUES (4135, '2013-08-21 08:30:44.040527+00', '2023-02-04 01:18:36.387395+00', 353, 3, NULL, 'ace', '1-8::
    1s dance RSh round each other & dance 6 bars of Crown Triangles
    (start with 1M facing 3s & 1L facing 2s). End 1M facing up, 1L
    facing down
9-16::
    1s dance diag RSh reel of 4 with 2nd corners, 1s pass RSh
17-24::
    1s dance diag RSh reel of 4 with 1st corners, 1s pass RSh to end in
    2nd place on opp sides
25-32::
    1s set & cast 1 place, cross over RH & change places LH on side with
    4s.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7359, '2013-08-21 08:31:39.490045+00', '2023-02-04 01:22:31.237789+00', 14318, 3, NULL, 'ace', '1-8::
    1s turn RH & turn LH
9-16::
    1s+2s dance RH across then LH across
17-24::
    1s+2s+3s circle 6H round & back
25-32::
    1s+2s+3s+4s Adv+Ret twice
33-40::
    5s lead up to top & cast back to places
41-48::
    1s cast to bottom & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (1600, '2012-01-20 13:06:12.852223+00', '2022-01-29 00:58:38.573545+00', 12401, 2, 136, 'ace', '1-8::	1C TRH & cast 1 pl. 1M ½ fig 8 rnd 3C pos & 1W ½ fig 8 rnd 2C pos as  2+3C ½ rts & lfts - on side first.
9-12::	1M+2C LHA, (down) 1W+3C LHA (up).
13-16::	1C ½ Turn & Twirl (face out)
17-24::	1C cast R, come into centre back to back, M face up, W down. Set in Crown Triangles pos, move ¼ rnd & set again. (finish facing 1st cnr pos)
25-32::	½ diag reel with 1st cnrs & pass RS to ½ reel with 2nd cnrs, pass RS to own side.
33-40::	6 hands rnd & back.

', 3);
INSERT INTO 'dancecrib' VALUES (3945, '2013-08-21 08:30:39.947708+00', '2023-02-04 01:18:22.94969+00', 10962, 3, NULL, 'ace', '1-8::
    All set advancing & turn partners 2H to face up, 1s followed by
    2s+3s+4s dance up & cast to 4 3 2 1
9-16::
    All repeat bars 1-8 to original places
17-24::
    1s+2s dance RH across 1/2 way & 1s+3s dance RH across 1/2 way, 1s+4s
    dance RH across 1/2 way & all cross RH
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12684, '2020-03-23 23:14:34.539329+00', '2022-01-29 21:29:52.898115+00', 19904, 1, NULL, 'ace', '*Start (1,2,3x,4x)*   

1--::

  1c /4c both dance inwards along the middle and turn 2c/3c EH on the sides, finish 2c/3c in 1pl/4pl and 1c between 2c facing 4c between 3c ; 1c+4c A&R up/down

9--::

  1c+4c cross up/down, 1c NHJ passing between 4c, then 4c between 2c and 1c between 3c, turn EH ¾ on the sides to (2,4x,1,3x) ; 4c+1c (face P and join hands) A&R across (2,4x,1,3x)

17--::

  4c+1c cross (4M+1W NHJ pass between the others) | turn end couples EH ¾ into lines across, 4c (between 2c) facing 1c (between 3c) ; 1c+4c turn opposite BH, opening into

25--::

  Circle8 and back (2,4,1x,3x)

', 3);
INSERT INTO 'dancecrib' VALUES (3946, '2013-08-21 08:30:39.957537+00', '2023-02-04 01:18:22.974639+00', 10113, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    2s dance up 1 place, cast & dance down between 3s & cast to face 1st
    corners
17-24::
    2s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    Pass+Turn with 2nd corners
25-32::
    1s+2s+3s dance the Knot with 3s+2s dancing 1/2 LH across to end 2 3
    1', 0);
INSERT INTO 'dancecrib' VALUES (2062, '2012-01-22 19:29:17.69285+00', '2022-02-01 22:46:47.307608+00', 10793, 1, NULL, 'ace', '1–::

  1c cross RH | cast (2c up) ; dance between 3c and cast up to join LH and RH with 2cnr

9–::

  BiL on 2diag, swivel to face 2cnr | set to 2cnr ; turn 2cnr RH, passing Lsh to face 3cnr pos. _while{8}_   cnrs set diagonally | chase clw ½ round set | set diagonally

17-20::

  1c+1cnrs ½ diag Reel4, finish LHJ and RHJ with 1cnr (now back in own place)

21-28::

  BiL on 1diag, swivel to face 1cnr | set to 1cnr ; turn 1cnr RH, passing Lsh to face 2cnr _while{8}_   2cnrs set diagonally | chase clw ½ round set | set diagonally

29-32::

  1c+2cnrs ½ diag Reel4, at end touch LH into

33–::

  2c+1W & 1M+3c RHA, pass Rsh | 2c+1M & 1W+3c LHA (2,1,3)', 3);
INSERT INTO 'dancecrib' VALUES (14572, '2022-02-02 03:03:39.737551+00', '2022-02-02 03:15:50.116889+00', 15341, 1, 202, 'ace', '1--::
  1c (2c,3c & 4c following) lead down ; cross and cast up to P places (1x,2x,3x,4x)
9--::
  1c & 3c Petronella turn to midline | set ; Petronella turn to own sides | set (1,2x,3,4x)
17--::
  1c+2c ½ R&L (polite turn) (to 2,1x,3,4x) ; 1c+3c S&Link on sides (2,3,1x,4x)
25--::
  1c+4c set | ½ RHA ; 1c set | turn P BH (2,3,4,1)', 3);
INSERT INTO 'dancecrib' VALUES (8635, '2015-02-13 12:48:15.823635+00', '2023-02-04 01:22:31.260216+00', 15571, 3, NULL, 'ace', '1-8::
    1s cross over RH, cast one place. (2s up), 1s dance petronella turn,
    1M between 2s, 1L between 3s, and all set in lines across.
9-16::
    Opposing Reels of 3 across, 1s give RSh to 3rd corner to start.
17-24::
    1s petronella to 2nd place own sides, all set on the sidelines, all
    Adv+Ret.
25-32::
    Six hands round and back.', 0);
INSERT INTO 'dancecrib' VALUES (14574, '2022-02-02 23:18:14.956958+00', '2022-02-02 23:24:24.304229+00', 2386, 1, 202, 'ace', '1--::

  1c turn P RH 1½ to 2plx ; dance RSh round 1cnrs into facing lines3 across | all set

9--::

  ½ Reels3 on opposite sides, 1c LSh to 2cnrs ; ½ Reels3 on own sides, LSh to 4cnrs. 1c finish LHJ with P RHJ with 1cnrs

17--::

  BiL on 1diag | 1c turn 1cnrs RH ; turn P LH into 2diag joining RH with 2cnrs

25--::

  BiL on 2diag | 1c turn 2cnrs RH ; turn P LH to 2pl (2,1,3)', 2);
INSERT INTO 'dancecrib' VALUES (14573, '2022-02-02 18:31:57.61313+00', '2022-02-02 18:44:18.08961+00', 5455, 1, 1645, 'ace', '1--::

  1c & 4c petronella to centre line (2c & 3c step outwards) | all set ; 1c+2c & 3c+4c &frac12; RHA | all set

9--::

  1c+4c &frac12; Reel4 on centre line ; 1c & 4c turn &frac34; BH | cast inwards (2x,4x,1x,3x)

17--::

  All set on sides | 2c+4c & 1c+3c RHA | all set on sides

25--::

  All &frac12; Reels4 on sides ; chase &frac12; way clw (2,4,1,3)

', 2);
INSERT INTO 'dancecrib' VALUES (7360, '2013-08-21 08:31:39.580195+00', '2023-02-04 01:22:31.278053+00', 14810, 3, NULL, 'ace', '1-4::
    1s turn RH
5-8::
    1s+2s dance RH across
9-16::
    2s+1s+3s circle 6H round & back
17-24::
    1s+2s+3s+4s Adv+Ret & dance DoSiDo
25-32::
    1s slip step down the centre & back
33-40::
    1s followed by 2s+3s+4s cast to bottom & 1s form arch as 2s+3s+4s
    dance under arch & up to top', 0);
INSERT INTO 'dancecrib' VALUES (14575, '2022-02-03 23:59:01.85929+00', '2022-02-03 23:59:13.387464+00', 20659, 1, 1645, 'ace', '1--::

  1c & 4c chase once round clw & curve in to midline, M facing down, W up

9--::

  1c+2c & 3c+4c RHA ; LHA back, 1c & 4c end facing on midline

17--::

  1c+4c LSh Reel4 on midline, 4c end on the sides, 1c face up

25--::

  1c cast off to 4pl (2c+3c+4c step up) ; all turn P RH (2,3,4,1)

::

  *NB crib derived from the video*

', 2);
INSERT INTO 'dancecrib' VALUES (7361, '2013-08-21 08:31:39.588416+00', '2023-02-04 01:22:31.297977+00', 9893, 3, NULL, 'ace', '1-8::
    1s & 4s set, cast in 1 place & circle 4H round to left
9-16::
    1s+4s set, dance 1/2 RH across, set & cross RH _while_ 2s & 3s set,
    turn RH (4 bars) & set
17-24::
    1L followed by 4L dance down behind 3L & up to the middle 2nd/3rd
    place opp side _while_ 4M followed by 1M dance out behind 2M & down
    to 3rd/2nd places, 1s+4s dance 1/2 R&L
25-32::
    All Adv+Ret & 2s+4s also 1s+3s circle 4H round to left.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7362, '2013-08-21 08:31:39.596402+00', '2023-02-04 01:22:31.315888+00', 10855, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s dance 1/2 Fig of 8 round 2s
9-16::
    All dance Grand Chain,
17-24::
    1s turn RH & cast 1 place, 1s dance 1/2 Fig of 8 round 3s
25-32::
    3s+1s dance R&L.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7363, '2013-08-21 08:31:39.606137+00', '2023-02-04 01:22:31.34012+00', 14967, 3, NULL, 'ace', '1-8::
    1s cross RH, cast, dance 1/2 Fig 8 round 3s (2s step up bars 3-4)
9-16::
    1s lead down the middle and back to 2nd place
17-24::
    2s+1s+3s join hands on sides Adv+Ret, all turn partners RH into
    promenade hold
25-32::
    2s+1s+3s dance Promenade', 0);
INSERT INTO 'dancecrib' VALUES (8925, '2015-09-24 14:54:20.573299+00', '2022-01-29 00:59:35.905697+00', 2416, 2, 160, 'ace', '1-8::
  Top 2 cpls and bottom 2 cpls dance Half R&L ;
  All Cross RH, end cpls set *while* middle cpls (1s with 4s) turn with LH 3/4 on the sides into line of 4 across - 1M 4L join RH.
9-16::
  1C 4C Balance, Turn LH half round ; Balance, turn LH 3/4 round. End 2,1,4,3.
17-24::
  Half Reel4 on sides  ;  On the ends of the reel - all turn RH once round - 4C 1C pass by Rsh to end  3,1,4,2.
25-32::
  All set, Men arch and all cross by Rsh to opposite side ;
  All chase CW back to own sides. Order is 2,4,1,3.', 0);
INSERT INTO 'dancecrib' VALUES (9943, '2017-06-06 23:43:28.514915+00', '2022-08-05 17:01:42.437976+00', 14728, 1, 202, 'ace', '1--::

 1c set | cast (2c up) ; ½ Fig8 down (2,1x,3)

9--::

 Mirror Reels3, 1c cross to 1pl, 2c & 3c ending with loop (2,1,3)

17--::

 All set | cross RH ; set | 2c cross LH _while_ 1c & 3c turn LH ¾ to midline

25--::

 1c+3c H.Schottische Poussette (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (3108, '2012-01-22 19:30:11.621653+00', '2022-01-30 18:04:32.774025+00', 5574, 1, NULL, 'ace', '1–::

  1c cross RH | cast behind sideline (2c up), turn inwards and dance to between 2c all facing down NHJ

9–::

  In line across dance down the middle ; swivel towards opposite P and lead up RHJ to (2,1x)

17–::

  2c+1c R&L

25–::

  1c set twice ; cross over to 2pl own sides (2,1)', 3);
INSERT INTO 'dancecrib' VALUES (11761, '2019-04-02 20:32:27.377751+00', '2022-03-12 22:45:18.816728+00', 19254, 2, NULL, 'ace', '1-4::

  1 s & 3s petronella turn and set.

5-8::

  1st lady leads her partner to 3rd place (clockwise) as 3rd man leads his partner to 1st place (clockwise). (1s & 3s finish on opposite sides) Meanwhile 2s petronella turn twice to finish in 2nd place on opposite sides of the dance. The 2nd man finishes facing down and the 2nd lady finishes facing up. 

9-12::

 All three couples chase clockwise round the dance to finish in their original places.

13-16::

  1s, 2s & 3s turn right hands to finish in the middle of the dance facing down.

17-20::

  With 3s leading, all three couples lead down the dance for four bars and turn about to face up the dance.

21-24::

  With 1s leading all three couples lead up the dance to original places. 1s finish facing out.

25-32::

  1st man with left hand & 1st woman with right hand, turn 2s 1½ times. 2nd couple finish in 1st place. 1st man with right hand and 1st woman with left hand turn 3s once round.



*Deviser''s note* : On the second time through or in a three couple set 1s turn 1½ times on bars 29-32 to finish at the bottom of the dance.', 2);
INSERT INTO 'dancecrib' VALUES (3959, '2013-08-21 08:30:40.094494+00', '2023-02-04 01:18:23.499471+00', 14557, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 2 places, 1s cross RH & cast up to 2nd place
9-16::
    2s+1s set & dance RH across 1/2 way, set & dance LH across 1/2 way
17-24::
    1M+3L turn 2H, 1L+3M turn 2H
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4035, '2013-08-21 08:30:42.357464+00', '2023-02-04 01:18:29.026327+00', 8528, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place to face 1st corner, set to 1st corner, set to
    2nd corner & end facing 2nd corner
9-16::
    1s dance diagonal reel of 4 with 2nd corners end (1s end LSh to LSh
    with 1M facing up)
17-24::
    1M dances RH across with 2L+3L _while_ 1L dance RH across with 2M+3M
    (2s & 3s end in places & 1s in 2nd place opp side facing out),
    2s+1s+3s Bal-in-Line & 1s cast to 3rd place
25-32::
    1s cross down to 4th place, all set on side & turn partners RH.  2 3
    4 1', 0);
INSERT INTO 'dancecrib' VALUES (14720, '2022-04-01 00:18:31.796836+00', '2023-02-04 01:18:29.039352+00', 20706, 3, NULL, 'ace', '1-8::
    1s+4s cast down/up (2s+3s step up/down bars 1-2), 1s+4s dance RH
    across & cast back to original places & in to meet partner in centre
    (2s+3s step down/up & in on bars 7-8)
9-16::
    1s+2s+3s+4s dance Interlocking Poussette:
::
    1s+2s also 3s+4s dance Poussettes but 1s+4s pass during bar 11 to
    end in order 2 4 1 3 with 2s facing 4s & 1s facing 3s
17-24::
    All dance RSh reels of 4 on the sides
25-32::
    All dance 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14721, '2022-04-01 00:18:31.812636+00', '2023-02-04 01:18:29.061349+00', 20707, 3, NULL, 'ace', '1-6::
    1s+3s set, dance dow, 1s cast up behind 4s into 2nd place _while_ 3s
    cast up behind 5s into 4th place (2s+4s step up bars 3-4) 2 1 4 3 5
7-8::
    1s+3s set advancing to face 1st corners
9-16::
    1s+3s dance ''Hello-Goodbye'' setting ending with Petronella turn
    (with a clap) into 2nd & 4th places own sides. (4s, in 3rd place,
    face out on bar 16) 2 1 4 3 5
17-24::
    1s+4s+3s dance a Chaperoned Chain Progression:
::
    _17-18_    1s & 3s 3/4 turn partner RH into middle _while_ 4s dance
    clockwise 1/4 round the set picking up 1L/3M
::
    _19-22_    who promenade 1/2 way clockwise _while_ middle people (1M
    + 3L) turn LH 1.1/2.
::
    _23-24_    3s & 1s turn partner RH 3/4 to own sides _while_ 4s dance
    clockwise 1/4 round to end in 3rd place
::
    Meanwhile
::
    2s+5s turn RH into promenade hold (2M with partner on right, 5M with
    partner on left), dance clockwise to own side at opposite end of
    set. 5 3 4 1 2
25-32::
    5s+3s also 1s+2s dance RH across (4 bars). All turn partner RH or
    birl (4 bars)
33-40::
    5s+3s+4s+1s+2s dance 10H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9793, '2017-04-14 21:56:36.518274+00', '2022-01-29 17:13:56.651605+00', 5579, 1, NULL, 'ace', '1--::

  Circle6 and back

9--::

  1c set | cast (2c up) ; All turn P RH (2,1,3)

17--::

  All A&R ; All cross RH (2x,1x,3x) 

25--::

  All A&R ; All chase ½ clw (3,1,2)



*Note: unusual progression.*', 3);
INSERT INTO 'dancecrib' VALUES (10434, '2018-02-16 20:56:00.60368+00', '2022-08-13 21:36:46.644288+00', 18243, 2, NULL, 'ace', '1-8::

  8 hands round and back

9-16::

  Heads cross RH +loop ; cross back RH +loop - Sides wait 2, cross RH, loop + cross back.

17-22::

  Women dance RHA once and a half round to change ends [6 bars]; Men set, chase half round to change ends

23-24::

  All promenade one place CW.

25-28::

  All advance + retire;

29-32::

  All turn RH 1/2 (face out of set) - if facing another couple Pass that couple Rshoulder into new set-

  If not facing another couple turn 1/2 more and face in.



Dance 2x as Strathspey and 2x as Reel

        ', 3);
INSERT INTO 'dancecrib' VALUES (8401, '2014-09-12 20:23:49.181626+00', '2022-01-29 22:08:52.428425+00', 15621, 1, NULL, 'ace', '1--::

  1c cross down into Reels3{6} on opposite side | 2c cast up as 1c dance down into DTr position (2,1x,3)

9--::

  Set twice in DTr position ; 1c cast R round 1cnr, meet and pivot R into DTr position, M facing down, W up

17--::

  Set twice in DTr position ; 1c cast R round 4cnr to (2,1,3)

25--::

  All Circle6 and back



*Make a clear St Andrew’s Cross on [9-12] and [17-20]*

', 3);
INSERT INTO 'dancecrib' VALUES (3888, '2013-08-21 08:30:38.634162+00', '2023-02-04 01:18:16.754226+00', 12731, 3, NULL, 'ace', '{{explanation}}
Start 5s in centre facing 1s

1-8::
    5s+1s+3s all in prom hold dance RSh reels of 3 up/down & 5s end in
    centre facing 4s
9-16::
    5s+4s+2s all in prom hold dance LSh reels of 3 across & 5s end
    facing 4s
17-24::
    5L+1s dance RH across _while_ 5M+3s dance LH across, 5L+2s dance LH
    across _while_ 5M+4s dance RH across & 5s end facing 1s
25-32::
    5s+1s set & circle 4H round to left 1/2 way, 5s+2s+3s+4s set & chase
    anticl''wise 1 pl _while_ 1s (in middle) set to each other & turn RH
    to face top', 0);
INSERT INTO 'dancecrib' VALUES (3889, '2013-08-21 08:30:38.640645+00', '2023-02-04 01:18:16.944505+00', 11799, 3, NULL, 'ace', '1-8::
    1s cross RH & set, cross back RH & set _while_ 2s dance Fig of 8
    round 3s
9-16::
    2s cross RH & set & cross back RH & set _while_ 3s dance Fig of 8
    round 4s
17-24::
    1s lead down the middle & back to top
25-32::
    1s+2s dance RH across 1/2 way _while_ 3s+4s dance 1/2 R&L, 2s+1s
    dance 1/2 R&L _while_ 4s+3s dance RH across 1/2 way
33-40::
    1s cross RH & cast 1 place, 1s cross down & cast to 4th place
    _while_ 2s+3s+4s face up & dance up 1 place on bars 39-40', 0);
INSERT INTO 'dancecrib' VALUES (3890, '2013-08-21 08:30:38.651316+00', '2023-02-04 01:18:16.968645+00', 1928, 3, NULL, 'ace', '1-8::
    1s in prom hold dance reel of 3 across with 2s (giving RSh to 2M) &
    1s end in Double Triangles position
9-16::
    2s+1s+3s set & 1s dance out as 2s & 3s dance in & all turn right
    about, all set & 2s & 3s dance out & turn right about as 1s dance in
17-24::
    1L dances RH across with 2s as 1M dances RH across with 3s, 1s pass
    LSh followed by couples & chase to opposite ends
25-32::
    1s dance LH across with same couples, 1s pass RSh followed by
    couples & chase back to own sides 1s ending in 2nd place
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (3891, '2013-08-21 08:30:38.661893+00', '2023-02-04 01:18:17.007888+00', 10541, 3, NULL, 'ace', '1-8::
    All Set+Link, Men cast behind partners & dance RH across for 2
    places (Men with new partner on his left)
9-16::
    All Set+Link, Ladies cast behind Men & dance RH across for 2 places
    to partners (1s in 3rd place etc)
17-24::
    All in prom hold dance reels of 3 with 2s (in 1st place) giving RSh
    to 1s
25-32::
    All circle 6H round & back.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (3971, '2013-08-21 08:30:40.587443+00', '2023-02-04 01:18:24.563347+00', 10845, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-24::
    All dance full Schiehallion Reel
25-32::
    All set twice to partner & turn (elbow grip) into 1 place
    anticlockwise.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8828, '2015-08-04 22:47:11.879665+00', '2022-01-29 01:02:28.573228+00', 9465, 2, 963, 'ace', '*Couples in a circle round the room, all facing counter clockwise. Each man has his partner on his right.*

1-8::  All join nearer hands with partner and dance forward; turn towards partner and dance to original places, and turn towards partner to face anticlockwise again. 
9-16::  All women dance RS round the man in front of her partner, then round her own partner LS to place. 
17-24::  All men dance LS round the woman in front of his partner, then round his own partner RS to place.
25-28::  All join BH with partners and dance 8 slip steps anticlockwise.
29-30::  All slip back 4 steps. 
31-32::  All release hands and step backward for one step, clap and move on to the next person on the right to repeat the dance with a new partner.
', 0);
INSERT INTO 'dancecrib' VALUES (12477, '2020-01-05 00:36:14.642372+00', '2023-02-04 01:18:17.400523+00', 19806, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross LH & cast to the left (Lady up, Man
    down), to end 1L between 2s, 1M between 3s, facing 1st corners
9-12::
    1s dance 1/2 reel of 3 across the set with 2s & 3s (1s pass 1st
    corners RSh to start)
13-16::
    1s petronella turn into 2nd place opp. sides. All set on the side
17-20::
    1s dance 1/2 reel of 3 on the sides with 2s & 3s (1s dance RSh round
    2nd corner position to start)
21-24::
    1s petronella turn to end 1M between 3s (at top) and 1L between 2s
    (at bottom). All set.
25-32::
    All chase 1/2 round clockwise, 1s cross, passing RSh & cast to the
    left to end in 2nd place own sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11834, '2019-05-06 23:03:53.004179+00', '2022-01-29 22:15:07.940123+00', 19290, 1, NULL, 'ace', '1--::

  1c+3c long cast to 2pl/4pl (2c+4c up) ; 1c+3c Birl and face 1cnrs (2,1,4,3,5)

9--::

  1c+3c turn 1cnrs BH ¾ and face in diagonally ; the pairs A&R diagonally

17--::

  Reels 3,4,3 across, Rsh to 1cnr

25--::

  1c+3c turn P LH ¾ | cast off on own side (4c+5c up) ; Birl to finish (2,4,1,5,3)

', 3);
INSERT INTO 'dancecrib' VALUES (4138, '2013-08-21 08:30:44.06497+00', '2023-02-04 01:18:36.448766+00', 10786, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels on opposite sides
9-16::
    1s cross RH to own sides, cast 1 place, 1M dances up between 2s &
    casts to 2nd pl opp side _while_ 1L dances down between 3s & casts
    to 2nd pl
17-24::
    1s turn RH (4 bars), cast round 1st corners to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12360, '2019-11-16 21:09:27.320382+00', '2022-01-29 01:03:13.364838+00', 12855, 2, 160, 'ace', '1-8::
  1s cross RH, cast down 1place [2s up]; 1M half fig.8 round 2s 1W, similarly, half fig.8 round 3s. (2 1 3)
9-16::
  Reels 3 on own sides - 1W in & up (rsh to 2W) 1M in & down (rsh to 3M) - corners end with loops into...
17-24::
 Reels 3 across the set - 1W 2M pass Lsh to begin - 1M 3W the same. (2 1 3)
25-32::
2s 1s Rights&Lefts.', 3);
INSERT INTO 'dancecrib' VALUES (3145, '2012-01-22 19:30:13.276857+00', '2022-01-29 17:29:08.380296+00', 5708, 1, NULL, 'ace', '{{explanation}}

Couples in single circle RR, all facing P.



1–::

  All Set to P 4 times

9–::

  Tulloch turn R ; Tulloch turn L, ending in partner''s place facing next dancer

17-32::

  Repeat 1-16 with the new P



{{explanation}}

The dance continues till the original partners meet again.', 3);
INSERT INTO 'dancecrib' VALUES (13225, '2020-10-06 09:29:36.219692+00', '2022-01-29 22:21:33.845764+00', 20099, 1, 202, 'ace', '1--::

  1c set | long cast to 2 pl (2c up on [5-6] | set advancing to face 1cnrs

9--::

  »Corners Pass and RSh turn« [: same as Corners Pass and Turn but no hands]. 1c in 2plx face clw (2,1x,3)

17--::

  Reels3 on sides, 1c LSh to 1cnrs (2,1x,3)

25--::

  1c Fig8 on own sides starting RSh to 4cnrs (2,1,3)



*Note:

»RSh Turn« (Right Shoulder Turn) is also known as Gypsy Turn, a term now considered offensive by some.*', 5);
INSERT INTO 'dancecrib' VALUES (8526, '2015-02-13 12:47:20.207899+00', '2023-02-04 01:18:18.735521+00', 15592, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp. sides

1-8::
    1s & 4s set & cast in 1 place, 1s+4s dance 1/2 R&L
9-16::
    All dance reels of 4 on sides
17-24::
    2L+4L, 1M+3M, 2M+4M & 1L+3L all turn RH, 4L+1M & 4M+1L turn LH
25-32::
    4s+1s dance Ladies'' Chain. End 2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (12814, '2020-05-14 23:13:15.382179+00', '2023-02-04 01:18:29.323869+00', 19258, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance first 6 bars of Bourrel then turn RH into
    allemande hold
::
    _1-4_    1M+2L also 3M+4L set advancing, 3/4 turn 2H & twirl to end
    BtoB (Lady facing up & Man down) _while_ partners chase
    anticlockwise to face partner
::
    _5-8_   Set to partners & turn RH into allemande hold
9-16::
    2s+1s also 4s+3s dance Allemande
17-20::
    1s/4s dance RSh 1/2 round partner & cast to 2nd/3rd place. Bars
    19-20 2s & 3s NHJ dance to 1st/4th place.  2 1 4 3
21-24::
    1s+4s dance RH across
25-32::
    1s+4s dance Poussette (all round)
33-40::
    2s+1s also 4s+3s dance R&L.  2 1 4 3', 0);
INSERT INTO 'dancecrib' VALUES (4041, '2013-08-21 08:30:42.411775+00', '2023-02-04 01:18:29.492287+00', 7340, 3, NULL, 'ace', '1-8::
    All set, 1s & 4s cast in 1 place & dance 1/2 Figs of 8 round end
    couples
9-16::
    All dance Grand Chain
17-24::
    1L+4M set & change places RH, 1M+4L repeat
25-32::
    All circle 8H round & back.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11731, '2019-03-25 23:40:45.907611+00', '2022-01-29 01:04:48.878909+00', 4633, 2, NULL, 'ace', '1-8::
   couple following couple lead up the middle and alternately go left or right at the top of the room;    
9-16::
   two side-by-side Grand Chains halfway round the room: an inner circle and an outer circle;    
17-24::
   alternating over and under arches halfway round the room;    
25-32::
  couple followed by couple lead up the middle and all turn left at the top and march around the room to end with a double circle around the room, men in the middle. ladies on the outer circle, all facing partner.    ', 5);
INSERT INTO 'dancecrib' VALUES (3154, '2012-01-22 19:30:13.624521+00', '2022-01-29 17:31:15.570782+00', 9110, 1, NULL, 'ace', '1–::

  1c (no hands) dance down cross below 3c and (2c up) cast up to 2W ; 1c (1W leads)+2W RHA

9–::

  1c+2M LHA, finish facing up, 1M behind 1W ; dance up and cast off on own side to 3M (1W leading)

17–::

  1c+3M RHA ; 1c+3W LHA, 1c finish facing down, 1W leading

25–::

  1c dance down between 3c, cast up on own side to 2pl ; 2c+1c+3c turn RH



{{explanation}}

After 2nd turn new 3c step up on [1-2]', 3);
INSERT INTO 'dancecrib' VALUES (3490, '2012-01-22 19:30:27.628067+00', '2022-01-29 22:32:58.010211+00', 6972, 1, NULL, 'ace', '1–::

  Parallel Reels4 on the sides

9–::

  1c+3c set advancing to midline and join RH with P, LH in middle | BiL (2c+4c up) ; 1c+2c & 3c+4c RHA

17–::

  1W+3M turn LH ¾ _while{2}_ 1M+3W dance round clw ¼ to meet P in line across | BiL ; repeat

25–::

  3c+2c & 1c+4c RHA ; 1c+3c turn person ahead (»corner«) RH to finish (2,3,4,1) (M turn once and a bit, W turn 1½ and a bit)



{{explanation}}

Note: the set tends to move upwards; ease down gently in the turns to end in the right positions', 3);
INSERT INTO 'dancecrib' VALUES (3905, '2013-08-21 08:30:38.932976+00', '2023-02-04 01:18:19.119146+00', 9100, 3, NULL, 'ace', '1-4::
    Top 4 Men change places RH diagonally with bottom 4 Ladies _while_
    1L sets to 5M & all dancers dance on 1 place clockwise
5-8::
    Repeat from new pstns back to places
9-16::
    1s & 3s set & cast down 1 place, all advance for 2 steps & 1s & 3s
    turn single into BtoB position for Double Triangles as 2s, 4s & 5s
    retire
17-24::
    All dance Double Triangles ending with 1s & 3s turning singly to
    face2nd corners
25-32::
    1s & 3s dance RSh round 2nd corners & meet partner in middle, turn
    RH & cast 1 place.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (3993, '2013-08-21 08:30:40.96532+00', '2023-02-04 01:18:26.266352+00', 9578, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s
9-16::
    1s+2s dance RH across & LH across back to sides
17-24::
    1s+2s+3s dance LSh reels of 3 on own sides. 1M faces out
25-32::
    1M followed by partner casts 1 place & 1M crosses to 2nd place opp
    side; 1s turn RH 1.1/2 times to own sides', 0);
INSERT INTO 'dancecrib' VALUES (4151, '2013-08-21 08:30:44.321531+00', '2023-02-04 01:18:37.123331+00', 377, 3, NULL, 'ace', '1-8::
    1s cross down & dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reels of 3 on own sides
17-24::
    1s dance down 1 place & set to each other, dance up & cast to face
    1st corners
25-32::
    1s turn 1st corners RH & partner LH, 2nd corner RH & partners LH', 0);
INSERT INTO 'dancecrib' VALUES (11176, '2018-09-30 22:19:12.967337+00', '2023-02-04 01:18:19.542129+00', 16210, 3, NULL, 'ace', '1-8::
    1s cross RH, cast & dance 1/2 Fig 8 (1M round 2M, 1L round 3L)
    finish facing 1st corners (2s step up 3-4)
9-16::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH to end
    in 2nd place own side facing out
17-20::
    1s cast to Left (1M between 3s, 1L between 2s), cross RH _while_
    corners Adv+Ret diagonally
21-24::
    1L casts up round 3M, 1M casts round 2L to 2nd place opp sides &
    cross RH _while_ corners Adv+Ret diagonally
25-32::
    2s+1s+3s dance DoSiDo, clap (bar 29) & all turn partner RH   2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (3911, '2013-08-21 08:30:38.999988+00', '2023-02-04 01:18:19.566371+00', 14013, 3, NULL, 'ace', '1-8::
    1s+2s dance Tourbillon:
::
    1s & 2s 1/2 turn ptnrs 2H, 1M & 2L lead ptnrs by nearer hand 1 place
    cl''wise (end 1s on Ladies'' side & 2s Men''s side), 1s set to 2s
::
    1s & 2s 1/2 turn ptnrs 2H & lead ptnrs clockwise to 2s in 1st place
    & 1s in 2nd place then both cross RH to own sides  2 1 3
9-16::
    1s dance 1/2 reels of 3 on sides (RSh to 4th corner) & 1/2 reels of
    3 across (LSh to 1st corner) & end facing 3rd corner (pstn)
17-20::
    1s set to 3rd corner & right about turn & dance into into corner
    behind them _while_ 3rd corners (pstns) dance in & turn right about
    to face 1s
21-24::
    1s+corners set & corners turn right about & dance into corner behind
    them _while_ 1s dance in & turn right about to face 4th corner
    (pstns)
25-32::
    Repeat bars 17-24 ending with 1s crossing RSh to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (10032, '2017-08-01 13:27:19.371003+00', '2022-01-29 01:06:02.837399+00', 12853, 2, 160, 'ace', '1-8::
  1C set, cast ; Turn LH  to face men''s side with 1M behind partner.
9-16::
  *Guillaume Reel* -- 1W with 2nd + 3rd men dance a Lsh Reel3 on sides *AS* 1M dances Rsh figure of eight on men''s side. 1C end facing women''s side, 1M leading.
17-24::
  *Guillaume Reel* --  1M with 2nd + 3rd women dance a Lsh Reel3 on sides *AS* 1W dances a Rsh figure figure of eight on the women''s side. End facing 1st corners.
25-32::
   1C turn 1corner, pass Rsh; turn 2corner pass Rsh to own sides. Corners dance for 4 bars.', 0);
INSERT INTO 'dancecrib' VALUES (2590, '2012-01-22 19:29:48.887543+00', '2022-01-29 17:32:42.633133+00', 3561, 1, NULL, 'ace', '1–::

  All C set advancing (pass RH) to face P''s corners | set to {2} and turn this corner BH {4} and face P

9–::

  Set twice to partners ; turn BH 1½ to original places

17–::

  1c RHJ Promenade cclw round inside of square, greeting each couple in passing

25–::

  1c Poussette round inside square (no specific pattern proposed in the text)

33–::

  1c+3c cross to change places, 1c passing between 3c ; and change back, 3c passing between 1c

41–::

  Repeat

49–::

  Circle8 L

57–::

  All RHA, W in middle NHJ with P on their L 



{{explanation}}

Repeat dance with 2c, 3c, 4c leading', 3);
INSERT INTO 'dancecrib' VALUES (3913, '2013-08-21 08:30:39.074335+00', '2023-02-04 01:18:19.909211+00', 9761, 3, NULL, 'ace', '1-8::
    1s+2s set, 1/2 Turn RH continue to turn individually dancing out to
    opposite side, chase 1/2 way & 1s end facing 3rd corners
9-16::
    1s dance RSh reels of 3 across & turn LH to face 1st corner
17-24::
    1s turn corners RH, pass RSh, turn 2nd corners RH & cross RSh to
    place
25-32::
    2s+1s+3s circle 6H round & turn partners 2H', 0);
INSERT INTO 'dancecrib' VALUES (4156, '2013-08-21 08:30:44.363789+00', '2023-02-04 01:18:37.287585+00', 11556, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & turn LH to end 2nd place own sides
9-16::
    1s dance LSh reels of 3 across (Lady with 2s & Man with 3s)
17-24::
    1s dance RSh reels of 3 across with other couple
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9964, '2017-06-18 14:39:30.219492+00', '2022-01-29 01:09:40.236655+00', 17789, 2, 2697, 'ace', '1-8::
    1s set | 1M (cat) casts to 2nd pl and dances across, 1L (otter) following (2s step up on b4-5), 1s turn LH ending on opp sides, M facing up, L down.
9-16::
    Mammals’ Chain: 1M with 2s dance ladies'' chain but all opposite role _while_ 1L with 3s dance normal ladies'' chain. 
  This figure is like a ladies'' chain up and down the dance. At the top, 1M+2M turn RH about ¾ while 2L dances across, while at the bottom the *ladies* turn RH while 3M dances across | All meet someone [of the opposite sex, not your partner] coming towards you: half turn them LH  (2L+1M, 2M+3L, 1L+3M) | Then the same people as before change right hand or dance across | End with everyone turning partner left hand.
17-24::
    1M up, 1L down, half fig 8 to (2, 1, 3); All half RSh reel of 3 on own side. 1s naturally end facing in, 3L & 2M naturally end facing out, 3M & 2L finish their loop to face in. (3, 1, 2)
25-32::
    1s RH birl _while_ 3s+2s chase CW half way and RH birl. All end with a LF skip-change out to sidelines (2, 1, 3) on bar 32', 3);
INSERT INTO 'dancecrib' VALUES (3176, '2012-01-22 19:30:14.530697+00', '2022-01-29 17:36:33.610452+00', 5802, 1, NULL, 'ace', '1–::

  1c cross RH | cast off 2 (2c up) ; cross LH and cast up (2,1,3)

9–::

  All turn RH ½ | retain hold & set ; all chase clw to own sides (3,1,2)

17–::

  3c+1c+2c Circle6 and back

25–::

  All turn LH ½ | retain hold & set ; all chase cclw to (2,1,3)



*Note: 3c does not move on bars 1-8.*', 3);
INSERT INTO 'dancecrib' VALUES (3916, '2013-08-21 08:30:39.104222+00', '2023-02-04 01:18:20.113403+00', 29, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 3 facing 3

1-8::
    All Adv+Ret, all repeat
9-16::
    Centre Men dance RH across with partner on right & opposite dancer,
    LH back with partner on left & opposite dancer
17-24::
    Centre Men dance diag R&L ending with centre Men facing out
25-32::
    All dance RSh reels of 3 with new partners & all end facing next
    line of 3
::
    Note- centre Men do not advance but simply dance to & fro', 0);
INSERT INTO 'dancecrib' VALUES (3917, '2013-08-21 08:30:39.116716+00', '2023-02-04 01:18:20.147477+00', 30, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cast 1 place _while_ 2s cross up, 1s+3s set, 1s cast 1
    place _while_ 3s cross up
9-16::
    2s+3s+1s dance reels of 3 on sides (2s in/down, 3s out/up, 1s in/up
    to start)
17-24::
    3s+1s dance 1/2 R&L, 2s+1s dance 1/2 R&L
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11851, '2019-05-15 16:01:02.927825+00', '2022-01-29 01:10:34.5493+00', 19355, 2, NULL, 'ace', '1-8::
    1C turn RH, lead down below 3C; cast up to 2nd place on own sides, on bars 7-8, set advancing and pull back RS to end back-to-back facing own sides
9-16::
    Double triangles. 1C finish in the middle of the set facing up, NHJ, man with his partner on his right.
17-24::
    2C, 1C, 3C mirror reels of 3 on sides, 1C and 2C continuing the track to finish in original order, BHJ with partner
25-32::
    1C and 2C poussette.', 3);
INSERT INTO 'dancecrib' VALUES (3178, '2012-01-22 19:30:14.608879+00', '2022-01-29 17:38:33.553406+00', 5808, 1, NULL, 'ace', '1–::

  1c+4c cross RH, cast to middle (2c+3c to ends) ; 1c+4c RHA

9–::

  1c+4c Pick up cnrs LH and continue double wheel half round ; set to cnrs, change place with cnr LH

17–::

  2c+3c (middles) pick up new cnrs for ½ RHA in double wheel ; set to cnrs and change place using sideline hand to finish in end places with 1c+4c in the middle NHJ facing ends

25–::

  1c+4c dance through ends, cast to middle ; ½ R&L (2,4,1,3)



{{explanation}}

Note: the set keeps a longwise shape', 3);
INSERT INTO 'dancecrib' VALUES (3922, '2013-08-21 08:30:39.186446+00', '2023-02-04 01:18:20.826356+00', 43, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1L followed by partner casts down below 2s, cross & cast up on Men''s
    side & back to places
17-24::
    1M repeats this Fig starting by casting down own side followed by
    partner
25-32::
    1s+2s & 3s+4s R&L
33-40::
    1s+2s+3s circle 6H round & back
41-48::
    1s+2s Allemande
49-56::
    All dance Grand Chain
57-64::
    1s lead up to top & cast down own sides to 4th place', 0);
INSERT INTO 'dancecrib' VALUES (3923, '2013-08-21 08:30:39.194613+00', '2023-02-04 01:18:21.371217+00', 9447, 3, NULL, 'ace', '1-8::
    1s & 2s set advancing & 3/4 turn RH, 1s+2s dance 1/2 reel of 4
9-16::
    2s & 1s set & 3/4 turn to own sides, 1s dance 1/2 Fig of 8 round 2s
17-24::
    2s+1s dance RH across for 3 bars & LH back, 2s set as 1s cross LH
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4092, '2013-08-21 08:30:43.450795+00', '2023-02-04 01:18:33.89785+00', 12608, 3, NULL, 'ace', '1-8::
    1s+2M dance RH across (2L steps up & 2M ends in 1st pl), 1s+3L dance
    LH across
9-16::
    1s+3M dance RH across, 1s+2L dance LH across & 1s end 2nd place own
    sides
17-24::
    2s+1s+3s dance Grand Chain
25-32::
    1s circle 3H round to left (1L with 2s & 1M with 3s), 2s+1s+3s dance
    6H round to left', 0);
INSERT INTO 'dancecrib' VALUES (4094, '2013-08-21 08:30:43.477912+00', '2023-02-04 01:18:34.025542+00', 289, 3, NULL, 'ace', '1-8::
    1M+2L cross diag RH, 1s cross LH diag with 2M/3M, 1s cross RH diag
    with 3L/4L, 1L+4M cross LH & all end on opp sides 1s at bottom
9-16::
    2s & 1s (end cpls) cross RH as 3s+4s dance 1/2 RH across, 2s facing
    4s also 3s facing 1s change places LH on sides & all turn ptnrs RH
17-24::
    4s+2s dance Allemande _while_ 1s+3s dance an inverse Allemande (to
    bottom), middle couples (4s+3s) cross LH
25-32::
    4s & 3s cast to ends & dance into centre to 2nd/3rd places (opposite
    sides) & dance 1/2 R&L.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9868, '2017-05-19 18:55:35.777532+00', '2022-01-29 01:12:05.832274+00', 14480, 2, 274, 'ace', 'The king is sitting in the centre of the set, the others dance around him
1-8::
 All: Set advancing (towards the king) and back – joining nearer hands ; set to partner and 3/4 turn with RH, finish in promenade hold facing clockwise
9-16::
   All: Clockwise promenade, back to own places
17-24::
   All: Grand chain, finish facing partner
25-32::
   All: Set to partner, half turn with right hands - facing corner; Turn corner with left hands – facing partner, half right hand turn with partner
33-40::
   All: Half circle to the left, set – with joining hands, 1/4 circle to the right.

Everyone finishes one place to the left from original places
', 5);
INSERT INTO 'dancecrib' VALUES (3204, '2012-01-22 19:30:15.594797+00', '2022-01-29 17:40:48.012389+00', 11398, 1, NULL, 'ace', '1–::

  1c+2c Circle4 L ; set to P | 1c cross down (no hands) and face out _while_{2} 2c cast up (2,1x 3)

9–::

  1c turns 1cnr RH | turn P LH ¾ ; 2c+1W & 1M+3c RHA, 1c pass Lsh into

17–::

  1c turns 2cnr LH | turn P RH ¾ ; 2c+1M & 1W+3c LHA (to 2,1,3)

25–::

  1c+3c set | 1M+3W cast (down/up) _while_{2} 1W+3M dance L down/up the middle and curve L into ; 3c+1c Circle4 R (2,3,1)



{{explanation}}

Bars 25-28 are a mirrored »S&Link«', 3);
INSERT INTO 'dancecrib' VALUES (3931, '2013-08-21 08:30:39.511497+00', '2023-02-04 01:18:21.935627+00', 12056, 3, NULL, 'ace', '1-8::
    1s+2s turn 2H & circle 4H round to left
9-16::
    1s lead down for 2 bars, set, lead up & cast to round 2s to face
    other partner
17-24::
    1s+2s dance reel of 4 across & end in middle 1s facing up with 2s
    behind them
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (13383, '2020-12-02 01:18:23.720701+00', '2023-02-04 01:18:21.965115+00', 20142, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 on own sides, dancing in/down to start (in front of
    2s, behind 3s)
9-16::
    1s+2s dance RH across & LH across
17-24::
    1s followed by 2s lead down, 2s followed by 1s lead back up. Couples
    remain in middle facing up ready for …
25-32::
    2s+1s promenade

{{explanation}}
Note:	In a 2 couple set, Bars: 1-8 1s dance Fig 8 round 2s', 0);
INSERT INTO 'dancecrib' VALUES (4104, '2013-08-21 08:30:43.564777+00', '2023-02-04 01:18:34.423533+00', 307, 3, NULL, 'ace', '1-8::
    1M casts 1 place & 1/2 turns 3L RH as 1L crosses to opp side, casts
    1 pl & joins (in front of ptnr) for 3H across to end 1s in 2nd pl
    own sides
9-16::
    1L casts up & 1/2 turns 2M LH as 1M crosses to opp side, casts up &
    joins (in front of ptnr) for LH across to end 1s facing 2nd corners
17-24::
    1s set to & turn 2nd corners ending in 2nd place, 2s+1s+3s set &
    turn 2H all ending on own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (3213, '2012-01-22 19:30:15.948287+00', '2022-01-29 17:42:22.926254+00', 5911, 1, NULL, 'ace', '1–::

  1c cross RH | cast off (2c up) ; turn 4cnr RH (pass Lsh) to face 1cnr on 1diag.

9–::

  1cnrs (=3W+2M) full diagonal Reel4 _while{8}_   1c pass 1cnr Rsh | chase clw half round the set | pass new cnr Rsh and pass P Lsh to face 4cnr _while{8}_   2cnrs (=2W+3M) chase one place clw | join ½ diagonal Reel4 | chase 1 place clw to starting places

17–::

  Repeat with 4cnrs (2cnrs full reel, 1cnrs chase / ½Reel / chase), at end 1c pass Lsh into

25–::

  Teapots R and L (2c+1W & 1M+3c RHA ; 2c+1M & 1W+3c LHA) (to 2,1,3)  

  *At the ends of the reels, the dancers leaving and entering pass Lsh, not Rsh round each other*', 2);
INSERT INTO 'dancecrib' VALUES (12901, '2020-07-01 00:18:20.4369+00', '2023-02-04 01:18:22.754229+00', 17584, 3, NULL, 'ace', '1-8::
    All dance 1/2 Grand Chain, set to partner & turn 2H
9-16::
    1s+3s set advancing, 1M+3L face 2s, 1L+3M face 4s & all set.
    Couples dance 1/2 R&L, 2s+4s finish in centre, 1s+3s omit polite
    turns to end 1s facing top, 3s facing bottom
17-20::
    2s+4s dance 1/2 LH across _while_ 1s+3s cast to original place.
    1s+4L+2M & 3s+4M+2L dance 1/2 RH across
21-24::
    1s+3s dance LH across ending on side in 2nd/4th places _while_ 2L+4L
    stand (2 bars) then step right into next Ladies'' place _while_ 2M+4M
    cast anticlockwise 1/2 round to meet partner in 1st/3rd places
25-32::
    All circle 8H round & back.  End 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (11565, '2019-02-05 00:02:34.495517+00', '2022-11-12 11:58:02.694999+00', 5911, 2, 202, 'ace', '1--::

  1c cross RH | cast (2c up) ; turn 4cnrs RH and face 1cnrs. 4cnrs face clw

9--::

  »Modified Reel4« on 1diag [1cnrs dance normal Reel4 _while{8}_ 1c dance Reel4 {2} | chase clw ½ {4} | dance Reel4 {2} _while{8}_ 2cnrs chase clw ¼ {2} | join in Reel4 {4} | chase clw ¼ {2}]. Finish as started. On [16] 1c pass LSh to face 4cnrs

17--::

  Repeat [9-16] on 2diag. On [24] 1c pass LSh ready for

25--::

  2c+1W & 1M+3c RHA, pass RSh ; 2c+1M & 1W+3c LHA (2,1,3)



*Editor''s note:  

Both diagonal Reels4 are like »Weasel Reel« except that cnrs starting the Reel4 dance a normal Reel4.*', 3);
INSERT INTO 'dancecrib' VALUES (8688, '2015-03-02 01:55:34.647849+00', '2022-04-25 20:27:48.945575+00', 15248, 2, 160, 'ace', '1–::

 1C 2C four hands round to the left, finishing 1C facing down & 2C facing up, near hands joined ; 1C 2C set, IC turn toward each other & face up on bar 6 and cast one place *AS* 2C dance up NHJ to end in top place facing out. (2,1,3)

9–::

 1C followed by 2C dance down between 3C and cast up ; meet and dance up through 2pl crossing w/LH at top cast off to 2pl - 2C cross left hand and curve into top place.  (2x, 1x, 3)

17–::

 2C 1C set and link ; dance half rights and lefts. (2,1,3)

25–::

 1C 3C dance the Bourrel. (2,3,1)', 2);
INSERT INTO 'dancecrib' VALUES (14362, '2021-10-11 22:38:41.484548+00', '2023-02-04 01:18:32.120457+00', 20485, 3, NULL, 'ace', '1-8::
    1M+2L set advancing & turn RH back to place; 1s+2s Set+link
9-16::
    2M+1L set advancing & turn RH back to place; 1s+2s Set+link
17-24::
    1s dance down middle & back up to 2nd place own side (2s step up
    19-20)
25-32::
    1s+3s Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4178, '2013-08-21 08:30:44.907457+00', '2023-02-04 01:18:39.040634+00', 9422, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L
9-16::
    1s+4s dance 1/2 R&L, all turn RH 1.1/2 times
17-24::
    2s+3s also 4s+1s dance RH across & LH back
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4211, '2013-08-21 08:30:45.391467+00', '2023-02-04 01:18:40.711682+00', 13440, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-16::
    1s+2s dance RH across ending in middle facing up, 1s cast to 2nd
    place as 2s dance up & 1s petronella turn into middle
17-24::
    1s dance 1/2 reel of 3 on their own sides, 1/2 reel of 3 on opposite
    sides & 1s end facing 1st corners.
25-32::
    1s set to corners & dancing round each other to face 2nd corners,
    set to corners & dance round each other to 2nd place on own side', 0);
INSERT INTO 'dancecrib' VALUES (4212, '2013-08-21 08:30:45.401592+00', '2023-02-04 01:18:40.738601+00', 13441, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    1s+2s also 3s+4s dance double Fig of 8  (1s & 4s cross down/up to
    start)
9-16::
    2s+3s set & dance 1/2 RH across, 1s+3s & 2s+4s set & dance 1/2 LH
    across.  (3)(1)4 2
17-24::
    All dance LSh reels of 4 on sides
25-32::
    All set & cross RH, all chase clockwise 1/2 way  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (10848, '2018-06-14 06:19:31.28687+00', '2022-01-29 01:15:18.62732+00', 18262, 2, 942, 'ace', '1-8::
  Inverted Set & Rotate for 3 finishing 2C (pass P LSh) facing 1st crns
9-16::
  HALF diag LSh Reel-4 with 1st crns + twirl to face 2nd crns ; HALF diag LSh Reel-4 with 2nd crns  
  (Official alternative 8-16): ...finishing 2C (pass P LSh) facing 2nd crns: HALF diag LSh Reel-4 with 2nd crns (pass P left) ; HALF diag LSh Reel-4 with 1st crns) (1x-2x-3x)
17-24::
  Inverted Set & Link for 3 ; WHILE 1C+3C HALF Lefts & Rights (starting up/down) 2C turn left 1-1/4  into (1-2-3)
25-32::
  3Couple Poussette', 2);
INSERT INTO 'dancecrib' VALUES (3947, '2013-08-21 08:30:39.967625+00', '2023-02-04 01:18:23.046669+00', 67, 3, NULL, 'ace', '1-8::
    All Ladies RH across, face partners, set & turn partners RH back to
    places
9-16::
    All Men LH across, face partners, set & turn partners LH back to
    places
17-24::
    1s+3s dance 1/2 Ladies'' Chain , 2s+4s dance 1/2 Ladies'' Chain
25-32::
    1s+3s dance 1/2 Ladies'' Chain , 2s+4s dance 1/2 Ladies'' Chain with
    Men ending facing out
33-40::
    All dance interlocking reels of 4 (touching RH in middle) & end in
    prom hold with (Men on inside) facing anticlockwise
41-48::
    All Promenade 2 places, 1s lead up the middle followed by 2s+3s+4s
    to form longwise set with 2s & 4s crossing to opposite sides
49-56::
    1s+2s also 3s+4s dance RH across 1/2 way, set to partner, dance LH
    across 1/2 way & set to partner
57-64::
    1s+2s also 3s+4s dance Ladies'' Chain
65-72::
    All dance LSh reels of 4 on sides ending with 2s & 4s crossing back
    to own sides RH & all facing up in prom hold
73-80::
    All Promenade round anticlockwise to end in square formation & turn
    Ladies into centre for Bow or Curtsey', 0);
INSERT INTO 'dancecrib' VALUES (3214, '2012-01-22 19:30:15.988009+00', '2022-01-29 17:45:01.543674+00', 5915, 1, NULL, 'ace', '{{title}}

Strathspey



1-16::

  ''Chorus''  ½G-Chain (1 step/hand, start with P) ; all set H.Schottische to P.  Repeat [1-8], M finish in centre & face out

17–::

  ''Diamond''  All M dance a fling step (e.g. rocking step) _while{8}_ W Petronella, ending ½ way round

25–::

  All pairs Turn RH ½, all W ½ LHA ; all turn P RH 1¼ (to places)

33-48::

  ''Chorus'' Repeat [1-16], finishing for

49–::

  ''Criss-cross'' All ½RHA, W in middle, M outside ; All W dance to place of the M in front _while{2}_ he dances to place of the W in front | Change back the same way (W pass behind M!) to original wheel

57–::

  Repeat [49-54] | dance out to original positions and clap twice



{{title}}

Reel



65-80::

  ''Chorus'' All ½ G-Chain (1 step per hand, start with P) ; all turn P twice with R arm in elbow grip.  Repeat [1-8], to places

81–::

  ''Turn and round'' 1c+3c set advancing and turn opposite BH ; Circle4 L, to places

89–::

  2c+4c repeat

97-112::

  ''Chorus'' Repeat [1-16], W finish facing out

113-128::

  ''Schiehallion Reel''  All M dance through the centre to next W''s place on R _while{2}_ all W dance loop R to P''s place | repeat interchanging M and W ; repeat these 4 bars 3 times to finish in own place

', 3);
INSERT INTO 'dancecrib' VALUES (11177, '2018-09-30 22:19:13.833612+00', '2023-02-04 01:18:23.077354+00', 18581, 3, NULL, 'ace', '1-4::
    All set advancing with hands joined, turn partner 2H, remain in
    centre on own sides facing down NHJ
5-8::
    All set and »Cross-Link«:
::
    As normal Set+Link for two people, to change places with partner,
    but 1L and 2M, likewise 2L and 3M, and 3L and 4M, dance round each
    other RSh to join partner NHJ facing down
9-16::
    All dance down and on bar 12 change sides to face up, Man passing
    Lady under his R arm; all dance up to original places
17-30::
    1s+2s dance 1/2 R&L; 2s cross back RH (bars 21-22) as 1s+3s start
    1/2 R&L (bars 21-24); 3s cross back RH (bars 25-26) as 1s+4s dance 6
    bars of R&L (Bars 25-30) no polite turns throughout
31-32::
    All set', 0);
INSERT INTO 'dancecrib' VALUES (3948, '2013-08-21 08:30:39.976007+00', '2023-02-04 01:18:23.101027+00', 68, 3, NULL, 'ace', '1-4::
    1s 1/2 turn RH moving down 1 place, set to partner & turn right
    about to face 1st corners
5-16::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s finish facing 3rd
    corner (pstn)
17-24::
    1s 3/4 turn corner RH, set (facing in diag with corner on R),
    1s+corners dance RH across 1/2 way (crnrs end in orig pl) & 1s face
    4th crnr (pstns)
25-32::
    1s 3/4 turn corners LH, set (facing diagonally in with corner on
    left), 1s+corners LH across 1/2 way to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10897, '2018-07-13 23:28:04.828644+00', '2022-01-29 01:17:09.363997+00', 18398, 2, 2697, 'ace', '1-8::
    1s set | 1M followed by 1L casts 1 place, crosses to opposite side; 1s and 3s change places by right shoulder to (2, 3, 1x).
9-16::
    3s and 1s dance RH across; 1s cast to 2nd place _while(2)_ 3s lead down to 3rd place | 1s ½ turn LH, finishing facing down.
17-24::
    1s lead down and back to face 1st corners, left shoulder to left shoulder.
25-32::
    Modified "Hello-Goodbye" Setting:  1s set to corners turning to each other at end, take both hands |  1s turn ½ anticlockwise holding both hands, turning to face 3rd corners at end holding left hand | 1s set to 3rd corners turning to each other at end, take both hands| 1s turn ~ quarter anticlockwise and retire to own lines', 2);
INSERT INTO 'dancecrib' VALUES (12716, '2020-04-11 10:50:08.197478+00', '2023-02-04 01:18:23.13149+00', 17195, 3, NULL, 'ace', '1-4::
    All turn partner RH once round (2 bars) Ladies dance 1 place
    clockwise passing partner RSh
5-8::
    All turn new partner LH once round (2 bars), Men dance 1 place
    anticlockwise (passing new partner LSh (now opposite original
    partners)
9-16::
    1L+3M & 1M+3L (in 2nd & 4th places) set advancing, turn original
    partner 2H once round, opening out to circle 4H round to left, pull
    back RSh, 1s face couple in 1st place, 3s face couple in 3rd place
17-24::
    All dance RSh reels of four up/down set & form square set, 1L+3M
    (2nd place)1M+3L (4th place) opposite partner (Lady on Man''s right)
25-28::
    All set & Petronella in Tandem 1 place anticlockwise round
29-32::
    "Interlocking Set+Link"
::
    All set, Ladies cast clockwise round outside 1 place _while_ Men
    dance through the middle (passing LSh) 1 place anticlockwise round
    to finish with original partner.  All have moved clockwise 1 place.
    4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (4217, '2013-08-21 08:30:45.452822+00', '2023-02-04 01:18:40.992241+00', 475, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret & dance DoSiDo with Men making arches
9-16::
    1s followed by 2s+3s dance under arches made by 2s+3s, 1s followed
    by 2s+3s dance up under arches made by 2s+3s
17-24::
    1s+2s+3s Promenade to right
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (8380, '2014-08-20 11:10:41.738287+00', '2022-01-29 01:18:17.158914+00', 15568, 2, NULL, 'ace', '1–4::
    1s dance down between the 2s and cast up round them back to places.
5–8::
    1s dance ½ Fig8 round 2s, joining RH with partner in passing.
9–16::
    2s repeat bars 1– 8 respectively round 1s, joining LH with partner.
17–24::
    1s and 2s Adv+Ret then ½ R&L.
25–32::
    RHA, LHA.

*(Dance Crib compiled by the devisor, Hans Prade)*', 5);
INSERT INTO 'dancecrib' VALUES (9586, '2017-02-09 10:44:47.75828+00', '2022-01-29 17:49:08.18626+00', 8289, 1, NULL, 'ace', '1--::

  All dance BtoB with P ; All Tulloch turn

9--::

  1c & 3c change places, 1c passing inside NHJ ; repeat back to places, 3c passing inside NHJ

17--::

  Side couples repeat (2c inside first)

25--::

  1c+3c R&L

33--::

  2c+4c R&L

41--::

  1c+3c L-Chain

49--::

  2c+4c L-Chain, finish in promhold with corner

57--::

  All new cpls promenade cclw, the M returning to original places.

', 3);
INSERT INTO 'dancecrib' VALUES (3963, '2013-08-21 08:30:40.219706+00', '2023-02-12 16:51:51.147872+00', 9333, 3, NULL, 'ace', '1-8::

    1s+2s+3s Set+Link for 3 twice (all end on opposite sides 3 2 1)

9-20::

    3s+2s+1s dance 3 couple R&L

21-24::

    3s+2s dance 1/2 RH across _while_ 1s cross RH, 2s+3s+1s set

25-32::

    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4125, '2013-08-21 08:30:43.947719+00', '2023-02-04 01:18:35.938151+00', 335, 3, NULL, 'ace', '1-8::
    2M dances reel of 3 with 1s (RSh to 1L)
9-16::
    2L dances reel of 3 with 1s (LSh to 1M)
17-24::
    1L+2M change places RH, 1M+2L change places RH, 1s+2s dance 1/2 R&L
25-32::
    1s cross, cast & dance 1/2 Fig of 8 round 2s', 0);
INSERT INTO 'dancecrib' VALUES (3228, '2012-01-22 19:30:16.54924+00', '2022-01-29 17:50:36.241893+00', 5952, 1, NULL, 'ace', '1–::

  All Cs set | All petronella in tandem 1 position cclw ; repeat (3,4,1,2)

9–::

  1c+3c promenade to places, passing RSh ; 2c+4c repeat (1,2,3,4)

17–::

  All M 5/8 LHA and cast R to opp W''s place _while_{4}   all W set and cast to P''s place ; repeat with M and W switching roles (3,4,1,2)

25–::

  Repeat [17-24] finishing in big LH wheel (all M holding LHA and holding P on the outside) (1,2,3,4)

33–::

  All together ½ LHA ; All C S&Link with P, into big LH wheel with W inside

41–::

  All together ½ LHA ; All C S&Link with P, putting M into the middle facing P in own place

49–::

  All Cs dance BtoB (W touch hands in middle) ; set to P  | turn RH ½ putting W in the middle facing P

57–::

  All Cs dance BtoB (M touch hands in middle) ; set to P  | turn RH, putting W in the middle for bow /curtsey

', 2);
INSERT INTO 'dancecrib' VALUES (3972, '2013-08-21 08:30:40.595666+00', '2023-02-04 01:18:24.582943+00', 9223, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s+2s dance RH across with 1s crossing to 2nd place
    opposite sides _while_ 2s cast up
9-16::
    1s cast RSh round 1st corners, into middle & pass LSh to face
    opposite sides (2nd pl), circle 3H round to left on sides & 1s end
    facing 1st corners
17-24::
    1s 1/2 reel of 4 with 1cnrs, pass RSh _while_ 2cnrs chase clockwise
    1/2 way, 1s 1/2 reel of 4 with 2cnrs & pass RSh _while_ 1cnrs chase
    clw 1/2 way to pl
25-32::
    1s dance Pass+Turn with 3rd corners & pass RSh to face 4th corners,
    Pass+Turn with 4th corners ending in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (1595, '2012-01-20 13:06:12.828205+00', '2022-11-27 16:42:28.827641+00', 4673, 2, 1, 'ace', ' 1-4::

  1C+3C petronella and set

 5-6::

  1C+3C dance 2 bars of a Reel4, 1W+3M passing LS to face 2M+2W, respectively

 7-8::

  2W+3M+1W+2M dance 2 bars of a Reel4 (across), 2W+2M passing LS to face 1M+3W,  respectively

 9-16::

  Continue pattern for 8 bars (fin w/set effectively rotated 180°)

17-20::

  1C+3C set and petronella (to own sides)

21-24::

  3C+2C+1C turn R 1½

25-32::

  3C cross R _while_ 2W+1M, likewise 2M+1W, change places R | 2C set

  _while_ 1M+3W, likewise 1W+3M, change places L ;

  1C cross R _while_ 2W+3W, likewise 2M+3M, change places R | 3C set

  _while_ 1M+2M, likewise 1W+2W, change places L

  (*top-crossing U-chain*) 

', 3);
INSERT INTO 'dancecrib' VALUES (12903, '2020-07-01 00:18:21.947933+00', '2023-02-04 01:18:24.60394+00', 17123, 3, NULL, 'ace', '1-8::
    1s & 4s turn partner RH, 1s & 4s cast down/up 1 place (2s & 3s step
    up/down); 1s+4s dance LH across
9-16::
    2s+1s+4s dance Grand Chain (2s cross, 1s+4s change places on side to
    start)  At end 1L omit polite turn
17-24::
    1s+4s+3s dance RSh reels of 3 on sides (1s RSh to 4s to start)
25-32::
    1s+4s set, dance 3/4 R&L to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4225, '2013-08-21 08:30:45.607833+00', '2023-02-04 01:18:41.759197+00', 488, 3, NULL, 'ace', '1-8::
    1s turn RH to end side by side facing up, 1s cast 1 place (2s step
    up) & 2s+1s+3s set
9-16::
    2s+1s+3s Adv+Ret & turn LH into promenade hold
17-24::
    2s+1s+3s Promenade
25-32::
    1s dance down between 3s, cast up, dance up between 2s & cast to 2nd
    place', 0);
INSERT INTO 'dancecrib' VALUES (8543, '2015-02-13 12:47:27.297827+00', '2023-02-04 01:18:41.818447+00', 15405, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance 1/2 Fig. 8 up round 2s
9-16::
    1M+2s also 1L+3s dance reels of 3 across (1M+2M, 1L+3L pass LSh).
    1s end in 2nd place opp. sides
17-24::
    1s set, turn 3/4 RH, 1M with 2s (at top) also 1L with 3s (at bottom)
    dance LH across.  1s finish in 2nd place own sides
25-32::
    2s+1s R&L', 0);
INSERT INTO 'dancecrib' VALUES (1603, '2012-01-20 13:06:12.865991+00', '2022-01-29 01:21:18.133586+00', 13464, 2, 518, 'ace', '1-8::
   1st woman & 2nd man set twice; turn RH to places.
9-16::
   1st man & 2nd woman set twice; turn LH to places (1st man facing out).
17-24::
   1st man followed by partner casts behind 2nd man & crosses up between 2nd
   cpl; 1st man followed by partner casts behind 2nd woman & crosses to 2nd 
   place own side. 2nd cpl step up bars 23-24.
25-32::
   2nd & 1st cpl dance RA; 2nd & 1st cpls dance LA.

', 2);
INSERT INTO 'dancecrib' VALUES (3237, '2012-01-22 19:30:16.932403+00', '2022-01-29 17:52:03.383578+00', 5992, 1, NULL, 'ace', '{{explanation}}

On 2nd chord 1c+3c cross to opposite sides (1x,2,3x,4)



1–::

  Parallel Reels4 on the sides

9–::

  1c+4c dance clw ½ round set, _while{4}_ 2c+3c ½ LHA | 2c+3c change LH on the sides ; 4c+2c & 3c+1c RHA (4x,2x,3,1)

17–::

  2c+3c Half Petronella, at end 2c face 4c and 3c face 1c. (4x,2,3x,1)

25–::

  Progressive Half Petronella: 4c+2c & 3c+1c Petronella Turn to face each other in line4 across | set ; Petronella Turn | set (2,4x,1,3x)



{{explanation}}

Note: Compared with the start, M and W have changed sides', 2);
INSERT INTO 'dancecrib' VALUES (4134, '2013-08-21 08:30:44.032321+00', '2023-02-04 01:18:36.364857+00', 352, 3, NULL, 'ace', '1-8::
    All cross RH & cross back LH, 1s lead down between 2s, cross & cast
    up to 1st place opposite sides
9-16::
    1s+2s+3s dance reels of 3 on sides, 1s dancing between 2s to start &
    1s end in 2nd place (on opposite sides)
17-24::
    1s+3s+4s dance reels of 3 on sides, 1s dancing out & 3s in & up to
    start, 1s end in 3rd place (on opposite sides)
25-32::
    All set, 1s cast to bottom, lead up 1 place, cross & cast back to
    bottom', 0);
INSERT INTO 'dancecrib' VALUES (8446, '2014-11-18 15:41:51.016657+00', '2022-01-29 01:23:38.863263+00', 15702, 2, 160, 'ace', '1–::
 Reel of three on opposite sides (1C cross down to begin)
9–::
 Reel of three on own sides. 1C 2C end in centre BH joined.
17–::
 1C 2C poussette.
25–::
 1C dance reel of 3 on sides *while* 2C 3C dance reel of 3 across the set.
  1M in and down, 1L in and up 2C cast down, 3C cast up to begin.
  Timing for corners - 2 to cast, 2 to cross, 2 to cast and 2 to cross. 
  Note: 3M passes in front of 3L.
', 2);
INSERT INTO 'dancecrib' VALUES (3238, '2012-01-22 19:30:16.971569+00', '2022-01-29 17:52:45.006547+00', 5995, 1, NULL, 'ace', '1–::

  1c mirror Fig8 on own side of the dance, dance in and down to begin

9–::

  1c down the middle {3} and up, cast to 2pl (2c up) finish NHJ 2c facing 1c  (2,1)

17–::

  1c make an arch and dance up, 2c dancing down under, all swivel inwards to face back | return same way, 2c making the arch ; repeat, bottom couple making the arch

25–::

  2c+1c R&L', 2);
INSERT INTO 'dancecrib' VALUES (12627, '2020-03-02 01:51:17.664679+00', '2023-02-04 01:18:25.473627+00', 17047, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 RH across, 1s+3s dance 1/2 LH across; 1s+4s dance
    1/2 RH across & all couples set  (2) (3) (4) (1)
9-16::
    _1/2_ 4 couple Grand Chain (end cross, middles change places on side
    to start, 1 bar to each hand); all set & cross RH with partner
17-24::
    _1/2_ RSh reels of 4 on sides; all set & cross RH with partner
25-32::
    All petronella turn into centre & set; all turn partner 1.1/4 RH to
    own side.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4100, '2013-08-21 08:30:43.52845+00', '2023-02-04 01:18:34.288433+00', 301, 3, NULL, 'ace', '1-8::
    1s+2s cross RH & set, 1s lead down & dance out between 2s & 3s on
    opposite side, cast down & lead up to 2nd pl in centre of dance
9-16::
    2s+1s dance »inverse« Allemande (1s dancing down to start)
17-24::
    1s+2s cross RH, set & dance 1/2 Poussette, 1s end facing 1st corners
25-32::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH', 0);
INSERT INTO 'dancecrib' VALUES (4147, '2013-08-21 08:30:44.287038+00', '2023-02-04 01:18:37.028055+00', 373, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance R&L
9-16::
    1s+2s & 3s+4s set & dance RH across 1/2 way, set & cross RH to own
    sides.  2 1 4 3
17-24::
    All dance reel of 4 on own sides, 2s end in 1st place on sides, Bar
    24 1s+4s+3s all dance into centre towards partner ready for ...
25-32::
    1s+4s+3s (bottom 3 couples) dance Allemande (2s in top place stand)', 0);
INSERT INTO 'dancecrib' VALUES (9273, '2016-07-14 19:43:08.316815+00', '2022-11-20 15:45:44.917972+00', 5053, 2, 160, 'ace', '1-8::

  1C 2C 3C set, cross RH ; set, turn RH 3/4 (1L face 2M, 2L face 3M).

9-16::

  1L, 2M, 2L, 3M dance Left Shoulder reel 4 in the centre - 2C must pass Rsh at end!

  *While* 1M & 3L dance CW round the reel.

17-24::

  All turn Ptnrs RH 3/4 to finish home, all set ; 1C 2C RHA half, turn RH to own sides, progressed.', 0);
INSERT INTO 'dancecrib' VALUES (14363, '2021-10-11 22:38:50.941439+00', '2023-02-04 01:18:43.421207+00', 20490, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s
9-16::
    2s+1s+3s circle 6H round & back
17-24::
    1s+3s Set & Rotate. 2 3 (1)
25-32::
    All set, 1s followed by 3s lead up, 1s cross & 1s followed by 3s
    dance down own sides to 3rd/2nd place.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4246, '2013-08-21 08:30:46.028281+00', '2023-02-04 01:18:43.664368+00', 522, 3, NULL, 'ace', '1-8::
    1M+2L turn 2H, 1L+2M turn 2H (3 bars) &1s+2s+3s dance in for…
9-16::
    1s+2s+3s Promenade
17-24::
    1s cross RH, cast to 2nd place, cross up between 2s & cast to 2nd
    place (2s move up on bars 23-24)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (11720, '2019-03-20 21:36:46.129353+00', '2022-01-29 01:29:48.858138+00', 5191, 2, 160, 'ace', '1-8::
  1M 2M, also 2W 3W (NHJ) set on the sidelines | 1M with 2W and 2M with 3W (on diagonal) turn RH half round [2] merge into RHA just over once round. End 2C back in place while 1M and 3W  have changed places. 
9-16::
  1W 2W also 2M 3M (NHJ) set on the sidelines | 1W with 2M and 2W with 3M (on diagonal) turn LH half round [2] merge into LHA just over once round. End 2C back in place (facing out) while 1W and 3M have changed places. (3x, 2, 1x)
17-24::
  Rsh Reel3 on sides - 2M out and up, 2W out and down to begin. End 3C NHJ facing down, 1C NHJ facing up.
25-32::
  3C 1C set, 3C dance down under arch by 1C who dance up; couples cross to own sides (women under men''s arm), 1C cast off to 2nd place on own sides.
', 2);
INSERT INTO 'dancecrib' VALUES (4002, '2013-08-21 08:30:41.052496+00', '2023-02-22 09:09:20.638005+00', 11631, 3, NULL, 'ace', '1-8::

    1s set, cross down behind 3s & dance up to face 1st corners

9-16::

    1s set to 1st corners & turn RH, turn 2nd corner LH & set to 2nd

    corner

17-24::

    1s turn 2nd corners RH, turn 1st corner LH to 2nd place (opp sides),

    2s+1s+3s set & 1s cross RH to own sides

25-32::

    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8539, '2015-02-13 12:47:25.30058+00', '2023-02-04 01:18:35.400165+00', 15594, 3, NULL, 'ace', '1-8::
    All set & cross RH, all set & cross back LH
9-12::
    5s followed by 4s+3s+2s+1s lead down & retaining RH all turn right
    (Ladies dance under arms) into Prom hold
13-16::
    1s followed by 2s+3s+4s+5s dance up & 1s+3s cast down 1 place into
    middle BtoB (Men face down) to form circles (3 at top & bottom, 4 in
    centre)
17-24::
    2s+1L & 1M+4s+3L & 3M+5s set in circles then circle left to end on
    sides & set.  2 1 4 3 5
25-32::
    All dance DoSiDo, 1s+3s cast 1 place as 2s+4s+5s dance DoSiDo
    (giving LSh).  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (4222, '2013-08-21 08:30:45.50436+00', '2023-02-04 01:18:41.48242+00', 480, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across, set & dance 1/2 LH across
9-16::
    1s lead down the middle & back to top
17-24::
    1s+2s dance Allemande 1s end facing 1st corners
25-32::
    1s turn 1st corners RH, partner LH, 2nd corners RH & partner LH to
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (10624, '2018-04-16 21:41:28.728847+00', '2023-02-04 01:18:44.209712+00', 13873, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    All circle 4H round & back
9-16::
    Ladies Chain
17-24::
    All dance R&L
25-32::
    All join hands with partner, set twice to opp couple, drop hands,
    Adv passing opp person RSh (3 steps) & Ret 1 step', 0);
INSERT INTO 'dancecrib' VALUES (8051, '2013-10-01 08:46:27.692559+00', '2023-02-04 01:18:27.324426+00', 15154, 3, NULL, 'ace', '1-8::
    1s lead down middle & up then cast 1 place
9-16::
    2s+1s+3s Adv+Ret, 1s cross RH & cast round 1st corner into lines of
    3 across
17-24::
    All Adv+Ret, 1s change places LH & cast left to 2nd place own sides
25-32::
    2s+1s dance R&Ls', 0);
INSERT INTO 'dancecrib' VALUES (9504, '2016-11-26 16:49:00.209252+00', '2022-01-29 01:35:38.039111+00', 17482, 2, NULL, 'ace', '1-8::
  1C set, cross down to 2pl ; cast R around 1cor., dance in to 2pl BtB & facing own side.
9-16::
  Double Triangles. - standard for corners, modified for 1C 
    9-10:: All set in DT
    11:: (PdB R) 1C move to their right and face ptnr up/down the dance
    12:: (PdB L) 1C move in to end BtB & face opp sides
    13-14:: All set
    15:: (PdB R) 1C move to their right
    16:: (PdB L) FInish setting ptner
17-24::
  Turn 1crnr RH pass ptnr Rsh; Turn 2crnr RH cross to own side passing Rsh. Corners dance 4 bars.
25-32::
6 hands round and back.', 1);
INSERT INTO 'dancecrib' VALUES (4013, '2013-08-21 08:30:41.628353+00', '2023-02-04 01:18:27.520336+00', 9042, 3, NULL, 'ace', '1-8::
    1s+2s set advancing & dance RSh round partner 1.1/2 times spiralling
    out to opposite sides & circle left 4H round 1/2 way
9-16::
    1s+3s repeat above figure
17-24::
    1s lead up between 3s & out behind 2s to top, 1s turn 2H
25-32::
    1s+2s dance the Knot:', 0);
INSERT INTO 'dancecrib' VALUES (4168, '2013-08-21 08:30:44.558706+00', '2023-02-04 01:18:37.87158+00', 400, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s, 1s+2s dance 1/2 R&L
9-16::
    1s+3s dance 1/2 R&L, 2s+3s+1s turn RH 1.1/2 times end with 3s+1s in
    centre facing up
17-24::
    3s+1s dance Allemande
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4229, '2013-08-21 08:30:45.644428+00', '2023-02-04 01:18:41.896125+00', 12728, 3, NULL, 'ace', '1-8::
    1s set advancing & turn 2H, cast 1 place & cross LH
9-16::
    2s+1s+3s dance reels of 3 on sides (LSh to 2nd corner) & end facing
    1st corner
17-24::
    1s dance 1/2 diag reel of 4 with 1st corners & pass LSh to face 2nd
    corners, dance 1/2 reel of 4 with 2nd corners & end 2nd place
    opposite sides
25-32::
    3s+1s+2s Set+Link for 3 twice', 0);
INSERT INTO 'dancecrib' VALUES (13038, '2020-08-10 00:18:36.061205+00', '2023-02-04 01:18:42.800515+00', 10689, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret; all dance DoSiDo with partner & clap bar 8
9-16::
    1s turn RH (4 bars); 1s cast (2s step up) & set
17-24::
    1s lead down the middle & back up to 2nd place
25-32::
    2s+1s dance R&L.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8472, '2014-12-02 19:25:38.180661+00', '2022-01-29 01:37:59.540434+00', 13163, 2, 160, 'ace', '1–::
 1M2C dance Half Lsh Reel3 across ;
5–::
 1L2C also 1M3C dance Half Rsh Reel3 across. (1L pass 2L / 1M pass 3M to begin). 2C end in top pl.
9–::
 1L3C also 1M4C dance Half Lsh Reel3 across (1L pass 3M / 1M pass 4L to begin). 3C end in 2pl.
13–::
 1L4C also 1M5C dance Half Rsh Reel3 across (1L pass 4L and 1M pass 5M to begin). 4C end in 3pl.
17–::
 1L5C dance Half Lsh Reel3 across (1L pass 5M to begin). 1L end in 4Ls pl. *while* 1M cast up round 5L position and dance across to own side in 4pl. 5C end home.
21–::
1C5C dance LH Across half round, cross LH w/ LH to own side. 
25–::
 All set, crossover Rh ; set and cross back RH. (2 3 4 5 1)', 2);
INSERT INTO 'dancecrib' VALUES (4176, '2013-08-21 08:30:44.860841+00', '2023-02-04 01:18:38.603129+00', 12021, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, set advancing (pass LSh) into double
    triangles position
9-16::
    1s dance Double Triangles & all end in middle for…
17-24::
    2s+1s+3s dance Allemande
25-32::
    1s+2s dance R&L.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4234, '2013-08-21 08:30:45.911566+00', '2023-02-04 01:18:43.02011+00', 501, 3, NULL, 'ace', '1-8::
    1s dance down centre of set & cast back to places _while_ 4s cast to
    top & dance down to places
9-16::
    2s+3s dance RH across, lead out of ends & cast back to places
17-24::
    All set (HS) & turn partner twice
25-32::
    1s & 3s dance down under arches of 2s/4s who dance up, repeat with
    1s & 3s making arches; 2s, 3s & 4s make arches & 1s dance to 4th
    place. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4269, '2013-08-21 08:30:46.364488+00', '2023-02-04 01:18:45.041519+00', 545, 3, NULL, 'ace', '1-8::
    1s cast down behind own lines & back to top
9-16::
    1s cross RH, cast 1 place, cross LH & cast up to original places
17-24::
    1s+2s Adv+Ret, dance 1/2 R&L
25-32::
    2s+1s Adv+Ret, turn RH 1.1/2 times to own sides', 0);
INSERT INTO 'dancecrib' VALUES (9628, '2017-03-01 12:11:08.345889+00', '2022-01-29 01:38:59.21574+00', 17625, 2, NULL, 'ace', '1 -4::
  1C dance 1/2 Fig of 8 around 2C
5-8::
  1L+2M turn RH 1 -1/4 times while 1M+2L turn LH 1 -1/4 times. 1C end BtB, 1Lfacing 2M & 1M facing 2L in a line across the set ready for
9-16::
  1C+2C dance reel of 4 across the dance in 2nd place; 1C end in 2nd place on opp sides facing out while 2C end in 1 st place
17-24::
  1C cast RSh round their 1 st corner into center, (bar 4) turn LH ¾ to finish in center of set, 1L facing up and 1M facing down. 1C dance up/down & cast R to end 2nd place own side; WHILE corners dance along path of full reel of 4. Corners meet in a small LHA at beginning of bars 2&6 and curve out to place
25-32::
  1C+3C dance The Knot', 2);
INSERT INTO 'dancecrib' VALUES (4012, '2013-08-21 08:30:41.537976+00', '2023-02-04 01:18:28.520214+00', 169, 3, NULL, 'ace', '1-8::
    1s cast & cross RH, 1s cast round 1st corner into middle & end BtoB
    facing own side
9-16::
    1s dance Double Triangles ending on own sides
17-24::
    1s followed by 3s dance up & dance Fig of 8 round 2s (Ladies LSh
    round 2M, Men RSh round 2L) to end 1s in 3rd place & 3s in 2nd place
25-32::
    3s+1s set & dance 1/2 RH across, 1s+3s set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (4184, '2013-08-21 08:30:44.963059+00', '2023-02-04 01:18:39.225801+00', 430, 3, NULL, 'ace', '1-8::
    1M sets advancing to 2L & turns partner LH, 1L sets advancing to 2M
    & turns partner RH
9-16::
    1s cross RH, cast 1 place, cross LH, cast round 3s & lead up to face
    1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners to end in centre
    facing Ladies'' side
25-32::
    1s dance out between 2L & 3L, cast (Lady up & Man down), meet in
    centre & dance out between 2M & 3M & cast ending in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (8141, '2013-12-26 16:06:57.512859+00', '2022-01-29 01:50:13.966753+00', 15327, 2, NULL, 'html', '1-8::
  1C turn R & cast (2C step up) | turn L 1¼ to face opp sides [2,1,3]
9–16::
  1C figs. 8 across (cast R round 1st corners; finish facing up/down in 3s across)  
  _while_ 2&3C dance track of Reels3 on sides (2M R to 1W, 3W R to 1M, put loops
  on end of reels to face up/down on sidelines)
17–24::
  1C cross R up/down, cast to R round 2nd corners to 2pl; turn L ¼ and
  dance out to ends, cast R round 4th corners, meet BHJ in the middle,
  2pl, facing opp sides  
  _while_ 2&3C dance R&L, starting on sides. 3C fin by turning BH ½,
  finishing BHJ in middle, facing opp sides
25–32::
  1&3C Progressive Strathspey Poussette – similar to quick-time P,
  but, using travelling steps, all start RF (trailing dancers moving slightly L
  to pass partner''s LF) and quarter turns are replaced by ¾ turns (1M leads
  backwards down M''s side, 3W leads backwards up W''s side) [2,3,1]', 5);
INSERT INTO 'dancecrib' VALUES (4283, '2013-08-21 08:30:46.602801+00', '2023-02-04 01:18:46.240488+00', 564, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s, 1s+2s dance RH across
9-16::
    1L & 2L pass LSh for reel of 4 across set with Men turning LH to end
    in centre facing partner
17-24::
    1s & 2s set to partners, turn 2H & dance 4H round back to places (1s
    on opp side)
25-32::
    1s & 2s set & dance 3/4 double Fig of 8 with 1s casting to start', 0);
INSERT INTO 'dancecrib' VALUES (9575, '2017-01-31 15:21:22.149068+00', '2022-01-29 01:50:58.791464+00', 15010, 2, 160, 'ace', '1-8::
  1C prom. fig.8 round 2C - begin Rsh to 2M.
9-16::
  1C followed by 2C lead down ; 2C followed by1C lead up and all cast to orig. pl.
17-24::
  1C 2C set, Turn BH ; circle L.
25-32::
 Maurice Prog. – 1M 2L B-to-B *AS* 1L 2M cast 1pl CW and adv. as ptnr retires - end in diagonal line ; 1C 2C half poussette.', 3);
INSERT INTO 'dancecrib' VALUES (4042, '2013-08-21 08:30:42.419808+00', '2023-02-04 01:18:29.502079+00', 11184, 3, NULL, 'ace', '1-8::
    1s+2s cross RH, cast down 2 places, cross RH & cast up to places
9-16::
    3s+4s cross RH, cast up 2 places, cross RH & cast back to places
17-24::
    1s+4s Adv+Ret (diagonally), 1s cast bottom as others step up
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4203, '2013-08-21 08:30:45.176083+00', '2023-02-04 01:18:40.385841+00', 11681, 3, NULL, 'ace', '1-8::
    1s set, 1s cross down RH to 2nd pl opp sides, cast to right into
    centre to form lines across (1L between 2s & 1M between 3s) & all
    set
9-16::
    1s turn RH to face 1st corners, turn 1st corners LH 1.1/4 times to
    join hands with 1st+4th corners to BtoB position ready for…
17-24::
    1s dance Crown Triangles & end facing out on opposite sides
25-32::
    1s turn 1st corner RH, turn partner LH, turn 2nd corner RH & partner
    LH to end 1L facing 2s & 1M facing 3s
33-40::
    1s dance reels of 3 across (LSh to 1st corners to start) ending in
    2nd place own sides
41-48::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14723, '2022-04-01 00:18:41.436126+00', '2023-02-04 01:18:40.580418+00', 18307, 3, NULL, 'ace', '1-4::
    2s cross RH & cast RSh round 1st corner into lines of 3 across (2L
    between 1s at top, 2M between 3s)
5-8::
    All set, 2s cast pull back RSh & cast to 2nd place own side. 1 2 3
9-16::
    All dance Knot for 3 couples, 2s finish facing 1st corners
17-24::
    2s dance Corner Pass+Turn with 1st corners & Corner Pass+Turn with
    2nd corners. Bars 23-24 2s cross RH to 2nd place own side.  3 2 1
25-32::
    3s+2s Set & Rotate to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (12876, '2020-06-03 16:27:49.008391+00', '2023-02-04 01:22:31.38315+00', 13927, 3, NULL, 'ace', '1-8::
    1s dance in & cast, meet, dance down between 3s & cast up to 2nd
    place (2s step up 7-8)
9-20::
    2s+1s+3s dance R&L for 3 couples
21-24::
    2s+3s turn partner RH _while_ 1s turn 1.3/4 RH into lines across, 1L
    between 2s facing 2L, 1M between 3s facing 3M
25-32::
    _6_ bar RSh reels of 3 across, Bars 31-32: 1L dances up, 1M down,
    out of ends & cast right to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11947, '2019-07-05 21:37:41.117824+00', '2022-01-29 01:53:38.767994+00', 15914, 2, 963, 'ace', '*In a large circle, woman on man''s right near hands joined*

March
1-8::
  All adv for 2, retire for 2, ret for 2, adv for 2 to finish facing ccw in prom hold    
9-16::
  prom ccw, turn inward; prom cw to finish facing prtn, man in centre    
17-20::
  All dance btob with prtn; turn RH  
21-24:: btob with prtn; turn LH 3/4 into crcl, men with new prtn on rt  
  Repeat 3 more times  
 
Strathspey  
1-8::
  All circle round and back  
9-16::
  Each cpl lead anywhere to finish in 2c sets  
17-24::
  1c&2c RHA;LHA  
25-32::
  1c fig 8 around 2c, crossing dn to start  
33-40::
 1c&2c set|2H turn partner; circle 4H round to left  
41-48::
  2c fig 8 around 1c, crossing up to start  
49-52::
  Turn prtn RH  
53-64::
  Nearer hands joined, w on rt, all dance back into a circle  
  
Reel  
1-8::
  All circle round and back  
9-16::
  M dance in, face prtn & set: dance back to place, face prtn & set (w set back)  
17-24::
  Men fig 8, in front of prtn, behind next w etc back to place  
25-40::
  women repeat 9-24  
41-48::
  BH joined, c slip into middle (2), slip out (4), slip in (2)  
49-56::
  Turn prtn RH;LH  
57-72::
  Women repeat 25-40  
73-88::
  Men repeat 9-24  
89-96::
  All circle round and back

This was written to go with very specific music!  ', 3);
INSERT INTO 'dancecrib' VALUES (12717, '2020-04-11 10:50:13.50906+00', '2023-02-04 01:18:29.7943+00', 18679, 3, NULL, 'ace', '1-8::
    1s dance down between 2s & cast back to top; 1s dance down between
    3s & cast up to 2nd place (2s step up on bars 5-6).
9-20::
    2s+1s+3s dance R&L for 3 couples.
21-24::
    1s turn RH 1.1/2 to face 1st corners.
25-32::
    1s dance Corner Pass+Turn with 1st corners & Corner Pass+Turn with
    2nd corners.  1s end facing down in the centre ready to repeat.  2 1
    3

{{explanation}}
End of 2nd time through, 1s dance down centre to 4th place, 4s step up as new 1st couple begin', 0);
INSERT INTO 'dancecrib' VALUES (8228, '2014-04-01 15:19:41.418855+00', '2022-01-29 01:55:53.10915+00', 6609, 2, 160, 'ace', '1–4::
  1L, followed by 1M, cast off 2 and cross to 3Ms place; (2C+3C up)
5–8::
  1C set, lead up RH to top & take prom hold facing M side (L above M) _while_ 2L, followed by 2M, cast off 2 and cross to 3Ms place. (3C up)
9–12::
  1C cast 1pl _while_ 2C set, lead up RH to 2Ws pl & take prom hold (L above M) facing in _while_ 3L, followed by 3M cast off 2 and cross to 3Ms place.
13-16::
   3C set, lead up RH  to top & take prom hold facing M side  (L above M)
17-24::
   1C 2C 3C Reel of 3 across - 3C pass 1C Lsh to begin. 3C end in middle facing up.
25-32::
   Promenade - 3C followed by 1C then 2C cast off on M side, lead up middle & separate, 3C 1C cast on own sides. End 2 1 3.', 3);
INSERT INTO 'dancecrib' VALUES (4277, '2013-08-21 08:30:46.547265+00', '2023-02-04 01:18:45.886439+00', 11108, 3, NULL, 'ace', '1-8::
    1s set, cast 2 places & turn RH
9-16::
    3s+1s Set+Link, circle 4H round to left
17-24::
    2s+1s Reverse Set+Link, circle 4H round to right
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11804, '2019-04-23 13:40:21.774924+00', '2022-01-29 01:56:59.134005+00', 9337, 2, NULL, 'ace', '*Couple facing couple around the room, lady on man’s right*
1-4::
  All couples advance and retire
5-8::
  Clockwise couples join nearer hand and progress by making arch, facing couple dance under arch. Clockwise couple now dance under arch made by anticlockwise couples. (i.e.over, under for 2)
9-16::
  All couples four hands round and back with new facing couple
17-20::
  All turn the person you are facing with right hand
21-24::
  All turn own partner by left hand
25-28::
  All dos-a-dos with facing couple
29-32::
  All dos-a-dos with partner

', 4);
INSERT INTO 'dancecrib' VALUES (4066, '2013-08-21 08:30:42.95871+00', '2023-02-04 01:18:31.625104+00', 229, 3, NULL, 'ace', '1-8::
    1M+2L change place RH, 1L+2M repeat, 1M+3M repeat, 1L+3L repeat
9-16::
    1s (in 3rd place) cross RH, cast up to 1st place, 1s+2s+3s set &
    cross RH
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance 1/2 R&L, set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (4226, '2013-08-21 08:30:45.618249+00', '2023-02-04 01:18:41.795775+00', 12426, 3, NULL, 'ace', '1-8::
    1s set & 1L followed by partner casts below 3s. 1L crosses & casts
    up to face her 1st corner _while_ 1M dances up the middle to face
    1st corner
9-12::
    1s set to 1st corners & dance RSh round each other into 3rd corner
    (pstn) _while_ 1st corners dance in & turn right about to face their
    original position
13-16::
    1s+1st crnr person set & 1st crnr persons dance RSh round each other
    into diag opp crnrs _while_ 1s dance in & pivot to right to face 2nd
    crnrs
17-24::
    1s repeat bars 9-16 with 2nd corners & end passing RSh to 2nd place
    opposite sides.  (3)(1)(2)
25-32::
    3s+1s+2s chase clockwise 1/2 way & turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (9841, '2017-05-12 12:00:07.798639+00', '2022-01-29 02:01:40.702256+00', 14479, 2, 274, 'ace', '1-8::
 1M+2M, 1L+2L, 3M+4M, 3L+4L: Set and change RH ; 1C+4C LHA.  
 At the end 1M and 4M facing down, 1L and 4L facing up
9-16::
 Two 1/2 lead-change Reel3 - (4M+1M and 1L+4L dance together)  
 First: across the set, left shoulder to 1st CP  
 Second: on opposite sides, right shoulder to 2nd CP
17-24::
 1C+4C dance RL, 1M and 4M finish facing up, 1L and4L facing down
25-32:: 
 Two 1/2 lead-change Reel3 (4M+1M and 1L+4L dance together)  
 First: across the set, left shoulder to 3rd CP  
 Second: on own sides, right shoulder to 4th corners
33-40::
 1C+4C dance RA; 1M+4M and 1L+4L set to each other (on the
sides) and change LH  
Finish in order 2 4 1 3 - 4M facing 2M, 4L facing 2L, 1M facing 3M, 1L facing 3L', 5);
INSERT INTO 'dancecrib' VALUES (4072, '2013-08-21 08:30:43.105123+00', '2023-02-04 01:18:32.090266+00', 9708, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 1s followed by 2s+3s dance down, cross over & dance up
    to partners place
9-16::
    1s followed by 2s+3s dance down, cross over & dance up to original
    place & set
17-24::
    1s cast 1 place, turn LH 1.1/4 times & 1s dance RH across (Lady with
    2s & Man with 3s), 1s pass RSh to face other couple
25-32::
    1s dance reels of 3 across, 1M+2s & 1L+3s  giving RSh to 2nd corner
    to start', 0);
INSERT INTO 'dancecrib' VALUES (4201, '2013-08-21 08:30:45.15556+00', '2023-02-04 01:18:40.06702+00', 7350, 3, NULL, 'ace', '1-8::
    1s dance in, cast down below 3s, meet & dance up to 2nd place BtoB
    facing out on own sides
9-16::
    1s dance Double Triangles with 2s+3s
17-24::
    1s turn RH & LH (slow turns)
25-32::
    1L dances RH across with 2s & 1M with 3s, pass RSh & dance LH across
    with other couple', 0);
INSERT INTO 'dancecrib' VALUES (14201, '2021-08-14 00:18:39.290004+00', '2023-02-04 01:18:42.452089+00', 12144, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across; 1s cast 1 place, pass RSh to finish back to
    back in the centre facing opposite sides _while_ 2s NHJ dance up to
    1st place
9-16::
    2s+1s+3s dance Double Triangles, on bars 15-16 1s cast into 3rd
    place _while_ 3s step up.  2 3 1 4
17-24::
    1s dance LSh reels of 3 across, Lady with 3s & Man with 4s
25-32::
    1s set & cast to 4th place _while_ 4s step up. All turn partners RH.
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14510, '2022-01-10 02:18:28.322778+00', '2023-02-04 01:18:42.562514+00', 20563, 3, NULL, 'ace', '1-8::
    1s dance down, turn 3s (Men RH, Ladies LH); 1s dance down below 3s &
    cast up to 1st place
9-16::
    1s+3s dance R&L ending 1M facing out _while_ 2s turn 2H, face each
    other then set & dance RSh round each other to face again, pull back
    RSh & dance out to place
17-24::
    1M followed by 1L casts off 1 place, dances between 2L & 3L, casts
    behind 3L & into 3rd place own side (2s+3s step up 23-24).  2 3 1
25-32::
    1s dance up, turn 2s (Men LH, Ladies RH); 1s dance up between 2s &
    cast to 3rd place. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4293, '2013-08-21 08:30:46.764549+00', '2023-02-04 01:18:47.081769+00', 584, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    All set & 1s+2s also 3s+4s dance RH across once round, 1s & 4s cast
    in 1 place to 2 1 (4)(3)
9-12::
    1s & 4s cross RH & cast to ends of set to meet partners in prom hold
    & dance into centre of dance
13-16::
    1s+4s dance round passing RSh & to end 1s in the middle on Men''s
    side facing up & 4s in the middle on Ladies'' side facing down
17-24::
    All (1s & 4s in prom hold) dance RSh reels of 3 on sides
25-28::
    4s+1s dance RH across in centre once round to end 4s facing up & 1s
    facing down
29-32::
    4s & 1s lead out of ends crossing & cast in 1 place to end 2 4 (1)
    (3)', 0);
INSERT INTO 'dancecrib' VALUES (4297, '2013-08-21 08:30:46.882807+00', '2023-02-04 01:18:47.445208+00', 588, 3, NULL, 'ace', '1-8::
    1L+2M Adv+Ret & dance DoSiDo
9-16::
    1M+2L Adv+Ret & dance DoSiDo
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (8448, '2014-11-18 16:32:41.06338+00', '2022-01-29 02:03:21.233318+00', 15176, 2, 160, 'ace', '1–::
 1C cross, cast ; 2C 1C left hands across.
9–::
 Ladies Chain - 1C face out.
17–::
 Reel3 across. To Begin: 1M out & up/1L out & down (giving Lsh to 2crnr); 2C in and up to pass ptnr Rsh, 3C in and down to also pass ptnr Rsh. 1C end facing on centerline.
25–:: 1C turn RH to 2pl own side, cast to 3pl ; All Turn RH.', 1);
INSERT INTO 'dancecrib' VALUES (4080, '2013-08-21 08:30:43.216178+00', '2023-02-04 01:18:32.693274+00', 14497, 3, NULL, 'ace', '1-8::
    1s+2s dance the Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH to face 1st corners
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners & pass RSh to face
    2nd corner, 1s dance 1/2 diag reel with 2nd corners & end facing 3rd
    corners
17-24::
    1s dance 1/2 diagonal reel of 4 with 3rd corners & pass RSh to face
    4th corner, 1s dance 1/2 diag reel with 4th corners & end 2nd place
    own sides
25-32::
    2s+1s+3s chase clockwise 1/2 way & turn partner RH 1.1/2 times
33-40::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4081, '2013-08-21 08:30:43.224238+00', '2023-02-04 01:18:33.152491+00', 262, 3, NULL, 'ace', '1-8::
    1s turn RH, cast down 1 place & turn LH & dance LSh round 1st
    corners to 2nd place opposite sides
9-16::
    2s+1s+3s dance reels of 3 on sides 1s giving RSh to 2nd corner & end
    facing 1st corners
17-24::
    1s set to 1st corners & turn 2H, set to 2nd corners & turn 2H
25-32::
    1M circle 3H round to left with 2s & 1L with 3s, set facing in
    centre & petronella turn to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4207, '2013-08-21 08:30:45.318978+00', '2023-02-04 01:18:40.505659+00', 454, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH & twirl (pull back RSh) & dance out to opposite
    sides, 2s repeat
9-16::
    3s repeat (all now on opp sides).  1s+2s+3s 1/2 turn & twirl to own
    sides
17-24::
    1s slip step down the middle & back to end at top facing partner
25-32::
    1s set & cast 1 place, 1M+3M turn RH 1.1/2 times _while_ 1L+3L turn
    LH 1.1/2 times to end 2 3 1
::
    (Variation - See »Wes Clindinning''s Hornpipe«)', 0);
INSERT INTO 'dancecrib' VALUES (4244, '2013-08-21 08:30:45.998983+00', '2023-02-04 01:18:43.512429+00', 520, 3, NULL, 'ace', '1-8::
    1s set advancing, turn 2H & 1M presents partner to 2M & retires to
    place, 2M+1L set & turn 2H & 1L presents 2M to 2L & retires to place
9-16::
    2s set, turn 2H & 2M presents partner to 1M & retires to place,
    1M+2L set & turn 2H & retire to place
17-24::
    1s & 2s petronella turn into centre, 3/4 turn RH to opposite sides,
    petronella turn into centre & 3/4 turn RH to dance…
25-32::
    1s+2s dance the Rondel', 0);
INSERT INTO 'dancecrib' VALUES (12169, '2019-09-04 21:45:13.961009+00', '2023-02-04 01:18:47.687515+00', 19573, 3, NULL, 'ace', '1-8::
    1s dance down, cast down behind 3s, cross up LH, cast up behind 2s,
    dance down to 2nd place BtoB in centre facing opp sides (2s step up
    7-8)
9-12::
    1s join hands with corners & all set, 2nd step 1s rotate 1/4 right,
    join hands (1M+3s, 1L+2s) & all set. End 1L facing up, 1M facing
    down
13-16::
    1s dance 1/2 reels of 3 on sides (1L+2L & 1M+3M pass RSh).  1s end
    2nd place BtoB in centre facing own sides
17-20::
    Repeat bars 9-12. End 1L facing down, 1M facing up
21-24::
    1s dance 1/2 reels of 3 on sides (1L+2M & 1M+3L pass RSh).  1s end
    2nd place opp sides
25-32::
    1s turn 1st corner LH, 2nd corner RH & pass RSH to end 2nd place own
    side', 0);
INSERT INTO 'dancecrib' VALUES (4331, '2013-08-21 08:30:47.404035+00', '2023-02-04 01:18:49.698769+00', 650, 3, NULL, 'ace', '1-8::
    1s+2s set twice & dance RH across
9-16::
    1s+2s set twice & dance LH across
17-24::
    1s 1/2 Fig of 8 round 2s, cross RH & cast 1 place
25-32::
    2s+1s R&L', 0);
INSERT INTO 'dancecrib' VALUES (8536, '2015-02-13 12:47:24.94325+00', '2023-02-04 01:18:33.874149+00', 14356, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up), 1s dance LSh round 1st cnr to 2nd
    place opp sides _while_ 2s+3s set & cross RH
9-16::
    1s turn LH 1.3/4 times, turn 4th cnrs RH 1/2 way, 4th cnrs (2M+3L)
    turn LH 1.1/4 to face ptnrs on diagonal
17-24::
    2s+3s turn ptnrs RH 1/2 way, 2L+3M turn LH 1.1/4 times to face 1s on
    diagonal. 2L+1M also 3M+1L turn RH 1/2 way, 1s turn LH 1.1/2 times
    to end 1M between 3s to face 1L between 2s
25-32::
    Lines of 3 across set, 1s dance reels of 3 across giving RSh  to
    person on their Right (2s+3s dance loop at end of reel)
33-40::
    Reels of 3 on sides with 1M+3M also 1L+2L passing LSh to start.  End
    in lines of 3 across (as bar 24) & all set
41-48::
    All circle 6H round to Left ending with 1s in 2nd place on opp
    sides, 1s turn RH 1.1/2 times to 2nd place own sides   3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4339, '2013-08-21 08:30:47.490818+00', '2023-02-04 01:18:50.208392+00', 662, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, turn LH to end 1L between 2s & 1M between
    3s facing each other
9-16::
    2s+1s+3s set twice 1s turning onto opposite sides, set twice 1s
    turning to face 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting & end facing 2nd corners
25-32::
    1s dance reels of 3 on sides passing 2nd corners RSh & cross RH to
    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4101, '2013-08-21 08:30:43.538485+00', '2023-02-04 01:18:34.356339+00', 8728, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, turn LH & cast on own sides (Lady up & Man
    down)
9-16::
    1s dance reels of 3 across giving RSh to 1st corners & end facing
    1st corners
17-24::
    1s set & turn 1st corners 2H into lines across (1L between 2s & 1M
    between 3s), 2s+1s+3s advance, 1s 1/2 turn 2H to change places & all
    retire
25-32::
    1s dance reels of 3 with new couples giving LSh to 2nd corners & end
    facing 2nd corners
33-40::
    1s set & turn 2nd corners 2H onto sides, 2s+1s+3s advance, 1s 1/2
    turn 2H to change places & all retire', 0);
INSERT INTO 'dancecrib' VALUES (4102, '2013-08-21 08:30:43.548264+00', '2023-02-04 01:18:34.381269+00', 9380, 3, NULL, 'ace', '1-8::
    1s set, dance down for 2 steps _while_ 2s set, 1s dance up as 2s
    cast, 1s cast as 2s dance up _while_ 3s set & face out (Man turns
    right & Lady left)
9-16::
    2s+1s+3s dance reels of 3 on sides (2s dance out & down to start) &
    1s end facing 1st corners
17-24::
    1s set to 1st corner, set to partner, set to 2nd corner & end Man
    between 2s & Lady between 3s, 1s turn RH to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9350, '2016-10-06 07:18:08.200352+00', '2023-02-04 01:18:49.118036+00', 17228, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast, turn LH to finish facing 1st corners (2 step
    up 5-6)
9-16::
    1s dance ''Hello-Goodbye'' setting, ending set advancing turning Right
    about to finish back-to-back in middle (1M facing up, 1L down)
17-24::
    RSh reels of 3 across (1M+2L, 1L+3M pass RSh to start). 1s finish in
    2nd place own side
25-32::
    2s+1s+3s Adv+Ret, turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (4110, '2013-08-21 08:30:43.762859+00', '2023-02-04 01:18:34.844828+00', 315, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & cross RH, set & cross back (Ladies dance under Men''s
    arches passing partner RSh)
9-16::
    1s set & cast 1 place, 1s dance 1/2 reels of 3 across (Man with 2s &
    Lady with 3s)
17-24::
    1s dance 1/2 reels of 3 on opposite sides (1s end in middle facing
    up), set to 3s (at top), set to 2s & end BtoB (Lady facing up)
25-32::
    1s dance 1/2 reels of 3 across (Lady with 3s RSh to 3M - Man with 2s
    RSh to 2L) & dance 1/2 reels of 3 on own sides ending in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (9908, '2017-06-05 11:30:44.195531+00', '2023-02-04 01:18:42.487428+00', 17737, 3, NULL, 'ace', '1-8::
    2s also 4s dance Figs 8 on own sides RSh to person on right & LSh to
    person on left
9-16::
    All dance RH across, 2L+1s, 2M+3s+4L, 4M+5s.  2s & 4s pass partners
    RSh to dance LH across with other couples.  2s & 4s end facing 1st
    corners
17-24::
    2s & 4s dance Corner Pass+Turn with 1st corners, repeat with 2nd
    corners to end in original places
25-28::
    1s+2s also 3s+4s Set+Link
29-32::
    1s+4s (in 2nd & 3rd places) also 3s+5s (4th & 5th places) Set+Link.
    End 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (4360, '2013-08-21 08:30:47.794505+00', '2023-02-04 01:18:51.422497+00', 700, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    1L+2L Adv+Ret & turn RH
9-16::
    1M+2M Adv+Ret & turn LH
17-24::
    All dance Ladies'' Chain
25-32::
    All set to partner, set diagonally, set to opposite person & pass RH
    to face next couple', 0);
INSERT INTO 'dancecrib' VALUES (4242, '2013-08-21 08:30:45.978546+00', '2023-02-04 01:18:43.467205+00', 518, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1L+2L cross between partners & cast back to places, 1M+2M repeat
17-24::
    1s dance Fig of 8 round 2s
25-32::
    1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (12719, '2020-04-11 10:50:24.843652+00', '2023-02-04 01:18:46.217496+00', 19947, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up), 1s turn RH, finish in prom hold
    (Lady on Man''s right) facing 3M
9-16::
    1s+3s dance 1/2 RSh reel of 3 across, finish facing 2L, 1s+2s dance
    1/2 RSh reel across. 1M passes 1L across in front LH ready for …
17-24::
    1M+2s & 1L+3s dance RH across once round to finish all on opp sides
    (2) (1) (3);  All 3 set and cross RH with partner
25-32::
    All dance 6H round and back. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4256, '2013-08-21 08:30:46.237398+00', '2023-02-04 01:18:44.483054+00', 14691, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & cross RH, set & 1/2 turn RH into promenade hold
9-16::
    1s+2s+3s Promenade
17-24::
    1s+2s lead down & back
25-32::
    1s+2s dance allemande', 0);
INSERT INTO 'dancecrib' VALUES (4301, '2013-08-21 08:30:46.918841+00', '2023-02-04 01:18:47.5937+00', 4403, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s+2s dance RH across & LH back
17-24::
    2s followed by 1s lead down, 1s followed by 2s lead back to top
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (4347, '2013-08-21 08:30:47.681045+00', '2023-02-04 01:18:50.689462+00', 9662, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back
9-16::
    1s+2s+3s advance to meet partners, 1s followed by 2s+3s dance up,
    cast down to 3rd place & dance up to places
17-24::
    1s+2s+3s dance DoSiDo & turn RH
25-32::
    1s cross RH, cast 1 place, cross down below 3s & cast up to 2nd
    place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4261, '2013-08-21 08:30:46.292214+00', '2023-02-04 01:18:44.80331+00', 10942, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across & chase clockwise 1/2 way
9-16::
    4s+3s also 2s+1s dance RH across & chase clockwise back to places
17-24::
    1M+2L change places RH, 1L+2M also 1M+3M change places LH, 1L+3L
    also 1M+4L change places RH & 1L+4M change places LH
25-32::
    All set & 1/2 turn partners 2H, 2s+3s also 4s+1s circle 4H round to
    left', 0);
INSERT INTO 'dancecrib' VALUES (4356, '2013-08-21 08:30:47.764082+00', '2023-02-04 01:18:51.325052+00', 694, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    All set, 1s & 4s cross RH _while_ 2s+3s dance 1/2 RH across, all set
    & cross back RH
9-16::
    3s+2s dance 4H round to left, set & turn partner RH into prom hold
    facing each other
17-24::
    3s+2s set (Glasgow Highlanders step), dancing forward (diag to
    right) to form a line across & wheel round anticlockwise 3/4 to line
    up/down set
25-32::
    3s & 2s in prom hold dance LSh Pass+Turn with 2nd corners & pass LSh
    to face 1st corners, LSh Pass+Turn with 1st corners to end in
    original order in Allemande hold 1s facing up, 2s facing 3s & 4s
    facing up
33-40::
    1s+3s dance Allemande up _while_ 2s+4s dance Allemande down (2s & 3s
    pass LSh) to end 3 1 (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (4312, '2013-08-21 08:30:47.123082+00', '2023-02-04 01:18:48.598876+00', 608, 3, NULL, 'ace', '1-8::
    1s cast 2 places & turn 2H (2s+3s step up 1-2); 2s cast 2 places &
    turn 2H (3s+1s step up 5-6)
9-16::
    3s+1s+2s set & turn partners 2H; 3s cast to original places (1s+2s
    step up 15-16)
17-24::
    1s+3s circle 4H round to left (1s move down to meet 3s); 1s end in
    middle, between 2s, facing up, dance up & cast to 2nd place (2s step
    up 23-24)
25-32::
    2s+1s dance R&L.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4394, '2013-08-21 08:30:48.231454+00', '2023-02-04 01:18:53.52773+00', 754, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, cross RH & cast down 1 place on opposite
    sides
9-16::
    3s+1s dance 4H round to left, 1s lead up to top & cast on opposite
    sides to face 1st corners
17-24::
    1s set to & turn 1st corner; set to & turn 2nd corner
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners &
    cross RH to 2nd place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (4322, '2013-08-21 08:30:47.28144+00', '2023-02-04 01:18:49.089368+00', 12149, 3, NULL, 'ace', '1-8::
    1s+2s set, 1/2 turn RH & dance RH across
9-16::
    1s dance RSh reels of 3 on sides
17-24::
    1s+2s set, 1/2 turn LH & dance LH across
25-32::
    1s dance LSh reels of 3 on sides
33-40::
    1M followed by partner dance behind 2M, 1M crosses up between 2s &
    casts to 2nd place _while_ 1L dances down between 3s & casts up to
    2nd place
41-48::
    1s dance RH across (1M with 3s, 1L with 2s) & LH across with other
    couple', 0);
INSERT INTO 'dancecrib' VALUES (4377, '2013-08-21 08:30:47.946669+00', '2023-02-04 01:18:52.181647+00', 10172, 3, NULL, 'ace', '1-8::
    1s set, cross down 1 place, cast behind 3s & cross up to 2nd place
    on own side
9-16::
    2s+1s+3s dance reels of 3 on sides (1s out & up to start)
17-24::
    3s followed by 1s+2s lead up to top & cast to end 2 1 3
25-32::
    1s+3s dance RH across, 2s+1s dance LH across
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4175, '2013-08-21 08:30:44.851101+00', '2023-02-04 01:18:38.433683+00', 415, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place _while_ 2s cross up, 1s set & cast down 1 place
    _while_ 3s cross up
9-16::
    2s+3s+1s dance reels of 3 on sides (1s cross up to start)
17-24::
    3s+1s dance 1/2 R&L, 2s+1s dance 1/2 R&L
25-32::
    1s cross RH, cast down 1 place & 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4294, '2013-08-21 08:30:46.83818+00', '2023-02-04 01:18:47.243244+00', 9699, 3, NULL, 'ace', '1-8::
    All circle 8H round to left & back
9-24::
    All dance full Schiehallion reel
25-32::
    Ladies dance RH across & LH back as Men set Highland style
33-48::
    All dance Grand Chain 1/2 way (1bar per hand), all 1/2 turn partner
    RH & set, repeat back to places
49-56::
    All Petronella-in-Tandem twice to end in opposite places
57-64::
    All Ladies dance 1/2 double Ladies'' Chain , all Men dance 1/2 double
    Men''s Chain to end in original places.

{{explanation}}
Repeat in Reel Time', 0);
INSERT INTO 'dancecrib' VALUES (4388, '2013-08-21 08:30:48.081615+00', '2023-02-04 01:18:52.894532+00', 743, 3, NULL, 'ace', '1-8::
    1s turn RH cast 1 place, turn LH & 1L casts up as 1M casts down to
    form lines of 3 across facing each other
9-16::
    1L+2s & 1M+3s set twice then 1s cast back to 2nd places & turn RH
    ending on own sides
17-24::
    2s+1s+3s set twice & turn partners 2H
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4412, '2013-08-21 08:30:48.537497+00', '2023-02-04 01:18:54.950294+00', 778, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back
9-16::
    1L+2M turn RH _while_ 1M+2L turn RH (1L passes in front of 1M),
    1L+2M turn LH _while_ 1M+2L turn LH to end BtoB between 2s in 1st
    place
17-24::
    1s+2s dance RSh reel of 4 across dance
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (4304, '2013-08-21 08:30:46.944865+00', '2023-02-04 01:18:47.738449+00', 596, 3, NULL, 'ace', '1-8::
    1s cross RH to face out between 2s & 3s; set, 1s dance 1/2 reels of
    3 giving LSh to 2nd corner
9-16::
    1s dance reels of 3 across, 1M with 2s (in 3rd place) & 1L with 3s
    (in 2nd place), 2s & 3s passing partners LSh
::
    2s+1s+3s end in a circle (not holding hands) 1s in 2nd place on
    opposite sides 1M facing out & up; 1L facing out & down
17-24::
    1s dance round outside of circle anticl''wise to opp side; pick up
    dancer on left; cross over (Men making arches) & turn away from each
    other
25-32::
    1s pick up dancer on their left & repeat (crossing diagonally); pick
    up dancer on left & repeat
33-40::
    2s+1s+3s dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4308, '2013-08-21 08:30:46.980782+00', '2023-02-04 01:18:48.24412+00', 8658, 3, NULL, 'ace', '1-8::
    1s & 4s slip step down into middle & back to places, 1s+2s also
    3s+4s 1/2 turn on the sides (2s & 3s turning inwards), 1s+4s cross
    RH.  2 1 4 3
9-16::
    2s & 3s repeat ending in original places opposite sides
17-24::
    1s+2s dance 1/2 RH across, set, 1s+3s dance 1/2 LH across & set
25-32::
    1s+4s dance 1/2 RH across, set & all turn RH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13881, '2021-04-05 00:18:45.237542+00', '2023-02-04 01:18:50.614388+00', 677, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All set twice to opp couple; all turn opp person RH
9-16::
    All circle 4H round to left; all dance LH across back to place
17-24::
    Ladies change places RH, Men changes places RH; all dance RH across
25-32::
    All circle 4H round to right back to new places; all turn partner
    1.1/2 RH, turn back on opp couple to face new couple

{{explanation}}
Note:  dance attributed to Hugh Thurston but Thistle Magazine (39) gives deviser as John Geddes', 0);
INSERT INTO 'dancecrib' VALUES (4311, '2013-08-21 08:30:47.104085+00', '2023-02-04 01:18:48.49665+00', 605, 3, NULL, 'ace', '1-8::
    1s & 3s set, cast 1 place on own sides & dance 1/2 Fig of 8 round
    couple above them to end 1 place down on opposite sides
9-16::
    1s & 3s set into centre & dance Double Triangles (Men face up to
    couple above & Ladies face down (to start), 4s face in & 2s & 5s
    face down/up)
17-24::
    All dance RH across, 1L with 2s, 1M+3L with 4s & 3M with 5s, 1s & 3s
    pass partners RSh to change places & dance LH across
25-32::
    1s & 3s dance down under arch made by 4s or 5s, all cross to
    opposite sides passing LSh, all set, all cross LH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (4431, '2013-08-21 08:30:48.736472+00', '2023-02-04 01:18:56.268875+00', 820, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across for 3 steps, LH across for 3 steps, 1s cast as
    2s dance up _while_ 3s+4s dance RH across & back
9-16::
    1L dances Fig of 8 round 2s _while_ 1M dances Fig of 8 round 3s
17-24::
    1s set, cast to 3rd place, turn RH & face down in prom hold (Lady on
    Mans left)
25-32::
    1s dance reel of 3 across giving RSh to 4M to start & ending in 4th
    place', 0);
INSERT INTO 'dancecrib' VALUES (4210, '2013-08-21 08:30:45.357749+00', '2023-02-04 01:18:40.612188+00', 462, 3, NULL, 'ace', '1-8::
    1L & 3L cross down 1 pl & cast up on opp side into centre as 1M & 3M
    dance across & cast down into centre, 1s+2s & 3s+4s dance RH across
9-16::
    1s & 3s dance reel of 4 up & down centre of dance
17-24::
    1s & 3s 3/4 turn RH to face up _while_ 2s & 4s dance up on sides &
    turn in to face down & all set, all circle 4H round to left & end on
    sides
25-32::
    1s & 3s lead up between 2s/4s crossing over & cast down 1 place, 1s
    & 3s turn 2H & 1s dance down to 4th place as 3s cast up on own sides
    to 2nd pl', 0);
INSERT INTO 'dancecrib' VALUES (4328, '2013-08-21 08:30:47.374292+00', '2023-02-04 01:18:49.560139+00', 644, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s circle 4H round & back
9-16::
    1s in prom hold (Lady on Mans Left) dance down the middle & dance up
    behind Men back to places
17-24::
    All dance RSh reels of 4 on sides
25-32::
    1s 1/2 turn RH & dance down opposite sides & turn RH at bottom 1.1/2
    times', 0);
INSERT INTO 'dancecrib' VALUES (4371, '2013-08-21 08:30:47.888697+00', '2023-02-04 01:18:51.915138+00', 11017, 3, NULL, 'ace', '1-8::
    3s cross RH & cast to top, 3s dance 1/2 Fig of 8 round 1s
9-16::
    2s cross RH & cast to top, 2s dance 1/2 Fig of 8 round 3s
17-24::
    1s cross RH & cast to top, 1s dance 1/2 Fig of 8 round 2s
25-32::
    1s set & cross RH _while_ 2s+3s dance 1/2 R&L, 2s set & cross RH
    _while_ 1s+3s dance 1/2 R&L.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4345, '2013-08-21 08:30:47.663037+00', '2023-02-04 01:18:50.643361+00', 682, 3, NULL, 'ace', '1-8::
    1s set & turn RH, 1s+2s facing on sides set & turn RH
9-16::
    1s lead down below 3s, cast up to 2nd place on own sides & set twice
17-24::
    2s+1s dance R&L
25-32::
    1L dances 3H round to left with 2s as 1M dances 3H round with 3s, 1s
    pass by right & dance 3H round to right with other couple
33-40::
    1s lead out between 2L+3L, cast round nearest corner, into centre,
    lead out between 2M+3M & cast round corner to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4438, '2013-08-21 08:30:48.797774+00', '2023-02-21 13:32:17.864123+00', 827, 3, NULL, 'ace', '{{explanation}}

3s & 4s on opp sides



1-8::

    All set, 1s turn RH, cross down to 2nd place, cast up to top & dance

    in to face down with nearer hands joined _while_ 2s cross RH, cast

    up, cross down to own side & join 1s in a line across (2s facing up)

    _while_ 3s cross RH, cast down, cross up to original sides & join 4s

    in a line across (3s facing down) _while_ 4 turn RH, lead up to 3rd

    place crossing to other side, cast to 4th place & turn to face up

    with nearer hands joined

9-16::

    All set in line, 1/2 turn to bring outside persons into centre, set

    & 1/2 turn back to lines

17-24::

    1s & 4s (prom hold) dance RSh reels of 3 across set (1s with 2s & 4s

    with 3s)

25-32::

    1s & 4s (prom hold) dance down to bottom/up to top (Men passing

    LSh), drop RH, cross & cast to 2nd/3rd place then cross RH.  2

    4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (4235, '2013-08-21 08:30:45.920032+00', '2023-02-04 01:18:43.047619+00', 9226, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s Advance into tight circles (Hands Raised) & Retire,
    1s+2s also 3s+4s dance RH across
9-16::
    1s+2s also 3s+4s dance 1/2 R&L, 2s & 3s turn 1.1/2 times, 1M+4L also
    1L+4M turn RH 1.1/2 times on sides into prom hold
17-24::
    1M+4L & 1M+4L in prom hold dance reels of 3 on sides (RSh to 2L/3L)
25-32::
    4s+1s dance LH across & end facing corners, turn corners RH ending
    on sides 2 4(1)(3)
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4241, '2013-08-21 08:30:45.970347+00', '2023-02-04 01:18:43.45306+00', 8722, 3, NULL, 'ace', '1-8::
    1s set advancing, turn 2H, lead down crossing below 3s & cast up to
    2nd place opposite sides
9-16::
    2s+1s+3s Adv+Ret & turn partners 2H
17-24::
    2s+1s dance 4H round to left, 1s cross up to 1st place & cast to 2nd
    place as 2s cast to 2nd place & lead up to 1st place
25-32::
    2s+1s+3s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (4364, '2013-08-21 08:30:47.830424+00', '2023-02-04 01:18:51.582361+00', 711, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance  3 facing 3

1-8::
    All circle 6H round & back
9-16::
    Men set advancing to BtoB position facing opposite Ladies & turn
    Lady on right RH, turn Lady on left LH & Men give RH cross back to
    places
17-24::
    Ladies dance RH across & LH back
25-32::
    All Adv+Ret & advance passing opposite person RSh to meet next group
    of 3 dancers', 0);
INSERT INTO 'dancecrib' VALUES (12383, '2019-12-05 01:29:02.591463+00', '2023-02-04 01:18:57.070803+00', 19410, 3, NULL, 'ace', '1-8::
    1s cross down RH, cast behind 3s, meet & dance up (NHJ) to top &
    cast to 2nd place opp sides (2s step up 7-8). 2 (1) 3
9-16::
    1L+3s & 1M+2s dance RH across; 1s turn LH to face 3rd corners
17-24::
    1s+3rd corners dance 1/2 diag reel of 4, 1s pass RSh; 1s+4th corners
    dance 1/2 diag reel of 4. 1s pass RSh to end 2nd place opp sides
    (3)(1)(2)
25-32::
    2s+1s+3s dance clockwise 1/2 round; All turn partners RH (or birl)
    to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15216, '2022-11-03 01:18:53.719668+00', '2023-02-04 01:18:58.000581+00', 20428, 3, NULL, 'ace', '1-8::
    1s+2s+3s Petronella turn & set; 1s+2s+3s Petronella turn & 1/2 turn
    partner RH into Allenmade hold facing up
9-16::
    1s+2s+3s dance Allemande.  3 2 1
17-24::
    1s cast up 1 place (2s step down), 1s set & turn RH _while_ 2s+3s
    dance 6 bars R&L.  2 1 3
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4372, '2013-08-21 08:30:47.898411+00', '2023-02-04 01:18:51.941416+00', 8167, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 2s
9-16::
    1s turn 1st corner, partner, corner & partner to end 2nd place
    opposite sides facing out
17-24::
    1s dance a Fig of 8 round 2nd corners (LSh to 2nd corners, passing
    RH in centre & RSh to 4th corner) to end 2nd place own sides & set
    _while_ 2s+3s cross RH, 2s set to 3s on sides, change places LH &
    set to partners
25-32::
    3s+1s+2s dance Diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (4410, '2013-08-21 08:30:48.519374+00', '2023-02-04 01:18:54.81459+00', 9576, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance LSh reels of 3 on sides
9-16::
    1L+2M turn LH, 1M+2L turn RH
17-24::
    1s cross RH, cast 2 places, cross LH & cast to bottom
25-32::
    4s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (11178, '2018-09-30 22:19:25.21223+00', '2023-02-04 01:18:57.391771+00', 9939, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s+4s cross to opp sides

1-8::
    1s+4s turn 1.1/2 RH;  cast down/up to 2nd/3rd place & 1/2 turn LH
    into prom hold,1s facing up/ 4s down (2s+3s step up/down bars 5-6)
9-16::
    Reels of 3 across, 1s RSh to 2L, 4s RSh to 3L to start.  End with 1s
    on Men''s side, 4s on Ladies'' side. Bar 16 1s+4s swap partners, 1M+4L
    face up, 4M+1L face down in prom hold
17-24::
    Reel of 3 on sides, 1M+4L RSh to 2L, 4M+1L RSh to 3L to start.  End
    1s in 3rd place opp sides, 4s in 2nd place own sides
25-32::
    1s/4s dance NHJ out of ends (4s up/1s down), cast back to 2nd/3rd
    place; all 4 couples turn RH.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (4383, '2013-08-21 08:30:47.996575+00', '2023-02-04 01:18:52.358738+00', 12622, 3, NULL, 'ace', '1-4::
    1s cross RH & cast 1 place
5-16::
    All dance 3 couple R&L
17-24::
    All dance a Reverse Snowball Grand Chain for 3 cpls to end 3 1 2 :
::
    2s cross RH & change places LH on side with 1s
::
    2s change places RH with 3s _while_ 1s cross RH
::
    2s cross LH _while_ 1s & 3s change places LH.  3 1 2
25-32::
    All set, 3s+1s dance RH across 1/2 way _while_ 2s cross RH, all set
    & 1/2 turn partner RH to face up in allemande hold
33-40::
    1s+3s+2s dance Allemande. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (8548, '2015-02-13 12:47:29.478625+00', '2023-02-04 01:18:52.383715+00', 15611, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 Figs of 8 (1M round 2s & 1L
    round 3s)
9-16::
    1s cross up/down into reels of 3 on opposite sides giving LSh to 1st
    corner
17-24::
    1s cross up/down into reels of 3 across giving RSh to 4th corner
    ending 2nd place opposite sides
25-32::
    1s dance 1/2 Figs of 8 (1M round 2s & 1L round 3s), 1s dance RH
    across (1L with 2s & 1M with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (12384, '2019-12-05 01:29:03.173659+00', '2023-02-04 01:18:57.738991+00', 17535, 3, NULL, 'ace', '1-8::
    1s+3s dance R&L
9-16::
    All Men dance RH across & LH back
17-24::
    All Ladies dance RH across & LH back to place & face out
25-40::
    All dance full Schiehallion Reel
41-48::
    All Set+Link, 3/4 turn partners RH into promenade hold, all chase
    anticlockwise 1 place to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4476, '2013-08-21 08:30:49.37525+00', '2023-02-04 01:18:59.028751+00', 886, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    1s also 4s cross RH & cast in 1 place, 2s+1s also 4s+3s dance RH
    across
9-16::
    All dance RSh reels of 4 on sides
17-24::
    2s+1s also 4s+3s dance double Fig of 8 with 1s & 4s dancing between
    2s/3s 1s & 4s end BtoB facing nearest corners
25-32::
    1s & 4s dance »Hello-Goodbye« setting to end facing opposite corners
33-40::
    1s & 4s turn (long) corners RH join hands in circle, Set & Rotate
    round to right to face in again
41-48::
    1s+4s dance RH across, dance out between end couples cross & cast in
    1 place to end 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (4485, '2013-08-21 08:30:49.522173+00', '2023-02-04 01:18:59.43512+00', 894, 3, NULL, 'ace', '1-8::
    All petronella turn into the centre & set to partner, turn 2H 1.1/4
    times back to places
9-16::
    1s+2L & 3s+2M dance RH across, 2s pass RSh & dance LH across with
    other couple
17-24::
    2s in prom hold dance reel of 3 with 1s passing 1L RSh. End with 2s
    in centre at top, 1s casting to follow 2s & 3s stepping in ready for
    …
25-32::
    2s+1s+3s dance Allemande.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4502, '2013-08-21 08:30:49.752766+00', '2023-02-04 01:19:00.53123+00', 915, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret & dance RH across ending 1s facing 2s
9-16::
    Repeat & end in original places
17-24::
    1s+2s set, petronella turn into centre, set & change places RH with
    partner
25-32::
    1s+2s dance 1/2 RSh reel of 4 & turn partners RH 1.1/4 times', 0);
INSERT INTO 'dancecrib' VALUES (4288, '2013-08-21 08:30:46.719088+00', '2023-02-04 01:18:46.756189+00', 573, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place & dance 1/2 R&L
9-16::
    All dance RSh reels of 4 on sides
17-24::
    2s+4s also 1s+3s dance RH across, 4s+1s dance LH across & end facing
    corners
25-32::
    Turn corners RH, 1/2 LH across in centre, turn opposite corner RH &
    1/2 LH across in centre to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4439, '2013-08-21 08:30:48.805925+00', '2023-02-04 01:18:56.486495+00', 8812, 3, NULL, 'ace', '1-8::
    1s set, cross RH to face 2s, 1s+2s set to each other on sides &
    change place with 1s dancing between 2s into double triangle pstns
9-16::
    1s dance Double Triangles & end facing 1st corners
17-24::
    1s turn 1st corner, partner, 2nd corner & partner to end 2nd place
    opposite sides
25-32::
    2s+1s+3s Adv+Ret, 1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (4481, '2013-08-21 08:30:49.491324+00', '2023-02-04 01:18:59.294701+00', 13598, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 RH across, 1s change places LH on side with 3s &
    1s+4s turn RH on sides
9-12::
    1s cross up between 3s & turn 2s (1M turns 2L RH, 1L turns 2M LH) 1s
    meet NHJ facing down
13-16::
    1s dance down between 3s to turn 4s (1L turns LH & 1M turns RH) &
    end 1L facing 3M as 1M facing 4L
17-24::
    1s dance 1/2 diag RSh reel of 4 with 4L+3M passing RSh & 1/2 diag
    RSh reel of 4 with 3L+4M to end 3rd place
25-32::
    1s+4s dance RH across (cpl above them), All 4 cpls turn RH 1.1/2
    times to own side  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4503, '2013-08-21 08:30:49.760784+00', '2023-02-04 01:19:00.550892+00', 916, 3, NULL, 'ace', '1-6::
    1s cast 1 place & circle 3H round to left (1L with 2s & 1M with 3s)
7-12::
    1s circle 3H round to right (with same couple) & turning left about
    dance out own sides casting left to face 1st corners
13-18::
    1s turn 1st corners RH, turn partner LH & face 2nd corners
19-24::
    1s turn 2nd corners RH & cross LH to 2nd place own side', 4);
INSERT INTO 'dancecrib' VALUES (4300, '2013-08-21 08:30:46.908906+00', '2023-02-04 01:18:47.509027+00', 8345, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    2s+3s set & dance RH across 1/2 way, 3s+2s 1/2 turn partner RH,
    twirl & dance out to own side
9-16::
    All circle 8H round to left for 2 steps, Men turn Lady behind them
    2H & continue circle to places
17-24::
    1s+3s also 2s+4s set & petronella-in-tandem into middle, set &
    petronella-in-tandem to sides
25-32::
    1s+4s dance RH across, lead up/down cross & cast in 1 place.  3 1
    (4)(2)', 0);
INSERT INTO 'dancecrib' VALUES (12072, '2019-08-30 09:53:53.084524+00', '2023-02-04 01:18:55.342039+00', 19360, 3, NULL, 'ace', '1-8::
    1s+2s+3s cross RH & set;  2L+1s & 2M+3s dance 1/2 RSh reels of 3
    across.  All end in original places
9-16::
    All Set+Link twice to end on opp sides (3)(2)(1)
17-24::
    3s+2s dance 1/2 R&L _while_ 1s cross LH & set; 2s+3s+1s turn
    partners RH
25-32::
    2s+2s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4454, '2013-08-21 08:30:49.065755+00', '2023-02-04 01:18:57.127428+00', 845, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s dance Fig of 8 round 2s
17-24::
    1s lead down for 2 bars, turn RH, lead up & cast to 2nd places
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4493, '2013-08-21 08:30:49.597897+00', '2023-02-04 01:18:59.94276+00', 904, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 3rd place (2s+3s step up 3-4); 2s dance in &
    cast to 3rd place (3s+1s step up 7-8)
9-16::
    All set, cross RH, all set & 1/2 turn partner RH ending in centre of
    dance
17-24::
    All dance 3 couple Allemande
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4506, '2013-08-21 08:30:49.880335+00', '2023-02-21 13:13:41.96538+00', 925, 3, NULL, 'ace', '1-8::

    1M+2L set advancing & turn RH, 1L+2M set advancing & turn RH

9-16::

    1s+2s dance diagonal reel of 4 (1M & 2L pass LSh _while_ 1L & 2M

    cast)

17-24::

    1L followed by 1M cast 1 place, dance 1/2 Fig of 8 round 2s & across

    towards 2L

25-32::

    1s dance RH across with 2L & LH across with 2M ending in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4305, '2013-08-21 08:30:46.952923+00', '2023-02-04 01:18:48.005029+00', 598, 3, NULL, 'ace', '1-4::
    1s cross down below 2s & cast up to top _while_ 4s cross up & cast
    to bottom
5-8::
    1s & 4s dance in to meet, Men dance out Ladies'' side as Ladies dance
    out Men''s side, cross & cast to opp ends.  (4)2 3(1)
9-16::
    4L+2L+3M+1M dance 1/2 diagonal RSh reel of 4, 4M+2M+3L+1L dance 1/2
    diag reel of 4.  1 (3)(2) 4
17-20::
    1s set & cast 1 place
21-28::
    1s dance Diag R&L
29-32::
    1s lead down 1 place & dance behind 4s to 4th place.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8363, '2014-07-29 12:59:29.73448+00', '2023-02-04 01:22:31.691823+00', 15070, 3, NULL, 'ace', '1-8::
    1s set, turn 2H face up and cast to 2nd place
9-16::
    1s+3s dance Double Fig. 8, 1s crossing down to start
17-24::
    1s set, turn 2H face down and cast up to original places
25-32::
    1s+2s dance Double Fig. 8, 1s crossing down to start
33-40::
    1s lead down middle and back, finish in 1st place facing out
41-48::
    1s change places with 2s (Men LH, Ladies RH), then with 3s (Men RH,
    Ladies LH), 1s turn 4s 1.1/2 times (Men LH, Ladies RH)', 0);
INSERT INTO 'dancecrib' VALUES (4316, '2013-08-21 08:30:47.228923+00', '2023-02-04 01:18:48.807969+00', 615, 3, NULL, 'ace', '{{explanation}}
2 chords - Honour partner & corner

1-8::
    All dance DoSiDo with corners, 1s+3s dance 1/2 R&L
9-16::
    Repeat but with 2s+4s dancing R&L
17-24::
    All Men dance advancing to face Lady on Right & set, 1/2 turn Lady
    RH into centre to face her partner & all set
25-32::
    All dance DoSiDo with partner & turn RH 1.1/4 times to new positions
    in Square Set.  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (4430, '2013-08-21 08:30:48.728476+00', '2023-02-04 01:18:56.241348+00', 819, 3, NULL, 'ace', '1-8::
    1L+2L+3L Adv+Ret for 2 steps, 1M+2M+3M Adv+Ret
9-16::
    1s followed by 2s+3s cast on own sides to 3rd place & lead back up
    to original places
17-24::
    1s+2s+3s dance 6H round & back
25-32::
    1s+2s dance the Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13394, '2020-12-02 01:18:53.721736+00', '2023-02-04 01:18:57.573308+00', 19897, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 2nd place (2s step up bars 3-4), 1s dance RSh
    round partner to face 3rd corners
9-16::
    1s dance Corners Pass & Touch Elbows (no hands) with 3rd corners
    (Corners, with arms crossed, change places touching right elbows in
    the middle), 1s pass RSh & repeat with 4th corners & pass RSh to
    opposite sides to end Ladies facing up, Men facing down (3) (1) (2)
17-24::
    All chase clockwise 1/2 way ending in middle facing in, all set (no
    hands), 4 spring points 2 1 3
25-32::
    All chase clockwise for 6 bars, ending in the centre, on bars 31-32
    pull back RSh & dance back to sides 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8556, '2015-02-13 12:47:31.37266+00', '2023-02-04 01:19:01.273231+00', 15616, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s _while_ 3s dance Fig of 8 round 4s
9-16::
    1s+2s also 3s+4s dance RH across & LH back
17-24::
    1s dance Figs of 8 on own sides (in & down to start)
25-32::
    1s cross RH, cast 2 places, cross RH & change places LH with 4s', 0);
INSERT INTO 'dancecrib' VALUES (4520, '2013-08-21 08:30:50.037575+00', '2023-02-04 01:19:01.718547+00', 13523, 3, NULL, 'ace', '1-8::
    1s+2s dance Allemande.  2 1 3 4
9-16::
    All dance reflection reels of 4 on sides (2s & out & down to start)
17-24::
    1s+3s dance RH across & end with 1s casting to 3rd place as 3s dance
    up, 1s+4s dance LH across & end with 1s casting to 4th pl as 4s
    dance up
25-32::
    All dance down closing in to meet partner & lead up RH back to
    places.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4335, '2013-08-21 08:30:47.444093+00', '2023-02-04 01:18:49.889419+00', 655, 3, NULL, 'ace', '1-8::
    1s+2s set twice; 1s+2s cross RH & clap 3 times
9-16::
    1s+2s repeat back to places
17-24::
    1s cross & lead out on opposite sides between 2s & 3s, cast round
    3s, lead up to top, cross & cast to 2nd place on own sides with 3
    claps
25-32::
    1s+3s circle 4H round to left, 1s turn RH & cast up to top
33-40::
    1s+2s dance 1/2 R&L & cross RH all clap 3 times', 0);
INSERT INTO 'dancecrib' VALUES (4461, '2013-08-21 08:30:49.128051+00', '2023-02-04 01:18:57.474993+00', 853, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s cross RH & cast 1 place (2s step up), 1s dance 1/2 Fig of 8 up
    through the 2s
17-24::
    2s+1s dance RH across & LH back
25-32::
    2s+1s Adv+Ret & turn partners RH to places', 0);
INSERT INTO 'dancecrib' VALUES (4349, '2013-08-21 08:30:47.699512+00', '2023-02-04 01:18:50.749371+00', 8500, 3, NULL, 'ace', '1-8::
    1s lead down & cross below 2s, cast down behind 3s & lead up into
    double triangle position facing opposite sides & 2s+1s+3s set
9-12::
    1s turn 1st corner RH & dance RSh round corner to end facing in
    middle (M facing up, L down) _while_ 2nd corners petronella into
    centre & set
13-16::
    1s+2nd corners dance 1/2 reel of 4 up/down set (3M ends in 2L place
    & 2L in 3M place) _while_ 1st corners chase 1/2 way round set
17-24::
    1s dance RH across (L with 3s & M with 2s), pass RSh & dance LH
    across with other couple 1s ending in 2nd place own side
25-32::
    1s dance Diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (4351, '2013-08-21 08:30:47.715667+00', '2023-02-04 01:18:50.840789+00', 686, 3, NULL, 'ace', '1-4::
    1s cross RH & cast 1 place (2 step up)
5-12::
    1s dance in & down for reflection reels of 3 on sides with 3s+4s
13-16::
    1s & 4s cross RH & cast up 1 place (2s+3s step down)
17-24::
    4s dance in & up for reflection reels of 3 on sides with 1s+2s
25-28::
    1s & 4s cross RH & cast down1 place (2s+3s step up)
29-32::
    1s cross LH & cast to bottom (3s+4s step up)', 0);
INSERT INTO 'dancecrib' VALUES (4358, '2013-08-21 08:30:47.778336+00', '2023-02-04 01:18:51.379611+00', 10104, 3, NULL, 'ace', '1-8::
    1s cast & dance down behind own lines & back to places
9-16::
    1s cross RH, cast 1 place, cross LH & cast up to places
17-24::
    1s+2s 1/2 R&L, set & cross RH
25-32::
    1s+2s set facing in diagonally, set to partner & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4494, '2013-08-21 08:30:49.686508+00', '2023-02-04 01:19:00.130821+00', 905, 3, NULL, 'ace', '1-8::
    1s+5s cross RH, cast in 1 place & turn partners RH 1.1/4 times to
    end in line in the middle Ladies facing down & Men up
9-16::
    1s+5s dance RSh reel of 4 in middle _while_ 2s+3s+4s dance RSh reels
    of 3 on own sides (3L up & 3M down to start)
17-24::
    2s+1s also 5s+4s dance RH across & LH back ending with 1M facing 5L
    in centre
25-32::
    1M+5L turn RH 1.1/2 times to change pl, then 1L+5L also 1M+5M turn
    LH 1.1/2 times to end own sides Men''s side 2 3 4 5 1 & Ladies 5 1 2
    3 4

{{explanation}}
Repeat with new partners 4 more times', 0);
INSERT INTO 'dancecrib' VALUES (4495, '2013-08-21 08:30:49.69629+00', '2023-02-04 01:19:00.301527+00', 907, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, turn LH & cast to 3rd place
9-16::
    1s lead up, cast to 2nd place, dance down & cast up round 3s to face
    1st corners
17-24::
    Set to 1st corner, set to 2nd corner, set to each other (down/up) &
    turn 2H 1.1/2 times to face Ladies'' side (1L at top)
25-32::
    1s lead out between 2L+3L, cast (Lady up & Man down), meet & lead
    out Men''s side & cast (Lady up & Man down) round to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4474, '2013-08-21 08:30:49.356891+00', '2023-02-04 01:18:58.923134+00', 14740, 3, NULL, 'ace', '1-8::
    1s NHJ Slip step or dance down & cast up behind own lines back to
    place
9-16::
    1s dance in & cast below 3rd place to meet in promenade hold & dance
    up to top
17-24::
    1s+2s promenade & 1s cast to 2nd place as 2s dance to top
25-32::
    1s+ 1st corners Adv+Ret, 1s+2nd corners Adv+Ret
33-40::
    2s+1s+3s circle 6H round & back.', 0);
INSERT INTO 'dancecrib' VALUES (4477, '2013-08-21 08:30:49.383297+00', '2023-02-04 01:18:59.058529+00', 887, 3, NULL, 'ace', '1-8::
    1s set & 1/2 turn RH into prom hold, 1s dance 1/2 RSh reel of 3 with
    2s (2s end on opposite sides)
9-16::
    1s dance 1/2 LSh Reel of 3 with 3s & 1/2 RSh reel of 3 with 4s
17-24::
    1s followed by 4s+3s+2s cast up on opposite sides to top, cross over
    to own sides each Lady passing in front of partner & down own side
25-32::
    All set to partners & turn 2H into 4H round (2s with 3s & 4s with
    1s)', 0);
INSERT INTO 'dancecrib' VALUES (4380, '2013-08-21 08:30:47.970667+00', '2023-02-04 01:18:52.288283+00', 731, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance 6H round & back
9-16::
    1s+2s+3s set, turn partners 2H & set
17-24::
    1s & 3s dance double Figs of 8 round 2s (1s cross down to start)
25-32::
    1s+2s dance RH across (3 bars) & LH back, 1s cast 1 place as 2s
    dance up', 0);
INSERT INTO 'dancecrib' VALUES (4514, '2013-08-21 08:30:49.978565+00', '2023-02-04 01:19:01.332581+00', 942, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, turn RH to face 1st corners
9-16::
    1s dance reels of 3 on opposite sides passing 1st corner RSh & end
    facing 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting & end in centre both facing Ladies''
    side
25-32::
    1s lead out between 2L+3L & cast (1M up & 1L down), dance into
    centre, out between 2M+3M, cast & into centre _while_ 2s+3s dance
    R&L
33-40::
    1s change places RH & 1M casts up round 3M to 2nd place own side as
    1L casts down round 2L.  2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4556, '2013-08-21 08:30:50.506945+00', '2023-02-04 01:19:04.351521+00', 1008, 3, NULL, 'ace', '1-8::
    1s dance Inveran Reels with 2s+3s
9-16::
    1s+2s also 3s+4s dance double Fig of 8 with 1s & 3s crossing down to
    start
17-24::
    1s+2s also 3s+4s set, dance 1/2 RH across, all set & cross RH
25-32::
    1s+4s set, dance 1/2 RH across, 1s & 4s cross RH & cast down 1 place
    _while_ 3s dance up to 2nd place.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4389, '2013-08-21 08:30:48.091304+00', '2023-02-04 01:18:53.000587+00', 745, 3, NULL, 'ace', '1-8::
    1s set HS & turn 2H 1.3/4 times ending with 1L between 2s facing
    down & 1M between 3s facing up
9-16::
    2s+1s+3s set HS & turn opposite person 2H 1.1/2 times to change
    places
17-24::
    All set HS & turn 2H 1.1/2 times, end 1L facing 2L & 1M facing 3M
25-32::
    1s dance RSh reels of 3 across (1L with 2s & 1M with 3s) ending in
    2nd places on own sides', 0);
INSERT INTO 'dancecrib' VALUES (4521, '2013-08-21 08:30:50.056337+00', '2023-02-04 01:19:01.850433+00', 958, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, 1s followed by 2s lead down the middle
9-16::
    2s+1s dance 1/2 R&L, 1s followed by 2s lead up to top
17-24::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (4522, '2013-08-21 08:30:50.069892+00', '2023-02-04 01:19:02.085878+00', 12104, 3, NULL, 'ace', '1-8::
    1s set, cast & turn LH to face 1st corners
9-16::
    1s dance ''Hello-Goodbye'' setting & end facing own side for…
17-24::
    1s dance RH across (M with 2s & L with 3s), 1s (followed by 2s/3s)
    pass diag LSh to change ends & loop round to left 1s dancing up to…
25-32::
    1s dance LH across (1M+3s at top & 1L+2s), 1s (followed by 2s/3s)
    pass diag RSh to change ends & loop round to right to end in 2nd pl.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4598, '2013-08-21 08:30:51.212202+00', '2023-02-17 18:40:01.328279+00', 1085, 3, NULL, 'ace', '1-8::

    1s+2s circle 4H round & back

9-16::

    1s+2s dance RH across & LH back

17-24::

    1s lead down the middle & back

25-32::

    1s cast to bottom & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4550, '2013-08-21 08:30:50.360242+00', '2023-02-04 01:19:04.151579+00', 1001, 3, NULL, 'ace', '{{explanation}}
3s & 4s on opp sides

1-8::
    1s & 4s set & cast 1 place, turn LH 1.1/2 times to end facing Ladies
    corner (1M behind partner facing 2M & 4M behind 4Lfacing 3M)
9-16::
    1s & 4s dance 1/2 Alternating Tandem RSh reel of 4 with 2M+3M;
    dancing couples pass LSh & dance 1/2 Alternating Tandem RSh 1/2 reel
    of 4 with 2nd corners
17-24::
    1s & 4s repeat 1/2 Alternating Tandem reels with 3rd & 4th corners &
    end in 2nd/3rd places opp sides. 2 (1) 4 (3)
25-32::
    1s & 4s 1/2 turn partners RH into RH across 1/2 way;  2s+4s also
    1s+3s LH across once round.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (4568, '2013-08-21 08:30:50.828434+00', '2023-02-04 01:19:05.812537+00', 1034, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s+2s+3s Promenade
17-24::
    1s+2s Poussette
25-32::
    1s dance Double Triangles with 2s+3s', 0);
INSERT INTO 'dancecrib' VALUES (13398, '2020-12-02 01:19:01.770838+00', '2023-02-04 01:19:07.438584+00', 19151, 3, NULL, 'ace', '1-8::
    All 4 couples dance promenade
9-16::
    All set, all Adv+Ret (1 step each); 1s+2s also 3s+4s dance 1/2 RH
    across, 1s+4s (middle couples) dance 1/2 LH across.  (2) 4 1 (3)
17-24::
    Reels of 4 on sides
25-28::
    4s+1s (middle couples) 1/2 turn partner 2H, pull back RSh & dance
    out to opp sides. (2) (4) (1) (3)
29-32::
    All circle 8H 1/2 round to left.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (4609, '2013-08-21 08:30:51.385669+00', '2023-02-04 01:19:07.684402+00', 1098, 3, NULL, 'ace', '1-8::
    1s cross down between 2s to dance reels of 3 across giving LSh to
    2nd corners & pass RSh to face 1st corners
9-16::
    1s Fig of 8 round 1st & 2nd corner pstns (RSh to 1st corner to
    start) _while_ corners dance R&L 1s end facing 1st corners
17-24::
    1s dance ''Hello-Goodbye setting & end in centre BtoB Lady facing
    down & Man up
25-32::
    1s dance Double Triangles (up/down set) & end in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (14415, '2021-11-06 01:10:18.86622+00', '2023-02-17 18:54:50.367664+00', 1037, 3, NULL, 'ace', '1-8::

    1s cast behind 2s, lead down NHJ between 3s (2s step up). On bar 5

    1s 1/2 turn 2H (2 bars), 1s lead up to 2nd place opposite sides.

9-16::

    Diagonal 1/2 R&L (Man up/Lady down: 1L+3L & 1M+2M RH to start);

    diagonal 1/2 R&L (Man up/Lady down: 1L+3M & 1M+2L RH to start) (3)

    (1) (2)

17-24::

    All set, all cross giving RSh to partner, all turn partner 2H (3

    bars) to own side, all step in ready for …

25-32::

    _3_ couple Allemande 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4574, '2013-08-21 08:30:50.880845+00', '2023-02-04 01:19:06.140471+00', 11110, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cross turning other partner 2H on sides & end in line
    of 4 facing partner (1s above 2s) & set to partners
9-16::
    1s+2s dance 1/2 reel of 4 & spiral out round partner to own side
    (order 2 1 with 1s facing out)
17-24::
    1s cast to right, dance across, cast to 2nd place & cross RH _while_
    2s+3s dance 3/4 R&L & 3s+1s+2s set
25-32::
    3s+1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (4615, '2013-08-21 08:30:51.558849+00', '2023-02-04 01:19:08.040297+00', 1113, 3, NULL, 'ace', '1-8::
    2s+3s circle 4H round to left, 1s+2s also 3s+4s circle 4H round to
    right
9-16::
    1s & 4s cross RH, cast in 1 place, dance 1/2 Fig of 8 round 2s/3s &
    end facing other partner
17-24::
    2s+3s dance RSh reel of 4 on sides as 1s+4s dance 3/4 double RSh
    diag reel of 4 (give LH in centre) & end facing in centre.  2 4 1 3
25-32::
    4s+1s dance LH across & end 4s facing up & 1s down (on opp sides),
    4s & 1s lead out ends crossing to own side & cast to 2nd/3rd place', 0);
INSERT INTO 'dancecrib' VALUES (4459, '2013-08-21 08:30:49.110251+00', '2023-02-04 01:18:57.372806+00', 849, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    All dance RH across, Ladies cross RH & set _while_ Men set & cross
    RH
9-16::
    Ladies cross LH & set _while_ Men set & cross LH, All dance LH
    across,
17-24::
    All dance R&L
25-32::
    All turn opposite person RH 1.1/4 times into a line across, all set
    in line & each couple dances on to meet new couple', 0);
INSERT INTO 'dancecrib' VALUES (14112, '2021-07-07 00:18:51.726809+00', '2023-02-04 01:19:05.256434+00', 1027, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All circle 4H round & back
9-12::
    Couples facing anticlockwise lead between other couple, cross & cast
    back to partner''s place
13-16::
    Couples facing clockwise repeat 9-12
17-24::
    All dance 1/2 R&L, (RH to partner to start); All turn partner RH to
    end facing new couple', 0);
INSERT INTO 'dancecrib' VALUES (4618, '2013-08-21 08:30:51.583185+00', '2023-02-04 01:19:08.146239+00', 9843, 3, NULL, 'ace', '{{explanation}}
Dancers holding mobile phone with LH to ear!

1-8::
    1s cast behind own lines & back to place (it would be proper to
    phone one''s partner)
9-16::
    1s+2s dance RH across, 1s cross RH & cast 1 place
17-24::
    1s+3s dance RH across, 1s dance 1/2 Fig of 8 round 2s
25-32::
    1s turn 1st corner RH, pass partner RSh, turn 2nd corner RH & pass
    RSh to place', 0);
INSERT INTO 'dancecrib' VALUES (4621, '2013-08-21 08:30:51.613456+00', '2023-02-04 01:19:08.214868+00', 10769, 3, NULL, 'ace', '1-8::
    All set, cross RH, set & cross back RH
9-16::
    All dance quadruple Fig of 8 :
::
    1s+3s dance double Fig of 8 round 2nd places _while_ 2s+4s dance
    double Fig of 8 round 3rd places (1s & 2s cross down to 3rd/4th
    place as 3s & 4s cast up to 1st/ 2nd places to start)
17-24::
    1s cross RH, cast 1 place, cross LH & cast to bottom
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13045, '2020-08-10 00:18:47.927327+00', '2023-02-04 01:18:57.536846+00', 15047, 3, NULL, 'ace', '1-8::
    1s+2s dance the RSh »Helix«:
::
    1s+2s set passing partner RSh into BtoB position & cast round
    partner to own sides; 1s+2s 1/2 turn partners RH & dance 1/2 RH
    across
9-16::
    Reels of 3 on sides, 1M up, 1L down (RSh to 3rd corner). 1s end
    facing 1st corners
17-24::
    1s+1st corners dance Corner Pass+Turn (corners 1/2 turn RH, pull
    back RSh & dance out to diag opp place), 1s pass RSh & dance Corner
    Pass+Turn with 2nd corners.  (3) 1 (2)
25-32::
    1s dance diag R&L.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4471, '2013-08-21 08:30:49.280365+00', '2023-02-04 01:18:58.307977+00', 9169, 3, NULL, 'ace', '1-8::
    1M+2L cross RH, 1L+2M cross RH, 2s+1s Set+Link
9-16::
    1L+2M cross RH, 1M+2L cross RH, 2s+1s Set+Link back to original
    places
17-24::
    1s+2s 1/2 turn RH, slip step down for 2 bars & back, 1/2 turn 2H
    (PdB) to face up
25-32::
    1s+2s dance Allemande.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (4594, '2013-08-21 08:30:51.16568+00', '2023-02-04 01:19:07.132006+00', 10156, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place, 1/2 turn RH, twirl dance out to
    own side
9-16::
    2s+1s also 4s+3s dance RH across & LH back
17-24::
    4s followed by 1s dance 1/2 Figs of 8 round 3s (4s dance up to 2nd
    place), 4s & 1s dance 1/2 Fig of 8 round end couples
25-32::
    All circle 8H round to left for 6 steps, pivot left & chase to own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (11442, '2019-01-01 01:56:24.472711+00', '2023-02-04 01:18:58.968145+00', 18941, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 2nd place (2s step up 3-4).  1s+3s Adv+Ret
9-16::
    1s+3s dance modified Chain Progression:
::
    _9-10_    1s+3s turn 3/4 RH
::
    _11-14_  1M+3L turn LH 1.1/2 times _while_ partners chase clockwise
    1/2 way
::
    _15-16_  3s+1s turn 3/4 RH to end 3L behind 1L facing down in middle
    (Ladies'' side) & 1M behind 3M facing up (Men''s side)
17-24::
    Alternating Tandem reels of 3 across,  (1L+3L RSh to 4M & 3M+1M RSh
    to 2L).  Lead swaps bars 19-20.  All end on own sides 2 3 1 4
25-28::
    1s+4s NHJ set advancing, drop hands to face up.  1s cast to 4th
    place & face up _while_ 4s NHJ dance up 1 place turning outwards to
    face down
29-32::
    1s dance in/up & turn 4s on sides (Ladies RH, Men LH) to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4475, '2013-08-21 08:30:49.366809+00', '2023-02-04 01:18:58.982456+00', 10431, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 on opposite sides (1s cross to 2nd place, behind
    3s. 1s end in 1st place opposite sides)
9-16::
    1L+2M turn RH _while_ 1M+2L turn LH, 1s dance down below 3s divide &
    cast up to 2nd place
17-24::
    1L+3M turn RH _while_ 1M+3L turn LH, 1L dances up between 2s & casts
    into 2nd place _while_ 1M dances down between 3s & casts up to 2nd
    place
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4587, '2013-08-21 08:30:50.995616+00', '2023-02-04 01:19:06.703162+00', 1068, 3, NULL, 'ace', '1-8::
    1s turn 2H, cast 1 place own side, lead down below 3s & cast up to
    2nd place
9-16::
    1s+2L circle left, 1s+2M circle right
17-24::
    1s dance reels of 3 across (Lady with 2s & Man with 3s) & all turn
    RH
25-32::
    1s lead up, cast 1 place & 2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4641, '2013-08-21 08:30:52.000239+00', '2023-02-04 01:19:09.451228+00', 14984, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance diag reels of 4 (RSh to partner to start) &
    end facing partner
9-16::
    1s+2s also 3s+4s dance Chain Progression to 2 1 4 3 :
::
    1s+2s also 3s+4s 3/4 turn RH, 1M+2L also 3M+4L turn LH 1.1/2 times
    as ptnrs chase cl''wise 1/2 way, 2s+3s turn RH to sides as 1s+4s turn
    RH into…
17-24::
    1s+4s dance Allemande.  2 4 1 3
25-32::
    2s+4s also 1s+3s circle 4H round to left, 4s+1s dance 4H round to
    right', 0);
INSERT INTO 'dancecrib' VALUES (4650, '2013-08-21 08:30:52.285453+00', '2023-02-04 01:19:09.792273+00', 1154, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & circle 6H round to left
9-16::
    1s+2s+3s set & circle 6H round to right
17-24::
    1s+2s+3s dance Promenade, 1s casting to 2nd place
25-32::
    1s+3s dance RH across, 2s+1s dance LH across', 0);
INSERT INTO 'dancecrib' VALUES (4605, '2013-08-21 08:30:51.351603+00', '2023-02-04 01:19:07.527677+00', 11391, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels (1s in & down)
9-16::
    1L crosses between 1M+2M & casts to 3rd pl. as 3M crosses between
    2L+3L & casts up to 1st pl, 1M+3L repeat but contra
17-24::
    3s+2s+1s+4s dance reflection reels (3s in & down)
25-32::
    3s & 1s dance 1/2 Figs of 8 crossing down, 3L+2L also 1L+4L 1.1/2
    turn as partners 1.1/2 turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4656, '2013-08-21 08:30:52.344206+00', '2023-02-04 01:19:10.209509+00', 1162, 3, NULL, 'ace', '1-8::
    1s set, cross down to 2nd place, cast round 1st corner to meet
    partner (LH joined) facing 2nd corners
9-16::
    1s set to 2nd corner, turn inwards to face 4th corner & set, face
    1st corners & set, turn inwards & set to 3rd corner
17-24::
    1s dance reels of 3 on own sides (1M RSh to 2M & 1L RSh to 3L) & 1s
    end RH joined (M facing up, L down), 2s NHJ facing down & 3s up
25-32::
    2s+1s+3s set, 1s turn towards each other to take LH & all set, 1s
    dance RH across (Lady with 2s & Man with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (8307, '2014-07-29 12:58:50.563499+00', '2023-02-04 01:19:10.755463+00', 14738, 3, NULL, 'ace', '1-8::
    1s set, dance down below 3s (2s step up), cast up to 2nd place, pass
    LSh to face 1st corners
9-16::
    1s dance RSh reels of 3 on opposite sides, 1s end facing 1st corners
17-24::
    1s set to 1st corners, dance 3/4 round partner by RSh, 1s set to 2nd
    corners, dance round partner to own side, facing out
25-32::
    Promenade (Chaperoned) Chain progression:
::
    _25-26_    2s & 3s 3/4 turn partner RH into middle _while_ 1s dance
    clockwise 1/4 round the set picking up 2L/3M …
::
    _27-30_    who promenade 1/2 way clockwise _while_ middle people (2M
    + 3L) turn LH 1.1/2.
::
    _31-32_    2s & 3s turn partner RH 3/4 to own sides _while_ 1s dance
    clockwise 1/4 round to end in 2nd place. 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4523, '2013-08-21 08:30:50.079851+00', '2023-02-21 12:50:39.134604+00', 962, 3, NULL, 'ace', '1-8::

    2M sets advancing to 1L & turns RH _while_ 2L sets advancing to 3M &

    turns RH (2s end in partners place), 2s set & cross RH

9-16::

    2L sets advancing to 1M & turns RH _while_ 2M sets advancing to 3L &

    turns RH (2s end in original places), all set & turn RH into prom

    hold

17-24::

    All in prom hold dance reel of 3 (1s pass 2s RSh to start)

25-32::

    All set, 1s cast to 3rd place, all set & turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (4679, '2013-08-21 08:30:53.04386+00', '2023-02-17 18:24:48.925651+00', 1195, 3, NULL, 'ace', '1-8::

    1s cast 1 place, cross RH, cast down 1 place, cross up & cast down

    to 3rd place

9-16::

    1s followed by 3s dance up, cast round 2s & dance to 3rd place &

    cast up to 2nd place (3s end in 3rd pl)

17-24::

    1s set & petronella turn, set & petronella turn to opposite sides

25-32::

    1s dance reels of 3 on opposite sides (RSh to 2nd corner to start) &

    cross RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4535, '2013-08-21 08:30:50.185506+00', '2023-02-04 01:19:02.80484+00', 14392, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up) & dance NHJ down between 3s & cast up
    to 2nd place opp sides
9-16::
    2s+1s+3s circle 6H round & back
17-24::
    1s turn 1.1/2 RH _while_ 2s+3s chase clockwise 1/2 round set & all
    set twice
25-32::
    3s+1s+2s dance Diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (4685, '2013-08-21 08:30:53.126705+00', '2023-02-17 18:02:19.821318+00', 1200, 3, NULL, 'ace', '1-8::

    1s dance up for 2 steps, dance down for 2 steps _while_ 2s step up,

    1L curves round left to 2nd place _while_ 1M curves round right to

    2nd place & set

9-16::

    1s dance up for 2 steps, dance down for 2 steps, 1L curves round

    left below 3s _while_ 1M curves round right below 3s & cast up to

    2nd place

17-24::

    1s turn LH, lead up crossing & cast to 2nd places opposite sides,

    cross passing LSh to own sides in double triangle position

25-32::

    1s dance Double Triangles ending in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4662, '2013-08-21 08:30:52.475974+00', '2023-02-04 01:19:10.819585+00', 1167, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast into centre & dance 1/2 Fig of 8 round new
    end couples
9-16::
    All set, 1s+4s dance 3/4 R&L to face nearest corners
17-24::
    1s & 4s set & turn corners RH, 1s+4s set & turn each other LH on
    sides
25-32::
    All dance reels of 4 on sides', 0);
INSERT INTO 'dancecrib' VALUES (4555, '2013-08-21 08:30:50.497175+00', '2023-02-04 01:19:04.316374+00', 7631, 3, NULL, 'ace', '1-8::
    1s set, cast 2 places, cross RH & cast up 2 places
9-16::
    1s+2s 1/2 R&L, 1s 1/2 Fig of 8 round 3s
17-24::
    1s Fig of 8 round 2s
25-32::
    2s+1s Adv+Ret 2 steps & turn partners RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (4561, '2013-08-21 08:30:50.654075+00', '2023-02-04 01:19:04.853289+00', 9688, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s lead down middle & back
17-24::
    1s+2s dance Allemande
25-32::
    2s+1s cross RH & turn LH on sides (4 Bars) then cross RH', 0);
INSERT INTO 'dancecrib' VALUES (4665, '2013-08-21 08:30:52.50362+00', '2023-02-04 01:19:10.877496+00', 1171, 3, NULL, 'ace', '1-8::
    1s+2s facing diagonally in Adv+Ret 1 step twice, petronella turn to
    right 1 place & set (diagonally in)
9-16::
    1s+2s repeat bars 1- 8 to end on opposite sides 1s in 2nd place
17-24::
    2s+1s turn 2H & dance 1/2 R&L back to original places
25-32::
    1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (4703, '2013-08-21 08:30:53.574777+00', '2023-02-04 01:19:13.80694+00', 10758, 3, NULL, 'ace', '1-8::
    1s & 3s petronella turn into centre & set, dance 1/2 reel of 4
9-16::
    3s & 1s petronella turn to own sides _while_ 2s petronella turn to
    form lines of 3 across & all set, 2s petronella turn to sides & all
    set on sides.  3 (2) 1
17-24::
    2s dance 1/2 reel of 3 across (2L RSh to 3L at top & 2M RSh to 1M) &
    1/2 LSh reels of 3 on sides.  (1) 2 (3)
25-32::
    2s dance 1/2 reel of 3 across (2M RSh to 1M at top & 2L with 3L), 1s
    cast to 2nd place _while_ 2s cross up & 1s turn RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4710, '2013-08-21 08:30:53.703061+00', '2023-02-04 01:19:14.249308+00', 8502, 3, NULL, 'ace', '1-8::
    1L+2L+3L Adv+Ret, 1L+2M also 2L+3M dance DoSiDo
9-16::
    1M+2M+3M Adv+Ret, 1M+2L also 2M+3L dance DoSiDo
17-32::
    1s+2s+3s dance 3 couple R&L, 1s set & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (4667, '2013-08-21 08:30:52.721326+00', '2023-02-04 01:19:11.060755+00', 9203, 3, NULL, 'ace', '1-8::
    1L+2M change places RH & cast to partners place _while_ 1M+2L set &
    dance down/up 1 place, 1s+2s dance RH across
9-16::
    1L+2M change places LH & cast to original places _while_ 1M+2L set &
    dance to original places, 1s+2s dance LH across
17-24::
    1s+2s+3s dance LSh reels of 3 on own sides
25-32::
    1M+2M also 1L+2L turn LH 1.1/2 times & 1s+3s dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (4669, '2013-08-21 08:30:52.873624+00', '2023-02-04 01:19:11.423891+00', 9844, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Figs of 8 round 3s
9-16::
    1s dance 1/2 reel of 3 across (Lady up with 2s & Man down with 3s);
    1/2 reel of 3 on opposite sides (Man up Lady''s side, Lady down Man''s
    side) & 1s end facing 3rd corner (own 1st corner person)
17-24::
    "Hello-Goodbye setting": 1s set to 3rd corners, set on sides (2nd
    place), set to 4th corners & petronella turn to 2nd place opposite
    sides
25-32::
    3s+1s+2s chase clockwise 1/2 way & turn partner RH. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4712, '2013-08-21 08:30:53.731521+00', '2023-02-04 01:19:14.408922+00', 1231, 3, NULL, 'ace', '1-8::
    Top 3 Men turn bottom 3 Ladies RH, top 3 Ladies turn bottom 3 Men RH
9-16::
    1L also 4M followed by partners cast in 1 place & cross to opposite
    side (2s & 3s step down/up 11-12); 1M+4M also 1L+4L turn LH 1.1/2
    times on sides
17-24::
    1s+4s turn partners RH; 4M also 1L, followed by partners, cast to
    ends & cross to own sides
25-32::
    4s+2s also 3s+1s dance 1/2 R&L; 4s & 1s dance 1/2 Figs of 8 round
    2s/3s _while_ 2s & 3s set & cross RH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4579, '2013-08-21 08:30:50.92658+00', '2023-02-04 01:19:06.346418+00', 12871, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 1L+2M change places RH _while_ partners set & 1s+2s
    dance RH across 1/2 way
9-16::
    1s+2s+3s dance Grand Chain (3s cross to start)
17-24::
    1s+2s Set+Link with partners, 1M+2L change places RH _while_
    partners set & 1s+2s circle 4H round to left 1/2 way
25-32::
    2s+1s+3s dance reels of 3 on sides (1s down between 3s to start)
    with 1s & 2s crossing to own sides when dancing up to top', 0);
INSERT INTO 'dancecrib' VALUES (4582, '2013-08-21 08:30:50.951013+00', '2023-02-04 01:19:06.444602+00', 9290, 3, NULL, 'ace', '1-8::
    1s dance reel of 3 with 2L (1s pass RSh)
9-16::
    1s+2s 1/2 turn & dance out to partners place, 1s+2s dance 4H round
    to left
17-24::
    1s dance reel of 3 with 2M (1s pass RSh)
25-32::
    1s+2s Set+Link twice', 0);
INSERT INTO 'dancecrib' VALUES (4722, '2013-08-21 08:30:53.923961+00', '2023-02-04 01:19:14.949744+00', 8086, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s lead down the middle & up
17-24::
    1s+2s dance Poussette.  2 1
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (13050, '2020-08-10 00:18:55.359864+00', '2023-02-04 01:19:06.762689+00', 8040, 3, NULL, 'ace', '1-8::
    All Adv+Ret; All cross to opp side, Ladies dancing under arches made
    by Men
9-16::
    Repeat 1-8, Ladies making arches
17-24::
    1s slip step down middle & back up ; 1s dance behind 2s, in front of
    3s & behind 4s to 4th place (2s+3s+4s step up as 1s dance past them)
25-32::
    2s+3s+4s+1s circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4683, '2013-08-21 08:30:53.109907+00', '2023-02-04 01:19:12.515899+00', 1198, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret 2 steps & turn RH to end facing the top
9-16::
    1s+2s Allemande
17-24::
    1s+3s RH across & LH across
25-32::
    1s dance up to top, cast behind 2s, dance down below 3s & cast up to
    2nd place
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4601, '2013-08-21 08:30:51.302878+00', '2023-02-04 01:19:07.287358+00', 8041, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s circle 4H round & back, all end on sides
9-16::
    All dance RSh reels of 4 on the sides.
17-24::
    1s lead down the middle & back.
25-32::
    1s cast to 4th place, 1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (4736, '2013-08-21 08:30:54.057854+00', '2023-02-04 01:19:15.55467+00', 1274, 3, NULL, 'ace', '1-8::
    1s+2s dance DoSiDo & turn partners RH
9-16::
    1M dances RSh round 2L to 2nd Man''s place as 2M dances RSh round 1L
    ending in 1st Man''s place, 1s+2s clap & circle 4H round to left
17-24::
    1L dances RSh round partner to 2nd lady''s place as 2L dances RSh
    round partner to 1st Lady''s place, 2s+1s clap & circle 4H round to
    left', 0);
INSERT INTO 'dancecrib' VALUES (4745, '2013-08-21 08:30:54.246314+00', '2023-02-04 01:19:16.083007+00', 10600, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    All dance RH across & LH back
9-16::
    All turn opposite person RH & turn partner LH (long turns)
17-24::
    All circle 4H round & back
25-32::
    All Adv+Ret for 2 steps & cross passing RSh to face next couple', 0);
INSERT INTO 'dancecrib' VALUES (4704, '2013-08-21 08:30:53.582814+00', '2023-02-04 01:19:13.83707+00', 1218, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & turn RH 1.1/2 times
9-16::
    1s cross up to dance reels of 3 on own sides
17-24::
    1s Adv+Ret, 2s+1s+3s dance DoSiDo
25-32::
    1s dance Double Triangles with 2s+3s', 4);
INSERT INTO 'dancecrib' VALUES (4751, '2013-08-21 08:30:54.29487+00', '2023-02-04 01:19:16.610183+00', 1298, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, 1L+2M set turning 1/4 left & change places
    passing BtoB with slip steps, set turning to face partner (Set &
    Shuttle)
9-16::
    1s+2s dance 1/2 R&L changing place on side lines to start, 1M+2L
    change places Set & Shuttle ending facing partners
17-24::
    2s+1s set, cross RH & turn RH
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4723, '2013-08-21 08:30:53.93368+00', '2023-02-04 01:19:15.115138+00', 1247, 3, NULL, 'ace', '1-16::
    1s & 3s cast 1 place as 2s & 4s advance turning right about to face
    1s/3s, all set, dance full reel of 4 across & circle 4H round to
    left
17-24::
    2s+3s dance RH across for 3 steps (all the way round) & change
    places LH with corner, 1s+4s repeat changing back to places
25-32::
    1s set HS, cast to bottom & Bal-in-Line with partner RH', 0);
INSERT INTO 'dancecrib' VALUES (4724, '2013-08-21 08:30:53.941755+00', '2023-02-04 01:19:15.125494+00', 1250, 3, NULL, 'ace', '1-8::
    1M followed by 2M+3M (who dance up) cross & cast down Ladies'' side;
    cross below 3s & dance up on own side to places
9-16::
    1s+2s+3s turn partners RH once round & turn partners LH once round
17-24::
    1L followed by 2L+3L (who dance up) cross & cast down Men''s side;
    cross below 3s & dance up on own side
25-32::
    All 4 couples Adv+Ret; 1s cast to 4th place _while_ 2s+3s+4s step up', 0);
INSERT INTO 'dancecrib' VALUES (4765, '2013-08-21 08:30:54.869457+00', '2023-02-04 01:19:18.257835+00', 12672, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set & petronella-in-tandem.  1s+2s also 3s+4s dance
    RH across once round
9-16::
    1L+2L & 1M+2M set & petronella-in-tandem as 3s+4s dance similar.
    All set, cross RH, 2M+4M+1L+3L pull back RSh ready for...
17-24::
    Reels of 4 on sides. Bars 23-24 1s+4s do not pass LSh instead 1s 1/2
    turn 4s 2H. All face in
25-28::
    1s+4s circle 4H round to Left
29-32::
    1s+4s Set+Link   End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4738, '2013-08-21 08:30:54.171012+00', '2023-02-04 01:19:15.683377+00', 10916, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH, 3s+4s set & cross RH
9-16::
    4s followed by 3s+2s+1s dance down for 2 bars, all 1/2 turn partners
    RH & dance up to places
17-24::
    1s lead down for 2 bars, lead up & cast to bottom
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4773, '2013-08-21 08:30:55.017028+00', '2023-02-04 01:19:18.696366+00', 7373, 3, NULL, 'ace', '1-8::
    1s in prom hold dance reel of 3 with 3M+2L passing 3M by RSh to
    start ending in centre facing down
9-16::
    1s in prom hold dance reel of 3 with 3L+2M passing 3L by LSh to
    start ending in centre facing down
17-24::
    1s dance down below 3s, cast up on own sides to 2nd place & dance RH
    across with2s
25-32::
    All set, 1s cast to 3rd place & all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (4638, '2013-08-21 08:30:51.975198+00', '2023-02-04 01:19:09.29647+00', 10049, 3, NULL, 'ace', '1-16::
    1s cross RH, cast 1 place, dance 3 couple R&L & end facing 1st
    corners
17-24::
    1s dance ''Hello-Goodbye'' setting & end BtoB (Man facing up)
25-32::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corners &
    cross RH to places', 0);
INSERT INTO 'dancecrib' VALUES (4749, '2013-08-21 08:30:54.277159+00', '2023-02-04 01:19:16.491697+00', 11805, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s lead down for 2 & back, cross to own sides & cast to face 1st
    corners
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4763, '2013-08-21 08:30:54.85387+00', '2023-02-04 01:19:17.869657+00', 1315, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-16::
    1L+2L dance between partners, divide & dance back to places, 1s turn
    RH 1.1/2 times as 2s turn LH 1.1/2 times
17-24::
    1M+2M dance between partners, divide & dance back to places, 1s turn
    RH 1.1/2 times as 2s turn LH 1.1/2 times
25-32::
    1s+2s set, circle 4H round to left 1/2 way & turn partners 2H 1.1/2
    times', 0);
INSERT INTO 'dancecrib' VALUES (4758, '2013-08-21 08:30:54.3591+00', '2023-02-04 01:19:16.941897+00', 1308, 3, NULL, 'ace', '1-4::
    1s turn RH & cast 1 place
5-16::
    2s+1s+3s cross RH, 1s change places LH on sides with 1st corners
    _while_ 2nd corners set, repeat twice to end (3)(1)(2)
17-24::
    1s cross RH, dance round 3rd corners pstns RSh into centre & turn LH
    1.1/2 times
25-32::
    1s dance RH across (Lady with 3s at top & Man with 2s), 3M followed
    by 3L+1L chase cl''wise 1/2 way _while_ 2L followed by 2M+1M chase
    1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (4802, '2013-08-21 08:30:55.284083+00', '2023-02-04 01:19:20.484021+00', 14394, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides.  2 1 3
9-16::
    1s+3s dance RH across, 2s+1s+3s chase clockwise 1/2 way.  (3)(1)(2)
17-24::
    3L & 2M change places RH then 3M & 2L change places LH, 1s 1/2 turn
    RH moving down 1 place & all set  2 3 1
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4812, '2013-08-21 08:30:55.38004+00', '2023-02-17 12:12:24.421795+00', 1390, 3, NULL, 'ace', '1-8::

    1M+2L turn RH 1.1/4 times, dance out behind partner (RSh) & cross LH

    back to places

9-16::

    1L+2M turn LH 1.1/4 times, dance out behind partner (LSh) & cross RH

    back to places

17-24::

    1s+2s set, dance 1/2 RH across, change places RH on sides & dance

    1/2 RH across

25-32::

    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4660, '2013-08-21 08:30:52.45731+00', '2023-02-04 01:19:10.77916+00', 2786, 3, NULL, 'ace', '1-8::
    2s & 4s set advancing & Bal-in-Line, 1/2 turn RH & Bal-in-Line
9-16::
    2L+1s, 2M+3s+4L & 4M+5s dance LH across, 2s & 4s pass LSh into RH
    across with other couples & end passing LSh to face own sides (BtoB)
17-24::
    All set (as Double Triangles), 2s & 4s change places RH with person
    on right _while_ others set, all set (as Double Triangles), centre
    dancers change places LH with person on left _while_ others set &
    all end on own sides facing new partners.  Order 2M 4M 1M 5M 3M & 3L
    1L 5L 2L 4L
25-32::
    Top 2 couples also bottom 2 couples dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (4661, '2013-08-21 08:30:52.465893+00', '2023-02-04 01:19:10.795023+00', 12873, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set & dance 1/2 RH across, 1s+4s dance 1/2 LH
    across & all set
9-16::
    2s+4s also 1s+3s dance Ladies'' Chain
17-24::
    2s+4s also 1s+3s set & dance 1/2 RH across, 2s+3s dance 1/2 LH
    across & all set
25-32::
    All dance Grand Chain 1/2 way (all starting on sides), set, 1s dance
    down to 4th place _while_ 2s+3s+4s dance up 1 place', 0);
INSERT INTO 'dancecrib' VALUES (13399, '2020-12-02 01:19:10.568019+00', '2023-02-04 01:19:19.578144+00', 19899, 3, NULL, 'ace', '1-8::
    All Set+Link twice
9-16::
    1M followed by 1L chase to 2nd place, Bar 11:  2s chase to 3rd place
    & 1s dance into 2nd place & so on to finish all couples progressed &
    all Men end back to back in the centre facing Lady. 1M+2M+3M dance
    in on bar 16, 4M loops in from 1L place
17-22::
    All men dance 6 bars of Crown Triangles (no hands) _while_ Ladies
    set, Petronella turn to the Right & set
23-24::
    All Petronella turn to change places with facing person to end
    Ladies back to back inside the set
25-30::
    Repeat bars 17-22
31-32::
    All petronella to the right to end on sides in order 3 4 1 2. 1s
    stay in the centre
33-40::
    1s dance all Round Poussette
41-48::
    All circle no hands to Left, pivot & circle back giving hands 4 1 2
    3', 0);
INSERT INTO 'dancecrib' VALUES (13058, '2020-08-10 00:19:06.446487+00', '2023-02-04 01:19:19.555393+00', 19898, 3, NULL, 'ace', '{{explanation}}
No hands are given throughout

1-8::
    1s+3s dance double Fig 8 round 2s (1s cross down, 3s cast up)
9-16::
    1s+2s+3s circle round & back
17-24::
    Grand Chain, 1s cross passing RSh, 2s+3s change places on sides to
    start
25-32::
    1s lead down & back up into 3rd place (2s+3s step up 31-32)', 0);
INSERT INTO 'dancecrib' VALUES (4687, '2013-08-21 08:30:53.171746+00', '2023-02-04 01:19:12.807482+00', 1202, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All circle 8H round & back
9-16::
    All petronella turn to Ladies BtoB facing partners & set, turn
    partners RH twice round
17-24::
    All Ladies dance LH across 1.1/2 times _while_ Men chase clockwise
    1/2 way, all turn partners RH 1.1/2 times to Men BtoB facing
    partners
25-32::
    All Men dance LH across 1.1/2 times _while_ Ladies chase clockwise
    1/2 way, all turn partners RH 2.1/4 times to end in original places

{{title}}
Reel

1-8::
    All dance Grand Chain 1/2 way, set & turn partners 2H
9-16::
    Repeat bars 1-8 back to places
17-24::
    All Ladies Advance (clap) & Retire, all Men Advance (clap) & Retire
25-32::
    All set twice & turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (4850, '2013-08-21 08:30:55.882248+00', '2023-02-04 01:19:23.097632+00', 11392, 3, NULL, 'ace', '1-8::
    1M+2M dance 1/2 Diag R&L with 2L+3L, 3L casts down 2 places &
    crosses to place _while_ 1M casts up 2 places & crosses to place
9-16::
    1L+2M dance 1/2 Diag R&L with 2L+3M, 3M crosses & casts down 2
    places _while_ 1L crosses & casts up 2 places
17-24::
    1s dance diag reel of 3 with 2L (1s pass RSh to start) _while_ 3s
    dance diag reel of 3 with 2M (3s pass RSh to start)
25-32::
    1L+2L turn LH 1.1/2 times _while_ 1M+2M turn RH 1.1/2 times, 1s
    dance down between 3s & cast up to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (4707, '2013-08-21 08:30:53.609088+00', '2023-02-04 01:19:14.003663+00', 8250, 3, NULL, 'ace', '1-8::
    1L crosses down & cast down behind 3M, crosses down & casts up
    behind 4L to place
9-16::
    1s lead down to bottom & cast up round 4s to 3rd place, 2s+1s
    petronella turn into middle
17-24::
    2s+1s dance reel of 4 up/down middle
25-32::
    2s & 1s turn partners RH ending 2s at top & 1s at bottom, 2s+3s also
    4s+1s circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (4832, '2013-08-21 08:30:55.713472+00', '2023-02-04 01:19:22.267379+00', 8169, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & turn LH 1.1/2 times to end in 2nd place
    opposite sides
9-16::
    1s dance reels of 3 on sides giving LSh to 2nd corner to start & end
    2nd place opp sides facing out as 2s & 3s end in centre with nearer
    hands joined
17-24::
    1s chase anticlockwise to 2nd place own sides _while_ 2s+3s Adv+Ret
    to places, 2s+1s+3s turn RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4877, '2013-08-21 08:30:56.331404+00', '2023-02-04 01:19:24.889369+00', 1483, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig of 8 (1s cross down to start)
9-16::
    1s+2s dance R&L
17-24::
    1s set, cast 1 place, 1s+2s turn RH
25-32::
    2s+1s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (4721, '2013-08-21 08:30:53.914339+00', '2023-02-04 01:19:14.91414+00', 1246, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s lead down the middle for 3 steps & up for 3 steps then cast to
    2nd places
17-24::
    1s+3s circle 4H round to left, lead down & cast round 3s to top on
    own sides
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4835, '2013-08-21 08:30:55.739283+00', '2023-02-04 01:19:22.35593+00', 1424, 3, NULL, 'ace', '1-8::
    1s lead down for 3 steps, lead up to top & cast to 2nd place
9-16::
    2s+1s dance 3/4 R&L, face each other on sides & set
17-24::
    1M+2M also 1L+2L turn 1.1/2 times with nearer hand 1s dancing
    between 2s, 1s+3s repeat but 3s dance between 1s
25-32::
    1s+4s repeat with 1s dancing between 4s & all dance DoSiDo', 0);
INSERT INTO 'dancecrib' VALUES (4871, '2013-08-21 08:30:56.197053+00', '2023-02-04 01:19:24.257873+00', 1475, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, turn RH 1.1/2 times & pick up 1st corners
    (on their left)
9-16::
    Couples change pls (1L+crnr pass under arch made by ptnr+crnr), turn
    crnrs (1L RH & 1M LH) to end 1L between 2M+3M & 1M between 2L+3L &
    set
17-24::
    1s with 2nd corners repeat (but 1L turns RH & 1M turns LH)
25-32::
    1s cast to 2nd place own sides _while_ 3L+2M turn RH once into RH
    across 1/2 way with 1s, 1s turn LH into LH across 1/2 way with 3M+2L', 0);
INSERT INTO 'dancecrib' VALUES (4857, '2013-08-21 08:30:56.078725+00', '2023-02-17 11:53:41.439297+00', 1452, 3, NULL, 'ace', '1-8::

    1s+2s set, 1s cast, turn RH & lead up _while_ 2s turn RH lead up &

    cast

9-16::

    1s+2s dance Allemande

17-24::

    1L dances RH across with 2s & 1M with 3s, 1s lead up & cast

25-32::

    1L dances LH across with 3s & 1M with 2s, 1s lead down & cast back

    to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (4729, '2013-08-21 08:30:53.987214+00', '2023-02-04 01:19:15.368871+00', 1260, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back 1s ending in allemande hold facing
    Ladies'' side
9-16::
    1s set HS to 2L, 1s cast on own sides, dance down between 3s & cast
    up to 2nd place
17-24::
    1s dance reels of 3 on own sides dancing up between 2s to start
25-32::
    2s+1s+3s set HS on sides & turn partner 2H twice round', 0);
INSERT INTO 'dancecrib' VALUES (4741, '2013-08-21 08:30:54.20901+00', '2023-02-04 01:19:15.843762+00', 1280, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back, all remaining in centre with
    partner ready for …
9-16::
    1s+2s+3s Promenade
17-24::
    1s cross RH, cast to 2nd place (2 step up 19-20), cross LH, cast to
    3rd place & lead up to face 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting ending with a clap & petronella
    turn to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (4750, '2013-08-21 08:30:54.286794+00', '2023-02-04 01:19:16.594627+00', 1296, 3, NULL, 'ace', '{{explanation}}
1s start on opp sides

1-8::
    1s+2s dance R&L (RH on sides to start)
9-16::
    1s+2s set to partners twice & turn 2H
17-24::
    1s+2s dance RH across & LH back to places
25-32::
    1s+2s set twice facing up/down dance, 1s turn opposite dancer 2H
    1.1/2 times to end 2nd place opposite sides

{{explanation}}
Note -  on bar 64 new top couple crosses to opposite sides as original 1s at bottom cross to own sides.', 0);
INSERT INTO 'dancecrib' VALUES (4874, '2013-08-21 08:30:56.224379+00', '2023-02-04 01:19:24.556373+00', 1478, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH across back to places
9-16::
    1s lead down the middle & back
17-28::
    1s followed by 2s+3s+4s cast down on own sides & lead back up to top
29-32::
    1s lead down to bottom under arches made by 2s+3s+4s (2s+3s+4s step
    up bar 32).  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8314, '2014-07-29 12:58:53.987333+00', '2023-02-04 01:19:26.360371+00', 15222, 3, NULL, 'ace', '1-8::
    1s+3s cast 1 place, 1s+3s turn RH, 1s cast to 4th place as 3s lead
    up to 2nd place 2 3 4 1
9-16::
    2s+4s repeat bars 1-8, finishing 3 4 1 2 facing up/down on sides
17-24::
    3s+4s & 1s+2s set advancing passing each other LSh; 3s+2s set
    advancing passing each other LSh _while_ 4s+1s set & face in; 4s+2s
    & 3s+1s dance RH across
25-32::
    4s cross RH, cast (2s step up), 4s cross RH, cast (3s step up)
33-40::
    All circle 8H round to left (6 steps), pivot pulling RSh back & all
    chase to places 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4762, '2013-08-21 08:30:54.84565+00', '2023-02-04 01:19:17.840793+00', 14552, 3, NULL, 'ace', '1-8::
    1s+2s Dance Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    1s cross RH & cast right, cross LH up/down & cast left to end facing
    1st corners
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners & pass RSh to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4881, '2013-08-21 08:30:56.367661+00', '2023-02-04 01:19:25.172531+00', 9103, 3, NULL, 'ace', '1-8::
    1s cast down own sides & cast back to 2nd place (2s step up 3-4)
9-16::
    2s+1s dance RH across & LH back
17-24::
    1s turn RH to face 1st corners, turn 1st corner LH, turn 2nd corner
    RH & cross LH to 2nd places own sides
25-32::
    2s+1s+3s Adv+Ret & turn RH. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15221, '2022-11-03 01:19:16.946322+00', '2023-02-04 01:19:26.645429+00', 20448, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s+3s Petronella turn & set; Petronella turn & set.  (1) (2) (3)
9-16::
    1s dance in & cast (2s step up); 1s turn RH & face out (2nd place
    opp side)
17-24::
    Promenade (Chaperoned) Chain progression:
::
    _17-18_    2s & 3s 3/4 turn partner RH into middle _while_ 1s dance
    clockwise 1/4 round the set picking up 2L/3M …
::
    _19-22_   who promenade 1/2 way clockwise _while_ middle people
    (2L+3M) turn LH 1.1/2
::
    _23-24_   3s & 2s turn partner RH 3/4 to own sides _while_ 1s dance
    clockwise 1/4 round to end in 2nd place. (3) (1) (2)
25-32::
    3s+1s+2s dance Set+Link twice to end 2 1 3

{{title}}
Reel

{{explanation}}
Repeat 1-32 in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (4771, '2013-08-21 08:30:54.999401+00', '2023-02-04 01:19:18.651014+00', 10945, 3, NULL, 'ace', '1-8::
    1M+2L set & change places RH also 3L+4M set & change places LH,
    1s+2s dance RH across _while_ 3s+4s dance LH across
9-16::
    1L+2M set & change places LH also 3M+4L set & change places RH,
    2s+1s dance LH across _while_ 4s+3s dance RH across
17-24::
    All set & cross RH, 1s followed by 4s dance up between 2s & cast to
    3rd/2nd places.  2 4 1 3
25-32::
    4s & 1s dance Figs of 8 round end couples', 0);
INSERT INTO 'dancecrib' VALUES (8835, '2015-08-13 20:33:29.691199+00', '2023-02-04 01:19:26.007942+00', 16274, 3, NULL, 'ace', '1-8::
    1s+3s cross RH & set _while_ 2s & 4s Set+Link.  2s+4s cross RH and
    set _while_ 1s & 3s Set+Link
9-16::
    All circle 8H 1/2 round to Left, retain hands, Adv+Ret finish facing
    corners
17-24::
    Grand Chain 1/2 way (no hands - 2 bars to pass each person) and pass
    partners LSh at end
25-28::
    All turn partners LH & face in with NHJ
29-32::
    1s & 3s Adv+Ret into next place clockwise _while_ 2s & 4s set, pull
    back RSh & cast to next place clockwise   2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14519, '2022-01-10 02:18:55.956483+00', '2023-02-04 01:19:27.704118+00', 17959, 3, NULL, 'ace', '1-8::
    1s+2s dance 3/4 R&L (6 bars), 1s turn 2s LH on sides. 2 1 3
9-16::
    RSh reels of 3 on sides (1s RSh to 3s to start)
17-24::
    2s+1s+3s Adv+Ret; all circle 6H 1/2 round to left
25-32::
    2s+1s+3s Adv+Ret; all circle 6H 1/2 round to right', 0);
INSERT INTO 'dancecrib' VALUES (4784, '2013-08-21 08:30:55.113194+00', '2023-02-04 01:19:19.165584+00', 1348, 3, NULL, 'ace', '1-8::
    1s cast down own sides, turn inwards dance back to top
9-16::
    1s dance full Fig of 8 round 2s
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (4895, '2013-08-21 08:30:56.613553+00', '2023-02-04 01:19:26.436967+00', 1510, 3, NULL, 'ace', '1-8::
    1s+2s+3s turn RH (4 bars); 1s+2s dance 1/2 Poussette (out to side &
    1/4 turn, along sides & 3/4 turn 2H onto own sides).  2s face out,
    1s face in
9-16::
    2s+1s dance double Fig of 8 (1s cross up & 2s cast)
17-24::
    1s dance 1/2 reels of 3 across (1M with 2s & 1L with 3s); 2s+1s+3s
    advance, turn partner RH under Man''s arm & retire to sides
25-32::
    1s dance 1/2 reels of 3 across (1L with 2s & 1M with 3s); 1s dance
    RH across (1L with 2s & 1M with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (4792, '2013-08-21 08:30:55.185093+00', '2023-02-04 01:19:19.716912+00', 9054, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across; 1L followed by1M casts 1 place, Lady crossing
    to opposite side & facing out _while_ 2s retain RH & turn moving up
    to top place own side
9-16::
    1s+3s dance LH across: 1L followed by 1M casts down 1 place, Lady
    crossing to own side _while_ 3s retain RH & turn moving up to 2nd
    place own side. 2 3 1
17-24::
    3s+1s Set+Link; 2s+1s Set+Link
25-32::
    1s+2s set & dance 1/2 RH across; 2s+1s turn RH 1.1/2 times as 3s
    turn once round. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13062, '2020-08-10 00:19:12.188906+00', '2023-02-04 01:19:27.133278+00', 17630, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-8::
    1s+2s also 3s+4s Set & Rotate
9-16::
    1s+4s Set+Link, 1s+4s end NHJ with partner, 1s facing down, 4s
    facing up; 1s+4s Set+Link ending on side lines, 2s facing 4s, 1s
    facing 3s
17-24::
    2s+4s+1s+3s dance RSh reels of 4 on sides
25-32::
    2s+4s also 1s+3s dance R&L starting changing places RH on side

{{explanation}}
Dance 4 times through, 2x Strathspey + 2x Reel', 0);
INSERT INTO 'dancecrib' VALUES (13402, '2020-12-02 01:19:16.47529+00', '2023-02-04 01:19:27.272578+00', 19152, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L; 1s+3s dance 1/2 R&L
9-12::
    1s+4s dance 1/2 R&L. (2) (3) (4) (1)
13-16::
    All set, 2s+3s+4s 1/2 turn partner RH _while_ 1s cross RH
17-24::
    2s+3s+4s dance promenade
25-32::
    2s+3s also 4s+1s dance RH across & LH across,  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4798, '2013-08-21 08:30:55.246119+00', '2023-02-04 01:19:20.329667+00', 1367, 3, NULL, 'ace', '1-8::
    1L+2M change places RH, 2L+1M change places RH, 2s+1s turn RH on
    sides
9-16::
    Repeat with 1s ending facing 1st corners
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH to end
    in 2nd place own side
25-32::
    2s+1s+3s Adv+Ret & turn RH into prom hold
33-40::
    2s+1s+3s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (4910, '2013-08-21 08:30:56.872707+00', '2023-02-04 01:19:28.093924+00', 1526, 3, NULL, 'ace', '1-8::
    All set & 1s+4s turn RH moving down/up, 1M followed by partner
    dances out & down behind 3L to 4th place own side _while_ 4L
    followed by partner dances out & up behind 2M to 1st place own sides
9-16::
    All dance RSh reels on sides
17-24::
    4s+2s dance Rondel as 3s+1s dance a reversed Rondel (1s dance up
    under arch by 3s)
25-32::
    1s followed by 4s+3s lead up middle between 2s & cast down own
    sides, all turn partners RH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (10063, '2017-09-03 23:44:29.911844+00', '2023-02-04 01:19:28.15673+00', 17777, 3, NULL, 'ace', '1-8::
    1s Adv+Ret (bars 1-4), 2s Adv+Ret (bars 3-6), 3s Adv+Ret (bars 5-8)
9-12::
    2s, followed by 1s, dance down between 3s & cast up to top  2 1 3
13-16::
    1s, followed by 3s, dance up between 2s & cast to bottom  2 3 1
17-20::
    All set & cross RH
21-28::
    All circle 6H round & back
29-21::
    All cross LH & set', 0);
INSERT INTO 'dancecrib' VALUES (4915, '2013-08-21 08:30:56.9917+00', '2023-02-12 16:26:11.221689+00', 1535, 3, NULL, 'ace', '1-8::

    1s lead down the middle & back to face 2L in prom hold

9-16::

    1s dance reel of 3 across with 2s (giving RSh to 2L)

17-24::

    1s dance reel of 3 across with 3s (LSh to 3L) ending in the middle

    (Man facing down & Lady facing up to partner)

25-32::

    1s set in middle, petronella to 2nd place own sides & 2s+1s+3s turn

    RH (4 bars)', 0);
INSERT INTO 'dancecrib' VALUES (4808, '2013-08-21 08:30:55.335894+00', '2023-02-17 12:22:31.427983+00', 1382, 3, NULL, 'ace', '1-8::

    1s+2s petronella into centre & set, 3/4 turn partner RH & dance RH

    across 1/2 way (2s & 1s have changed places)

9-16::

    2L followed by 2M also 3M followed by 3L chase clock-wise 1/2 way to

    change places, 3s+1s+2s turn partners (1s LH & 3s & 2s RH)

17-24::

    3s+1s+2s turn ptnrs (other hand), 1L+3M also 1M+2L (nearer hands

    joined facing out) turn clockwise to place 3M/2L into 3rd/1st pstns

    (opp sides) _while_ 3L & 2M cross over to own sides, 1s set _while_

    2s+3s chase (round 1s) clock-wise 1 place to end 2 1 3 (on own

    sides)

25-32::

    2s+1s+3s set, circle 6H round to left & spiral out to places', 0);
INSERT INTO 'dancecrib' VALUES (13298, '2020-11-02 01:19:20.669821+00', '2023-02-04 01:19:29.646904+00', 20092, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place (2s step up 3-4) & dance 1/2 Fig of 8 round 2s
9-16::
    1s dance reflection reels of 3 on sides (1s in & down to start)
17-24::
    1s petronella turn into lines across, set; petronella turn again to
    2nd place & set
25-32::
    1s dance Fig of 8 down round 3s', 0);
INSERT INTO 'dancecrib' VALUES (9188, '2016-06-16 22:41:41.11881+00', '2023-02-04 01:19:29.681233+00', 12950, 3, NULL, 'ace', '1-8::
    1s+3s dance double Fig round 2s (1s cross down, 3s dance up)
9-16::
    1s+2s dance the Knot
17-24::
    1s turn LH, face up NHJ, dance up, cast to 2nd place facing down
25-32::
    Mirror reels of 3 on sides (2s out/down, 1s in/down, 3s out/up)

{{explanation}}
Note:	2nd time through Bars 25-32: 1s+4s dance 7 bar reel then bar 32 1s lead to 4th place as 4s dance up to 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (4820, '2013-08-21 08:30:55.448782+00', '2023-02-04 01:19:21.716399+00', 1404, 3, NULL, 'ace', '1-8::
    1s cross RH _while_ 2s+3s dance RH across 1/2 way, & all set. 1s+3s
    dance 1/2 RH across _while_ 2s cross RH & all set
9-16::
    Reels of 3 on sides with 1s crossing up to dance 1/2 reel on
    opposite side & crossing down to dance 1/2 reel on own side
17-24::
    1s 3/4 turn LH, dance out ends & cast Left back to 2nd place, 1s
    change pl diag with person to right, centre cpl change pl diag with
    persons to Left
25-32::
    All chase clockwise to own sides (2 bars), cross RH (with partner),
    set & cross back.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (4825, '2013-08-21 08:30:55.657022+00', '2023-02-04 01:19:22.027874+00', 1409, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides (1s
    end at top on opposite sides facing down & 3s facing up)
9-16::
    1s+3s dance Ladies'' Chain
17-24::
    1s+2s+3s Promenade, finishing with 1s casting to 2nd place own side,
    2s dance up to 1st place
25-32::
    1s dance reels of 3 across giving LSh to 1st corners', 0);
INSERT INTO 'dancecrib' VALUES (9356, '2016-10-06 07:18:17.208845+00', '2023-02-04 01:19:30.014725+00', 17142, 3, NULL, 'ace', '1-8::
    1s turn RH (4 bars) moving down to face 3rd corners (2s step up
    1-2); 1s+3rd corners (2M+1s+3L) dance 1/2 reel of 4. 1s pass LSh to
    face 4th corners
9-12::
    1s+4th corners (2L+1s+3M) dance 1/2 reel of 4.
13-16::
    1s dance RSh round 4th corner (pstn) & join RH, 1s joining LH
    with3rd corner pstn (1L+2M, 1M+3L) in Bal-in-Line position
17-24::
    1s+2s+3s dance ''The Spoke''. Bars 23-24 1s retain RH, turn to 2nd
    place opp sides (skip change) _while_ 3s+2s set.  (3) (1) (2)
25-32::
    3s+1s+2s dance clockwise 1/2 round then turn partners RH once round', 0);
INSERT INTO 'dancecrib' VALUES (4834, '2013-08-21 08:30:55.729412+00', '2023-02-04 01:19:22.322893+00', 1414, 3, NULL, 'ace', '1-8::
    1s cast down own sides, turning outwards cast back to places
9-16::
    1s+2s set, cross RH, set & cross back RH
17-24::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 2s (who have
    stepped up)
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4928, '2013-08-21 08:30:57.255861+00', '2023-02-04 01:19:29.525496+00', 8858, 3, NULL, 'ace', '1-8::
    2s followed by 1s dance down between 3s, cast up on own sides (2s to
    top), 1s followed by 3s dance up between 2s & cast (1s to 3rd place)
9-16::
    2s+3s+1s reel of 3 on sides & all cross when passing down thru 2nd
    pl (2s & 1s cast to start & 3s cross to opposite sides) & all end on
    opp sides
17-24::
    All Set+Link for 3 twice.  1 3 2
25-32::
    1s+3s dance the Knot to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (14903, '2022-06-27 00:19:23.744869+00', '2023-02-04 01:19:30.678048+00', 19711, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up); 1s cross RH & cast to right (1M down,
    1L up) to end 1L between 2s facing down, 1M between 3s facing up
9-16::
    All set in lines of 3 across & change places RH up/down with person
    opposite; 1s cast to right (1M down, 1L up) to 2nd place opp sides
    _while_ 2s+3s set to partners & change places LH (2) (1) (3)
17-24::
    All set on sides & cross RH with partner; 1s cast to right (1M up,
    1L down) to end 1M between 2s facing down, 1L between 3s facing up
    _while_ 2s+3s set & change places LH up/down with person opposite
25-32::
    Reels of 3 on sides (1s RSh to 1st corner to start), Bars 30-32 1s
    dance across to 2nd place own side _while_ 2s+3s finish reel.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4938, '2013-08-21 08:30:57.463211+00', '2023-02-04 01:19:30.775471+00', 1562, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance  3 facing 3

1-8::
    All circle 6H round & back
9-16::
    Centre dancer sets & turns 2H person on right, sets & turns 2H
    person on left (popular variation - turn person on right RH, turn
    person on left LH)
17-24::
    All dance reels of 3 with centre dancer passing LSh with person on
    right (popular variation - RSh to person on right)
25-32::
    All Adv+Ret, advance to meet next group of 3 dancers (1 group of 3
    passing under arches made by opposite group)', 0);
INSERT INTO 'dancecrib' VALUES (4854, '2013-08-21 08:30:55.914622+00', '2023-02-04 01:19:23.259629+00', 1449, 3, NULL, 'ace', '1-4::
    1s dance in, take prom hold & dance down to end between 4s _while_
    2s dance up, take prom hold & dance down to end between 3s (3s step
    up 3-4)
5-8::
    1s dance 1/2 reel of 3 with 4s (RSh to 4L) _while_ 2s dance 1/2 reel
    with 3s (RSh to 3M), 1s & 2s pass RSh to…
9-12::
    1s dance 1/2 reel of 3 with 3s (RSh to 3L) _while_ 2s dance 1/2 reel
    with 4s (LSh to 4M), 1s & 2s end facing down (nearer hands joined
    with partner)
13-16::
    2s followed by 1s dance down & 1s cast up round 3s to 1st place own
    side _while_ 2s cast up round 4s to 2nd place own side (3s step down
    15-16)
17-24::
    1s+2s+3s+4s set to partners, 1s+2s also 3s+4s dance 1/2 R&L, all
    set. (2) (1) (4) (3)
25-28::
    3s dance up between 4s & cast up behind 1s & 2s to 1st place opp
    side (2s+1s+4s step down 27-28)
29-32::
    3s+2s also 1s+4s dance RH across 1/2 way & all set.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4937, '2013-08-21 08:30:57.453181+00', '2023-02-04 01:19:30.653015+00', 1559, 3, NULL, 'ace', '1-8::
    1s+2s dance Tourbillon :
::
    1s & 2s turn partners 2H 1/2 way, 1M & 2L lead partners on 1 place
    clockwise to end 1s on Ladies'' side & 2s on Men''s side, 1s set to 2s
::
    1s & 2s 1/2 turn partners 2H, 1L & 2M lead partners on 1 place to
    end 2s in 1st pl & 1s in 2nd pl & 2s+1s cross RH to own sides
9-16::
    3s followed by 1s+2s lead down, with 2s leading, all dance up in
    prom hold (2s to top place)
17-24::
    2s go to left, 1s to right & 3s to left to dance reels of 3 across
    in prom hold (3s LSh to 2s to start) & end 2s separate to 1st places
    own sides, 1s dance down to end on Men''s side (Lady on Man''s right)
    & 3s dance down to end on Ladies'' side (Lady on Man''s right)
25-32::
    1M+3L also 1L+3M (opp persons) 1/2 turn 2H & chase clockwise 1 place
    to 2 3 1. All set 2s+3s circle 4H round to left _while_ 1s turn 2H
    1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (4865, '2013-08-21 08:30:56.146675+00', '2023-02-04 01:19:24.074193+00', 1466, 3, NULL, 'ace', '1-8::
    1s Figs of 8 on own sides dancing between 2s, round 3s, out & round
    2s to original places
9-16::
    1s dance Figs of 8 round 2s
17-24::
    1s lead down below 3s, cross & cast up (1L up to 2nd place & 1M up
    to top), cross to face 2s (M facing M)
25-32::
    1s+2s dance reel of 4 across', 0);
INSERT INTO 'dancecrib' VALUES (4941, '2013-08-21 08:30:57.572065+00', '2023-02-04 01:19:30.95506+00', 1568, 3, NULL, 'ace', '1-8::
    1s+2s RH across, LH back
9-16::
    1s set, cast to bottom & lead up to 1st corners (2s step up)
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH to end
    in 2nd place on own side
25-32::
    2s+1s+3s+4s Adv+Ret & 1s cast to 4th place (2s+3s+4s step up)', 0);
INSERT INTO 'dancecrib' VALUES (4955, '2013-08-21 08:30:57.884578+00', '2023-02-04 01:19:32.01999+00', 1586, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 R&L, set & dance 1/2 R&L back to places
9-16::
    1s lead down for 2 steps, set to each other, lead up to top & cast 1
    place & face 1st corners
17-24::
    1s set to 1st corner, set to 2nd corner, set to partner & turn 2H to
    end 2nd place opposite sides
25-32::
    2s+1s+3s Adv+Ret 1 step twice, 1s turn 2H 1.1/2 times to places', 0);
INSERT INTO 'dancecrib' VALUES (7987, '2013-08-21 08:31:54.127447+00', '2023-02-04 01:23:15.044923+00', 7219, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s+2s+3s Promenade
17-24::
    1s+2s dance Poussette (1s end in lines across 1L between 2s facing
    1M between 3s)
25-32::
    2s+1s+3s set twice (1s turning onto sides) & set to partners twice', 0);
INSERT INTO 'dancecrib' VALUES (12171, '2019-09-04 21:57:06.246578+00', '2023-02-04 01:19:31.118711+00', 19575, 3, NULL, 'ace', '1-8::
    1s lead down below 4s.  Bar 5: 4s followed by 3s & 2s dance down
    sides, meet partner below 1s & then 1s followed by 4s+3s+2s lead up.
    All end in prom hold facing up
9-16::
    1s+4s also 3s+2s dance »Allemande Knot«
::
    _9-12_    1s+4s also 3s+2s dance 4 bars of Allemande so all facing
    down on Men''s side
::
    _13-16_  1s+4s also 3s+2s dance last 4 bars of Knot, dancing up
    Ladies'' side & turning LH to end all on opp sides
17-24::
    4s+1s+2s (top 3 couples) Set+Link twice
25-28::
    1s+4s (middle couples) dance 1/2 R&L
29-32::
    4s+1s+3s (bottom 3 couples) Adv (1 bar), Ret (1 bar) & cross RH to
    own sides ending 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4946, '2013-08-21 08:30:57.688514+00', '2023-02-04 01:19:31.323629+00', 1577, 3, NULL, 'ace', '1-8::
    3s+4s dance 1/2 R&L, 1M+3M advance, set, pass LSh to face down/up
    _while_ partners cast to face them
9-16::
    3s+1s dance reel of 4 in middle
17-24::
    3s+2s dance Allemande _while_ 1s+4s dance Allemande down & end with
    1s dancing under arch made by 4s & cross to own side (4s on opp
    side)
25-32::
    2s+3s+4s dance reel of 3 on sides (4s cross up & 3s out & down to
    start)', 0);
INSERT INTO 'dancecrib' VALUES (4885, '2013-08-21 08:30:56.431676+00', '2023-02-04 01:19:25.480503+00', 1495, 3, NULL, 'ace', '1-8::
    1s+2s+3s petronella turn & set, 3/4 turn RH & set
9-16::
    1s cross down (each couple cross down as they reach top place) to
    dance reflection reels of 3 on sides
17-24::
    1s dance Figs of 8 on own sides (1s down & in to start)
25-32::
    All dance Progressive Grand Chain:
::
    _25-26_    1s (at top) turn once round RH as 2s+3s change places RH
    on sides,
::
    _27-28_    2s (at bottom) turn once round LH as 1s+3s change places
    LH on sides,
::
    _29-30_    3s (at top) turn once round RH as 1s+2s change places RH
    on sides,
::
    _31-32_    1s (at bottom) turn once round LH as 2s+3s change places
    LH on sides to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4886, '2013-08-21 08:30:56.439518+00', '2023-02-04 01:19:25.676322+00', 1496, 3, NULL, 'ace', '1-8::
    1s clap & cross passing RSh, cast 1 place & cross RH to own sides
    (2s step up 2-3), 2s repeat back to places (1s step up 6-7)
9-16::
    1s dance Figs of 8 on opposite sides round 2s+3s & 1s cross down RH
    to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (4973, '2013-08-21 08:30:58.376887+00', '2023-02-04 01:19:33.112111+00', 12875, 3, NULL, 'ace', '{{explanation}}
5s in centre facing each other, Lady with back to 2s, Man with back to 4s

1-8::
    1s+2s+3s+4s circle 8H round & back _while_ 5s turn RH & LH
9-16::
    5M dances reel of 3 with 1s+2s (in prom hold) giving LSh to 2s
    _while_ 5L dances with 3s+4s giving LSh to 3s
17-24::
    5M dances R&LH across with 1s+2s _while_ 5L dances R&LH across with
    3s+4s
25-32::
    5s 1/2 turn RH to face 3s, set, 2s+3s change places RH & 3s set in
    centre _while_ 1s+2s+5s+4s dance on 1 place clockwise', 0);
INSERT INTO 'dancecrib' VALUES (8564, '2015-02-13 12:47:38.444692+00', '2023-02-04 01:19:33.367238+00', 9371, 3, NULL, 'ace', '1-8::
    1s cast behind own lines, turn away, dance back to places
9-16::
    1s dance Fig. 8 round 2s who stand (2), cross RH (2), stand (2),
    cross RH (2) to places
17-24::
    1s lead down (2), 1/2 turn RH (2), lead up (2), 1/2 turn RH (2)
    _while_ 2s set, cross RH, set, cross RH, 1s+2s finish in middle both
    hands joined
25-32::
    1s+2s Poussette', 0);
INSERT INTO 'dancecrib' VALUES (4986, '2013-08-21 08:30:58.511974+00', '2023-02-04 01:19:34.169776+00', 13443, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance down between 3s & cast up to
    2nd opposite sides.
9-16::
    1s turn RH to face 1st corners & turn corners LH, turn 2nd corners
    RH & partner LH to end facing 1st corners
17-24::
    1s dance 1/2 reel of 4 with 1st corners & pass LSh to face 2nd
    corners, 1s dance 1/2 reel of 4 with 2nd corners & end 2nd place
    opposite sides.  3 1 2
25-32::
    3s+1s+2s Set+Link for 3 twice.  2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (8776, '2015-06-15 11:40:37.498264+00', '2023-02-04 01:19:34.208136+00', 16215, 3, NULL, 'ace', '1-8::
    1s & 4s dance in & cast down/up 1 place (2s+3s step up/down). 1s+4s
    dance 1/2 Poussette
9-16::
    All set, 2L+4M & 1L+3M change places RH.  All set, 2M+4L & 1M+3L
    change places RH
17-24::
    All set, all circle 8H 1/2 round to Left.  All set advancing ready
    for ...
25-32::
    1s+3s & 2s+4s dance 1/2 Poussette;  3s+1s & 4s+2s  dance RH across.
    End 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (4990, '2013-08-21 08:30:58.546422+00', '2023-02-04 01:19:34.353157+00', 13852, 3, NULL, 'ace', '1-8::
    All dance Grand Chain
9-16::
    All set & cross RH, all set & 1/2 turn RH to face up in middle
17-24::
    All dance Allemande.  3 2 1
25-32::
    3s set & cast 1 place, all Adv+Ret
33-40::
    All circle 6H round & back.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (4988, '2013-08-21 08:30:58.530353+00', '2023-02-04 01:19:34.31385+00', 14396, 3, NULL, 'ace', '1-8::
    1s & 3s dance Inveran reels with 2s (1s cross down with 3s dancing
    in & crossing up)
9-16::
    1s lead down to 4th place as 2s+3s+4s set & dance up 1 place, 2s+3s
    also 4s+1s circle left
17-24::
    2s & 4s dance Inveran reels with 3s (2s cross down with 4s dancing
    in & crossing up)
25-32::
    2s+3s also 4s+1s dance double Fig of 8  (2s cross down & 1s cross up
    to start)
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4989, '2013-08-21 08:30:58.538364+00', '2023-02-04 01:19:34.33032+00', 13436, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place & cross down between 3s RH, 1s cast up to 2nd
    place on opposite sides.
9-16::
    1s dance 1/2 LSh reels of 3 across, 1M with 2s, 1L with 3s (LSh to
    3rd corner). 1s swap ends & dance 1/2 LSh reels of 3 (LSh to 1st
    corner)  (2) (1) (3)
17-24::
    1s dance diag R&L.
25-32::
    3s+1s+2s Adv+Ret, circle 6H round to left 1/2 way.  2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (4992, '2013-08-21 08:30:58.562835+00', '2023-02-04 01:19:34.634452+00', 1647, 3, NULL, 'ace', '1-8::
    1s & 4s turn 1.1/2 times RH & cast 1 place, 1M & 4M also 1L & 4L
    turn LH on sides to end 1s facing up & 4s down.  2(1)(4)3
9-16::
    All dance reels of 4 on sides (Bar 16 1s & 4s do not pass LSh but
    turn right about into centre BtoB facing corner just passed).
    2(4)(1)3
17-24::
    4s & 1s set to corners & change places RH, set & change back LH
25-32::
    4s+1s dance RH across _while_ 2s & 3s set & cross RH, all set &
    cross RH back to places  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8996, '2015-11-30 08:59:40.302375+00', '2023-02-04 01:19:34.912389+00', 10880, 3, NULL, 'ace', '{{explanation}}
Any number of couples in circle, Lady on Man''s right

1-8::
    All turn partner RH then turn LH
9-16::
    Men pass prtnr RSh, dance round them & back to place.  Men repeat
    passing prtnr LSh
17-24::
    Ladies repeat bars 9-16.  All finish NHJ facing anticlockwise round
25-32::
    All promenade (6 bars) then Men stand as Ladies dance on 1 place to
    meet new partner', 0);
INSERT INTO 'dancecrib' VALUES (5000, '2013-08-21 08:30:58.629249+00', '2023-02-04 01:19:34.93464+00', 1654, 3, NULL, 'ace', '1-2::
    All set to partners
3-6::
    1s+2s dance up & cast down to change places _while_ 3s+4s dance down
    & cast up to change places
7-8::
    1s & 4s cross RH to end in middle of set facing corners (1M & 4L
    turn right about)
9-16::
    1s+4s turn corners 2H (2 bars) & 1s+4s dance 4H round (4 bars), 1s
    turn 2H 1/2 way to end in promenade hold facing 2L (1L on 1M''s
    right) _while_ 4s turn 2H once round (4L on 4M''s left) to end in
    promenade hold facing 3M
17-20::
    1s+2s also 4s+3s dance 1/2  RSh reels of 3 across
21-24::
    1s+4s retain promenade hold & pass each other RSh, 1s dance down &
    cross LH below 3s & cast into 3rd place own sides _while_ 4s dance
    up, divide & cast into 2nd place own sides _while_ 2s+3s continue
    reel across, back to own sides. 2 4 1 3
25-32::
    1s & 4s dance Poussette 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13068, '2020-08-10 00:19:18.234768+00', '2023-02-04 01:19:35.05736+00', 19514, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set & Rotate
9-16::
    RSh reels of 4 on sides.  2 1 4 3
17-24::
    1s+4s+3s (bottom 3 couples) chase clockwise 1/2 round; cross RH with
    partner & set
25-32::
    2s+3s+4s+1s circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (4926, '2013-08-21 08:30:57.235782+00', '2023-02-04 01:19:29.467867+00', 1543, 3, NULL, 'ace', '1-8::
    1s & 2s turn RH once round & dance RH across once round
9-16::
    1s+2s+3s dance RSh reels of 3 on own sides, 1s & 2s continue reels &
    loop round at top to 2M facing 1M & 2L facing 1L (1M+2L BtoB in
    middle)
17-24::
    1s+2s dance 3/4 reel of 4 across (2M & 1L pass LSh end bar 22) then
    pass partners RSh to progressed places own sides (2 1 3)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13070, '2020-08-10 00:19:18.462122+00', '2023-02-04 01:19:35.338628+00', 17768, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s turn 1.1/4 LH flowing into …
9-16::
    1M+2s also 1L+3s dance 1/2 RH across (2 bars), 1s chase clockwise
    1/2 round 2s+3s who dance LH across, 1L+2s also 1M +3s dance 1/2 RH
    across. 1s end facing 1st corners
17-24::
    2s+1s+3s dance Diagonal Weasel Reel:
::
    1M+3L also 1L+2M pass RSh to start _while_ 2L & 3M chase clockwise
    to join reel at ends.  End 1s facing 1st corners. 2 1 3
25-32::
    1s dance RSh round 1st corners; 1s turn RH to end 2nd place own
    side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5005, '2013-08-21 08:30:58.673334+00', '2023-02-04 01:19:35.369794+00', 13965, 3, NULL, 'ace', '1-8::
    1s set & 1/2 turn RH moving down to 2nd place; 1s set & turn LH to
    face 1st corners
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass LSh to face
    2nd corners; 1s dance 1/2 diagonal reel of 4 with 2nd corners & pass
    LSh to face 3rd corner (pstn)
17-24::
    1s set to & turn corners (3rd & 4th corner pstns), finishing 1M
    facing down, 1L facing up. (3) 1 (2)
25-32::
    1L+3s (at top) & 1M+2s (at bottom) circle 3H round to left (3 bars)
    opening out (1s leading) to all circle 6H round to left 1/2 way (3
    bars), 1s cross RH to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (4934, '2013-08-21 08:30:57.35131+00', '2023-02-04 01:19:30.577194+00', 1555, 3, NULL, 'ace', '1-8::
    1s cross passing RSh, 1M casts 2 places _while_ 1L turns 2M LH &
    casts to below 3M, 1s 1/2 turn RH & face 3L in prom hold
9-16::
    1s dance 1/2 diagonal reel of 3 with 3L+2M & 1/2 reel of 3 across
    with 2M+3M
17-24::
    1s dance 1/2 reel on sides of 3 with 3L+2M & 1/2 reel of 3 across
    with 2M+2L end facing in centre Lady facing down)
25-32::
    1s set _while_ 2s & 3s cross RH & set, 1s turn 2H 1.1/4 times to 2nd
    place own side', 0);
INSERT INTO 'dancecrib' VALUES (13403, '2020-12-02 01:19:19.276906+00', '2023-02-04 01:19:30.629807+00', 20144, 3, NULL, 'ace', '1-8::
    1s lead down & back to 1st place
9-16::
    1s+2s promenade
17-24::
    1s+2s dance R&L
25-32::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s', 0);
INSERT INTO 'dancecrib' VALUES (13233, '2020-10-16 00:19:31.614401+00', '2023-02-04 01:19:36.498329+00', 20088, 3, NULL, 'ace', '1-4::
    1s set, cast off one place. (2s step up 3-4)
5-8::
    1s pass LSh, dance RSh round 1st corner to end in lines of three
    across, 1M between 3s facing up, 1L between 2s facing down
9-12::
    All set, pass person opposite RSh & 1/4 turn to right to form 2
    lines of 3 across (in 2nd place) 1L+2s facing Men''s side, 1M+3s
    facing Ladies'' side
13-16::
    2M+1L+2L also 3L+1M+3M chase to right up/down sides & across into
    lines of 3 across in 1st/3rd place
17-20::
    _1/2_ diag R&L (1M+2M & 1L+3L cross diagonally to right)
21-24::
    _1/2_ diag R&L (1M+3M & 1L+2L cross diagonally to left)
25-28::
    1s cross RH up/down, cast right round 2nd corner to 2nd place opp
    sides _while_ 2s+3s set & cross RH up/down
29-32::
    1s turn 1.1/2 RH to 2nd place own side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5025, '2013-08-21 08:30:59.098202+00', '2023-02-04 01:19:36.997851+00', 9850, 3, NULL, 'ace', '1-8::
    1M+3M dance 1/2 diagonal reel of 4 with 2L+4L, top 2 couples also
    bottom 2 couples dance RH across
9-16::
    Partners repeat to end 4 3 2 1 on opposite sides
17-24::
    All chase clockwise 1/2 way & turn partners RH
25-32::
    1s cross RH, cast 1 place, dance down between 3s & cast to bottom', 0);
INSERT INTO 'dancecrib' VALUES (8315, '2014-07-29 12:58:54.936292+00', '2023-02-04 01:19:31.595505+00', 15408, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    2s+3s dance RH across & LH back to end in St Andrews cross giving RH
    to corners
9-16::
    All Bal-in-Line & 2s+3s 1/2 turn corners RH, Bal-in-Line & 1s+4s
    dance RH across 1/2 way
17-24::
    4s & 1s dance RH across with 2M/3M, 4s & 1s (Ladies following Men)
    dance LH across with 2L/3L
25-28::
    4s dance down under arch made by 1s who dance up & 1s dance down
    under arch made by 4s who dance up
29-32::
    4s dance up between 2s & cast down to 2nd place _while_ 1s dance
    down between 3s & cast up to 3rd place.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (4951, '2013-08-21 08:30:57.755842+00', '2023-02-04 01:19:31.624186+00', 14692, 3, NULL, 'ace', '1-8::
    1s set twice, 1s+2s set facing & change places RH
9-16::
    2s+1s chase clockwise
17-24::
    2s+1s Adv+Ret, turn partners RH to face down
25-32::
    1s followed by 2s lead down, 2s lead up followed by 1s.  2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (10829, '2018-06-11 00:36:10.688714+00', '2023-02-04 01:19:31.687882+00', 17149, 3, NULL, 'ace', '1-8::
    1s+2s set, turn partners 2H opening into circle 4H 1/2 round to opp
    sides & cross RH to own side (213)
9-16::
    1s+3s set, turn partners 2H opening into circle 4H 1/2 round to opp
    sides & 1/2 turn partner RH ready for …
17-24::
    1s+3s dance 1/2 Poussette; 1s+2s Set+Link (2s finish facing down)
25-32::
    All dance 1/2 Grand Chain (1s cross, 2s+3s change place RH on
    sides); all set, 1s cross RH _while_ 2s+3s dance 1/2 RH across (End
    2 3 1)', 0);
INSERT INTO 'dancecrib' VALUES (5033, '2013-08-21 08:30:59.178379+00', '2023-02-04 01:19:37.298635+00', 1712, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & change places curving round to left, repeat back to
    places (3s facing out)
9-16::
    1s & 3s dance double Fig of 8 round 2s (1s crossing down to begin)
17-24::
    1s+2s dance Poussette.  2 1 3
25-32::
    2s+1s+3s dance reels of 3 on sides (1s in & down to start)', 0);
INSERT INTO 'dancecrib' VALUES (5036, '2013-08-21 08:30:59.203261+00', '2023-02-04 01:19:37.393283+00', 1720, 3, NULL, 'ace', '1-4::
    1s cross down to centre _while_ 4s cast up outside to be level with
    1s, all set 1M in a LH cross with 2L+3L+4L & 1L in a RH cross with
    Men
5-8::
    All dance LH/RH across
9-16::
    1s followed by 2s+4s+3s dance down & back (3s leading) into 4H
    across pstns (other Hand)
17-24::
    1s followed by 3s+4s+2s dance up & back (2s leading) into 4H across
    pstns (original Hand)
25-32::
    1s dance down to bottom, cast up on opposite sides to top & dance
    down crossing to 4th place own sides _while_ 4s dance up outside to
    top, dance down the middle to 4th place & step up on bars 31-32
    (with 2s+3s)', 0);
INSERT INTO 'dancecrib' VALUES (14204, '2021-08-14 00:19:25.11747+00', '2023-02-04 01:19:37.422111+00', 12194, 3, NULL, 'ace', '1-8::
    1s dance down & out (1M between 2s, 1L between 3s) to dance Fig 8
    round 2s/3s & back to place (Bar 4: touch hands briefly on meeting).
    All face in & take prom hold
9-16::
    Reel of 3 across, 1s pass 3s RSh to start.  All end in original
    places facing partners
17-20::
    All set & turn RH finishing Men facing in. Ladies facing out
21-32::
    Schiehallion reels, dancers touch RH briefly in centre. Couples
    finish in original places
33-40::
    All circle 6H round & back
41-48::
    1s+2s dance 1/2 R&L; 1s+3s dance 1/2 R&L.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5038, '2013-08-21 08:30:59.221307+00', '2023-02-04 01:19:37.482878+00', 1722, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, turn RH into prom hold facing out between
    2s & 3s on Ladies'' side
9-16::
    1s cast round 3L, dance up, out between 2s & 3s on Men''s side & cast
    up round 2M to end in centre (2nd place) facing down as 2s+3s change
    places on sides (Ladies LH & Men RH)
17-24::
    3s+1s+2s dance reel of 3 on sides with 1s dancing out & down to
    start, 1s end in 2nd place own sides
25-32::
    1M casts up 1 place as 1L casts down 1 place, 1s dance 1/2 reels of
    3 across (Man with 3s & Lady with 2s) & 1s turn LH to face 1st crnr
    (pstn)
33-40::
    1s dance 1/2 reels of 4 with 1st corners, pass LSh & dance 1/2 reel
    of 4 with 2nd corners 1s ending in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (4969, '2013-08-21 08:30:58.344424+00', '2023-02-04 01:19:32.676773+00', 9336, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 2s+1s turn RH
9-16::
    2s+1s dance Ladies Chain
17-24::
    1M+2M dance anticlockwise 1/2 way round _while_ 1L+2L turn LH 1.1/2
    times, Men dance in front of partner to dance LH across with Ladies
25-32::
    1s+2s chase anticlockwise 1/2 way round, 2s+1s set twice & 1s cross
    RH to own side', 0);
INSERT INTO 'dancecrib' VALUES (12157, '2019-09-03 21:28:04.866311+00', '2023-02-04 01:19:32.697989+00', 19619, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across (3 bars) & LH across (3 bars); 1s cast, pass
    LSh to face 1st corners _while_ 2s dance up NHJ to 1st place
9-16::
    1s set to 1st corners, pull back RSh & dance round each other to
    face 2nd corners; 1s set to 2nd corners, pull back RSh & dance round
    each other to end in 2nd place own side
17-20::
    2s+1s+3s Adv+Ret (1 bar each), 2s (at top) cross RH _while_ 1s+3s
    dance 1/2 RH across.  (2) (3) (1)
21-24::
    2s+3s+1s Adv+Ret (1 bar each) & all cross RH to own side
25-32::
    2s+3s+1s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (4979, '2013-08-21 08:30:58.425436+00', '2023-02-04 01:19:33.448095+00', 8811, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across 1/2 way, set & dance LH across 1/2 way
    back to places
9-16::
    1L+2M change places RH as partners cast 1 place & turn other partner
    LH (as in Ladies), 1L+2M turn RH 1.3/4 times to end 2s in 1st place,
    1s in centre with 3s stepping in behind
17-24::
    1s+3s dance Poussette.  2 1 3
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9190, '2016-06-16 22:41:43.005566+00', '2023-02-04 01:19:38.31392+00', 16286, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up).  1s cross RH, cast (3s step up)
9-16::
    1s+3s dance RH across & LH across
17-24::
    2s+3s+1s dance mirror reels of 3 on sides (1s in/up to start) taking
    nearer hands with partners on meeting.  3s+1s end in centre ready
    for ...
25-32::
    3s+1s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (13074, '2020-08-10 00:19:20.828574+00', '2023-02-04 01:19:38.427397+00', 16731, 3, NULL, 'ace', '1-8::
    1s set, set advancing & join RH; 1s lead down middle
9-16::
    1s change places, Lady dancing under Man''s arm (2 bars), 1s lead up
    (4 bars) & cast to 2nd place opp sides (2s step up)
17-24::
    1M+2s also 1L+3s dance RH across, 1s pass RSh & dance LH across with
    other couple, 1s end 2nd place opp sides
25-32::
    2s+1s+3s Adv+Ret; 1s turn 1.1/2 RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5052, '2013-08-21 08:30:59.407501+00', '2023-02-04 01:19:38.820219+00', 1762, 3, NULL, 'ace', '1-8::
    1s set twice to 2L & circle 3H round to left
9-16::
    1M+1L+2L in diagonal line across set twice to 2M & circle 4H round
    to left
17-24::
    1s+2s dance RH across for 3 steps & LH back, 1s cast on own sides &
    cross to face 1st corners
25-32::
    1s set & turn 1st corners 2H, set & turn 2nd corners 2H
33-40::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners
41-48::
    1s set twice & turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (4996, '2013-08-21 08:30:58.597584+00', '2023-02-04 01:19:34.796179+00', 10307, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 2s
9-16::
    1s cross RH, cast to right, dance up/down (pass LSh) & cast left to
    2nd place own sides _while_ 2s & 3s set, cross RH, set & cross back
17-24::
    1s dance 1/2 reels of 3 on own sides (RSh to person on right) & 1/2
    reels of 3 across (LSh to 1st corner)
25-32::
    1s dance RH across (Man with 3s (top place) & Lady with 2s) & all
    chase clockwise to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5002, '2013-08-21 08:30:58.647261+00', '2023-02-04 01:19:34.995037+00', 8741, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place, dance down between 3s & cast up to 2nd
    places own sides
9-16::
    2s+1s+3s dance RSh round partners back to places & chase clockwise
    1/2 way
17-24::
    3s+1s+2s circle 6H round & back
25-32::
    3s+1s+2s dance LSh round partners back to opposite sides & chase
    anticlockwise 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (5061, '2013-08-21 08:30:59.499391+00', '2023-02-04 01:19:39.371538+00', 1774, 3, NULL, 'ace', '1-8::
    1L+2L+3L Adv+Ret, 1M+2M+3M Adv+Ret
9-16::
    1s cast down to 3rd place own sides followed by 2s & 3s, lead up
    middle back up to places & 1s cast 1 place to face 1st corners
17-24::
    1s turn 1st corners RH, turn partner LH, turn 2nd corners RH & turn
    partner LH back to 2nd place opposite sides
25-32::
    1s set twice & cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5062, '2013-08-21 08:30:59.509642+00', '2023-02-04 01:19:39.487513+00', 1775, 3, NULL, 'ace', '1-8::
    1s turn RH & turn LH
9-16::
    1s cast 1 place & turn RH to end BtoB in centre between 2s, 1M
    facing 2L & 1L facing 2M
17-24::
    1s+2s set HS & turn RH to end on sides with 1s in 2nd place on
    opposite sides
25-32::
    2s set HS & turn RH twice _while_ 1s set HS & turn 1.1/2 times to
    places', 0);
INSERT INTO 'dancecrib' VALUES (5064, '2013-08-21 08:30:59.527623+00', '2023-02-04 01:19:39.536556+00', 1777, 3, NULL, 'ace', '1-8::
    Reels of 3 on sides
::
    Start:  1s dance in & cast, 2s cross up LH & 3s dance in, join NH
    facing down and cast up. All take hands where possible.
::
    End:  2s in 2nd places opp side, 1s & 3s end in middle, 1s NHJ
    facing down & 3s NHJ facing up
9-16::
    All set, circle left for 2 bars, Men turn Lady on right 2H once
    round & continue circle to places
17-24::
    1s+2s dance RH across & end facing up, 1s cast 1 place & lead up
    _while_ 2s lead up crossing & cast 1 place
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (5068, '2013-08-21 08:30:59.81819+00', '2023-02-04 01:19:40.030894+00', 1782, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret & turn partners 2H
9-16::
    1s cast, lead down between 3s, cast up behind 3s, lead up between 2s
    & cast back to 2nd place
17-24::
    1s dance RH across (Lady with 2s & Man with 3s), pass RSh & dance LH
    across with other couple to end facing 1st corners
25-32::
    1s turn 1st corner, partner, 2nd corner & partner to own sides 2nd
    place
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5069, '2013-08-21 08:30:59.828015+00', '2023-02-04 01:19:40.13376+00', 1783, 3, NULL, 'ace', '1-8::
    1s+2s set twice & turn RH
9-16::
    1s followed by 2s lead down & 2s followed by 1s lead back to top, 2s
    cast to original places
17-24::
    1s+2s dance RH across & LH back, 1s casting to 2nd places
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5071, '2013-08-21 08:30:59.845952+00', '2023-02-04 01:19:40.259413+00', 1786, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across, set & dance 1/2 LH across back to
    places
9-16::
    1M+2L set advancing & turn RH back to places, 1L+2M set advancing &
    turn RH back to places
17-24::
    1s cross RH, cast to 2nd place & dance 1/2 Fig of 8 round 2s to 2nd
    place on own sides
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5079, '2013-08-21 08:31:00.117061+00', '2023-02-10 14:14:49.228102+00', 1807, 3, NULL, 'ace', '1-8::

    1s set & turn RH, 1s cast to 2nd place & set advancing to 1st

    corners

9-16::

    1s set HS to 1st corners, 1s turn corners 2H & pass partner by RSh

    to face 2nd corner

17-24::

    1s set HS to 2nd corners, 1s turn corners 2H & pass partner by LSh

    to face 1st corners

25-32::

    1s dance LSh Reels of 3 on opposite sides & 1s cross RH to 2nd place

    own side', 0);
INSERT INTO 'dancecrib' VALUES (5078, '2013-08-21 08:31:00.108797+00', '2023-02-10 14:22:57.702454+00', 1801, 3, NULL, 'ace', '1-8::

    1s set, turn 2H, dance down NHJ 1 place, face each other & set

    advancing passing LSh  to end BtoB (Lady facing up & Man down)

9-16::

    1s circle 3H round to left (1L with 2s & 1M with 3s), 1s set to &

    turn each other 2H to face 1st corners

17-24::

    1s dance 1/2 reel of 4 with 1st crnrs, pass each other LSh, dance

    1/2 reel with 2nd crnrs & pass each LSh to face out on opp sides

25-28::

    1s cast round 1st corners (pstn) into lines across (1L+3s at top &

    1M+2s) _while_ 3s+2s Adv+Ret, all change places RH up/down

29-32::

    1s cast round 2nd corners (pstn) to 2nd place opp sides _while_

    3s+2s Adv+Ret diagonally.  2s+1s+3s cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5086, '2013-08-21 08:31:00.217772+00', '2023-02-04 01:19:42.289176+00', 1819, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Figs of 8 round 2s
9-16::
    1s dance diagonal reel of 4 with 1st corners passing partner LSh &
    giving RSh to 1st corner End passing round partner LSh to face 2nd
    crnrs
17-24::
    1s dance diagonal RSh reel of 4 with 2nd corners ending in 2nd place
    own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5096, '2013-08-21 08:31:00.416522+00', '2023-02-10 14:00:42.019503+00', 1842, 3, NULL, 'ace', '1-8::

    All 3/4 turn partners RH, 1M+2L also 3M+4L turn LH 1.1/2 times

    _while_ their partners chase clockwise to change places, 1L+4M turn

    RH retaining hold until side by side (Lady facing up & Man down)

    partners now join them for RH across to own sides _while_ 2s & 3s

    turn 3/4 RH to 2 4 1 3

9-16::

    1L followed by 4L dances down behind 3L & up centre as 4M followed

    by 1M dances up behind 2M & down centre, 4M & 1L pass LSh to dance a

    1/2 reel of 4

17-24::

    1M followed by partner dances down round 3M & crosses to 3rd place

    opposite sides _while_ 4L followed by partner dances up round 2L &

    across to 2nd place opposite sides, 2s+4s also 1s+3s dance RH across

25-32::

    4s & 1s cross RH _while_ 2s & 3s set, 2s+4s also 1s+3s dance 1/2

    double Fig of 8 (1s & 4s casting to start) & all cross RH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5119, '2013-08-21 08:31:00.731228+00', '2023-02-04 01:19:44.918082+00', 12811, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s turn LH
9-16::
    2s+1s dance Ladies Chain
17-24::
    2s+1s+3s set, circle 6H round to left 1/2 way & set
25-32::
    1s dance diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (5121, '2013-08-21 08:31:00.7581+00', '2023-02-04 01:19:45.038369+00', 1883, 3, NULL, 'ace', '1-8::
    All 4 couples set, cross (no hands), set & cross back
9-16::
    1s lead down the middle & back to top
17-24::
    1s Allemande (4 bars) to end facing 1st corners (2s step up), set to
    1st corners & set to 2nd corners
25-32::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corners &
    cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (9726, '2017-04-06 08:39:40.28042+00', '2023-02-04 01:19:38.756375+00', 1756, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on sides (1s in/down). 1s end
    facing 2nd corners (1L passes in front of 1M), 2s in 1st place
9-16::
    1s & 2nd corners set (1 bar) dance RSh diagonal reel of 4.  1s pass
    RSh to face 1st corners
17-24::
    1s & 1st corners repeat 9-16.  1s end in 2nd place opp sides
25-32::
    2s+1s+3s set, 1s cross down RH to dance reflection reels of 3 on own
    side, 2s cast, 3s dance out/up to start.  1s end 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5125, '2013-08-21 08:31:00.880181+00', '2023-02-09 13:02:02.197246+00', 1891, 3, NULL, 'ace', '1-8::

    1s & 3s cross RH, cast 1 place, cross LH, cast round 4th corner into

    Double Triangle pstns (BtoB facing own sides)

9-16::

    All dance Double Triangles & end in 2nd/4th place own side

17-24::

    1s & 3s lead down 1 place, cast up 1 place, turn RH & lead up to

    original places to end with 1s facing 2s & 3s facing 4s

25-32::

    1s & 3s set to 2s/4s & 1/2 turn facing dancer 2H, 1s & 3s set to

    4s/5s & 1/2 turn facing dancer 2H to end 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (5051, '2013-08-21 08:30:59.399281+00', '2023-02-04 01:19:38.804871+00', 1760, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 1s cast 1 place _while_ 2s cross up LH to top & 3s
    cross over RH, 1s dance 1/2 Fig of 8 round 2s
9-16::
    1s dance 1/2 Fig of 8 round 3s, 2s+1s+3s set & 2s+3s cross RH
    _while_ 1s turn RH to face 3rd corners
17-24::
    1s dance 1/2 RSh reels of 3 on own sides, 1s pass RSh to dance 1/2
    reels on opposite sides ending with 1s in 2nd place on own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5126, '2013-08-21 08:31:00.928865+00', '2023-02-04 01:19:45.26531+00', 8113, 3, NULL, 'ace', '1-8::
    1s & 3s set & cross down RH into double triangle positions (2s & 4s
    up), set & turn 1st corner RH
9-16::
    1s+3s dance RSh reel of 4 up/down middle ending with 1L & 1M facing
    2L & 4L _while_ 3L & 3M face 4M & 5M
17-24::
    1s & 3s dance RSh reels across (reel of 3 top & bottom, reel of 4 in
    centre)
25-28::
    1L followed by prtnr casts down behind 4L to 3rd place & cross to
    opp side _while_ 3M followed by prtnr casts down behind 5M & cross
    to opp side
29-32::
    1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5057, '2013-08-21 08:30:59.460935+00', '2023-02-04 01:19:39.000909+00', 11513, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s dance R&L
9-16::
    2s & 3s cast to ends & down/up middle to dance 1/2 RH across & end
    dancing out to sides with other partner to 1 (2) 3 (4) (2s & 4s on
    opp sides)
17-24::
    1s+2s also 3s+4s dance Ladies Chain
25-32::
    1s cross RH & cast to 2nd place _while_ 2s cross up to top, 1s cross
    RH & cast to 3rd place _while_ 3s step up
33-40::
    1s cross RH, cast to 4th place _while_ 4s step up & all turn RH for
    4 bars.  2 3 (4)(1)', 0);
INSERT INTO 'dancecrib' VALUES (11445, '2019-01-01 01:56:44.143387+00', '2023-02-04 01:19:49.348782+00', 18967, 3, NULL, 'ace', '1-8::
    1s dance RSh reels of 3 on own sides
9-16::
    1s+2s dance RH across, LH back
17-24::
    1s lead down the middle for 3 steps, back to top & cast to 2nd place
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9729, '2017-04-06 08:39:41.951817+00', '2023-02-04 01:19:48.280886+00', 17649, 3, NULL, 'ace', '1-8::
    1s & 3s dance in, 1M+3L & 1L+3M dance Fig 8 round 2s & 4s, and back
    to place
9-16::
    2s & 4s dance 4H round and back
17-24::
    All Set+Link with partner. All Set+Link with corner
25-32::
    All dance 1/2 Ladies'' Chain, ending back with partner.  All turn
    partner 2H twice round
33-64::
    Repeat 1-32 in Strathspey time from new positions
::
    Repeat twice in Jig time but on bars 29-32 All turn RH or birl', 4);
INSERT INTO 'dancecrib' VALUES (9730, '2017-04-06 08:39:42.049135+00', '2023-02-04 01:19:48.927168+00', 17583, 3, NULL, 'ace', '1-8::
    1s set &cast below 3s, 1s cross RH & cast up to 2nd place opposite
    sides
9-12::
    1s+2s dance RH across
13-20::
    1s dance reels of 3 on sides (1s give LSh to 3s to start)
21-24::
    1s+3s Dance LH across & 1s end BtoB (1M facing up, 1L down) for…
25-32::
    1s dance Crown Triangles & end facing out own side
33-40::
    1s cast to right round 3rd corner, 1s turn LH 1.1/4 times to end 2nd
    place own side & set.', 0);
INSERT INTO 'dancecrib' VALUES (13741, '2021-03-02 01:19:41.781858+00', '2023-02-04 01:19:49.706216+00', 20230, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 down round 2s
9-16::
    1s with 2H joined slip down middle & back into 2nd place (2s step up
    11-12)
17-24::
    1s+2s dance LH across; 1s+3s dance RH across
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5094, '2013-08-21 08:31:00.28437+00', '2023-02-04 01:19:42.905028+00', 1838, 3, NULL, 'ace', '1-8::
    2s & 4s dance 1/2 Petronella figure to opposite sides (petronella
    turn & set, twice)
9-16::
    1s+2s & 3s+4s dance Ladies'' Chain
17-24::
    1s & 3s dance 1/2 Petronella figure to opposite sides (petronella
    turn & set, twice)
25-32::
    1s "zig-zag" to 4th place, 1L starting changing places diagonally LH
    with 2M:
::
    1L+2M change places LH, 1M+2L also 1L+3L change places RH, 1M+3M
    also 1L+4M change places LH & 1M+4L change RH', 0);
INSERT INTO 'dancecrib' VALUES (5163, '2013-08-21 08:31:01.732903+00', '2023-02-04 01:19:49.510863+00', 1965, 3, NULL, 'ace', '1-8::
    All set & cross RH, set & cross RH back to places
9-16::
    1M+2L also 3L+4M turn RH 1.1/2 times, all set (HS) to partner on
    sides
17-24::
    All dance reels of 4 on sides
25-32::
    1L+2M also 3M+4L turn RH 1.1/2 times, 2s+1s also 4s+3s dance 1/2 R&L
33-40::
    All circle 8H round & back
41-48::
    1s+2s dance 1/2 RH across & 1s+3s dance 1/2 LH across, 1s+4s dance
    1/2 RH across & all cross LH back to places', 0);
INSERT INTO 'dancecrib' VALUES (13135, '2020-09-15 00:19:31.241768+00', '2023-02-04 01:19:49.684234+00', 12206, 3, NULL, 'ace', '1-8::
    1s+2s+3s 1/2 turn 2H, face partner, pull back RSh & curve out to
    opposite sides. 1s+2s+3s cross RH to own side,1s end facing out
9-16::
    1s (taking hands where possible) dance Fig of 8 round 2s & 3s, 1s
    cast one place to face 1st corners _while_ 2s NHJ dance up & cast
    into 1st place
17-24::
    1s set & turn 1st & 2nd corners 2H ending b''tw''n corners
25-28::
    2s+1s+3s Adv+Ret 1 step twice
29-32::
    1s 1.1/2 turn 2H to 2nd place _while_ 2s turn RH & 3s turn LH

{{explanation}}
On second repeat 1s turn & cast to 4th place, 4s turn into 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (13300, '2020-11-02 01:19:38.027566+00', '2023-02-04 01:19:50.111122+00', 20096, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 Set & Rotate (set, rotate singly & dance on 1 place
    clockwise), 1s+2s dance 1/2 Set & Rotate again (2) (1) 3
9-16::
    1s dance reels of 3 on opposite sides (1M down LSh to 1st corner, 1L
    up RSh to 1st corners)
17-24::
    2s+1s petronella in tandem (no hands) & set & repeat 1 2 3
25-28::
    1s+2s dance 1/2 Espagnole (no hands)
::
    _25-26_   1s+2s cross (Ladies lead across, no hands, passing between
    Men) with Ladies changing places no hands
::
    _27-28_   1s+2s cross back (Men lead across, no hands, between
    Ladies) with Men changing places no hands
29-32::
    2s dance LSh DoSiDo _while_ 1s dance RSh DoSiDo.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8779, '2015-06-15 11:40:40.61044+00', '2023-02-04 01:19:50.401505+00', 1989, 3, NULL, 'ace', '1-8::
    1s lead down [3 bars], lead back to top & cast to 2nd place
9-16::
    1s+3s turn prtnrs RH 1.1/2 times, 1s face up/3s face down,1s+3s set
    to end couple & turn them  3/4 (nearer hands) to finish on sides   2
    (1) (3) 4
17-24::
    1s+3s dance 1/2 R&L, 1s+3s turn partner RH, 1s ending in centre, 3s
    on sides & 4s coming in ready for …
25-32::
    1s+4s Poussette   2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13132, '2020-09-15 00:19:27.673086+00', '2023-02-04 01:19:45.975906+00', 14997, 3, NULL, 'ace', '1-8::
    1L+2s dance RSh reel of 3 across (1L RSh to 2M, 2L dances to right
    to start)
9-16::
    1M+2s dance LSH reel of 3 across (1M LSh to 2L, 2M dances to left to
    start)
17-24::
    1s lead down middle & back, remaining in centre, 2s step in ready
    for …
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (13081, '2020-08-10 00:19:30.392973+00', '2023-02-04 01:19:50.60132+00', 2000, 3, NULL, 'ace', '1-8::
    1s lead down to 3rd place, cross, cast up to top & cross LH _while_
    2s+3s dance R&L starting up/down on sides
9-16::
    1s lead down (5 bars) & back up to 2nd place in centre facing up (2s
    step up 11-12)
17-24::
    2s+1s+3s dance reels of 3 on sides (1s dance up to top & cast, 2s
    in/down, 3s out/up to start)
25-32::
    2s+1s dance R&L.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8568, '2015-02-13 12:47:41.808169+00', '2023-02-04 01:19:50.62891+00', 15640, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place (2s step up), 1s turn RH finishing in 2nd
    place opp. sides
9-16::
    2s+1s+3s set twice, 1s turn RH 1.1/4 to finish 1L between 2s facing
    down, 1M between 3s facing up
17-24::
    2s+1L & 3s+1M set twice, 1s turn RH 1.1/4 to finish     in 2nd place
    own sides 1M facing up, 1L facing down
25-32::
    All dance clockwise once round set  Order:  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5136, '2013-08-21 08:31:01.248017+00', '2023-02-09 12:58:19.18146+00', 1905, 3, NULL, 'ace', '1-8::

    1s+2s+3s set, petronella turn into centre, set & 3/4 turn partners

    RH (to opposite sides)

9-16::

    1s+2s+3s set, cross RH to own sides, 1M followed by 2M+3M cast &

    dance down to 3rd place & cross to form line of 3 across (facing up)

    _while_ 3L followed by 2L+1L cast up to top & cross to form a line

    facing down

17-24::

    1s+2s+3s set in lines across, change places RH with partner & dance

    6H round to left back to original places

25-32::

    1s & 2s dance in, join RH with partner, dance clockwise to end 1s in

    2nd place & 2s in top place & dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (5135, '2013-08-21 08:31:01.239908+00', '2023-02-04 01:19:46.697401+00', 1903, 3, NULL, 'ace', '1-8::
    1s petronella turn into centre, turn on opposite sides, turn into
    centre & turn back to places
9-16::
    1s cast 1 place, lead down below 3s, cast up to 2nd place opposite
    sides & turn 2H
17-24::
    2s+1s circle 4H round & back
25-32::
    1s+3s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5185, '2013-08-21 08:31:02.003916+00', '2023-02-04 01:19:51.093802+00', 11394, 3, NULL, 'ace', '1-4::
    1s cross RH & cast 1 place dancing in to face 2nd corners
5-16::
    Dance to Corners & Set:
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 4 more times. On
    bars 15-16 1s & 1st corners turn 1/2 RH to sidelines _while_ 2nd
    corner positions (3M & 2L) set. (3) 1 (2)
17-24::
    3L (followed by 1M) cross & cast to 3rd/2nd place Ladies'' side
    _while_ 2M (followed by 1L) dance similar to 1st/2nd place Men''s
    side, 1s turn 1.1/2 LH
25-32::
    3M (followed by 1L) cross & cast to 3rd/2nd place Men''s side _while_
    2L (followed by 1M) dance similar to 1st/2nd place Ladies'' side, 1s
    cross LH & cast to 3rd place (3s step up) 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5191, '2013-08-21 08:31:02.272691+00', '2023-02-04 01:19:51.629465+00', 2020, 3, NULL, 'ace', '1-4::
    5s dance LH across on sides (5L with 2s & 5M with 4s)
5-8::
    5s dance 1/2 reels of 3 with Ladies [5L with 2L+3L (RSh to 3L) & 5M
    with 1L+4L (RSh to 1L)] note - 5L dances behind 3M & 5M behind 1M
    also 3L dances behind 2M & 1L behind 4M
9-12::
    5s dance 1/2 reels of 3 with Men [5L with 2M+3M (LSh to 2M) & 5M
    with 1M+4M (LSh to 4M)] note  - 5L dances behind 3L & 5M behind 1L
    also 2M & 4M behind partners to end  4 3 2 1 with 5s in middle
13-16::
    5s dance LH across on sides [5L with 3s (2nd place) & 5M with 1s
    (4th place)] & 5s end facing top/bottom couples (Man up)
17-24::
    All set as 5s dance Crown Triangles around set to end 5L facing 2s
    (3rd place) & 5M facing 1s (4th place)
25-32::
    5s dance out through facing couples dancing round to meet & dance
    between 2s/1s to face top couple _while_ 3s+4s dance 1/2 R&L, 5s+3s
    dance 1/2 RH across & all set as 3s set turning out ready to start
    again.  5.4.2.1 with 3s in middle', 0);
INSERT INTO 'dancecrib' VALUES (5192, '2013-08-21 08:31:02.282413+00', '2023-02-04 01:19:51.651737+00', 14701, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s turn LH 1.1/2 times to end facing out
9-16::
    1s dance LSh reels of 3 on own sides, 1s 1/2 turn LH to end facing
    out
17-24::
    1s dance LSh reels of 3 on opp sides & turn LH to face 1st corners
25-32::
    1s turn 1st corners RH & passing RSh to face 2nd corners, turn 2nd
    corners RH & cross RSh to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (5193, '2013-08-21 08:31:02.372874+00', '2023-02-04 01:19:51.722762+00', 2021, 3, NULL, 'ace', '1-8::
    1s+2s dance the Bourrel:
::
    1M+2L set advancing, 3/4 turn 2H & twirl to end BtoB (Lady facing up
    & Man down) _while_ partners chase anticlockwise 1/2 way
::
    Set to partners & turn 2H to own sides having changed places
9-16::
    1s cross down & cast up behind 3s, dance up between 2s & cast to
    face 2nd corners
17-24::
    1s set to 2nd corners & turn 2H pivoting right about to face 1st
    corners, set to 1st corners & turn 2H pivoting right about to 1L
    facing up between 2s & 1M facing down between 3s
25-32::
    1s dance RSh reels of 3 across & cross LH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (8569, '2015-02-13 12:47:42.172484+00', '2023-02-04 01:19:51.946917+00', 15854, 3, NULL, 'ace', '1-10::
    1s lead down middle & back to top then cast to 2nd place
11-20::
    1s dance RH across (1M with 3s, 1L with 2s) & dance LH across with
    other couple then 1s turn RH to end BtoB facing 1st corners
21-28::
    1s set to & turn 1st corner; set to & turn 2nd corner
29-30::
    1s turn RH to end BtoB (Man facing up, Lady down)
31-40::
    1s dance 6 bar reels of 3 on sides (RSh to 2nd crnr) & 1s cross RH
    to 2nd place own side & all set', 0);
INSERT INTO 'dancecrib' VALUES (12915, '2020-07-01 00:19:26.344392+00', '2023-02-04 01:19:48.492697+00', 17591, 3, NULL, 'ace', '1-8::
    1s & 4s set, cast in to 2nd/3rd place (2s & 3s step down/up).  1s+4s
    dance RH across
9-12::
    2s+1s also 4s+3s turn on sides once round (Ladies LH, Men RH)
13-16::
    2s+1s+4s+3s dance 1/2 reels of 4 on sides  (Men''s side RSh, Ladies''
    side LSh).  3 4 1 2
17-24::
    1s dance down to 4th place _while_ 2s cast up to 3rd place; 2s cross
    LH, cast up to top & cross RH to own sides (3s+4s step down 23-24)
25-32::
    All circle 8H round & back.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12545, '2020-02-02 02:47:42.184919+00', '2023-02-04 01:19:48.525534+00', 19616, 3, NULL, 'ace', '1-8::
    2s+3s dance Fig 8 around couples above/below
9-16::
    All set, all Adv+Ret, all set
17-24::
    1s+2s dance 1/2 RH across, 1s+4s dance 1/2 LH across; 1s+3s dance RH
    across once round _while_
::
    4s+3s dance 1/2 RH across, 4s+1s dance 1/2 LH across; 4s+2s dance RH
    across once round
25-28::
    1s+4s dance 1/2 LH across, 1s+2s dance 1/2 RH across _while_ 4s+3s
    dance 1/2 RH across. End 1 2 3 4
29-30::
    All set
31-32::
    1s turn LH to BtoB between 2s who step up (1M facing 2M, 1L facing
    2L), _while_ 4s turn LH to BtoB between 3s who step down (4M facing
    3M, 4L facing 3L)
33-40::
    RSh reels of 4 across. 1s+4s finish the reel side-by-side facing
    down with Lady on Man''s right
41-48::
    4s followed by 1s, dance down (4 bars) & back up,  finishing BtoB in
    middle, 1s in 2nd place facing up and 4s in 3rd place facing down
49-52::
    With nearer hands joined, 1s and 4s set to corners and turn corners
    with free hand finishing on sides.  2 (1) (4) 3
53-56::
    1s+4s dance 1/2 R&L.  2 4 1 3
57-64::
    All circle left round and back. End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5197, '2013-08-21 08:31:02.44017+00', '2023-02-09 11:57:29.240431+00', 2030, 3, NULL, 'ace', '1-8::

    1s dance down 1 place & cast up on own side to places, dance down 2

    places & cast up on own side, into centre to face 1st corners

9-16::

    1s dance full diagonal Reel of 4 with 1st corners & pass partner LSh

    to face 2nd corners

17-24::

    1s dance full diagonal Reel of 4 with 2nd corners & end in centre

    facing up between 2s

25-32::

    1s cast to 2nd place & 2s+1s+3s set, 2s+1s+3s turn partners 2H. End

    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5159, '2013-08-21 08:31:01.675216+00', '2023-02-04 01:19:49.16164+00', 14693, 3, NULL, 'ace', '1-8::
    1s set & turn RH, 1M followed by partner cast 1 place & cross to
    opposite side
9-16::
    1s dance reels of 3 on opposite sides 2s+1s pass LSh to start
17-24::
    2s+1s dance Ladies'' Chain
25-32::
    1M followed by partner cast 1 place & cross to own side. All turn 2H
    & twirl out to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5201, '2013-08-21 08:31:02.476219+00', '2023-02-04 01:19:52.669601+00', 11806, 3, NULL, 'ace', '1-8::
    Ladies dance RH across 1/2 way, turning to right dance to opposite
    place & dance clockwise back to places
9-16::
    Men set advancing & turn to right to face partner, set (high cuts),
    set moving 1 place clockwise to face next Lady & set (high cuts)
17-24::
    All dance double reels of 4 (give LH in centre)
25-32::
    Men turn new ptnrs RH into allemande hold, Allemande anticl''wise
    once round & end with Men passing Lady in front to Lady facing out,
    Men in
33-40::
    All dance 1/2 Schiehallion Reel (2 places)
41-48::
    All circle 8H round & back

{{explanation}}
Repeat with Men progressing 1 place anticlockwise each time & Ladies swap ends/sides', 0);
INSERT INTO 'dancecrib' VALUES (13080, '2020-08-10 00:19:29.740515+00', '2023-02-04 01:19:49.475082+00', 1957, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, dance RSh round partner to finish in a line in centre
    facing partner (Men facing up, Ladies down) & all set
9-16::
    1s+2s+3s dance reel of 6 (8 bars) passing partner RSh to start. End
    3 2 1 in centre facing partner (Men facing up, Ladies down)
17-24::
    All turn partner 2H 1.1/4 to own side; 3s+2s+1s dance 4 bars Grand
    Chain (3s cross to start). End (2) (1) 3
25-32::
    2s+1s dance 1/2 R&L; 1s+2s turn partner RH, 1s lead down to 2nd
    place _while_ 2s cast up to top place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5161, '2013-08-21 08:31:01.716623+00', '2023-02-04 01:19:49.487965+00', 1961, 3, NULL, 'ace', '1-8::
    1L passes ptnr LSh & dances down behind Men, cross below 3s & dances
    up to pl _while_ 2L (on bar 3) & 3L (on bar 5) pass ptnr LSh &
    follow to pl
9-16::
    Men repeat passing partners RSh
17-24::
    1s+2s dance the Slip Knot - as the Knot but end by passing Lady in
    front & dancing 1/2 LH across back to own side, remaining in centre
    facing up, ready for …
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5162, '2013-08-21 08:31:01.724744+00', '2023-02-04 01:19:49.498518+00', 8669, 3, NULL, 'ace', '1-8::
    Men dance LH across 1/2 way, dance all the way round opposite Lady
    RSh & dance anticlockwise round set to original places
9-16::
    All dance Pass+Turn Grand Chain [RH to Ptnr, LH to next Dancer, RH
    turn with next Dancer (opp Ptnr) & back LH, turn Ptnr RH] to orig
    places
17-24::
    Join hands in circle & set HS, Ladies cast clockwise behind partners
    & turn next Man LH to end beside him on his right
25-32::
    All Set+Link with new Partner to end in corners with next Partner,
    Set+Link again to end in Sq.Set with another new Partner
::
    (Ladies progress 2 places clockwise & Men 1 place anticlockwise each
    32 bars)', 0);
INSERT INTO 'dancecrib' VALUES (9001, '2015-11-30 08:59:43.892185+00', '2023-02-04 01:19:53.925644+00', 16728, 3, NULL, 'ace', '1-8::
    1s set, dance in and cast (4 bars) & set advancing to face 1st
    corners (2s step up bars 5-6)
9-12::
    1s cast round 1st corner RSh to face 2nd corner, _while_ 1st corners
    1/2 turn RH and pull back RSh to dance out to each other''s places.
13-16::
    1s repeat 9-12 with 2nd corners, meet in the middle pulling back RSh
    to finish ready for double triangles.
17-24::
    3s+1s+2s dance double triangles to finish 1M between 3s (top) facing
    Ladies'' side, 1L between 2s (bottom) facing Men''s side.
25-28::
    1M+3s & 1L+2s dance 1/2 RSh reels of 3 across. 1s end in 2nd place
    opp side
29-32::
    1s turn RH 1.1/2 to finish in 2nd place own side.', 0);
INSERT INTO 'dancecrib' VALUES (5174, '2013-08-21 08:31:01.905584+00', '2023-02-04 01:19:50.430407+00', 1990, 3, NULL, 'ace', '1-8::
    All set & turn 2H, all dance 1/2 reflection reels of 4 on sides (LSh
    on Ladies'' side & RSh on Men''s side)
9-16::
    4s+3s & 2s+1s dance double Fig of 8
17-24::
    4s & 2s set to partners & turn RH, 4s cast to 3rd place _while_ 2s
    lead up to top
25-32::
    2s+3s & 4s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (12548, '2020-02-02 02:47:46.451437+00', '2023-02-04 01:19:54.638161+00', 13906, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-8::
    1s & 4s set, cast in 1 place (2s/3s step up/down); 1s+4s dance RH
    across 1.1/2 round to end 1M followed by 4L facing 3M & 4M followed
    by 1L facing 2M
9-16::
    Tandem RSh reels of 3 on sides; ending with line of 4 across, 1M+4M
    BtoB (1M facing Men''s side, 4M facing Ladies'' side), Ladies facing
    partners
17-20::
    1s+4s dance 1/2 RSh reel of 4 across
21-24::
    1L dances across to 3rd place Men''s side, 4L across to 2nd place
    Ladies'' side _while_
::
    1M dances down to 3rd place Ladies'' side, 4M dances up to 2nd place
    Men''s side & All set.  2 4 (1) (3)
25-32::
    All dance DoSiDo with partner; 2s+4s & 1s+3s circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (12391, '2019-12-05 01:29:48.95671+00', '2023-02-04 01:19:55.200078+00', 17526, 3, NULL, 'ace', '1-2::
    1s+2s turn 3/4 RH into line of 4 in middle, take prom hold, 1s
    facing Men''s side, 2s facing Ladies'' side
3-4::
    1s+2s dance 1/2 round clockwise, Ladies face up, Men down, retaining
    RH
5-8::
    1s+2s set, turn 3/4 RH to end 2s at top, 1s in 2nd place own sides
9-16::
    Reels of 3 across, 1s passing 2nd corner RSh to start. 1s pull back
    LSh to end 1M between 2s facing down, 1L between 3s facing up
17-24::
    All circle 6H round & back
25-32::
    1s petronella turn into centre BtoB, 1M facing up, 1L down & all set
    (as Crown Triangles); 1s cast to Left round 3rd corners to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5227, '2013-08-21 08:31:02.935516+00', '2023-02-04 01:19:55.260165+00', 9811, 3, NULL, 'ace', '1-8::
    All set & cross RH, all chase clockwise 1/2 way
9-16::
    4s+3s also 2s+1s dance RH across & dance 1/2 reel of 4 on sides
17-24::
    1M+2L cross RH & set _while_ partners set & cross RH, 1M+3M cross RH
    & set _while_ partners set & cross RH
25-32::
    1M+4L cross RH & set _while_ partners set & cross RH, all turn 2H
    1.1/2 times to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5226, '2013-08-21 08:31:02.927067+00', '2023-02-09 11:44:17.165343+00', 2095, 3, NULL, 'ace', '1-8::

    1L+2L+3L dance 1/2 reel of 3 on side (1L passes 2L LSh to start), 1s

    change places RH & cast to 2nd place on opp sides (2s step up/down)

9-16::

    3L+1L+2L dance RH across 1/2 way to face partner, dance round their

    partner LSh & dance RH across 1/2 way back to places (as at bar 8)

17-24::

    2M+1M+3M set advancing & dance LH across 1/2 way to end BtoB facing

    partners. All turn partners 2H to end facing clockwise round set

    (Men on outside) & dance round until 2s are in 2nd place on Men''s

    side, 1s in top place & 3s in 3rd place on Ladies'' side

25-32::

    3s dance in & down followed by 1s+2s & cross to own side (Lady under

    partner''s arm) on bar 4. 2s followed by 1s+3s lead up to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5194, '2013-08-21 08:31:02.388683+00', '2023-02-04 01:19:51.918018+00', 2024, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reels on own sides
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Allemande (1s ending in the centre in double triangle
    pstns)
33-40::
    1s dance Double Triangles', 0);
INSERT INTO 'dancecrib' VALUES (13407, '2020-12-02 01:19:40.281835+00', '2023-02-04 01:19:56.303582+00', 19929, 3, NULL, 'ace', '{{explanation}}
No hands are given throughout the dance

1-4::
    Men dance around partner LSh into middle of set facing down.
5-8::
    Ladies move in behind their partners & all dance down the middle in
    a single line (3s leading)
9-12::
    Ladies pull back RSh to turn to Men''s side _while_ Men pull back LSh
    turn to ladies'' side. 1s leading, all dance up the middle, side by
    side with partner (Lady on Man''s left) to opposite sides.
13-16::
    1M & 1L dance RSh round each other 1.1/2 times to own sides
17-32::
    All dance Sheeps Head Hey:
::
    1M followed by 2L+3L dances across the top of the set, behind 1L to
    weave down through 2M & 3M & back up. When 3L dances below 2M, she
    dances back up the line leading 1M & 2L. When 2L dances up around
    2M, she continues back down line, leading 3L & 1M below 2M, behind
    3M across the set & up the Men''s side in order 2L 3L 1M
33-40::
    All Adv+Ret; 1L casts to 3rd place _while_ 2L & 3L dance across to
    their own side _while_ 2M & 3M dance diagonally up to their own
    side, all pulling back RSh to face partner. All set. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5243, '2013-08-21 08:31:03.405456+00', '2023-02-04 01:19:56.821938+00', 2126, 3, NULL, 'ace', '1-8::
    1s+2s+3s chase clockwise to places
9-16::
    1s+2s dance RH across & LH back
17-24::
    1s cast below 3s, dance up to top & cast to 2nd place
25-32::
    2s+1s+3s Adv+Ret & turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (5210, '2013-08-21 08:31:02.663273+00', '2023-02-04 01:19:53.503857+00', 2052, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance RSh reel of 3 on sides (1s+2s pass RSh to start)
9-16::
    2s+3s+4s dance RSh reel of 3 on sides (3s+4s pass RSh to start)
17-24::
    1s+2s also 3s+4s dance RH across, all set & cross RH
25-32::
    1s set, cast 1 place; 1s+2s dance 1/2 double Fig of 8 (2s cast to
    start)
33-40::
    1s set, cast 1 place; 1s+3s dance 1/2 double Fig of 8 (3s cast to
    start)
41-48::
    1s set, cast 1 place; 1s+4s dance 1/2 double Fig of 8 (4s cast to
    start)', 0);
INSERT INTO 'dancecrib' VALUES (5211, '2013-08-21 08:31:02.671628+00', '2023-02-04 01:19:53.540256+00', 10863, 3, NULL, 'ace', '1-8::
    All Men cross & dance RSh round partner into face them, all set, Men
    pivot to right & dance back to place _while_ Ladies set
9-16::
    Repeat with Ladies crossing
17-24::
    2s followed by 1s dance down for 3 bars, cross & dance up (2s
    leading) to top, 2s+1s set _while_ 3s+4s cross RH.  (2)(1)(3)(4)
25-32::
    All dance Set+Link for 4 twice :
::
    All set, First corner pair (2 dancers at left end of lines) dance to
    the right & curve round to face up/down _while_ the other 2 dancers
    cast & chase clockwise to form lines across with the other 1st
    corner pair, repeat to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5248, '2013-08-21 08:31:03.558466+00', '2023-02-04 01:19:57.256983+00', 2136, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 R&L, set & dance 1/2 R&L
9-16::
    1s dance down the middle & back to 2nd place own sides
17-24::
    1s+3L circle 3H round to left, 1s+3M circle 3H round to left
25-32::
    2s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (13989, '2021-05-03 00:19:36.216691+00', '2023-02-04 01:19:57.509634+00', 16086, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s
9-16::
    2s+1s dance Ladies'' Chain
17-24::
    1s dance 1/2 Fig 8 down round 3s; 2s+1s+3s turn partners RH into
    prom hold facing up
25-32::
    2s+1s+3s promenade', 0);
INSERT INTO 'dancecrib' VALUES (10443, '2018-02-24 07:52:29.970444+00', '2023-02-04 01:19:57.568552+00', 17887, 3, NULL, 'ace', '1-8::
    1s +2s+3s dance reflection reels of 3 on sides (1s in/down to
    start); Bars 7-8 1s cross down to 2nd place opp sides facing out as
    2s dance up
9-16::
    1M+3s also 1L+2s dance reels of 3 across (6 bars for 1s, 1s pass 1st
    corners RSh to start, 2s & 3s pass partner LSh to begin); 1s turn
    3/4 LH to 2nd place own sides
17-24::
    2s+1s+3s set, 1s dance down between 3s, cast up meet in centre,
    dance up between 2s & cast into 1st place as 2s step down
25-32::
    1s+2s dance the Z-progression:
::
    1M, with right hand, crosses 1L in front of him to 2M''s place as 2M
    steps up & 1M dances to 1L''s place, 1s+2s set
::
    1M, with left hand, crosses 1L in front of him to 2L''s place as 2L
    steps up & 1M dances to 2M''s place, 2s+1s set', 0);
INSERT INTO 'dancecrib' VALUES (5257, '2013-08-21 08:31:03.649088+00', '2023-02-04 01:19:57.771187+00', 2153, 3, NULL, 'ace', '1-8::
    1s facing 2s set & change places RH & repeat back to places LH
9-16::
    1s+2s+3s Promenade (1s+2s remain in centre of dance)
17-24::
    1s+2s dance Poussette (1s end in double triangle position)
25-32::
    2s+1s+3s dance Double Triangles', 0);
INSERT INTO 'dancecrib' VALUES (10333, '2017-12-22 15:44:19.090376+00', '2023-02-04 01:19:55.039795+00', 15619, 3, NULL, 'ace', '1-8::
    1s set, cast (2 step up). 1s turn RH, cast up (2s step down)
9-12::
    1s+2s change places on sides (Ladies LH, Men RH), 1s with polite
    turn to face partner & 1s+2s set
13-16::
    1s+3s turn once round (Ladies LH, Men RH)  2 1 3
17-20::
    1s petronella turn to lines across, 1M between 3s, 1L between 2s &
    all set
21-24::
    All 1/2 turn opposite dancer RH, pull back RSh (twirl) & dance
    up/down to lines across, 1M+3s at top, 1L+2s in 3rd place
25-32::
    All Set+Link for 3 ending (3)(1)(2).  1s birl (or RH turn 1.1/2) to
    own sides 2nd place _while_ 3s & 2s chase clockwise 1/2 round.  2 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (5265, '2013-08-21 08:31:03.722052+00', '2023-02-04 01:19:58.346636+00', 2166, 3, NULL, 'ace', '1-8::
    1s lead down the middle & up to end facing 1st corners
9-16::
    1s dance reels of 3 across giving RSh to 1st corner (1s end facing
    1st corners)
17-24::
    1s set & turn 1st corners, set & turn 2nd corners ending in 2nd
    place opposite sides
25-32::
    1s set twice & turn 2H 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (5232, '2013-08-21 08:31:02.984568+00', '2023-02-04 01:19:55.542953+00', 2104, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Grand Chain
9-16::
    1s cross down to 2nd place, facing out hold hands on side & set,
    turn 2nd corners & end with 1s in prom hold facing 3L
17-24::
    1s dance RSh reel of 3 across with 3s, 1s end on own sides facing up
    & out
25-32::
    1s dance reels of 3 on sides 1s dancing out & up to start', 0);
INSERT INTO 'dancecrib' VALUES (13891, '2021-04-05 00:19:40.961974+00', '2023-02-04 01:19:58.752708+00', 20217, 3, NULL, 'ace', '1-8::
    1s cross down, cast behind 3s, meet & dance up to 2nd place opp
    sides & all 3 couples set.  2 (1) 3
9-16::
    2L+1s+3M Petronella turn & set (1s turning Right about); 1M+2s &
    1L+3s dance RH across.  1s pull back RSh to end facing 1st corners
17-24::
    1s dance Corner Pass+Turn with 1st corners, dance Corner Pass+Turn
    with 2nd corners.  1s pass RSh to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5268, '2013-08-21 08:31:03.825969+00', '2023-02-04 01:19:58.769301+00', 11515, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & turn LH 1.1/4 times to end 1M between 2s
    & 1L between 3s
9-16::
    2s+1s+3s Set+Link for 3 twice 1s end facing 1st corners pstns
17-24::
    1s dance 1/2 reel with 1st corners & 1/2 reel with 2nd corners, 1s
    ending in 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5238, '2013-08-21 08:31:03.253266+00', '2023-02-04 01:19:56.489373+00', 12020, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s cross RH & cast 1 place, 2s+1s+3s 1/2 turn & twirl out to
    partners place
9-16::
    1s cross RH & cast to right to 1L between 2s facing 1M between 3s,
    all 1/2 turn & twirl with opposite person (still in lines across)

{{title}}
Reel

17-24::
    All clap & 1s dance LH across on opposite sides (1M with 2M+3M, 1L
    with 2L+3L), 1s turn RH 1.1/2 times _while_ 2s+3s dance
    anticlockwise 1/2 way
25-32::
    1s dance LH across on own sides (1M with 2M+3M, 1L with 2L+3L), 1s
    turn RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5249, '2013-08-21 08:31:03.566997+00', '2023-02-04 01:19:57.285593+00', 2140, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, set & 1L casts up 1 place _while_ 1M casts
    down 1 place
9-16::
    2M dances diagonal reel of 3 with 1L+3M (passing 1L RSh to start)
    _while_ 3L dances a reel with 1M+2L (passing 1M RSh to start)
17-24::
    1s dance RSh reels of 3 on own sides to end facing 1st corners
25-32::
    1s turn 1st corners RH, partner LH, 2nd corners RH then partner LH &
    back to place', 0);
INSERT INTO 'dancecrib' VALUES (5286, '2013-08-21 08:31:04.062907+00', '2023-02-04 01:19:59.539138+00', 7300, 3, NULL, 'ace', '1-8::
    1L+2M set, cast & chase clockwise to change places & set _while_
    partners change places RH, set, cross back LH & set
9-16::
    1s+2s dance R&L
17-24::
    1M+2L set, cast & chase anticlockwise to change places & set _while_
    partners change places RH, set, cross back LH & set
25-32::
    2s+1s dance RH across, 2s+1s set & cross LH', 0);
INSERT INTO 'dancecrib' VALUES (8575, '2015-02-13 12:47:43.605625+00', '2023-02-04 01:19:59.568653+00', 15331, 3, NULL, 'ace', '1-4::
    1M and 2L turn RH once round, back to their places.
5-8::
    1L and 2M turn LH, to finish back to back in the middle, facing
    their partners.
9-16::
    Diagonal Reel of 4.
17-20::
    1s and 2s change places with their partners giving RH, then 1M and
    2L (now in the middle) turn  LH 3/4, to finish on the sidelines in
    partner''s place .
21-24::
    1s and 2s set and cross over RH, stay together joining BH, ready for
25-32::
    Poussette.', 0);
INSERT INTO 'dancecrib' VALUES (13144, '2020-09-15 00:19:37.904523+00', '2023-02-04 01:19:58.234163+00', 17135, 3, NULL, 'ace', '1-8::
    1s cross RH, 1s+2s change places on sides (1M RH, 1L LH); 2s+1s
    dance Double Fig 8 (1s cross up, 2s dance out/down)
9-16::
    2s+1s+3s dance mirror reels of 3 (1s in/down) giving hands where
    possible
17-24::
    _17-20_   1s & 3s moving clockwise, dance into centre, pull back RSh
    & dance out to diagonally opposite place. (2) (3) (1)
::
    _21-24_   2s+3s+1s set, 1/2 turn partner 2H to own side
25-32::
    3s+1s dance Rose Progression:
::
    _25-26_   1L+3M set as 1M+3L change places RH
::
    _27-28_   1L+3M 1/2 turn 2H as 1M & 3L dance into partner''s place
::
    _29-30_   1L+3M cast into each other''s place as 1M+3L 1/2 turn 2H
::
    _31-32_   1M & 3L dance into 2nd/3rd places own side as 1L & 3M cast
    to right to new places.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5290, '2013-08-21 08:31:04.191797+00', '2023-02-04 01:19:59.99521+00', 8515, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set+Link, 1s & 3s turn partners LH 1.1/2 times to
    end facing 1st corners
9-16::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners
17-24::
    1L dances LSh reel of 3 with 2s _while_ 1M+3L dance LSh reel of 4
    with 4s as 3M dances LSh reel of 3 with 5s
25-32::
    1s+4s also 3s+5s dance the Rondel to end 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (12815, '2020-05-14 23:14:23.046072+00', '2023-02-04 01:20:00.383934+00', 19970, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Inveran reels (1s cross down RH to start, cross RH to
    reel on own side from 3rd place)
9-12::
    "Flirt & Cast":
::
    _9-10_    1L+2M dance 1 step towards each other, pull back RSh,
    dance out again to place (1 step) & face out
::
    _11-12_  1L+2M cast to Right (1L down, 2M up) _while_ 1M+2L dance
    towards the middle & curve right (down/up) into their own sidelines
    2 1 3
13-16::
    2s+1s+3s 1/2 turn partner RH, pull back RSh & dance out to opp side
17-20::
    Repeat "Flirt & Cast": 1M+3L begin dancing towards one another &
    1L+3M curve through the middle
21-24::
    2s+3s+1s cross RH & all set
25-32::
    2s+3s+1s circle 6H round to left (2 bars), retain hands & all set;
    continue 6H round to left to own sides.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5278, '2013-08-21 08:31:03.916999+00', '2023-02-04 01:19:59.154551+00', 8354, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    2s dance Fig of 8 round 1s
17-24::
    1s dance Fig of 8 round 2s
25-32::
    1s cross RH, cast 1 place, cross LH & cast to bottom', 0);
INSERT INTO 'dancecrib' VALUES (9003, '2015-11-30 08:59:45.229365+00', '2023-02-04 01:20:00.86459+00', 16533, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up).  1L+2s also 1M+3s dance RH across.  1s
    finish in middle facing up, 1M following 1L
9-16::
    1s (in tandem) +2s dance reel of 3 across (1s pass 2L RSh). 1s end
    in 2nd place own sides
17-24::
    1s set, turn 3/4 RH to face own sides.  1L+2s also 1M+3s dance LH
    across. 1s finish in middle facing down, 1L following 1M
25-32::
    1s (in tandem) +3s dance reel of 3 across (1s pass 3M RSh). 1s end
    in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (9194, '2016-06-16 22:41:47.315935+00', '2023-02-04 01:19:59.643927+00', 16847, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up 3-4), dance down between 3s & cast up
    to face 1st corners
9-12::
    _1/2_ »Rotating Reel of 4«:
::
    1s+1st corners pass RSh, corners pass each other LSh in centre
    pulling back RSh to »twirl« & dance out to opp corner passing 1s RSh
13-16::
    1s turn RH 1.1/2 to face 2nd corners _while_ 1st corners dance
    clockwise round set to original places
17-24::
    Repeat bars 9-16 with 2nd corners.  1s finish in 2nd place own sides
25-32::
    2s+1s+3s circle 6H round to left (7 steps), cross R foot over L,
    pulling back LSh & chase anticlockwise to place  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5312, '2013-08-21 08:31:04.689321+00', '2023-02-04 01:20:01.784551+00', 11517, 3, NULL, 'ace', '1-8::
    1s+3s dance RH across, turn partners RH to face corner & set
9-16::
    1M+2s+3L also 1L+4s+3M dance reels of 4 on sides
17-20::
    All Ladies dance in & turn 90o to right to face next Man (Men stand
    for 2 bars), Ladies dance out as Men dance in & turn 90o to right
21-24::
    Men dance out to partner''s side (Ladies stand for 2 bars) & all set
    facing in
25-32::
    All circle 8H round & back

{{explanation}}
Repeat 3 more times moving 1 place anticlockwise each 32 bars', 0);
INSERT INTO 'dancecrib' VALUES (5326, '2013-08-21 08:31:04.820629+00', '2023-02-04 01:20:02.397391+00', 9020, 3, NULL, 'ace', '1-8::
    1L followed by partner cast to 3rd place & cross to opposite side,
    all set & cross RH
9-16::
    1M followed by partner cast up to top & cross to opposite side
    sides, all set & cross LH
17-24::
    1s lead down for 2 steps, set, lead up & turn 2H (2s dance in for…)
25-32::
    1s+2s dance 1/2 Diamond Poussette, 1s+3s dance 1/2 Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (5327, '2013-08-21 08:31:04.830667+00', '2023-02-04 01:20:02.414519+00', 2271, 3, NULL, 'ace', '1-8::
    1s lead down the middle & up to face 1st corners
9-16::
    1s turn 1st corners RH & face 2nd corners, turn corner LH & 1s cross
    LSh to own sides
17-24::
    1s dance LSh reels of 3 across (1L with 2s & 1M with 3s)
25-32::
    1s dance 1/2 Fig of 8 round 2s, 1s dance 1/2 Fig of 8 round 3s', 0);
INSERT INTO 'dancecrib' VALUES (5334, '2013-08-21 08:31:04.89603+00', '2023-02-04 01:20:02.723119+00', 2288, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cast 1 place, cross up & cast to 2nd place opposite
    sides _while_ 2s cross up, cast 1 place & cross up to 1st place own
    sides
9-16::
    2s+1s+3s set, cross RH & circle 6H round to left to end 1L between
    2M+3M at top facing down & 1L between in 3rd place facing up
17-24::
    All set in line across, change place LH with partners & circle 6H
    round to right to end 1L between 2M+3M on Men''s side & 1M between
    2L+3L on Ladies'' side
25-32::
    2s+1L also 3s+1M dance reels of 3 across (2M LSh to 2L as 1L casts
    up & 3L LSh to 3M as 1M casts down), 1s end turning LH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5335, '2013-08-21 08:31:04.906089+00', '2023-02-04 01:20:02.744101+00', 10928, 3, NULL, 'ace', '1-8::
    1s+3s dance 3/4 RH across, 1s+4s also 2s+3s dance 1/2 LH across &
    all 1/2 turn LH into lines of 4 on sides (3L+3M+2L+2M & 4M+4L+1M+1L)
9-16::
    1s+4s also 2s+3s dance 1/2 reel of 4 (pass partners LSh to start),
    all set & turn partners RH Men ending in centre LH joined
17-24::
    Men dance LH across _while_ Ladies chase clockwise to meet partner
    (1 place clockwise from orig places) Men facing out to partner, all
    set & turn RH into circle
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13616, '2021-02-04 01:19:44.514821+00', '2023-02-04 01:20:03.566431+00', 13229, 3, NULL, 'ace', '{{explanation}}
4 persons facing as for a reel of 4 up & down the room

1-8::
    All Petronella turn (the set is now square), 1+2 change places RH
    (across the set); 1+3 cross diagonally LH, 1+4 turn 1/2 RH to end
    NHJ facing up, & 3+2 NHJ facing down
9-12::
    All dance modified Set+link: All set. LH ends (3 & 4) turn 3/4 LH in
    centre _while_ RH ends (2 & 1) cast 1/4 clockwise to form line
    across (L to R: 2 3 4 1).
13-16::
    All dance 1/2 RSh reel of 4 across
17-24::
    _1_+4 also 3+2 turn 3/4 RH, All set facing up/down, on bar 20 turn
    to face across NHJ (now in same formation as bar 9 rotated 1/4
    clockwise). Repeat Modified Set+link to form line up/down 2 3 4 1
25-32::
    All 1/2 RSh reel of 4 up/down; 1+4 also 3+2 turn 1/2 RH,  all set
    facing up/down 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (5342, '2013-08-21 08:31:04.984643+00', '2023-02-04 01:20:03.087468+00', 11809, 3, NULL, 'ace', '1-8::
    1s turn RH, 2s turn LH
9-16::
    3s turn RH & 1s+2s+3s chase clockwise 1/2 way
17-24::
    3s+2s dance 1/2 R&L, 3s+1s dance 1/2 R&L
25-32::
    3s dance 1/2 Fig of 8 round 1s, 2s+1s+3s Adv+Ret', 0);
INSERT INTO 'dancecrib' VALUES (5355, '2013-08-21 08:31:05.257955+00', '2023-02-04 01:20:04.082525+00', 8946, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, dance 1/2 Fig of 8 round couple to right
    (1M round 2s & 1L round 3s) & end facing 1st corners
9-16::
    1s dance 1/2 reel of 4 with 1st corners & 1/2 reel with 2nd corners
    ending 2nd place opposite sides
17-24::
    3s+1s+2s Set+Link for 3 once, turn opposite person (up/down) RH
25-32::
    3s+1s+2s Set+Link for 3 once & turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (5359, '2013-08-21 08:31:05.359747+00', '2023-02-04 01:20:04.284756+00', 2333, 3, NULL, 'ace', '1-8::
    1s cross down & dance 6 bars of Double Triangles to end facing own
    sides
9-16::
    1s cast 1 place, turn 2H, slip step to top & cast to 2nd place own
    sides
17-24::
    1s dance reels of 3 across giving LSh to 1st corners
25-32::
    2s+1s+3s set advancing, turn 2H & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5360, '2013-08-21 08:31:05.368276+00', '2023-02-04 01:20:04.332165+00', 12609, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, set & 1/2 turn RH to face up
9-16::
    1s+2s+3s Promenade ending with 1s casting to 2nd place
17-24::
    1s dance RH across (1L with 2s & 1M with 3s), all chase clockwise
    1/2 way & end with 2s & 3s turning left about
25-32::
    1s dance LH across (1L with 3s at top & 1M with 2s), all chase
    anticlockwise 1/2 way & end with 2s & 3s turning right about
33-40::
    1L dances up & casts left _while_ 1M dances down & casts left into
    reels of 3 on opposite sides (2s give RSh to 3s to strart) 1s end
    crossing to 2nd pl', 0);
INSERT INTO 'dancecrib' VALUES (5350, '2013-08-21 08:31:05.19122+00', '2023-02-04 01:20:03.746051+00', 11811, 3, NULL, 'ace', '1-8::
    All dance 8H round & back
9-16::
    All Set+Link with partner, 1M+4L & 3M+2L dance 1/2 R&L
17-24::
    All Set+Link with corners, 2s+4s (1st & 3rd places) dance 1/2 R&L.
    4 1 2 3
25-32::
    1s+3s (2nd & 4th places) dances Figs of 8 round 4s & 2s (1L & 3M
    dance up round 4s as 1M & 3L dance down & Ladies pass in front of
    Men)', 0);
INSERT INTO 'dancecrib' VALUES (8322, '2014-07-29 12:59:00.924439+00', '2023-02-04 01:20:03.75689+00', 15278, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig. 8 around 2s, 1s dance 1/2 Fig. 8 around 3s (2s
    step up bars 7-8)
9-16::
    1s cross LH, cast (Man up / Lady down), approach up and down in
    middle of set, turn RH to face 1st corners
17-24::
    1s dance corners Pass+Turn, 1s finish in 2nd place own side
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (8578, '2015-02-13 12:47:45.084529+00', '2023-02-04 01:20:04.864048+00', 15411, 3, NULL, 'ace', '1-8::
    1s+3s dance down between 2s/4s and cast back to places, 1s+2s also
    3s+4s dance circle 4H round to Left
9-16::
    2s+4s dance up between 1s/3s and cast back to places.   1s+2s also
    3s+4s dance circle 4H round to Right
17-24::
    1s+2s set, 1/2 RH across.  1s+3s set, 1/2 LH across
25-32::
    1s+4s set, 1/2 RH across.  All 4 couples set and cross RH', 0);
INSERT INTO 'dancecrib' VALUES (5386, '2013-08-21 08:31:06.1691+00', '2023-02-04 01:20:05.977027+00', 7301, 3, NULL, 'ace', '1-8::
    1s cross down to dance reels of 3 on opposite sides
9-16::
    1s cross down to dance reels of 3 on own sides
17-24::
    1s+2s+3s set, Adv+Ret for 1 step, 1s turn 2H 1.1/2 times _while_
    2s+3s dance 1/2 R&L
25-32::
    1s+3s Set+Link, 3s+1s+2s Set+Link for 3 once
33-40::
    2s+1s+3s Set+Link for 3 once & 1s+3s Set+Link', 0);
INSERT INTO 'dancecrib' VALUES (13745, '2021-03-02 01:19:55.582262+00', '2023-02-04 01:20:05.817664+00', 13700, 3, NULL, 'ace', '1-4::
    1s & 3s cast (2s & 4s step up), 1s & 3s set, _while_ 2s & 5s cross
    RH
5-8::
    1s & 3s turn LH to face 1st corners _while_ 2s & 5s chase clockwise
    1/2 round the set (2M and 5L leading)
9-16::
    1s & 3s turn 1st corners RH & partner LH, turn 2nd corner RH &
    partner LH to face 1st corners again
17-20::
    1s & 3s dance 1/2 diag reels of 4 with 1st corners, pass partner LSh
21-24::
    1s & 3s dance 1/2 diag reels of 4 with 2nd corners, pass partner LSh
25-32::
    1s & 3s dance 1/2 diag reels of 4 with 3rd corners; 1s & 3s turn LH
    with partner, cast 1 place (4s & 5s step up 31-32). End 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (5390, '2013-08-21 08:31:06.200221+00', '2023-02-04 01:20:06.074022+00', 12253, 3, NULL, 'ace', '1-8::
    1M+3L cast 2 places (1M down, 3L up), meet in centre & turn LH to
    finish in each other''s place
9-16::
    1L+3M repeat but turning RH
17-32::
    2M+4L repeat turning LH, then 2L+4M repeat turning RH
33-40::
    3s+4s & 1s+2s dance 1/2 R&L, 1s turn RH _while_ 4s+3s+2s dance 1/2
    reels of 3 on sides', 0);
INSERT INTO 'dancecrib' VALUES (5389, '2013-08-21 08:31:06.193864+00', '2023-02-04 01:20:06.056192+00', 2380, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1M+2L turn 1.1/2 times to change places, 1L+2M repeat
17-24::
    2s facing down & 1s facing up set HS step, 2s+1s circle 4H round 1/2
    way & 1s cast 1 place _while_ 2s lead up to top
25-32::
    2s+1s set & cross passing RSh, set again & cross back to own side', 0);
INSERT INTO 'dancecrib' VALUES (5410, '2013-08-21 08:31:06.57078+00', '2023-02-04 01:20:07.246628+00', 2427, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1/4 turn RH & 1s dance up/down between
    2s/3s & cast round 2nd corner to face 1st corner (BtoB with partner)
9-16::
    1s set to 1st corner turning R about to face partner & turn prtnr
    RH, retaining hands Bal-in-Line with 1st corners & 1s turn RH to
    face 2nd corners
17-24::
    1s set to 2nd corner turning R about to face partner & turn prtnr
    RH, retaining hands Bal-in-Line with 2nd corners & 1s turn 2nd crnr
    LH to face 1st crnr
25-32::
    1s turn 1st corners RH, pass partner RSh & turn 2nd corners RH &
    pass RSh to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5414, '2013-08-21 08:31:06.691087+00', '2023-02-04 01:20:07.494729+00', 2433, 3, NULL, 'ace', '1-8::
    All dance down 1 step, in 1 step to meet partner & turn 2H, dance up
    1 step, dance out 1 step & 1s cast 1 place _while_ 2s dance up
9-16::
    1s+3s dance 1/2 R&L & turn partners 2H 1.1/2 times
17-24::
    1s+4s dance 1/2 Diamond Poussette & turn 2H to places
25-32::
    2s+3s also 4s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5415, '2013-08-21 08:31:06.700731+00', '2023-02-04 01:20:07.592346+00', 2436, 3, NULL, 'ace', '1-8::
    1s cross down,  set to 3s, 1M+3L lead up behind 2L & into centre as
    1L+3M lead down behind 4M into centre
9-16::
    1M+3L also 3M+1L advance 2 steps down/up & Men lead own partner to
    original places (by facing out turning round to left), 1s+2s+3s turn
    LH ready for ...
17-24::
    1s+2s+3s Promenade
25-32::
    1s cast 2 places, lead up the middle to top & cast to bottom', 0);
INSERT INTO 'dancecrib' VALUES (5416, '2013-08-21 08:31:06.71058+00', '2023-02-04 01:20:07.603905+00', 2437, 3, NULL, 'ace', '1-8::
    1s turn 2H & remain in middle facing each other as 2s step up, 1s+2s
    set (1s advancing & pass LSh to face opposite partner) & dance 1/2
    reel of 4 across with 2s with 1s ending reel giving LH to face down
    on own side between 2s
9-16::
    1s dance down to end between 3s & face each other, 1s+3s set (1s
    advancing & pass LSh to face opposite partner) & 1/2 reel of 4
    across with 3s 1s end giving LH to face up on own side between 3s
17-24::
    1s lead up to top, cross over & cast to 2nd place & 1/2 reels of 3
    across (L with 2s & M with 3s)
25-32::
    2s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (13302, '2020-11-02 01:19:54.632881+00', '2023-02-04 01:20:07.214928+00', 19225, 3, NULL, 'ace', '1-8::
    1s cast behind own lines & back to 1st place
9-16::
    1s cross RH, cast (2s step up);  1s dance 1/2 Fig 8 (1M up round 2s,
    1L down round 3s). 1s end facing 1st corner
17-24::
    1s turn 1st corner RH, pass RSh, turn 2nd corner RH, pass RSh to 2nd
    place own sides (corners dance 4 bars)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5409, '2013-08-21 08:31:06.480084+00', '2023-02-04 01:20:07.224884+00', 14643, 3, NULL, 'ace', '1-8::
    1s set & 1L followed by partner casts 2 places, 1L crosses & dances
    up behind 3M to 2nd place as 1M dances up middle to 2nd place
9-16::
    1s dance LSh reels of 3 on opposite sides (LSh to 2s) & 1s end in
    centre facing Ladies'' side (1L on left) 2M & 3M loop into place
17-24::
    1s dance out & cast (1L up, 1M down) into middle, dance out Men''s
    side, cast as before to end in 2nd place own sides
::
    _while_ 2s+3s cross RH & set, cross back RH & set
25-32::
    2s+1s+3s chase clockwise 1/2 way & circle 6H 1/2 round to left, back
    to places', 0);
INSERT INTO 'dancecrib' VALUES (15064, '2022-09-05 00:19:51.676912+00', '2023-02-04 01:20:08.134743+00', 20798, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s+2s dance double Fig 8 (1s cross down, 2s dance up to start)
17-24::
    1s set, cast (2s step up 19-20); 1s dance DoSiDo
25-32::
    1s+3s dance the Knot.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5427, '2013-08-21 08:31:06.919728+00', '2023-02-04 01:20:08.215919+00', 10894, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s+2s dance LH across, 1L dances down between 2s & casts up behind
    2M to meet partner in Prom hold (Lady on Man''s right)
17-24::
    1s dance reel of 3 across with 2s (LSh to 2L to start)
25-32::
    1s dance in & down crossing LH to 3rd place own sides, 2s dance
    out/up to 2nd place 25-26, 3s step up 27-28; 1s+3s turn 1.1/2 times
    on sides (Ladies LH & Men RH but turn twice 2nd time through).  2 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (5428, '2013-08-21 08:31:06.927812+00', '2023-02-04 01:20:08.245558+00', 9115, 3, NULL, 'ace', '1-8::
    All advance for 1 step & retire, 1s+2s also 3s+4s dance RH across
    1/2 way, 1/2 turn partners RH & cast out to sides
9-16::
    1s+4s circle 4H round to left, 1s dance down under arch made by 4s &
    cast round 3s to 3rd place _while_ 4s dance up & cast round 2s to
    2nd place
17-24::
    2s+4s also 1s+3s dance Diamond Poussette
25-32::
    3s dance up 2 places (as 4s+1s step down), 2s+3s+4s dance reel of 3
    on sides (3s out & up to start)', 0);
INSERT INTO 'dancecrib' VALUES (9198, '2016-06-16 22:41:49.941622+00', '2023-02-04 01:20:08.276864+00', 13863, 3, NULL, 'ace', '1-8::
    1s set, cross down, cast RSh round 1st corners & 1s 1/2 turn LH
    remaining in middle facing own sides
9-16::
    1L+3s also 1M+2s dance RH across.  1s pass RSh, dance LH across with
    other couple.  1s end in 2nd place opp sides facing 2nd corners
17-24::
    1s dance 6 bar reel of 3 on opp sides (RSh to 2nd corner)  1s cross
    RH bars 23-24
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (5425, '2013-08-21 08:31:06.903642+00', '2023-02-04 01:20:08.159941+00', 2458, 3, NULL, 'ace', '1-8::
    1s 1/2 turn, twirl (pull back RSh) & dance out to opposite sides,
    cast 1 place & turn RH to face 1st corners
9-24::
    1s dance a full clover leaf round 1st 2nd 3rd & 4th corner pstns
    passing RSh in centre _while_ 1st corners 1/2 turn & twirl opposite
    corner
::
    2nd corners repeat, but then 2s+3s 1/2 turn partners & twirl to
    opposite sides & 2s+3s facing on sides 1/2 turn & twirl to change
    places
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12152, '2019-09-02 23:55:53.219411+00', '2023-02-04 01:20:08.71439+00', 19612, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, cross LH & dance RSh round 1st corner to end
    1M between 3s facing up & 1L between 2s facing down
9-16::
    All Adv+Ret (up/down), 1s cross passing LSh & dance RSh round 2nd
    corner to end 2nd place opp sides
17-24::
    1s dance RH across (1M with 2s. 1L with 3s), 1s turn RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (14370, '2021-10-11 22:40:02.760036+00', '2023-02-04 01:20:08.848775+00', 20489, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance down between 3s & cast up to 2nd
    place own side
9-16::
    2s+1s+3s 1/2 turn partner RH, pull back RSh & dance out to opp
    sides; 2s+3s repeat _while_ 1s turn RH twice round to face 1st
    corners
17-24::
    1s dance Corner Pass+Turn with 1st corners, dance Corner Pass+Turn
    with 2nd corners.  1s pass RSh to 2nd place own sides (corners turn
    2H)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5448, '2013-08-21 08:31:07.553556+00', '2023-02-04 01:20:09.703689+00', 2498, 3, NULL, 'ace', '{{explanation}}
2 Ch - 1M stand as 1L crosses to 2M pl who crosses to ptnrs pl, 2L steps up

1-8::
    1s+2s dance R&L ending with 2M between 1L+2L facing down 1M directly
    behind 2M
9-16::
    All dance down middle, turn right about & 1M dances Ladies back to
    top (2M follows) to form a line 4 across with Men BtoB facing
    partners
17-24::
    All set to partners with suitable step
25-32::
    All dance reel of 4 across ending in new pstns with each couple
    having moved 1 place anticlockwise round set
::
    On bars 31/32 3M crosses to partners place as 3L steps up to start
    next 32 bars
::
    Similarly on bars 31/32 (2nd time through) 4M crosses to partners
    places as 4L steps up', 0);
INSERT INTO 'dancecrib' VALUES (5457, '2013-08-21 08:31:07.759363+00', '2023-02-04 01:20:10.141933+00', 10251, 3, NULL, 'ace', '1-8::
    1s lead down middle & back remaining in middle with 2s stepping in
    behind them
9-16::
    1s+2s dance Allemande & 1s end facing 1st corners
17-24::
    1s turn 1st corner RH & partner LH, turn 2nd corner RH & turn
    partner LH to 2nd place own side
25-32::
    1s+3s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (5458, '2013-08-21 08:31:07.77393+00', '2023-02-04 01:20:10.349324+00', 2508, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance & 1/2 R&L then RH across 1/2 way & all set
9-16::
    1s & 4s face across as 2s+3s face on sides & dance reels of 4
    passing facing person RSh to start (sometimes known as Borrowing
    Reels)
17-20::
    1s+2s dance 1/2 double Fig of 8 (1s cross down _while_ 2s cast up)
21-24::
    1s repeat bars 17-20 with 3s _while_ 2s cast up & cross to own side
25-28::
    1s repeat bars 17-20 with 4s _while_ 3s cast up & cross to own side
29-32::
    1s turn LH 1.1/2 times _while_ 4s cast up & cross to own side', 0);
INSERT INTO 'dancecrib' VALUES (5469, '2013-08-21 08:31:07.909817+00', '2023-02-04 01:20:10.850564+00', 9681, 3, NULL, 'ace', '1-8::
    1s+3s dance R&L _while_ 2s+4s set & cross RH, set & cross back RH
    all end facing corners
9-16::
    All set to corners, turn 2H, set to partners & turn 2H
17-24::
    All Set+Link with partners, Set+Link with corners (all are now
    opposite partners)
25-32::
    2s+4s (in 1st/3rd pstns) dance 1/2 Ladies Chain, 1s+3s dance 1/2
    Ladies Chain to end with 2s at top', 0);
INSERT INTO 'dancecrib' VALUES (5481, '2013-08-21 08:31:08.078591+00', '2023-02-04 01:20:11.416668+00', 2563, 3, NULL, 'ace', '1-4::
    1s+3s set facing diagonally with 1L+3M advancing turning to face
    partner in a diagonal line & turn partners 2H
5-8::
    1s+3s dance 1/2 diagonal reel of 4 (1s+3s end in opp places)
9-16::
    3s+2s+1s circle 6H round & back
17-24::
    1s & 3s petronella turn into next place on right & set, repeat to
    original places & set
25-32::
    1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (13161, '2020-09-15 00:19:50.71633+00', '2023-02-04 01:20:11.436074+00', 18499, 3, NULL, 'ace', '1-8::
    1L followed by 1M casts, dance Fig of 8 round 2s. On bars 7-8, 1L
    curves left & 1M loops left into place
9-16::
    3M followed by 3L casts up, dance Fig of 8 round 2s. On bars 7-8, 3M
    curves left & 3L loops left into place
17-24::
    1s+2s Set+Link, 1s+3s Set+Link to end 1s curving right to face up,
    2s+3s face down 2 3 1
25-32::
    2s+3s+1s dance reel of 3 on the sides (1s RSh to 3s) On bars 31-32,
    3s+1s loop round each other. 1s finish in 2nd place, 1L facing out 2
    1 3

{{explanation}}
On second repeat 1s dance an 8 bar reel to finish in 4th place, 4th couple finish in 3rd place', 0);
INSERT INTO 'dancecrib' VALUES (13234, '2020-10-16 00:20:05.963056+00', '2023-02-04 01:20:11.836223+00', 11707, 3, NULL, 'ace', '1-8::
    1L followed by 1M casts & dances across to 2nd place opp side (2s
    step up 3-4); 1s turn 1.3/4 LH
9-16::
    1L+2s also 1M+3s dance RH across; 1s pass RSh to dance LH across
    with other couple
17-20::
    1s pass LSh into 1s+1st corners dance 1/2 diag reel of 4, 1s pass
    RSh  & 1M curves round to follow 1L
21-24::
    2nd corners+1L+1M in tandem dance 1/2 diag reel of 3 (RSh to 3M)
25-28::
    1st corners (pstn)+1L+1M in tandem dance 1/2 diag reel of 3 (RSh to
    3L place), 1s separate, 1L curves right to face 2nd corner (pstn)
29-32::
    1s+2nd corners (pstn) dance 1/2 diag reel of 4.  1s end in 2nd place
    own side. 2 1 3

{{explanation}}
Note: Ian Brockbank devised this modified version of »The Gloomy Winter« (bars 9-16 amended)', 0);
INSERT INTO 'dancecrib' VALUES (10997, '2018-08-17 07:52:17.258798+00', '2023-02-04 01:20:12.136608+00', 18445, 3, NULL, 'ace', '{{explanation}}
2 chords - 3s & 4s cross to opp sides on 2nd chord

1-4::
    1s+2s & 3s+4s Set+Link
5-8::
    2s+1s & 4s+3s Do-Si-Do
9-16::
    2s+1s+4s+3s dance RSh reels of 4 on sides, finishing 1s & 4s turning
    3/4 LH for …
17-24::
    1s+4s dance The Targe, finishing 2 4 (1) (3) facing up/down on sides
25-32::
    2s+4s & 1s+3s set on side & turn 2H, opening out to 4H circle to
    Left', 0);
INSERT INTO 'dancecrib' VALUES (14371, '2021-10-11 22:40:05.513545+00', '2023-02-04 01:20:12.317339+00', 20488, 3, NULL, 'ace', '1-8::
    1s & 3s set & dance 1/2 Fig 8 round couples below. All set (no
    hands), Ladies turning to face out on bar 8. (1) 2 (3) 4
9-16::
    1s+2s also 3s+4s dance Ladies'' Chain but Men cross RH & turn Ladies
    LH on sides. Ladies end facing out
17-24::
    Ladies dance LSh round Man on their left, meet & pass giving RH in
    centre & dance RSh round partner (end beside partner)
25-32::
    Men repeat 17-24 casting behind partner, meet & pass giving RH in
    centre & dance LSh round Lady on left to end opposite partner. 3M &
    1M face out. (2) 1 (4) 3
33-40::
    1L followed by 1M & 3M followed by 3L chase 1/4 clockwise to swap
    places; all set & all cross RH with partner.  2 3 4 1
41-48::
    2s+3s also 4s+1s circle 4H round & back.  (Last time through circle
    8H round & back)', 0);
INSERT INTO 'dancecrib' VALUES (8781, '2015-06-15 11:40:45.725069+00', '2023-02-04 01:20:12.410827+00', 16121, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance mirror (reflection) reels of 3 (1s in/down) taking
    hands where possible. 1s+3s finish in middle NHJ, 1s facing down, 3s
    facing up
9-16::
    1s+3s Set+Link as 2s cross RH & set. All chase clockwise 1/2 way.
    1s+3s finish in middle facing up/down  3 2 1
17-24::
    Repeat bars 9-16
25-32::
    All set, all Advance to form circle, all Retire to sidelines; All
    set
33-40::
    1s+2s change places (1L+2L LH,1M+2M RH); 1s+3s change places other
    hand. All couples turn 2H.  End  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (11190, '2018-09-30 22:19:49.192955+00', '2023-02-04 01:20:12.655485+00', 18536, 3, NULL, 'ace', '1-6::
    1s set, 1L followed by 1M, cast to below 3s in middle of set facing
    up.
7-8::
    1s dance up to 2nd place opp side facing out.
9-16::
    1s dance reels of 3 on opp side with 2s and 3s. 1s pass 1st corner
    RSh to begin. End with 1s BtoB facing 1st corner.
17-22::
    1s dance 6 bars of "Hello-Goodbye"
23-24::
    1s turn RH to face up, 1M with partner on Right. Meanwhile 2s and 3s
    dance in and face up.
25-32::
    2s, 1s and 3s dance 3C allemande, finishing order 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5499, '2013-08-21 08:31:08.400822+00', '2023-02-04 01:20:12.680966+00', 10915, 3, NULL, 'ace', '1-8::
    2s pass LSh & dance 1/2 diagonal reel of 4 with 1st corners, pass
    RSh & dance 1/2 reel of 4 with 2nd corners & end 3 2 1 on opposite
    sides
9-24::
    3s+2s+1s dance 3 Couple R&L & end with 1s casting up to 2nd place
    (opp sides) & 3s+1s+2s set
25-32::
    3s+1s+2s circle 6H round to left 1/2 way & turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (9732, '2017-04-06 08:39:48.032006+00', '2023-02-04 01:20:12.70084+00', 13772, 3, NULL, 'ace', '1-8::
    1s lead down (3 bars) & back (3 bars). 1s cast, pass RSh to 2nd
    place opp sides
9-12::
    2s+1s+3s 3/4 circle 6H to Left, Men pull back LSh to face
    anticlockwise
13-24::
    _3_ Couple Ladies'' Chain:
::
    Ladies dance RH across one place _while_ Men dance one place
    anticlockwise
::
    Men turn Ladies LH
::
    Repeat twice more
25-28::
    All 3/4 circle 6H to Right
29-32::
    1s cross LSh & cast to 3rd place', 2);
INSERT INTO 'dancecrib' VALUES (11191, '2018-09-30 22:19:49.270396+00', '2023-02-04 01:20:12.970481+00', 18588, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s set & dance 3/4 "Lefts & Rights"
9-16::
    1s+4s dance 1/2 RH across, retain RH with partner, dance out of ends
    of set, cross & cast to face nearest corner on diagonals (4L+2M,
    4M+2L, 1L+3M, 1M+3L)
17-24::
    4s & 1s dance double "Hello-Goodbye" setting, finishing in centre
    facing diagonally opposite corner
25-32::
    1s & 4s turn corners (1L+2M & 4L+3M LH, 1M+2L & 4M+3L RH) dancing
    out of ends of set to finish on sides.  1s+4s Set+Link   2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (5505, '2013-08-21 08:31:08.479333+00', '2023-02-04 01:20:13.097777+00', 10500, 3, NULL, 'ace', '1-8::
    All Ladies dance RH across to end LSh to partner, 3/4 turn LH to
    original place & set
9-16::
    All Men dance LH across to end RSh to partner, 3/4 turn RH to
    original place & set
17-24::
    All petronella turn (Ladies BtoB in centre), set, petronella turn to
    partners place & set
25-32::
    All circle 6H round for 2 bars, turn partner RH 1.1/4 times into
    prom hold (Ladies on inside) & travel on 1 place clockwise', 0);
INSERT INTO 'dancecrib' VALUES (5509, '2013-08-21 08:31:08.525688+00', '2023-02-04 01:20:13.440509+00', 2600, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s+4s cast to bottom on own sides, dance up & all
    curve out to original places
9-16::
    1s+2s & 3s+4s Set+Link, 2s+1s & 4s+3s circle 4H round to left
17-24::
    2s+1s & 4s+3s dance the Knot, 1s end BtoB between 2s on opposite
    sides
25-32::
    1s dance the Spurtle: 1s dance 1/2 RSh reel of 4 with 2s & turn RH,
    1s dance 1/2 reel of 4 with 3s & turn RH to face 4s
33-40::
    1s dance 1/2 reel of across with 4s & turn RH to 4th place opposite
    sides, all set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (15066, '2022-09-05 00:19:56.553402+00', '2023-02-04 01:20:13.469012+00', 20918, 3, NULL, 'ace', '1-8::
    1s & 5s cross RH with partner & cast in 1 place _while_ 2s & 4s set
    & cross up/down to ends; 1s & 5s dance LH across & face corners
9-12::
    2L+1L+5M+4M dance 1/2 diag reel of 4 (on 1st corner diagonal)
    _while_ 2M+1M also 5L+4L turn RH ending facing
13-16::
    2M+1M+5L+4L dance 1/2 diag reel of 4 (on 2nd corner diagonal)
    _while_ 2L+1L also 5M+4M turn RH.  4 5 3 1 2
17-20::
    4s+5s+3s+1s Double Set+Link:
::
    _17-18_  All set in pairs
::
    _19-20_  4s & 1s cast 2 places (passing each other RSh) _while_ 5s &
    3s move to nearest end. 5 1 4 3 2
21-24::
    1s+4s+3s+2s Double Set+Link to end 5 4 2 1 3
25-32::
    All circle 10H round to left (6 bars), pivot & chase back.  5 4 2 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (5512, '2013-08-21 08:31:08.571921+00', '2023-02-04 01:20:13.860491+00', 10935, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s dance 1/2 R&L, 1s+4s advance & 1/2 turn RH into
    prom hold to face out (1s facing Ladies'' side & 4s facing Men''s
    side) _while_ 2s & 3s cross RH & set to partner
9-16::
    1s & 4s dance RSh reels of 3 on sides (1s RSh to 3M & 4s RSh to 2L)
    & end facing out
17-20::
    1s & 4s separate & cast to ends to meet other partner & face down/up
    (between end couples) _while_ end couples (2s+3s) cross RH & set
21-24::
    1s+4s adv, turn ptnr 1.1/2 times to prom hold facing out side (as
    before) _while_ 2s+3s turn RH 1.1/2 on sides
25-32::
    1s & 4s dance LSh reels of 3 on sides (1s LSh to 2L & 4s LSh to 3L)
    & end Men crossing partner over to other side.  2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (5513, '2013-08-21 08:31:08.581697+00', '2023-02-04 01:20:13.891477+00', 2604, 3, NULL, 'ace', '1-8::
    1s turn RH & cast to 2nd place, turn partner LH 1.1/4 times
9-16::
    1s dance RH across (Lady with 2s at top & Man with 3s); 1s pass RSh
    & dance LH across with other couple
17-24::
    1s lead down the middle & back to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5516, '2013-08-21 08:31:08.735222+00', '2023-02-04 01:20:14.443881+00', 8053, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, turn RH (4 bars)
9-16::
    1s followed by 2s lead down & 2s followed by 1s lead up to top
    having changed places
17-24::
    2s+1s+3s set, cross RH, set & cross back RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5519, '2013-08-21 08:31:08.759889+00', '2023-02-04 01:20:14.500898+00', 14360, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette but end turning 2H to face down (on
    opposite sides)
9-16::
    2s followed by 1s dance cross down between 3s & cast up own sides,
    1L+2s also 1M+3s dance RH across & 1s end facing 2nd corner
17-24::
    1s dance Pass+Turn with 2nd corners & pass RSh to face 3rd corners,
    Pass+Turn with 3rd corners ending in 2nd place opposite sides
25-32::
    1s dance reels of 3 on opposite sides (1L RSh to 2M, 1M RSh to 3L) &
    end 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13165, '2020-09-15 00:19:53.39734+00', '2023-02-04 01:20:14.561702+00', 15272, 3, NULL, 'ace', '{{explanation}}
Square set, 5s in centre facing 1s

1-8::
    1s+5s dance RH across, 5s+3s dance LH across
9-16::
    1s+5s+3s dance reels of 3 up/down set (5s RSh to 1s to start). 5s
    end facing 4s
17-24::
    2s+5s+4s dance reels of 3 across (5s LSh to 4s to start). 5M with 5L
    following faces 1L
25-32::
    5s+1s change places passing RSh, 1s+4s repeat; 4s+3s repeat, 3s+2s
    repeat & 2s face up', 0);
INSERT INTO 'dancecrib' VALUES (13166, '2020-09-15 00:19:53.775204+00', '2023-02-04 01:20:15.05496+00', 2632, 3, NULL, 'ace', '1-8::
    All dance Grand Chain
9-16::
    1s lead down through 3rd place (1M followed by 2L+2M+3L, 1L followed
    by 4M+4L+3M); 1s (followed by others) cast & dance up to top place
    to form 2 lines facing across ("Ladies'' side": 1M 2L 2M 3L  "Men''s
    side": 1L 4M 4L 3M)
17-24::
    All set to opposite person & cross RH; all dance 1/2 reels of 4 on
    sides
25-28::
    In order from 1st place, pairs of couples - 3s face down, 2M+4L face
    up, 2L+4M face down, 1s face up - all couples take Allemande hold &
    dance anticlockwise round to
::
    TOP...……2L+4M……1s
::
    ………….3s…….2M+4L
29-30::
    Men turn Ladies into centre to form 2 lines up/down set all facing
    in
31-32::
    Each Man drops RH, passes the Lady he is with by left (Bar 31),
    passes next Lady by Right, all dancing into original places

{{explanation}}
Repeat with each couple in turn leading through the opposite place on bar 9 and dancing same figures on new alignment', 0);
INSERT INTO 'dancecrib' VALUES (5536, '2013-08-21 08:31:08.909631+00', '2023-02-04 01:20:15.435242+00', 13621, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of 8 around 2s & end
    facing 1st corner
17-24::
    1s turn corners RH & pass RSh to face 2nd corners, 1s turn 2nd
    corners RH & pass RSh to end 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13896, '2021-04-05 00:19:56.944546+00', '2023-02-04 01:20:15.460895+00', 19490, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 2s+1s dance RH across.  1s end in
    middle facing down in prom hold
9-12::
    1s +1st corners dance 1/2 reel of 3 on 1st corner diagonal  (1s LSh
    to 3L to start)
13-16::
    1s+2nd corners dance 1/2 reel of 3 on 2nd corner diagonal (1s RSh to
    3M to start).  1s end in middle, 2nd place, facing down
17-24::
    1s dance mirror reels of 3 on opp sides, 1M LSh to 2M (in 3L''s
    place) & 1L RSh to 2L (in 3M''s place).  1s end in 2nd place opp
    sides. (3) (1) (2)
25-32::
    3s+1s+2s dance Set+Link for 3 couples twice.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5543, '2013-08-21 08:31:08.966832+00', '2023-02-04 01:20:15.886973+00', 13751, 3, NULL, 'ace', '1-8::
    1s dance down 2 steps & set dancing round 4th corner RSh to face 1st
    corners (RSh to RSh)
9-16::
    Dance to Corners & Set: (6 bars):
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 2 more times to end
    1s meet in the middle again. 1s turn RH to face 2nd corner position
17-24::
    1s dance 1/2 diagonal reel of 4 with 2nd corners (pstn) & pass LSh
    to face 1st crnr (pstn), 1s dance 1/2 reel with crnrs pass RSh to
    face 2nd crnr (pstn)
25-32::
    1s Dance to (3) Corners & Set:
::
    _25-26_ 1s change places with 2nd corner (pstn) passing RSh &
    corners pass RSh & 1/4 turn to right in middle to 3rd crnrs (pstn)
    as 3rd crnrs set
::
    _27-28_ Corners change places with 3rd crnrs passing RSh & 1/4 turn
    to right to face 1s in 4th crnr (pstn) as 1s set
::
    _29-32_ Corners change places with 1s passing RSh as 1st corners set
    & 1s turn RH to 2nd place opposite sides.  2(1)3
33-40::
    1s dance LSh round 2nd corners into middle to face partner (on own
    sides), set & dance down between 3s who dance up to 2nd places.  2 3
    1', 0);
INSERT INTO 'dancecrib' VALUES (13897, '2021-04-05 00:19:57.598332+00', '2023-02-04 01:20:16.127837+00', 2681, 3, NULL, 'ace', '1-8::
    1s+2s turn partners 1/2 RH, stay in centre to dance 1/2 RH across,
    1s+2s turn partner RH to finish on sides (1M facing out & up, 1L
    facing out & down)
9-16::
    2s+1s+3s dance reels of 3 on sides (1s giving RSh to 3rd corners, 2s
    dance in/down, 3s dance in/up)
17-24::
    2s+1s+3s Adv+Ret, 1s turn 2H (Pas de Basque) opening lower hands (1L
    RH, 1M LH) into BtoB facing 1st corners
25-32::
    1s dance 1/2 diagonal reel with 1st corners, pass LSh, 1s dance 1/2
    diagonal reel with 2nd corners (3) (1) (2)
33-36::
    3s+2s change places RH on sides _while_ 1s Petronella turn into
    lines of 3 across (1L between 3s, 1M between 2s). All set
37-40::
    2s+3s change places RH with partners _while_ 1s Petronella turn to
    2nd place own sides. All set 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5555, '2013-08-21 08:31:09.230075+00', '2023-02-04 01:20:16.492812+00', 9332, 3, NULL, 'ace', '1-8::
    1s+3s dance R&L
9-16::
    2s & 4s in prom hold dance reels of 3 on sides (start LSh to person
    on left)
17-24::
    2s+4s dance R&L
25-32::
    1s & 3s in prom hold dance reels of 3 across (start LSh to person on
    left)
33-40::
    All set to partner & change places RH, Ladies dance LH across ending
    in partner''s place facing out
41-48::
    Ladies dance out behind partner & loop LSh all the way round next
    Man to end in original opposite Mans position
49-56::
    All set to new partner & change places RH, Men dance LH across
    ending in own place facing out
57-64::
    Men dance out behind new partner & loop LSh all the way round next
    Lady to end in original opposite Mans position
65-72::
    1L+3M also 1M+3L dance in & dance RSh once round other partner, 1M &
    3M followed by own partner dance out between facing couple & cast
    clockwise to original places
73-80::
    2s & 4s repeat above figure
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12082, '2019-08-30 09:54:18.306166+00', '2023-02-04 01:20:16.807424+00', 2706, 3, NULL, 'ace', '1-8::
    1s lead down (3 bars), lead back up (3 bars), cross & cast to 2nd
    place opp sides
9-16::
    1s petronella turn to 1M between 2s facing down, 1L between 3s
    facing up & 1s set; lines of 3 Adv+Ret up/down
17-24::
    1s petronella turn to own sides & set; 1s cross RH & dance RSh round
    1st corners to end facing 1st corners
25-32::
    1s turn 1st corner RH, partner LH, turn 2nd corner RH & cross LH to
    2nd place own side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5561, '2013-08-21 08:31:09.284234+00', '2023-02-04 01:20:16.82816+00', 2707, 3, NULL, 'ace', '1-8::
    1M+ 2L turn RH 1.1/2 times to end 1M in 2L place & 2L in 2M place
    (2M up on bars 3/4), 1s & 2s turn LH 1.1/2 times on sides
9-16::
    1L+2L change places RH & 1s+2s facing set diagonally, 1s dance 1/2
    Fig of round 2s.  2 1 3
17-24::
    1s cross RH & cast to right, change places RH up/down & cast to 2nd
    place opp side _while_ 2s+3s set & cross RH, set & change places RH
    on sides
25-32::
    All chase clockwise 1/2 way & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5562, '2013-08-21 08:31:09.294043+00', '2023-02-04 01:20:16.93484+00', 2708, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reels on own sides ending in
    original pstns
17-24::
    1s dance down the middle & back, ending in 2nd place in middle BtoB
    facing own sides
25-32::
    1s dance Double Triangles & end facing out own sides
33-40::
    1s cast down behind 3s, cross RH, cast down to 4th place & cross LH
41-48::
    2s+3s also 4s+1s dance RH across & LH back', 0);
INSERT INTO 'dancecrib' VALUES (5569, '2013-08-21 08:31:09.367629+00', '2023-02-04 01:20:17.253741+00', 2716, 3, NULL, 'ace', '1-8::
    1s lead down & cast up behind 3s, lead up between 2s & cast down to
    end facing 2L nearer hands joined
9-16::
    1s set to 2L, turn in to face 3M & set, 1s lead out between 2M & 3M
    & cast round 3M to face 2M
17-24::
    1s set to 2M, turn in to face 3L & set, 1s lead out between 2L & 3L
    & cast round 2L
25-32::
    1s dance reels of 3 on opposite sides & cross back to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (5570, '2013-08-21 08:31:09.379126+00', '2023-02-04 01:20:17.273257+00', 2717, 3, NULL, 'ace', '1-8::
    1s set, cross down to 2nd place in centre facing 3s (2s step up
    3-4); 1s set to 3s, rotate, turning inwards, to face 2s & set to 2s
9-16::
    1s dance out, casting right to dance RSh round 1st corner, 1s pass
    RSh in centre & dance RSh round 2nd corner to end in 2nd place opp
    sides
17-24::
    1s dance RSh reels of 3 across (Lady up RSh to 2L & Man down RSh to
    3M) & 1s cross RH to own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5575, '2013-08-21 08:31:09.444438+00', '2023-02-04 01:20:17.412252+00', 2725, 3, NULL, 'ace', '1-8::
    All couples turn partners RH, dance 1/2 Grand Chain & cross RH back
    to own sides
9-16::
    End couples (4s+1s) set, cast in 1 pl & dance RH across _while_
    2s+3s dance 1/2 RH across, dance out to ends, set & cross back RH
17-24::
    4s+1s dance 1/2 Diamond Poussette, 2s+1s also 4s+3s dance 1/2
    Diamond Poussette back to original places
25-32::
    All set & turn RH, 1s cast to bottom _while_ 2s+3s+4s lead up & all
    set', 0);
INSERT INTO 'dancecrib' VALUES (14115, '2021-07-07 00:19:36.236824+00', '2023-02-04 01:20:17.500368+00', 2727, 3, NULL, 'ace', '1-8::
    1M+2L set & cross RH; 1L+2M set & cross RH (2) (1) 3
9-16::
    1s+2s set & cross RH with partner; 1s+2s dance RH across. 2 1 3
17-24::
    1s NHJ dance down between 3s, cast up, meet & dance up to top & cast
    to end facing 1st corners
25-32::
    1s turn 1st corner RH, partner LH; turn 2nd corner RH & cross LH to
    2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5586, '2013-08-21 08:31:09.688671+00', '2023-02-04 01:20:17.911295+00', 2739, 3, NULL, 'ace', '1-8::
    1s set, turn RH, cast 1 place & turn LH to face 2nd corners
9-16::
    1s dance 1/2 reel of 4 with 2nd corners, turn 4th corner (2nd corner
    person) RH & turn partner LH to face 1st corners
17-24::
    1s dance 1/2 reel of 4 with 1st corners, turn 3rd corner (1st corner
    person) RH & 3/4 turn partner LH to face out in 2nd place opposite
    sides
25-32::
    1s dance reel of 3 on opposite sides giving LSh to 2nd corner (pstn)
    1s end in lines across (1L between 3s (at top) & 1M between 2s), all
    set
33-40::
    3s+1s+2s circle 6H round to left 1/2 way, 1s petronella into 2nd
    places own sides & set

{{explanation}}
2nd time through as new 1s start, original 1s also set, turn RH and cast to bottom (i.e. repeat bars 1-6)', 0);
INSERT INTO 'dancecrib' VALUES (12637, '2020-03-02 01:52:38.891703+00', '2023-02-04 01:20:17.929718+00', 13913, 3, NULL, 'ace', '1-8::
    1L+2M 1/2 turn RH to change places, 1s+2s dance RH across, 1M+2L 1/2
    turn RH to change places.  (2) (1) 3
9-16::
    2s+1s dance R&L  finishing 2s facing down, 1s facing up
17-24::
    2L+1L, 2M+1M & 3s set & dance mirror reels of 3 on sides (2s
    in/down, 1s out/up, 3s in/up). 1s end facing out
25-32::
    2s cross down LH to 2nd place & cast up to 1st place _while_ 1s cast
    up & cross down LH to 2nd place; 1s+3s circle 4H round to left.  End
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14909, '2022-06-27 00:20:05.79511+00', '2023-02-04 01:20:19.175372+00', 20884, 3, NULL, 'ace', '1-8::
    1s slip step down 2H joined (2 bars), 1/2 turn 2H, cast up round 3s
    & cross RH to 2nd place, 1M facing up, 1L facing down (2s step up
    1-2)
9-14::
    2s+1s+3s dance 6 bar reels of 3 on own sides (1s RSh to 3rd corners)
    finish 1M between 3s facing up, 1L between 2s facing down
15-16::
    1s 1/2 turn RH, pull back RSh to end BtoB, 1M facing up & 1L facing
    down
17-24::
    2s+1s+3s dance Double Triangles
25-28::
    1s dance out (1M up, 1L down) cast round 2nd corners to 2nd place
    opp sides _while_ 2s+3s Adv+Ret diagonally
29-32::
    1s dance advance (1), 1/2 turn 2H skip change (1), retire (2),
    _while_ 2s & 3s Adv+Ret
33-40::
    2s+1s+3s circle 6H round to the left for 6 steps, pivot pulling back
    LSh & chase anticlockwise back to places', 0);
INSERT INTO 'dancecrib' VALUES (5604, '2013-08-21 08:31:09.944773+00', '2023-02-04 01:20:19.208812+00', 2768, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Grand Chain
9-16::
    1s+2s+3s set, 1s followed by 2s+3s lead down, cross at 3rd place &
    dance up on opposite sides
17-24::
    1s+2s+3s Adv+Ret, turn partners RH 1.1/2 times 3s ending on sides
    _while_ 1s+2s end in centre for Poussette
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9368, '2016-10-06 07:18:29.851183+00', '2023-02-04 01:20:19.902466+00', 17271, 3, NULL, 'ace', '1-8::
    1s 1/2 turn & twirl to change places, 1s cross LH down between 3s &
    cast up to 2nd place own sides
9-16::
    1s dance RH across (L up with 2s, M with 3s), 2s+1s+3s chase 1/2 way
    clockwise
17-24::
    1s dance LH across (L up with 3s, M with 2s), 3s+1s+2s chase 1/2 way
    anticlockwise
25-32::
    1s dance reels of 3 across giving LSh to 1st corners (L with 2s, M
    with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (5611, '2013-08-21 08:31:10.123182+00', '2023-02-04 01:20:19.91389+00', 2782, 3, NULL, 'ace', '1-8::
    1L+2L+3L Adv+Ret, 1s+2s+3s dance DoSiDo
9-16::
    1M+2M+3M Adv+Ret, 1s+2s+3s dance DoSiDo
17-24::
    1s cross RH, cast to 2nd place, cross LH & cast to 3rd place
25-32::
    1s dance Fig of 8 round 3s', 0);
INSERT INTO 'dancecrib' VALUES (13748, '2021-03-02 01:20:07.971272+00', '2023-02-04 01:20:19.925496+00', 12267, 3, NULL, 'ace', '1-4::
    1s lead down & cross to face 3s (2s step up 1-2), 1s turn 3s on
    sides (1L+3M LH, 1M+3L RH)
5-8::
    1s NHJ dance up to 2nd place & turn 2s on the sides (1M+2L RH, 1L+2M
    LH)
9-16::
    1s dance 6 bar reels of 3 on opposite sides (1s in/down, 2s
    out/down, 3s out/up to start), 1s turn LH to face 1st corners
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & cross LH to own
    sides
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5643, '2013-08-21 08:31:10.749751+00', '2023-02-04 01:20:21.645715+00', 13619, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 on own sides (RSh to 2s)
9-16::
    1s turn RH & cast 1 place, 1s turn LH into 2nd place facing down
17-24::
    2s+1s+3s dance Grand Chain
25-32::
    2s+1s+3s Adv+Ret, 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (14491, '2021-12-18 01:44:17.37369+00', '2023-02-04 01:20:20.123455+00', 2799, 3, NULL, 'ace', '1-8::
    All 4 couples dance RSh reels of 4 on sides
9-12::
    All dance 1/2 Grand Chain (1 hand to each step), ending (4) (3) (2)
    (1).  1s & 4s face out
13-16::
    4s+3s also 2s+1s dance 1/2 Double Fig 8 (4s cast, 3s cross up, 1s
    cast up, 2s cross down).  4 3 2 1
17-20::
    4L (top) & 1M (bottom) cast to opposite end own side _while_ others
    dance DoSiDo with person diagonally opposite to right, finishing
    having moved up 1 place on own side. [Ladies'' side: 3 2 1 4; Men''s
    side: 1 4 3 2]
21-24::
    Repeat 17-20 from new positions, Lady at top (3L) & Man at bottom
    (2M) cast down/up _while_ others dance as bars 17-20 to end 2 1 4 3
25-32::
    1s+4s+3s 1/2 turn partner RH & 3 couples dance 1/2 RH across to own
    side; 3s+4s+1s turn partner RH.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5635, '2013-08-21 08:31:10.67822+00', '2023-02-04 01:20:21.354621+00', 14978, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place, dance down between 3s & cast up to 2nd
    place
9-16::
    1s lead down & turn 2H, 1s lead up & 1/2 turn 2H turning about to
    face 1st corner
17-20::
    1s pass corners RSh as corners turn RH in middle then corners dance
    out to original place & 1s passing RSh face 2nd corners
21-24::
    1s pass corners RSh as corners turn RH in middle then corners dance
    out to original place & 1s passing RSh dance out to 2nd place own
    sides
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (5645, '2013-08-21 08:31:10.767841+00', '2023-02-04 01:20:21.767029+00', 11264, 3, NULL, 'ace', '1-4::
    1M casts 2 places & dances in to face 3L _while_ 1L dances across,
    casts 1 place to face 2L
5-12::
    1s dance RSh reels of 3 across (1L with 2s & 1M with 3s) ending in
    lines across facing down/up & all set
13-16::
    All circle 6H round to left to end all on opposite sides
17-20::
    1s set advcg (diag) & turn 2H
21-24::
    1s cast 2 places (M down, L up) behind Men/Ladies into middle
    _while_ 3s+2s set & turn partner 2H to 3s facing up & 2s down
25-32::
    1s dance under arches made by 3s/2s to end 2nd place opposite side
    _while_ 3s/2s dance up/down, all chase clockwise 1/2 way.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5652, '2013-08-21 08:31:10.826026+00', '2023-02-04 01:20:22.258356+00', 2871, 3, NULL, 'ace', '{{explanation}}
1s & 3s start on opp sides

1-8::
    1s also 4s in prom hold dance reel of 3 with 2s/3s (RSh to 2M/3M to
    start) & 1s+4s end in middle
9-16::
    1s+4s dance RH across, 1s & 4s change places with corner persons RH
    & set to them
17-24::
    All dance 3/4 double diagonal reel of 4 giving LH in centre (end
    with 3s in 1st pl, 4s & 1s in middle & 2s in 4th pl opp sides)
25-32::
    4s+1s dance LH across _while_ 3s+2s chase clockwise 1/2 way & all on
    sides set to partner & change places RH.  (2)4(1)3', 0);
INSERT INTO 'dancecrib' VALUES (8590, '2015-02-13 12:47:50.034886+00', '2023-02-04 01:20:22.795903+00', 2886, 3, NULL, 'ace', '1-8::
    1s+2s set, 1L followed by 1M casts, crosses up between 2s, casts
    round 2M into 2nd place own sides (2s step up 7-8)  2 1 3
9-16::
    1s+3s set, 1M followed by 1L casts, crosses up between 3s, cast
    round 3L into 3rd place own sides (3s step up 15-16)  2 3 1
17-24::
    1M followed by 1L casts up behind 3M and into 1st place opp. sides
    _while_ 2L followed by 2M casts behind 3L and into 3rd place opp.
    sides.  1s+3s+2s circle 6H round to left  (1) 3 (2)
25-32::
    1s+2s repeat bars 17-24 in opposite direction  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5661, '2013-08-21 08:31:10.989962+00', '2023-02-04 01:20:22.926764+00', 9086, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH, set & cross back RH
9-16::
    1s dance Fig of 8 round 2s (cross down to start)
17-24::
    1s dance down for 2 bars, set, dance up & cast to 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (12148, '2019-09-02 22:32:01.54592+00', '2023-02-04 01:20:24.768316+00', 19608, 3, NULL, 'ace', '1-8::
    1s set & cross RH, 1s cast 1 place & turn LH to face 1st corners
9-16::
    1s turn corners RH & pass RSh to face 2nd corners, 1s turn corners
    RH & pass RSh to 2nd place own sides
17-24::
    1s dance reels of 3 on sides (RSh to 3rd corner) & turn LH to…
25-32::
    1s dance RH across (1L with 2s, 1M with 3s) & LH across with other
    couple ending 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5689, '2013-08-21 08:31:11.831578+00', '2023-02-04 01:20:25.80015+00', 2943, 3, NULL, 'ace', '1-4::
    1s & 4s cross down/up RH _while_ 2s & 3s cast to ends, 2s & 3s (end
    cpls) set _while_ 1s+4s (middle cpls) set to each other on sides
5-8::
    2s & 3s (end cpls) cross RH _while_ 1s+4s (middle cpls) change pl on
    sides RH, 1s & 4s (middle cpls change pl with end persons LH.
    (4)(2)(3)(1)
9-16::
    4s+2s also 3s+1s (top & bottom 2 cpls) circle 4H round to left,
    2s+3s (middle cpls) dance 1/2 diamond Poussette.  (4)(3)(2)(1)
17-24::
    2s+1s (bottom 2 cpls) dance RH across 1/2 way & cross RH with
    partner, 3s+1s (middle cpls) dance LH across 1/2 way & cross LH with
    partner
25-32::
    4s+1s (Top 2 cpls) dance RH across 1/2 way & cross RH with partner,
    all circle 8H round to left 1/2 way to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5695, '2013-08-21 08:31:11.901022+00', '2023-02-04 01:20:26.04194+00', 12835, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s, 1s+3s full turn LH into…
9-16::
    1s+3s dance Ladies Chain (up/down)
17-24::
    1s dance reflection reels on opposite sides (1s out & down to start)
25-32::
    1s cast down 2 places & lead up to top, cross & cast to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (12641, '2020-03-02 01:52:44.71807+00', '2023-02-04 01:20:26.080265+00', 17045, 3, NULL, 'ace', '1-8::
    1s set, lead down & cast down behind 3s, meet & lead up to finish in
    centre 2nd place BtoB facing own side
9-16::
    1s set, 2M+1M+3M & 2L+1M+3L circle 3H round to Left (4 bars), 1s
    cast round 3rd corners (1M round 2M, 1L round 3L)
17-24::
    _1/2_ reels of 3 across (1s LSh to 1st corners); 2s+1M (above 2s) &
    1L+3s (1L below 3s) dance 1/2 LH across & 1s turn RH to 2nd place
    own side
25-32::
    2s+1s+3s circle 6H round & back. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5697, '2013-08-21 08:31:11.919217+00', '2023-02-04 01:20:26.255395+00', 2956, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret, cross RH & dance RH across 1/2 way
9-16::
    2s+1s Adv+Ret, cross LH & dance LH across 1/2 way
17-24::
    1s dance slip step down for 4 & back to top
25-32::
    1s set, cast 1 place & 2s+1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5714, '2013-08-21 08:31:12.693274+00', '2023-02-04 01:20:28.610121+00', 2975, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret 1 step, 1s cast 1 pl as 2s dance up, 1s turn LH to
    face 2nd corners & turn corners RH into prom hold (corners on 1s
    right)
9-12::
    1s+2nd corners dance 1/2 reel of 4 with 3rd corners (RSh to 3rd
    crnr) _while_ 3rd crnrs dance in & turn LH in centre to dance out to
    2nd crnrs (opp sides)
13-16::
    1s turn LH to face 2nd corner (pstns) & turn RH into prom hold
    _while_ original 2nd corner persons dance out to other corner on own
    sides
17-24::
    1s repeat with bars 9-16 with ''new'' corners but 1s end turning LH to
    2nd place own sides
25-32::
    1s dance Diag R&L

{{explanation}}
Note - 3rd time through bars 1- 4 with original 1s in 3rd place all 4 couples Adv+Ret, then new 1s & original 1st couples both cast 1 place  
The Bindweed (Optional) - 2nd time through read right for left & 1st corner for 2nd corner & vice versa', 0);
INSERT INTO 'dancecrib' VALUES (5715, '2013-08-21 08:31:12.701271+00', '2023-02-04 01:20:28.639026+00', 8029, 3, NULL, 'ace', '1-8::
    All set, 1s+2s & 3s+4s dance RH across, 1s & 4s cast into centre of
    dance as 2s & 3s dance up or down
9-16::
    1M+4M & 1L+4L dance Petronella-in-tandem to opposite sides
17-24::
    4s dance 1/2 Fig of 8 round 2s as 1s dance 1/2 Fig of 8 round 3s,
    all turn partners 2H & each dancer turns round to right to flow
    into…
25-32::
    All circle 8H round & back.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5726, '2013-08-21 08:31:13.030038+00', '2023-02-04 01:20:29.116866+00', 8057, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    Ladies Adv+Ret & dance DoSiDo
9-16::
    Men Adv+Ret & dance DoSiDo
17-24::
    All dance RH across, LH back
25-32::
    All Adv+Ret & pass RSh to meet new couple', 0);
INSERT INTO 'dancecrib' VALUES (15228, '2022-11-03 01:20:08.513416+00', '2023-02-04 01:20:29.590257+00', 21149, 3, NULL, 'ace', '1-8::
    Men dance LH across back to place; all Set+Link
9-16::
    Ladies dance LH across back to partner''s place; all Set+Link to
    original places, Ladies face out
17-20::
    All dance 4 bars of Schiehallion reels (pass LSh in centre). Ladies
    face out (all have progressed 1 place anticlockwise)
21-24::
    All turn corner LH , face partner & turn partner 2H once round,
    opening out ready to …
25-32::
    All circle 6H round & back.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (3955, '2013-08-21 08:30:40.0369+00', '2023-02-04 01:20:31.720541+00', 10517, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across 1/2 way & set, cross RH & set
9-16::
    1s dance down & back to face 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places
25-32::
    1s+3s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5733, '2013-08-21 08:31:13.328875+00', '2023-02-04 01:20:29.987216+00', 3010, 3, NULL, 'ace', '1-8::
    2s & 4s cross LH & join RH with 1st corners, all balance in 2 diag
    lines of 4; 2s & 4s turn 1st corners RH into lines of 3 or 4 across
    (4M between 5s, 2M+4L with 3s, 2L with 1s)
9-16::
    2L with 1s & 4M with 5s dance RSh reels of 3 across (RSh to 1st
    corner) _while_ 2M+4L dance RSh reel of 4 across
17-24::
    2s & 4s join LH, dance up/down to join RH with 2nd corners &
    Bal-in-Line with corners; 2s & 4s turn corners RH ending on opp
    sides, 1s, 3s & 5s remain facing out
25-32::
    1s cast 1 place as 2s cross up, 1s cross down to 3rd place as 3s
    cast up; 1s cast down as 4s cross up & 1s cross down as 5s cast up.
    2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (10079, '2017-09-03 23:44:47.089496+00', '2023-02-04 01:20:30.017173+00', 16209, 3, NULL, 'ace', '{{explanation}}
Circle, Man has Lady on his right

1-8::
    Ladies dance in front & round partner, back to place (4 bars).  Men
    repeat.
9-12::
    All turn partners RH, Ladies face out
13-16::
    Ladies dance out, cast to Right, dance in through next Lady''s place
    (2 steps) pulling back RSh to face out _while_ Men Adv+Ret
17-20::
    Repeat bars 13-16 finishing Ladies in middle, between 2 Men, facing
    out
21-24::
    All set as in Triangles, drop Left hands & all turn RH so Men are in
    middle, between 2 Ladies, facing out
25-32::
    Men repeat bars 13-20
33-40::
    All set as in Triangles, drop Left hands & all turn RH (3 bars) then
    Men turn next Lady LH (3 bars) to form circle again', 0);
INSERT INTO 'dancecrib' VALUES (5738, '2013-08-21 08:31:13.452375+00', '2023-02-04 01:20:30.392053+00', 3027, 3, NULL, 'ace', '1-8::
    1s cast 1 place, cross RH, cast below 3s & dance up middle to 2nd
    place BtoB in centre facing opp sides for Double Triangles
9-16::
    1s dance Double Triangles & end facing 2nd corners
17-24::
    1s dance diagonal reels of 4 with 2nd corners, pass partner LSh to
    face 1st corners
25-32::
    1s dance reels of 4 with 1st corners, pass partner LSh to end in 2nd
    place facing out to start next sequence', 0);
INSERT INTO 'dancecrib' VALUES (5740, '2013-08-21 08:31:13.470304+00', '2023-02-04 01:20:30.426183+00', 3033, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance RH across with 3s
9-16::
    1L followed by 3M dance Tandem reel of 3 across with 2s (RSh to 2L)
    _while_ 3L followed by 1M dance Tandem reel of 3 across with 4s (RSh
    to 4M), 1L & 3L followed by 3M/1M dance down sides to end 1s in 3rd
    place opposite sides & 3s in 2nd place own sides
17-24::
    1s cross RH, cast to bottom & turn RH (long turn) to end 2 3 4 1
25-40::
    All dance special R&L for 4 couples:
::
    The following 4 bar moves are all danced simultaneously & all the
    terms used refer to pstns not persons: -
::
    {1L casts to 4L,
::
    {4M casts to 1M,
::
    {1M+2L & 2M+3L & 3M+4L all change places RH & persons ending in 2nd
    & 3rd positions change places LH on sides _while_ those ending at 1M
    & 4L positions cross over to other side
::
    Repeat a further 3 times to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (15335, '2022-12-19 01:20:15.073655+00', '2023-02-04 01:20:30.897325+00', 21128, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-4::
    1s & 4s dance 1/2 Figs of 8 round end couples
5-8::
    1s+2s also 3s+4s Set+Link.  2 (1) 4 (3)
9-16::
    All dance RSh reels of 4 on the sides (1L & 4L finish facing out)
17-20::
    1s+4s dance RSh round the end couples (as if continuing the reel)
21-24::
    1L+4M also 1M+4L turn LH to end in tandem with Man leading
25-32::
    1M+4L & 4M+1L dance Tandem LSh reels of 3 across with end couples
    (2s/3s). Bars: 31-32 1s & 4s dance down/up sides to 2 4 (1) (3)
::
    Repeat Strathspey then twice as Ree', 0);
INSERT INTO 'dancecrib' VALUES (9370, '2016-10-06 07:18:32.594722+00', '2023-02-04 01:20:30.910871+00', 17147, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across. 1s+2s Set+Link but 1s end 2nd place facing
    Men''s side, 2s in 1st place facing Ladies'' side (no polite turns)
9-16::
    2s+1s+3s dance reels of 3 on sides (1s+3s pass LSh)
17-24::
    1M followed by 1L casts round 3M, up middle, finishing between 2s
    facing down & 1L between 3s facing up.  Lines of 3 across set
25-32::
    1M+2s also 1L+3s dance Set+Link for 3 couples (2)(1)(3).  All set &
    cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (5744, '2013-08-21 08:31:13.542087+00', '2023-02-04 01:20:31.003277+00', 3038, 3, NULL, 'ace', '1-8::
    1s followed by 2s cast to bottom, 1s+2s turn out & 2s followed by 1s
    dance back to top, 2s casting to 2nd places
9-16::
    1s lead down, cross dance out between 2s+3s opposite sides, cast
    round 3s, lead up to top, cross & cast on own sides to 2nd places
17-24::
    1s+3s circle 4H round to left, 2s+1s circle 4H round to left
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (13085, '2020-08-10 00:19:56.927224+00', '2023-02-04 01:20:31.286888+00', 3053, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s face on sides, set & change places RH; 2s+1s &
    4s+3s dance RH across
9-16::
    2s+1s+4s+3s dance RSh reels of 4 on sides
17-24::
    2s+1s also 4s+3s dance reels of 4 across (1L+2M & 3L+4M pass LSh to
    start)
25-32::
    1s+4s dance LH across, face out; 4s cast to bottom followed by 1s
    (3s step up 29-30), 1s continue down to 4th place as 3s+4s step up.
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5750, '2013-08-21 08:31:13.604419+00', '2023-02-04 01:20:31.318299+00', 3054, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 double Fig of 8 (1s cross down, 2s dance up); 1s+2s
    change places on sides (LH Ladies'' side & RH Men''s side), 1s+3s
    change places on sides (RH Ladies'' side & LH Men''s side)
9-16::
    1s+3s dance 1/2 double Fig of 8 (1s cross down, 3s dance up); 1s+3s
    change place on sides (RH Ladies'' side & LH Men''s side), 1s+2s
    change place on sides (LH Ladies'' side & RH Men''s side), 2s end
    facing out & up
17-24::
    1s dance reflection reels 3 on own sides (1s dance in to start) with
    2s & 3s crossing at top to own sides. 1s end 2nd place
25-32::
    1s+3s dance LH across once round; 2s+1s dance RH across once round', 0);
INSERT INTO 'dancecrib' VALUES (9202, '2016-06-16 22:41:55.969386+00', '2023-02-04 01:20:31.766021+00', 11200, 3, NULL, 'ace', '1-8::
    1s cross down to dance reels of 3 on opp sides
9-16::
    1s cross down to dance reels of 3 on own sides
17-20::
    1s NHJ dance down under arch made by 3s who dance up.  Repeat, 3s
    dancing under arch made by 1s
21-24::
    Repeat bars 17-20.  1s remain in centre, 2s step in ready for ...
25-32::
    1s+2s poussette', 0);
INSERT INTO 'dancecrib' VALUES (5756, '2013-08-21 08:31:13.82883+00', '2023-02-04 01:20:31.877396+00', 3063, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & face 1st corners, dance 1/2 diagonal RSh reel
    of 4 with 1st corners & pass LSh to face 2nd corners
9-16::
    1s dance 1/2 reel of 4 with 2nd corners & end curving into 2nd place
    opposite sides, 3s+1s+2s turn 2H 1.1/2 times to own sides
17-24::
    3s+1s set, dance 1/2 RH across, 3s+2s set & dance 1/2 LH across
25-32::
    1L+2M dance DoSiDo _while_ partners chase clockwise 1/2 way, 2L+1M
    dance DoSiDo _while_ partners chase clockwise 1/2 way. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5761, '2013-08-21 08:31:13.874198+00', '2023-02-04 01:20:32.1303+00', 7285, 3, NULL, 'ace', '1-8::
    1s+2s turn 1.1/2 times RH, 1s+2s dance RH across to end opp sides
    _while_ 3s+4s now turn 1.1/2 times RH (3s+4s start 4 bars behind
    1s+2s)
9-16::
    1s+2s dance 1/2 R&L _while_ 3s+4s dance RH across, 1s+3s (centre
    couples) dance 1/2 R&L
17-24::
    3s+1s dance full Ladies'' Chain
25-32::
    1s+4s lead up for 3 bars & 1/2 turn partner (Lady under Man''s arm),
    4s lead down to bottom & cast to 3rd place as 1s dance down to
    bottom', 0);
INSERT INTO 'dancecrib' VALUES (9372, '2016-10-06 07:18:32.901741+00', '2023-02-04 01:20:32.163016+00', 17076, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 2s face 1s for dance 1/2 RSh reel of 3 on sides with
    1s ending in middle (1M facing down to partner who faces up)
9-16::
    1s turn RH & LH to face 1st corner (pstn) _while_ 3s+2s dance R&L
    (RH on sides to start)
17-24::
    1s dance 1/2 diag reel of 4 with corners & pass RSh to face 2nd
    corner (pstn), 1s dance 1/2 reel of 4 with corners ending 2nd place
    opp sides.  (2)(1)(3)
25-32::
    2s+1s+3s circle 6H round & back

{{explanation}}
Repeat the dance in reverse with top of dance at other end (3s as the dancing couple) to end 2 3 1 on own sides', 0);
INSERT INTO 'dancecrib' VALUES (15231, '2022-11-03 01:20:10.962148+00', '2023-02-04 01:20:32.432626+00', 21151, 3, NULL, 'ace', '1-8::
    1s cast (2s step up), 1s turn RH remain in centre facing own side;
    1s dance 1/2 Fig 8 (1M down round 3M, 1L up round 2L) & face 1st
    corners
9-16::
    1s+1st corners dance diagonal RSh Weasel Reel:
::
    All dance part reel of 4 on 1st corner diagonal but when reaching
    either end they chase clockwise to other end to re-enter reel.
::
    Corners end in original places, 1s end in centre facing opp sides,
    1M below 1L
17-24::
    1L+2s & 1M+3s dance RH across;1s pass RSh to dance LH across with
    other couple. 1s end facing 2nd corner
25-32::
    1s+2nd corners dance diagonal RSh Weasel Reel:
::
    Reel as bars 9-16 on 2nd corner diagonal, but bar 32: 1s do not pass
    RSh but curve left to face out in 2nd place own side.  2 1 3

{{explanation}}
Note:	After 2nd turn 1s cast to 4th place as 4s step up bars 1-2 of next repeat', 0);
INSERT INTO 'dancecrib' VALUES (12394, '2019-12-05 01:30:21.932759+00', '2023-02-04 01:20:32.452436+00', 3088, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 2s+1s+3s turn partners RH & face
    clockwise
9-16::
    All dance clockwise 1/2 roun; 1s turn 1.1/4 RH to opp sides _while_
    2s+3s continue dancing round.  End 2 (1) 3
17-24::
    1s cast RSh round 1st corners, pass RSh & cast RSh round 2nd
    corners. 2 (1) 3
25-32::
    Reels of 3 on sides, 1s+1st corners pass LSh to start (6 bars), 1s
    cross RH to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15336, '2022-12-19 01:20:16.954049+00', '2023-02-04 01:20:33.167017+00', 21129, 3, NULL, 'ace', '1-4::
    1s turn RH & cast 1 place (2s step up 3-4)
5-8::
    1s dance 1/2 diagonal R&L with 1st corners (Man down, Lady up)
9-12::
    1s dance 1/2 diagonal R&L with 4th corners (Man down, Lady up). (3)
    1 (2)
13-16::
    1s Petronella turn  into centre & set moving on bar 16 to face 1st
    corners
17-24::
    1s & 1st corners dance 1/2 diamond reel of 4:
::
    _17-18_  1s dance out (pass RSh) as 1st corners pass LSh & turn to
    face each other on the 2nd corners diagonal (Long steps) into
    diamond formation
::
    _19-20_  1s & 1st corners set, on bar 20 1st corners move in to
    finish BtoB in centre facing 3rd corner positions
::
    _21-22_  1st corners dance out as 1s dance in (long step) &
    Petronella turn to 2nd place on opposite sides
::
    _23-24_  1s set & move on bar 24 to finish BtoB facing 2nd corners
25-32::
    Repeat bars 17-22 with 2nd corners, 1s end facing partner up/down
    set & Petronella to own sides.   2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8181, '2014-02-10 10:26:32.786481+00', '2023-02-04 01:20:33.279343+00', 3102, 3, NULL, 'ace', '1-8::
    1s dance Inveran reels with 2s+3s
9-16::
    1s followed by 2s dance down middle & set to partners, 2s followed
    by 1s dance up 2s to1st place & 1s in middle facing up
17-24::
    1s followed by 3s dance up & cast & dance down to 3rd place & 1s
    cast up to 2nd place
25-32::
    2s+3s dance R&L starting on sides _while_ 1s dance track of reel of
    3 across giving LSh to 1st corner pstn & end 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (5777, '2013-08-21 08:31:14.04436+00', '2023-02-04 01:20:33.694222+00', 3111, 3, NULL, 'ace', '1-8::
    1s turn RH 1.1/2 times, turn 2s on sides nearer hands joined
    (passing between 2s) to end in a line of 4 across with 1s in middle
    all facing down
9-16::
    1s+2s dance down centre & back to places
17-24::
    1s+2s dance RH across & LH across back
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (5778, '2013-08-21 08:31:14.052514+00', '2023-02-04 01:20:33.717935+00', 13528, 3, NULL, 'ace', '1-8::
    1s cross down & dance reels of 3 on opposite sides
9-16::
    1s cross RH & cast 1 place, dance down between 3s & cast up to face
    1st corners
17-24::
    1s dance Pass+Turn with 1st corners, 1s dance Pass+Turn with 2nd
    corners
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13239, '2020-10-16 00:20:24.336551+00', '2023-02-04 01:20:34.108073+00', 3133, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 2s+1s dance 1/2 R&L
9-16::
    1s+2s dance Ladies'' Chain. End facing in diagonally
17-24::
    Highland Schottische Petronella:
::
    _17-20_   Set right (HS) then pivot to right to face out & set left
    (HS) & pivot right to face in again having moved 1 place
    anticlockwise round
::
    _21-24_   Repeat 17-20 to end on sides. 2 (1)
25-32::
    1s lead down (2 bars), lead up, cross & cast.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (5789, '2013-08-21 08:31:14.153522+00', '2023-02-04 01:20:34.500316+00', 8934, 3, NULL, 'ace', '{{explanation}}
Danced twice through

1-8::
    All dance reels of 3 on sides (1s give RSh to 2s to start)
9-16::
    All Promenade
17-24::
    All set, 1s cast to bottom _while_ 2s+3s set & dance up 1 place, all
    set
25-32::
    All Adv+Ret & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (12553, '2020-02-02 02:48:16.379809+00', '2023-02-04 01:20:35.176879+00', 19840, 3, NULL, 'ace', '{{explanation}}
Circle, Man has Lady on his right

1-8::
    All Ladies Advance, Clap, Retire;  Men repeat
9-16::
    All circle round and back & finish facing partner
17-24::
    All dance DoSiDo with partner (Pass RSh to start); all turn partner
    2H
25-32::
    Retain 2H & all slip step into centre & back out; all turn partners
    1.1/2 RH to change places

{{explanation}}
Repeat with new partner', 0);
INSERT INTO 'dancecrib' VALUES (5813, '2013-08-21 08:31:14.671285+00', '2023-02-04 01:20:35.648826+00', 9026, 3, NULL, 'ace', '1-4::
    1s cross down RH to 2nd place (2s step up), 1M casts up to between
    2s facing down _while_ 1L dances behind 3M to between 3s facing up
5-8::
    1s dance 1/2 reels of 3 on own sides (1L+2L & 1M+3M pass LSh to
    start). End in lines of 3 across, 1L between 3s at top, 1M between
    2s in 3rd place
9-16::
    3s+1s+2s circle 6H round & back ending in lines of 3 across again
17-24::
    1s dance 1/2 reels of 3 on opposite sides (LSh to 2nd corner pstn) &
    end in lines across, 1M between 2s & 1L between 3s; 1s cross RH &
    cast to 2nd place own side
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5809, '2013-08-21 08:31:14.63222+00', '2023-02-04 01:20:36.101192+00', 9127, 3, NULL, 'ace', '1-8::
    1s cast 1 place (4 bars) & dance RH across (Lady with 2s & Man with
    3s)
9-16::
    1M casts up & dances down as 1L casts down below 3s & dances up, 1s
    dance LH across (1L with 2M+3M & 1M with 2L+3L) & face 1st crnrs
17-24::
    1s set to 1st corners, set to 2nd corners ending Man between 2s
    facing down & Lady between 3s facing up, 1s set & change places RH
25-32::
    1s dance RSh reels of 3 across (Lady with 2s & Man with 3s) & 1s end
    crossing down to 3rd places (3s up)', 0);
INSERT INTO 'dancecrib' VALUES (5810, '2013-08-21 08:31:14.640455+00', '2023-02-04 01:20:36.13099+00', 9759, 3, NULL, 'ace', '1-8::
    All set, 1s+2s also 3s+4s dance 1/2 double Fig of 8 (2s & 3s cast to
    start), 1s & 4s dance down/up into centre as 2s & 3s dance to ends
9-16::
    1s+4s dance Set & Rotate to end :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place (2)(4)(1)(3)
17-24::
    All set & cross RH, 2s+4s also 1s+3s set on sides & turn (full)
25-32::
    All dance RSh reels of 4 to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5811, '2013-08-21 08:31:14.6526+00', '2023-02-04 01:20:36.153624+00', 15037, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & 1s+2s dance RH across 1/2 way _while_ 3s cross RH.
    All chase clockwise 1/2 way.  3 1 2
9-16::
    1s dance reels of 3 across (1M up passing 3L by RSh, 1L down passing
    2M by RSh) to end with 1s dancing to top NHJ _while_ 3s cast to 2nd
    place
17-24::
    1s dance reels of 3 on own sides casting to start & 3s dancing
    in/down. All give hands where possible  1 3 2
25-32::
    _3_ couple Set & Rotate:
::
    _25-28_  1s+2s+3s Set & Rotate singly & chase clockwise to form
    lines of 3 across (Men facing down & Ladies up)
::
    _29-32_  All change places with partner & chase clockwise to own
    sides to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5824, '2013-08-21 08:31:14.931623+00', '2023-02-04 01:20:37.30709+00', 8060, 3, NULL, 'ace', '1-8::
    1s turn RH & LH
9-16::
    2s turn RH & LH
17-24::
    1s dance down middle & back up to 2nd place
25-32::
    2s+1s dance RH across & LH back', 0);
INSERT INTO 'dancecrib' VALUES (8841, '2015-08-13 20:33:44.943985+00', '2023-02-04 01:20:37.593658+00', 13121, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    Double Ladies Chain (Ladies dance 1/2 RH across in middle)
9-16::
    1s & 3s Petronella in Tandem to face across. 1s & 3s set, dance RH
    across finishing facing & all couples take promenade hold
17-24::
    Promenade reel of 4 across (1s & 3s pass RSh)  1s & 3s finish facing
    in centre, nearer hands joined
25-32::
    1s dance under arch made by 3s. 1s & 3s dance out thro'' 4s/2s (Men
    between, Ladies pass standing Men LSh) back to places & turn LH
    1.1/2
33-56::
    2s & 4s repeat bars 9-32
57-64::
    All circle 8H round & back

{{title}}
Jig

{{explanation}}
Repeat, except bars 17-24 & 40-48 danced as parallel reels of 4 (1L+3M, 1M+3L pass RSh)', 0);
INSERT INTO 'dancecrib' VALUES (5826, '2013-08-21 08:31:14.948311+00', '2023-02-04 01:20:37.617163+00', 12542, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 pl, all circle 6H round 3/4 way to left & end in
    lines of 3 across (Ladies face down & Men up)
9-16::
    All set & change places with partner RH, all circle 6H round 3/4 way
    to left & end in middle facing up.  3 1 2
17-24::
    All dance Allemande. 2 1 3
25-32::
    1s+3s (bottom 2 couples) dance the Bourrel to end 2 3 1 :
::
    1M+3L set advg, 3/4 turn 2H & twirl to end BtoB (up/down middle L
    facing up & M down) _while_ 1L+3M chase anticl''wise 1/2 way to face
    prtnr
::
    1s+3s set to partners & turn 2H to own sides having changed places', 0);
INSERT INTO 'dancecrib' VALUES (5834, '2013-08-21 08:31:15.02889+00', '2023-02-04 01:20:38.026197+00', 8564, 3, NULL, 'ace', '1-4::
    1s & 3s cross RH & cast 1 place
5-8::
    1s & 3s cross LH & Ladies cast up 1 place as Men cast down all into
    lines across (1L facing 2L, 1M facing 4L BtoB with 3L facing & 3M
    facing 5L)
9-16::
    1L+2s also 3M+5s dance RSh reels of 3 across as 1M+3L+4s dance RSh
    reel of 4, 1s & 3s end facing 1st corners
17-24::
    1s & 3s set & turn 1st corners 2H, set & turn 2nd corners 2H to end
    in 2nd/4th place opposite sides
25-32::
    All Adv+Ret, 1s & 3s cross RH & cast 1 place _while_ 2s/4s/5s turn
    RH 4s & 5s ending 1 place up', 0);
INSERT INTO 'dancecrib' VALUES (5835, '2013-08-21 08:31:15.037201+00', '2023-02-04 01:20:38.076384+00', 13318, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance 1/2 Reflaction reels of 3 on sides (1s dance in &
    down), 1s cross RH & cast up to partners original place
9-16::
    1s repeat bars 1-8 on opposite sides
17-24::
    1s & 3s dance double Fig of 8 around 2s (1s cross down & 3s cast up
    to start)
25-32::
    2s followed by 1s dance down middle for 2 steps &  set to partners.
    1s followed by 2s dance up to top & 1s cast to 2nd place as 2s dance
    to top', 0);
INSERT INTO 'dancecrib' VALUES (5846, '2013-08-21 08:31:15.392911+00', '2023-02-04 01:20:38.931644+00', 8837, 3, NULL, 'ace', '1-8::
    1s lead down crossing, cast off behind the 3s, cross RH, cast up 1
    place & 3/4 turn LH to face 3rd corners
9-16::
    1s dance LSh reels of 3 across (1M+2M & 1L+3L pass LSh), 1s 1/2 turn
    LH to face 1st corners -
17-24::
    1s dance LSh reels of 3 (1M+3L & 1L+2M pass LSh) ending with 3/4
    turn RH to face 4th corners -
25-32::
    1s dance RSh reels of 3 on own sides (1M+3M & 1L+2L pass RSh) & 1s
    end in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (5848, '2013-08-21 08:31:15.411558+00', '2023-02-04 01:20:39.128582+00', 3250, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 double Fig of 8 (1s cast to start), 1M+2M turn RH
    1.1/2 times _while_ Ladies turn LH 1.1/2 times
9-16::
    1s+3s dance 1/2 double Fig of 8 (1s cross down to start), 1M+3L turn
    RH once round _while_ 1L+2M turn LH & 1s end facing up
17-24::
    2s+1s+3s dance reels of 3 on sides (1s in & up to start)
25-32::
    1s dance 1/2 reels of 3 across (1L with 2s & 1M with 3s), 1s 1/2
    turn & twirl to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (14578, '2022-02-05 02:20:10.029005+00', '2023-02-04 01:20:39.910609+00', 20614, 3, NULL, 'ace', '1-8::
    1M+3L Adv+Ret (2 steps each); 1M+3L turn RH back to place (4 brs)
9-16::
    1L+3M repeat bars 1-8
17-24::
    All 3 couples join hands on side & Adv+Ret; 2s dance DoSiDo
25-32::
    1s+2s dance Set & Rotate to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5860, '2013-08-21 08:31:15.645148+00', '2023-02-04 01:20:40.25787+00', 11164, 3, NULL, 'ace', '1-8::
    1s set & cross RH, 1s+2s set & cross RH
9-16::
    1s+2s+3s set & cross RH, all circle left 1/2 way.  3 (2) 1
17-24::
    3s+2s+1s dance reels of 3 on sides with 1s crossing up to start.  3
    (2)(1)
25-32::
    3s+2s+1s dance Grand Chain (4 hands 2 bars per hand) with 3s
    crossing to start.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5868, '2013-08-21 08:31:15.844296+00', '2023-02-04 01:20:40.550765+00', 8138, 3, NULL, 'ace', '1-8::
    1s+2s set & Petronella-in-tandem into centre, circle 4H round to
    left 1/2 way & turn partners 2H ready for diagonal Poussette
9-16::
    2s+1s dance 1/2 Diamond Poussette, 2s+3s dance 1/2 Diamond Poussette
    ending on own sides.  1 3 2
17-24::
    3s dance diag R&L  (2)3(1)
25-32::
    2s also 1s dance petronella turn into centre & set, 2s & 1s turn
    partners LH 1.1/4 times to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5869, '2013-08-21 08:31:15.852647+00', '2023-02-04 01:20:40.568853+00', 11890, 3, NULL, 'ace', '1-8::
    1s cross down to dance reels of 3 on opposite sides
9-16::
    1s dance down below 3s & 1L followed by partner casts up round 3M &
    1L dances LH across with 2s _while_ 1M dances RH across with 3s
17-24::
    1s dance out Ladies side, 1L followed by partner casts up round 2L,
    1L dances RH across with 2M+3M _while_ 1M dances LH across with
    2L+3L
25-32::
    1s set to 3s, turn inwards & set to 2s, cross up & cast to 2nd place
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (5876, '2013-08-21 08:31:15.912814+00', '2023-02-04 01:20:40.818989+00', 5371, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1M dances full reel of 3 with 2s (LSh to 2L) picking up partner on
    bar 4 _while_ 4M reels with 3s & picks up partner on bar 4 & end
    facing in centre
9-16::
    1s+4s set, dance RH across & dance up/down to opposite original
    places
17-24::
    All facing on sides dance Grand Chain
25-32::
    All set, 1s+2s also 3s+4s change pl on sides RH, 1s+4s change pl on
    sides LH & top 2 couples also bottom couples circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (5881, '2013-08-21 08:31:15.957373+00', '2023-02-04 01:20:40.958877+00', 3299, 3, NULL, 'ace', '{{explanation}}
2 chords - on 2nd chord 2s & 4s cross to opposite sides

1-8::
    1L+2L also 3L+4L set to each other & change places RH, Men repeat.
    2 (1) 4 (3)
9-16::
    2s+1s also 4s+3s dance RH across, 1s+4s dance LH across _while_ end
    couples chase clockwise to other end of set.  3 (1) 4 (2)
17-24::
    3s+1s also 4s+2s dance Men''s Chain across dance
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (11087, '2018-09-09 17:53:03.167935+00', '2023-02-04 01:20:43.975344+00', 18563, 3, NULL, 'ace', '1-8::
    1s set & cast to 2nd place, 1s dance down between 3s & cast up to
    2nd places
9-16::
    1s dance RH across with 2s, 1s dance LH across with 3s
17-24::
    1s lead down middle & lead back to 2nd places
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (5893, '2013-08-21 08:31:16.095357+00', '2023-02-04 01:20:41.594875+00', 3331, 3, NULL, 'ace', '{{explanation}}
4s & 5s & 6s start on opp sides

1-8::
    All dance reel of 3 on sides (1M followed by 2M (in & down to
    start), 3M by 4L & 6L by 5L also 1L by 2L (in & down), 3L by 4M & 6M
    by 5M
9-16::
    3s+4s dance 1/2 reel of 4 across (Men pass LSh to start), 2s & 5s
    turn 2H 1.1/2 times _while_ 3M & 4L, 4M & 3L turn 2H 1.1/2 times on
    sides (2s,3s,4s & 5s have changed sides)
17-18::
    1L & 4L cast down 2 places as partners cross to their places _while_
    3L & 6L cast up 2 places as partners cross to their places
19-24::
    1s+3s & 4s+6s set facing diagonally & dance 1/2 RH across _while_ 2s
    & 5s set on sides, all 1/2 turn partners RH to end in prom hold (1s
    & 4s on Men''s side facing in, 3s & 6s on Ladies side facing in, 2s
    in centre facing up & 5s in centre facing down
25-32::
    1s+2s+3s also 4s+5s+6s in prom hold dance reels of 3 across (2s &
    3s, 5s & 4s passing RSh to start)
33-40::
    2s followed by 3s & 1s Allemande down Men''s side _while_ 5s followed
    by 4s & 6s Allemande up Ladies side to end 5 4 6 1 3 2
41-48::
    All set, turn partners RH 1.1/2 times & set (bottom 3 couples end on
    opposite sides)

{{explanation}}
NB Can be danced 3 times or 6 times through', 0);
INSERT INTO 'dancecrib' VALUES (5897, '2013-08-21 08:31:16.257399+00', '2023-02-04 01:20:41.763399+00', 3339, 3, NULL, 'ace', '1-8::
    1s slip step down for 4 steps & back, cast to 2nd places & meet in
    centre 2H
9-16::
    1s repeat ending in 3rd places
17-24::
    2s+3s+1s circle 6H round & back
25-32::
    1s lead up to top, set & cast to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (9008, '2015-11-30 08:59:55.48006+00', '2023-02-04 01:20:41.930067+00', 16726, 3, NULL, 'ace', '1-4::
    1s+4s cross RH, 1s cast off, _while_ 4s cast up.
5-8::
    1M+2s dance RH across, _while_ 4L+3s dance RH across, _while_ 1L+4M
    set advancing and turn RH.
9-16::
    1L followed by 4L dance RSh tandem reel across with 2s, _while_ 4M
    followed by 1M dance RSh tandem reel across with 3s.  4s and 1s
    finish on opposite sides.
17-20::
    4s+1s dance LH across.
21-24::
    4s+1s set and cross RH.
25-32::
    2s+1s+4s+3s circle 8H round and back.', 0);
INSERT INTO 'dancecrib' VALUES (9009, '2015-11-30 08:59:55.48709+00', '2023-02-04 01:20:41.972958+00', 3349, 3, NULL, 'ace', '1-8::
    1s dance down below 2s, cast up to top, lead down RH joined, cross
    to 2nd place opposite sides & face out. 2s move up on [5-6]. All
    take hands and set
9-16::
    1s dance RSh Reels of 3 on opposite sides to end 1s pass RSh to face
    1st corners
17-24::
    1s dance DoSiDo with 1st corners, 1s set to 1st corners, 1s dance
    RSh round each other to face 2nd corners
25-32::
    1s repeat bars 17-24 with 2nd corners & end passing RSh to 2nd place
    own side', 0);
INSERT INTO 'dancecrib' VALUES (14528, '2022-01-10 02:19:43.517646+00', '2023-02-04 01:20:42.246868+00', 19785, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s circle 4H round & back
9-12::
    1s+2s also 3s+4s set; 1s & 4s cast out of end into 2nd/3rd place
    _while_ 2s & 3s (middle couples) dance up/down to 1st/4th place
    facing out 2 1 4 3
13-16::
    2L+1L also 4M+3M turn RH _while_ 2M+1M also 4L+3L turn LH. 2s (at
    top) face down/out, 3s (at bottom) face up/out
17-24::
    1L followed by 4L dance Alternating Tandem reel of 3 on Ladies'' side
    (RSh to 2L) _while_ 1M followed by 4M dance similar on Men''s side
    (LSh to 2M)
25-32::
    2s & 3s cross RH with partner & chase clockwise 1/2 round to other
    end.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (8843, '2015-08-13 20:33:46.204146+00', '2023-02-04 01:20:43.129669+00', 13123, 3, NULL, 'ace', '1-8::
    Mirror (reflection) reels of 3 on opp sides (1s cross down, then 2s
    & 3s cross down from top place)
9-16::
    1s set, cross down RH (2s step up), set & turn LH 3/4
17-24::
    1M+2s & 1L+3s dance RH across. 1M followed by 2M+2L dances down
    Ladies'' side, across & up Men''s side to 2nd place as 1L+3L+3M dance
    similar up men''s side, across and down Ladies'' side  3 1 2
25-32::
    All circle 6H round & back
33-40::
    1s+2s dance 1/2 R&L, 2s+3s dance 1/2 R&L  2 (3) (1)
41-48::
    1s followed by 3s lead down, Lady dances under partner''s arm & 3s
    followed by 1s dance back up  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (11453, '2019-01-01 01:57:05.584309+00', '2023-02-04 01:20:43.183276+00', 18957, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    Top 3 cpls set, top 3 dancers on Ladies'' side (1L+2L+3M) cross
    passing prtnrs RSh & chase clockwise back to the Ladies'' side
9-16::
    Bottom 3 cpls set, bottom 3 dancers on Men''s side (2M+3L+4L) cross
    passing prtnrs RSh and chase clockwise back to the Men''s side.
17-24::
    The 4 Ladies (now in the middle positions) dance 1/2 RH across, take
    prom hold with prtnrs and dance clockwise 3 places round the set,
    ending in the sidelines facing in, Men with partner on right
25-32::
    All 4 cpls set, petronella-in-tandem to the right, set and change
    places RH with person facing, ending 3 (4) 1 (2)
33-40::
    All dance LSh reels of 4 on side (3s and 2s begin by pulling back
    RSh).
41-42::
    Middle dancers (4s+1s) turn RH on sides to end BtoB, _while_ 3s & 2s
    cross RH
43-48::
    All dance a Grand Chain for 3 places (LH, RH, LH) to end 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (5935, '2013-08-21 08:31:16.997214+00', '2023-02-04 01:20:44.538828+00', 14696, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s
9-16::
    1s 1/2 turn 2s (M RH, L LH) & 1/2 turn 3s (other hand), 1/2 turn 4s
    & set turning into 4th place
17-24::
    All turn RH, 1s lead up crossing over to 1st place opposite sides
25-32::
    1s 1/2 turn 2s (M RH, L LH) & 1/2 turn 3s (other hand), 1/2 turn 4s
    & cross RH 4th place
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14530, '2022-01-10 02:19:45.109954+00', '2023-02-04 01:20:44.88567+00', 17966, 3, NULL, 'ace', '1-8::
    All set on sides, 1s cast below 3rd places followed by 2s+3s, turn
    in & dance back up to place
9-16::
    1M+2L set, cross RH, set & cross RH back to place _while_ 1L+2M
    cross RH & set, cross RH & set
17-20::
    1L followed by 1M casts & crosses to 2nd place opp side, 1s turn
    right about, 1M to face out (2s step up 19-20)
21-24::
    1M followed by 1L casts & crosses to 3rd place own side (3s step up
    23-24).  2 3 1
25-32::
    All circle 6H round to left, Advance in (shout »Hoi«) & Retire to
    place', 0);
INSERT INTO 'dancecrib' VALUES (5944, '2013-08-21 08:31:17.113514+00', '2023-02-04 01:20:45.371514+00', 3412, 3, NULL, 'ace', '1-8::
    1s set, cast to 3rd place, set & cast back to top
9-16::
    1s lead down below 2s, cross & cast down behind 3s, lead up to top &
    cast to 2nd place opposite sides to face 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s dance reels of 3 across passing 1st corners RSh
33-40::
    1s dance reels of 3 on own sides giving RSh to 3rd corner', 0);
INSERT INTO 'dancecrib' VALUES (11454, '2019-01-01 01:57:06.165467+00', '2023-02-04 01:20:45.406537+00', 18080, 3, NULL, 'ace', '1-8::
    1s set, turn 2H & face up, cast 1 place (2s do not step up)  1s pass
    LSh & dance RSh round 1st corners to end in centre1L above 2s, 1M
    between 3s & 4s
9-16::
    1L+2s dance RH across, LH back _while_
::
    1M + [4M followed by 3M] + 4L [followed by 3L] dance tandem reel of
    3 across (1M LSh to  3M to start).
::
    End 1L above 2s & 1M below 4s in centre
17-20::
    1s set (Glasgow Highlanders setting) _while_ 2s+3s+4s dance DoSiDo
    with partners
21-24::
    1s dance towards each other & turn 2H to end between 2s & 3s own
    side facing out (2s step up 21-24)
25-32::
    1s+3s 1/2 turn (Ladies RH, Men LH), 1s+4s 1/2 turn other hand; 4s+1s
    set & turn partner 2H', 0);
INSERT INTO 'dancecrib' VALUES (13754, '2021-03-02 01:20:28.889503+00', '2023-02-04 01:20:45.434943+00', 12293, 3, NULL, 'ace', '1-8::
    1L casts down to 4th place (2L+3L+4L step up 3-4) _while_ 4M casts
    up 1st place (1M+2M+3M step down 3-4), all turn opposite dancer RH
9-16::
    2L casts down to 4th place (3L+4L+1L step up 7-8) _while_ 3M casts
    up 1st place (4M+1M+2M step down 7-8), all turn partner RH 3 4 1 2
17-24::
    3s+4s also 1s+2s dance 1/2 R&L; 4s+3s+2s (top 3 couples) dance 1/2
    reel of 3 (3s out & down to start)
25-32::
    All Adv+Ret; All turn partners 1.1/2 RH. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (5945, '2013-08-21 08:31:17.121901+00', '2023-02-04 01:20:45.466335+00', 3415, 3, NULL, 'ace', '1-8::
    1M+2M 1/2 turn RH _while_ 1L+2L 1/2 turn LH into D Triangle position
    & set, 1M+3M 1/2 turn LH as 1L+3L 1/2 turn LH to form a line across
    facing up & set
9-16::
    1s dance up to end between 2s facing up _while_ 2s face down & set,
    1s turn 2s with nearer hand into 2nd places & 2s+1s+3s set
17-24::
    1s followed by 3s cross up & dance Fig of 8 round 2s, 1s ending in
    3rd place & 3s in 2nd place
25-32::
    3s+1s 3/4 turn ptnrs RH into line in centre, 3M+1L turn LH 1.1/2
    times _while_ ptnrs chase 1/2 way cl''wise, 1s+3s 3/4 turn ptnrs RH
    as 2s full turn RH', 0);
INSERT INTO 'dancecrib' VALUES (5946, '2013-08-21 08:31:17.131915+00', '2023-02-04 01:20:45.4886+00', 3416, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    All circle 4H round & back
9-16::
    All dance RH across & LH back
17-24::
    Men change places RH, Ladies Change places RH & all dance 1/2 R&L
    (RH to opp person to start)
25-32::
    All set to partner, set to opposite person & turn opposite person RH
    1.1/2 times to end facing next couple', 0);
INSERT INTO 'dancecrib' VALUES (5947, '2013-08-21 08:31:17.141913+00', '2023-02-04 01:20:45.51551+00', 3418, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, set on side lines to 1st corners & change
    places with them RH
9-16::
    1L+3L also 2M+1M set to each other on sides & change places LH, 1s
    turn RH 1.1/2 times to 2nd place on own sides
17-24::
    1s set on side lines to 2nd corners & change places with them RH,
    1M+3M also 2L+1L set to each other on sides & change places LH
25-32::
    3s+1s+2s Adv+Ret, circle 6H round 1/2 way to left', 0);
INSERT INTO 'dancecrib' VALUES (9377, '2016-10-06 07:18:35.821724+00', '2023-02-04 01:20:45.610192+00', 16222, 3, NULL, 'ace', '1-8::
    1s lead down (4 steps), cast up behind 3s & 2s to place
9-16::
    All dance 6H round & back
17-24::
    1s+2s set & dance 3/4 R&L (6 steps).  1s end in 2nd place facing out
25-32::
    1s cast round person on Right (Man up, Lady down), meet in middle &
    turn 1.3/4 RH moving down to 3rd place own sides (3s step up 31-32)', 0);
INSERT INTO 'dancecrib' VALUES (5948, '2013-08-21 08:31:17.15012+00', '2023-02-04 01:20:45.638662+00', 11832, 3, NULL, 'ace', '1-8::
    All dance 8H round & back
9-16::
    All 1/2 turn partner RH & twirl to opposite side, set & cross back
    RH
17-24::
    1s & 4s set, petronella turn into centre & 2s+1s also 4s+3s dance RH
    across (2s & 3s having moved towards ends slightly)
25-32::
    1s+4s dance 1/2 reels of 4 up/down centre, set to partners & 3/4
    turn 2H.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5949, '2013-08-21 08:31:17.158503+00', '2023-02-04 01:20:45.665582+00', 3422, 3, NULL, 'ace', '1-4::
    1s, 3s & 5s cross RH, cast 1 place
5-8::
    Ladies dance 1/2 Fig of 8 round cpl above & Men with cpl below
    (dncrs pass LSh) & end facing 2nd crnr pstns _while_ 2s,4s, 6s & 7s
    set & cross RH
9-24::
    1s, 3s & 5s dance ''Mairi''s Wedding'' reels with corners ending 7 1 6
    3 4 5 2 Dancing couples pass RSh to end Men facing down & Ladies up
25-32::
    1s, 3s & 5s turn partners 3/4 RH to end facing up, 1s, 3s & 5s lead
    up to top & cast into 6th, 4th & 2nd places.  7 5 6 3 4 1 2', 0);
INSERT INTO 'dancecrib' VALUES (5962, '2013-08-21 08:31:17.383127+00', '2023-02-04 01:20:46.458055+00', 3449, 3, NULL, 'ace', '1-8::
    1s & 3s cross down between 2s/4s, cast down round 4s/5s, dance up
    between 4s & 2s/5s & 4s, cross & cast to end facing 1st corners
9-16::
    1s & 3s turn 1st corner RH, partner LH, 2nd corner RH & partner LH
17-24::
    1s & 3s dance RH across (1L with 2s, 1M+3L with 4s & 3M with 5s),
    pass RSh for LH across with other couple & pass LSh to face 1st
    corners
25-32::
    1s & 3s dance RSh reels of 4 with 1st corners & pass RSh to face 2nd
    corners
33-40::
    1s & 3s dance RSh reels of 4 with 2nd corners ending on sides.  2 1
    4 3 5
41-48::
    1s & 3s turn RH, cast & turn LH', 0);
INSERT INTO 'dancecrib' VALUES (13245, '2020-10-16 00:20:34.726539+00', '2023-02-04 01:20:46.849778+00', 15585, 3, NULL, 'ace', '1-8::
    1M+2L+3M+4L dance 1/2 diag reel of 4, 2L+3M pass RSh in centre to
    face 2nd corner; 1L+3M+2L+4M dance 1/2 diag reel of 4.
9-12::
    3M+4s (at top) & 2L+1s (at bottom) dance RH across _while_ 2M+3L 1/2
    turn RH, pull back RSh & dance out to opp sides.  (4) (3) (2) (1)
13-16::
    4s+3s+2s+1s circle 1/2 round to left.  1 2 3 4
17-24::
    All set, 1s+2s also 3s+4s Petronella in Tandem; 2s+1s (at top) also
    3s+4s (at bottom) circle 4H round to left to form 4 lines of 2
    facing up/down
25-28::
    All set, top 2 couples & bottom 2 couples Petronella in Tandem (2)
    (1) (4) (3)
29-32::
    End couples (2s & 3s) set & cross RH _while_ middle couples (1s+4s)
    dance 1/2 R&L.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5974, '2013-08-21 08:31:17.516229+00', '2023-02-04 01:20:47.274318+00', 7781, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place (2s step up); 1s dance up between 2s &
    cast to 2nd place own side
9-16::
    1L+2s & 1M+3s dance RH across; 1s dance the Snake:
::
    1M followed by 2s & 1L by 3s cross diagonally passing LSh to change
    ends & 1s end with 1L followed by 1M facing down. 3 1 2
17-20::
    1s dance Alternating Tandem 1/2 reel of 3 across with 2s (RSh to 2M
    in 3rd place)
21-24::
    1s dance Alternating Tandem 1/2 reel of 3 across with 3s (RSh to 3L
    in 1st place). 1s end facing  1M''s 1st corner person (3rd corner
    pstn)
25-28::
    1s dance Alternating Tandem 1/2 reel of 3 on 1st corner diagonal. 1s
    end facing 1M''s 2nd corner person (4th corner pstn)
29-32::
    1s dance Alternating Tandem 1/2 reel of 3 on 2nd corner diagonal &
    1s end in 2nd place own side. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10083, '2017-09-03 23:44:53.132682+00', '2023-02-04 01:20:47.579709+00', 3503, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L+4L dance across top of set, down behind Men,
    across the bottom & back to places
9-16::
    Men repeat above Fig
17-24::
    1s lead down the middle & back to top
25-32::
    1s cast to 4th place _while_ 2s+3s+4s step up on bars 27-28, 1s turn
    RH', 0);
INSERT INTO 'dancecrib' VALUES (11738, '2019-03-26 02:05:33.977076+00', '2023-02-04 01:20:48.058746+00', 19203, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s+2s+3s set & circle 6H round to left
17-24::
    1s followed by 2s dance down, 2s divide & 1s followed by 2s dance
    back up, remaining in middle, 1s facing 2s
25-32::
    1s+2s dance Rondel', 0);
INSERT INTO 'dancecrib' VALUES (5988, '2013-08-21 08:31:17.673926+00', '2023-02-04 01:20:48.237351+00', 3522, 3, NULL, 'ace', '1-8::
    1s lead down middle (3 steps), lead up (3 steps) & cast to 2nd place
    (2s step up)
9-16::
    2s+1s+3s Adv+Ret, 1s turn RH to end in middle facing up
17-24::
    1s dance up, cast round 2s, meet in middle, dance down & cast up
    round 3s into 2nd place own sides
25-32::
    2s+1s+3s dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6001, '2013-08-21 08:31:17.801508+00', '2023-02-04 01:20:48.888363+00', 12296, 3, NULL, 'ace', '1-8::
    1s cross down & cast down behind 3s, cross up between 3s & cast up
    behind 2s
9-16::
    1s followed by 2s+3s dance down, 1s followed by 2s+3s dance up & 1s
    cast to 2nd place as 2s dance to top
17-24::
    1s pass LSh to dance RH across with 1st & 2nd corners, pass RSh to
    dance LH across with 3rd & 4th corners
25-32::
    1s dance reels of 3 across (M with 2s, L with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (13247, '2020-10-16 00:20:36.527629+00', '2023-02-04 01:20:48.912472+00', 8683, 3, NULL, 'ace', '1-8::
    1L dances towards partner, pulls back RSh & 1L followed by 1M casts
    off & crosses to opp side (2s step up); 1s+2s set
9-16::
    1M dances towards partner, pulls back LSh & 1M followed by 1L cast
    up & cross to own side (2s step down); 1s+2s set
17-24::
    1s Petronella turn twice to opp sides & turn 1.1/2 RH remaining in
    centre (2s step in) ready for …
25-32::
    1s+2s dance Poussette. 2 1', 0);
INSERT INTO 'dancecrib' VALUES (6002, '2013-08-21 08:31:17.809869+00', '2023-02-04 01:20:48.934401+00', 9787, 3, NULL, 'ace', '1-8::
    1M+2M Set+Link _while_ 1L+2L reverse Set+Link (1s end facing out),
    1s+3s set & 1/2 turn on sides (Men LH & Ladies RH)
9-16::
    2s+3s+1s dance reflection reels on own sides (1s dance up between 3s
    who dance out & down to start)
17-24::
    1s set, cross RH, cast up to 2nd place & turn LH to face 1st corners
25-32::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh & dance
    1/2 reel with 2nd corners ending in 2nd place opposite sides
33-40::
    3s+1s+2s turn partners RH & chase clockwise 1/2 way to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6003, '2013-08-21 08:31:17.820086+00', '2023-02-04 01:20:49.224853+00', 8336, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, turn partners RH & change places LH with other
    partner on the sides
9-16::
    1s dance 1/2 Fig of 8 round 2s to meet in reverse prom hold & dance
    1/2 reel of 3 with 2s giving LSh to 2M
17-24::
    1s lead down the middle & back to top
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (14579, '2022-02-05 02:20:17.995401+00', '2023-02-04 01:20:49.858969+00', 18520, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across & LH across back to place
9-16::
    1M+2L also 3M+4L turn RH; 1L+2M also 3L+4M turn RH
17-24::
    1s slip step down middle (4 bars) & slip  back up (2 bars) to finish
    in 4th place own side (2s+3s+4s step up 21-22), All clap 4 times
25-32::
    All circle 8H round & back.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6009, '2013-08-21 08:31:17.962624+00', '2023-02-04 01:20:50.115502+00', 3563, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1L+2M also 3L+4M turn RH 1.1/2 times, centre couples dance LH across
9-16::
    1M+2L also 3M+4L turn RH 1.1/2 times, centre couples dance LH
    across.  (2)(1) 4 3
17-24::
    All dance RSh reels of 4 on sides
25-32::
    4s dance diag R&L (M down)  (2)(3) 4 1

{{explanation}}
Note the new 1s+2s will now be on opposite sides while 3s+4s are on own sides', 0);
INSERT INTO 'dancecrib' VALUES (13622, '2021-02-04 01:20:23.822645+00', '2023-02-04 01:20:50.167332+00', 9483, 3, NULL, 'ace', '1-4::
    1s+2s also 3s+4s dance 1/2 RH across (2 bars), 1s+4s dance 1/2 LH
    across _while_ 2s+3s turn partner LH (2 bars)
5-8::
    Repeat bars 1-4 from new positions, ending 4 3 2 1
9-16::
    All set, cross RH, set & cross back RH
17-24::
    Repeat bars 1-8 ending original places
25-30::
    1s cross RH to 2nd place as 2s step up, 1s cast to 3rd place as 3s
    dance up to 2nd place, 1s cross LH to 4th place as 4s step up
31-32::
    All turn partner 2H to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6010, '2013-08-21 08:31:17.972666+00', '2023-02-04 01:20:50.186978+00', 3564, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 on own sides (dance in to start)
9-16::
    1s cross RH & cast 1 place, cross LH & cast down 1 place.  2 3 1
17-24::
    1s dance up to top, all turn partners RH
25-32::
    1s+2s dance Allemande.  2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (6011, '2013-08-21 08:31:17.980889+00', '2023-02-04 01:20:50.203107+00', 3567, 3, NULL, 'ace', '1-8::
    1s+2L also 3s+4L dance diagonal reels of 3 across 1s & 3s passing
    partners RSh to start (1L & 4L dance up side to start)
9-16::
    1s+2M also 3s+4M dance diagonal reels of 3 across 1s & 3s passing
    partners LSh to start (2M & 4M dance up side to start)
17-24::
    1s+2s set & dance 1/2 RH across, 1s+3s set & dance 1/2 LH across
25-32::
    1s+4s set & dance 1/2 RH across, all set & cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6012, '2013-08-21 08:31:17.99093+00', '2023-02-04 01:20:50.317954+00', 3570, 3, NULL, 'ace', '1-8::
    1s lead down the middle, back to top, cross & cast to 2nd places
9-16::
    2s lead down the middle & back to top
17-24::
    2s+1s dance reel of 4 across (Ladies pass LSh to start)
25-32::
    2s+1s dance R&L, 1s end facing 1st corners
33-40::
    1s set & turn 1st corners, set & turn 2nd corners
41-48::
    1s dance reels of 3 on sides passing 1st corners LSh & cross to own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (14580, '2022-02-05 02:20:21.676664+00', '2023-02-04 01:20:54.942355+00', 20612, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s lead down between 3s, cast up & turn
    2H to face 1st corner
9-16::
    1s dance 1/2 diag reel of 4 with 1st corners, pass LSh, dance 1/2
    diag reel of 4 with 2nd corners. 1s pass RSh to end in centre, 2nd
    place facing out (3) 1 (2)
17-24::
    3s+1s+2s dance Double Triangles but no hands given, 1s Petronella
    turn to 2nd place own side
25-32::
    1s+ corners dance Diag R&L (1M down, 1L up).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7364, '2013-08-21 08:31:39.694101+00', '2023-02-04 01:22:31.708337+00', 6177, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s, 1s 1/2 turn 2s with nearer hand (1M
    LH, 1L RH) & 1/2 turn 3s with other hand. 1s end in 3rd place opp
    sides
9-16::
    1s dance 1/2 Fig of 8 round 3s, 1s 1/2 turn 3s with nearer hand (1M
    LH, 1L RH) & 1/2 turn 2s with other hand. 1 2 3
17-24::
    1s dance down to 2nd place in centre (2s step up), 1s set to 3s, set
    to partner & set to 2s
25-32::
    1L dances RH across with 2L+3L on Ladies'' side & 1M dances LH across
    on Men''s side, 1s dance up & cast to 2nd place own sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7365, '2013-08-21 08:31:39.702149+00', '2023-02-04 01:22:31.735845+00', 6178, 3, NULL, 'ace', '1-8::
    1s cross down to face 1st corners & dance reels of 3 across giving
    RSh to 1st corners
9-16::
    1s dance reels of 3 with other couples giving LSh to 2nd corners
17-24::
    1s lead out between 2L+3L, 1L casts up 1M down, meet & lead out
    between 2M+3M, 1L casts up to original place as 1M casts down & up
    to pl
25-32::
    1s dance DoSiDo, cast to 2nd places & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (7366, '2013-08-21 08:31:39.712045+00', '2023-02-04 01:22:31.843285+00', 6182, 3, NULL, 'ace', '1-8::
    1s cast & dance down own side below 3s & lead up to places
9-16::
    1s+2s+3s dance RH across & LH back to places
17-24::
    1s lead down the middle & back to top
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15339, '2022-12-19 01:20:32.528303+00', '2023-02-04 01:20:50.338412+00', 21131, 3, NULL, 'ace', '1-8::
    2s set, cast right to finish 2M between 1s, 2L between 3s facing
    opposite sides; 2s dance 1/2 LSh reels of 3 across
9-16::
    2s dance LSh round partner to end BtoB in centre, 2M facing up, 2L
    facing down; 1s+2M also 2L+3s circle 3H round to the left. 2s finish
    in 2nd place own sides (1) 2 (3)
17-20::
    1s+2s+3s Set+Link for 3 couples, 3s & 1s end facing partner.
21-24::
    2s Petronella to 2nd place own side & set _while_ 3s+1s set to
    partner & cross RH to own sides.  3 2 1
25-32::
    2s+1s dance the Knot to finish 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (9381, '2016-10-06 07:18:36.750216+00', '2023-02-04 01:20:50.363579+00', 17185, 3, NULL, 'ace', '{{explanation}}
2 chords: 2nd chord 3s+4s cross to opposite sides

1-8::
    All Ladies pass partner LSh and dance to opposite ends, 3L+4L+1M+2M
    also 1L+2L+3M+4M dance LH across
9-16::
    Repeat bars 1-8, passing opp Man LSh, to original positions
17-24::
    1M+2M, 1L+2L, 3M+4M, 3L+4L Set+Link, 1L+4L cross RH and set _while_
    1M+4M set and cross RH
25-32::
    2s+4s+1s+3s circle 8H round and back', 0);
INSERT INTO 'dancecrib' VALUES (6019, '2013-08-21 08:31:18.129392+00', '2023-02-04 01:20:51.065201+00', 12952, 3, NULL, 'ace', '1-8::
    All circle to right & back
9-16::
    1s+3s dance RH across 1.1/4 times, pass facing dancer LSh & chase
    anticlockwise to original places
17-24::
    1s & 3s dance Tandem reels across with corners (RSh to 4M/2M to
    start)
25-32::
    1s+3s dance LH across 1.1/4 times, pass facing dancer LSh & chase
    anticlockwise to opposite places
33-40::
    3s+1s dance R&L
41-44::
    3s & 1s cast round corners & cross in through side couples into line
    up/down centre (1L+1M+3M+3L)
45-48::
    1s+3s Bal-in-Line to right & set rotating to face partner, 3/4 turn
    RH to original places _while_ 2s & 4s set & turn RH
49-88::
    2s+4s repeat bars 9-48 (reels up/down & Balance across)
89-96::
    All circle to left & back', 0);
INSERT INTO 'dancecrib' VALUES (13250, '2020-10-16 00:20:37.587927+00', '2023-02-04 01:20:51.086588+00', 8063, 3, NULL, 'ace', '1-8::
    All Men Adv+Ret; All Ladies Adv+Ret
9-16::
    Men pass partner RSh, dance down behind Ladies & up own side
17-24::
    Ladies pass partner LSh, dance down behind Men & up own side.  4 3 2
    1
25-32::
    1s make arch, 2s+3s+4s dance down under arch & cast up own side.  2
    3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12401, '2019-12-05 01:30:37.287542+00', '2023-02-04 01:20:51.457717+00', 3586, 3, NULL, 'ace', '1-8::
    1s lead down & back remaining in middle at top in prom hold, 1s
    facing Men''s side, 2s step in, take prom hold to face Ladies'' side
    (2L on right of 2M)
9-16::
    Couples dance out to sides & face across (2 bars), set, dance into
    middle with 1s facing up, 2s at top facing partner (2 bars), 1s set
    _while_ 2s 1/2 turn RH to face top ready for…
17-24::
    2s+1s dance promenade
25-32::
    1s cast up (2s step down), turn 2H, cast down to 2nd place (2s step
    up) & turn 2H to end in 2nd place own side.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (11455, '2019-01-01 01:57:08.734885+00', '2023-02-04 01:20:51.492998+00', 18950, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L (No polite turns for 2L & 1M)
9-16::
    1s+2s+3s dance reels of 3 on own sides with 2s passing 3s RSh to
    start. 1M finishes facing out on own side, his partner ready to
    follow.
17-20::
    1M dances out & behind 2M & across dance to 2L''s place facing out
    and up _while_ 1L  follows partner to finish in 2 M''s place, facing
    2L.( 2s step up bars 19 & 20)
21-28::
    2s+1s dance Ladies'' Chain. Finish 1L ready to dance up between 2s,
    1M ready to dance down between 3s
29-32::
    1L dances up & casts down round 2L to 2nd place _while_ 1M dances
    down & casts up round 3M to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6027, '2013-08-21 08:31:18.234065+00', '2023-02-04 01:20:52.403868+00', 3601, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s followed by 2s lead down to bottom & 2s lead back
17-24::
    2s+1s+3s set, cross RH, set & cross back RH except 1s who pass RSh
    to end BtoB facing own sides in Double Triangle position
25-32::
    1s dance Double Triangles with 2s+3s', 0);
INSERT INTO 'dancecrib' VALUES (9207, '2016-06-16 22:42:00.474027+00', '2023-02-04 01:20:52.441487+00', 11202, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 R&L (1 hand per bar), 2s+1s set, cross RH with
    partner
9-16::
    1s+3s repeat bars 1-8
17-24::
    1s set, lead up to top, cross & cast to 2nd place opp side (3s step
    down 21-22)
25-32::
    2s+1s+3s dance 6 bar reels of 3 on sides (1s in/down) & cross RH to
    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6029, '2013-08-21 08:31:18.252181+00', '2023-02-04 01:20:52.567452+00', 3607, 3, NULL, 'ace', '1-8::
    1s+2s+3s set cross RH, set & 1/2 turn RH into Promenade hold
9-16::
    1s+2s+3s Promenade
17-24::
    1s set & cast to 2nd place, 1s dance DoSiDo
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6043, '2013-08-21 08:31:18.389034+00', '2023-02-04 01:20:53.628727+00', 3625, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s+2s dance RH across, LH back to places & 1s cast 1 place
9-16::
    1s+3s dance R&L

{{title}}
Reel

17-24::
    2s+1s circle 4H round & back
25-32::
    1s dance reels of 3 on own sides giving RSh to 4th corner', 0);
INSERT INTO 'dancecrib' VALUES (6060, '2013-08-21 08:31:18.549105+00', '2023-02-04 01:20:54.972221+00', 3653, 3, NULL, 'ace', '1-8::
    All set, 1s & 3s cross down 1 place _while_ 2s & 4s cast up, all
    set, 2s & 4s cross down _while_ 1s & 3s cast up
9-16::
    1s & 3s cross RH, change pl LH on side with 2s/4s, 1s turn RH as 2s
    & 4s cross RH as 3s 1/2 turn RH, 1s cast to 4th pl as 3s cross up to
    2nd pl
17-24::
    1s set, cross up, cast up behind 3s & cross up
25-32::
    2s+3s+4s Adv+Ret for 1 step twice _while_ 1s dance down behind 2s in
    front of 3s & behind 4s to 4th pl & all dance DoSiDo round partner', 0);
INSERT INTO 'dancecrib' VALUES (12554, '2020-02-02 02:48:30.29905+00', '2023-02-04 01:20:55.027817+00', 3654, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 2s+1s+3s turn RH, all end in centre
    facing up ready for…
9-16::
    2s+1s+3s dance allemande, 1s end facing 1st corners
17-24::
    ''Hello-Goodbye'' setting, 1s end in 2nd place own side
25-32::
    3s+1s+2s circle 6H 1/2 round to left; all turn partners 1.1/2 2H..
    End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6061, '2013-08-21 08:31:18.559457+00', '2023-02-04 01:20:55.054841+00', 8571, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH, lead down & cross below 3s, cast up to 2nd place own
    side & set
9-16::
    1s+1st corners Adv+Ret 1 step (on diagonal), 1s+2nd corners Adv+Ret
    1 step & all dance DoSiDo
17-20::
    1s cross up (no hands) to top as 2s cast down & 1s dancing out 1/2
    turn 2s with nearer hand
21-24::
    1s cross down to bottom as 3s cast up & 1s dancing out 1/2 turn 3s
25-32::
    1s dance LSh reels of 3 across (Lady with 2s & Man with 3s) & 1/2
    turn 3s (Ladies LH & Men RH)', 0);
INSERT INTO 'dancecrib' VALUES (6063, '2013-08-21 08:31:18.587495+00', '2023-02-04 01:20:55.216004+00', 3656, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left 1/2 way, set, circle 4H round to right
    1/2 way & set
9-16::
    1s followed by 2s+3s cast on own sides, cross below 3rd place
    (passing partners LSh) then dance up opposite side
17-24::
    1s+2s+3s repeat above Fig back to places
25-32::
    1s+2s dance Poussette.  2 1 3
33-40::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6071, '2013-08-21 08:31:18.666732+00', '2023-02-04 01:20:55.537297+00', 8533, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, set & 1s cast down 1 place _while_ 2s lead
    up & face out as 3s turn individually to face out
9-16::
    KELPIE REELS - 2s+1s+3s dance reels of 3 on sides with each couple
    cross up from 2nd pl (2s cast & 1s cross up to start), 1s end facing
    1st crnrs
17-24::
    1s dance ''Hello-Goodbye'' setting
25-32::
    1s change places LH, dance reels of 3 across set giving LSh to 1st
    corner to start & 1s end in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6074, '2013-08-21 08:31:18.691917+00', '2023-02-04 01:20:55.626719+00', 3678, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-16::
    1L+2M cross RH & cast behind partners back to original places, 1s+2s
    dance RH across
17-24::
    1M+2L cross LH & cast behind partners back to original places, 1s+2s
    dance LH across
25-32::
    1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (12402, '2019-12-05 01:30:41.64981+00', '2023-02-04 01:20:56.103533+00', 3698, 3, NULL, 'ace', '1-8::
    1s lead down & back
9-16::
    1s+2s dance RH across (3 bars), LH across (3 bars) & 1s cast to 2nd
    place as 2s dance up to top
17-24::
    1s+3s circle 4H round & back
25-32::
    2s+1s+3s dance reels of 3 on sides , 1L+2L & 1M+3M pass RSh to start
    (1L up, 1M down).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6103, '2013-08-21 08:31:18.968441+00', '2023-02-04 01:20:57.540426+00', 3729, 3, NULL, 'ace', '1-8::
    1s+2s walk RH across 1/2 way, set, walk RH across 1/2 way & set
9-16::
    1s+2s repeat above Fig
17-24::
    1s lead (walk) down to bottom & chasse back to top in allemande hold
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (9764, '2017-04-06 09:57:35.111239+00', '2023-02-04 01:20:57.566295+00', 3731, 3, NULL, 'ace', '1-8::
    1s set twice, cross RH, cast (2s step up 7-8)
9-16::
    1s dance Figs 8, 1L round 2s (pass 2L RSh) & 1M round 3s (pass 3M
    RSh).  1s end 2nd place opp sides
17-24::
    2s+1s+3s set twice, 1s turn 1.1/4 RH to finish 1L between 2s, 1M
    between 3s
25-32::
    Lines of 3 across set twice.  1s turn 1.1/4 RH to 2nd place own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (6111, '2013-08-21 08:31:19.041912+00', '2023-02-04 01:20:58.297379+00', 3747, 3, NULL, 'ace', '1-8::
    1s+2s also 4s+5s dance reel of 4 across (1L & 2M also 4L & 5M pass
    LSh to start), 1s & 5s ending in 2nd & 4th places
9-16::
    1s+3s+5s dance reel of 3 on sides (3s out & up to start)
17-24::
    1s+3s set & dance LH across 1/2 way, 5s dance 1/2 Diag R&L with
    their 1st corners
25-32::
    5s dance 1/2 Diag R&L with 2nd corners, 3s & 4s set & cross RH.  2 3
    4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (6112, '2013-08-21 08:31:19.050141+00', '2023-02-04 01:20:58.319635+00', 3748, 3, NULL, 'ace', '1-8::
    1s turn 1.1/2 RH, 1M+2M turns 1.1/2 LH into centre BtoB facing 2s
    (facing own partners) for reel of 4 across
9-16::
    1s+2s dance full reel of 4 ending with Men holding LH in centre with
    partners on RH
17-24::
    1s+2s Bal-in-Line, 1/2 turn partners RH, Bal-in-Line & turn to end
    with couples on sides with Ladies on partners right (2s on Ladies
    side)
25-32::
    1s with nearer hands joined lead down middle followed by 2s, cross
    (Ladies dancing under Men''s right arm) & 2s lead back to top', 0);
INSERT INTO 'dancecrib' VALUES (6113, '2013-08-21 08:31:19.058369+00', '2023-02-04 01:20:58.400004+00', 9193, 3, NULL, 'ace', '1-8::
    1s cross down RH & cast behind 3s, 1s dance to top & cast to 2nd
    place.  2(1)3
9-16::
    1s dance reflection reels on opposite sides (1s in & down to start)
    & 1s end facing 2nd corners
17-24::
    1s dance Pass+Turn with 2nd corners & turn RH to face 1st corners,
    1s dance Pass+Turn with 1st corners & 1s cross to 2nd place own
    sides.  2 1 3
25-32::
    All circle 6H round to left & left about turn to chase back', 0);
INSERT INTO 'dancecrib' VALUES (13255, '2020-10-16 00:20:43.273127+00', '2023-02-04 01:20:58.475817+00', 15248, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left; 1s+2s set down/up NHJ with partner,
    1s turn inwards, dance up & cast to 2nd place _while_ 2s dance up to
    1st place & face out
9-16::
    1s followed by 2s dance down, cast up round 3s, cross up LH & cast
    round 1st place,1s to 2nd place opp sides, 2s curve into 1st place
    opp sides
17-24::
    2s+1s Set+Link; 1s+2s dance 1/2 R&L
25-32::
    1s+3s dance Bourrel:
::
    _25-28_   1M+3L advancing, 3/4 turn 2H & twirl to end BtoB (Lady
    facing up & Man down) _while_ partners chase anticlockwise to face
    partner
::
    _29-32_   1s+3s set to partners & turn 2H to own sides having
    changed places.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (13998, '2021-05-03 00:20:24.48059+00', '2023-02-04 01:20:58.534345+00', 19979, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s
9-16::
    1s set, cross RH; 2s+1s dance RH across
17-24::
    1s lead down middle & back up to 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6121, '2013-08-21 08:31:19.142598+00', '2023-02-04 01:20:58.789799+00', 3762, 3, NULL, 'ace', '1-8::
    1L+4M advance towards each other, turn RH, turn LH & dance back to
    places
9-16::
    1M+4L repeat
17-20::
    2s+3s adv to ptnrs, 2s lead up & cross over to end BtoB between 1s
    as 3s dance down & cross over to end BtoB between 4s
21-24::
    All set, couples on Men''s side turn round by RH as couples on Ladies
    side turn round LH all end facing down
25-32::
    All dance down, individually turn Right about & dance up 1s+2s
    turning to Right to face 3s+4s
33-36::
    All set, 1s+4s change places RH (with partners) across the dance as
    2s+3s change places RH up/down dance
37-40::
    All set in lines across, 1s & 4s cross RH to original places _while_
    2s+3s dance RH across 1/2 way to original places
41-48::
    All set to partners, all cross RH, all set, 3s & 4s cross RH as
    1s+2s dance in for Allemande
49-56::
    1s+2s dance Allemande but 1s end by leading down & turning to face
    up above the 4s as 4s dance in (3s step up)
57-64::
    1s+4s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (6122, '2013-08-21 08:31:19.156648+00', '2023-02-04 01:20:58.97268+00', 3763, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back to places
9-16::
    1s lead down for 3 steps, back to top & cast to 2nd places on own
    sides
17-24::
    2s & 1s turn partner RH, turn partner LH', 0);
INSERT INTO 'dancecrib' VALUES (13179, '2020-09-15 00:20:28.894308+00', '2023-02-04 01:21:00.243575+00', 13215, 3, NULL, 'ace', '1-8::
    1s & 4s set, cast in 1 place (bars 3-4: 2s & 3s step down/up) &
    dance 1/2 Figs of 8 round end couples to finish in the middle (1s
    facing 2s diagonally up, 4s facing 3s diagonally down)
9-12::
    2M & 1L also 3L & 4M 1.1/2 turn RH _while_ 2L & 1M also 3M & 4L
    1.1/2 turn LH.  All finish on sides (1) 2 3 (4)
13-16::
    1s+4s set, cross RH, 1s face out 1 2 3 4
17-24::
    1s & 2s change places on sides (Ladies RH, Men LH), 1s repeat with
    3s using other hand; 1s repeat with 4s, 1s turn 2H in 4th place 2 3
    4 1
25-32::
    All set, circle left for 3 bars. On bar 30 dance into centre with
    left foot, pull back RSh & spiral out to chase clockwise to own
    sides 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6186, '2013-08-21 08:31:20.074976+00', '2023-02-04 01:21:03.732859+00', 3878, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back to places
9-16::
    1s cross RH, cast to 2nd place & turn RH
17-24::
    2s+1s+3s circle 6H round & back
25-32::
    1s cross LH, cast to bottom & 1s turn LH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6147, '2013-08-21 08:31:19.557776+00', '2023-02-04 01:21:01.145415+00', 8519, 3, NULL, 'ace', '1-8::
    1s set, dance down NHJ for 2 steps, dance up (2 steps) & cast to 2nd
    place (2s step up 7-8)
9-16::
    1s dance Diag R&L (RH to 1st corner to start) & end facing 4th
    corner (pstn)
17-24::
    1s dance diagonal RSh reel with 4th corners, Bars 23-24: 1s 1/2 turn
    LH finishing side by side in middle facing opp sides _while_ corners
    finish reel
25-32::
    1s dance RH across (1L with 2s & 1M with 3s), 1s pass RSh to dance
    LH across with other couple. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12140, '2019-09-02 16:35:03.485639+00', '2023-02-04 01:21:01.206009+00', 19595, 3, NULL, 'ace', '1-8::
    1s turn 1.1/4 RH to finish 1M behind 1L facing down. 1L followed by
    partner dances 1/2 Fig of 8 round 2M to end 1L between 2s
9-16::
    1L joins NH with 2s & dances down middle with 1M following, all turn
    by right to face up, 1M picks up 2s to dance back up to top with 1L
    following
17-24::
    1M followed by 1L casts round 2L then 1L dances down round 3L
    _while_ 1M dances up round 2M, both finishing in 2nd place own side
25-32::
    1s+3s dance R&L. End  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6150, '2013-08-21 08:31:19.584884+00', '2023-02-04 01:21:01.578463+00', 3798, 3, NULL, 'ace', '1-8::
    1s & 3s set, cast (2s & 4s step up) & all dance RH across - 1L+2s
    (at top), 1M+3L+4s (middle), 3M+5s (bottom), 1s & 3s end facing 1st
    corners
9-16::
    1s & 3s dance 1/2 diagonal reels of 4 with 1st corners, pass partner
    RSh & dance 1/2 reel of 4 with 2nd corners
17-24::
    1s & 3s dance 1/2 reels of 4 with 3rd corners & 1/2 reels of 4 with
    4th corners, 1s & 3s end in centre facing partners (Men facing down)
25-32::
    1s+3s dance reel of 4 _while_ others chase clockwise 4 places to own
    side (2s in 1st place, 4s in 3rd, 5s in 5th) 1s & 3s end in middle
    BtoB with partner facing own sides ready for ….
33-40::
    1s & 3s dance Double Triangles, bars 39-40 1s & 3s petronella turn
    to 3rd/5th place _while_ 4s & 5s dance up to 2nd/4th (PdB).  End 2 4
    1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (6158, '2013-08-21 08:31:19.821728+00', '2023-02-04 01:21:01.994856+00', 3814, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Grand Chain 1/2 way turning 3rd person RH once round
    & repeat back to places
9-16::
    1s & 3s 3/4 turn RH & 1M+3L turn LH _while_ partners set, 1s & 3s
    3/4 turn RH to opposite sides _while_ 2s set & cross RH
17-24::
    1s+2s+3s dance reels of 3 on sides each person crossing to own side
    from top place (1s cross down to start) 1s & 2s continue reel to
    change pls
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6163, '2013-08-21 08:31:19.877738+00', '2023-02-04 01:21:02.422322+00', 3829, 3, NULL, 'ace', '1-8::
    1s & 3s set, cast 1 place & turn LH
9-16::
    1s & 3s dance, 1L reel of 3 with 2s (LSh to 2M) - 1M+3L reel of 4
    with 4s (pass LSh & give RSh to 4s) - 3M with 5s (LSh to 5L)
17-24::
    All dance RH across with same couples, 1s & 3s pass partners RSh to
    dance LH across with other couples
25-32::
    1s & 3s turn 1st corners RH, partners LH, 2nd corners RH & pass
    partners LSh to end BtoB facing own sides
33-40::
    1s & 3s dance Double Triangles & end 2nd/4th places own sides facing
    out
41-48::
    1s+3s cast round 3rd corners to face each other in centre, 3/4 turn
    partner RH & cast down 1 place', 0);
INSERT INTO 'dancecrib' VALUES (9480, '2016-11-09 08:48:41.053414+00', '2023-02-04 01:21:02.991144+00', 16144, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up) & 1s turn 2H to face 1st corners
9-12::
    1s+1st corners change places RH, 1st corners change places LH
    _while_ 1s loops round corner place, then 1s+1st corners change
    places RH. 1s pass RSh to face 2nd corners
13-16::
    1s+2nd corners repeat 9-12 with 1s passing RSh to end in centre
    facing own sides  (3) 1 (2)
17-24::
    1s dance Figs 8 on own side (1L+2M & 1M+3L pass RSh).  1s dancing
    across to end in 2nd place opp sides
25-32::
    3s+1s+2s dance Set+Link for 3 twice  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6174, '2013-08-21 08:31:19.971371+00', '2023-02-04 01:21:03.152005+00', 3854, 3, NULL, 'ace', '1-8::
    1s dance down for 3 & 1M swings his partner round in front of him &
    they dance up on opp sides, 2s face top with inner arm on hip which
    1s link & turn to change pl
9-16::
    2s+1s dance R&L
17-24::
    2s+1s dance Ladies Chain
25-32::
    1s set, 4 spring points & set, cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6177, '2013-08-21 08:31:19.997739+00', '2023-02-04 01:21:03.337245+00', 3861, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place (2s step up); 1s turn LH 1.3/4 times to
    face 1st corners
9-16::
    1s dance reels of 3 on opposite sides giving LSh to 1st corner
17-24::
    1s dance reels of 3 across (Lady with 2s & Man with 3s) giving RSh
    to 4th corner, Bars 23-24 1s cross to 2nd place own side
25-32::
    2s+1s+3s circle 6H round to left; 2s+1s+3s dance LH across', 0);
INSERT INTO 'dancecrib' VALUES (6178, '2013-08-21 08:31:20.007607+00', '2023-02-04 01:21:03.435598+00', 3862, 3, NULL, 'ace', '1-8::
    1s lead down, 1/2 turn RH, lead up to 2nd places opposite sides
9-16::
    1s+2s dance Ladies Chain
17-24::
    2M+1L followed by 1M+2L Promenade & end with 1M dancing to own
    partner as 2M casts to 2nd place to meet his partner
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6179, '2013-08-21 08:31:20.015863+00', '2023-02-04 01:21:03.459244+00', 3864, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH _while_ 2s set, 1s dance reels of 3 on side with
    2s+3s (1s dance out & down to start)
9-16::
    1s & 3s set to partners _while_ 2s cross RH, 1s dance reels of 3 on
    sides with 2s+3s (1s in & down to start)
17-24::
    1M+2L cross RH & set _while_ 1L+2M set & cross RH, 1s turn 2H 1.1/2
    times
25-32::
    1M+3L cross RH & set _while_ 1L+3M set & cross RH & all turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (6183, '2013-08-21 08:31:20.050283+00', '2023-02-04 01:21:03.546602+00', 3870, 3, NULL, 'ace', '{{explanation}}
Circle with Lady on Man''s right

1-8::
    All circle round to left (4 bars) and back to the right (4 bars)
9-16::
    All turn partners RH, all turn partners LH & end facing »corner«
    person
17-24::
    All turn corners RH, all turn corners LH & end joining hands with
    »corner« in Promenade hold facing anticlockwise (Lady on Man''s
    right)
25-32::
    All Promenade round to finish in circle', 0);
INSERT INTO 'dancecrib' VALUES (9015, '2015-11-30 08:59:58.764594+00', '2023-02-04 01:21:03.842378+00', 10905, 3, NULL, 'ace', '1-8::
    All Ladies dance round prtnr RSh, face prtnr & turn RH back to place
9-16::
    Men repeat bars 1-8, passing Ladies LSh & turning LH
17-24::
    1s, followed by 2s+3s+4s, dance down NHJ & cast back to places
25-32::
    1s turn RH, cast to 4th place (2s+3s+4s step up 27-28).  1s turn 2H
    (4 bars)', 0);
INSERT INTO 'dancecrib' VALUES (6207, '2013-08-21 08:31:20.469198+00', '2023-02-04 01:21:05.56195+00', 7545, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & cross RH, all set & 2s+3s cross LH _while_ 1s 1/2
    turn LH to face down
9-16::
    1s dance down, dance up between 3s & behind 2s to top
17-24::
    1s dance reflection reels of 3 on own sides (dancing between 2s to
    start) & end turning 2s with nearer hand into double triangle
    positions
25-32::
    All set & 1s turn 3rd corners RH & pass each other RSh to 2nd place
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (6219, '2013-08-21 08:31:20.579146+00', '2023-02-04 01:21:06.162739+00', 3935, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s set, turn RH, cast in 1 place & 1/2 turn RH into prom hold
    (Lady on left) to face 2L/3L
9-16::
    1s+4s dance Pass+Turn with 2L+3L & Pass+Turn with 2M+3M ending 1s
    between 2s facing down & 4s between 3s facing up
17-24::
    All set in lines of 4 & 1s+4s change places LH with opposite
    partner, 4s & 1s lead out ends crossing RH & cast back to 2nd/3rd
    places
25-32::
    1s+4s change pl LH on sides dancing into centre, 1s & 4s lead out
    ends cross & cast (1s own sides, 4s opp sides) & dance 1/2 RH
    across.  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (6220, '2013-08-21 08:31:20.589126+00', '2023-02-04 01:21:06.236562+00', 3938, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s then 1/2 Fig of 8 round 3s ending in
    2nd place
9-16::
    2s repeat above Fig (ie dance 1/2 Fig of 8 round 1s then 1/2 Fig of
    8 round 3s ending in 2nd place)
17-24::
    1s+2s dance 1/2 R&L, set & cross RH
25-32::
    2s set & cast to 2nd place then 1s set & cast back to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6228, '2013-08-21 08:31:20.855808+00', '2023-02-04 01:21:07.068774+00', 7811, 3, NULL, 'ace', '1-8::
    1s lead down middle for 3 bars, back up to top & cast to 2nd place
9-16::
    1s+3s dance RH across once round, 3L followed by 1L dance down
    behind 4L & up between 4s _while_ 1M followed by 3M dances up behind
    2M & down between 2s, 1M+3L pass RSh & turn singly to face each
    other (up/down) as 1L & 3M turn right about to face ends (BtoB with
    partner)
17-24::
    1L+4s, 3M+2s join hands (as in double triangles), 1M+3L (face each
    other) & all set, all set again as 1s+3s (BtoB with partner) set
    rotating 1/2 way round to Right to change positions; 1M+4s, 3L+2s &
    1L+3M set, 1s & 3s dance petronella turn to own sides _while_ 2s &
    4s continue setting & all face in
25-32::
    1s dance 1/2 Fig of 8 up round 3s & cast to 4th place; 1s advance,
    change places & retire', 0);
INSERT INTO 'dancecrib' VALUES (6231, '2013-08-21 08:31:20.880763+00', '2023-02-04 01:21:07.183707+00', 11525, 3, NULL, 'ace', '1-8::
    All dance Grand Chain
9-16::
    1s dance Inveran reels with 2s+3s
17-24::
    1s cross RH, cast to 3rd place & turn 2H 1.1/2 times
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9209, '2016-06-16 22:42:02.995226+00', '2023-02-04 01:21:07.209373+00', 16276, 3, NULL, 'ace', '1-4::
    All 1/2 turn partners RH, turn Right about & dance out to opp sides
5-8::
    All turn partners 2H 1.1/2 times
9-16::
    1s+3s dance Double Fig 8 round 2s (1s cast, 3s cross up).  2s step
    up bars 15-16.  End 2 1 3 all in middle in promenade hold
17-24::
    2s+1s+3s promenade
25-32::
    2s+1s+3s dance the Knot
33-40::
    All circle 6H round and back    End  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6241, '2013-08-21 08:31:20.997225+00', '2023-02-04 01:21:07.803571+00', 9740, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, turn 1.1/2 times & end in middle facing
    down
9-16::
    2s+1s+3s dance reflection reels on own sides 1s dancing between 3s
    to start
17-24::
    1s dance ''Hello-Goodbye'' setting & end BtoB (Man facing up)
25-32::
    1s dance reels of 3 across giving RSh to 2nd corners & 1s end in 2nd
    place', 0);
INSERT INTO 'dancecrib' VALUES (6353, '2013-08-21 08:31:22.976363+00', '2023-02-04 01:21:08.931061+00', 4026, 3, NULL, 'ace', '1-8::
    All dance 1/2 Ladies Chain & RH across once round
9-16::
    All dance LH across & 1/2 Ladies Chain
17-24::
    Set HS to partner (2 bars right foot only), 1/2 turn LH, set HS
    (Left foot only) & 1/2 turn RH
25-32::
    All dance the Rondel to face new couple (couples facing clockwise
    dance under arch made by other couple)', 0);
INSERT INTO 'dancecrib' VALUES (6361, '2013-08-21 08:31:23.050838+00', '2023-02-04 01:21:09.195651+00', 4048, 3, NULL, 'ace', '1-8::
    1s & 3s set to partners, set to opposite person & dance LH across
    (1.1/4 times) to end facing side couples (1s face 4s with Man facing
    Man)
9-16::
    All set & change places RH with opposite person, repeat with LH &
    retain hand to form St Andrews Cross (1s+3s RH in middle)
17-24::
    All set, 1s & 3s retain partner''s hand, dance RH across once round &
    turn to end in prom hold in original places _while_ 2s & 4s set
    again & turn RH into prom hold & all face anticlockwise
25-32::
    All Promenade round back to original places & all set
33-40::
    1s+3s change places with 3s making an arch & set, repeat with 1s
    making an arch
41-48::
    All circle 8H round & back

{{explanation}}
Repeat with 2s & 4s leading', 0);
INSERT INTO 'dancecrib' VALUES (13264, '2020-10-16 00:20:53.023612+00', '2023-02-04 01:21:09.825626+00', 16474, 3, NULL, 'ace', '1-8::
    1s+3s set to partner & turn RH; all turn corner LH to end with
    Ladies facing out
9-24::
    All dance Schiehallion Reel back to place
25-32::
    All turn partner RH into Allemande hold facing clockwise; all
    promenade 3/4 round (3 places). End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14210, '2021-08-14 00:20:45.670724+00', '2023-02-04 01:21:10.149536+00', 17659, 3, NULL, 'ace', '1-8::
    All 3 couples join hands on the sides & set, cross RH; All 3 couples
    set and turn partner 1/2 RH into Allemande hold facing up
9-16::
    All 3 couples dance Allemande.  3 2 1
17-24::
    3s+2s (top couples) dance Set+Link & circle 4H once round to the
    left. 2 3 1
25-32::
    3s+1s (bottom couples) dance Poussette. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6265, '2013-08-21 08:31:21.518115+00', '2023-02-04 01:21:10.781395+00', 4092, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s+3s (own sides) giving RSh to 2s
9-16::
    1s+2s Adv+Ret & dance RH across
17-24::
    1s followed by 2s lead down & 2s lead back followed by 1s end facing
    1st corners
25-32::
    1s turn 1st corners RH, partner LH, 2nd corner RH & cross LH to 2nd
    place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13265, '2020-10-16 00:20:54.903744+00', '2023-02-04 01:21:12.038369+00', 17623, 3, NULL, 'ace', '1-8::
    1L+2M dance DoSiDo; 1L+2M turn RH
9-16::
    1M+2L dance DoSiDo; 1M+2L turn RH
17-24::
    1s dance Fig 8 found 2s
25-32::
    1s followed by 2s dance down NH joined; 2s followed by 1s dance up
    to end 2s in 1st place, 1s in 2nd place

{{explanation}}
Note:	May also be danced as reel', 0);
INSERT INTO 'dancecrib' VALUES (11203, '2018-09-30 22:20:08.730173+00', '2023-02-04 01:21:12.529123+00', 18654, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides.  2 1 3
9-16::
    1L+2s also 1M+3s dance RH across; 2s+1s+3s turn LH & 1s end in 2nd
    place side by side facing up
17-24::
    1s dance Fig of 8 on own sides _while_ 2s+3s dance R&L (RH on sides
    to start) & 1s end facing 1st corners
25-32::
    1s dance 1/2 diagonal reel of 4 with 1st corners, 1s dance 1/2
    diagonal reel with 2nd corners
33-40::
    1s dance 1/2 diagonal reel with 3rd corner (pstns), 1/2 diagonal
    reel with 4th corner (pstns)', 0);
INSERT INTO 'dancecrib' VALUES (6299, '2013-08-21 08:31:22.158888+00', '2023-02-04 01:21:13.201491+00', 7288, 3, NULL, 'ace', '1-8::
    1s & 3s set, turn partners RH 1.1/2 times to face out on opposite
    sides & all Bal-in-Line
9-16::
    1s+2s+3s dance 1/2 reels of 3 on sides (RSh to 1st corner to start),
    2s & 4s turn partners RH 1.1/2 times.  (3)(2)(1)(4)
17-24::
    All set & cast 1 place clockwise, middle dancers (4L+1L & 2M+3M)
    dance 1/2 R&L
25-32::
    All set & cast 1 place clockwise, 2s+3s also 4s+1s dance RH across.
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6304, '2013-08-21 08:31:22.218555+00', '2023-02-04 01:21:13.407954+00', 4179, 3, NULL, 'ace', '1-8::
    1s+2s set twice, 1M+2L also 1L+2M turn RH & return to places (1M
    crosses behind 1L to start)
9-16::
    1s set twice to 2s on sides & turn (passing between 2s)
17-24::
    1s dance Inveran Reels with 2s+3s
25-32::
    1s+2s dance a Half Rondel:
::
    1s dance down under the arch made by 2s who dance up, Ladies cross
    in front of Men & all cast to meet the other Lady or Man on the
    opposite side & join nearer hands, set on opposite sides of the
    dance & cross LH back to own sides', 4);
INSERT INTO 'dancecrib' VALUES (10447, '2018-02-24 07:52:55.234875+00', '2023-02-04 01:21:14.058703+00', 15768, 3, NULL, 'ace', '1-8::
    1s dance in & cast off one place (2s step up 3-4). 1s dance 1/2 Fig
    of 8 round 2s
9-16::
    2s+1s+3s set and cross RH, set & cross RH
17-24::
    2s+1s+3s chase clockwise 1/2 round & dance DoSiDo with partner (3) 1
    (2)
25-28::
    1s dance 1/2 diag R&L with 3L & 2M (1M down, 1L up)
29-32::
    1s dance 1/2 diag R&L with 3M & 2L (1M down, 1L up)', 0);
INSERT INTO 'dancecrib' VALUES (6326, '2013-08-21 08:31:22.499478+00', '2023-02-04 01:21:14.432672+00', 14349, 3, NULL, 'ace', '1-8::
    1s set & cross down to 2nd place, 1s cast round 1st corners & dance
    down/up middle & turn right about to end BtoB with partner
9-16::
    1s dance out through the ends & cast round 4th corner & turn right
    about to end BtoB with partner in middle _while_ 2s+3s set &
    Adv+Ret. all set as in double triangles
17-24::
    1s dance out & cast round 3rd corners & dance down/up middle & turn
    right about to end BtoB with partner _while_ 2s+3s set & Adv+Ret up/
    down set, all set as in double triangles
25-32::
    1s dance reels of 3 on opposite sides passing 2nd corner RSh & 1s
    cross RH', 0);
INSERT INTO 'dancecrib' VALUES (8064, '2013-10-01 08:47:07.724697+00', '2023-02-04 01:21:14.906666+00', 15138, 3, NULL, 'ace', '1-8::
    All dance 1/2 Grand Chain (2 bars per hand) to end in diagonally
    opposite positions
9-16::
    All set HS, all turn 2H 1.1/4 times to end in centre with Ladies
    facing down & Men up
17-24::
    4s+3s also 2s+1s, dance Highland Schottische poussette & end final
    turn by joining hands in 2 circles
25-32::
    All circle 4H round; 2s dance up to 1st place as 3s, 4s & 1s step
    down on bars 31-32.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6338, '2013-08-21 08:31:22.684032+00', '2023-02-04 01:21:15.272027+00', 11283, 3, NULL, 'ace', '1-8::
    1L+2M turn 2H, 1M+2L turn 1.1/4 2H & end in middle facing own
    partner
9-12::
    1s & 2s 1/2 turn partners 2H (1 bar) & 1M+1L NHJ dance down sideline
    _while_ 2L+2M NHJ dance up sideline (1 bar) fowing into 1s+2s circle
    4H 1/2  round. Men face down, Ladies face up, NHJ
13-16::
    1s & 2s Set+Link across to end 1L facing down, 2M facing up
17-20::
    1M+2L dance DoSiDo _while_ 1L+2M dance clockwise 1 place round into
    centre facing partner & advance as they retire, all in line on 2nd
    corner diagonal
21-24::
    1s+2s dance 1/2 diagonal reel of 4
25-32::
    2s & 1s pivot into place to dance a Diamond Poussette right round  2
    1', 0);
INSERT INTO 'dancecrib' VALUES (6339, '2013-08-21 08:31:22.691987+00', '2023-02-04 01:21:15.325816+00', 4239, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reels of 3 on own sides
17-24::
    1s cross RH, cast to 2nd place & dance 1/2 Fig of 8 round 2s
25-32::
    1s dance down between the 3s, cast up to 2nd place & 2s+1s+3s turn
    partners RH', 0);
INSERT INTO 'dancecrib' VALUES (13267, '2020-10-16 00:20:57.751457+00', '2023-02-04 01:21:15.675303+00', 16160, 3, NULL, 'ace', '1-8::
    1M followed by 1L dances Fig 8 round 3s (RSh to 3M to start). 1s end
    facing 2M
9-16::
    1M dances Fig 8 round 2M & 3M (LSh to 2M) _while_ 1L+2M turn RH;
    1L+3M turn 3/4 LH to end 1L followed by 1M facing 2L
17-24::
    1L dances Fig 8 round 2L & 3L (RSh to 2L) _while_ 1M+2L turn LH;
    1M+3L turn 3/4 RH to end 1s facing 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting ending with Petronella turn to 2nd
    place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6344, '2013-08-21 08:31:22.807496+00', '2023-02-04 01:21:15.701714+00', 4248, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place & turn LH to face 1st corners
9-16::
    1s dance 1/2 diagonal reels of 4 with 1st corners & 1/2 reel of 4
    with 2nd corners ending 2nd place opposite sides (3)(1)(2)
17-24::
    1s set & petronella turn to centre as 2s+3s petronella turn to
    centre & set (3L+2M change places when setting), 1s+2s+3s repeat to
    sides
25-32::
    1s+2s+3s repeat bars 17-24 (3M+2L change places when setting), 1s
    end dancing into centre & individually turn 1/4 right ready for …
33-40::
    1L with 2s also 1M with 3s dance RH across, 1s pass RSh to dance LH
    across with other couple.End  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8785, '2015-06-15 11:40:57.721301+00', '2023-02-04 01:21:16.527242+00', 16219, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    _4_ couples petronella-in-tandem & set twice
9-16::
    1s & 3s Adv turning to face partner, set & turn partners 2H to
    finish in lines of 4 across
17-24::
    1s+3s dance reel of 4 across
25-32::
    1M+3L dance out between 2s (4th pl), cross & cast to original places
    _while_ 1L+3M dance similarly between 4s (2nd pl). 1s & 3s turn
    partners RH
33-56::
    2s & 4s repeat bars 9-32
57-64::
    All circle 8H round and back

{{title}}
Reel

{{explanation}}
Repeat bars 1-64', 0);
INSERT INTO 'dancecrib' VALUES (6371, '2013-08-21 08:31:23.152123+00', '2023-02-04 01:21:16.721158+00', 4293, 3, NULL, 'ace', '1-8::
    1M turns 2L RH, 2M turns 1L RH 1.1/2 times ending in centre in line
    across with original partners
9-16::
    1s+2s dance down the middle, turn to right & dance back to top
17-24::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6373, '2013-08-21 08:31:23.251518+00', '2023-02-04 01:21:16.818083+00', 4300, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s who set twice pivoting (1L to left,
    1M to right) to face person dancing round them, 1s+2s set & cross
    RH.  1(2)
9-16::
    1s+2s dance the Swirl:
::
    Turn partner RH into Allemande hold & dance LSh round other couple
    1/2 way, dance LH across & swirl to face partners.  (2)1
17-24::
    1s+2s set & cross RH, 1s+2s dance RH across.  2(1))
25-32::
    1s dance 1/2 Fig of 8 round 2s, 1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (6388, '2013-08-21 08:31:23.404032+00', '2023-02-04 01:21:17.983659+00', 4325, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place (2s step up), 1s turn LH & cast to 3rd
    place (3s step up)
9-16::
    1s lead down the middle (3s step down) & back to face 1st corners
17-24::
    1s set to & turn 1st corners, set to & turn 2nd corners ending in
    2nd place opposite sides
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners, 1s
    cross RH to own sides bars 31-32', 0);
INSERT INTO 'dancecrib' VALUES (6396, '2013-08-21 08:31:23.476304+00', '2023-02-04 01:21:18.518557+00', 4356, 3, NULL, 'ace', '1-8::
    1s cast to bottom, turn out & cast up to top
9-16::
    1s lead down the middle & up to top
17-24::
    1s+2s dance Poussette 1s end facing 1st corners
25-32::
    1s turn 1st corners RH, partners LH, 2nd corners RH & partner LH to
    places
33-40::
    2s+1s circle 4H round to left 1/2 way, 1s+2s dance 1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (10383, '2018-01-17 20:31:05.176734+00', '2023-02-04 01:21:19.470818+00', 4384, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH moving down in centre (2s step up). 1s drop hands,
    set & cross LH, dance out of sides and cast Left (1M round 3M, 1L
    round 2L) & pass LSh to face 2nd corners
9-16::
    1s dance diag reel of 4 with 2nd corners _while_ 1st corners dance
    track of diag reel of 4 (2s+3s brief LH across in centre). 1s pass
    LSh to face 1st corners
17-24::
    1s repeat diag reels of 4 with 1st corners _while_ 2nd corners dance
    track of diag reel of 4 (2s+3s brief LH across in centre). 1s pass
    LSh to face out in 2nd place own side
25-32::
    Reels of 3 across (1M+3s, 1L+2s) 1M+3M & 1L+2L pass LSh to start &
    corners pass partner RSh in centre.  1s end 2nd place own side.  2 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (6407, '2013-08-21 08:31:23.834158+00', '2023-02-04 01:21:19.492324+00', 4388, 3, NULL, 'ace', '1-8::
    1s+3s dance double Fig of 8 around 2s, 1s crossing down to start
9-16::
    1s+2s dance the Knot, 1s end facing 1st corners
17-24::
    1s dance 1/2 RH across (1L+2s & 1M+3s), 2s+3s dance 1/2 LH across
    _while_ 1s chase 1/4 clockwise, all 3 Ladies & all 3 Men dance 1/2
    RH across, 1s turn 1.1/4 LH to face 1st corners
25-32::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners & 1s pass RSh to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (14668, '2022-03-07 02:20:45.918486+00', '2023-02-04 01:21:19.519866+00', 20399, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back.
9-16::
    1s lead down and back, finishing in the centre in 1st place
17-24::
    1s dance in & cast (2s step up) and turn LH 1.1/4 into lines of 3
    across, 1L between 2s, 1M between 3s, facing 1st corners
25-32::
    All dance reels of 3 across (1s giving LSh to 1st corners), 1s
    finish in 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10629, '2018-04-16 21:42:14.87565+00', '2023-02-04 01:21:19.775712+00', 4401, 3, NULL, 'ace', '1-4::
    1s turn 2H (2 bars), 1s cross RH _while_ 2s turn once 2H
5-8::
    3s & 4s repeat bars 1-4 _while_ 1s+2s circle 4H round to Left.  End
    (1) 2 (3) 4
9-12::
    Grand Chain (3 hands - 1 bar per hand, 1s & 4s cross with partner,
    2s & 3s on side to start), Men pull back RSh to form circle (bar
    12),
13-16::
    All circle 8H 1/2  round to Left (stay in circle)
17-24::
    Ladies change places LH with Man on their Left, polite turn to face
    in, all circle 8H 2 places round to Right (2 bars); Repeat these 4
    bars.  4 (2) 3 (1)
25-28::
    4s+2s also  3s+1s dance 1/2 R&L (2 bars), 2s+1s turn 2H once _while_
    4s & 3s cross RH, all to own sides
29-32::
    2s stand at top _while_ 4s+1s+3s circle 6H hands 1/2 round to Left
    (2 bars), 1s+4s continue circle 4H 1/2 round to Left _while_ 3s
    cross RH. End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13269, '2020-10-16 00:21:01.558492+00', '2023-02-04 01:21:20.213651+00', 14987, 3, NULL, 'ace', '1-8::
    1s lead down (2s step up 3-4); 1s lead up (2 bars) to above 3s; &
    turn RH into prom hold facing up
9-16::
    1s+3s dance reel of 3 across (1s LSh to 3M). Bar 16: 2s dance in
    (above 1s) & 3s dance in (behind 1s), all face up in prom hold
17-24::
    2s+1s+3s dance Allemande, 1s Petronella turn to end 1L between 3s
    (at top) facing down, 1M between 2s facing up
25-32::
    All set, all Adv+Ret (1 step each), all change places RH with person
    opposite & 1s Petronella turn to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14293, '2021-09-08 00:20:50.508693+00', '2023-02-04 01:21:20.384713+00', 20211, 3, NULL, 'ace', '1-8::
    1s dance in, cast (2s step up); 1s turn 1.1/4 RH
9-16::
    1M+2s & 1L+3s dance RH across; 2s+1s+3s Adv+Ret
17-24::
    1s dance down middle & back up to 2nd place
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8340, '2014-07-29 12:59:16.54044+00', '2023-02-04 01:21:20.722802+00', 15140, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 R&L, all cross RH & all set (1s facing 2s
    also 3s facing 4s)
9-16::
    All dance reels of 4 on sides
17-24::
    1s+4s set, turn partners 2H & circle 4H round to left
25-32::
    1s+4s dance 1/2 diamond Poussette, 1s+3s dance 1/2 diamond Poussette
33-40::
    2s & 1s (top & bottom couples) cross RH _while_ 4s+3s (middle
    couples) dance RH across 1/2 way. All set & cross RH. All couples
    set.   2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6437, '2013-08-21 08:31:24.275828+00', '2023-02-04 01:21:21.994504+00', 4450, 3, NULL, 'ace', '1-8::
    1M casts & turns 3L L H to end in 2nd place opposite side, 1L casts
    & turns 3M RH to end in 2nd place opposite side
9-16::
    2s+1s dance RH across, 1s+3s dance LH across & 1s end facing 1st
    corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners &
    cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6438, '2013-08-21 08:31:24.285486+00', '2023-02-04 01:21:22.089952+00', 4451, 3, NULL, 'ace', '1-8::
    1M+2L cross RH, 1L+2M cross RH, 1M+3M cross RH & 1L+3L cross RH
9-16::
    2s+3s+1s set twice, 2s+3s dance 1/2 R&L _while_ 1s turn 2H
17-24::
    1s dance reels of 3 on own sides (3s RSh to 2s to start)
25-32::
    1s followed by 2s+3s cast up to top, 1s cast to 2nd place & 2s+1s+3s
    turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (12411, '2019-12-05 01:31:04.726316+00', '2023-02-04 01:21:23.321353+00', 4487, 3, NULL, 'ace', '1-8::
    1s+2s Advance & 1/2 turn partner 2H; Retire to opp sides & 1s+2s
    change places LH on side
9-16::
    1s+3s repeat bars 1-8 (1s Retiring to own side)  (2) (3)  1
17-24::
    1s followed by 3s+2s lead down, on 4th step 1s turn 1/2  RH to face
    up; 3s+2s divide & 1s lead up followed by 2s+3s, all cross & dance
    out to own sides. 1 2 3
25-32::
    1s+2s dance 1/2 R&L; 2s+1s set & cross RH with partner to own side.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6460, '2013-08-21 08:31:24.592857+00', '2023-02-04 01:21:24.006749+00', 11528, 3, NULL, 'ace', '1-8::
    1s & 4s dance in, cast in 1 place & turn partners RH
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1s & 4s dance Figs of 8 round 2s/3s
25-32::
    1s+4s dance Espagnole:
::
    _25-26_   1s+4s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _27-28_   1s+4s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _28-32_   4s turn RH as 1s turn LH
33-40::
    All circle 8H round & back.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6464, '2013-08-21 08:31:24.639636+00', '2023-02-04 01:21:24.412855+00', 4518, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH, set & cross RH back to places
9-16::
    1s+2s dance RH across for 3 steps & LH back, 1s cast to 2nd place
17-24::
    1s cross RH, cast up, cross LH & cast back to 2nd places
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6469, '2013-08-21 08:31:24.68011+00', '2023-02-04 01:21:24.568965+00', 9575, 3, NULL, 'ace', '1-8::
    1s cast to bottom, turn out & cast back to places
9-16::
    1s+2s+3s dance reflection reels on own sides
17-24::
    1s cross RH, cast 1 place, cross LH & cast to bottom
25-32::
    4s+1s dance RH across & LH back to places', 0);
INSERT INTO 'dancecrib' VALUES (6483, '2013-08-21 08:31:24.9423+00', '2023-02-04 01:21:25.318632+00', 4563, 3, NULL, 'ace', '1-8::
    1L+2M also 1M+2L turn RH 1s end in middle facing each other
    (up/down) & set, 3/4 turn RH to both face down Lady on mans right
9-12::
    1s lead down, 1M leaves ptnr face out below 3s on Ladies side & with
    3L dances up to top & both face own sides as 1L dances to left to
    face in
13-16::
    3M+1L dance up above 1st pl as 1M+3Ls dance round to 1st pl, 3M with
    own ptnr dances down middle to orig pl as 1L dances round to own pl
17-24::
    1s set, cast 1 place to face 1st corners, set to 1st corners, set to
    2nd corners
25-32::
    1s dance down the middle below 3s, cast up to 2nd place on opposite
    sides, lead up to top & cast to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (6494, '2013-08-21 08:31:25.328486+00', '2023-02-04 01:21:25.933992+00', 1232, 3, NULL, 'ace', '1-8::
    1L+2M set & cast (Lady down & Man up) as 1M & 2L step down/up, 1L+2M
    turn 2H
9-16::
    1M+2L repeat back to original places
17-24::
    1s dance Fig of 8 round 2s
25-32::
    1s+2s dance ''Divided Knot: 1s+2s set & 1/2 turn prtnrs 2H to face
    down, 2s cast up to 1st pl as 1s dance dn & cast to 2nd pl & 2s+1s
    cross RH', 0);
INSERT INTO 'dancecrib' VALUES (6495, '2013-08-21 08:31:25.336606+00', '2023-02-04 01:21:25.95461+00', 4585, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret (diagonally & touching hands) & dance RH across
9-16::
    Repeat but dancing LH across
17-24::
    1s+2s dance double Fig of 8 (1s cast to start)
25-32::
    1s cast 1 place, turn RH, lead up & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (6496, '2013-08-21 08:31:25.350533+00', '2023-02-04 01:21:26.093069+00', 4595, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH, set & cross back RH
9-16::
    1s+2s dance RH across & LH across back
17-24::
    1s lead down the middle & back to face 1st corners
25-32::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partner LH to
    places', 0);
INSERT INTO 'dancecrib' VALUES (11470, '2019-01-01 01:57:54.150087+00', '2023-02-04 01:22:31.860302+00', 18974, 3, NULL, 'ace', '1-8::
    All dance 4 couple Knot.
9-16::
    All chase clockwise 1/2 way, turn partners LH & set
17-24::
    1s followed by 2s lead down to bottom _while_ 3s+4s cast up 2
    places, 3s+4s also 2s+1s dance RH across
25-32::
    All circle 8H round & back.  3 4 2 1', 0);
INSERT INTO 'dancecrib' VALUES (11052, '2018-08-31 15:49:36.451225+00', '2023-02-04 01:21:26.348323+00', 14117, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 2 places, meet below 3s & lead up to finish in
    centre BtoB facing partner''s side (2s step up on 3-4)
9-20::
    1s, 2s & 3s dance ''Half-Crown Triangles'':
::
    _9-10_    1L with 2M+3M & 1M with 2L+3L form triangle & set
::
    _11-12_   1s change places with dancer on right who dance in passing
    LSh to BtoB in centre, 3L facing up and 2M facing down.
::
    _13-14_    All set
::
    _15-16_    2M & 3L change places with dancer on right who pass LSh
    to finish BtoB facing their partner''s side.
::
    _17-18_    All Set
::
    _19-20_    3M & 2L change places with 1s who pass LSh to finish
    facing 2nd corner position
21-28::
    1s+corners dance 1/2 diag reel of 4, 1s pass RSh  & dance 1/2 reels
    of 3 across - 1L RSh to 2M & 1M RSh to 3L. 1s end in 2nd place own
    side
29-32::
    2s+1s+3s turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (6513, '2013-08-21 08:31:25.604273+00', '2023-02-04 01:21:26.920579+00', 8246, 3, NULL, 'ace', '1-16::
    1s set & cast 1 place, top 3 Men & bottom 3 Ladies dance 3 couple
    Diag R&L
17-24::
    Top 3 Ladies & bottom 3 Men dance interlocking reels of 3 on
    Diagonal between 1L & 4M positions with outer 2 dancers (1L+2L also
    3M+4M at start) passing LSh & centre dancers (2M+3L at start)
    turning RH into their reels of 3, all end on sides
25-32::
    1s+3s dance RH across 1/2 way then 1s+4s dance LH across 1/2 way,
    all set & turn RH to own sides.
33-40::
    All circle 8H round & back.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6514, '2013-08-21 08:31:25.614119+00', '2023-02-04 01:21:26.955553+00', 4634, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s cross RH & cast in 1 place, 1s+4s dance RH across & end
    facing corners
9-16::
    1s & 4s 1/2 turn corners RH, 2s+3s dance RH across _while_ 1s & 4s
    chase 1 place anticlockwise & set, 2s & 3s 1/2 turn new corners LH
17-24::
    1s & 4s 1/2 turn partners RH into Prom hold to dance out (4s out
    Ladies side, 1s out Mens side) casting to right & into centre then
    1s & 4s change places RH with opposite dancer
25-32::
    4s+1s dance RH across ending on sides, 4s & 1s turn partners RH.  2
    4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (6522, '2013-08-21 08:31:25.771593+00', '2023-02-04 01:21:27.356437+00', 7464, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1M+2s also 4M+3s dance 1/2 LSh reel, pick up partner in prom hold &
    continue for another 1/2 reel & end 2 1 (4)(3) - (1s facing 4s in
    centre)
9-16::
    1s+4s change with opposite person RH, 1/2 turn partner LH into LH
    across 1/2 way & end facing corners
17-24::
    1s & 4s dance "Hello-goodbye" setting & end facing ''2nd corner''
25-32::
    1s & 4s turn corners RH, pass other person RSh on sides & turn next
    corner RH to end 2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (6533, '2013-08-21 08:31:26.19719+00', '2023-02-04 01:21:27.952001+00', 4654, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 RH across, 1s+4s dance full LH across,
    2s+1s also 4s+3s dance 1/2 RH across
9-16::
    All dance RSh reels of 4 on sides
17-24::
    Top 3 dancers Mens side change places RH with bottom 3 dancers
    Ladies side & top 3 dancers Ladies side change places LH with bottom
    3 dancers Mens side, repeat to end (4)(3)(2)(1)
25-32::
    All set & cross RH, top 3 dancers each side dance 1/2 reels of 3 on
    sides (4s in & down to start).  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12733, '2020-04-11 10:52:21.108013+00', '2023-02-04 01:21:28.122119+00', 9658, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s, change places on side RH, 1s+4s dance LH across
    once round (4 bars), 2s+1s, also 4s+3s, 1/2 RH turn back to place
9-16::
    RSh reels of 4 own side, finish facing own partners
17-24::
    1s+2s also 3s+4s, dance Tournée. 2s finish in top place, 1s & 4s+3s
    (who step in) finish ready for …
25-32::
    1s+4s+3s dance Allemande. End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8341, '2014-07-29 12:59:18.154178+00', '2023-02-04 01:21:28.804555+00', 15280, 3, NULL, 'ace', '1-8::
    1s set, dance down 1 place, set (2s step up 3-4); still setting, 1L
    turns under Left arm, 1s retire to opp. sides
9-16::
    1s+3s dance R&L, 1s finish facing 1st corners
17-24::
    1s dance Hello-Goodbye setting
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (6545, '2013-08-21 08:31:26.32721+00', '2023-02-04 01:21:29.109991+00', 12055, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back.
9-16::
    1s+2s double Fig of 8 (1s cross down to start)
17-24::
    1s+2s turn 2H & circle 4H round to left
25-32::
    1s+2s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (12871, '2020-06-03 16:27:11.784837+00', '2023-02-04 01:21:29.250336+00', 13921, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); cross down LH & cast up round 3s to
    2nd place own side. 2 1 3
9-16::
    1L+2s & 1M+3s dance RH across, 1s pass RSh to dance LH across with
    other couple
17-24::
    1s pass LSh to dance reels of 3 across with 1st corners (1s pass 1st
    corner LSh to start)
25-32::
    2s+1s+3s set, dance DoSiDo with partner, all set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6548, '2013-08-21 08:31:26.352618+00', '2023-02-04 01:21:29.279241+00', 4675, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across, set & cross RH to own side (1s face
    out)
9-16::
    1s cast (Lady up & Man down) to end in lines of 3 across facing (1L
    between 2s & 1M between 3s), 2s+1s+3s set & 1s turn RH to face 1st
    corners
17-24::
    1s dance ''Hello-Goodbye'' setting
25-32::
    1s dance reels of 3 across set giving RSh to 2nd corner to start', 0);
INSERT INTO 'dancecrib' VALUES (6554, '2013-08-21 08:31:26.534776+00', '2023-02-04 01:21:30.120487+00', 4697, 3, NULL, 'ace', '1-8::
    1s dance in, cast 1 place & dance 1/2 Fig of 8 round 2s to end 2nd
    place opposite sides
9-16::
    1s pass LSh to dance 1/2 diagonal RSh reel of 4 with 3rd corners
    back to 2nd place opposite sides, repeat with 4th corners
17-24::
    3s+1s+2s chase 1/2 way clockwise & turn RH
25-32::
    3s+1s+2s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6557, '2013-08-21 08:31:26.645235+00', '2023-02-04 01:21:30.498158+00', 10653, 3, NULL, 'ace', '1-8::
    1s set advancing & turn 2H to face down & give nearer hand to 2s (2s
    face up), 1s+2s set & 1s turn 2s on sides with nearer hand
9-16::
    1s followed by 2s (who dance up to follow) dance down for 3 bars, 1s
    dance to top as 2s divide & follow, 1s cast to 2nd place, 2s to top,
    facing out
17-24::
    2s+1s+3s dance reflection reels of 3 on sides (1s in & down to
    start, all giving hands where possible) 2s & 3s ending with a loop
25-32::
    1s dance 1/2 reels of 3 across (Lady with 2s & Man with 3s), 1s
    dance 1/2 reels of 3 across (Man with 2s & Lady with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (6559, '2013-08-21 08:31:26.663256+00', '2023-02-04 01:21:30.566473+00', 13617, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s cast below 3s & dance up to top then cast to 2nd place
17-24::
    1s+3s dance RH across & LH back
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6566, '2013-08-21 08:31:26.734478+00', '2023-02-04 01:21:31.248108+00', 4744, 3, NULL, 'ace', '1-8::
    1s in prom hold dance out & down behind 2M, dance up between 2s, out
    behind 2L & dance in to 2nd place own side
9-16::
    2s repeat above Fig (Bars 1- 8)
17-24::
    1s lead down the middle for 4 steps, turn inwards, lead up, divide &
    dance up behind 3s on own sides & up to 2nd places
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6567, '2013-08-21 08:31:26.740563+00', '2023-02-04 01:21:31.266622+00', 10111, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s+4s lead down middle & cast back to places
9-16::
    1s+2M dance RH across, 1s+3L dance LH across
17-24::
    1s+4M dance RH across, 1L followed by partner casts round 4M &
    dances up Men''s side & crosses to place
25-32::
    1s+2s also 3s+4s dance 1/2 R&L, 1s+4s dance 1/2 R&L _while_ 2s & 3s
    set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (6568, '2013-08-21 08:31:26.74869+00', '2023-02-04 01:21:31.308374+00', 9683, 3, NULL, 'ace', '1-8::
    1s advance & cast 1 place, dance 1/2 Figs of 8 round 3s
9-16::
    All set, 1s advance setting & pass by LSh to circle 3H round with
    3rd+4th corners
17-24::
    1s cast round 3rd corners to 1M between 2s facing down & 1L between
    3s facing up, all set & 1s advance setting & pass LSh to face ends
25-32::
    1M dances RH across with 3s & 1L with 2s, 1s+3s dance 1/2 Diamond
    Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6569, '2013-08-21 08:31:26.756809+00', '2023-02-04 01:21:31.340543+00', 4746, 3, NULL, 'ace', '1-8::
    1s+2s+3s petronella turn & set, turn partner RH 1.1/4 times back to
    place
9-16::
    1s+2s set, dance 1/2 RH across, 2s+1s+3s set & turn partner RH into
    prom hold ending with 2s & 1s facing down & 3s up
17-24::
    2s+1s+3s dance promenade reel of 3 in middle (1s+3s pass RSh to
    start)
25-32::
    1s+3s dance RH across; 1s+2s dance 1/2 RH across, 1s cast to 2nd
    place own side _while_ 2s turn RH into 1st place. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6577, '2013-08-21 08:31:27.132039+00', '2023-02-04 01:21:31.987328+00', 10547, 3, NULL, 'ace', '1-8::
    1s+2s+3s turn 2H, 1M followed by 2M+3M cross & dance down Ladies
    side _while_ 3L followed by 2L+1L cross & dance up Men''s side
9-16::
    1s+2s+3s turn 2H, 1M followed by 2M+3M cross & dance up Men''s side
    _while_ 3L followed by 2L+1L cross & dance down Ladies side
17-24::
    1s followed by 2s+3s dance down the middle, cast & lead up (1s+2s
    end in middle)
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (12734, '2020-04-11 10:52:24.410177+00', '2023-02-04 01:21:32.636664+00', 9651, 3, NULL, 'ace', '1-8::
    1s  Petronella turn & set facing each other up/down; 1s turn 2H
    1.1/4 times, to finish facing up at top. 2s and 3s step in behind
    (bar 8) for …
9-16::
    1s+2s+3s dance Allemande finishing 1s in 3rd place, 3s at top. Bars
    15-16 2s+3s turn partners 2H ready for …  3 2 1
17-24::
    3s+2s (top 2 couples) dance 1/2 diamond poussette; 3s+1s dance 1/2
    diamond poussette.
25-32::
    1s (from 2nd place) dance Fig of 8 own side. (1L RSh to 2L, 1M RSh
    to 3M).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6590, '2013-08-21 08:31:27.415534+00', '2023-02-04 01:21:33.163663+00', 9672, 3, NULL, 'ace', '1-8::
    1M+2L Adv+Ret & change places RH & rest for 2 bars _while_ 1L+2M
    rest for 2 bars, Adv+Ret & change places RH
9-16::
    2s+1s dance RH across & LH back
17-24::
    1s dance 1/2 Fig of 8 up round 2s, 2s dance 1/2 Fig of 8 down round
    1s
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6594, '2013-08-21 08:31:27.457115+00', '2023-02-04 01:21:33.597019+00', 4806, 3, NULL, 'ace', '1-8::
    1s+2s set, turn 2H & circle 4H round to left
9-16::
    1s lead down the middle & back to face 1st corners
17-24::
    1s dance reels of 3 across giving RSh to 1st corners 1s end facing
    1st corners
25-32::
    1s turn 1st corners RH, partners LH, 2nd corners RH & partners LH to
    own sides & lead up to top
33-40::
    1s+2s dance Allemande
41-48::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6596, '2013-08-21 08:31:27.476943+00', '2023-02-04 01:21:33.65472+00', 4809, 3, NULL, 'ace', '1-8::
    1s+2s dance Poussette & continue turning to dance out to partner''s
    place
9-16::
    1s+2s dance RH across 1/2 way _while_ 3s set & 1s+2s+3s circle 6H
    round to Left & 1s end facing 1st corners
17-24::
    1s set to & turn 1st corners; set to & turn 2nd corners ending in
    2nd place opposite sides
25-32::
    1s dance reel of 3 on opp sides giving RSh to 1st corner to start &
    cross over to own sides in 2nd place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6601, '2013-08-21 08:31:27.524653+00', '2023-02-04 01:21:34.484579+00', 4827, 3, NULL, 'ace', '1-4::
    1s lead down middle & cross over to cast up to 2nd pl _while_ 2s set
    & cross RH to 3rd pl _while_ 3s cast up to 1st place & cross RH
5-8::
    All set & 1/2 turn 2H to own side
9-16::
    Repeat bars 1- 8 from new pstns
17-24::
    1s lead up to 1st place (4 bars); 1s set (2 bars) then 1s+2s set
    advancing ready for …
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6608, '2013-08-21 08:31:27.583332+00', '2023-02-04 01:21:34.922282+00', 8068, 3, NULL, 'ace', '1-8::
    All set, cross RH, set & 1/2 turn RH
9-16::
    All Promenade
17-24::
    1s cross RH, cast to bottom & dance 1/2 Fig of 8 round 3s
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6615, '2013-08-21 08:31:27.781362+00', '2023-02-04 01:21:35.418659+00', 4858, 3, NULL, 'ace', '{{explanation}}
3 couple set: Start with1M+3M changing places (1M to 3rd place & 3M to 1st place) Chord: Bow/curtsey to opp person

1-8::
    1s turn RH 1.1/2 times (2s step up/down to vacant corners) & dance
    RSh round 2nd corners to 2nd place opposite side
9-16::
    1s dance diag R&L with Man going down & Lady up each time (polite
    turns)
17-24::
    1s repeat bars 9-16 & 1s end by turning in to face 1st corners
25-32::
    1s dance ''Hello Goodbye'' setting & end facing 2nd corners
33-40::
    1s dance full diagonal reel of 4 with 2nd corners & end by passing
    LSh to face 2nd corners again
41-48::
    1s dance reel of 3 (on opp sides) giving RSh to 2nd corner, 1s cross
    to own side (M up to top & L down to bottom) as 3s cast into 2nd
    place (2L 3L 1L : 1M 3M 2M)', 0);
INSERT INTO 'dancecrib' VALUES (6624, '2013-08-21 08:31:27.868241+00', '2023-02-04 01:21:36.103374+00', 12529, 3, NULL, 'ace', '1-8::
    1s & 3s set & change places passing RSh to chase 1/4 round set
    cl''wise, 1s & 3s dance in (Ladies round Men, Men round Ladies) &
    turn right about to face 2s/4s (Lady facing Man)
9-16::
    All dance RSh reels of 4 across set, but 1s & 3s cast & dance
    clockwise into 3rd/1st places
17-32::
    2s+4s repeat bars 1-16 all ending in opposite places
33-40::
    All set & turn partners RH into 1/4 Schiehallion reel 1 place.  4 1
    2 3', 0);
INSERT INTO 'dancecrib' VALUES (6625, '2013-08-21 08:31:27.876259+00', '2023-02-04 01:21:36.130914+00', 6678, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance 1/2 Diag R&L (Lady up & Man down)
9-16::
    1s dance RSh reel of 3 on opposite sides (Man up & Lady down)
17-24::
    1s dance 1/2 Fig of 8 across (Man with 2L+3L at top & Lady with
    2M+3M at bottom) & dance 1/2 Diag R&L (Man up & Lady down)
25-32::
    3s+1s+2s chase clockwise 1/2 way & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (10837, '2018-06-11 00:36:49.524574+00', '2023-02-04 01:21:36.161939+00', 18332, 3, NULL, 'ace', '1-8::
    All set, 1s+2s also 3s+4s dance RH across, all set.
9-16::
    2s+3s dance Reel of 4 across (2L & 3M pass LSh to start) & end 1 3 2
    4.
17-24::
    All circle 8H round to left 1/2 way, set on sides & turn partner 2H
    1/2 way & remain in middle.  4 2 3 1
25-32::
    4s+2s also 3s+1s dance Poussette.', 0);
INSERT INTO 'dancecrib' VALUES (9027, '2015-11-30 09:00:06.149766+00', '2023-02-04 01:21:36.404559+00', 16522, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up). 1s dance 1/2 Figs 8 (1M round 2s, 1L
    round 3s) & join LH giving RH to 1st corners
9-16::
    2s+1s+3s dance The Spoke: 1s Bal-in-Line with 1st corners, then 2nd,
    3rd & 4th corners.  1s finish facing 1st corners
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh, dance
    1/2 diagonal reel of 4 with 2nd corners to finish in 2nd place, opp
    sides facing clockwise
25-32::
    3s+1s+2s dance clockwise 1/2 way round.  1M+3s &1L+2s dance RH
    across', 0);
INSERT INTO 'dancecrib' VALUES (6631, '2013-08-21 08:31:27.982734+00', '2023-02-04 01:21:36.449191+00', 10518, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, turn 2H & dance up to top
9-16::
    1s+3s dance double Fig of 8 around standing 2s (1s cast to start)
17-24::
    1M+2M turn LH 1.1/2 times _while_ 1L+2L turn RH 1.1/2 times, 1s set
    to 2s on sides, 1s & 2s set to partners
25-32::
    All turn partners 2H 1.1/2 times & chase clockwise 1/2 way.
33-40::
    4s+3s also 1s+2s dance Diamond Poussette.  4 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6632, '2013-08-21 08:31:28.078852+00', '2023-02-04 01:21:36.660777+00', 10519, 3, NULL, 'ace', '1‑8::
    1s lead down & back to places
9‑16::
    1s+2s dance 1/2 R&L, 2s+1s dance RH across
17‑24::
    2s & 1s cross RH, set, 2s+1s change places RH on sides & set  1 2 3
    4
25‑32::
    All dance 1/2 reels of 4 on sides, 4s+3s+2s (top 3 couples) dance
    1/2 reels of 3 on sides  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12095, '2019-08-30 09:54:42.691482+00', '2023-02-04 01:21:36.877002+00', 19081, 3, NULL, 'ace', '1-8::
    1s+2s set, pull back RSh & cast 1 place round clockwise;  1s+2s
    circle 4H once round to the left
9-16::
    1s+2s change places RH with partner on sides & chase 1 place
    clockwise (2 1 3); 1s+3s turn LH once round on sides (4 bars)
    flowing into…
17-24::
    2s+1s+3s dance RSh reels of 3 on sides (2s+1s pass RSh)
25-32::
    1s dance up between 2s, cast, turn 2H to face down NHJ & 1s+3s 1/2
    turn (Men RH, Ladies LH).  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6643, '2013-08-21 08:31:28.172241+00', '2023-02-04 01:21:37.003685+00', 9877, 3, NULL, 'ace', '1-8::
    1s turn 2H, dance down & face each other between 3s, 3s set as 1s
    set adv & pass RSh, 3s dance in (2nd pl) as 1s turn RH & face up
9-16::
    3s+1s dance Allemande
17-24::
    2s+1s+3s set, 1L dances reel of 3 with 2s & 1M with 3s
25-32::
    2s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6650, '2013-08-21 08:31:28.320588+00', '2023-02-04 01:21:37.749016+00', 4917, 3, NULL, 'ace', '{{explanation}}
All form circle around the room with partner on Man''s right

1-8::
    Each couple Adv+Ret 2 steps, repeat & end facing partner
9-16::
    Turn RH & turn LH
17-24::
    Lady dances Fig of 8 round partner & Man behind
25-32::
    Man dances Fig of 8 round partner & Lady behind
33-40::
    All couple dance Grand Chain (1 bar per hand) to meet new partner', 0);
INSERT INTO 'dancecrib' VALUES (6658, '2013-08-21 08:31:28.503638+00', '2023-02-04 01:21:38.448309+00', 12777, 3, NULL, 'ace', '1-8::
    1s cast behind own sides & cast back to places
9-16::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of 8 round 2s to end
    facing 1st corners
17-24::
    1s+1st corners turn RH & 1s pass partner RSh to face 2nd corners,
    1s+ 2nd corners turn RH & 1s pass partner RSh to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6659, '2013-08-21 08:31:28.513596+00', '2023-02-04 01:21:38.472123+00', 4929, 3, NULL, 'ace', '1-8::
    1s+3s dance RH across & LH back to form facing diagonal lines of 4
    (1s+2s & 3s+4s)
9-16::
    All Adv+Ret, 1s+4s & 2s+3s dance 1/2 R&L
17-24::
    1s+3s (now in 4th & 2nd places) dance 1/2 Ladies Chain, 2s+4s (in
    3rd & 1st places) dance 1/2 Ladies Chain
25-32::
    All repeat above Fig
33-40::
    All Adv+Ret, 1/2 R&L back to original places (repeat of bars 9-16)
41-48::
    All Promenade round anticlockwise
49-96::
    Repeat from beginning with 2s+4s leading & diagonal lines in other
    direction with 1s+4s facing 2s+3s', 0);
INSERT INTO 'dancecrib' VALUES (6661, '2013-08-21 08:31:28.533503+00', '2023-02-04 01:21:38.579352+00', 4932, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH, set & cross back RH
9-16::
    1s+2s set, dance RH across 1/2 way, set & dance LH across back to
    places
17-24::
    1s lead down 2 steps, set, lead back to top & cast to 2nd places
25-32::
    1s+3s circle 4H round to left, 2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (6664, '2013-08-21 08:31:28.59169+00', '2023-02-04 01:21:39.075217+00', 4940, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2 (1s are the couple facing clockwise)

1-8::
    1s dance Fig of 8 around 2s (1L giving LSh to 2L & 1M giving RSh to
    2M) note 1s give hands when passing between 2s LH & then RH
9-16::
    2s repeat dancing round 1s
17-24::
    All dance R&L (2s omitting polite turn to face out)
25-32::
    1s in prom hold dance reel of 3 with 2s giving RSh 2M to start & on
    last bar 1s dance between 2s to face next couple as 2s dance on', 0);
INSERT INTO 'dancecrib' VALUES (10019, '2017-07-23 15:58:43.389881+00', '2023-02-04 01:21:39.10592+00', 8654, 3, NULL, 'ace', '{{explanation}}
2 chords:  2nd chord 3s+4s cross to opp sides

1-8::
    1s & 4s set.  1s+2s also 3s+4s dance 3/4 Double Fig 8 (1s & 4s cross
    down/up, 2s & 3s dance up/down).  End (2) 1 (4) 3 with 1s & 4s
    facing
9-16::
    1s+4s dance R&L up down.  End with 3/4 LH turn to line up/down
    middle, Men in centre, 1M facing Ladies'' side, 4M facing Men''s side
17-24::
    1s & 4s dance a Men''s Targe
::
    _17-18_   Men turn RH 3/4 _while_ women dance anticlockwise 1/4
::
    _19-20_   1s and 4s turn partners LH
::
    _21-22_   Men turn RH 3/4 _while_ women dance anticlockwise 1/4
::
    _23-24_   1s and 4s turn partners LH 3/4 to finish 1s in 3rd place
    opposite sides and 4s in 2nd place own sides. End (2) 4 1 (3)
25-32::
    2s & 3s set to partners, 1/2 RH & all circle 8H 1/2 round to Left to
    end 3 1 (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (9030, '2015-11-30 09:00:07.049842+00', '2023-02-04 01:21:40.122776+00', 10884, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All Advance (2 steps), clap, Retire (2 steps).  Repeat
17-24::
    All turn partners RH then LH
25-32::
    »Hearts«:  1M dances between 2s, 1L between 4s, dance round outside
    of set, meet below 3s, dance between 3s NHJ and back to place

{{explanation}}
Repeat 3 times with 2s, then 3s, then 4s dancing last 8 bars round set & between opposite couple', 0);
INSERT INTO 'dancecrib' VALUES (6678, '2013-08-21 08:31:28.755844+00', '2023-02-04 01:21:40.30477+00', 4959, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH, clap 3 times & cross RH back to places
9-16::
    1s+2s dance RH across 1/2 way, set, clap 3 times & dance LH across
    1/2 way
17-24::
    1s lead down & back to top
25-32::
    1s+2s dance 1/2 R&L, clap 3 times & cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6682, '2013-08-21 08:31:28.94595+00', '2023-02-04 01:21:40.952555+00', 4965, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to top
9-16::
    1s set _while_ 2s cross RH, 1s+2s (facing up/down) set & dance RH
    across
17-24::
    1s+2s dance reel of 4 across (Men pass LSh to start & Ladies end
    dancing straight across)
25-32::
    1s+2s set, dance 1/2 R&L & 1s cross RH', 0);
INSERT INTO 'dancecrib' VALUES (6686, '2013-08-21 08:31:29.182442+00', '2023-02-04 01:21:41.476088+00', 11628, 3, NULL, 'ace', '1-8::
    1s & 3s set, cross RH, 1L & 3L followed by partners dance round to
    right clockwise back to partners place
9-16::
    1s dance RH across with 2L & LH across with 4M _while_ 3s dance RH
    across with 4L & LH across with 2M
17-24::
    1s & 3s (Ladies leading) dance an Alternating Tandem RSh reel of 3
    with corners
25-32::
    1L & 3L followed by partners dance round clockwise to opposite
    places, set & cross RH back to original places
33-64::
    2s & 4s repeat bars 1-32
65-72::
    1s+3s change places (1s dancing under arch made by 3s), set to
    partner, repeat back to places (1s making arch) & set to partner
73-80::
    2s+4s repeat bars 65-72 (4s first making arch)
81-88::
    All turn partners RH (4 bars) & corner LH
89-96::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8786, '2015-06-15 11:41:02.623556+00', '2023-02-04 01:21:41.832012+00', 16278, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance RH across (1M with 2s & 1L with
    3s)
9-16::
    1s turn LH & down 1 place opposite sides, cross up & turn 2s (2M RH
    & 2L LH)
17-24::
    1s dance reflection reels of 3 on own sides (1s dance between 2s to
    start) & 1s+2s remain in middle for …
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (8845, '2015-08-13 20:33:56.887393+00', '2023-02-04 01:21:41.859836+00', 16272, 3, NULL, 'ace', '{{explanation}}
2 facing 2 round the room

1-8::
    All circle 4H round and back
9-16::
    All dance RH across & LH across
17-24::
    All dance Ladies'' Chain
25-32::
    Couples Adv+Ret & pass opp. person RSh to meet new couple', 0);
INSERT INTO 'dancecrib' VALUES (13530, '2021-01-09 01:21:01.738513+00', '2023-02-04 01:21:42.621331+00', 19878, 3, NULL, 'ace', '{{explanation}}
No hands given throughout the dance

1-8::
    1s dance in &  cast to 2nd place (2s step up 3-4); 1s dance up &
    cast to end facing 1st corners
9-16::
    1s dance Corner Pass+Turn with 1st corners who dance RSh round each
    other & back to place), 1s pass RSh; 1s repeat with 2nd corners to
    end in 2nd place own side facing out
17-24::
    RSh reels of 3 on own sides (1M up, 1L down); 1s cross bars 19-20 to
    continue reel on opp sides. 1s end facing 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting ending with Petronella turn to 2nd
    place own sides.  2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (13280, '2020-10-16 00:21:21.504483+00', '2023-02-04 01:21:42.850677+00', 19642, 3, NULL, 'ace', '1-8::
    1s turn 2H, 1s+2s+3s dance mirror reels of 3 on sides (1s in/down to
    start)
9-16::
    1s dance in & cast (2s step up 11-12); 1s dance 1/2 Fig 8 (1M round
    3s, LSh to 3L, 1L round 2s, LSh to 2M). 1s join LH with partner in
    centre & RH with 2nd corners
17-24::
    1s+2nd corners "Strathspey Balance & Turn":
::
    _17_      1s drop LH, 1s+2nd corners set to right, release RH & join
    LH
::
    _18_      1s+2nd corners 1/2 turn LH & briefly join RH with partner
::
    _19-20_ 1s drop LH, join RH with partner & set to right, 1s 1/2 turn
    LH _while_ 2nd corners set
::
    _21-24_  1s turn 2nd corners RH, turn partner 3/4 LH to join RH with
    1st corners
25-32::
    1s repeat 17-24 with 1st corners.  1s end in 2nd place own side.  2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (8066, '2013-10-01 08:47:14.687231+00', '2023-02-04 01:21:43.118072+00', 15139, 3, NULL, 'ace', '1-8::
    1s cross & cast 1 place, 1s dance 1/2 Fig of 8 round 2s
9-16::
    1s dance reflection reels of 3 on own sides dancing in & down to
    start
17-24::
    1s lead down middle & back to 2nd place
25-32::
    1s+3s dance an Allemande.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (8185, '2014-02-10 10:26:50.144716+00', '2023-02-04 01:21:43.509614+00', 15334, 3, NULL, 'ace', '1-8::
    1s & 3s dance Figs of 8 round 2s/4s (1M+3L round 2s, 1L+3M round 4s)
    dancing out & between 2s/4s to start & end back in original places
9-16::
    All circle left & back
17-24::
    2s & 4s dance similar loops:
::
    2L & 4L followed by partner dance anticlockwise loops round 1s/3s
    (2s round 1s, 4s round 3s) with Men dancing in between the standing
    couples to take lead, continue dancing anticlockwise round standing
    couples with Ladies dancing in between the standing couples to meet
    the other dancing couples
25-32::
    2s+4s dance RH across & dance out through standing couples (Men
    passing 1L/3L RSh & Ladies passing 1M/3M RSh) & clockwise to places
    then dancing couples change places RH
33-40::
    2s+4s dance Men''s Chain
41-56::
    1s & 3s repeat bars 17-32 (dancing around 2s/4s)
57-64::
    1s+3s dance Men''s Chain
65-72::
    2s & 4s dance Figs of 8 round 1s/3s (2L & 4M round 1s, 2M & 4L round
    3s)
73-80::
    ALL circle 8H round and back', 0);
INSERT INTO 'dancecrib' VALUES (6716, '2013-08-21 08:31:29.877124+00', '2023-02-04 01:21:43.646434+00', 5028, 3, NULL, 'ace', '1-8::
    1s+2s+3s cross RH & cross back RH
9-16::
    1s lead down the middle & back to top
17-24::
    1s+2s dance Allemande
25-32::
    2s1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9031, '2015-11-30 09:00:08.369052+00', '2023-02-04 01:21:45.264166+00', 10904, 3, NULL, 'ace', '1-8::
    1s cast behind own lines, cast back up to places
9-16::
    1s+2s dance RH across, LH across
17-24::
    1s turn RH, cast  (2s step up) & turn LH (4 bars)
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14537, '2022-01-10 02:20:22.894495+00', '2023-02-04 01:21:45.520812+00', 17972, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole ending 2 1 3 with 1L facing out/down
9-16::
    1s+3s turn RH twice round on side; 1s+3s turn LH twice round
17-24::
    2s+1s+3s dance RSh reels of 3 on sides (1s+3s pass RSh to start). 2
    1 3
25-32::
    1s+3s change places dancing the »Maurice Progression«:
::
    _25-28_  1M+3L dance DoSiDo _while_ 1L+3M cast 1 place (1 bar) & Adv
    to centre & face partner (1 bar), Adv as partners Ret to form line
    on 1st corner diagonal ready for …
::
    _29-32_  1s+3s dance 1/2 Poussette.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (6740, '2013-08-21 08:31:30.174281+00', '2023-02-04 01:21:45.552372+00', 5080, 3, NULL, 'ace', '1-8::
    1s set & cross over RH, set & 3/4 turn RH
9-16::
    1s dance RH across with 2M & LH across with 2L
17-24::
    1L followed by 1M dance down for 2 & 1M followed by1L dance up for
    2, both cast on Ladies side & 1M crosses to 2nd place own side
25-32::
    2s+1s R&L', 0);
INSERT INTO 'dancecrib' VALUES (14124, '2021-07-07 00:20:46.826289+00', '2023-02-04 01:21:45.908174+00', 20062, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1M+2L cross RH & set _while_ 2M+1L set & cross RH; 2s+1s chase 1/2
    round clockwise back to place
17-24::
    1M+2L cross LH & set _while_ 2M+1L  set & cross LH; 2s+1s chase 1/2
    round anticlockwise back to place
25-32::
    1s+2s Set & Rotate', 0);
INSERT INTO 'dancecrib' VALUES (13314, '2020-11-02 01:21:18.092843+00', '2023-02-04 01:21:46.779706+00', 17578, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance R&L
9-16::
    All set, all 2H turn partner, all circle 8H left 2 places to finish
    men at top & ladies at bottom, 3M+1M & 1L+3L change places RH
17-24::
    All Men also all Ladies dance RH across, all dance 1/2 reels of 4 on
    sides
25-32::
    All Ladies at top also all Men at bottom circle 4H left, circles
    unwind with 1L leading the Ladies & 2M leading the Men to own sides
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13315, '2020-11-02 01:21:18.106584+00', '2023-02-04 01:21:46.804503+00', 18379, 3, NULL, 'ace', '1-8::
    1s set advancing, turn 2H to finish in middle facing down, 1s dance
    down 2 places, turn 2H to 3rd place 2 3 1
9-16::
    3s+1s dance Tourbillon:
::
    3s & 1s 1/2 turn partners 2H, 3M & 1L lead partners on 1 place
    clockwise to end 3s on Ladies'' side & 1s on Men''s side, 1s set to 3s
::
    3s & 1s 1/2 turn partners 2H, 1L & 3M lead partners on 1 place to
    end 1s in 2nd pl & 3s in 3rd pl & 1s+3s cross RH to own sides 2 1 3
17-24::
    All chase clockwise 1/2 way, all 1/2 turn partner RH, face partner,
    pull back RSh & dance out to own sides 3 1 2
25-32::
    1s+2s dance Diamond Poussette 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6760, '2013-08-21 08:31:30.482859+00', '2023-02-04 01:21:47.348226+00', 5111, 3, NULL, 'ace', '1-4::
    All set, 2s+3s cross RH to opp sides _while_ 1s & 4s 1/2 turn
    partner RH to end in middle 1s facing down to 4s facing up
5-8::
    1s+4s Advance, join NH with dancer opposite & dance out through
    sides, separate & cast to ends (1) (2) (3) (4)
9-12::
    All set, 1s+4s cross RH _while_ 2s & 3s 1/2 turn partner RH to end
    in middle 2s facing up & 3s down
13-16::
    2s+3s dance out ends & cast back to original places. 1 2 3 4
17-24::
    1s+2s & 3s+4s dance RH across & LH across back to places
25-32::
    1s cross diag down RH _while_ 4s cross diag up LH to form circle in
    centre, 1s+4s circle 4H to left, continue circle opening for 1L+4L
    to dance down to 4th/3rd place own side as 4M+1M dance up to 3rd/4th
    place own side (2s+3s step up 31-32).  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6782, '2013-08-21 08:31:30.808737+00', '2023-02-04 01:21:48.522474+00', 5139, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1M+2M & 3M+4M turn LH on sides _while_ 1L+2L & 3L+4L turn RH, 2s &
    3s dance 1/2 Fig of 8 round end couples
9-16::
    2s+3s 3/4 turn ptnrs LH into middle & Bal-in-Line, 1s+2L dance RH
    across as 2M+3M turn RH as 3L+4s dance RH across & all end in orig
    place
17-24::
    1s+2s also 3s+4s Adv+Ret, 1s+2s also 3s+4s circle 4H round to left
25-32::
    1M+2M & 3M+4M turn RH on sides _while_ 1L+2L & 3L+4L turn LH, 1L
    crosses down & casts up as 1M crosses & casts 2nd place (2L up)
    _while_ 4L crosses up & casts as 4M crosses & casts (3L down)
33-40::
    1s & 4s cross LH diagonally & cast up/down, cross RH diagonally &
    cast up/down
41-48::
    1s & 4s 1/2 turn partners RH to end in 2nd/3rd places & dance RH
    across 1/2 way, turn partners RH to end 2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (6790, '2013-08-21 08:31:30.873176+00', '2023-02-04 01:21:48.879722+00', 11788, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    2s+3s dance R&L & end in prom hold with other partner
9-16::
    2M+3L dance reel of 3 with 1s (pass 1L RSh) _while_ 3M+2L dance reel
    of 3 with 4s (pass 4L RSh)
17-24::
    1M+2M also 3M+4M turn LH 1.1/2 times _while_ Ladies turn RH 1.1/2
    times, 1s & 4s dance 1/2 Figs of 8 round end couples
25-32::
    4s followed by 1s dance down between 3s & cast up to 2nd/3rd places
    & all turn partners RH.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (6793, '2013-08-21 08:31:30.919781+00', '2023-02-04 01:21:49.220761+00', 5161, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides & end
    between 3s facing opposite partner
9-16::
    1s turn 3s RH, 1s pass LSh to dance 1/2 RSh reel of 4 across with 3s
    with 1M ending above 3s & 1L below, 1s+3s dance RH across 1/2 way
17-24::
    1L with 2s & 1M with 4s dance LH across 1/2 way & 1L+3M also 1M+3L
    turn RH, 1s dance 1/2 reels of 3 across (1L with 2s, 1M with 3s)
25-32::
    1s 3/4 turn LH & turn 3s RH, 1s turn LH & change places with 4s (1L
    LH, 1M RH)  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (15348, '2022-12-19 01:21:25.441668+00', '2023-02-04 01:21:49.454292+00', 5172, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s lead down crossing below 2s & cast to top, 1s cross RH & cast to
    2nd place
17-24::
    2s+1s set & cross RH, 2s+1s set & 1/2 turn RH for…
25-32::
    2s+1s Promenade

{{explanation}}
Note: Originally published as Strathspey. In revised version of »Stepping Out« published as Reel', 0);
INSERT INTO 'dancecrib' VALUES (13628, '2021-02-04 01:21:12.699702+00', '2023-02-04 01:21:49.52076+00', 18850, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s lead down crossing below 2s & cast to top, 1s cross RH & cast to
    2nd place
17-24::
    2s+1s set & cross RH, 2s+1s set & 1/2 turn RH for…
25-32::
    2s+1s Promenade

{{explanation}}
Note: Originally published as Strathspey. In revised version of »Stepping Out« published as Reel', 0);
INSERT INTO 'dancecrib' VALUES (6799, '2013-08-21 08:31:31.282525+00', '2023-02-04 01:21:50.1132+00', 5179, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, turn LH to face 1st corners
9-16::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH to
    face 1st corners
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners ending in 2nd place own sides
25-32::
    2s+1s+3s circle 6h round & back', 0);
INSERT INTO 'dancecrib' VALUES (6821, '2013-08-21 08:31:31.480189+00', '2023-02-04 01:21:51.301107+00', 5208, 3, NULL, 'ace', '1-16::
    All 4 couples set twice, turn RH,1s+2s remain in middle facing up &
    1s+2s dance Allemande
17-32::
    2s+1s+3s dance Grand Chain. 1s+3s dance RH across & back LH
33-48::
    1s+3s dance Poussette, 1s finish BtoB facing own sides & dance
    Double Triangles with 3s & 4s
49-64::
    1s dance up to the top (2s+3s step down 51-52) & cast down followed
    by 2s+3s+4s, dance up the middle, 2s+3s+4s make arches, Bar 60 1s
    face down & dance under arches to bottom. 2s+3s+4s step up bar 64', 0);
INSERT INTO 'dancecrib' VALUES (6833, '2013-08-21 08:31:31.597624+00', '2023-02-04 01:21:52.293618+00', 5223, 3, NULL, 'ace', '1-8::
    1s lead & cast down round 2M, cross & cast round 3L, lead up the
    middle to places
9-16::
    1s lead down the middle, 1s dancing up turn RH & LH to face 1st
    corners
17-24::
    1s turn 1st corners RH, pass by RSh to turn 2nd corners LH & cross
    to 2nd place own sides
25-32::
    1s+3s circle 4H round to left, 2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (14215, '2021-08-14 00:21:22.191457+00', '2023-02-04 01:21:52.684011+00', 12372, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast 1 place & turn LH to face 1st corners (2s
    step up bars 5-6)
9-16::
    1s dance 1/2 reel of 4 with 1st corners, pass RSh to dance 1/2 reel
    with 2nd corners, pass RSh to 2nd place own side.
17-24::
    1s cast down round 2s (in 3rd place) dance up to top, cast round 3s
    (in 1st place) to 2nd place own sides
25-32::
    3s+1s+2s dance Diagonal R&L (1M down, 1L up). End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6843, '2013-08-21 08:31:31.710136+00', '2023-02-04 01:21:53.011193+00', 8857, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, turn LH & cast round 4th corners to end
    between 2s/3s
9-16::
    All Set+Link for 3, 2M+3L change places RH & cast to 2nd places own
    side
17-24::
    2L+3M change places LH & cast to 2nd place own side, 1s change
    places RH & cast to 2nd place opposite side.  2(1)3
25-32::
    1s 1/2 turn RH & twirl to own sides, all dance DoSiDo', 0);
INSERT INTO 'dancecrib' VALUES (12556, '2020-02-02 02:49:10.333741+00', '2023-02-04 01:21:53.25863+00', 5257, 3, NULL, 'ace', '1-8::
    1M dances LSh round partner finishing in middle facing partner; 1s
    2H joined slip step down & back up to place
9-16::
    All 4 couples slip step down & back up to place
17-24::
    All 4 couples circle 8H round & back
25-32::
    1s lead down to 4th place (2s+3s+4s step up 27-28); 1s turn 2H (skip
    change). 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6848, '2013-08-21 08:31:31.782288+00', '2023-02-04 01:21:53.545242+00', 5260, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1L dances 1/2 Fig of 8 round 2s & 1M
    round 3s end in centre each facing 1st corner & holding LH
9-16::
    1s set to 1st corners, turn inwards & set to 3rd corner, 1/4 turn RH
    & set to 2nd corners, turn inwards & set to 4th corner
17-24::
    1L with 2s & 1M with 3s dance RH across, 1s turn 1.1/2 times LH in
    centre _while_ 2s & 3s chase round clockwise 1/2 way
25-32::
    1L with 2s & 1M with 3s dance RH across (same couple but at other
    end), 1s turn 1.1/2 LH _while_ 2s & 3s chase round clockwise 1/2 way
33-40::
    1L with 2s & 1M with 3s dance full LSh reels of 3, 1s ending on own
    sides in 2nd place
41-48::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6850, '2013-08-21 08:31:31.800247+00', '2023-02-04 01:21:53.58288+00', 5261, 3, NULL, 'ace', '1-8::
    1s & 4s turn RH, cast in 1 place, dance LH across once round & end
    facing corners
9-16::
    All dance double diagonal reels of 4 (giving LH in centre)
17-24::
    1s & 4s dance ''Hello-Goodbye'' setting end facing opposite corners
    (2s+3s set 8 bars)
25-32::
    1s & 4s pass corners RSh to dance 3/4 Figs of 8 round end couples
    (1s round 3s, 4s round 2s), Bars 28-29  pass partners RSh & continue
    to end on own side 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6856, '2013-08-21 08:31:31.852511+00', '2023-02-04 01:21:53.859127+00', 5271, 3, NULL, 'ace', '1-8::
    All set & 1s followed by 2s+3s+4s dance down the middle, divide &
    dance back up to places
9-16::
    1s & 2s dance 1/2 Fig of 8 round next cpl, 1s+2s & 3s+4s turn 1.1/2
    on sides (RH on Men''s side & LH on Ladies), end 2s+4s face down &
    1s+3s up
17-24::
    All dance reflection reels of 4 on sides (RSh on Men''s side & LSh on
    Ladies side)
25-32::
    1s followed by 3s dance out & up to top, lead down (on opposite
    sides) & turn LH 1s to 4th place & 3s to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (9399, '2016-10-06 07:18:48.717849+00', '2023-02-04 01:21:53.875059+00', 16614, 3, NULL, 'ace', '1-8::
    1s+2s dance all round Poussette
9-16::
    1s set, cast (2s step up 11-12), meet in middle, dance down, cast up
    round 3s into middle facing up
17-24::
    Reflection (mirror) reels of 3 on sides (1s up, 2s out/down, 3s
    out/up)
25-32::
    1s+3s Set+Link, 3s+1s circle 4H round to Left  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (9485, '2016-11-09 08:48:53.193622+00', '2023-02-04 01:21:54.463959+00', 16930, 3, NULL, 'ace', '1-8::
    1s set, turn RH moving down to face out in 2nd place own side (2s
    step up). 1s cast Right to lines across (1M between 2s facing down,
    1L between 3s facing up)
9-16::
    All set, 1s cross RH, cast Right, dance through 2nd place own side,
    pass LSh to face 1st corners
17-24::
    1s turn 1st corner RH, pass RSh, turn 2nd corner RH, pass RSh to 2nd
    place own sides
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (6864, '2013-08-21 08:31:31.943571+00', '2023-02-04 01:21:54.493569+00', 5289, 3, NULL, 'ace', '1-8::
    1s set, dance in & cast to 2nd place (4 bars), turn LH to face 3rd
    corner (partner''s 1st corner), 2s step up 5-6
9-16::
    1s change places RH with corners, 1s set as corners pass LH, 1s
    change places RH with 1st corner persons, corners set as1s turn LH
    to face own 2nd corner
17-24::
    Repeat with 2nd corners & 1s turn LH in middle to finish Lady facing
    up & Man facing down
25-32::
    1s dance RH across (Lady with 3s at top & Man with 2s), 1s pass RSh
    to dance LH across with other couple ending in 2nd place own sides
33-40::
    1s dance Diag R&L  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6868, '2013-08-21 08:31:31.977851+00', '2023-02-04 01:21:54.824311+00', 14683, 3, NULL, 'ace', '1-8::
    2s cross RH & cast round 1st corner & dance 1/2 reels of 3 across
    (2M+3M, 2L+1L pass LSh) ending in lines across
9-16::
    2s change places RH, cast round 2nd corner (pstn) & dance 1/2 reels
    of 3 on sides ending in 2nd place opposite sides.  (3)(2)(1)
17-20::
    All dance in to join RH with partner, 3s cross RH & cast to 3rd
    place _while_ 2s cross up & cast to 2nd place _while_ 1s lead up,
    cross & cast to 1st place
21-24::
    All turn 2H to end with 3s in 3rd place & 1s+2s in middle ready for…
25-32::
    1s+2s dance 1/2 diamond Poussette; 1s+3s dance 1/2 Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (6870, '2013-08-21 08:31:31.996105+00', '2023-02-04 01:21:55.028079+00', 5302, 3, NULL, 'ace', '1-8::
    All dance RH across & LH back
9-16::
    All dance Ladies'' Chain
17-24::
    All Adv+Ret & dance DoSiDo
25-32::
    All set to partner twice & turn opposite person RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (6876, '2013-08-21 08:31:32.04494+00', '2023-02-04 01:21:55.654067+00', 5310, 3, NULL, 'ace', '{{explanation}}
1s start on opp sides

1-8::
    1s facing 2s on sides set & change places RH, 2s+1s set to partner &
    cross RH
9-16::
    2s+1s repeat above Fig
17-24::
    1s lead down the middle & back to places
25-32::
    1s+2s dance Polka Poussette (1s end opposite sides to start again)', 0);
INSERT INTO 'dancecrib' VALUES (6877, '2013-08-21 08:31:32.051033+00', '2023-02-04 01:21:55.673298+00', 8986, 3, NULL, 'ace', '{{explanation}}
5 person diamond set with 5th person in centre facing north

1-8::
    RSh Reel with North & South
9-16::
    LSh Reel with West & East
17-24::
    Set & 1/2 turn RH with North, set & 1/2 turn RH with West
25-32::
    Set & 1/2 turn RH with South, set & 1/2 turn RH with East', 4);
INSERT INTO 'dancecrib' VALUES (13532, '2021-01-09 01:21:13.165962+00', '2023-02-04 01:21:56.01233+00', 20059, 3, NULL, 'ace', '{{explanation}}
No hands given throughout the dance

1-8::
    1s set, cast (2s step up); 1s cross down, cast up round 3s to end
    BtoB facing 1st corner
9-16::
    1s dance ''Hello-Goodbye'' setting. 1s end facing 3rd corner
17-24::
    LSh reels of 3 on sides (1s pass 3rd corner LSh to start)
25-32::
    RSh reels of 3 across (1M RSh to 2L at top, 1L RSh to 3M).  1s end
    in 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6890, '2013-08-21 08:31:32.166554+00', '2023-02-04 01:21:56.496491+00', 5344, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across 1/2 way, set & cross RH to own sides
9-16::
    1s set advancing into BtoB position 1L facing up & 1M down & dance
    Crown Triangles ending with 1s 1/2 turning RH
17-24::
    1s dance to right round 1st corner into centre, turn right about &
    dance round 4th corner to 2nd place own side
25-32::
    1s+3s+4s dance Poussette to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6903, '2013-08-21 08:31:32.532159+00', '2023-02-04 01:21:57.604689+00', 5366, 3, NULL, 'ace', '1-8::
    1s dance down to bottom & 1/2 turn with Lady passing under Man''s
    arm, 1s on opposite sides dance up, out between 2s & 3s & cast up to
    1st place
9-16::
    1s dance reflection reels on opposite sides
17-24::
    1s turn 2s 1.1/2 times (on sides) dancing between 2s to start, cross
    passing LSh & turn 3s 1.1/2 times (on sides) dancing between them to
    start
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6908, '2013-08-21 08:31:32.57762+00', '2023-02-04 01:21:57.833994+00', 11979, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s lead down the middle & up (3s leading) with
    2s+3s casting back to places
9-16::
    1s+2s dance the Knot
17-24::
    1s+3s dance the Knot
25-32::
    1s lead up crossing RH & cast to 2nd place, 1s dance 1/2 Fig of 8
    round 2s', 0);
INSERT INTO 'dancecrib' VALUES (14131, '2021-07-07 00:20:57.627535+00', '2023-02-04 01:21:58.519943+00', 10285, 3, NULL, 'ace', '1-8::
    1s+2s set & dance 1/2 RH across; 1s+3s set & dance 1/2 LH across.
    (2) (3) 1
9-16::
    1s lead up to top, cross & cast round 2s, meet, dance down between
    3s & cast up to 2nd place opp sides (3s step down 15-16). (2) (1)
    (3)
17-24::
    2s+1s+3s Set+Link for 3 couples twice. 3 1 2
25-32::
    3s+1s+2s circle 6H round & back.  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (6934, '2013-08-21 08:31:33.321208+00', '2023-02-04 01:22:00.092393+00', 5414, 3, NULL, 'ace', '1-8::
    2s & 3s dance up/down between end couples & cast back to place, 1s &
    4s dance down/up between 2s/3s & cast back to place
9-16::
    1s 1/2 turn RH down to 2nd place facing up as 4s 1/2 turn LH up to
    3rd place facing down (2s+3s dance down/up and in to face 1s/4s).
    2s+1s also 4s+3s set, dance RH across to sides 2 (1) (4) 3
17-24::
    All dance reels of 4 on sides
25-32::
    1s+4s 1/2 turn 2H, set to partner, 1s followed by 4s dance up
    between 2s & cast, 1s to 3rd,, 4s to 2nd place  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (6941, '2013-08-21 08:31:33.398691+00', '2023-02-04 01:22:00.58074+00', 5434, 3, NULL, 'ace', '1-8::
    1s cast 1 place, cross RH & face partner, set & turn RH to face 2nd
    corner
9-16::
    1s dance diagonal reel of 4 with 2nd corners, 1s passing LSh to end
    in 2nd place M facing in (opposite side) _while_ L faces down in
    centre of set
17-24::
    1M circle 5H round & back with 2s & 3s _while_ 1L sets turning
    slowly in opposite direction (e.g. PdeB & Points)
25-32::
    1s in prom hold dance out & down behind 3M, cross up to 2nd place
    Ladies side & cast to 3rd place
33-40::
    1M dances LH across with 4s _while_ 1L faces out on Men''s side, 1L
    followed by partner cast to 4th place own sides', 0);
INSERT INTO 'dancecrib' VALUES (6951, '2013-08-21 08:31:33.538731+00', '2023-02-04 01:22:01.245624+00', 5445, 3, NULL, 'ace', '1-8::
    1s & 3s set, 1/2 turn RH into prom hold & dance down crossing at
    bottom & 3s cast to top _while_ 1s cast up to 3rd place
9-16::
    All dance "Inter-linked Chain"
::
    _9-12_     3s+2s also 1s+4s Set+Link,  3M, 2L, 1M & 4L face out
::
    _13-14_   2M+3L also 4M+3L turn 3/4 RH end facing out _while_
    partners cast (all in starting places as bar 8),
::
    _15-16_   2M+3L also 4M+1L cast 1 place _while_ partners turn 3/4 RH
    and stay facing out (all in progressed places as bar 12)  2 3 4 1
17-24::
    All dance reels of 4 on sides and finish facing as at start of reels
25-32::
    2s+3s also 4s+1s turn 2H on sides, 2s+3s also 4s+1s circle 4H round
    to left 1/2 way, staying in middle &  turn prtnrs 2H, 2s+3s also
    4s+1s circle 4H round to left 1/2 way  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (6957, '2013-08-21 08:31:33.595251+00', '2023-02-04 01:22:01.848073+00', 11748, 3, NULL, 'ace', '1-8::
    1s & 3s dance 1/2 Fig of 8 round couple below, cross RH & cast 1
    place
9-16::
    1s & 3s advance setting turning right about to face own sides & all
    set as in Double Triangles,1s & 3s dance out & turn right about to
    face in _while_ 2s+4s+5s dance in & turn right about to face out
    (Inverted Triangle formation), 2s+4s+5s PdB round partner to face
    opposite side
17-24::
    All set & 1s also 3s dance in turning right about to face out
    _while_ 2s+4s+5s dance out & turn right about to face in, 1s+3s PdB
    round partner to face opposite side & all set
25-32::
    1s & 3s dance RSh 1/2 reels across (1L with 2s, 1M+3L with 4s, 3M
    with 5s), 1s & 3s turn LH & cast to 3rd/5th places', 0);
INSERT INTO 'dancecrib' VALUES (10529, '2018-03-20 06:27:12.567775+00', '2023-02-04 01:22:01.872608+00', 17445, 3, NULL, 'ace', '1-8::
    1s dance behind 2s, in front of 3s & behind 4s; 1s set advancing &
    turn RH to 4th place own side, 2s+3s+4s step up (7-8)
9-16::
    2s+3s also 4s+1s dance R&L
17-24::
    2s+1s (end couples)  Adv+Ret on diagonal; 3s+4s (middle couples)
    dance RH across
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9224, '2016-06-16 22:42:13.976796+00', '2023-02-04 01:22:02.024107+00', 14818, 3, NULL, 'ace', '1-8::
    1s cross RH and cast 1 place, 1s dance 1/2 Fig of 8 round 2s (2s
    step up 3-4).
9-12::
    1L+2s and 1M+3s dance RH across, 1s finish in the middle
13-16::
    1s+2s+3s dance Snake Pass: 1L followed by 2L & 2M, 1M followed by 3L
    & 3M, pass LSh in the middle, dance out to the side, down to 3rd/up
    to 1st place, cross to own side and cast up/down to 2nd place in
    middle
17-20::
    1L with 2s and 1M with 3s dance LH across to finish in the middle
21-24::
    1s+2s+3s dance Snake Pass: 1L followed by 2L & 2M, 1M followed by 3L
    & 3M - pass RSh in the middle, dance out to the side, up to 1st
    place/ down to 3rd, cross to own side and cast down/ up to 2nd place
    own sides
25-32::
    2s+1s+3s circle 6H round to the left (6 steps) and pivot to chase
    anticlockwise back to own side', 0);
INSERT INTO 'dancecrib' VALUES (6963, '2013-08-21 08:31:33.771771+00', '2023-02-04 01:22:02.202927+00', 5462, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s lead down the middle & back to top
17-24::
    1s+2s dance Allemande
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (6968, '2013-08-21 08:31:33.924387+00', '2023-02-04 01:22:02.362361+00', 14790, 3, NULL, 'ace', '1-8::
    1s & 3s 3/4 turn RH into line of 4 up/dn middle (Ladies face dn, Men
    up) & dance RSh 1/2 reel of 4, 1s & 3s turn prtnr 3/4 RH to own
    sides 3 2 1
9-16::
    All circle 6H round & back
17-24::
    3s & 1s dance 3/4 Fig of 8 round 2s (3s cast to start) & 3s cross RH
    as 1s+2s set advancing ready for …
25-32::
    1s & 2s dance1/2 Diamond Poussette; 1s & 3s dance 1/2 Diamond
    Poussette.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (8623, '2015-02-13 12:48:10.608442+00', '2023-02-04 01:22:02.655679+00', 15647, 3, NULL, 'ace', '1-8::
    1L+2M set, change places RH.  1s set, change places RH
9-16::
    1s+2s circle 4H round and back, finish in line of 4 facing down, 1s
    on Right of 2s
17-20::
    1s+2s dance down and turn to face partner
21-24::
    1s also 2s join 2H with partners, slip step up middle to finish in
    middle, 1s above 2s ready for…
25-32::
    1s+2s dance poussette', 0);
INSERT INTO 'dancecrib' VALUES (15235, '2022-11-03 01:21:23.47345+00', '2023-02-04 01:22:02.962319+00', 20286, 3, NULL, 'ace', '1-8::
    1s+2s set & cross RH; facing up/down all set & change places on the
    sides (RH on Ladies'' side, LH on Men''s).  (2) (1)
9-16::
    1s dance 1/2 Fig 8 up round 2s; 2s dance 1/2 Fig 8 down round 1s
17-24::
    2s followed by 1s (who dance up to start) lead down; turn inwards &
    1s followed by 2s lead up. 1s cast to 2nd place into centre _while_
    2s dance up to 1st place in centre, ready for …
25-32::
    2s+1s dance Promenade.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (6982, '2013-08-21 08:31:34.065786+00', '2023-02-04 01:22:03.202531+00', 5496, 3, NULL, 'ace', '1-8::
    1s cross down, cast down behind 3s, cross down & cast up around 4s
    to 3rd place
9-16::
    1s cross up, cast up behind 2s to 1st place & turn RH 1.1/2 times
17-24::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L
25-32::
    1s+4s dance 1/2 R&L & all turn RH
33-40::
    All set & dance a modified La Baratte :
::
    Men 1/2 turn partners RH & retain hand but at arm''s length from each
    other, Men retrace steps with partner turning right under his arm
    briefly into Allemande hold (Men behind partner facing Men''s
    original place) & releasing partner''s RH she turns under Mans left
    arm & all change places LH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (6985, '2013-08-21 08:31:34.089852+00', '2023-02-04 01:22:03.400918+00', 5498, 3, NULL, 'ace', '1-8::
    All set, cross RH, set & cross RH
9-16::
    1s+2s also 3s+4s dance double Fig of 8  (2s & 4s dance cast up to
    start)
17-24::
    All dance reels of 4 on sides (Men RSh reel & Ladies LSh)
25-32::
    All dance Poussette with 1s dancing to bottom', 0);
INSERT INTO 'dancecrib' VALUES (13332, '2020-11-02 01:21:32.003877+00', '2023-02-04 01:22:03.810934+00', 15268, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 down round 2s ending in centre 2H joined, 2s step in
    ready for …
9-16::
    1s+2s dance Poussette, 2s end in 1st place own side _while_ 1s turn
    2H to end 1L followed by 1M facing 2M (Lady''s 1st corner)
17-24::
    1s dance Alternating Tandem RSh reel with 1st corners. End 1L
    followed by 1M facing 3M (Lady''s 2nd corner)
25-32::
    1s dance Alternating Tandem LSh reel with 2nd corners. 1s end facing
    own 1st corner
33-40::
    1s dance ''Hello-Goodbye'' setting, Petronella turn to 2nd place own
    side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9228, '2016-06-16 22:42:14.567374+00', '2023-02-04 01:22:04.258032+00', 16835, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection (mirror) reels of 3 on sides, 1s dance in
    and down to begin
9-16::
    1s lead down the middle & back to 2nd place (2s step up 11-12)
17-24::
    1L crosses up to dance Fig of 8 around 2s _while_ 1M crosses down to
    dance Fig of 8 around 3s.
25-32::
    1s turn RH, 1s turn LH.', 0);
INSERT INTO 'dancecrib' VALUES (6377, '2013-08-21 08:31:23.285985+00', '2023-02-04 01:22:04.44283+00', 4309, 3, NULL, 'ace', '{{explanation}}
1s start on opp sides

1-8::
    1M turns 2L RH 1.1/2 times on side, 1L turns2M LH 1.3/4 times on
    side (1s end BtoB in centre facing 2s)
9-16::
    2s+1s dance reel of 4 across
17-24::
    1M+2L set & 3/4 turn RH _while_ 1L+2M set & 3/4 turn LH (1s end in
    2nd place opposite sides), 1s turn 2H
25-32::
    2s+1s circle 4H round to left 1/2 way then 1/2 R&L', 2);
INSERT INTO 'dancecrib' VALUES (6996, '2013-08-21 08:31:34.210482+00', '2023-02-04 01:22:04.490792+00', 12680, 3, NULL, 'ace', '1-8::
    1s cross down & dance reel of 3 on opposite sides
9-16::
    1s dance down middle & back
17-24::
    1L+2M changes places LH, 1L+3M RH, 1L+4M LH & 1L+ 5M RH _while_ 1M
    dances similarly with Ladies
25-32::
    2s dance Fig of 8 round 3s+4s (between 3s to start) _while_ 1s
    casting dance a Fig of 8 round 5s+4s & cross down to 5th place', 0);
INSERT INTO 'dancecrib' VALUES (6999, '2013-08-21 08:31:34.260186+00', '2023-02-04 01:22:04.802127+00', 9102, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s slip step down the middle & back
17-24::
    1s followed by 2s, 3s & 4s cast to bottom, 1s make an arch as 2s, 3s
    & 4s dance under
25-32::
    2s+3s+4s+1s clap 8 times & turn partners RH once round', 0);
INSERT INTO 'dancecrib' VALUES (14541, '2022-01-10 02:20:35.126523+00', '2023-02-04 01:22:05.208138+00', 17974, 3, NULL, 'ace', '1-8::
    1s cast (2s step up), set & turn RH 1.1/4 to end 1L facing down
    followed by partner
9-12::
    1s in tandem dance 1/2 reel of 3 with 2nd corners (RSh to 3M to
    start)
13-16::
    1L+3M+2L complete reel of 3 _while_ 1M+3L turn RH.  1s end in 2nd
    place opp side facing out
17-24::
    1s dance 6 bar reels of 3 on sides (1s LSh to 2nd corners), 1s turn
    3/4 LH to end 1M facing down followed by partner
25-28::
    1s in tandem dance 1/2 reel of 3 with 1st corners (LSh to 3L to
    start)
29-32::
    1M+3L+2M complete reel of 3 _while_ 1L+3M turn 3/4 LH to end 1s in
    2nd place own side facing out.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7013, '2013-08-21 08:31:34.393595+00', '2023-02-04 01:22:06.043068+00', 11402, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s, 1s cross down LH & cast to left to
    end 1L between 2s, 1M between 3s
9-16::
    1s dance 1/2 petronella to change places
17-24::
    1s dance reels of 3 across (LSh to dancer on left) & turn RH to end
    2nd place own side
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7014, '2013-08-21 08:31:34.403597+00', '2023-02-04 01:22:06.176487+00', 5532, 3, NULL, 'ace', '1-8::
    Ladies advance into centre & set
9-16::
    Ladies turn in Tulloch hold & end facing opposite Man
17-24::
    All set
25-32::
    All turn in Tulloch hold Men ending in the centre
33-64::
    Repeat with Men in centre
65-128::
    Repeat all of above & couples end in original places', 0);
INSERT INTO 'dancecrib' VALUES (9750, '2017-04-06 08:40:11.21864+00', '2023-02-04 01:22:06.812606+00', 13828, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s+2s set to partners then 1s+2s set to each
    other on sides
9-16::
    1s+2s+3s dance RSh reel of three on sides
17-24::
    1s set, cast (2s step up) & turn RH (4 bars).
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (7019, '2013-08-21 08:31:34.490029+00', '2023-02-04 01:22:07.00357+00', 5539, 3, NULL, 'ace', '1-8::
    1s set, turn RH, cast to 2nd place & 1/2 turn LH to end in centre
    BtoB facing opposite sides
9-16::
    1M+2L+3L also 1L+2M+3M circle 3H round & back on sides. At end 1s
    slip past each other by Left towards own side (1L passing below 1M)
    1s end in centre facing down on own sides
17-24::
    1s lead down the middle & back to top
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13334, '2020-11-02 01:21:33.769659+00', '2023-02-04 01:22:07.442995+00', 16732, 3, NULL, 'ace', '1-8::
    1M+2L cross RH & set; 1L+2M cross LH & set.  (2) (1) 3
9-16::
    2s+1s dance 1/2 R&L; 1s+2s turn partner RH, remaining in centre
    facing up in Allemande hold ready for …
17-24::
    1s+2s dance Allemande, 1s end facing 1st corner
25-32::
    1s turn 1st corner  RH, partner LH, 2nd corner RH, partner LH ending
    1M between 3s, 1L between 2s
33-40::
    1s dance reels of 3 across, 1s pass 1st corner LSh to start. 1s end
    in 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7031, '2013-08-21 08:31:34.684772+00', '2023-02-04 01:22:07.814602+00', 12896, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set, 1s+2s & 3s+4s dance RH across 1/2 way, all set
    & cross RH.  2 1 4 3
9-16::
    1s & 4s dance 1/2 Figs of 8 round end couples _while_ 2s+3s set &
    cross RH;  2s+1s also 4s+3s circle to left
17-24::
    All dance 1/2 reels of 4 on sides, 3s+4s+1s (top 3 couples) dance
    1/2 reels of 3 on sides
25-32::
    1L+2M advance (2 skip change) & turn RH, pulling back RSh on bar 28
    & lead partner clockwise round to opp end of set
::
    _while_ 3s+4s set facing on sides, change places RH, set to partners
    & cross RH.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7034, '2013-08-21 08:31:34.707654+00', '2023-02-04 01:22:07.838519+00', 5559, 3, NULL, 'ace', '1-8::
    1s+2s+3s set on sides, 1s cross down RH to 2nd place & turn 2nd
    corners LH & pass LSh to face 1st corners
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass RSh & dance
    1/2 reel with 2nd corners 1s end facing 1st corner (pstn)
17-24::
    1s set to 1st corners, set to 2nd corners, dance out ends passing
    own 1st corner (pstn) LSh & cast to 2nd place opposite sides
25-32::
    1s dance 1/2 RSh reels of 3 on sides (Man up & Lady down), 1s dance
    1/2 reels of 3 across (Man up & Lady Down)', 0);
INSERT INTO 'dancecrib' VALUES (13634, '2021-02-04 01:21:27.466397+00', '2023-02-04 01:22:07.873906+00', 5560, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H 1/2 round to left & cross RH to own side;
    1s+2s+3s circle 6H 1/2 round to right & cross LH remaining in centre
    for …
9-16::
    1s+2s+3s dance Promenade. 1s & 3s end on sides but 2s remain in
    centre facing up
17-24::
    Mirror reels of 3 on sides (1s out/down. 2s up & cast, 3s out/up)
25-32::
    1s cast to 3rd place _while_ 2s lead up & set _while_ 3s set & step
    up to 2nd place; All turn partner RH.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7041, '2013-08-21 08:31:34.782908+00', '2023-02-04 01:22:08.133174+00', 5568, 3, NULL, 'ace', '1-8::
    1s dance RSh Fig of 8 on own sides round standing 2s & 3s
9-16::
    2s+3s set, cross RH & dance RH across once round to end facing
    corner person
17-24::
    1L+2M+3L+4M dance 1/2 diagonal reel of 4 _while_ others turn corners
    RH, 1M+2L+3M+4L dance 1/2 diagonal reel of 4 _while_ others turn
    corners RH
25-32::
    Repeat
33-40::
    1s cast 1 place (2s cross up), cross RH & cast down 2 places (3s
    cross up 1 place & 4s step up) & 1s cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (12420, '2019-12-05 01:31:43.604574+00', '2023-02-04 01:22:08.896435+00', 14076, 3, NULL, 'ace', '{{explanation}}
2s start on opp sides

1-8::
    2s cross RH & cast (2M up, 2L down); 1/2 LSh reels of 3 across
    (2M+1L & 2L+3M pass LSh).  2s end in centre facing down/up
9-16::
    2s cross RH up/down, cast to right to 2nd place own side;  1/2 LSh
    reels of 3 on sides (2M up, 2L down).  (3) 2 (1)
17-24::
    R&L for 3 couples (all couples now with new partner)
25-32::
    All turn new partner RH once round & chase 1/2 way round
::
    Order now: Ladies'' side 2L 1M 1L; Men''s side 3M 3L 2M.  Repeat twice
    more from new positions', 0);
INSERT INTO 'dancecrib' VALUES (7052, '2013-08-21 08:31:34.968892+00', '2023-02-04 01:22:09.031158+00', 12733, 3, NULL, 'ace', '1-8::
    All dance interlocking reels of 4
9-16::
    All circle 8H round & back
17-24::
    All Ladies dance in & set in circle formation, turning to right
    dance back to partner & turn 2H to face in
25-32::
    All Adv+Ret with corner, set & turn corners 2H to face in
33-40::
    All Adv+Ret with partner, set & turn partners 2H to face in
41-48::
    All Men dance in & set in circle formation, turning to left dance
    back to partner & turn 2H to form circle
49-56::
    All circle 8H round & back
57-64::
    All dance interlocking reels of 4', 0);
INSERT INTO 'dancecrib' VALUES (8354, '2014-07-29 12:59:25.735336+00', '2023-02-04 01:22:09.289355+00', 15059, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate
9-12::
    1s dance 1/2 Fig 8 round 3s (1M round 3L, 1L round 3M)
13-20::
    1s dance Reflection reels of 3 on opposite sides (2s down/out, 1s
    in/up, 3s out/up to start)
21-24::
    1s cross up between 2s, cast to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15147, '2022-10-05 00:21:37.903748+00', '2023-02-04 01:22:09.320173+00', 20782, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Inveran reels (1s cross down to start, cross from 3rd
    place to continue reel on own side)
9-16::
    1s set, dance down NHJ between 2s, out and down round 3s, meet &
    lead up to face 1st corners (2s step up 11-12)
17-24::
    1s dance RSh round 1st corners & turn RH 1.1/2 to face 2nd corners
    _while_ corners cross RH to diag opp place & chase clockwise 1/2
    round back to place
25-32::
    1s+2nd corners repeat 17-24. 1s end in 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7064, '2013-08-21 08:31:35.071162+00', '2023-02-04 01:22:09.579656+00', 5616, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels of 3 on sides with all couples dancing "double"
    Inveran Reels - top couples crossing down to 2nd place opposite
    sides & casting down round 3rd place as bottom couples cross up to
    2nd place & middle couples cast up to top place, 1s continue reel to
    2nd place own sides as 2s cast up to 1st pl ending 2 1 3 4
9-16::
    1s set & cast down 1 place, all circle 4H round to left (2s+3s
    &1s+4s)
17-24::
    1s set & cast down to bottom & all turn RH with 2s & 4s turning
    1.1/2 times to face down  2(3)4(1)
25-32::
    All dance a reel of 4 in prom hold & end with couples in 2nd & 3rd
    places (3s & 4s) passing RSh as 2s & 4s end on own sides', 0);
INSERT INTO 'dancecrib' VALUES (7065, '2013-08-21 08:31:35.079214+00', '2023-02-04 01:22:09.603259+00', 9023, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, dance down between 3s & cast up to face
    1st corner
9-16::
    1s dance 1/2 reel of 4 with 1st corners, pass RSh & dance 1/2 reel
    with 2nd corners & end in middle 1L facing up to 2s & 1M down to 3s
17-24::
    1s dance up/down & cast to 2nd place own sides _while_ corners set &
    cross RH, 3s+1s+2s turn RH into Allemande hold
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7077, '2013-08-21 08:31:35.254199+00', '2023-02-04 01:22:10.203056+00', 5636, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 2 places & dance up to 2nd place in prom hold
9-16::
    2s+1s+3s (in prom hold) dance reel of 3 in centre (1s giving RSh to
    2s to start) & end on sides
17-24::
    1s cross RH, cast down 1 place, cross LH, cast down 1 place & dance
    up to 3rd place in prom hold
25-32::
    3s+1s+4s (in prom hold) dance reel of 3 in centre (1s giving RSh to
    3s to start) & end on sides (2,3,1,4)
33-40::
    1s+4s set, dance 1/2 RH across, set & cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (14804, '2022-05-05 00:21:28.521413+00', '2023-02-04 01:22:10.770233+00', 17111, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    Ladies dance behind partner & into centre, join RH with partner &
    dance LH across. Ladies leave partner in opp place, continue LH
    across back to place & face out
9-16::
    Ladies dance anticlockwise behind corner to next place  & all set;
    All Adv+Ret with new partners
17-24::
    Couples in 1st & 3rd places dance Ladies'' Chain
25-32::
    Couples in 2nd & 4th places dance R&L & finish facing partners on
    corners
33-40::
    All couples dance Interlocking reels of 4 (pass partner RSh to
    start)
41-48::
    All set to partner, turn RH into prom hold & promenade anticlockwise
    to original places

{{title}}
Reel

1-16::
    Repeat Strathspey bars 1-16 but with Men leading
17-24::
    Couples in 1st & 3rd places dance Men''s Chain
25-32::
    Couples in 2nd & 4th places dance R&L & finish facing partners on
    corners
33-48::
    Repeat Strathspey bars 33-48', 0);
INSERT INTO 'dancecrib' VALUES (7093, '2013-08-21 08:31:35.516227+00', '2023-02-04 01:22:11.218794+00', 8628, 3, NULL, 'ace', '1-8::
    1s set advancing & dance around each other RSh, cast 1 place & set
    advancing to 1st corners
9-16::
    1s dance 1/2 reel of 4 with 1st corners, pass LSh to turn 2nd
    corners RH & pass RSh to face 1st corners
17-24::
    1s turn 1st corners LH, pass LSh to dance 1/2 reel of 4 with 2nd
    corners & pass partner LSh to…
25-32::
    1s dance RH across on own side (1M with 3L+2L, 1L with 3M+2M), 1s
    turn 2H & twirl out to 2nd place _while_ 2s+3s chase clockwise 1/2
    way', 0);
INSERT INTO 'dancecrib' VALUES (7098, '2013-08-21 08:31:35.604086+00', '2023-02-04 01:22:11.737472+00', 13613, 3, NULL, 'ace', '1-8::
    1s cross down RH to 2nd place opposite sides & 2s+1s set, 1s cross
    down LH to 3rd place own sides & 3s+1s set
9-16::
    All dance reflection reels of 3 with (1s & 2s cast to start) but 1s
    cross up LH from 2nd place to 1st place opposite sides & end 2 3(1)
17-24::
    1s cast up to 2nd pl as 3s dance down & loop round into 3rd pl, 1s
    1/2 turn & twirl out to 2nd pl own sides then cast right to end
    between 2s/3s
25-32::
    1M turns 1L under his right arm as 2s & 3s 1/2 turn & all dance the
    Knot to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7100, '2013-08-21 08:31:35.620963+00', '2023-02-04 01:22:11.791414+00', 5669, 3, NULL, 'ace', '1-8::
    1s+2s set, turn 2H & circle 4H round to left
9-16::
    1s+2s dance reel of 4 across (1M+2L pass LSh to start) & end with
    1L+2M turning LH to give RH to partner (diagonal line)
17-24::
    1s+2s Bal-in-Line (Rocking step or alternative), 1L+2M turn LH 1.1/2
    times to own sides (1L to 2nd pl & 2M to 1st pl) _while_ partner
    chase 3/4 round
25-32::
    1s+2s set twice (diagonally in) & dance 2 couple DoSiDo: dance in
    diagonally move round to right & dance backwards to pl (or RH
    across)', 0);
INSERT INTO 'dancecrib' VALUES (7107, '2013-08-21 08:31:35.748371+00', '2023-02-04 01:22:12.1463+00', 5687, 3, NULL, 'ace', '1-8::
    1s cast 1 place & dance 1/2 Fig 8 round 2s, 1s turn LH to face 1st
    corners
9-16::
    1s set to 1st corners, set to partner & face 2nd corners, 1s dance
    1/2 diagonal RSh reel of 4 with 2nd corners & end facing 4th corner
    (pstn)
17-24::
    1s set to 4th corners, set to partner & face 1st corners, 1s dance
    1/2 diagonal RSh reel of 4 with 1st corners & pass LSh to…
25-32::
    1s dance RH across (Man with 3s at top & Lady with 2s), 1s turn LH
    1.1/2 times to 2nd place _while_ 3s+2s chase clockwise 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (7108, '2013-08-21 08:31:35.758081+00', '2023-02-04 01:22:12.228628+00', 5688, 3, NULL, 'ace', '1-8::
    1L+2M 3/4 turn RH & set to each other (Man facing up & Lady down),
    1L+2M turn 1/2 LH back to places & set
9-16::
    1M+2L repeat above Fig
17-24::
    1s lead down the middle & back ready for Allemande
25-32::
    1s+2s dance Allemande
33-40::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7118, '2013-08-21 08:31:36.047332+00', '2023-02-04 01:22:13.021219+00', 14649, 3, NULL, 'ace', '1-8::
    1s lead down to bottom & cross to cast up to 2nd pl on opp sides, 1s
    dance 1/2 Fig of 8 (L up round 2s, M down).  2 1 3
9-16::
    All cross RH & chase clwise 1/4 way into lines across, all change
    places with partner RH & chase clwise to opp sides.  (3)(1)(2)
17-24::
    1s change places RH with person diagonally to right & new centre
    couple LH with person diag left, new centre cpl RH diag right & 2s
    (at top) cross RH as 1s & 3s 1/2 turn RH into Allemande hold
25-32::
    1s+3s dance Allemande.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7120, '2013-08-21 08:31:36.070143+00', '2023-02-04 01:22:13.259506+00', 5710, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, lead down between 3s & cast up to 2nd place
    own sides
9-16::
    1s dance 1/2 reels of 3 across (1L with 2s, 1M with 3s) & change
    into 1/2 reels with other couple
17-24::
    2s+1s+3s set facing partners twice & 1s turn RH 1.1/4 times to end
    1M between 2s facing 1L between 3s
25-32::
    1s dance 1/2 reels of 3 on opposite sides & change into 1/2 reels of
    3 on own sides ending between 2s/3s as bar 24
33-40::
    2s+1s+3s set in lines across twice & 1s turn LH 1.1/4 times to 2nd
    place own sides', 0);
INSERT INTO 'dancecrib' VALUES (14805, '2022-05-05 00:21:31.149096+00', '2023-02-04 01:22:13.770665+00', 17112, 3, NULL, 'ace', '{{explanation}}
Square set, 5s in centre, 5L facing up, 5M facing down

1-8::
    1s+2+3s+4s circle 8H round & back _while_ 5s set, 1/2 turn RH, set &
    1/2 turn LH to end 5L facing 1s & 5M facing 3s
9-10::
    5L+1L & 5M+3M change places RH
11-12::
    5L+1M, 5M+3L, 1L+3M turn LH
13-14::
    5L+1L & 5M+3M change places RH
15-16::
    1L+1M & 3L+3M turn LH _while_ 5L+5M turn 3/4 LH to 5L facing 2L, 5M
    facing 4M
17-18::
    5L+2L & 5M+4M change places RH
19-20::
    5L+2M, 5M+4L, 1L+4M turn LH
21-22::
    5L+2M & 5M+4M change places RH
23-24::
    2s & 4s turn LH _while_ 5s turn 3/4 LH to end 1M followed by 1L
    facing 1s
25-32::
    All couples in tandem (Man leading) change places passing RSh as
    follows: 5s+1s, 1s+4s, 4s+3s, 3s+2s

{{explanation}}
Repeat with new couple (2s) in centre', 0);
INSERT INTO 'dancecrib' VALUES (8628, '2015-02-13 12:48:12.799819+00', '2023-02-04 01:22:14.373705+00', 15648, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig 8 round 2s _while_ 2s+3s set, cross RH.  1s+2s+3s
    set, turn RH 1/2 way to face up in promenade hold
9-16::
    1s+2s+3s promenade, 1s cast to face 1st corners, 2s finish in 1st
    place
17-24::
    1s set to corners.  1s pass 2nd corners RSh to 2nd place opp. sides
    & cross RH to own sides
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (7136, '2013-08-21 08:31:36.329142+00', '2023-02-04 01:22:14.402423+00', 5741, 3, NULL, 'ace', '1-8::
    1s dance in & cast to face 2nd corner, set to & turn corner 2H to
    face 1st corner
9-16::
    _1/2_ reels of 3 on sides, 1s giving LSh to 1st corner; 1/2 reels of
    3 across, 1s giving RSh to 4th corner position. 1s end in 2nd place
    own sides (3)1(2)
17-24::
    3s+1s+2s Adv+Ret for 1 step & cross passing RSh, 1s cast round 2nd
    corner into lines across (M between 3s in 1st place & L between 2s)
25-32::
    All Adv+Ret for 1 step, change places with opposite person passing
    RSh & 1s cast round 4th corner to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (14682, '2022-03-07 02:21:32.111496+00', '2023-02-04 01:22:14.76182+00', 20657, 3, NULL, 'ace', '1-8::
    Mirror reels of 3 on sides (1s in/down, 2s out/up, 3s in/up)
9-16::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s
17-24::
    1s cross down below 3s to dance 1/2 reel of 3 on opp sides; 1s cross
    up above 1st place to dance 1/2 reel of 3 on own side (2s+3s dance
    full reel of 3 on own sides, 2s dance out/down, 3s out/up to start)
25-32::
    2s+1s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7172, '2013-08-21 08:31:36.790517+00', '2023-02-04 01:22:16.536093+00', 14924, 3, NULL, 'ace', '{{title}}
Strathspey

1-::
    _8_     1s set & cast 1 place, dance between 3s & cast to face 1st
    corners
9-16::
    Turn corner, partner, corner & 3/4 turn partner…

{{title}}
Reel

17-24::
    1s dance RH across (1L with 2s, 1M with 3s), 1s dance LH across with
    other couple
25-32::
    All set in double triangle formation up/down & 1s petronella turn to
    2nd places opposite sides, 1s cross RH & cast to bottom', 0);
INSERT INTO 'dancecrib' VALUES (13191, '2020-09-15 00:21:29.130044+00', '2023-02-04 01:22:16.589017+00', 18506, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reels of 3 on own sides
17-24::
    1s+2s Set+Link, 1s+3s Set+Link 2 3 1
25-32::
    All dance 6H round to the left for 6 steps, pivot & chase back to
    places', 0);
INSERT INTO 'dancecrib' VALUES (7175, '2013-08-21 08:31:36.817141+00', '2023-02-04 01:22:17.443744+00', 5857, 3, NULL, 'ace', '1-8::
    1s cast to 4th place & lead up to 1st place
::
    as 2s set & cross RH, cast to 4th place & cross RH
::
    as 3s dance Fig of 8 round 2nd positions
::
    as 4s turn RH & cast down & follow 1s up middle to 2nd place.  1 4 3
    2
9-12::
    4s+3s+2s dance 1/2 reflection reels of 3 on sides (3s in & down
    between 2s to start).  1 2 3 4
13-16::
    1s+2s+3s dance 1/2 reflection reels of 3 on sides (2s out & up
    between 1s to start).  3 2 1 4
17-24::
    All set & 3s+2s also 1s+4s dance 1/2 R&L then all cross RH
25-32::
    All circle 8H round & back.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7177, '2013-08-21 08:31:36.850576+00', '2023-02-04 01:22:17.596644+00', 8206, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1M followed by partner cast down to 3rd place & cross to opposite
    sides, 3s+1s dance LH
17-24::
    3s+1s dance RH across, 1L followed by partner cast up to top & cross
    to own sides
25-32::
    1s dance 1/2 Fig of 8 round 2s+3s on own sides (in between 2s to
    start) & 2s+3s+1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (7184, '2013-08-21 08:31:36.911163+00', '2023-02-04 01:22:17.883482+00', 5862, 3, NULL, 'ace', '{{explanation}}
2 chords, on 2nd chord 2s & 3s advance to centre & turn BtoB to face corners

{{title}}
Strathspey

1-8::
    2s & 3s turn corners RH, pass LSh to face 2nd corner & repeat to end
    facing 1st corners
9-16::
    Repeat bars 1- 8
17-24::
    1s+2s also 3s+4s dance double Fig of 8 (2s & 3s crossing up/down to
    start)
25-32::
    2s+3s dance RH across, 1s+2s also 3s+4s dance LH across

{{title}}
Reel

1-8::
    1M+4L cross diag RH, dance out other end & dance back to place
    _while_ 1L+4M cast down own side to other end & cross back to place
    up/down RH
9-16::
    All 3/4 turn RH & Bal-in-Line in centre, 1/2 turn partner&
    petronella to own side
17-24::
    All dance reels of 4 on sides ending with 2s & 3s in prom hold
25-32::
    2s & 3s dance up/down under arches made by 1s/4s & cast round to
    left & dance down/up under other arch & cross to own sides as 1s &
    4s advance to centre & turn to face corners.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (14219, '2021-08-14 00:21:44.485546+00', '2023-02-04 01:22:18.638285+00', 12422, 3, NULL, 'ace', '1-4::
    1s dance in & lead down to end between 2s (2 bars), turn RH (2 bars)
    (2s step up on bars 3-4)
5-8::
    1s pass RSh, dance out between corners, cast right round 1st corners
    to finish between corners facing 1st corner
9-16::
    1s set to & turn 1st corners 2H, 1s pull back RSh to face 2nd
    corners. 1s set to & turn 2nd corners 2H to finish between corners
17-24::
    1s set to & turn partner 2H, to finish facing up; 1s lead up, cross,
    cast round 2nd couple to meet in centre with 3s (who step in on bar
    24) ready for …
25-32::
    1s+3s dance 1/2 Diamond Poussette. 1s+4s dance 1/2 Diamond Poussete
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12168, '2019-09-04 21:42:19.088451+00', '2023-02-04 01:22:18.676649+00', 19571, 3, NULL, 'ace', '1-4::
    1s & 4s set & cross RH _while_ 2s+3s circle left
5-8::
    1s & 4s set _while_ 2s & 3s cross RH & 1s+4s cross diagonally LH
    (down/up) to 2nd/3rd place _while_ 2s & 3s cast up/down to ends.
    2(1)(4)3
9-16::
    Repeat bars 1-8 from new positions.  (1)(2)(3)4)
17-24::
    1s+2s & 3s+4s dance LH across (2M & 3L face out), 2M also 3L
    followed by partner cast to end in line in middle (M facing up, L
    facing down)
25-32::
    2s+3s dance reel of 4 _while_ 1s & 4s stand for 4 bars & set across
    then set facing
33-40::
    1s dance down sidelines & 1/2 turn 4s 2H _while_ 2s & 3s set &
    petronella turn to opposite sides & all turn 1.1/2 times.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7193, '2013-08-21 08:31:37.091359+00', '2023-02-04 01:22:19.070381+00', 11982, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 3s
9-16::
    4s cross RH, cast up 1 place & dance 1/2 Fig of 8 round 1s (in 2nd
    place)
17-24::
    1s+4s dance 1/2 R&L & turn partners RH 1.1/2 times
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14220, '2021-08-14 00:21:44.94493+00', '2023-02-04 01:22:19.149835+00', 5882, 3, NULL, 'ace', '1-8::
    1s 1/2 turn 2H, face partner & set; all cast (pull back RSh) & chase
    clockwise 1/2 round to own side (Men follow 4M, Ladies follow 1L).
    End 4 3 2 1
9-12::
    1s+4s 1/2 turn partner RH moving towards centre to dance 1/2 RH
    across ending in original places
13-16::
    3s+2s 1/2 turn partner RH & dance 1/2 RH across ending in original
    places. 1 2 3 4
17-20::
    1L+2M & 3L+4M change places passing RSh, all 1/2 turn partner 2H on
    side opening out for …
21-24::
    1s+2s & 3s+4s circle 4H round 1.1/4 to left.  End 1s & 3s facing
    down, 2s & 4s facing up NHJ with partner (1s face 2s, 3s face 4s)
25-28::
    All set advancing to pass facing couple, 1s+4s set advancing to pass
    _while_ 2s/3s drop hands & dance up/down & cast to 1st/4th place
29-32::
    4s dance up & cast to 2nd place _while_ 1s dance down & cast up to
    3rd place.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8358, '2014-07-29 12:59:27.68677+00', '2023-02-04 01:22:19.725733+00', 5894, 3, NULL, 'ace', '1-8::
    Reflection reels of 3 on sides 1s cross down bars 1-2, 3s cross down
    bars 5-6 (1) 2 (3)
9-16::
    1s+2s+3s circle 6H round and back
17-24::
    1s cross down below 2s & cast behind 3s into 3rd place own side
    (2s+3s step up 19-20); 1s+3s dance 1/2 RH across, 2s+1s+3s set
25-28::
    1s cross up to top, cast off to 2nd place and meet _while_ 2s cast
    off 1 place, dance up & 2s+1s join both hands with partners
29-32::
    2s+1s turn partners 2H once round and retire to own sides [2nd rpt -
    1s retire to bottom place, bottom couple step up]', 0);
INSERT INTO 'dancecrib' VALUES (9042, '2015-11-30 09:00:16.10972+00', '2023-02-04 01:22:19.740215+00', 10591, 3, NULL, 'ace', '1-4::
    All change places RH with corners.  Men turn new partner 3/4 LH so
    Ladies in centre
5-8::
    Ladies dance RH across 1/2 way & turn original partner 1/2 LH,
    retain hands & Men in centre join RH, Ladies facing anticlockwise
9-12::
    Modified Spoke:
::
    Men set advancing (1 step), Bal-in-Line with next Lady, set
    advancing (1 step) & Bal-in-Line with new partner
13-16::
    All turn new partners 1.1/2 LH retaining hands & Ladies in centre
    join RH, Men facing anticlockwise
17-20::
    Ladies repeat bars 9-12 to return to original partner
21-24::
    All turn partners 3/4 with LH to reform square set
25-32::
    All circle 8H round and back .  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7214, '2013-08-21 08:31:37.359958+00', '2023-02-04 01:22:20.24918+00', 5906, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast round 2s, lead up & cross to places
9-16::
    2s set, cross RH, cast up round 1s, lead down & cross to places
17-24::
    1s followed by 2s lead down the middle & 2s followed by 1s lead back
    to top
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (9487, '2016-11-09 08:48:58.340321+00', '2023-02-04 01:22:20.279788+00', 5907, 3, NULL, 'ace', '1-8::
    1M+2L dance Fig 8 round partners (1M+2L pass RSh, round partner LSh,
    pass RSh back to places).
9-16::
    1s+2s dance R&L
17-24::
    1L+2M dance Fig 8 round partners (1L+2M pass LSh, round partner RSh,
    pass LSh back to places).
25-32::
    1s+2s dance The Knot', 0);
INSERT INTO 'dancecrib' VALUES (11000, '2018-08-17 07:52:56.011617+00', '2023-02-04 01:22:20.324754+00', 9800, 3, NULL, 'ace', '1-8::
    1s dance in & cast (2s step up); 1s turn 1.1/4 LH to face 1st
    corners
9-16::
    1s set to corners, turn corner RH to end 1L between 2s facing 2L &
    1M between 3s facing 3M.  1/2 LSh reels of 3 across ending in lines
    of 3 across facing down/up
17-24::
    All Adv+Ret; 1s dance RSh round each other to face 3rd corner pstns
25-32::
    Repeat 9-16 ending with 2s+3s facing in & 1s facing each other
    up/down
33-40::
    1s set advancing joining RH, set with Lady turning under Man''s arm.
    1s face up RH joined, lead up, cross & cast.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7222, '2013-08-21 08:31:37.425204+00', '2023-02-04 01:22:21.035601+00', 5932, 3, NULL, 'ace', '1-8::
    1s set, cross down RH to 2nd place, cast to right & dance down/up to
    end with nearer hands joined in centre facing Ladies side
9-16::
    1s dance reels of 3 across (Lady LSh to 2L & Man RSh to 3L)
17-24::
    1s dance reels of 3 on own sides (1s out & up to start) giving hands
    & end in centre with RH joined in order 21 3
25-32::
    All set twice with Lady turning under Man''s arm bars 27-28 (as in
    "Gay Gordons") & all turn RH (4 bars)', 0);
INSERT INTO 'dancecrib' VALUES (14588, '2022-02-05 02:21:30.992911+00', '2023-02-04 01:22:21.497312+00', 20611, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    2L dances Fig 8 round 1s _while_ 2M dances Fig 8 round 3s
9-16::
    1M+3L pass RSh to dance Fig 8 round 2s
17-24::
    1L+3M pass LSh to dance Fig 8 round 2s
25-32::
    1s cross RH, cast 2 places (2s+3s step up); 1s turn 2H 1.1/2 round.
    2 3 1

{{title}}
Reel

{{explanation}}
note new numbering applies

33-40::
    2s (i.e. new 2nd couple) repeat bars 1-8 of Strathspey
41-48::
    1M+3L repeat bars 9-16 of Strathspey
49-56::
    1L+3M repeat bars 17-24 of Strathspey but bar 56 all 3 couples dance
    in to face partner for …
57-64::
    All dance 3 couple Poussette

{{explanation}}
Note:  lead couple end in 3rd place after each 32 bars so numbering changes. After 32 Strathspey/32 Reel x 3, each couple has lead in both rhythms', 0);
INSERT INTO 'dancecrib' VALUES (7234, '2013-08-21 08:31:37.542106+00', '2023-02-04 01:22:21.727732+00', 7511, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s turn RH, cast 1 place & turn 1.1/2 times to end facing 1st
    corners
17-24::
    1s dance reels of 3 across giving LSh to 1st corner (Lady with 2s &
    Man with 3s) & end in 2nd place on own side
25-32::
    2s+1s+3s Adv+Ret for 2 steps & dance DoSiDo', 0);
INSERT INTO 'dancecrib' VALUES (7241, '2013-08-21 08:31:37.634045+00', '2023-02-04 01:22:22.5897+00', 11399, 3, NULL, 'ace', '1-8::
    1L+2L change places LH as 1M+2M change RH. 1L+3L change LH as 1M+3M
    change RH, 3s face out. 2s+3s+1s dance 1/2 reflection reels of 3 on
    sides (1s in & up to start).  1 3 2
9-16::
    1s cross RH, face out then 1s+2s dance The Capstan around standing
    3s:
::
    1s cast 2 places, dance up to top & cast back to 3rd place _while_
    2s dance up to top, cast off & dance back up to the top 2 3 (1)
17-20::
    1s+3s turn 1.1/2 times (1M+3L RH, 1L+3M LH). 1s end in centre facing
    up, 3s in 3rd place facing in/up.
21-24::
    1L+2M+3M dance LH across _while_ 1M+2L+3L dance RH across & 1s end
    facing 2nd corners (1L pull back LSh to face 3M)
25-32::
    1s set to 2nd corners, set to 1st corners, 1L dances up between 2s &
    casts to 2nd place own side as 1M dances down between 3s & casts to
    2nd place own side 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7245, '2013-08-21 08:31:37.670088+00', '2023-02-04 01:22:22.815659+00', 5981, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, turn LH & cast to 3rd places
9-16::
    3s+1s dance 1/2 Poussette within the set, set to 1st corners, set to
    2nd corners & 1s end in centre facing down (Lady on Mans left)
17-24::
    1s+3s circle 4H round & back
25-32::
    2s+1s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (14223, '2021-08-14 00:21:48.142499+00', '2023-02-04 01:22:23.096287+00', 11546, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 on own side (in/down to start, giving hands)
9-16::
    1s followed by 2s & 3s lead down, 2s & 3s separate & follow 1s who
    lead up.  All remain in centre ready for …
17-24::
    1s+2s+3s dance Allemande
25-32::
    2s+3s+1s circle 6H round & back.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7248, '2013-08-21 08:31:37.696077+00', '2023-02-04 01:22:23.124228+00', 12807, 3, NULL, 'ace', '1-4::
    1s+2s+3s set & 1/2 turn partners 2H to face up
5-8::
    1s followed by 2s+3s dance up, cast to 3rd pl & 1s dance up to face
    1st corners _while_ 2s cross up & cast to 3rd pl & 3s cross up &
    cast to 1st pl
9-16::
    1s set to & turn 1st corners (pstns) 2H to face 2nd corners, set &
    turn 2nd corners 2H to end between corners
17-24::
    1s dance 1/2 reels of 3 on opposite sides (LSh to 1st corners pstn)
    & dance 1/2 reels of 3 across (LSh to 3rd corners) to end 2nd place
    own sides
25-32::
    1s+2s dance 1/2 double Fig of 8 (1s cross up, 2s cast to start),
    1s+3s dance 1/2 double Fig of 8 (1s cross down, 3s cast up to start)', 0);
INSERT INTO 'dancecrib' VALUES (9407, '2016-10-06 07:18:54.240386+00', '2023-02-04 01:22:23.421867+00', 14819, 3, NULL, 'ace', '1-4::
    All set. All petronella turn with 1M & 3L solo but 1L+2L also 2M+3M
    in tandem
5-8::
    LH across, 1M+1L+2L also 3L+3M+2M. Bar 8 1M+3L pass LSh to side by
    side facing opp sides
9-10::
    _1/2_ RH across, 3L+2L+1L also 1M+2M+3M
11-14::
    1M crosses to Men''s side & dances up to 1M place as 2M+3M continue
    RH across & then follow 1M to original places.  Ladies dance similar
    with 3L crossing to Ladies'' side & down to 3L place followed by
    2L+1L
15-16::
    All set advancing ready for...
17-24::
    1s+2s+3s dance Poussette for 3 couples (1s end 3rd place)
25-32::
    2s+3s+1s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (12423, '2019-12-05 01:31:55.913188+00', '2023-02-04 01:22:23.444566+00', 17524, 3, NULL, 'ace', '1-8::
    1s+2s dance reel of 4 across in 2nd place (1L+2M pass LSh). End 2s
    in original place, 1s in middle facing down with 1M behind 1L
9-16::
    1s dance down (2 bars), turn by the right (bar 3) to face up with 1M
    leading. 1s dance up, cast to 3rd place own sides (2s+3s step up
    15-16).  2 1 3
17-24::
    2s+1s face in diagonally & all set, dance in 1 step to form circle,
    pull back RSh, dance out, pull back RSh to face in & all set
25-32::
    2s+3s+1s circle 6H round & back. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7268, '2013-08-21 08:31:38.026536+00', '2023-02-04 01:22:24.308049+00', 9124, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s, 1s dance 1/2 Fig of 8 round 3s as 2s
    step up
9-16::
    1s dance up to 2s (who face down), join hands & set, 1s 3/4 turn 2s
    with nearer hand & 2s+1s set to partners
17-24::
    2s+1s+3s circle 6H round & back
25-32::
    1s+3s dance non-progressive Knot (usual Knot but end dancing 1/2 LH
    across)', 0);
INSERT INTO 'dancecrib' VALUES (7269, '2013-08-21 08:31:38.199373+00', '2023-02-04 01:22:24.509987+00', 6030, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across 1/2 way & set, 1s+3s dance LH across 1/2 way &
    set
9-16::
    1s+3s dance 1/2 R&L, 2s+1s dance 1/2 R&L
17-24::
    1s lead down below 3s, cast up behind 3s, lead up between 2s & cast
    to 2nd place
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7276, '2013-08-21 08:31:38.280634+00', '2023-02-04 01:22:25.260691+00', 8486, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round & back
9-16::
    1s+2s+3s dance Grand Chain
17-24::
    1s cross RH, cast 2 places, 1/2 turn RH & dance up to 2nd place
25-32::
    1L+2L+3L dance RH across _while_ partners dance LH across, 1s dance
    up to top & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (8632, '2015-02-13 12:48:14.709821+00', '2023-02-04 01:22:25.5052+00', 15588, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s lead down the middle for 4 bars, 1/2 turn RH & dance up to 2nd
    place in double triangle position facing opp sides
9-12::
    2s+1s+3s Adv+Ret for 1 step, & 1s dance out turning right about to
    face in _while_ 2s & 3s dance in & turn right about to face out
13-16::
    Repeat to end facing 1st corners
17-24::
    1s turn 1st corner RH & pass partner RSh to face 2nd corner, turn
    2nd corner LH & pass partner RSh to 2nd place own side
25-32::
    1s+3s dance Diamond Poussette

{{title}}
Reel

1-8::
    1s dance down the middle for 4 bars, 1/2 turn RH dance up to 3rd
    place in middle
9-16::
    1M with 3L+4L dance RH across _while_ 1L dances LH across with
    3M+4M, 1s pass RSh to dance L/RH across on own sides & end facing
    1st corners
17-24::
    1s turn 1st corner RH & pass partner RSh to face 2nd corner, turn
    2nd corner LH & pass partner RSh to 3rd place in middle (4s step in)
25-32::
    1s+4s dance Poussette.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14224, '2021-08-14 00:21:50.350002+00', '2023-02-04 01:22:26.115549+00', 14655, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & cross RH; set & 1s turn partner RH to face down
    _while_ 2s & 3s turn partner 1/2 RH to face up. All take prom hold
9-16::
    1s+2s+3s dance reel of 3 up/down centre (1s & 2s pass RSh to start).
    1s+2s remain in centre facing each other _while_ 3s end in 3rd place
17-24::
    1s+2s dance RH across; 1s cross RH & cast _while_ 2s turn RH moving
    up to 1st place own side
25-32::
    1s dance down NHJ, cast up round 3s to 2nd place own side; all turn
    partner RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7290, '2013-08-21 08:31:38.432403+00', '2023-02-04 01:22:26.132871+00', 9012, 3, NULL, 'ace', '1-8::
    1s lead down the middle & up to 2nd place in middle
9-16::
    1s in prom hold dance 1/2 diagonal reel of 3 with 2L+3M (RSh to 2L
    to start) & dance 1/2 diag reel of 3 with 2M+3L (RSh to 2M to start)
17-24::
    1s dance 1/2 reel of 3 across with 2s (3rd pl) (LSh to 2M) & 1/2
    reel of 3 with 3s (LSh to 3L), 1s end in 2nd place (middle) facing
    1M down & 1L up
25-32::
    1s set & petronella turn to 2nd place own sides, 3s+1s+2s turn RH
33-40::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (10453, '2018-02-24 07:53:17.936085+00', '2023-02-04 01:22:26.919798+00', 14453, 3, NULL, 'ace', '1-8::
    All Ladies dance 3/4 RH across, dancing out to position facing ''new''
    Man, all set, all turn RH
9-16::
    All Men dance 3/4 LH across, dancing out to position facing ''new''
    Lady, all set, all turn LH (all new pairs now facing partners across
    set)
17-24::
    End couples (2s & 4s with ''new'' partners) cross RH with own
    partners, Ladies cast & followed by ''new'' partner dance clockwise
    1/2 way round outside.  Man dances in between & Lady round side
    couple, into centre pulling back RSh to face own partner & turn 2H
    to original places
25-32::
    Side couples (1s+3s) repeat 17-24
33-40::
    8H round and back

{{explanation}}
Repeat once more in strathspey time & twice in reel time', 0);
INSERT INTO 'dancecrib' VALUES (7310, '2013-08-21 08:31:38.796069+00', '2023-02-04 01:22:27.140487+00', 6091, 3, NULL, 'ace', '1-8::
    1s+2s+3s cross RH & set, cross back RH & set
9-16::
    1s & 3s dance double Fig of 8  round 2s (3s casting)
17-24::
    1s followed by 2s+3s dance down, 1s followed by 2s+3s (who part to
    let 1s thru) dance back to top
25-32::
    1s+2s dance the Rondel', 0);
INSERT INTO 'dancecrib' VALUES (7311, '2013-08-21 08:31:38.805848+00', '2023-02-04 01:22:27.175172+00', 9093, 3, NULL, 'ace', '1-8::
    1s set advg, turn about (1M to left & 1L to right) to face own side,
    turn 2s with nearer hand to end in 2nd pl, 1s repeat with 3s to end
    in 3rd pl
9-16::
    1s dance 1/2 Fig of 8 round 3s, dance up to top & cast to 2nd place
    opposite sides
17-24::
    1s dance 1/2 reels of 3 across (1L with 2s & 1M with 3s) into 1/2
    reel of 3 on own sides  (3) 1 (2)
25-32::
    1s+2s dance RH across, 1s turn LH _while_ 2s+3s chase clockwise 1/2
    way', 0);
INSERT INTO 'dancecrib' VALUES (7330, '2013-08-21 08:31:38.975856+00', '2023-02-04 01:22:28.257546+00', 12900, 3, NULL, 'ace', '1-8::
    All dance reflection reels of 4 on sides (1s & 3s dance in & down)
9-12::
    1s cross RH, 1s+2s change places LH on sides, 1s cross RH, 1s+3s
    change places LH on sides
13-14::
    1s cross RH, 1s+4s change places LH on sides
15-16::
    1s cross RH to own side 4th place
17-24::
    All set, turn partner 2H, 2s+3s also 4s+1s circle 4H round to left
    into…
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7334, '2013-08-21 08:31:39.014387+00', '2023-02-04 01:22:28.95427+00', 8814, 3, NULL, 'ace', '1-8::
    1s & 3s, in promenade hold (Lady on left), dance reels of 3 across
    with 2s/4s (RSh to 2M/4M)
9-16::
    Mirror reels of 4 on sides (1s & 3s dance in/down between 2s/4s to
    start)
17-24::
    All Promenade
25-32::
    1s cast to 4th place & all turn RH (4 bars). End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9412, '2016-10-06 07:18:55.40008+00', '2023-02-04 01:22:29.517404+00', 17236, 3, NULL, 'ace', '1-8::
    1s lead down the middle and back finish in the centre facing up (2s
    step up 7-8)
9-16::
    1s dance Fig. 8 round 2s
17-24::
    2s+1s+3s turn RH (4bars) chase clockwise to finish on opp side
25-32::
    3s+1s+2s turn LH (4bars) chase anticlockwise to finish on own side
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14917, '2022-06-27 00:21:56.942403+00', '2023-02-04 01:22:29.651917+00', 16572, 3, NULL, 'ace', '1-8::
    All 3 couples set & dance 6 bar mirror reels of 3 on sides (1s dance
    in/down to start).  1 2 3
9-12::
    1M+2L 1/2 turn 2H, 1M dances into 2M''s place & 2L into 1L''s place
    _while_ 1L+2M chase anticlockwise 3 places round to end opposite
    partner
13-16::
    All 3 couples set & turn partner RH into promenade hold facing up
17-24::
    All dance promenade
25-32::
    1M+3s also 1L+2s dance RH across; 1s followed by 3s dance up to top,
    1s cast to 3rd place, 3s to 2nd place.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (8787, '2015-06-15 11:41:11.225728+00', '2023-02-04 01:22:29.787824+00', 16153, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up), 1s turn 3/4 RH to finish 1M between
    3s all facing up, 1L between 2s all facing down.  Lines of 3 set
9-12::
    _1/2_ reels of 3 across (1s pass 1st crnr RSh) 1s end BtoB in middle
    (1M facing down, 1L facing up)
13-16::
    All set as in Double Triangles, 1s petronella turn to 2nd place own
    sides as 2s+3s continue to set   (2) 1 (3)
17-20::
    _1/2_ reel of 3 on sides (1s pass 4th crnr pstn RSh)  1s  end BtoB
    in 2nd place facing own sides
21-24::
    All set as in Double Triangles, 1s petronella turn to lines across
    (1M+3s at top, 1L+2s in 3rd place)
25-32::
    1M+3s & 1L+2s Set+Link for 3.  All set, 1s cross RH to 2nd place own
    side.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7346, '2013-08-21 08:31:39.199706+00', '2023-02-04 01:22:30.254024+00', 6152, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, 1s set & cast 1 place
9-16::
    1s+3s dance RH across & LH back (1s end facing 1st corners)
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners &
    cross to places', 0);
INSERT INTO 'dancecrib' VALUES (13345, '2020-11-02 01:21:52.080234+00', '2023-02-04 01:22:30.457403+00', 13887, 3, NULL, 'ace', '1-8::
    1L sets advancing, 1s turn RH; 1s+2L dance LH across
9-16::
    1s+2M dance RH across; 1L followed by 1M dances across, casts behind
    2L (2s step up), across to 2M''s place (2s step up 7-8).  2 (1) 3
17-24::
    2s+1s+3s dance reels of 3 on sides (1s pass 3s LSh)
25-32::
    1M+2s & 1L+3s dance RH across; 1s turn 1.1/4 LH to 2nd place own
    sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8609, '2015-02-13 12:48:01.241854+00', '2023-02-04 01:22:31.361516+00', 15569, 3, NULL, 'ace', '1-8::
    1s with 2s, 3s with 4s dance R&L.
9-16::
    All dance Reels of 4 on the sidelines.
17-24::
    1s cast off to 4pl, _while_ 2s, 3s and 4s move up [19 - 20], and all
    turn partner RH.
25-32::
    Eight hands round and back.', 0);
INSERT INTO 'dancecrib' VALUES (7367, '2013-08-21 08:31:39.732181+00', '2023-02-04 01:22:31.88777+00', 6185, 3, NULL, 'ace', '1-8::
    All set, 1s & 3s cast down 1 place, cross up & cast 1 place opposite
    sides _while_ 2s & 4s cross up, cast 1 place & cross up to own
    sides.  2(1)4(3)
9-16::
    1s+4s set & dance RH across 1/2 way to end facing corners, All set,
    1/2 turn corners LH to form St Andrew''s Cross
17-24::
    All set twice, turn corners LH onto sides & 4s+1s dance RH across
    1/2 way, 1M facing up, 4M facing down
25-32::
    2s+1s also 4s+3s dance Ladies'' Chain
33-40::
    2s (at top) stand _while_ 1s+4s+3s dance 1/2 reel of 3 on sides (1s
    & 4s pass RSh to start), 1s+3s set & cross RH.  2 3 4 1
41-48::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14225, '2021-08-14 00:21:55.192163+00', '2023-02-04 01:22:32.227596+00', 19507, 3, NULL, 'ace', '1-8::
    1s lead down (2s step up 3-4); 1s lead back up & finish between 2s &
    take prom hold
9-16::
    1s dance reel of 3 across with 2s (1s pass 2L RSh). 1s end in
    centre, 2nd place facing up in prom hold
17-24::
    1s dance up, separate & cast to 2nd place own side; 1s turn RH
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7368, '2013-08-21 08:31:39.740377+00', '2023-02-04 01:22:31.919945+00', 6186, 3, NULL, 'ace', '1-8::
    1M & 4L cast in 1 place, turn RH 1.1/2 times & cast to each others
    place
9-16::
    1L & 4M cast in 1 place & dance into centre, turn LH 1.1/2 times &
    cast to each others place
17-24::
    2s & 3s set, dance up/down, cast back to places & dance RH across
    1/2 way
25-32::
    All set, circle 8H round to left 1/2 way to original places & set
33-40::
    1s+2s 1/2 R&L, 1s+3s 1/2 R&L
41-48::
    1s+4s 1/2 R&L, all set & cross RH.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7369, '2013-08-21 08:31:39.748423+00', '2023-02-04 01:22:31.940467+00', 7518, 3, NULL, 'ace', '1-8::
    All dance interlocking reels of 3 (RSh to partner)
9-16::
    All set, turn partners LH to Ladies in centre, Ladies dance RH
    across 1⅓ times to next Man Clockwise
17-24::
    All set to new partners, turn RH to Men in centre, Men dance LH
    across 1⅓ times to next Lady anticlockwise
25-32::
    All dance Grand Chain (RH to new partner & end with same new
    partner)

{{explanation}}
Repeat with new partner', 0);
INSERT INTO 'dancecrib' VALUES (8636, '2015-02-13 12:48:16.010936+00', '2023-02-04 01:22:31.959062+00', 6188, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance, couple facing couple, Lady on Man''s Left

1-8::
    All dance 1/2 R&L, set to partners joining hands with person
    opposite (1M+2L, 1L+2M), turn partners 2H into diag. line, men
    back-to back
9-16::
    All dance 1/2 reel of 4 passing partner RSh to start.  All  dance
    1/2 Poussette to meet next couple', 0);
INSERT INTO 'dancecrib' VALUES (7370, '2013-08-21 08:31:39.758558+00', '2023-02-04 01:22:31.990804+00', 10544, 3, NULL, 'ace', '1-8::
    All Ladies cast round partner into middle, dance RH across & cast
    round partners back to places
9-16::
    All Men repeat dancing LH across
17-24::
    1L+3M dance Fig of 8 round 4s _while_ 1M+3L dance Fig of 8 round 2s
25-32::
    2L+4M dance Fig of 8 round 1s _while_ 2M+4L dance Fig of 8 round 3s
33-40::
    1L+3L dance into middle, dance out (right) to 4L & 2L places as
    4L+2L dance in, 4L+2L dance out to 3L & 1L places as 3M+1M dance in,
    3M+1M dance out to 2M & 4M places as 2M+4M dance in
41-48::
    2M+4M dance out to 1M & 3M places as 2L+4L dance in, 2L+4L dance out
    to 4L & 2L places as 1L+3L dance in, 1L+3L dance out to 3L & 1L
    places as 2M+4M dance in, 2M+4M dance out to 4M & 2M places as 1M+3M
    turn RH to form line across with partners
49-56::
    1s+3s Bal-in-Line _while_ 2s & 4s set to partners, 1M & 3M (LH to
    partner) dance out to places as partners set _while_ 2s+4s turn LH
    into line across, 2s+4s Bal-in-Line _while_ 1s & 3s set to partners,
    2M & 4M (LH to partner) dance out to places as partners set _while_
    1s & 3s turn RH all ending in prom hold facing clockwise
57-64::
    All promenade 3/4 round to new places (1 place clockwise) & set', 0);
INSERT INTO 'dancecrib' VALUES (10099, '2017-09-03 23:45:25.945297+00', '2023-02-04 01:22:32.024105+00', 17892, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, LH back
9-16::
    1s lead down (2 steps), retain RH & set to each other, lead up to
    top & cast (2s step up 15-16)
17-24::
    1s+3s dance Double Fig 8 (1s cross down, 3s dance up to start)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14918, '2022-06-27 00:21:58.950323+00', '2023-02-04 01:22:32.054264+00', 20899, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 round 2s (give RH crossing down, LH crossing back to
    place)
9-16::
    1L+2M turn 1.1/4 LH into diagonal line facing partners; 1s+2s dance
    1/2 Poussette. 2 1
17-24::
    2s+1s Set+Link; 1s+2s circle 4H round to left.  1 2
25-32::
    1s+2s dance ''Rose Progression'':
::
    _25-26_  1M+2L facing in diagonally set _while_ 2M+1L change places
    RH to face out
::
    _27-28_  1M+2L 1/2 turn 2H to face each other as 1L+2M dance into
    partners place
::
    _29-30_  1M+2L cast into each others place as 1L+2M 1/2 turn 2H to
    face each other
::
    _31-32_  1M+2L dance into 2nd/1st place own side _while_ 2M+1L pull
    back RSh cast to 1st/2nd place own side.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (7415, '2013-08-21 08:31:40.509137+00', '2023-02-04 01:22:35.242214+00', 5803, 3, NULL, 'ace', '1-8::
    1s+2s dance 4H round & back
9-16::
    1s set & cast below 3s & dance up into double triangle pstns, B-to-B
    facing own sides
17-24::
    1s dance Double Triangles ending 2nd place own side
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7371, '2013-08-21 08:31:39.766555+00', '2023-02-04 01:22:32.073968+00', 10834, 3, NULL, 'ace', '1-8::
    1s dance round each other LSh & 1L followed by 1M dance down middle,
    1s dance round each other RSh & cast to 2nd place own sides
9-16::
    2s+1s+3s Set+Link for 3, 1s change places RH & cast to 2nd place own
    sides _while_ 2s+3s turn 2H on sides
17-24::
    3s+1s+2s repeat bars 9-16
25-32::
    2s+1s+3s Set, Adv+Ret (I step) & dance DoSiDo', 0);
INSERT INTO 'dancecrib' VALUES (7372, '2013-08-21 08:31:39.774621+00', '2023-02-04 01:22:32.09738+00', 6196, 3, NULL, 'ace', '1-8::
    1s & 3s set & turn 2H, dance down between 2s / 4s & cast back to
    places
9-16::
    1s+2s also 3s+4s dance double Fig of 8  (1s & 3s cross down to
    start) & all end in middle 1s facing down as others face up
17-24::
    All set 3 times with 1s passing down 1 place each setting (out to
    right, in to left as couples pass) & all turn 2H to end 2 3 4 1 with
    2s & 4s facing down
25-32::
    2s+3s also 4s+1s circle 4H round & end in one line up/down middle
    facing partner (Men face down), all set & petronella turn to own
    sides', 0);
INSERT INTO 'dancecrib' VALUES (7471, '2013-08-21 08:31:41.857573+00', '2023-02-04 01:22:38.638036+00', 6306, 3, NULL, 'ace', '{{explanation}}
Round the Room, 2 facing 2

1‑8::
    All dance RH across 1/2 way, petronella turn to 1 place
    anticlockwise, dance RH across 1/2 way & petronella turn 1 place
    anticlockwise
9‑16::
    Ladies change places RH & all change places with opposite person LH,
    Men change places RH & all change with ptnr LH to end in orig places
17‑24::
    All Set+Link with partner, all Set+Link with opposite person
25‑32::
    All set to partner, change places LH into LH across once round &
    dance on to meet next couple', 0);
INSERT INTO 'dancecrib' VALUES (7373, '2013-08-21 08:31:39.782709+00', '2023-02-04 01:22:32.122302+00', 6197, 3, NULL, 'ace', '{{explanation}}
4s+5s+6s start on opp sides

1-8::
    1s & 6s cross RH, cast in 1 place & dance 1/2 Figs of 8 round 3s/4s.
    2 1 3 (4)(6)(5)
9-16::
    All dance reels 3 on sides (1s/6s dance between end cpls to start
    reels) & all turn on sides (1s/6s with end persons nearer hand &
    centre cpls 2H)
17-24::
    1s & 6s dance 1/2 Figs of 8 round end couples _while_ centre couples
    circle 4H round to left, all 1/2 turn RH to face next couple & set.
    (2) 1 (3) 4 (6) 5
25-32::
    1s+4s+5s dance Allemande _while_ 2s+3s+6s dance reverse Allemande
    (down) to end 5 4 1 (6)(3)(2)', 0);
INSERT INTO 'dancecrib' VALUES (7374, '2013-08-21 08:31:39.790668+00', '2023-02-04 01:22:32.150987+00', 6199, 3, NULL, 'ace', '1-8::
    1s lead down for 2 & turn RH, lead up to top & cast to 2nd place
9-16::
    2s+1s+3s dance the Knot
17-24::
    1s dance RH across (1L with 3s at top & 1M with 2s), pass RSh &
    dance LH across with other couple
25-32::
    1M followed by 3s & 1L followed by 2s pass RSh to change ends & loop
    round to right to end on own sides, 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (7375, '2013-08-21 08:31:39.79867+00', '2023-02-04 01:22:32.165325+00', 12348, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s dance Figs of 8 on sides (1s dance in & down as 4s dance in
    & up to start)
9-16::
    1s+2s also 3s+4s dance double Fig of 8
17-24::
    1s & 4s 1/2 turn RH moving down/up to 2nd/3rd places, 2s cast up, 3s
    cast down. 1s+4s dance RH across 1/2 way & 4s lead up crossing &
    cast to 2nd place own side _while_ 1s lead down crossing & cast to
    3rd place opp side.  2 4(1)(3)
25-32::
    2s+4s+1s+3s circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7500, '2013-08-21 08:31:42.182137+00', '2023-02-04 01:22:41.625692+00', 6367, 3, NULL, 'ace', '1-16::
    1s+2s set to partners & cross RH, set to other person on sides &
    change places LH, repeat to return to places
17-24::
    1s+2s with hands crossed facing each other slip step down & back
25-32::
    1s+2 dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7376, '2013-08-21 08:31:39.804934+00', '2023-02-04 01:22:32.174568+00', 11731, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 3 Men facing anticlockwise to 3 Ladies

1-8::
    All Adv+Ret, Men make arches & all advance passing 2 lines to face
    3rd line
9-16::
    All circle 6H round & back
17-24::
    Middle Man & Lady dance RH across with couple to their right & LH
    back again
25-28::
    All in lines of 3 walk sideways for 3 steps & swing L foot to right,
    all walk to left back to places
29-32::
    All walk forward to right & left to face new trio', 0);
INSERT INTO 'dancecrib' VALUES (15428, '2023-02-04 01:22:32.189919+00', '2023-02-04 01:22:32.191162+00', 21140, 3, NULL, 'ace', '1-8::
    1s cross RH, cast to 2nd place (2s step up bar 3-4). 1s dance LH
    across (Lady with 2s, Man with 3s)
9-12::
    All dance a »Snake pass«:
::
    1L followed by 2M+2L & 1M followed by 3L+3M pass RSh diagonally
    across through 2nd place to change ends, loop round to right & dance
    up/down sides, 1s end in 2nd place on opposite sides 3 (1) 2
13-16::
    All chase clockwise 1/2 way round (2) 1 (3)
17-22::
    2s+1s+3s set, dance DosiDo
23-24::
    2s+3s set _while_ 1s 3/4 turn RH
25-32::
    1s dance 1/2 reels of 3 across (1L with 2s, 1M with 3s). 1s dance
    LSh round 1st corners & cross RH to 2nd place own side 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9046, '2015-11-30 09:00:21.099632+00', '2023-02-04 01:22:42.500876+00', 6394, 3, NULL, 'ace', '1-4::
    1s+2s dance 1/2 double Fig 8 (1s cross down, 2s dance up to start).
    1s end in prom hold facing down.
5-8::
    1s(in prom hold)+2s dance 1/2 RSh reel across (1s pass 2L RSh to
    start). At end 1s dance down middle, 2s dance up.
9-16::
    2s+1s+3s dance reel of 3 on side giving hands (1s dance out and down
    to start). At end 1s curve round to face out on Men''s side.
17-20::
    1L+2M turn RH, as 1M+3M turn LH.
21-24::
    1L+2L turn LH, as 1M+3L turn RH. 1s finish BtoB ready for double
    triangles.
25-32::
    2s+1s+3s dance double triangles.', 0);
INSERT INTO 'dancecrib' VALUES (13770, '2021-03-02 01:22:03.115255+00', '2023-02-04 01:22:42.698756+00', 13703, 3, NULL, 'ace', '1-8::
    1s cross down to dance Inveran reels with 2s+3s, 2s cross to opp
    side bars 3-4; 1s cross to own side bars 5-6, 2s cross to own side
    bars 7-8
9-16::
    1s followed by 2s lead down, cross below 3s and cast up to 1st place
    opp side, 1s+2s 1/2 turn RH remaining in centre facing up for …
17-24::
    1s+2s dance Allemande
25-32::
    2s+1s+3s dance grand chain', 0);
INSERT INTO 'dancecrib' VALUES (7522, '2013-08-21 08:31:42.381935+00', '2023-02-04 01:22:42.886974+00', 6395, 3, NULL, 'ace', '1-8::
    1s dance reflection reels of 3 on own sides (1s dance out & down to
    start) & 1s cast to face 1st corners as 2s & 3s loop round
9-16::
    1s dance "Hello-Goodbye" setting ending with petronella turn to 2nd
    places
17-24::
    All set, cross RH, set & cross back RH
25-32::
    1s+3s Set+Link & all turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (12826, '2020-05-14 23:16:18.179348+00', '2023-02-04 01:22:32.208858+00', 17318, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L (no polite turns), 1s+2s face on sides
9-16::
    1s+2s set, turn (Men RH, Ladies LH) 2s end facing 3s; 2s+3s set,
    turn (Men LH, Ladies RH).  1 2 3
17-24::
    Mirror reels of 3 on sides (1s in/down, 2s out/up, 3s in/up)
25-28::
    1s+2s circle 1/2 round to left, turn partner 2H _while_ 3s stand 2
    bars & 1/2 turn partner 2H
29-32::
    1s+3s circle 1/2 round to left, turn partner 2H _while_ 2s stand 2
    bars & 1/2 turn partner 2H. End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7377, '2013-08-21 08:31:39.812929+00', '2023-02-04 01:22:32.244155+00', 6202, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret, 1s+2s dance DoSiDo
9-16::
    1s+2s Adv+Ret, 1s+2s dance 1/2 R&L
17-24::
    1s dance 1/2 Fig of 8 round 2s, 2s+1s turn RH
25-32::
    2s dance 1/2 Fig of 8 round 1s, 2s+1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (7378, '2013-08-21 08:31:39.820869+00', '2023-02-04 01:22:32.262877+00', 6204, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, dance down between 3s & cast up to 2nd place
9-16::
    2L+1L+3L set & cross passing partner RSh & dance up behind Men,
    cross & down own sides
17-24::
    2M+1M+3M set & cross passing partner RSh & dance down behind Ladies,
    cross & up own sides all end in middle for…
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7491, '2013-08-21 08:31:42.029662+00', '2023-02-04 01:22:40.601215+00', 8834, 3, NULL, 'ace', '1-8::
    1s+2s set, set advancing, turn 2H & 1s cast as 2s lead up
9-16::
    1s+3s repeat (1s casting to 3rd place)
17-24::
    1s lead up to top, cast to 2nd place & turn 2H (4 bars)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7379, '2013-08-21 08:31:39.829011+00', '2023-02-04 01:22:32.278808+00', 6205, 3, NULL, 'ace', '1-8::
    1s set, cross down to face out joining hands with corners &
    Bal-in-Line, 1s turn 1st corners RH to form lines across 1L with 2s
    & 1M with 3s
9-16::
    All set & change places RH with opposite person; All set & 1/2 turn
    person opposite RH, 1L+3L+3M pull back RSh (twirl) to end 1s facing
    up in centre, 2s+3s facing down on sides
17-24::
    1s+2s+3s dance Tandem reel of 3 across (1M+1L facing up, 3L+2L &
    3M+2M each pair dancing as 1 person), 1s end in centre 1M giving LH
    to 2M+3M & 1L RH to 2L+3L
25-32::
    Men dance LH across & Ladies RH across once round, continue but
    change places with partner when passing thru centre (as Alison Rose)
33-40::
    1s followed by 3s+2s dance up, cross & cast to 2 3 1 & all turn
    partners RH
41-48::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9757, '2017-04-06 08:40:17.961641+00', '2023-02-04 01:22:40.621789+00', 17619, 3, NULL, 'ace', '{{explanation}}
Note:  Ladies progress 1 place anticlockwise to new partner each time through, Men remain in original places

{{title}}
Part 1

1-16::
    All dance the ''Cloverleaf'':
::
    _1-8_    Ladies dance 3/4 RH across _while_ Men dance 1 place
    anticlockwise.  All turn partners 1/2 LH & promenade 1 place
    anticlockwise, Man crosses Lady LH in front into centre as he dances
    to place
::
    _9-16_  All repeat bars 1-8
17-24::
    Men dance in front of partner, behind next Lady & finish beside Lady
    opposite.  Ladies dance in front of Man (to Left), behind next Man &
    finish beside partner
25-32::
    All set to corners, turn 3/4 RH & promenade to Man''s original place

{{title}}
Part 2

1-16::
    All dance the ''Cloverleaf''
17-24::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L
25-32::
    All set to corners, turn 3/4 RH & promenade to Man''s original place

{{title}}
Part3

1-16::
    All dance the ''Cloverleaf''
17-24::
    1s+3s set, dance 1/2 RH across. 2s+4s set, dance 1/2 RH across
25-32::
    All set to corners, turn 3/4 RH & promenade to Man''s original place

{{title}}
Part 4

1-16::
    All dance the ''Cloverleaf''
17-24::
    Men dance in front of partner, behind next Lady & finish beside Lady
    opposite.  Ladies dance in front of Man (to Left), behind next Man &
    finish beside partner
25-32::
    All set to corners, turn 3/4 RH & promenade with original partner to
    Man''s original place.  Ladies finish BtoB in centre', 0);
INSERT INTO 'dancecrib' VALUES (7380, '2013-08-21 08:31:39.83701+00', '2023-02-04 01:22:32.300639+00', 6209, 3, NULL, 'ace', '1-8::
    1s & 4s set, cross to 2nd/3rd places (1s RH & 4s LH), change places
    LH on sides & chase clockwise to end 1s between 2s & 4s between 3s
9-16::
    1s+2s also 4s+3s dance Alternating Tandem RSh reels of 3 across (1s
    & 4s dancing as 1 person)
17-24::
    1s+4s dance 1/2 RH across, set to partner & dance 1/2 Figs of 8
    round 2s/3s to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7492, '2013-08-21 08:31:42.038327+00', '2023-02-04 01:22:40.66369+00', 10354, 3, NULL, 'ace', '1-8::
    All dance Grand Chain (RH to partner to start)
9-16::
    1s+3s dance Ladies'' Chain & end in prom hold, 1s facing 4s & 3s
    facing 2s
17-24::
    1s & 3s dance Figs of 8 round standing 2s/4s (dancing between
    standing couple & round to left) & end facing same couple
25-32::
    1s+4s also 3s+1s circle 4H round to left opening out to circle 8H
    round to left 3/4 way to new pstns (1s in 4th place & 3s in 2nd
    place)', 0);
INSERT INTO 'dancecrib' VALUES (8788, '2015-06-15 11:41:11.728999+00', '2023-02-04 01:22:32.322102+00', 10339, 3, NULL, 'ace', '{{explanation}}
Round the Room - 3 facing 3

1-8::
    All set & circle 6H round to left 1/2 way, cross RH back to own
    sides
9-16::
    Centre dancers dance 1/2 diagonal reel of 4 with 1st corner (pstn),
    pass RSh to dance 1/2 diagonal reel with 2nd corner (pstn)
17-24::
    Centre dancers dance 1/2 diagonal reel with 3rd corner (pstns), pass
    RSh to 1/2 diagonal reel with 4th corner (pstns)
25-32::
    Centre dancers dance DoSiDo as corners change places RH on sides &
    set, both lines cross passing RSh & progress a 2nd time passing LSh

{{explanation}}
Repeat in Reel Time', 0);
INSERT INTO 'dancecrib' VALUES (9754, '2017-04-06 08:40:16.080488+00', '2023-02-04 01:22:32.471485+00', 15634, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate
9-16::
    1s dance 1/2 Fig 8 down round 3s, dance 1/2 Fig 8 up round 2s
17-24::
    1s dance RH across with 3s, dance LH across with 2s
25-32::
    Reels of 3 on sides, 1s pass 3s RSh to start.  1s end in 2nd place
    own side
33-40::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (7559, '2013-08-21 08:31:44.570469+00', '2023-02-04 01:22:46.700326+00', 8526, 3, NULL, 'ace', '1-8::
    1L+3M change places RH, 1M +3L change places RH, 2s cross RH & all
    1/2 turn into Allemande hold
9-16::
    All dance Allemande
17-24::
    1s set & cast 1 place (2s step up); 3s set & cast up 1 place (1s
    step down.  2 3 1
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7382, '2013-08-21 08:31:39.853061+00', '2023-02-04 01:22:32.496086+00', 6210, 3, NULL, 'ace', '1-8::
    1L+2L lead thru partners, cast back to place & pass RSh to change
    places & cross RH with opposite partner
9-16::
    1M+2M repeat (2s at top)
17-24::
    2s+1s dance RH across, 1s lead up & cast _while_ 2s cast & lead up
25-32::
    1s+3s dance LH across, 1s cast & lead up _while_ 3s lead up & cast
33-40::
    2s+1s+3s dance reel of 3 on sides (1s dancing out & up to begin)', 0);
INSERT INTO 'dancecrib' VALUES (12428, '2019-12-05 01:32:09.00006+00', '2023-02-04 01:22:40.704088+00', 19782, 3, NULL, 'ace', '1-8::
    1s and 3s face in diagonally and set, dance RH across and set facing
    in diagonally again
9-16::
    2s petronella into the centre, set facing partners, change places LH
    up/down and cast left back to places
17-24::
    1s lead down for 3 bars, back up to the top and cast to 2nd place
    (2s step up on 23-24)
25-32::
    1s & 3s dance the Tournee. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7383, '2013-08-21 08:31:39.863091+00', '2023-02-04 01:22:32.529571+00', 6212, 3, NULL, 'ace', '1-8::
    1s also 4s cross RH & cast 1 pl as 2s+3s dance RH across 1/2 way, 3s
    also 2s cross RH & cast 1 pl as 1s+4s dance RH across 1/2 way
9-16::
    1s (at bottom) followed by 2s+3s+4s cross & lead up opposite sides
    to original places, all turn 2H 1.1/2 times
17-24::
    1M+2L+3M+4L dance 1/2 diag reel of 4 (1M & 3M giving RSh to 2L &
    3L), 1L+2M+3L+4M dance 1/2 reel of 4 (1L & 3L give RSh to 2M & 4M)
25-32::
    4s+2s dance LH across 1/2 way, 1s+3s turn LH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (7384, '2013-08-21 08:31:39.871131+00', '2023-02-04 01:22:32.565275+00', 6217, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 reel of 3 across (1L with
    2s & 1M with 3s)
9-16::
    1s dance RH across with 1st corners & dance 1/2 reels of 3 across
    (1L down & 1M up)
17-24::
    1s dance RH across with 2nd corners, 1L dances up & casts to 2nd
    place own side _while_ 1M dances down & casts up to 2nd place
25-32::
    2s+1s+3s turn RH 1.1/4 times, set to partners & petronella turn to
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (7385, '2013-08-21 08:31:39.8792+00', '2023-02-04 01:22:32.593862+00', 6219, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cast to face up in centre _while_ 2s turn LH 1/2 way
    moving up & face down, 2s+1s Set+Link with ptnr 2s end own sides &
    1s face 2L
9-16::
    1s+2L RH across & LH across with 3M & end facing 1st corners
17-24::
    1s turn 1st corners RH, partner LH, 2nd corners RH & partner LH to
    end in centre facing up Man behind partner
25-32::
    1s+2M LH across & RH across with 3L, 1s end 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (14806, '2022-05-05 00:21:46.210617+00', '2023-02-04 01:22:32.619159+00', 17113, 3, NULL, 'ace', '1-8::
    1s+2s set & dance 1/2 RH across; 2s+1s set & cross RH
9-16::
    1s+2s+3s Set+Link for 3; 1s dance 1/2 reels of 3 across, LSh to 2nd
    corner (pstn) to start
17-24::
    1s+2s+3s Set+Link for 3; 1s dance 1/2 reels of 3 on sides, LSh to
    1st corner (pstn) to start
25-32::
    1M dances up between 2s, 1L dances down between 3s & they cast to
    2nd place own sides; 2s+1s+3s turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (14807, '2022-05-05 00:21:46.421736+00', '2023-02-04 01:22:32.785578+00', 17116, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All dance interlocking reels of 4 (RSh to parner to start)
9-16::
    All dance Double Men''s Chain with Men giving LH in centre
17-24::
    1s & 3s set to partner, 1s+3s dance 6 bars of R&L (RH to partner to
    start)
25-32::
    2s &4s repeat 17-24
33-40::
    1s+3s 1/2 turn RH, pull back RSh & dance out to opp place; 2s+4s
    repeat. Ladies end facing out ready for …
41-56::
    All dance Schiehallion reels
57-64::
    All circle 8H round to left 1 place (2 bars), dance in to centre (1
    bar), pull back RSh & dance out to next place round (1 bar); repeat
    circle, twirl & out to finish in original places. 1 2 3 4

{{title}}
Reel

1-56::
    Repeat Strathspey bars 1-56
57-64::
    All circle 8H round to left (3 bars) pull back LSh  & chase
    anticlockwise back to place.  1 2 3 4', 0);
INSERT INTO 'dancecrib' VALUES (7386, '2013-08-21 08:31:40.033443+00', '2023-02-04 01:22:32.916754+00', 6224, 3, NULL, 'ace', '1-8::
    1s lead down & cross & cast down behind 3s to 3rd place, 3s+1s
    circle 4H round to left 1s casting to 2nd places as 3s lead down to
    pl
9-16::
    1s crossing down dance 1/2 double Fig of 8 with 3s, 1s crossing up
    dance 1/2 double Fig of 8 with 2s (2s+1s+3s end on opposite sides)
17-24::
    2s+1s+3s dance DoSiDo, all turn 2H 1.1/2 times
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (15152, '2022-10-05 00:22:03.915533+00', '2023-02-04 01:22:40.793574+00', 19671, 3, NULL, 'ace', '1-8::
    All dance 6 bar mirror reels of 3 on sides (1s in/down, 2s out/up).
    Bars 7-8: 1s+2s continue reel to change places 2 1 3
9-16::
    1s+3s dance LH across; 2s+1s dance RH across
17-24::
    1s+3s dance Petronella turn in Tandem, set facing up/down;
    Petronella turn in Tandem to opp sides & cross RH with partner.  3 2
    1
25-32::
    2s+3s+1s circle 6H 1/2 round to left, pull back LSh & chase
    anticlockwise to own side 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7387, '2013-08-21 08:31:40.042174+00', '2023-02-04 01:22:32.948779+00', 11815, 3, NULL, 'ace', '1-8::
    1s turn RH 1.1/2 times moving down to face 2s & dance the Spurtle:
    1s dance 1/2 reel of 4 with 2s & turn partner RH to face 3s
9-16::
    1s dance 1/2 reel of 4 with 3s & turn partner RH to face 4s, 1s
    dance 1/2 reel of 4 with 4s & turn RH to 4th place opposite sides.
    (2)(3)(4)(1)
17-20::
    All Set+Link for 4: 2L+1M (left end of lines) turn LH & curve to
    left end of lines across _while_ the other dancers cast & chase
    cl''wise into lines across
21-24::
    2L leads Ladies into 4H round to left at top as 1M leads Men into 4H
    round at bottom
25-28::
    2L also 1M lead Ladies/Men down/up own sides & advance to meet
    partner then retire. 1 4 3 2
29-32::
    All set & 1s+4 also 3s+2s Link for 2 to end 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (11214, '2018-09-30 22:20:33.845198+00', '2023-02-04 01:22:32.968234+00', 18571, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place, 2s+1s+3s Set+Link
9-16::
    2s+1s+3s dance DoSiDo with opposite dancer (up/down), 2s+1s+3s
    Set+Link & 1s end facing 1st corners (pstn)
17-20::
    1s+1st corner set with 1s turning right about & cast to 3rd corners
    (pstn) as 1st corners dance in & face corner position they just left
21-24::
    1s+corners set & 1s dance in turning right about to face 2nd corner
    (pstn) as corners cast into opposite corner places
25-28::
    1s+corners set with 1s turning right about & cast to 4th corners
    (pstn) as 2nd corners dance in & face corner position they just left
29-32::
    1s+corner dancers set & 1s dance in turning right about to face own
    sides as corners cast into opposite corner places.  2 1 3
33-40::
    1s dance out & cast to right, dance up/down passing RSh & cast to
    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (11710, '2019-03-18 21:02:54.188975+00', '2023-02-04 01:22:32.996136+00', 17476, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of three on sides, 1s (then each
    couple) crossing down from top place.  (1) (2) (3)
9-16::
    1s+2s+3s dance reflection reels of three on opp sides, 1s dance
    in/down to start.  (1) (2) (3)
17-20::
    1s+2s dance 1/2 double Fig 8, 1s cross down to begin and 2s dance
    out and up.
21-24::
    1s dance down between 3s and cast up to 2nd place.  2s dance up to
    top place on bars 21-22.  2 1 (3)
25-28::
    1s+ 3s dance a 1/2 double Fig 8.  1s cross down to begin and 3s
    dance out and up
29-32::
    1s lead up between 2nd couple, cross and cast to 2nd place. 2 1 3

{{explanation}}
Note:	3rd time through, 4s dance into reel from 4th place', 0);
INSERT INTO 'dancecrib' VALUES (13347, '2020-11-02 01:21:53.895166+00', '2023-02-04 01:22:33.026059+00', 17311, 3, NULL, 'ace', '1-8::
    1s Petronella turn & set; Petronella turn & set.  (1) 2
9-16::
    1s+2s dance ''Interlocking Knot'':
::
    1s+2s 1/2 turn RH, 1s face up, 2s face down in Allemande hold. 1s
    dance down Men''s side _while_ 2s dance up Ladies'' side; Couples turn
    partner LH to sides.  2 (1)
17-24::
    2s+1s circle 4H to right & back to left
25-32::
    1s set, 1/2 turn RH,  pull back RSh & dance out to own side, 2s+1s
    set.  End 2 1', 0);
INSERT INTO 'dancecrib' VALUES (13440, '2020-12-02 01:21:49.234121+00', '2023-02-04 01:22:33.170409+00', 16384, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left; 1s+2s turn partner 2H 1.1/4 to end in
    centre, Men facing down, Ladies facing up
9-16::
    1s+2s dance reel of 4
17-24::
    1s+2s Petronella turn to own sides & set; 1s+2s turn partner RH into
    allemande hold facing up
25-32::
    1s+2s dance allemande', 0);
INSERT INTO 'dancecrib' VALUES (7388, '2013-08-21 08:31:40.078787+00', '2023-02-04 01:22:33.192846+00', 6229, 3, NULL, 'ace', '1-8::
    All dance 8H round & back
9-24::
    All Adv+Ret &1s+3s dance RH across & dancing out through own place
    dance clockwise round outside of set back to place
25-40::
    All Adv+Ret & 2s+4s dance LH across & dancing out through own place
    dance anticlockwise round outside of set back to place
::
    (ending in diag lines with 1s & 4s facing 2s & 3s)
41-48::
    All set twice in diagonal lines, all dance 1/2 R&L (1s with 2s, 3s
    with 4s)
49-56::
    All repeat bars 41-48
57-64::
    All dance 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9241, '2016-06-16 22:42:20.44312+00', '2023-02-04 01:22:33.212322+00', 16831, 3, NULL, 'ace', '1-8::
    1s turn RH, cast off, turn LH 1.1/4 to finish 1L between 2s, 1M
    between 3s
9-16::
    1s dance 1/2 reel of 3 across (LSh to 1st corner), 1s turn 1/2 RH &
    dance 1/2 Reel of 3 across RSh to 2nd corner pos. (Corners dance
    complete reels across)
17-24::
    1s lead down the middle & back finish back-to-back facing opp sides
    _while_ corners set on sides, tulloch turn to change places and set.
25-28::
    3s+1s+2s set, advancing and turning about on 2nd step to double
    triangle pstn.  Repeat to finish as bar 25.
29-32::
    Repeat bars 25-26.  1L+3M+2M & 1M+3L+2L dance RH across half way 1s
    passing RSh to finish on own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13281, '2020-10-16 00:22:00.925912+00', '2023-02-04 01:22:33.234151+00', 19694, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance mirror reels of 3 on sides (1s in/down, 2s out/up to
    start)
9-16::
    1s dance down & cast up round 2s; 1s dance down (2 step up) & cast
    up round 3s into 2nd place own side
17-24::
    1M+2s & 1L+3s dance LH across, pass LSh to dance RH across with
    other couple
25-32::
    2s+1s+3s circle 6H round & back

{{explanation}}
Note:	Modified version of "Twa Sparkling Een" by Iain Boyd', 0);
INSERT INTO 'dancecrib' VALUES (7389, '2013-08-21 08:31:40.087054+00', '2023-02-04 01:22:33.253372+00', 5635, 3, NULL, 'ace', '1-8::
    1s cross RH, cast down 1 place (2s step up); 1s cross LH & cast up
    to top place (2s step down)
9-16::
    1s+2s+3s dance mirror reels of 3 on own sides (1s in & down to
    start). Hands may be given in reels
17-24::
    1s lead down for 2 steps, lead up & cast to 3rd place (2s+3s step up
    bars 7-8)
25-32::
    3s+1s set twice & turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (7390, '2013-08-21 08:31:40.095405+00', '2023-02-04 01:22:33.28796+00', 8708, 3, NULL, 'ace', '1-8::
    1s set & 3/4 turn RH moving down to 2nd place, 1s set to each other
    & 3/4 turn RH
9-16::
    1s dance reels of 3 on opposite sides (RSh to 1st corner) & end
    turning RH facing down diagonally to 3s (1M facing 3M)
17-24::
    1L+3L set & turn LH _while_ 1M+3M set & turn RH, 1s cross up & cast
    to 2nd place opposite sides facing up to 2s (1M facing 2L)
25-32::
    1L+2M set & turn LH _while_ 1M+2L set & turn RH, 1s cross down &
    cast up to 2nd place own sides

{{explanation}}
Repeat from 2nd place in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (8637, '2015-02-13 12:48:16.519733+00', '2023-02-04 01:22:33.318102+00', 15306, 3, NULL, 'ace', '1-8::
    1s set, dance down below 3s, cast up to 2nd place, pass LSh to face
    1st corners (2s step up 3-4)
9-20::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s meet again in
    middle RSh to RSh facing own sides
21-24::
    1s dance out through 2nd place, cast to Right to finish 1M between
    3s (1st place) facing 3M, 1L between 2s (3rd place) facing 2L
25-32::
    1s dance LSh reels of 3 across
33-40::
    1s dance RSh reels of 3 on opp sides, 1L+3L also 1M+2M pass RSh to
    start. End 1M between 3s (1st place), 1L between 2s (3rd place)
41-48::
    1s change places giving LH, cast to Left to 2nd place opp sides.
    All set, all cross RH.  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7495, '2013-08-21 08:31:42.063518+00', '2023-02-04 01:22:41.148889+00', 10940, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across & LH back
9-16::
    All set to partners, 1M+2L also 3M+4L change places RH, 1L+2M also
    3L+4M change places LH & all cross RH
17-24::
    1s+4s set & cross RH, change places on sides LH & cross RH
25-32::
    All circle 8H round & back.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12745, '2020-04-11 10:53:06.468748+00', '2023-02-04 01:22:33.345241+00', 17606, 3, NULL, 'ace', '1-8::
    1s dance RSh round each other ("Gypsy Turn"); 1s cast (2 step up) &
    turn LH to face 1st corners
9-16::
    1s+1st corners dance Corner Pass+Turn, 1s pass RSh & dance Corner
    Pass+Turn with 2nd corners, 1s end in centre giving LH to partner,
    RH to 2nd corners
17-24::
    1s dance 1/2 "Spoke" with 2nd & 3rd corners; 1s turn 3rd corners RH
25-32::
    1s dance 1/2 "Spoke" with 3rd & 4th corners; 1s turn 4th corner RH
    to end in 2nd place own sides
33-40::
    2s+1s+3s circle 6H round to left (3 bars), bar 36 all pivot (right
    foot over left); & all chase anticlockwise to own side.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (5776, '2013-08-21 08:31:14.034311+00', '2023-02-04 01:22:33.466506+00', 6233, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back to places
9-16::
    1s lead down the middle & back to face 1st corners
17-24::
    1s set & turn 1st corners, set & turn 2nd corners (1s end in lines
    across Lady between 2s facing down & Man between 3s facing up)
25-32::
    1s set twice & turn 2H 1.1/4 times to own sides', 0);
INSERT INTO 'dancecrib' VALUES (13636, '2021-02-04 01:21:47.392887+00', '2023-02-04 01:22:33.484523+00', 15245, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s
9-16::
    1s set, cross RH, 1L turns to face in; 1M followed by 1L casts up
    round 2M & dances down centre.  End 1M in centre 2nd place, 1L
    between 2s at top, all facing down
17-24::
    1M+ 1L with 2s dance down; all pull back RSh; 2L with 2s followed by
    1M dance up.  2s end in 1st place, 1s between 2s (1L on 1M''s right)
25-32::
    1s cast to 2nd place & set; 2s+1s dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (7391, '2013-08-21 08:31:40.124036+00', '2023-02-04 01:22:33.537198+00', 14968, 3, NULL, 'ace', '1-8::
    1L passing in front of 1M dances Fig of 8 round 2M+3M (pass 3M LSh)
    _while_ 1M dances Fig of 8 round 2L+3L (pass 3L RSh) & 1s end in
    partners place with 2s facing up
9-16::
    1M+2L change places LH as 1L+2M change RH & 1s end facing out then
    all dance reels of 3 on sides (1M pass 3L RSh & 1L pass 3M LSh) & 1s
    end facing out 2 1 3
17-24::
    2s+3s dance R&L _while_ 1s cast round 1st crnr & dance into middle
    (bar 20) to turn 1.1/2 RH ending M facing down L up
25-32::
    1M dances down round 3M _while_ 1L dances up round 2L & all turn
    partners RH 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7392, '2013-08-21 08:31:40.134153+00', '2023-02-04 01:22:33.564557+00', 6234, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Diamond Poussette
9-16::
    1s+2s also 3s+4s Set+Link on sides, 1s & 3s turn 2H, 1s lead down to
    end facing down between 4s _while_ 3s cast up to end between 2s face
    up
17-24::
    3s & 1s in prom hold dance reels of 3 across (3s with 2s giving LSh
    to 2M & 1s with 3s giving LSh to 4L) & ending own sides.  2 3 4 1
25-32::
    2s+3s also 4s+1s dance RH across & LH back', 0);
INSERT INTO 'dancecrib' VALUES (7393, '2013-08-21 08:31:40.142458+00', '2023-02-04 01:22:33.591054+00', 6236, 3, NULL, 'ace', '1-8::
    All dance "Inveran reels" of 3 on sides with each couple crossing to
    opposite sides from top place & crossing back from bottom
9-16::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 2s to end
    facing 1st corners
17-24::
    1s dance diagonal reel of 4 with 1st corners
25-32::
    1s turn RH in centre, cast down 1 place opposite sides & dance 1/2
    Fig of 8 round 3s', 0);
INSERT INTO 'dancecrib' VALUES (12425, '2019-12-05 01:32:03.837332+00', '2023-02-04 01:22:33.618901+00', 19783, 3, NULL, 'ace', '1-8::
    1s 1/2 turn 2s (Men RH, Ladies LH), 1s end  BtoB in centre, 2s+1s+3s
    dance 1st 6 bars of Double Triangles. 1s end facing 1st corners
9-16::
    1s dance reel of 4 with 1st corners & turn LH to face 2nd corners
17-24::
    1s turn 2nd corner RH, turn partner LH 3/4 to face 1st corner, turn
    1st corner RH, pass partner LH ready for...
25-28::
    RH across (1M with 2s, 1L with 3s). 1s end by passing LSh to end in
    Double Triangles position facing own side
29-32::
    2s+1s+3s set (with hands joined) then 1s 1/2 turn 3s (Men L hand,
    Ladies R hand) to 3rd place own side.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (14687, '2022-03-07 02:21:47.036777+00', '2023-02-04 01:22:33.648692+00', 20397, 3, NULL, 'ace', '1-8::
    1s+2s set, turn partner 2H & flowing into circle 4H to the left
9-16::
    1s+2s+3s dance 6 bar RSh reels of 3 on sides, 1s+2s change places
    RH.  2 1 3
17-24::
    1s+3s set & dance 1/2 RH across; 3s+1s set & cross RH with partner.
    2 3 1
25-32::
    3s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (13441, '2020-12-02 01:21:49.667334+00', '2023-02-04 01:22:33.687578+00', 14350, 3, NULL, 'ace', '1-8::
    1s lead down & back up remaining in middle, 2s & 3s step in ready
    for …
9-16::
    1s+2s+3s dance allemande
17-24::
    3s+2s (top 2 couples) Set+Link; 3s+1s (bottom 2 couples) Set+Link
25-32::
    2s+1s+3s set, cross RH & chase clockwise 1/2 round to own side.  3 1
    2

{{explanation}}
Note:	Dance also works as 3 couple in 4C set - progression is 3 1 2 4', 0);
INSERT INTO 'dancecrib' VALUES (9755, '2017-04-06 08:40:16.382716+00', '2023-02-04 01:22:33.707627+00', 17652, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opposite sides

1-4::
    Set+Link with "interchange":
::
    1s & 2s also 3s & 4s, dance Set+Link but on bar 4 1s+4s pass on
    sides giving LH 2(4)1(3).
5-8::
    2s+4s also 1s+3s turn RH on sides, then 4s+1s 1/2 turn LH on sides,
    Men stay facing out end 2 1 (4) (3)
9-16::
    1s+4s dance Ladies'' Chain
17-24::
    RSh reels of 4 on the sides
25-28::
    2s+1s also 4s+3s circle 4H round to left
29-32::
    All join hands on side and set, then 1s+4s dance 1/2 RH across.  End
    2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (7394, '2013-08-21 08:31:40.15971+00', '2023-02-04 01:22:33.747121+00', 8709, 3, NULL, 'ace', '1-8::
    5s dance reels of 3 with 1s+3s (5s start by passing opposite dancer
    by LSh)
9-16::
    5L dances RH across with 2s _while_ 5M dances LH across with 4s, 5s
    lead up thru 1s & cast back to centre
17-24::
    5L dances LH across with 2s _while_ 5M dances RH across with 4s, 5s
    lead down thru 3s & cast back to centre
25-32::
    5s Tulloch turn right (Kilt Grip) twice, 5s+1s set & dance part LH
    across (5s dance 1/2 way _while_ 1s dance 1/4 way & into centre to
    face 2s)', 0);
INSERT INTO 'dancecrib' VALUES (7395, '2013-08-21 08:31:40.168144+00', '2023-02-04 01:22:33.776151+00', 10085, 3, NULL, 'ace', '1-8::
    1s turn RH 2.1/2 times to face 2nd corners
9-16::
    1s turn 2nd corners LH, pass LSh & turn 1st corners RH
17-24::
    1s dance reels of 3 on sides giving LSh to 2nd corners & when Lady
    reaches 1st place & Man 3rd place they cross down/up to 2nd place
    own sides
25-32::
    1s dance LH across (Man with 2s & Lady with 3s) & 2s+1s+3s turn LH', 0);
INSERT INTO 'dancecrib' VALUES (7396, '2013-08-21 08:31:40.176517+00', '2023-02-04 01:22:33.798285+00', 10153, 3, NULL, 'ace', '1-8::
    1L+2M change places RH, 1s+2s circle 4H round to left 1/2 way, 1M+2L
    change places RH & 1s+2s circle 4H round to left 1/2 way
9-16::
    1s followed by 2s lead down & 2s followed by 1s lead back Men
    crossing partner in front of them to own sides
17-24::
    1s set, dance up between 2s, cast, dance down between 3s & cast up
    to 2nd places
25-32::
    1s+3s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7397, '2013-08-21 08:31:40.26039+00', '2023-02-04 01:22:33.823871+00', 13614, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels of 3 with 1s crossing down to 2nd place to
    start with each couple in turn crossing down & all end on opposite
    sides
9-16::
    1s slip step down middle & back up to 2nd place (2s step up on bars
    11-12)
17-24::
    2s+1s+3s Set+Link for 3, all advance & retire (up/down)
25-32::
    2s+1s+3s Set+Link for 3 (to own sides), all turn RH into Allemande
    hold
33-40::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (14013, '2021-05-03 00:21:40.146814+00', '2023-02-04 01:22:33.850734+00', 19823, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s+4s cross to opp sides

1-8::
    1s+4s set, 1L/4L cast down/up 1 place (2L & 3L step up/down); centre
    dancers dance RH across (1L+4L+2M+3M)
9-16::
    Centre dancers set, 1L/4L cast up/down to original positions (2L/3L
    step down/up); 1s+2s also 3s+4s dance LH across
17-24::
    1s/4s set, 1s/4s cast down/up 1 place (2s/3s step up/down); 1s/4s
    dance 1/2 Fig of 8 up/down round 2s/3s
25-32::
    1s+4s dance a variation of Espagnole:
::
    1M+4L lead across RH & cross over to finish 4L/1M facing up/down
    _while_ 1L+4M dance across
::
    1L+4M lead across LH & cross over to finish 4M/1L facing up/down
    _while_ 4L+1M dance across
::
    4s turn RH _while_ 1s turn LH 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7398, '2013-08-21 08:31:40.355539+00', '2023-02-04 01:22:34.034253+00', 6242, 3, NULL, 'ace', '1-8::
    1s+2s+3s turn 2H & chase clockwise 1/2 way
9-12::
    3s+1s chase clockwise back to original places _while_ 2s turn 2H
    1.1/2 times
13-16::
    1s+2s dance RH across
17-24::
    1s dance reels of 3 on sides (1s pass 2s RSh to start)
25-32::
    1s+2s set, dance 1/2 R&L, 1s+2s cross RH', 0);
INSERT INTO 'dancecrib' VALUES (7399, '2013-08-21 08:31:40.36584+00', '2023-02-04 01:22:34.194203+00', 8710, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH, face each other, drop hands & set, pulling back RSh
    to face again; 1s cross RH & cast 1 place on own side into middle to
    end with loop (Lady to right, Man to left) to face 3rd corner
9-12::
    1s dance 1/2 reel of 3 on sides giving RSh to 3rd corner (1M up, 1L
    down) & turn right about to face 2nd corner
13-16::
    1s dance 1/2 reel of 3 across giving RSh to 2nd corner & turn right
    about to face 1st corner
17-20::
    1s dance 1/2 reel of 3 on sides giving RSh to 1st corner (1M down,
    1L up) & turn right about to face 4th corner
21-24::
    1s dance 1/2 reel of 3 across giving RSh to 4th corner & turn right
    about to end BtoB facing own side
25-32::
    1s dance Double triangles ending 2nd place own side (Optional - Bars
    27+28, 31+32 1s may "twirl"). End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7400, '2013-08-21 08:31:40.37426+00', '2023-02-04 01:22:34.219159+00', 8525, 3, NULL, 'ace', '{{explanation}}
5 couple square set: 5s in centre facing, Man with back to 4s & Lady with back to 2s)

1-8::
    5s set turning to right to face sides as others circle 8H round to
    right 1/4 way, 5s set rotating to right to face each other as others
    set & repeat
9-16::
    5L+4s (in 2nd pl) also 5M+2s dance RH across, 5s pass RSh to dance
    LH across [5L with 1s (in 3rd pl) & 5M with 3s] 5s passing LSh to
    face sides
17-20::
    4s & 2s in prom hold dance 1/2 LSh reel of 4 across with 5s [5M
    facing 2s (4th pl) & 5L facing 4s], 5s passing LSh to face
    top/bottom
21-24::
    3s & 1s dance similar 1/2 LSh reel with 5s who end facing 4s (all
    now in original places)
25-32::
    5s+4s dance 1/2 RH across, 4s+3s dance 1/2 RH across, 3s+2s dance
    1/2 RH across & 2s+1s dance 1/2 RH across to end 2 3 4 5 & 1s in
    centre', 0);
INSERT INTO 'dancecrib' VALUES (14808, '2022-05-05 00:21:47.771186+00', '2023-02-04 01:22:34.259471+00', 17118, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance Promenade
9-16::
    1s+2s+3s join hands on sides & set to partners, 1s+3s dance 3/4
    Double Fig 8 round 2s (1s cross down, 3s cast up to start), 3s join
    NH  (3) 2 1
17-24::
    3s dance down, cast up round 3rd place back to 1st place _while_ 2s
    dance up sides to top & follow 3s to end in 2nd place, all cross RH
    with partner, 1s at bottom face up NHJ  3 (2) (1)
25-32::
    3s+2s+1s dance »The Spinnaker«:
::
    _25-28_  1s Set+Link _while_ 2M+3L & 3M+2L Mirror Set+Link (3s cast,
    2s dance up). 2s at top face down NHJ (2) 3 1
::
    _29-32_  2s Set+Link _while_ 3L+1L & 3M +1M Mirror Set+Link (3s
    cast, 1s dance up).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7401, '2013-08-21 08:31:40.382658+00', '2023-02-04 01:22:34.317199+00', 13282, 3, NULL, 'ace', '1-8::
    1s+2s dance a Tourbillon:
::
    _1- 4_    1s & 2s 1/2 turn ptnrs 2H, 1M & 2L lead ptnrs by nearer
    hand 1 place cl''wise to end 1s on Ladies side & 2s Men''s side, 1s
    set to 2s
::
    _5- 8_    1s & 2s 1/2 turn ptnrs 2H & lead ptnrs on 1 place
    clockwise & 2s+1s cross RH to own sides
9-16::
    1s cast to right on own sides & pass RSh in middle of set, cast to
    right again & pass RSh to end in 2nd place on opposite side.
17-28::
    2s+1s+3s dance 3 couple R&L
29-32::
    1s turn 1.1/2 times to 2nd place own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7402, '2013-08-21 08:31:40.391232+00', '2023-02-04 01:22:34.342659+00', 6249, 3, NULL, 'ace', '1-4::
    1s dance RSh round each other moving down to Man facing down to 3s &
    Lady facing up to 2s & set as crown triangles
5-16::
    1s (facing 4th corners) Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s meet again in the
    middle & 1/4 turn RH to face 2nd corner position
17-24::
    1s change places with 2nd crnrs & 1s set _while_ crnrs change pl LH
    to face opp crnr, 1s turn corner persons RH 1.1/2 times & face 3rd
    crnr (pstn)
25-32::
    Repeat 17-24 with 3rd corners & 1s end in 2nd places own sides', 0);
INSERT INTO 'dancecrib' VALUES (7403, '2013-08-21 08:31:40.399638+00', '2023-02-04 01:22:34.370315+00', 6250, 3, NULL, 'ace', '1-8::
    1s & 3s 1/2 turn RH as 2s & 4s set, 1s & 3s prom down below 4s/5s as
    2s & 4s cast up 1 pl, 1s & 3s cross LH, cast up 1 pl to face 1st
    crnrs
9-16::
    1s & 3s dance Pass+Turn with 1st corners, turn right about
    (pirouette) in centre & dance Pass+Turn with 4th corner
17-24::
    1M dances full Fig of 8 round 2s giving RSh to own 2nd crnr as 3L
    dances similarly round 5s _while_ 1L+3M change places RH in centre &
    cast to right round couple in 3rd pl, change pl LH & cast to left
    round same couple to 2nd/4th places _while_ 2s+4s+5s set & cross RH,
    set & cross back LH
25-32::
    1s+3s set advancing, Bal-in-Line in centre (as Wild Geese), turn RH
    & cast down 1 place', 0);
INSERT INTO 'dancecrib' VALUES (15429, '2023-02-04 01:22:34.39228+00', '2023-02-04 01:22:34.39314+00', 19638, 3, NULL, 'ace', '1-8::
    1s+2s+3s Set+Link twice (3) (2) (1) 4
9-16::
    3s+2s+1s set, dance 6H 1/2 way to the left; 1s+2s+3s set,1s cast to
    2nd place (2s step up)
17-24::
    1s+3s+4s dance Inveran reels on the sides
25-28::
    1s dance down middle & cast up round 4s to 3rd place (3s step up
    27-28)
29-32::
    1s+4s 1/2 turn 2H into 4H 1/2 way round to left 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7404, '2013-08-21 08:31:40.407848+00', '2023-02-04 01:22:34.414609+00', 6252, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, cross down LH & cast up to 2nd place to
    end facing 2M (1M behind 1L)
9-16::
    1s dance RSh tandem reel of 3 with 1st corners & end dancing round
    to left to face 2L
17-24::
    1s dance LSh tandem reel of 3 with 2nd corners & end dancing round
    each other to face own 1st corner
25-32::
    1s turn 1st corner RH & partner LH, turn 2nd corner RH & cross to
    2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (12746, '2020-04-11 10:53:07.196294+00', '2023-02-04 01:22:34.430884+00', 10148, 3, NULL, 'ace', '1-8::
    1s cross RH & cast (2s step up); 1s turn LH (2 bars) & change places
    RH with 1st corners
9-12::
    1st corners (2M & 3L) turn 3/4 LH & change places RH with own
    partner
13-16::
    2nd corners (2L & 3M) turn 3/4 LH, 2L+1M & 3M+1L change places RH on
    1st corner diagonal. 1s face 1st corner position
17-20::
    1s dance 1/2 diag reel of 4 with 1st corner positions; 1s pass RSh
21-24::
    1M+2s (at top) & 1L+3s (at bottom) dance 1/2 reel of 3 across (RSh
    to 2nd corner to start). End 1M between 2, 1L between 3s
25-32::
    Lines of 3 across Set+Link for 3 to end on sides; All turn partners
    1.1/2 RH.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7405, '2013-08-21 08:31:40.422099+00', '2023-02-04 01:22:34.558856+00', 9609, 3, NULL, 'ace', '1-8::
    1s in prom hold dance reel of 3 with 2M+3M _while_ 4s in prom hold
    dance reel of 3 with 2L+3L 1s & 4s ending in middle at top/bottom
9-16::
    1s in prom hold dance reel of 3 with 2L+3L _while_ 4s dance reel of
    3 with 2s+3s continuing reel to end in top/bottom positions facing
    in as 1s+4s pass LSh to BtoB in centre facing out (1s face Mens
    side, 4s face Ladies)
17-24::
    All Adv+Ret (2 bars) & 1s+4s NHJ chase 1/2 way cl''wise (in middle)
    to other side, all Adv+Ret & 1s+4s chase 1/4 way cl''wise to end in
    middle 2 4 1 3
25-32::
    1s+4s dance RH across & LH back _while_ 2s+3s chase clockwise once
    round set to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7406, '2013-08-21 08:31:40.430716+00', '2023-02-04 01:22:34.575583+00', 6254, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s circle 4H round & back
9-16::
    1s also 3s turn RH, cast 1 place, dance down between next couple,
    cast up 1 place.  2 1 4 3 5
17-24::
    1s also 3s cross RH, cast up behind 2s/4s & turn LH twice to face
    2s/4s in line across (Man facing Lady)
25-28::
    2s+1s also 4s+3s turn opposite person RH, 1s & 3s turn partner LH to
    face 4s/5s in line across;
29-32::
    1s+4s also 3s+5s turn opposite person RH & turn partners LH to end
    in lines of 4 across facing 4s/5s again
33-40::
    1s+4s also 3s+5s dance RSh reels of 4 across & end ready for
    Allemande in order 1 4 3 5 (2s stand)
41-48::
    1s+4s also 3s+5s dance Allemande to end 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (8190, '2014-02-10 10:27:02.875216+00', '2023-02-04 01:22:34.593828+00', 6255, 3, NULL, 'ace', '1-8::
    1s set, cast to 2nd place, 2s+1s+3s turn RH, finishing in middle
    facing up, ready for…
9-16::
    _3_ couple Allemande. On bars 15-16 1s turn LH to face 3rd corner as
    2s+3s cross RH to opp. sides
17-24::
    1s dance 1/2 reel of 4 with 3rd crnrs, pass LSh, dance 1/2 reel of 4
    with 4th crnrs finish in 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8167, '2014-02-04 22:30:54.687984+00', '2023-02-04 01:22:34.614019+00', 9390, 3, NULL, 'ace', '1-8::
    1s set & cross down RH to 2nd place, set & turn LH 1.1/4  to face
    2nd corners
9-16::
    1s dance Pass+Turn with 2nd corners & 1s turn right about to face
    1st crnr, repeat with 1st crnrs & end turning right about to 1L
    facing up & 1M down
17-24::
    1s dance RH across (Lady with 2s & Man with 3s), 2s & 3s chase
    clockwise 1/2  way (1s follow couples & end in middle)
25-32::
    1s dance LH across (Man with 3s at top & Lady with 2s) & all chase
    anticlockwise 1/2  way to end 2 1 3
::
    Second time: 1s+4s change places LH on sides as new 1s begin', 0);
INSERT INTO 'dancecrib' VALUES (7408, '2013-08-21 08:31:40.447737+00', '2023-02-04 01:22:34.632087+00', 9099, 3, NULL, 'ace', '1-4::
    1L+2L+3L cross & dance RSh round partnrrs, 1L & 3L finish back in
    place _while_ 2L remains in centre
5-8::
    2L dances RH across with 1L+3L all ending in original places
9-16::
    1M+2M+3M cross & dance RSh round partners, follow 3M down Ladies
    side, cross & up Men''s side (Mens order 3 2 1)
17-24::
    All circle 6H round once (6 bars) & all cross RH with opposite
    dancer
25-28::
    1L crosses to own side & casts down behind opposite dancer _while_
    3L crosses & casts up behind opposite dancer, both cross diagonally
    up/down between 2s to end opposite partners.  3 2 1 all on opposite
    sides
29-32::
    1L followed by partner casts up 1 place & crosses to end 2nd place
    own sides
33-40::
    1s dance diag R&L to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10100, '2017-09-03 23:45:26.538903+00', '2023-02-04 01:22:34.6499+00', 17780, 3, NULL, 'ace', '{{explanation}}
Circle, Man has Lady on his right

1-8::
    Ladies dance 1/2 Fig 8 passing in front of partner, behind next Man
    to end on Man''s Left, facing him.  All change places RH then LH with
    partner, back to original places.
9-16::
    Men dance 1/2 Fig 8 passing behind partner, in front of next Lady to
    end on Ladies'' Right, facing her.  All change places RH then LH with
    partner, back to original places.
17-24::
    Ladies Adv+Ret.  Men Adv+Ret
25-32::
    All Set+Link with partner.  All turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (8789, '2015-06-15 11:41:12.326564+00', '2023-02-04 01:22:34.669633+00', 16255, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up bars 3-4), cross RH, cast to Right to
    1L between 2s facing down, 1M between 3s facing up
9-16::
    1L+2s & 1M+3s Adv+Ret, circle 6H 1/2 round to Left
17-24::
    1M+3s & 1L+2s Adv+Ret, 1s turn RH 1.1/4 times to face 1st corners
25-32::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh, 1/2 diag
    reel of 4 with 2nd corners. 1s end in middle 1M below 1L facing own
    sides
33-40::
    1L+2s & 1M+3s dance LH across. 1s end 2nd place opposite sides.
    2s+3s turn LH _while_ 1s turn RH 1.1/2 times to own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7409, '2013-08-21 08:31:40.456573+00', '2023-02-04 01:22:34.698592+00', 6259, 3, NULL, 'ace', '1-8::
    1s set, cast 2 places, cross RSh & cast up to 2nd place opp sides
    (2s step up 7-8)
9-16::
    2s+1s+3s dance mirror reels of 3 on sides, 1L+2M pass LSh, 1s
    dancing in/up, 2s out/down to start.  2s & 3s dance loops at end of
    reel ready for …
17-24::
    Reels of 3 across, 1L+3s (1L Lsh to 3L) & 1M+2s (1M LSh to 2M). Bars
    23-24 1s approach each other, pull back RSh to face 1st corners
25-36::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s meet again in the
    middle
37-40::
    1s turn RH to 2nd place own side _while_ 2s+3s dance clockwise 1/2
    round set to end 2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (14809, '2022-05-05 00:21:48.165387+00', '2023-02-04 01:22:34.725828+00', 17114, 3, NULL, 'ace', '{{explanation}}
Note: Music in 10 bar phrases

1-10::
    1s+3s set & dance 1/2 R&L (no polite turn), 3M+1L cross, dancing out
    between 2s _while_ 3L+1M cross, dancing out between 4s & 1s & 3s 1/2
    turn partner LH back to place
11-20::
    All set to partner, all dance 1/2 Grand Chain (1 bar/hand), all turn
    partner RH.  3 4 1 2
21-30::
    3s+1s set & dance 1/2 RH across, 2s+4s set & dance LH across, all
    set
31-40::
    All dance Double Ladies'' Chain with Ladies dancing 1/2 RH across in
    centre, Bars 37-38 all 1/2 turn LH into prom hold & dance
    anticlockwise 1 place round.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7410, '2013-08-21 08:31:40.465214+00', '2023-02-04 01:22:34.750656+00', 13733, 3, NULL, 'ace', '1-8::
    All dance Interlocking reels of 4 round the set giving RSh to
    partner
9-16::
    All set & advance with partners, retire diagonally with corners &
    set facing corner
17-24::
    All dance Interlocking reels of 4 round the set giving RSh to corner
25-32::
    All set in diagonally with corners, Adv+Ret with partners & set
33-40::
    All turn partners RH, all turn corners LH
41-48::
    All set with partners & Petronella-in-tandem twice
49-56::
    All dance 1/2 Schiehallion reels
57-64::
    All circle 8H round & back

{{explanation}}
Repeat in Reel time', 0);
INSERT INTO 'dancecrib' VALUES (7411, '2013-08-21 08:31:40.474142+00', '2023-02-04 01:22:34.770718+00', 12617, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All set twice & turn partner 2H
17-32::
    All dance Pass+Turn Grand Chain (pass 1st person RH & turn next LH
    1.1/2 times)
33-48::
    1L+3M dance full Petronella
49-56::
    Ladies dance RH across & turn partners RH 1.1/2 times
57-64::
    Men dance LH across & turn partners RH 1.1/2 times
65-96::
    1M+3L repeat bars 33-64
97-160::
    2L+4M & 2M+4L each repeat bars 33-64
161-176::
    All Ladies dance full Petronella
177-192::
    All repeat bars 49-64
193-200::
    All Men dance full Petronella
201-224::
    All repeat bars 49-64
225-256::
    All repeat bars 1-32', 0);
INSERT INTO 'dancecrib' VALUES (8638, '2015-02-13 12:48:16.974684+00', '2023-02-04 01:22:34.909242+00', 10423, 3, NULL, 'ace', '1-8::
    1s+2L dance reel of 3 across (1M+1L pass RSh to start). End in line
    of 3 facing down (1M in middle, 1L on his right) 2M step in to face
    1M
9-16::
    2M (dancing backwards) followed by 1s+2L dance down, 1M (dancing
    backwards) followed by 1s+2M dance back to top, 1s (on opp. sides)
    +2s finish in middle, 2H joined ready for…
17-24::
    1s+2s dance Poussette (1s, on opp. sides, dance towards Man''s side
    to start)
25-32::
    1s dance 1/2 Fig. 8 round 2s.  1s+2s turn once round (Men LH, Ladies
    RH)', 0);
INSERT INTO 'dancecrib' VALUES (8639, '2015-02-13 12:48:16.984581+00', '2023-02-04 01:22:34.931989+00', 14969, 3, NULL, 'ace', '1-8::
    1s cross RH, cast, dance 1/2 Fig 8 (1M round 2s, 1L round 3s). 1s
    pass LSh to face 1st corners as 4s cross RH and cast to 5th place
9-16::
    1s dance 1/2 diag. reel of 4 with 1st corners, pass RSh, repeat with
    2nd corners _while_ 4s dance Fig 8 round 5s. 1s+4s finish in middle,
    Ladies face down, Men face up
17-20::
    1s+4s dance 1/2 reel of 4.  1L finishes facing down followed by 1M,
    4M facing 1M pstn., 4L facing 3L pstn.
21-28::
    4s dance 1/2 diag reel of 4 with corners, pass RSh to 4L facing 3M
    (1L pstn) & 4M facing 2L (3M pstn)  Repeat 1/2 diag. reel with
    corners.  4s finish in middle facing up (4L on 4M''s Left) _while_ 1s
    dance alternating tandem reel with 5s (1s pass 5L LSh to start)
29-32::
    4s lead up, cross and cast to 3rd place as 1s lead up, cast round 3s
    into 5th place (3s step up bars 31-32)    2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (11711, '2019-03-18 21:02:54.645946+00', '2023-02-04 01:22:34.958858+00', 19140, 3, NULL, 'ace', '1-4::
    1L dances 1/2 Fig of 8 round 2M _while_ 1M dances across the set &
    casts round 2L to finish 1L facing down, 1M facing up
5-8::
    1s turn 1.1/4 RH to finish in 2nd place facing up in promenade hold
    _while_ 2s cast to top (bars 5-6) and 3s dance in on left foot on
    bar 8 to promenade hold
9-16::
    1s+3s dance 6 bars of Allemande. On bars 7 & 8 continue flow to
    left, drop RH & turn LH to finish in middle of set facing own sides
17-24::
    1s cast down round 4s _while_ 3s cast up round 2s,  1s+3s dance into
    centre & dance 4 Hands round to the left to finish on the sides 2 3
    1 4
25-32::
    1s cross RH, face down. 1s+4s dance 3/4 double Fig of 8 (4s cross
    up) at end 4L loops into 3rd place _while_ 4M dances directly into
    side', 0);
INSERT INTO 'dancecrib' VALUES (7412, '2013-08-21 08:31:40.482498+00', '2023-02-04 01:22:35.183117+00', 5798, 3, NULL, 'ace', '1-8::
    1s+2s+3s circle 6H round to left for 6 steps, turning left circle 6
    steps to right back to places
9-16::
    1s+3s dance double Fig of 8 round 2s (1s crossing down to start)
17-24::
    1L+2M change places RH, set & change back RH _while_ partners set,
    change places RH & set, 1L casts 1 place as 2M casts up as 1M+2L
    turn LH to face partners on diagonal
25-32::
    2s+1s dance 3/4 diagonal reel of 4 (6 bars), 1M+2M also 1L+2L turn
    RH to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7414, '2013-08-21 08:31:40.500979+00', '2023-02-04 01:22:35.208971+00', 5802, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 2 places, cross LH below 3s & cast up to 2nd place
    own sides
9-16::
    2s+1s+3s 1/2 turn RH retain hands & all set (M face down & L up) 2L
    leads Ladies across & down own side _while_ 3M leads Men across & up
17-24::
    3s+1s+2s circle 6H round & back
25-32::
    3s+1s+2s 1/2 turn LH retain hands & all set (M face up & L down) 2L
    leads Ladies across & up own side _while_ 3M leads Men across & down', 0);
INSERT INTO 'dancecrib' VALUES (7416, '2013-08-21 08:31:40.519082+00', '2023-02-04 01:22:35.416198+00', 5807, 3, NULL, 'ace', '{{explanation}}
Round the Room Dance 2 facing 2

1-8::
    All dance RH across & LH back
9-16::
    Ladies cross RH, set to other partner & turn LH
17-24::
    Ladies cross back RH, set to partner & turn LH
25-32::
    Men advance PdB, set & Tulloch turn to face partners
33-40::
    All dance diagonal reel of 4
41-48::
    All dance Poussette to face next couple', 0);
INSERT INTO 'dancecrib' VALUES (7417, '2013-08-21 08:31:40.527562+00', '2023-02-04 01:22:35.445214+00', 5808, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast in 1 place & dance RH across once round in
    the centre retaining hold of RH
9-16::
    1s+4s pick up corners on LH & all dance round 2 places (St Andrews
    cross formation), set to corner & change places LH
17-24::
    2s+3s form RH star in centre with corners on LH & dance round 2
    places, set & change pl with corners (2s & 3s pass between 1s & 4s)
25-32::
    1s & 4s with nearer hands joined dance out of ends & cast back to
    centre, 1s+4s dance 1/2 R&L ending in pstns 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13637, '2021-02-04 01:21:48.924653+00', '2023-02-04 01:22:35.534904+00', 15233, 3, NULL, 'ace', '1-4::
    All Set+Link to end with Men LHJ in centre, RHJ with Lady originally
    to right (i.e. 1M+4L etc)
5-8::
    All Bal-in-Line, Men dance 1/2 LH across _while_ Ladies dance 1
    place clockwise & join RH with partner
9-12::
    All Bal-in-Line, change places with partner & Men facing clockwise
13-16::
    Men followed by partners chase clockwise to end 2 3 4 1 & all set
17-24::
    2s+4s (1st & 3rd places) dance Ladies'' Chain
25-32::
    1s+3s (2nd & 4th places) set advancing, turn opp. person 2H (skip
    change); 1s+3s circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (12747, '2020-04-11 10:53:07.928179+00', '2023-02-04 01:22:35.569412+00', 14982, 3, NULL, 'ace', '1-4::
    1s turn 2s on sides 1.1/4 (Ladies LH, Men RH) 1s finish NHJ in
    centre facing down with 2s at the top
5-8::
    1s dance down between 3s and cast up to 2nd place, own side
9-12::
    1s turn 2s on sides (Ladies RH, Men LH) to finish NHJ in centre
    facing up, 2s at top
13-16::
    1s dance up between 2s and cast to 2nd place, own side
17-24::
    1s+3s turn once round on sides (Ladies LH, Men RH); 2s+1s turn once
    round on sides (Ladies RH, Men LH)
25-32::
    2s+1s+3s circle 6H round and back. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10227, '2017-11-04 01:46:06.250854+00', '2023-02-04 01:22:35.57982+00', 18023, 3, NULL, 'ace', '{{explanation}}
2 chords: 2nd chord 2s+3s step in towards each other

1-8::
    1s+4s dance R&L around standing 2s+3s.  2s+3s step back to original
    places on bar 8
9-16::
    1s+4s dance Figs 8 round 2s / 3s
17-24::
    2s+3s Adv+Ret then turn partners RH (Alternatively turn 2H)
25-32::
    2s+3s dance 1/2 R&L, all set; 2s+3s Adv to join RH in centre _while_
    1s+4s set, join hands with 2s+3s to form St Andrew''s Cross, all
    facing clockwise
33-40::
    All dance 2 steps round, all set, dropping hands & pulling back RSh
    on 2nd step to face anticlockwise;
::
    All join hands again & dance anticlockwise 2 steps round, all set
    returning to places (as bar 28) on 2nd setting step
41-48::
    2s+3s Adv+Ret then dance 1/2 R&L
49-56::
    1s+4s Adv+Ret. 1s cross RH as 4s turn RH
57-64::
    1s set twice (Highland step preferred), lead down crossing to 4th
    place (1L crossing in front of 1M) own sides
::
    Note:  Crib based on instructions & diagram published in "The Reel"
    Issue 301 (September-December 2017).  This differs from original
    description which contains barring errors and is described as 48 bar
    reel but with jig time music by deviser.', 0);
INSERT INTO 'dancecrib' VALUES (7420, '2013-08-21 08:31:40.551433+00', '2023-02-04 01:22:35.610559+00', 5804, 3, NULL, 'ace', '1-8::
    1L+2L also 1M+2M change places LH on sides, set to partners, 2s+1s
    circle 4H round to right
9-16::
    1s dance in, cast left, 1s dance in & turn to face 1st corner, turn
    RH (end 1L between 2s & 1M between 3s) & 2s+1s+3s set in line across
17-24::
    1s dance in, cast left, 1s dance in & turn to face 2nd corners, turn
    RH to end 2nd place opposite sides & 2s+1s+3s set
25-32::
    2s+1s+3s Adv+Ret, 1s turn 2H (PdB) & retire to own sides', 0);
INSERT INTO 'dancecrib' VALUES (7421, '2013-08-21 08:31:40.559838+00', '2023-02-04 01:22:35.640911+00', 8736, 3, NULL, 'ace', '1-8::
    1s cast 1 place, cross RH & face in giving LH to 1st corners,
    Set+Link with 1st corners
9-16::
    1s+1st corner persons dance RH across, 1s+2s+3s circle 6H round 3/4
    way to left (1M ends 1st place Ladies side & 1L ends 3rd place Men''s
    side)
17-24::
    1s cast round person in 2nd pl (who step up/down) & cross LH to 2nd
    pl own side & face in giving RH to 2nd crnrs, Reverse Set+Link with
    2nd cnrs
25-32::
    1s+2nd corner persons dance LH across & 1s+2s+3s circle 6H round 3/4
    way to right (1M ends 1st pl Men''s side & 1L ends 3rd pl Ladies
    side)
33-40::
    1s cast round person in 2nd pl (who step up/down), 2s+1s+3s advance
    (PdB) & turning right about & dance out to places & set', 0);
INSERT INTO 'dancecrib' VALUES (7422, '2013-08-21 08:31:40.568249+00', '2023-02-04 01:22:35.670557+00', 11107, 3, NULL, 'ace', '1-8::
    1s set advancing & turn 2H to finish facing up NHJ; 1s cast (2s step
    up) & petronella turn to 1L between 2s facing down, 1M between 3s
    facing up
9-16::
    All Set+Link for 3 twice to end 1M between 3s (1st place) facing
    down, 1L between 2s (3rd place) facing up (2s & 3s on opp sides)
17-24::
    All circle 6H round and back finishing in same positions
25-32::
    1M+3s & 1L+2s dance 1/2 reels of 3 across (1s RSh to person on
    Right); 1s turn 2H to 2nd place own side & all set
33-40::
    1s followed by 2s dance up between 3s and cast (3 2 1); 2s followed
    by 3s dance down between 1s and cast up to finish 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7423, '2013-08-21 08:31:40.576521+00', '2023-02-04 01:22:35.703859+00', 14518, 3, NULL, 'ace', '1-8::
    1s set & dance down below 3s, cast up 1 place to face 1st corner (2s
    up on bars 5/6)
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners & pass LSh to face
    2nd corner, 1/2 diagonal reel with 2nd corners & pass LSh to face
    3rd corner (pstn)
17-24::
    1s turn 3rd corners RH & partner LH to face 4th corner (pstn), turn
    4th corners RH & turn partner LH (M facing up, L down)
25-32::
    1s dance 1/2 reels of 3 across giving LSh to 3rd corner (pstn) & 1/2
    reels of 3 on sides RSh to 4th corner (pstn) to end in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (13920, '2021-04-05 00:21:50.78366+00', '2023-02-04 01:22:35.752319+00', 19513, 3, NULL, 'ace', '1-8::
    Mirror reels of 3 on sides (1s in/down, 2s out/up to start)
9-16::
    1s cross, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s.  2 1 3
17-24::
    2s+1s cross RH with partner,  1M+2L cross RH _while_ 1L+2M set;
    1s+2s cross RH, 2M+1L cross LH _while_ 1M+2L set.  (1) (2) 3
25-32::
    1s+2s dance the Tournée', 0);
INSERT INTO 'dancecrib' VALUES (7424, '2013-08-21 08:31:40.586804+00', '2023-02-04 01:22:35.778061+00', 11680, 3, NULL, 'ace', '1-8::
    All dance Grand Chain
9-16::
    1s & 3s set to partner, cross LH to face partners corner, 1L+3M
    dance RH across with 2s _while_ 1M+3L dance RH across with 4s & Men
    end behind partners for…
17-24::
    1s dance Tandem reel of 3 across with corners (RSh to 2L to start)
    _while_ 2s (in tandem) reel of 3 with their corners (RSh to 4L) &
    end with 1s+3s dancing RH across 1/2 way to face side couples (1M
    facing 2M, 1L facing 4L, 3L facing 2L & 3M facing 4M)
25-32::
    All turn facing person (Men RH & Ladies LH) 1s ending in 3rd place &
    3s in 1st place, 3s & 1s set to partner & change places RH
33-64::
    Repeat with 2s & 4s as dancing couples
65-96::
    Repeat with 3s & 1s as dancing couples ending in original places
97-128::
    Repeat with 4s & 2s as dancing couples all ending in original places', 0);
INSERT INTO 'dancecrib' VALUES (7419, '2013-08-21 08:31:40.542969+00', '2023-02-04 01:22:35.807187+00', 12902, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up 3-4), dance down NHJ between 3s, cast up to
    2nd place own sides
9-16::
    1s turn RH to face 1st cnr, turn 1st cnr LH, ptnr RH, 2nd cnr LH to
    finish 1M between 2s all facing down, 1L between 3s all facing up
17-24::
    All Set+Link; all set, all change places RH with partner
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (7425, '2013-08-21 08:31:40.595011+00', '2023-02-04 01:22:35.835584+00', 5817, 3, NULL, 'ace', '1-8::
    1s cross down to 2nd place, 2s+1s set & dance RH across
9-16::
    1s dance reel of 3 on opposite sides (LSh to 3s to start)
17-24::
    1s+3s dance LH across, 1s cross LH & set
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7426, '2013-08-21 08:31:40.601208+00', '2023-02-04 01:22:35.850504+00', 8154, 3, NULL, 'ace', '{{explanation}}
Couples in ballroom hold face anticlockwise round room, Ladies on the outside

1-8::
    All in waltz hold take 3 steps (Lady right, Man Left) & stamp both
    feet, 2 steps in opposite direction then 2 steps towards centre
    (start Lady right foot, Man left foot)
9-16::
    All take 2 steps back out & Lady turns under Man''s right arm, all
    waltz round room', 0);
INSERT INTO 'dancecrib' VALUES (9756, '2017-04-06 08:40:16.942889+00', '2023-02-04 01:22:35.87677+00', 17653, 3, NULL, 'ace', '1-8::
    1s+3s dance RH across & LH across back to place
9-16::
    All set to partner, turn partner RH, turn corner LH, set to partner
17-20::
    Grand Chain for 2 hands, then turn 3/4 RH with 3rd person.  End Men
    facing in, Ladies out
21-24::
    All dance Double Men''s Chain 1/2 way (Men LH across in centre).  End
    with own partner and facing in.
25-28::
    All Set & circle 8H round to left one place
29-32::
    All turn partner 2H. then circle 8H round to left one more place

{{explanation}}
All couples have now moved one place anticlockwise from original positions', 4);
INSERT INTO 'dancecrib' VALUES (8191, '2014-02-10 10:27:03.05816+00', '2023-02-04 01:22:35.902912+00', 14072, 3, NULL, 'ace', '1-8::
    1s & 2s also 3s & 4s dance Double Fig of 8 (1s and 3s cast, 2s and
    4s cross up to start)
9-12::
    1L followed by ptnr, casts round 2L, crosses to 3M place _while_ 3M
    followed by ptnr, casts up round 2M, cross to 1L place      (3) 2
    (1) 4
13-16::
    3s & 2s dance RH across _while_ 1s & 4s dance LH across
17-24::
    2s & 1s dance Ladies'' Chain (1L "pirouettes" or pivots to change
    direction)
25-28::
    2s & 3s dance clockwise to change places _while_ 1s & 4s dance
    clockwise to change places (2) 3 (4) 1
29-32::
    2s & 4s set and cross RH  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13348, '2020-11-02 01:21:56.161256+00', '2023-02-04 01:22:35.964487+00', 17620, 3, NULL, 'ace', '1-8::
    1s take prom hold, dance down between 3s, cast to left, dance in
    between 2s & curve back into 1st place
9-16::
    All circle 8H round & back
17-24::
    Ladies join RH in centre, retain LH with partner & all dance RH
    across, turn Men into centre & dance LH across
25-32::
    All promenade round anticlockwise 3 places; all turn partner RH (or
    birl).  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (7427, '2013-08-21 08:31:40.696074+00', '2023-02-04 01:22:36.212287+00', 7520, 3, NULL, 'ace', '1-8::
    2s+4s dance RH across, 2s dance up _while_ 4s dance down, 2s & 4s
    casting round ends on own sides to face 1st corners
9-16::
    2s+4s Pass+Turn with 1st corners, pass partner LSh & Pass+Turn with
    2nd corners & into centre facing partner (L facing down M up)
17-24::
    2s+4s dance reel of 4 ending in original places on sides
25-32::
    2s & 4s set & cast down 1 place _while_ 3s & 5s set & dance up 1
    place, 1s & 2s turn RH & cast down 1 place.  3 1 5 2 4', 0);
INSERT INTO 'dancecrib' VALUES (7428, '2013-08-21 08:31:40.704576+00', '2023-02-04 01:22:36.244448+00', 5824, 3, NULL, 'ace', '1-8::
    All advance for 2 steps & retire, turn partners RH to end in own
    places Men facing up & Ladies down
9-16::
    All chase round to places
17-24::
    1s+2s also 3s+4s dance RH hands across & back
25-32::
    1s & 4s Adv+Ret (up & down set), advance again up/down set & Men
    also Ladies advance to own sides to 2nd & 3rd places
33-40::
    1s dance Fig of 8 round 3s passing between 4s to start _while_ 4s
    dance Fig of 8 round 2s ending 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7429, '2013-08-21 08:31:40.790941+00', '2023-02-04 01:22:36.385352+00', 5825, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on own sides dancing down between 2s to start
9-16::
    1s followed by 2s+3s cross down to dance large Fig of 8 (through 1st
    & 3rd positions)
17-24::
    1M+2M+3M circle 3H round to left _while_ 1L+2L+3L circle round to
    right, 1s followed by 2s+3s lead down below 3rd pl & cast up to orig
    places
25-32::
    1s+2s dance reel of 4 across (1L+2M pass RSh to start) & 1s end in
    2nd place', 0);
INSERT INTO 'dancecrib' VALUES (7432, '2013-08-21 08:31:40.823601+00', '2023-02-04 01:22:36.40621+00', 8463, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s cross RH, cast 1 place, 1s dance 1/2 Fig of 8 round 2s
17-24::
    1s lead down & back to 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7433, '2013-08-21 08:31:40.831916+00', '2023-02-04 01:22:36.424299+00', 5830, 3, NULL, 'ace', '1-4::
    1s cross down RH below 3s & cast up 1 place _while_ 3s cast up to
    top & cross RH _while_ 2s set & cross down 1 place
5-8::
    1s cross LH & cast to left to end between 2s/3s facing up/down
9-16::
    All turn facing person RH, 1s dance 1/2 reels of 3 on own sides
    giving RSh to 3rd crnr (pstn) & end 1M between top couple/1L between
    bottom cpl
17-24::
    1s dance 1/2 Fig of 8 on own sides, 1s change places RH (up/down) &
    cast to 2nd place opposite side
25-32::
    All turn partners RH, 1s dance 1/2 reels of 3 across giving RSh to
    4th corner (pstn)', 0);
INSERT INTO 'dancecrib' VALUES (7434, '2013-08-21 08:31:40.840128+00', '2023-02-04 01:22:36.446696+00', 8494, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, 1s dance 1/2 Fig of 8 round 2s (crossing up)
9-16::
    1s dance 1/2 Fig of 8 round 3s (crossing down) & 1s+3s dance 1/2 R&L
17-24::
    1L followed by partner casts up to top & crosses to 1st place
    opposite sides, 1s+2s+3s set, 1/2 turn RH
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9488, '2016-11-09 08:49:01.834075+00', '2023-02-04 01:22:36.469395+00', 16006, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up) & dance 1/2 Fig 8 (1L round 3s, 1M
    round 2s) to 2nd place own sides
9-16::
    _1/2_ reels of 3 on sides (2L+1L & 1M+3M pass RSh).  1/2 Reels of 3
    across (1L+3M & 1M+2L pass LSh).  1s end facing 3rd corner (pstn)
17-20::
    1s+corners set, 1s pull back RSh & dance round each other & out to
    1st corner position _while_ corners dance in, pull back RSh to end
    BtoB facing corner position
21-24::
    1s+corners set, corners pull back RSh & dance round each other & out
    to 1st corner position _while_ 1s dance in, pull back RSh to end
    BtoB facing 4th corner position
25-32::
    1s+corners repeat bars 17-24 ending with 1s passing RSh to 2nd place
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (7436, '2013-08-21 08:31:41.125272+00', '2023-02-04 01:22:36.51687+00', 5832, 3, NULL, 'ace', '1-8::
    1s turn RH & cast to 2nd place & cross passing RSh to cast to 3rd
    place opposite side & left arm-turn 1.1/2 times.  2 3 1
9-16::
    1s cast up to 2nd place & cross passing LSh, 1s cast up to 1st place
    opposite side & cross RH & set.  1 2 3
17-24::
    1s lead down & back (2s step in Bar 24)
25-32::
    1s+2s dance a poussette', 0);
INSERT INTO 'dancecrib' VALUES (7437, '2013-08-21 08:31:41.13398+00', '2023-02-04 01:22:36.536608+00', 5835, 3, NULL, 'ace', '1-8::
    1M+2L set twice & turn RH _while_ 4M+3L set twice & turn LH
9-16::
    1L+2M set twice & turn LH _while_ 4L+3M set twice & turn RH
17-24::
    1s+2s also 3s+4s dance Allemande
25-32::
    1s+4s (Middle couples) set diagonally in & petronella on one place &
    repeat
33-40::
    1s/4s dance 1/2 Fig of 8 round 3s/2s & turn RH to 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7438, '2013-08-21 08:31:41.143969+00', '2023-02-04 01:22:36.551948+00', 5836, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, 2s+1s circle 4H round to left
9-16::
    1s dance reels of 3 on sides (1s dance in & up to start)
17-24::
    1s+2s dance RH across, 1s+3s dance LH across & 1s end facing 1st
    corners
25-32::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (7545, '2013-08-21 08:31:42.908772+00', '2023-02-04 01:22:44.704545+00', 9240, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, 1s cast 2 places & 1/2 turn RH to face up in
    prom hold
9-16::
    1s dance 1/2 RSh reel of 3 with 3s & 1/2 LSh reel of 3 with 2s & end
    at top with 2s behind for...
17-24::
    1s+2s dance Allemande 1s end turning LH 1.1/4 times
25-32::
    1s dance RH across (Lady with 2s & Man with 3s) & 2s+1s+3s turn 2H
    twice', 0);
INSERT INTO 'dancecrib' VALUES (10840, '2018-06-11 00:37:08.203895+00', '2023-02-04 01:22:36.580683+00', 12245, 3, NULL, 'ace', '1-8::
    1s+2s+3s 1/2 turn partner RH, pull back RSh (twirl), dance out to
    partner''s place; Men face down, Ladies up & all chase clockwise 1/2
    round to own sides.  3L & 1M face out
9-12::
    3L dances behind 2L & across to 3M place, pulls back RSh to face in
    as 1M dances similarly up behind 2M into 1L place _while_
::
    1L+3M turn 1.1/2 with 2H to just in front of partner''s place facing
    in
13-16::
    1s+3s turn partners 1.1/2 times 2H ending in middle NHJ, 1s in 1st
    place facing down, 3s in 3rd place facing up
17-24::
    1s+2s+3s circle 6H round & back finishing on sides
25-32::
    1s+2s set, turn partners 2H staying in middle facing down NHJ; 2s
    followed by 1s dance down below 3s & cast up on own sides to end 2 1
    3

{{explanation}}
Note:	End of 2nd time 1s can dance to 4th place (4s step up) or turn 4s 2H to end in 4th place', 0);
INSERT INTO 'dancecrib' VALUES (8718, '2015-03-11 23:47:50.278836+00', '2023-02-04 01:22:36.59367+00', 16158, 3, NULL, 'ace', '1-8::
    1s+3s turn partners RH (4 bars), 1s+3s chase clockwise (Men leading)
    to opp. sides _while_ 2s+4s Adv+Ret
9-16::
    2s+4s turn partners RH (4 bars), 2s+4s chase clockwise (Men leading)
    to opp. sides _while_ 1s+3s Adv+Ret
17-24::
    1s+3s Adv+Ret, 1s+3s dance 1/2 R&L
25-32::
    2s+4s repeat 17-24.  All face corner persons
33-64::
    All set to corners & dance La Baratte
::
    Men 1/2 turn corner RH & retain hand but at arm''s length from each
    other, Men retrace steps with corner turning right under his arm
    briefly into Allemande hold (Men behind corner facing Men''s original
    place) & releasing corner''s RH she turns under Man''s left arm & all
    change places LH and pass next person RSh to face next corner.
::
    Repeat with each corner in turn (Men moving clockwise, Ladies
    anticlockwise round set). Finish in partner''s original place, facing
    partner
65-72::
    All 1/2 turn partners RH, join hands in circle (Men facing in/Ladies
    out) & set.  All turn partners RH to original places (Ladies face
    out)
73-88::
    All dance Schiehallion Reels back to original places
89-96::
    All promenade anticlockwise once round', 0);
INSERT INTO 'dancecrib' VALUES (7439, '2013-08-21 08:31:41.152207+00', '2023-02-04 01:22:36.622198+00', 9408, 3, NULL, 'ace', '1-4::
    1s NHJ dance down to 4th place, curve to right to finish facing up
    in centre NHJ still joined (2s+3s+4s step up 3-4);
5-8::
    4s+1s set facing on sides & turn once round (1s dancing between 4s).
    1s end in middle facing up
9-16::
    1s repeat 5-8 with 3s, then 2s finishing at top facing up
17-24::
    1s dance up 1 step then cast on opp sides to 4th place _while_
    2s+3s+4s set & cross RH; 2s+3s also 4s+1s dance RH across
25-32::
    All set on sides, cross LH with partner; 2s+3s also 4s+1s dance LH
    across', 0);
INSERT INTO 'dancecrib' VALUES (7440, '2013-08-21 08:31:41.160506+00', '2023-02-04 01:22:36.65154+00', 8737, 3, NULL, 'ace', '1-8::
    2s & 4s RH across with 1s, 3s & 5s (Ladies up & Men down), pass RSh
    for LH across with other couples & end facing 1st corners
9-16::
    2s & 4s turn 1st corner RH, partner LH, 2nd corner RH, partner LH &
    end facing 1st corners
17-24::
    2L+1s also 4M+5s dance LSh reels of 3 across _while_ 2L+3s+4L dance
    RSh reel of 4 across all ending in original places
25-32::
    1s+2s also 3s+4s, Set+Link on the sides, 1s+4s also 3s+5s, Set+Link
    on the sides.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (7441, '2013-08-21 08:31:41.168817+00', '2023-02-04 01:22:36.676705+00', 8364, 3, NULL, 'ace', '1-8::
    1s lead down, cross below 4s, cast up behind 4s, dance up between 3s
    & cast up behind 2s to end at top in prom hold
9-16::
    1s dance 1/2 reel of 3 across with 2s (RSh to 2M) & 1/2 reel of 3
    across with 3s (LSh to 3L)
17-24::
    1s dance 1/2 reel of 3 across with 4s (RSh to 4M), 2s+3s also 4s+1s
    dance 1/2 double Fig of 8 (3s & 1s cast up to start)
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7442, '2013-08-21 08:31:41.178932+00', '2023-02-04 01:22:36.710996+00', 5839, 3, NULL, 'ace', '1-8::
    1M+2M set & cross _while_ partners cross diagonally down & cast up
    into partner''s place, 1L+2L set & cross _while_ partners cross
    diagonally down & cast up into partner''s place
9-16::
    1s 1/2 Fig of 8 on sides (RSh to 2s to start) & end in centre facing
    up, 1L dances RH across with 2L+3L _while_ 1M dances LH across with
    2M+3M
17-24::
    1s dance reels of 3 on sides (1s in & up to stat) & 1s end facing
    1st corner
25-32::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH to
    places', 0);
INSERT INTO 'dancecrib' VALUES (7443, '2013-08-21 08:31:41.188173+00', '2023-02-04 01:22:36.748325+00', 10921, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L & all end facing corners
17-24::
    All dance Interlocking reels of 4 (RSh to corner to start)
25-32::
    All Petronella-in-tandem to next place anticlockwise, set to partner
    & turn 2H ready to start again', 0);
INSERT INTO 'dancecrib' VALUES (7444, '2013-08-21 08:31:41.203003+00', '2023-02-04 01:22:36.791122+00', 5840, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, petronella turn to 1M between 2 & 1L
    between 3s (facing up) & all set
9-16::
    1s dance 1/2 reels of 3 across (RSh to person on right) into 1/2
    reel of 3 on opp sides to end 1M between 2s (3rd place) face up & 1L
    between 3s
17-24::
    2s+1s+3s Adv+Ret for 2 steps & 1s turn LH to 2nd place own sides
25-32::
    1s dance diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (14494, '2021-12-18 01:46:29.057895+00', '2023-02-04 01:22:36.813171+00', 20561, 3, NULL, 'ace', '1-8::
    All 3 couples set, 1L casts 2 places, dances up round 3L into 2nd
    place own side facing up _while_ 1M dances down centre, casts up
    round 3M to 2nd place facing up (2s step up on 5-6)
9-16::
    2s+1s+3s dance LSh reels of 3 on sides (1s pass 2s LSh to start)
17-24::
    2s+1s dance LH across; 1s+3s dance RH across
25-30::
    1L casts up 1 place, dances down centre to 3rd place _while_ 1M
    dances up centre, casts to 3rd place (3c step up on 27-28)
31-32::
    2s+3s+1s set', 0);
INSERT INTO 'dancecrib' VALUES (13638, '2021-02-04 01:21:50.013547+00', '2023-02-04 01:22:36.869607+00', 20214, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 on own sides (1s in/down to start, taking nearer
    hands where possible)
9-16::
    1s join 2H & slip step down & back to top, remaining in middle
    facing up
17-24::
    1s cast to 2nd place (2s step up bars 19-20); 2s+1s dance DoSiDo
25-32::
    2s+1s dance RH across & LH back', 0);
INSERT INTO 'dancecrib' VALUES (7447, '2013-08-21 08:31:41.228134+00', '2023-02-04 01:22:36.902765+00', 5843, 3, NULL, 'ace', '1-8::
    1s+2s set & dance 3/4 Double Fig of 8 (1s cast to start)
9-16::
    2s+1s+3s set, cross RH, set & 1/2 turn RH into centre
17-24::
    2s+1s+3s dance a Tandem reel of 3 (Men following partners with 1s
    giving RSh to 2s to start)
25-32::
    1s dance parallel reels of 3 on opp sides (1s RSh to 2s to start)
    ending with 2M+1M BtoB facing other partner
33-40::
    2s+1s dance reel of 4 across (RSh to Ladies) Men end by curving into
    BtoB position facing own partner
41-48::
    2s lead down between 3s as 1s 1/2 turn RH & follow 2s, cross below
    3s, cast up (2s to top & 1s to 2nd place) & cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (7448, '2013-08-21 08:31:41.241571+00', '2023-02-04 01:22:37.033549+00', 7928, 3, NULL, 'ace', '1-8::
    1s advance passing RSh twirl to left & retire (1M up & 1L down),
    repeat up/down & retire to opposite sides
9-16::
    2s repeat bars 1-8
17-24::
    1s+2s set, circle 4H round to left & 1/2 turn RH into…
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7449, '2013-08-21 08:31:41.251739+00', '2023-02-04 01:22:37.162053+00', 5847, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across 1/2 way, 1s+2s dance 1/2 Poussette back to
    places
9-16::
    1s lead down the middle & back
17-24::
    1s+2s dance RH across 1/2 way & turn partners RH to places', 0);
INSERT INTO 'dancecrib' VALUES (7450, '2013-08-21 08:31:41.260146+00', '2023-02-04 01:22:37.185417+00', 5848, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, turn LH 1.3/4 times to Man facing up &
    Lady down _while_ 2s+3s dance 1/2 R&L
9-16::
    1s dance RH across 1/2 way (Man up, Lady down), 1s dance RSh round
    2nd corners to outside & dance RH across 1/2 way on sides, 1s turn
    LH to face 1st corners (2s & 3s now back in correct corners)
17-24::
    1s dance 1/2 reel of 3 across (Lady with 2s, Man with 3s giving LSh
    to 1st corner) & dance 1/2 reel of 3 on opposite side (RSh to 2nd
    corners)
25-32::
    1s dance 1/2 reel of 3 across (LSh to 3rd corner) & dance 1/2 reel
    of 3 on own side (RSh to 4th corner) to end facing 1st corners
33-40::
    1s turn 1st corners RH, partner LH, 2nd corner RH & partner LH to
    2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7451, '2013-08-21 08:31:41.268416+00', '2023-02-04 01:22:37.207754+00', 14945, 3, NULL, 'ace', '1-8::
    1L+2M change places RH then 1M+2L change places RH, 1s+3s+4s chase
    clockwise 1/2 way  (2)(4)(3)(1
9-16::
    3M+4M dance LSh Tandem reel of 3 on sides (LSh to 1L) as 4L+3L dance
    LSh Tandem reel of 3 (LSh to 2L)
17-24::
    4s+3s dance RH across, 2s+4s+3s chase clockwise 1/2 way  3 4 2 1
25-32::
    2L+4L dance LSh Tandem reel of 3 on sides (LSh to 1L) as 4M+2M dance
    LSh Tandem reel of 3 (LSh to 3M)  3 4 2 1', 0);
INSERT INTO 'dancecrib' VALUES (13536, '2021-01-09 01:21:44.81616+00', '2023-02-04 01:22:37.444336+00', 17690, 3, NULL, 'ace', '1-4::
    1s+2s+3s Adv+Ret
5-16::
    1s+2s+3s dance 3 couple R&L
17-24::
    All Ladies cross passing partner LSh & chase anticlockwise 1/2 way
    round & set _while_ all men set, cross over & chase anticlockwise
    1/2 way round 3 2 1
25-28::
    3s+2s+1s dance 1/2 reflection reels of 3 on sides (3s+2s cross down
    to opp sides from 1st place, 3M gives RSh to 1L & 3L gives LSh to
    1M) 1 (2) (3)
29-32::
    1s+2s dance 1/2 RH across, 1s+3s dance 1/2 LH across 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7452, '2013-08-21 08:31:41.278438+00', '2023-02-04 01:22:37.468216+00', 6271, 3, NULL, 'ace', '1-8::
    1L & 3L set diagonally to 2M & 4M & change places RH, all set to
    partners on sides & change places RH
9-16::
    All dance full reels of 4 on sides
17-24::
    All set & cross over RH, 1s+2s also 3s+4s circle 4H round to left
    ending in 2 diagonal lines for 1/2 Poussette.  2 1 4 3
25-32::
    2s+1s also 4s+3s dance 1/2 Diamond Poussette & 1s lead down to
    bottom', 0);
INSERT INTO 'dancecrib' VALUES (7453, '2013-08-21 08:31:41.292056+00', '2023-02-04 01:22:37.573487+00', 8648, 3, NULL, 'ace', '1-8::
    1s+2s dance the Knot
9-16::
    2s+1s dance R&L
17-24::
    1s dance the Stafford Knot: 1s cross down RH below 3s to cast up 1
    place & cross RH to own side, 1s cast down below 3s to cross up LH
    to 2nd place opp sides
25-32::
    1s dance reflection reels of 3 on opposite sides (out & up to start)
    crossing up from 3rd place to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (14299, '2021-09-08 00:21:53.360225+00', '2023-02-04 01:22:37.600856+00', 20442, 3, NULL, 'ace', '1-4::
    1L crosses down, dances behind 3M to end between 3s _while_ 1M
    crosses down, casts up round 2L to end between 2s (2s step up 1-2)
5-8::
    1s turn LH into prom hold facing 3L
9-12::
    1s dance 1/2 diag reel of 3 with 1st corners (RSh to 3L to start).
    1s end in  centre facing up
13-16::
    1s lead up, cross & cast on opp sides & meet in centre, take prom
    hold to face 3M
17-20::
    1s dance 1/2 diag reel of 3 with 2nd corners (RSh to 3M to start).
    1s end in  centre facing Ladies'' side
21-24::
    1s dance out of Ladies'' side, cross & cast (1L up, 1M down) to end
    1L between 2s at top, 1M between 3s
25-32::
    All circle 6H 1/2 round; 1s set advancing & Petronella turn passing
    RSh to 2nd place own side
33-40::
    1s+3s dance Espagnole', 0);
INSERT INTO 'dancecrib' VALUES (14300, '2021-09-08 00:21:53.499361+00', '2023-02-04 01:22:37.77192+00', 20446, 3, NULL, 'ace', '1-8::
    1M+2L turn RH, 1M ends in 2nd place own side (2M steps up 3-4);
    1L+2M turn LH, 1L end in 2nd place own side (2L steps up 7-8).  2 1
    3
9-16::
    1M+3L turn RH, 1M ends in 3rd place own side (3M steps up 11-12);
    1L+3M turn LH, 1L end in 3rd place own side (3L steps up 15-16).  2
    3 1
17-24::
    Inverted Inveran Reels (1s cross up to start)
25-32::
    1s dance DoSiDo & turn RH (or birl)', 0);
INSERT INTO 'dancecrib' VALUES (7454, '2013-08-21 08:31:41.311705+00', '2023-02-04 01:22:37.825881+00', 15044, 3, NULL, 'ace', '1-8::
    1s+2M also 3s+4M dance RH across, 1s+2L also 3s+4L dance LH across
9-16::
    1s+4M also 3s+5M dance RH across, 1s+4L also 3s+5L dance LH across &
    1L also 3L end facing out Ladies side with partners behind them
17-24::
    1s & 3s dance out Ladies'' side & cast up 1 place, cross to Mens side
    & cast up to original place Ladies looping round by the right
25-32::
    1s cross & cast 1 place, 1s followed by 3s dance up & cast (1s to
    3rd place, 3s to 2nd place)
33-40::
    1s cross & cast 1 place, 1s followed by 5s dance up & cast (1s to
    5th place, 5s to 4th place).  2 3 4 5 1
::
    NB - No stepping up or down until bar 27', 0);
INSERT INTO 'dancecrib' VALUES (7455, '2013-08-21 08:31:41.321893+00', '2023-02-04 01:22:37.868277+00', 6273, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across, 1s cast 2 places _while_ 2s+3s
    dance up
9-16::
    2s+3s also 1s+4s dance LH across, 1s dance up to top as 2s+3s step
    down
17-24::
    1s cross RH, cast 1 place, cross RH & cast to bottom ending with 2s
    facing 1s up/down centre
25-32::
    2s & 1s advance towards each other & retire, 1s also 2s turn 3s/4s
    with nearer hand to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7456, '2013-08-21 08:31:41.330514+00', '2023-02-04 01:22:37.893473+00', 8512, 3, NULL, 'ace', '1-8::
    All dance 1/4 Grand Chain, Ladies dance RH across 1/2 way & turn
    partners LH
9-16::
    1s & 3s (4th/ 2nd pl) set to ptnr, 3/4 turn RH into a line across &
    dance 1/2 RSh reel of 4 _while_ 2s & 4s stand 4 bars, set to ptnr &
    3/4 turn RH into line
17-24::
    2s & 4s dance 1/2 reel of 4, set to partner & 1/2 turn RH _while_ 1s
    & 3s set to partner & 1/2 turn RH & dance 1/2 reel of 4 across
25-32::
    2s & 4s dance 1/2 reel of 4 across, set to partner & 3/4 turn to pl
    _while_ 1s & 3s set to ptnr & 3/4 turn RH to pl & stand for 4 bars
    (all have moved 1 pl)', 0);
INSERT INTO 'dancecrib' VALUES (7457, '2013-08-21 08:31:41.33917+00', '2023-02-04 01:22:37.926287+00', 10684, 3, NULL, 'ace', '1-8::
    1s set & cross RH, cast 1 place & turn LH 3/4 times to face 1st
    corners
9-16::
    1s set & dance La Baratte with 1st corners:
::
    _11-12_   Men 1/2 turn facing Lady RH & retain hand but at arm''s
    length from each other
::
    _13-14_   Man retraces steps with Lady turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies original
    place) & releasing Ladies RH she turns under Mans left arm until
    almost in original places
::
    _15-16_ Couple change places LH
17-20::
    1s (now in 1st corner positions) dance LSh round 2nd corners into
    middle _while_ 1st corner persons turn RH & dance back to places
21-24::
    1s turn LH 1.3/4 times to face 2nd corners
25-32::
    1s set & dance La Baratte with 2nd corners:
33-36::
    1s (now in 2nd corner positions) dance LSh round 3rd corners to 2nd
    place own side _while_ 2nd corner persons turn RH & dance back to
    places
37-40::
    1s+4th corners dance DoSiDo', 0);
INSERT INTO 'dancecrib' VALUES (7458, '2013-08-21 08:31:41.347591+00', '2023-02-04 01:22:37.956522+00', 8940, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 on own sides round 2s+3s (dancing between 2s to
    start)
9-16::
    1L dancing down dances LH across with 2L+3L _while_ 1M dances RH
    across with 2M+3M, 3s followed by 1s+2s cross & cast to top.
    (3)(1)(2)
17-24::
    1s dance in & turning left about dance out & cast left round 2nd
    corner pstns _while_ that corner person sets twice _while_ 1st
    corner persons set & change places diagonally RH into lines across &
    turn partners RH
25-32::
    1s dance in (up/down) & turning left about dance out & cast left
    round 3rd corner pstns _while_ that corner person sets twice _while_
    2nd corner persons set & change places diagonally RH into lines
    across & turn partners RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7459, '2013-08-21 08:31:41.357578+00', '2023-02-04 01:22:37.988692+00', 13453, 3, NULL, 'ace', '1-8::
    All couples follow 1s leading down & cast up round 4th place to
    original places
9-16::
    1s+2s dance RH across twice as 3s+4s dance LH across twice
17-28::
    All dance Grand Chain
29-32::
    All Advance+Retire
33-40::
    1s weave down own sides to 4th place, dancing between 2s to start,
    behind 3s,  in front of 4s, curving into 4th place (2s+3s+4s step up
    39-40)', 0);
INSERT INTO 'dancecrib' VALUES (7460, '2013-08-21 08:31:41.52479+00', '2023-02-04 01:22:38.214325+00', 6282, 3, NULL, 'ace', '1-8::
    1s cross down to 2nd place _while_ 2s cast up, 2s+1s set, 1s cross
    down to 3rd place _while_ 3s cast up 1 place & 3s+1s set
9-16::
    1s cross down to 4th place _while_ 4s cast up 1 place, 4s+1s set, 1s
    dance up to top crossing to original places
17-24::
    1M+2L also 3L+4M change places RH, all set, all cross RH & set
25-40::
    All Men dance RH across 1/4 way, turn corner Lady LH, repeat with
    each corner until turning partner to end 1 2 3 4
41-48::
    All dance 4 couple Poussette (1s to bottom)', 0);
INSERT INTO 'dancecrib' VALUES (9044, '2015-11-30 09:00:20.340415+00', '2023-02-04 01:22:38.248204+00', 16823, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across, 1s +2s set, 2s cross RH to 1st place
    as1s dance in, turn right about to end BtoB facing opp sides
9-16::
    1M with 2L+3L, 1L with 2M+3M set (Double Triangles pstn), 1s drop RH
    & turn person on L (2nd corner) LH into 1/2 reels across (1M RSh to
    2M, 1L RSh to 3L). 1s finish BtoB, 1M facing up, 1L down,
17-24::
    1M with 2s, 1L with 3s set (Double Triangles pstn), 1s drop RH and
    turn person on L (same person) by LH into 1/2 reels of 3 on side (1M
    RSh to 3L, 1L RSh to 2M) End (3) 1 (2)
25-32::
    1s dance diag R&L (1M down, 1L up)', 0);
INSERT INTO 'dancecrib' VALUES (7461, '2013-08-21 08:31:41.541922+00', '2023-02-04 01:22:38.398058+00', 6285, 3, NULL, 'ace', '1-8::
    1s cross RH to 2nd place opposite sides, all set, 1s cross back to
    original places & all set
9-16::
    2s cross RH to 3rd place opposite sides, all set; 2s cross back to
    original places & all set
17-24::
    All Adv+Ret 1 step twice, Ladies circle 3H round on sides _while_
    Men also circle 3H round
25-32::
    1s+2s dance 1/2 Diamond Poussette; 1s+3s dance 1/2 Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7462, '2013-08-21 08:31:41.550396+00', '2023-02-04 01:22:38.411571+00', 10576, 3, NULL, 'ace', '1-8::
    2s+3s dance RH across& LH back (star) _while_ 1s+4s chase (trek)
    clockwise once round back to places
9-16::
    All Adv+Ret twice (boldly go)
17-24::
    1s+2s also 3s+4s circle 4H round and back (into orbit)
25-32::
    4s lead up to top place (beam up) _while_ 1s+2s+3s step down & all
    turn RH or swing partners.  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (7463, '2013-08-21 08:31:41.571019+00', '2023-02-04 01:22:38.430244+00', 11769, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, PdB in turn right about to face opposite
    sides & set as double triangles
9-16::
    1s dance out, cast round 1st corners into centre _while_ 2s+3s
    Adv+Ret diagonally, 1s PdB towards each other& turn right about to
    face up/down & set as double triangles
17-24::
    1s dance up/down, cast to right to 2nd place own sides _while_ 2s+3s
    Adv+Ret, 1s dance RH across (1L with 2s & 1M +3s) end facing 1st
    crnrs
25-32::
    1s dance ''Hello-Goodbye'' setting ending with petronella turn to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (7464, '2013-08-21 08:31:41.595093+00', '2023-02-04 01:22:38.444866+00', 6287, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across; 1s cast down 1 place _while_ 2s dance up to
    top, 1s set advancing, turning right about to end BtoB facing own
    sides ready for ...
9-16::
    2s+1s+3s dance Double Triangles, ending with Petronella turn to 1L
    between 2s & 1M between 3s facing 4th corners
17-24::
    2s+1s+3s dance RSh reels of 3 across, 1s end in 2nd place opposite
    sides  2 (1) 3
25-32::
    2s+1s+3s circle 6H round to left (6 bars) & 1s cross RH to 2nd place
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (15151, '2022-10-05 00:22:02.256915+00', '2023-02-04 01:22:38.458505+00', 21029, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place (2s step up bars 3-4). 1s dance down
    between 3s & cast up to 2nd place. 2 1 3
9-10::
    2s+1s+3s cross RH. (1M+2s facing down & 1L+3s facing up)
11-12::
    1s dance small clockwise circle in place (2 small travelling steps)
    _while_ 2s change places with 3s on the sides passing 1s RSh on the
    sides. All face clockwise
13-16::
    3s+1s+2s chase 1/2 way clockwise. 1s finish facing 1st corners.
17-22::
    2s+1s+3s dance »Corners Pass+Turn 1/4 round«:
::
    _17-18_ Centre dancers change places with corners _while_ corners
    dance in & turn 1.1/4 RH to face next corner position, corners not
    moving face diagonally in & set.
::
    _19-22_ repeat bars 17-18 twice
23-24::
    2s+3s chase clockwise 1/4 way round set _while_ 1s follow 1st corner
    persons. (3) 1 (2)
25-32::
    3s+1s+2s dance Diagonal R&L (Man down / Lady up).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12945, '2020-07-01 00:21:41.207529+00', '2023-02-04 01:22:46.828347+00', 6459, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s petronella turn to 1M between 2s
    facing down, 1L between 3s facing up & All set
9-16::
    All Adv+Ret up/down set; 1s pertonella turn to 2nd place own sides &
    All set
17-24::
    2s+1s+3s circle 6H round & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7465, '2013-08-21 08:31:41.610323+00', '2023-02-04 01:22:38.472493+00', 6289, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s dance Figs of 8 round next couples
9-16::
    1s & 4s turn partners RH, 1L also 4L followed by ptnrs dance down/up
    centre (pass RSh) to other end, cast to left round corner into
    centre
17-24::
    4s dance LH across with 2L _while_ 1s dance LH across with 3L, RH
    across with 2M/3M to end in lines across (4s/1s in centre, Men
    together)
25-32::
    All set twice & 4s/1s turn corners 1.1/4 times (Men RH & Ladies LH)
    to 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (13921, '2021-04-05 00:21:53.029001+00', '2023-02-04 01:22:38.483811+00', 14991, 3, NULL, 'ace', '1-8::
    1L followed by 1M dance alternating tandem reel of 3 on Ladies'' side
    (LSh to 2L to start)
9-16::
    1M followed by 1L dance alternating tandem reel of 3 on Men''s side
    (RSh to 2M to start)
17-24::
    1s dance down below 3s, cast up to 2nd place own side (2s step up
    19-20); 2s+1s+3s turn partner RH
25-32::
    2s+1s+3s circle 6H round to the left for 6 steps, pivot & chase back
    to places', 0);
INSERT INTO 'dancecrib' VALUES (7466, '2013-08-21 08:31:41.625953+00', '2023-02-04 01:22:38.502118+00', 13615, 3, NULL, 'ace', '1-8::
    1s & 3s lead down for 3 steps, lead up to places & cast down 1 place
9-16::
    2s+1s dance double Fig of 8 (1s cross up) _while_ 4s+3s+5s dance
    reflection reels on own sides (3s in & down to start)
17-24::
    2s+1s+4s dance reflection reels (1s in & down to start) _while_
    3s+5s dance double Fig of 8 (3s cross down)
25-32::
    1s & 3s cross RH & cast down 1 place, 1s & 3s dance 1/2 Fig of 8
    round couple above them', 0);
INSERT INTO 'dancecrib' VALUES (7467, '2013-08-21 08:31:41.640696+00', '2023-02-04 01:22:38.530321+00', 6299, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s dance reels of 3 across (1L with 2s & 1M with 3s) end facing in
    centre
9-16::
    1s set (Marquis of Huntley step) for 4 bars, 1.1/4 turn 2H to 2nd
    place own side
17-24::
    2s+1s+3s set HS & turn partners 2H

{{title}}
Reel

1-8::
    1s PdB-Coupe & 1/2 turn 2H, turn to right to end BtoB facing
    opposite sides
9-16::
    1s dance 1/2 reel of 4 with 1st corners, pass RSh & dance reel of 4
    with 2nd corners ending BtoB with 1M facing up
17-24::
    1s circle 3H round (1M with top couple 3s & 1L with 2s) opening out
    with 1M leading 3s down Ladies side _while_ 1L leads 2s up Men''s
    side & circle 6H round to left to end 2 1 3 & set', 0);
INSERT INTO 'dancecrib' VALUES (11744, '2019-03-26 02:06:04.791295+00', '2023-02-04 01:22:38.565316+00', 19223, 3, NULL, 'ace', '1-8::
    1s set and cast off two places (2s and 3s step up); 1s set and cast
    up one place to face 1st corner (3s step down)
9-16::
    1s dance 1/2 diag reel with 1st corners, pass RSh & dance 1/2 diag
    reel with 2nd corners
17-24::
    1s cross up & cast to 2nd place _while_ 3s+2s dance 1/2 R&L starting
    by changing places RH on sides; all turn partners RH
25-32::
    2s+1s+3s circle 6H round & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7468, '2013-08-21 08:31:41.83231+00', '2023-02-04 01:22:38.593336+00', 9937, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH, cast 1 place & turn 2H 1.1/4 times
9-16::
    1L+2s also 3M+5s dance reels of 3 across (RSh to own side) _while_
    1M+4s+3L dance RH across (1s & 3s acknowledge ptnrs) & LH back
17-24::
    1s & 3s 3/4 turn RH, cast 1 place on opposite sides & dance 1/2 Figs
    of 8 round couples above them.  2 4 1 5 3
25-32::
    All 1/2 turn RH, turn to right & dance out to opposite sides, all
    set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (8704, '2015-03-03 08:48:05.0155+00', '2023-02-04 01:22:38.60832+00', 16108, 3, NULL, 'ace', '1-4::
    1s dance down NHJ. 1s turn 3s (Ladies LH, Men RH) _while_ 2s 1/2
    turn LH moving up to 1st place opp sides
5-8::
    1s dance up, turn 2s to finish in 2nd place (Ladies RH, Men LH)
    _while_ 3s 1/2 turn LH to opp sides
9-16::
    1s dance 1/2 diag R&L, 1L up to start, 1M down. Repeat.
17-20::
    All 1/2 turn RH and twirl, dance out to sidelines
21-24::
    All advance for 2 steps and retire for two steps
25-32::
    _3_ Couple Bourrel:
::
    _25-28_     1M+3L, 2M+1L set advancing, turn 2H, pull RSh back to
    end back to back, Ladies face down, Men up _while_ 3M dances across
    top and down behind Mens'' side to face up to 1L, 2nd L dances across
    bottom and up behind Ladies'' side to face 1M.
::
    _29-32_     All set to person facing, turn 3/4 2H to finish opp
    sides, Men 123, Ladies 231.
33-36::
    All 1/2 turn opp person LH. 1M changes places with 2M RH and 3M LH
    (1 step/change)
37-40::
    1s (in 3rd place) turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (7469, '2013-08-21 08:31:41.840938+00', '2023-02-04 01:22:38.617896+00', 12242, 3, NULL, 'ace', '1-8::
    1L+2M with arms folded set twice & DoSiDo
9-16::
    1M+2L repeat
17-24::
    1s+2s (arms folded) set twice & dance RH across 1/2 way & cross RH
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7470, '2013-08-21 08:31:41.849207+00', '2023-02-04 01:22:38.627673+00', 7521, 3, NULL, 'ace', '1-8::
    1s+4s advance for 2 steps diagonally & retire, advance towards
    partners & cast 1 place
9-16::
    2s & 3s repeat all ending in original places
17-24::
    1s cross RH, cast 1 place, cross LH & cast to bottom
25-32::
    All turn partners RH & LH', 0);
INSERT INTO 'dancecrib' VALUES (7472, '2013-08-21 08:31:41.865968+00', '2023-02-04 01:22:39.841568+00', 6311, 3, NULL, 'ace', '1-8::
    1s+4s set; cast 1 place & dance RH across
9-16::
    2s+1s & 4s+3s dance LH across; 1s+4s cast to ends & all set
17-24::
    All dance Grand Chain
25-32::
    1s dance down under 2s made by arch; 3s dance up under 1s arch; 1s
    dance down under 4s arch & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (9045, '2015-11-30 09:00:20.512255+00', '2023-02-04 01:22:39.863226+00', 12006, 3, NULL, 'ace', '{{explanation}}
Circle for up to 8 couples, Men on inside, Ladies outside, all facing partners

1-8::
    All clap 2 bars (1-2-3-4), all clap partner''s hand (2 bars), all
    turn on spot (2 bars), all clap partner''s hand (2 bars)
9-16::
    All stamp foot 2 bars (1-2-3-4), Men dance RSh round partner (4
    bars), all stamp foot (2 bars)
17-24::
    Repeat bars 9-16, Ladies dancing RSh round partners.  End with NHJ
    with partner facing anticlockwise
25-32::
    1s make arch & other couples dance under and round circle to places', 0);
INSERT INTO 'dancecrib' VALUES (5677, '2013-08-21 08:31:11.375337+00', '2023-02-04 01:22:47.487332+00', 6477, 3, NULL, 'ace', '1-8::
    1s+2s cross RH & cross back RH
9-16::
    1s+2s dance RH across & LH across back to places
17-24::
    1s lead down the middle & back to top
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (14440, '2021-11-06 01:13:19.775091+00', '2023-02-04 01:22:39.877642+00', 6310, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s dance down the middle & back to finish between 2s (2s step up on
    bars 11-12, 1M facing 2L & 1L facing 2M)
17-24::
    1s+2s dance reel of 4 (2s dance a complete reel. 1s dance 3/4 reel
    in 6 bars, on last 2 bars 1M/1L dance diagonally up/down to face
    each other in the middle)
25-28::
    1s+2s set to partners with Highland Schottische step
29-32::
    1s turn RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7473, '2013-08-21 08:31:41.87446+00', '2023-02-04 01:22:39.891714+00', 9894, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    All set, 1s & 4s turn RH 1/2 way _while_ 2s+3s cross RH, 1s & 4s
    lead into centre & dance RH across 1/2 way _while_ 2s+3s cross back
    RH
9-16::
    4s & 1s lead out of ends, cross & cast back to centre to face 1st
    crnr pstns (M face M in diag line), all turn LH to end 4 2 3 1
    (3s+1s on opp sides)
17-24::
    1s dance reel of 3 with 3M (3M+1M give LSh & 1L dances up to give
    RSh to partner) as 4s dance similarly with 2M all loop round to end
    4 2 1 3
25-32::
    1s dance similar reel of 3 with 3L as 4s dance with 2L all loop
    round to end 2 4 1 3
33-40::
    All Adv+Ret & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (15430, '2023-02-04 01:22:39.919622+00', '2023-02-04 01:22:39.921339+00', 19640, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Poussette 1 2 3 4
9-12::
    1s+3s turn partner 3/4 RH & face own side. 1s+3s cast right round 1
    person ( Men up/ Ladies down, 2L & 4L step up bars 11-12) End: Men''s
    side: 1 2 3 4, Ladies'' side: 2 1 4 3
13-16::
    1s+2s also 3s+4s Set+Link. 1s+3s face out End: Men''s side: 2 1 4 3,
    Ladies'' side 1 2 3 4
17-24::
    All dance reels of 4 on the sides, to begin middle dancers pass LSh
    to start
25-28::
    1L+3L dance RSh down round 2L & 4L _while_ 1M+3M dance RSh up round
    2M & 4M. 1s & 3s turn partners 2H 3/4 to finish in the middle facing
    down NHJ (2L & 4L step up 25-26)
29-32::
    1s dance down to 4th place _while_ 3s cast up to 2nd place 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13922, '2021-04-05 00:21:54.492003+00', '2023-02-04 01:22:39.943361+00', 19501, 3, NULL, 'ace', '1-8::
    1s set advancing, dance down (2s step up); 1s cast up round 3s to
    2nd place & advance (PdB) to centre to join LH with partner & RH
    with 1st corner
9-12::
    Bal-in-Line, 1s drop RH & move clockwise to 2nd corner & repeat
13-16::
    1s pull back RSh & dance round each other 1.1/4 times to end 1L
    facing 1st corner & 1M following _while_ 2s+3s dance 1/2 R&L
17-24::
    1s dance 1/2 RSh Alternating Tandem reel of 3 with 1st corners; 1s
    (Man now leading) dance RH across with 2L (Ladies'' 2nd corner pstn)
25-32::
    1s (Man leading) dance 1/2 LSh Alternating Tandem reel of 3 with 2nd
    corners; 1s (Lady now leading) dance LH across with 3L (Ladies'' 1st
    corner pstn).  1s end in centre BtoB facing own 1st corners
33-40::
    1s dance ''Hello-Goodbye'' setting with 1st & 2nd corners to end 1M
    between 2s at top, 1L between 3s at bottom, 1s turn 3/4 RH to 2nd
    place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8073, '2013-10-01 08:47:28.925092+00', '2023-02-04 01:22:51.841555+00', 9190, 3, NULL, 'ace', '1-8::
    1s & 2s set & turn 2H, 1s+2s circle left
9-16::
    1s set & cast 1 place, 2s+1s+3s Advance & Retire & 1s end facing 1st
    corner
17-24::
    1s dance "Hello-Goodbye" setting ending in 2nd place own sides
25-32::
    1s+3s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7474, '2013-08-21 08:31:41.8829+00', '2023-02-04 01:22:39.967546+00', 6317, 3, NULL, 'ace', '1-8::
    1M+2L set & change places RH, 1M+2s dance RH across
9-16::
    1L+2M set & change places LH, 1s+2M dance LH across
17-24::
    2s followed by 1s lead down, 1s followed by 2s lead up to top & 1s
    cast to 2nd place
25-32::
    2s+1s dance 1/2 double Fig of 8 (1s cross up), 2M+1M turn LH _while_
    2L+1L turn RH', 0);
INSERT INTO 'dancecrib' VALUES (7475, '2013-08-21 08:31:41.891349+00', '2023-02-04 01:22:39.993245+00', 6318, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s pass RSh into double triangle
    position & set
9-16::
    1s set dancing round each other & set on other side, 1s cast RSh
    round 1st corners into lines across (L between 2s, M between 3s)
17-24::
    1s pass RSh into double triangle position (up/down) & set, 1s set
    dancing round each other & set at other end
25-32::
    1s cast LSh round 1st corners into lines on opposite sides, 1s cross
    RH & cast to bottom', 0);
INSERT INTO 'dancecrib' VALUES (7476, '2013-08-21 08:31:41.899723+00', '2023-02-04 01:22:40.054205+00', 6319, 3, NULL, 'ace', '1-8::
    1s+3s 1/2 turn RH into 2nd/4th places facing up as 2s+4s step up &
    face down & all set, 2s+1s & 4s+3s circle 4H round but 1s+4s break
    for:
9-16::
    All circle 8H round for 2 bars & Men turn Lady on Right, all
    continue 8H round to places
17-24::
    1s+4s (middle cpls) dance reel of 4 up/down middle (Ladies dancing
    into middle facing down/up &  Men pass each other LSh to start)
25-32::
    1s & 3s change places by chasing round clockwise (1M & 3L casting),
    all set & turn LH into prom hold
33-40::
    All Promenade', 0);
INSERT INTO 'dancecrib' VALUES (8791, '2015-06-15 11:41:15.416638+00', '2023-02-04 01:22:48.194059+00', 15418, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up). 1s dance 1/2 Fig 8 round 3s
9-16::
    1s dance mirror (reflection) reels of 3 on own sides with 2s+3s (1s
    in/up to start)
17-24::
    1s dance mirror (reflection) reels of 3 on opp sides with 3s+4s (1s
    cross down through 3rd place, 3s out/up, 4s in/up to start) End  2
    (1) 3 4
25-32::
    1s cross RH, cast 2 places (3s+4s step up 27-28) All 4 couples turn
    RH (or birl)', 0);
INSERT INTO 'dancecrib' VALUES (10841, '2018-06-11 00:37:08.810161+00', '2023-02-04 01:22:40.084596+00', 9476, 3, NULL, 'ace', '1-8::
    1s cross RH & cast, 1s dance 1/2 Fig of 8 (1M up round 2s, 1L down
    round 3s)
9-12::
    1s turn LH to face 2nd Corners _while_ 2nd Corners set, 1s dance to
    2nd corner position (pass 2nd corner RSh) _while_ 2nd corners dance
    in;
13-16::
    1s set facing each other _while_ 2nd Corners turn LH, 2nd Corners
    dance back to place (pass 1s RSh) _while_ 1s dance in to middle (1M
    above 1L)
17-24::
    1s+1st corners repeat 9-16, ending with 1s dancing in, passing LSh
    curving round into 2nd place opp side facing out
25-32::
    1s dance LSh reel of 3 on opp sides (1L+3M, 1M+2L pass LSh to
    begin). 1L crosses down from 1M place to 2nd place own side, _while_
    1M crosses up from 3L place to 2nd place own side.', 0);
INSERT INTO 'dancecrib' VALUES (12427, '2019-12-05 01:32:08.409179+00', '2023-02-04 01:22:40.100874+00', 18531, 3, NULL, 'ace', '1-8::
    1s cast 2 places (2s step up 1-2) & cross up RH to 2nd place opp
    sides;  2s+1s+3s set & 1s cross LH to own side
9-16::
    1L+2s & 1M+3s dance RH across, 1s pass RSh to dance LH across with
    other couple
17-24::
    1s dance Fig 8 (1L round 2s & 1M round 3s) _while_ 2s+3s set, cross
    RH with partner, set & cross back RH
25-28::
    1s+3s circle 4H round to left, finishing joining 2H with partner on
    diagonal (1L+3M BtoB) ready for …
29-32::
    1s+3s dance 1/2 poussette.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7477, '2013-08-21 08:31:41.907952+00', '2023-02-04 01:22:40.115843+00', 9384, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set & dance 1/2 RH across, 1s+4s set & dance 1/2 LH
    across
9-16::
    All dance reels of 4 on sides & end with 2s facing 4s & 1s facing 3s
17-24::
    All set to facing person, 1/2 turn (2s & 3s dancing in between
    4s/1s), 4s & 1s end in prom hold & dance 1/2 RSh reels of 3 across
    (4s with 2s & 1s with 3s) ending with 2s at top & 3s in 4th place
25-32::
    4s & 1s set advancing (down/up) & petronella turn to sides, all turn
    partners RH.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14226, '2021-08-14 00:22:02.130954+00', '2023-02-04 01:22:40.138975+00', 12395, 3, NULL, 'ace', '1-8::
    1s cast down behind own lines & cast back to place
9-10::
    1s+2s dance 1/2 RH across _while_ 3s cross RH.
11-12::
    1s+3s dance 1/2 LH across _while_ 2s cross LH
13-16::
    1s lead up to top & cast into 2nd place own side. 3s step down
17-24::
    2s+1s dance Allemande
25-32::
    1s turn RH & cast to 2nd place; 1s+3s dance 4H across', 0);
INSERT INTO 'dancecrib' VALUES (7478, '2013-08-21 08:31:41.917901+00', '2023-02-04 01:22:40.245287+00', 6323, 3, NULL, 'ace', '1-8::
    1s lead down to 3rd place crossing RH & cast up 1 place, 2s+1s+3s
    turn 2H ending on own sides
9-16::
    1s cast up & lead down to 2nd place & turn 2H to face 1st corners
17-24::
    1s turn 1st corners RH, turn partner LH, turn 2nd corners RH, turn
    partner LH to face 1st corners
25-32::
    1s set to 1st corners, set to 2nd corners, 2s+1s+3s turn 2H to own
    sides (1s turn 1.1/2 times)', 0);
INSERT INTO 'dancecrib' VALUES (13353, '2020-11-02 01:22:04.700608+00', '2023-02-04 01:22:48.393812+00', 18354, 3, NULL, 'ace', '1-8::
    1s set, dance in & cast to 2nd place (2s step up 5-6), 1s turn RH
    into prom hold facing 2M
9-16::
    1s dance reel of 3 on sides with 2M & 3M (RSh to 2M to start). 1s
    end facing 2L
17-24::
    1s dance reel of 3 on sides with 2L & 3L (LSh to 2L to start). 1s
    end between 3s facing up
25-32::
    1s dance up, cast to 2nd place own side; 1s+3s turn 1.1/2 to change
    places (Men RH, Ladies LH).  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7479, '2013-08-21 08:31:41.926394+00', '2023-02-04 01:22:40.266164+00', 6327, 3, NULL, 'ace', '1-8::
    All set, 1/2 turn partners 2H, all pull back RSh & dance out to
    place on opp side, all set
9-16::
    1M+2L also 3M+4L change places RH, change places with partners 2H on
    sides; 1s+2s & 3s+4s dance RH across once round
17-24::
    All dance 1/2 RSh reels of 4 on sides passing partner RSh to start,
    1L+2M also 3L+4M change places RH & all set to partners. 4 3 2 1
25-28::
    4s+3s also 2s+1s dance 1/2 double Fig of 8 (3s cross up, 2s cross
    down & 1s & 4s casting to start)
29-32::
    1s & 4s cross RH as 2s+3s dance RH across 1/2 way, all change places
    RH on sides (1s+3s & 2s+4s) to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7667, '2013-08-21 08:31:46.392863+00', '2023-02-04 01:22:55.299457+00', 10887, 3, NULL, 'ace', '1-8::
    1M+2L 1/2 turn & twirl to change places, 1L+2M 1/2 turn & twirl to
    change places
9-16::
    2s+1s dance RH across, turn partners 2H 1.1/2 times to 2s facing
    down & 1s up
17-24::
    2s+1s circle 4H round & back
25-32::
    1s dance Fig of 8 round 2s', 0);
INSERT INTO 'dancecrib' VALUES (7580, '2013-08-21 08:31:44.973633+00', '2023-02-04 01:22:48.478396+00', 9896, 3, NULL, 'ace', '1-8::
    All set, 1/2 turn RH & chase clockwise 1/2 way
9-16::
    Repeat 1/2 turning LH & chasing anticlockwise 1/2 way
17-24::
    1s slip step down, slip step back up & cast to 4th place
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7480, '2013-08-21 08:31:41.934739+00', '2023-02-04 01:22:40.287221+00', 6328, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 Fig of 8 round 2s  2 1 3 4
9-16::
    1s reflection reel of 3 with 3s+4s (1s in & down to start)
17-24::
    1s cross RH & cast down 1 place; 1s dance 1/2 Fig of 8 round 4s  2 3
    1 4
25-32::
    1s dance reflection reels with 2s+3s (1s in & up to start)
33-40::
    1s cross RH & cast down 1 place, 1s turn RH 1.1/2 times  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7481, '2013-08-21 08:31:41.941895+00', '2023-02-04 01:22:40.303574+00', 8941, 3, NULL, 'ace', '1‑8::
    1s+2s set & dance RH across, 1s cast 1 place _while_ 2s lead up
9‑16::
    2s+1s+3s dance reels of 3 on opposite sides (1s crossing RH to 3rd
    pl to start)
17‑24::
    1s cross down LH, cast up round 3s & turn LH to face 1st corners
25‑32::
    1s dance 1/2 diag reel of 4 with 1st corners, pass LSh to dance 1/2
    reel of 4 with 2nd crnrs & end passing LSh to 2nd place own sides
33‑40::
    1s dance out & round person on right, meet in centre & turn LH 1.1/4
    times _while_ 3s+2s dance 1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (11217, '2018-09-30 22:20:37.876882+00', '2023-02-04 01:22:48.505287+00', 18589, 3, NULL, 'ace', '1-8::
    All circle 6H round & back
9-16::
    1s set NHJ, dance down between 2s & 3s, separate and cast (1M round
    2s, 1L round 3s) back to original places.  All face partners
17-24::
    All dance interlocking RSh reels of 4 ending facing partner
25-32::
    _25-28_   All set, Ladies pull back RSh on 2nd setting step to face
    anticlockwise round & all chase anticlockwise 1 place, Ladies pull
    back RSh to face partner
::
    _29-32_   All turn partner RH to end facing in', 0);
INSERT INTO 'dancecrib' VALUES (15357, '2022-12-19 01:22:10.390736+00', '2023-02-04 01:22:40.332189+00', 20774, 3, NULL, 'ace', '1-6::
    1L+2L+3L with hands joined,set advancing towards partner, drop
    hands, face up, 1L followed by 2L&3L casts down own side to 3rd
    place
7-8::
    2L+3L 1/2 turn RH to face across. (Ladies in order 2 3 1 4, Men in
    original places)
9-16::
    Top 3 couples dance modified Bourrel:
::
    _9-12_  1M+Lady in 2nd place also 2M+Lady in 3rd place set advcg &
    3/4 turn 2H to line up/down middle then 1/2 turn single to face own
    prtnrs as 2L (at top) & 3M chase anticl''wise to face partners
::
    _13-16_  All set & Petronella turn to own side
17-24::
    1s+2s dance Espagnole
25-28::
    1L+4L & 3M+2M set advancing, Ladies face down, Men face up, 4L cast
    up to 3rd place followed by 1L into 4th place _while_ 3M casts to
    2nd place follwed by 2M into 1st place
29-32::
    1M+4M & 3L+2L repeat 25-28.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7482, '2013-08-21 08:31:41.952598+00', '2023-02-04 01:22:40.356382+00', 6334, 3, NULL, 'ace', '1-8::
    1s & 3s petronella turn into centre & set, turn partner RH to end
    facing partner (Men face up)
9-16::
    1s+3s dance reel of 4 up/down dance with 3s ending in own places &
    1s remaining in middle
17-24::
    1s 3/4 turn RH & cast 1 place opposite sides, turn LH to face 1st
    corners
25-32::
    1s dance reels of 3 across dance giving LSh to 1st corners to start', 0);
INSERT INTO 'dancecrib' VALUES (7483, '2013-08-21 08:31:41.961225+00', '2023-02-04 01:22:40.389418+00', 6336, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-16::
    1s turn RH & cast 1 place, 1s cross & cast (Man down & Lady up) to
    end facing 1st corners
17-24::
    1s set to 1st corners, set to 2nd corners, 1s spiral round each
    other 1.1/2 times to face 4th corner (1L between 2s & 1M between 3s)
25-32::
    1s dance reels of 3 across giving RSh to 4th corner, 1s cross back
    to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7484, '2013-08-21 08:31:41.969589+00', '2023-02-04 01:22:40.415179+00', 10097, 3, NULL, 'ace', '1-8::
    Top 3 Men set diagonally to bottom 3 Ladies & change places RH, all
    dance 1/2 reels of 4 on sides
9-16::
    Top 3 on Ladies side set diagonally to bottom 3 on Mens side &
    change places RH, all dance 1/2 reels of 4 on sides.  1 2 3 4
17-24::
    1s turn 2s also 3s turn 4s 1.1/2 times RH on sides, 1s turn 4s 1.1/2
    times LH on sides.  2 4 1 3
25-32::
    4s & 3s dance Figs of 8 round couple above', 0);
INSERT INTO 'dancecrib' VALUES (7485, '2013-08-21 08:31:41.977932+00', '2023-02-04 01:22:40.451197+00', 6341, 3, NULL, 'ace', '1-8::
    1s Slip Step down & back
9-16::
    2s Slip Step down & back
17-24::
    1s followed by 2s+3s+4s cast to bottom & 1s make an arch, 2s+3s+4s
    dance under arch & up to new places
25-32::
    All turn RH, all turn LH', 0);
INSERT INTO 'dancecrib' VALUES (7486, '2013-08-21 08:31:41.987062+00', '2023-02-04 01:22:40.474938+00', 13437, 3, NULL, 'ace', '1-8::
    1s & 4s set, dance in & cast 1 place, dance RH across 1/2 way (1s+4s
    remain in middle).  2(4)(1)3
9-12::
    1s & 4s join hands with corners facing clockwise to form St Andrews
    Cross & wheel 1/2 way 2s/3s end on sides 1s/4s in middle facing
    corners
13-16::
    All set & change places with corners RH
17-24::
    All set & change places with corners LH & reform St Andrews Cross,
    all wheel 1/2 way (2s/3s end on sides)
25-32::
    4s & 1s lead out ends crossing & cast in 1 place, all turn partners
    RH to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7487, '2013-08-21 08:31:41.995514+00', '2023-02-04 01:22:40.495926+00', 6348, 3, NULL, 'ace', '1-8::
    1s cross down dancing out between 2s/3s to dance RH/LH across on
    sides 1.1/3 times (Man RH with 2L+3L & Lady LH with 2M+3M) to end 1s
    side by side in 3rd place, 2s outside between 2nd & 3rd place & 3s
    in 2nd place
9-16::
    1s dance reflection reels of 3 on sides (1s dance up & 2s down to
    start) to end 3 2 1
17-24::
    1s followed by 2s lead up to top & cast to 2nd place turning to face
    own side (for Double Triangles) as 2s end at top & 3s in 3rd place
25-32::
    1s dance Double Triangles & end facing 2nd corners
33-40::
    1s dance reels of 3 across giving RSh to 2nd corners & end in 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (7488, '2013-08-21 08:31:42.003785+00', '2023-02-04 01:22:40.517851+00', 6349, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & circle 6H round 1/2 way, set & continue to circle 6H
    round back to place
9-16::
    1s Lead down below 2s, cross & cast down round 3s, lead up between
    to top & cast 1 place (on opposite sides) to face 1st corners
17-24::
    Turn 1st corner RH, partner LH, 2nd corner RH & partner LH to end in
    2nd place opposite sides
25-32::
    2s+1s+3s Adv+Ret for 2 steps & 1s turn 2H 1.1/2 times to own sides', 0);
INSERT INTO 'dancecrib' VALUES (7489, '2013-08-21 08:31:42.012531+00', '2023-02-04 01:22:40.545511+00', 11532, 3, NULL, 'ace', '{{explanation}}
Circular sets of 4+ couples

1-8::
    All circle 8H round & back
9-20::
    Ladies dance Fig of 8 round partner (in front to start) & in front
    of next Man, round & back to place, Men repeat
21-24::
    All pass partner RH, pass next person LH & turn 3rd person RH into
    prom hold
25-32::
    All Promenade anywhere to form new set', 0);
INSERT INTO 'dancecrib' VALUES (7490, '2013-08-21 08:31:42.021143+00', '2023-02-04 01:22:40.575369+00', 11371, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across & all chase clockwise 1/2 way to
    opposite sides.  (4)(3)(2)(1)
9-16::
    4s+3s also 2s+1s dance reels of 4 across (4L+3M & 2L+1M passing LSh)
    all ending on sides
17-24::
    4s+3s also 2s+1s dance RH across & all chase clockwise 1/2 way to
    original places
25-32::
    1s+2s also 3s+4s Set+Link, 1s+4s  (centre couples) Set+Link
33-40::
    2s+4s+1s+3s circle 8H round & back. 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13923, '2021-04-05 00:21:55.192522+00', '2023-02-04 01:22:40.683479+00', 9018, 3, NULL, 'ace', '1-8::
    1s+2s dance the Knot ending with 1s turning LH  to face 2L (1L on
    1M''s right NHJ)
9-16::
    1s set to 2s, turn inwards, set to 3M, set to 3L, turn inwards & set
    to 2M.  End in 2nd place in centre facing up NHJ
17-24::
    2s+1s+3s dance mirror reels of 3 on sides giving hands(1s up between
    2s, 3s out/up to start).  2s+3s loop into place at end
25-32::
    2s+1s+3s circle 6H 1/2 round to left, pull back LSh & chase
    anticlockwise back to own side.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12942, '2020-07-01 00:21:36.581847+00', '2023-02-04 01:22:40.719398+00', 17607, 3, NULL, 'ace', '1-4::
    1s+2s+3s set, 1s cross RH _while_ 2s+3s dance 1/2 RH across
5-8::
    1s+3s+2s set, 1s lead down to 3rd place in centre _while_ 3s & 2s
    dance up & curve round to follow 1s
9-16::
    3s+2s+1s allemande down (6 bars), drop RH & cross LH to original
    places, 1s facing out
17-24::
    1s cast (2s step up), 2s+1s+3s set; 3 couples turn partner 2H
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12748, '2020-04-11 10:53:10.721926+00', '2023-02-04 01:22:40.746007+00', 14981, 3, NULL, 'ace', '1-8::
    1s set, 1/2 turn 2H to finish facing up NHJ; 1s cast (2s step up) &
    turn RH once round into Allemande hold facing down
9-16::
    1s dance down, turning to face up at end bar 12 (as in Gay Gordons);
    1s dance up to 2nd place middle of set, releasing hands at end bar
    16
17-24::
    2s+1s+3s dance mirror reels of 3 on sidelines giving hands where
    possible (1s dance out and up to start). 1s end facing 1st corners
25-32::
    1s+1st corners dance Corner Pass+Turn, 1s pass RSh; 1s+2nd corners
    dance Corner Pass+Turn, 1s pass RSh to 2nd place own side
33-36::
    1s+3s set, 1L casts off 1 place, & 3M casts up 1 place _while_ 1M
    and 3L pass each other RSh and curve out to finish 1M in 3rd place
    and 3L in 2nd place (order now 2 3 1)
37-40::
    3s+1s dance RH across once round. 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (15358, '2022-12-19 01:22:10.799736+00', '2023-02-04 01:22:40.770801+00', 21174, 3, NULL, 'ace', '1-8::
    1s dance in & cast (2s step up 3-4); 1s turn RH. 2 1 3
9-16::
    2s+1s+3s Set & Rotate for 3 couples
::
    _9-12_    2s+1s+3s Set & Rotate singly & chase clockwise to form
    lines of 3 across (Men face down & Ladies face up).
::
    _13-16_ All change places RH with partner & chase clockwise to own
    sides to end 3 1 2,
17-20::
    All cross RH, 3s+2s set facing diagonally opp dancer, _while_ 1M
    casts right to finish btwn 2s facing up, 1L casts right to finish
    btwn 3s facing down.
21-24::
    All cross RH with opp person, 2s+3s set facing diagonally opp dancer
    _while_ 1s cast to right to (2) (1) (3).
25-32::
    1s dance in & cast; (3s step up 27-28); all turn partner RH 1.1/2 to
    end 2 3 1.', 0);
INSERT INTO 'dancecrib' VALUES (11471, '2019-01-01 01:57:56.71119+00', '2023-02-04 01:22:40.815537+00', 6354, 3, NULL, 'ace', '1-8::
    1s+2s set & dance 1/2 RH across, 1s+3s set & dance 1/2 LH across
9-16::
    3s+1s face each other (up down) & set advancing to change places, 1s
    set & turn 1.1/4 times to end 1M between 2s (at top) & 1L between 3s
17-24::
    1M+2s Adv+Ret (down up) & set, _while_ 1L+3s set & Adv+Ret (up
    down), 2s+3s change places RH on sides as 1s turn RH to face 2nd
    corner (pstn)
25-32::
    1s dance 1/2 diag reel of 4 with corners, pass LSh & dance 1/2 diag
    reel of 4 with 1st corners & end 1L facing up to 2s & 1M faces 3s
33-40::
    1s dance RH across (L+2s, M+3s), pass LSh & dance LH across with
    other couple ending 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7493, '2013-08-21 08:31:42.046763+00', '2023-02-04 01:22:40.83458+00', 11692, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 on own sides dancing between 2s to start
9-16::
    1s dance down the middle & back 1s ending between 2s (Man facing
    Lady)
17-24::
    1s+2s dance reel of 4 across with 1s ending on own sides between 2s
25-32::
    2s+3s step up as 1s cast to 3rd place & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (14379, '2021-10-11 22:42:05.38216+00', '2023-02-04 01:22:40.856566+00', 18121, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up bars 3-4); 1s turn RH to face out in 2nd
    place own side
9-16::
    1s dance 1/2 reel of 3 on the sides giving RSh to person on their
    right to start. On bar 4, 1s turn LH to dance 1/2 reels of 3 on
    opposite sides (1L LSh to 2M, 1M LSh to 3L) to finish back to back
    facing 1st corners
17-24::
    1s turn 1st corners RH. On bar 20 1s pass RSh to face 3rd corner
    (corners dance for 4 bars). 1s turn 3rd corner LH to face 2nd
    corners
25-32::
    1s turn 2nd corners LH. On bar 28 1s pass LSh to face 4th corners.
    1s turn 4th corners RH to finish in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7494, '2013-08-21 08:31:42.055128+00', '2023-02-04 01:22:40.874732+00', 11533, 3, NULL, 'ace', '1-8::
    1s & 4s dance down/up into centre, about turn & dance back looping
    round to original places, 1s+2s also 3s+4s turn 1.1/2 times on sides
    (Ladies LH & Men RH) to 2 1 4 3
9-16::
    1s+4s dance RH across & LH back
17-24::
    2s+1s also 4s+3s circle 4H round & back
25-32::
    1s & 4s dance out ends looping into original places as 2s & 3s step
    down/up & 1s+2s turn 1.1/2 times on sides (Ladies RH & Men LH), 1s
    dance between 3s giving nearer hand to change places & turn 4s 1.1/2
    times (Ladies RH & Men LH) to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9414, '2016-10-06 07:18:57.941517+00', '2023-02-04 01:22:40.89798+00', 17238, 3, NULL, 'ace', '1-8::
    1s+4s dance in, join nearer hands, dance up/down, cast into centre
    (2s+3s step up/down 3-4).  1s+4s set facing diagonally in, 3/4 turn
    partners into line in middle
9-12::
    1s+4s set advancing (pass partner LSh), 1L+4M turn RH _while_
    partners dance to ends of set, pull back RSh to face partners
13-16::
    1s+4s set advancing (pass partner LSh), 1M+4L turn RH to finish 1M
    in 3L place, 4L in 2M place _while_ partners dance up/down out of
    ends, cast to Right to finish opposite partners  2 1 4 3
17-24::
    1s+4s dance 1/2 diag. reel of 4 (1L+4M pass LSh, pass partner RSh),
    finish facing partner, turn partners 2H to sidelines   2 4 1 3
25-32::
    All circle 8 hands round and back', 0);
INSERT INTO 'dancecrib' VALUES (10454, '2018-02-24 07:53:21.464359+00', '2023-02-04 01:22:40.933629+00', 17131, 3, NULL, 'ace', '1-8::
    1s turn 2H, dance down & out through 2nd place, behind 3rd place &
    turn 2H to face up
::
    _while_ 2s stand for 2 bars, cast up, set & turn 2H to face down
::
    _while_ 3s stand for 4 bars, dance up middle 1 place, 3/4 turn 2H,
    pull back RSh to end 3L facing up, 3M facing down
9-12::
    2s+3L & 3M+1s circle 3H round to Left, 3s finishing LSh to LSh
    facing opposite sides
13-16::
    "Snake Pass" figure:
::
    3L followed by 2s also 3M followed by 1s pass LSh diagonally across
    through 2nd place to change ends & loop round to left to end 1 3 2
17-24::
    All dance LSh reels of 3 on sides (3L faces up, 3M faces down), 3s
    finishing in 2nd place, pulling back RSh to face in
25-32::
    1s+3s dance Espagnole  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (10101, '2017-09-03 23:45:28.132143+00', '2023-02-04 01:22:41.118102+00', 8743, 3, NULL, 'ace', '1-8::
    1s lead down for 4 bars (2s step up 3-4), 1s lead up for 2 bars,
    turn RH to face 2M in prom hold
9-16::
    1s dance reel of 3 on the side with 2M & 3M (giving RSh to 2M) to
    finish facing 2L
17-24::
    1s dance reel of 3 on the side with 2L & 3L (giving LSh to 2L) to
    finish facing up in the middle of the set with LH joined, 2s & 3s
    face each other up & down the set
25-32::
    1s lead up, cross & cast one place, giving LH lead down, cross &
    cast up to 2nd place own side _while_ 2s & 3s dance R&L starting by
    changing places RH on the sides.', 0);
INSERT INTO 'dancecrib' VALUES (12943, '2020-07-01 00:21:36.897744+00', '2023-02-04 01:22:41.177068+00', 17608, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig 8 (1s cross down, 2s dance up to start)
9-16::
    1s followed by 2s lead down, 2s followed by 1s lead up, finishing 2
    1 on sides with 1s facing out
17-24::
    1s+3s dance double Fig 8 (1s cast, 3s cross up to start)
25-32::
    1s+3s dance Espagnole.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (5047, '2013-08-21 08:30:59.362757+00', '2023-02-04 01:22:41.303651+00', 6359, 3, NULL, 'ace', '1-8::
    1s turn RH 2.1/2 times (4 bars), 1L turns 2M LH then turns partner
    RH
9-16::
    1L turns 3M LH, turns partner RH, 1L turns 4M LH & turns partner RH
17-24::
    1M turns 4L LH, turns partner RH, 1M turns 3L LH & turns partner RH
25-32::
    1M turns 2L LH, turns partner RH, 1L turns 2M LH as 1M turns 2L LH,
    1s turn RH in centre
33-40::
    1s similarly turn 3s LH, turn partners RH, turn 4s LH & turn
    partners RH to 4th place own sides (last turn uses the next first 2
    bars of music)', 0);
INSERT INTO 'dancecrib' VALUES (7496, '2013-08-21 08:31:42.083322+00', '2023-02-04 01:22:41.331958+00', 12903, 3, NULL, 'ace', '1-8::
    1M+2L change places RH, 1L+2M change places LH, 1s+3s dance 1/2 R&L
9-16::
    1s+3s set & dance 1/2 RH across, 1s+2s set & dance 1/2 L across
17-24::
    1s+2s+3s dance reels of 3 on own sides (1s give LSh to 2s to start)
25-32::
    1s+2s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)', 0);
INSERT INTO 'dancecrib' VALUES (7497, '2013-08-21 08:31:42.121316+00', '2023-02-04 01:22:41.39139+00', 10577, 3, NULL, 'ace', '1-4::
    All set, all advance setting turning to BtoB with partner in middle
    (Ladies face up)
5-8::
    All loop to right to own sides - 1L & 3M to 2nd pl BtoB, 2L to 1st
    pl, 2M to 3rd pl & 1M also 3L to own places - all set
9-16::
    All set twice in double triangle position ending with 3M facing up &
    1L down, all set twice (up/dn) in double triangles
17-24::
    3M turns 1M LH into 2nd pl _while_ 1L turns 3L into 2nd pl, all
    dance reels of 3 on sides (1L in & up, 3M in & down)
25-28::
    1M+3M change places LH _while_ 1L+3L change places LH, 1M+2M change
    places RH _while_ 2L+3L change pls RH
29-32::
    All set twice - order - Ladies 2 3 1 & Men 3 1 2

{{explanation}}
Repeat with new partners', 0);
INSERT INTO 'dancecrib' VALUES (7498, '2013-08-21 08:31:42.129988+00', '2023-02-04 01:22:41.519742+00', 11025, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+3s dance 1/2 R&L, 1M & 3M pass partners LH to dance out opp sides
    between 2s/4s & dance round partners corner to face them
17-24::
    1s & 3s dance reels of 4 across
25-32::
    1s+3s dance RSh round facing person, chase clockwise 1 place & dance
    RH across
33-40::
    2s+4s dance 1/2 R&L, 1M & 3M pass partners LH to dance out between
    1s/3s & dance LSh round corner to face them
41-48::
    2s & 4s dance reels of 4 up/down
49-56::
    2s+4s dance RSh round facing person, chase clockwise 1 place & dance
    RH across
57-64::
    All join hands & Set+Link with ''new'' partner, joining hands Set+Link
    with ''new'' corner to end with own partner 1 place clockwise

{{explanation}}
Repeat from new positions', 0);
INSERT INTO 'dancecrib' VALUES (7499, '2013-08-21 08:31:42.138372+00', '2023-02-04 01:22:41.547635+00', 6362, 3, NULL, 'ace', '1-8::
    1s cast 2 places, lead up to top & cast on own side to face 1st
    corners
9-16::
    1s dance ''Hello-Goodbye'' setting & end facing 1st corners
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & turn partner LH
    to face 1st corners
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners &
    pass RSh to …
33-40::
    1s dance reels of 3 on own sides giving RSh to 4th corners & end in
    2nd place', 0);
INSERT INTO 'dancecrib' VALUES (11472, '2019-01-01 01:57:56.979897+00', '2023-02-04 01:22:41.59195+00', 18971, 3, NULL, 'ace', '{{explanation}}
2 Ch - 1M & 3M stand as 1L & 3L cross down to 2M/4M place who cross over to partners place as 2L/4L step up (Ladies on right of partners)

1-8::
    1s+2s also 3s+4s dance RH across & LH back
9-16::
    1s+4s dance 1/2 Diag R&L (M down), all Adv+Ret
17-24::
    All dance 1/2 R&L, all Adv+Ret
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7501, '2013-08-21 08:31:42.192267+00', '2023-02-04 01:22:41.66257+00', 6368, 3, NULL, 'ace', '1-8::
    1s cross RH, cast to 2nd place, cross LH & cast back to original
    places
9-16::
    2s cross LH, cast up, 2s+1s turn partners 2H to own sides
17-24::
    2s+1s dance reel of 4 across (1M & 2L pass LSh to start)
25-32::
    2s+1s dance RH across 1/2 way & cross RH to own sides, 1s+2s dance
    LH across 1/2 way & cross LH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (9415, '2016-10-06 07:18:58.076133+00', '2023-02-04 01:22:41.693207+00', 14817, 3, NULL, 'ace', '1-8::
    1s NHJ dance between 3s, separate & cast round 3s, dance out between
    2s/4s (1M between 2s, 1L between 4s) and back to place
9-16::
    Men RH across, dance out thro'' partner''s place & chase clockwise 1/2
    round to opp place _while_ Ladies chase clockwise 1/2 round & dance
    RH across to opp place.  All now in opp place with partner.
17-20::
    All "Set & Progressive Link":
::
    _17-18_ All set
::
    _19-20_ Men dance in front of partner to next Man''s place to right
    _while_ Ladies cast behind partner to next Ladies place to Left. Now
    opposite partner. Men face out
21-24::
    All dance Ladies'' Chain 1/2 way (Ladies RH in middle) turning
    partner LH into promenade hold & face anticlockwise
25-32::
    All, in Allemande hold, dance anticlockwise round to end 1 place
    round from original position', 0);
INSERT INTO 'dancecrib' VALUES (12429, '2019-12-05 01:32:09.94997+00', '2023-02-04 01:22:41.724596+00', 19412, 3, NULL, 'ace', '1-8::
    1s set, 1L casts (2L steps up); 1L+2M set, 1L casts (3L steps up)
9-16::
    All dance 3 couple Bourrel:
::
    _9-12_    1M+3L also 2M+1L set advcg & 3/4 turn 2H to line up/down
    middle then 1/2 turn single to face own prtnrs as 3M & 2L chase
    anticl''wise to face them
::
    _13-16_   All set & turn 2H to own sides.  3 1 2
17-24::
    3s+1s+2s dance Promenade (Chaperoned) Chain progression:
::
    _17-18_    2s & 3s 3/4 turn partner RH into middle _while_ 1s dance
    clockwise 1/4 round the set picking up 3L/2M …
::
    _19-22_    who promenade 1/2 way clockwise _while_ middle people (3M
    + 2L) turn LH 1.1/2.
::
    _23-24_    2s & 3s turn partner RH 3/4 to own sides _while_ 1s dance
    clockwise 1/4 round to end in 2nd place.
25-32::
    2s+1s+3s circle 6H round & back.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7502, '2013-08-21 08:31:42.200848+00', '2023-02-04 01:22:41.759294+00', 12792, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1s turn LH 1.1/2 times to face 2nd
    corners (side by side holding LH)
9-16::
    1s set to 2nd corners & turning inwards set to 4th corner, 1s dance
    1/2 reel of 4 with 4th corners & end facing 1st corners (holding LH)
17-24::
    1s set to 1st corners & turning inwards set to 3rd corner, 1s dance
    1/2 reel of 4 with 3rd corners & end in middle facing partner (1M
    down, 1L up)
25-28::
    2s+3s set & dance on clockwise 1 place _while_ 1s turn RH 1.1/2
    times to end 1L between 2L+3L (at top) & 1M between 2M+3M
29-32::
    All chase on 1 place to own sides & set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7503, '2013-08-21 08:31:42.211221+00', '2023-02-04 01:22:41.781356+00', 6371, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    All Adv+Ret, 1s & 4s pass partner RSh & turn next person with nearer
    hand to end 2 (1) 4 (3), 1s & 3s remain facing out
9-16::
    2s+1s & 4s+3s dance full Figs of 8 (2M & 3M remain facing out)
17-24::
    2s+1s & 4s+3s dance Ladies'' Chain
25-32::
    1s & 4s dance RH across 1/2 way, 1/2 turn nearer corner LH, 2s & 3s
    dance RH across 1/2 way & turn nearer corner LH
33-40::
    1s & 4s dance ''Hello-Goodbye'' setting to end 1s in centre facing up
    & 4s facing down
41-48::
    1s & 4s dance out ends of the set & cast in to 2nd & 3rd place &
    dance 1/2 Figs of 8 round top / bottom couples to end 3 1 (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (7504, '2013-08-21 08:31:42.221243+00', '2023-02-04 01:22:41.890054+00', 6373, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, cross passing LSh & cast RSh round their 1st
    corner into centre ending BtoB (Lady facing up, Man down)
9-16::
    1L circle left with 2s & 1M with 3s, turn to face partner & set, 3/4
    turn partner 2H to end facing 1st corners
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH, partner LH & end
    facing 1st corners
25-32::
    1s dance Reel of 3 on opposite sides passing 1st corner LSh & cross
    RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7505, '2013-08-21 08:31:42.229758+00', '2023-02-04 01:22:41.912149+00', 7578, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance 1/2 Figs of 8 across (Lady up &
    Man down)
9-16::
    1s dance RH across (Lady with 2s & Man with 3s), 1s pass LSh to face
    2nd corners & dance 1/2 diagonal reel of 4, 1s end with 1/2 turn LH
17-24::
    1s dance RH across (1L+3s on Ladies'' side, 1M+2s on Men''s side); 1s
    pass LSh to face 1st corners & dance 1/2 diag reel of 4, 1s end BtoB
    facing own sides
25-32::
    1s join hands with corners & set, 1s dance round each other by right
    into 2nd place opposite sides (corners continue setting); 3s+1s+2s
    chase clockwise 1/2 round to places.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7506, '2013-08-21 08:31:42.239003+00', '2023-02-04 01:22:41.944383+00', 6375, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & 2s dance RH across (2L with 1s, 2M with 3s), all
    dance 6H round to left 1/2 way
9-12::
    All set & 2s cast round 1st corner (pstns) to end between Men/Ladies
    _while_ 1st corner change places RH & 2nd corners set
13-16::
    All set & 2s cast round 4th corners to end 2nd place own sides
    _while_ 2nd corners change places RH & 1st corners set
17-24::
    2s turn 1st corners RH & partner LH, 2nd corner RH & 1/2 turn
    partner LH
25-32::
    2s dance full reels of 3 across (2L LSh to 1M, 2M LSh to 3L), Bar 30
    2s meet,  dance down below 3s & curve up to 3rd place _while_ 3s
    dance up & change places RH with 1s to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7507, '2013-08-21 08:31:42.247827+00', '2023-02-04 01:22:41.969645+00', 12396, 3, NULL, 'ace', '1-8::
    1s+3s dance double Fig of 8 round 2s (1s cross down to start)
9-16::
    1s+2s dance the Bourrel :
::
    1M+2L set advancing, 3/4 turn 2H & twirl to end BtoB (Lady facing
    up, Man down) _while_ prtnrs chase anticl''wise 3/4 way,
::
    Set to partners & 2s turn 2H to own sides as 1s turn 2H to end
    facing 1st corners
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    dance Pass+Turn with 2nd corners 1s ending BtoB Man facing up
    between 2s & Lady down between 3s
25-32::
    1s dance reels of 3 on opposite sides (RSh to 2nd corner) & end
    crossing RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7508, '2013-08-21 08:31:42.256186+00', '2023-02-04 01:22:41.992431+00', 10341, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH, cast 1 place & dance 1/2 Figs of 8 round couple
    above them
9-16::
    4s cross down between 3s & cast to top place as 2s cross down to end
    in 3rd place, 4s+1s+2s 1/2 turn LH into prom hold facing up
17-24::
    4s+1s+2s Promenade & end 4s casting to 3rd place followed by 1s who
    cast to 2nd place & 2s dance to top
25-32::
    1s & 4s dance 1/2 Fig of 8 around couple above/below, 1s+4s dance
    1/2 R&L
33-40::
    All dance reels of 4 on sides
41-48::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13349, '2020-11-02 01:21:59.780883+00', '2023-02-04 01:22:42.013676+00', 19550, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across (3 bars), LH across (3 bars), 1s cast to 2nd
    place as 2s dance up to top.  2 1 3
9-16::
    1s+1st corners dance ''La Baratte'':
::
    _9-12_   1s+1st corners set, 1s 1/2 turn 1st corner RH, retain hands
::
    _13-16_  Men retraces steps with Lady turning right under Man''s arm
    briefly into Allemande hold & releasing Ladies RH she turns under
    Man''s left arm until almost in original places; 1s change places LH
    with 1st corner
17-24::
    1L+2s (at top) & 1M+3s circle 3H round to right; flowing into circle
    6H round to right (1s lead 2s/3s into 6H round)
25-32::
    3s+1s+2 dance ''Slip Knot'': as normal Knot but Bars 31-32: 2s turn to
    own side _while_ 1s+3s dance 1/2 LH across.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7509, '2013-08-21 08:31:42.264709+00', '2023-02-04 01:22:42.036004+00', 6380, 3, NULL, 'ace', '1-8::
    All turn RH (4 bars) & Ladies dance on 1 place clockwise passing
    partner RSh & all set to new partners
9-16::
    Repeat bars 1-8 with new partner. Ladies end opposite original place
17-32::
    Repeat bars 1-16 but all turning LH & Men dance on anticlockwise
    (pass partner LSh).  All couples now with partner opposite original
    place
33-48::
    1s+3s dance RH across then 1M & 3M followed by ptnrs dance cl''wise
    round outside of set back to original places 2nd & 4th couples
    repeat
49-56::
    All Ladies dance Figs of 8 round their partners & corners (start by
    passing in front of partners)
57-64::
    All Men dance Figs of 8 round their partners & corners (start by
    passing in front of partners)
65-72::
    1s+3s change places (3s making an arch) & set, repeat back to places
    (1s make an arch
73-80::
    2nd & 4th repeat (4s make 1st arch, 2s make 2nd arch)
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7510, '2013-08-21 08:31:42.277746+00', '2023-02-04 01:22:42.078478+00', 11725, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides
9-16::
    1s cross RH, cast 1 place, turn LH 1.1/4 times & turn left about to
    end BtoB facing up/down
17-24::
    1s dance Double Triangles (up/down) & end in 2nd place opposite side
25-32::
    1s cross down, cast up round 3s on own side, dance up between 2s &
    cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (7511, '2013-08-21 08:31:42.286013+00', '2023-02-04 01:22:42.110452+00', 6382, 3, NULL, 'ace', '1-8::
    1s+2s set, circle 4H round & turn partner 2H, 1s end facing in & 2s
    facing out
9-16::
    1s+2s+3s dance reflection reels of 3 on sides (1s dance in & down)
17-24::
    1s+2s dance Chain Progression :
::
    1s+2s turn RH, 1M+2L turn LH 1.1/2 times as ptnrs chase cl''wise 1/2
    way, 2s+1s turn RH to…
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13924, '2021-04-05 00:21:56.372553+00', '2023-02-04 01:22:42.136412+00', 19488, 3, NULL, 'ace', '1-8::
    1s dance in & cast (2s step up); 1s turn 1.1/2 RH to face 1st
    corners
9-16::
    1s dance »Hello-Goodbye« setting to finish BtoB in centre facing 3rd
    corners
17-24::
    1s+3rd corners turn RH; 1s+4th corners turn LH.  1s face out
25-32::
    2s+1s+3s dance RSh reels of 3 on sides (1M up, 1L down)
33-40::
    2s+1s+3s circle 6H just over 1/2 round to left (4 bars), dance in,
    pull back RSh & chase clockwise (3 bars) to own side to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8640, '2015-02-13 12:48:18.471947+00', '2023-02-04 01:22:42.176957+00', 13766, 3, NULL, 'ace', '1-4::
    1s+3s turn 3/4 RH into line in middle (M face up, L face down) and
    set _while_ 2s turn RH 1/2 way, face, pull back RSh, dance out to
    opp. sides
5-8::
    1s+3s dance 1/2 reel of 4, finish 3L/1M in middle facing own sides
    (3M +1L remain at ends in middle)
9-12::
    1M+2s+3L dance 1/2 reel of 4 across. Finish facing partners in line
    up/down middle (2s finish in original places)
13-16::
    3s+1s set, turn partners 3/4 RH to own sides.  3 2 1
17-24::
    3s+2s (top 2 couples) dance 6 bars of Bourrel:
::
    _17-20_   3M+2L set advancing, turn 3/4 2H, pull back RSH to face
    down/up _while_ 3L+2M dance anticlockwise round to finish facing
    partners
::
    _21-24_   2s+3s set to partners and petronella turn to own sides.  2
    3 1
25-32::
    3s+1s dance Diamond (all-round) Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7512, '2013-08-21 08:31:42.296284+00', '2023-02-04 01:22:42.204479+00', 12533, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 1L & 2L dance RSh round partner & turn partners RH to
    end in partner''s place
9-16::
    1s+2s+3s dance RSh reels of 3 on sides
17-24::
    1s+2s+3s set, 1M & 2M  dance LSh round partner & turn partners LH to
    end in own place
25-32::
    1s dance in touching hands & cast to 2nd place; 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (10102, '2017-09-03 23:45:28.421203+00', '2023-02-04 01:22:42.228078+00', 17895, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across.  2s+3s dance LH across
9-16::
    All Ladies NHJ Adv+Ret _while_ all Men NHJ set twice on side.  All
    Men NHJ Adv+Ret _while_ Ladies set twice
17-24::
    1s followed by 2s+3s+4s (who dance up sides to start) dance down
    middle & cast up to original places
25-32::
    1s dance down & curve into 4th place (Lady pull back LSh, Man RSh)
    (2s+3s+4s step up 27-28).  All couples turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (7513, '2013-08-21 08:31:42.304632+00', '2023-02-04 01:22:42.251975+00', 6384, 3, NULL, 'ace', '1-8::
    1M+2L also 3M+4L set & change places RH, 1L+2M also 3L+4M repeat
9-16::
    2s+1s also 4s+3s dance 1/2 R&L, 1s face 2s also 3s face 4s on sides
    & set twice
17-24::
    All dance RSh reels of 4 on sides
25-32::
    1s lead down to the bottom, 1s turn inwards to face 4s & 4s+1s
    circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (7514, '2013-08-21 08:31:42.314968+00', '2023-02-04 01:22:42.274012+00', 12397, 3, NULL, 'ace', '1-8::
    1s & 4s set & dance down/up to centre, 1s+4s cast to places & all
    set advancing & face next couple
9-16::
    1s+2s also 3s+4s dance the Rondel (2s & 3s making the arches)
17-24::
    1s+4s dance RH across 1.1/2 times round, 4s & 1s lead out ends &
    cast round nearest corner to end BtoB facing 2s/3s
25-32::
    4s+2s dance LSh reel of 4 across _while_ 1s+3s dance RSh reel of 4
    across ending 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7515, '2013-08-21 08:31:42.323341+00', '2023-02-04 01:22:42.29984+00', 13744, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1M+2L 3/4 turn RH as 1L+2M 3/4 turn LH &
    1s end in middle 1L behind 1M both facing up
9-16::
    1s dance an Alternating Tandem reel across with 2s (RSh to 2L to
    start)
17-24::
    1s dance an Alternating Tandem reel across with 3s (LSh to 3L to
    start) & 1s end in middle side by side both facing down
25-32::
    1M turns 3L LH as 1L turns 3M RH, 1s turn 1.1/2 times RH to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (7516, '2013-08-21 08:31:42.329647+00', '2023-02-04 01:22:42.326898+00', 10303, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 2 places, turn RH & lead up to 2nd place opposite
    sides
9-16::
    1s in prom hold dance reel of 3 with 2s (giving RSh to 2L to start)
17-24::
    1s dance down between 3s & cast up to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8364, '2014-07-29 12:59:31.798531+00', '2023-02-04 01:22:42.343151+00', 14547, 3, NULL, 'ace', '1-8::
    All set, dance in (2 steps), drop hands, pivot right & dance 1 place
    anticlockwise, dance out to sides turning right about into square
    set
9-16::
    2s facing 4s, 3s+1s facing partner to start, dance interlocking R&L
    (2s with 4s & 3s with 1s)
17-24::
    All set, turn corners 2H, all set and take hands to form circle
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15431, '2023-02-04 01:22:42.368844+00', '2023-02-04 01:22:42.36992+00', 21191, 3, NULL, 'ace', '1-8::
    1s+2s 1/2 turn RH & dance 1/2 RH across; 2s+1s dance LH across, 1s
    end in tandem, 1L leading, facing down in centre in 3rd place
9-12::
    1s+3M dance RH across, 1s in tandem, 1L leading, face 2L
13-16::
    1s+2nd corners dance 1/2 LSh alternating tandem reel of 3, 1s face
    down, 1M below 1L
17-20::
    1s+3L LH across, 1s in tandem, 1M leading, face 2M
21-24::
    1s+1st corners dance 1/2 RSh alternating tandem reel of 3, 1s
    separate, 1L pulling RSh back, to end in 2nd place opposite sides
    (3)(1)(2)
25-32::
    Cross & Rotate:
::
    All cross RH, chase 1/4 clockwise round into lines of 3 across; all
    change places RH up/down with person opposite & chase 1/4 clockwise
    round to end  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7517, '2013-08-21 08:31:42.338252+00', '2023-02-04 01:22:42.389973+00', 6386, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, chase clockwise 1/2 way to end on opp
    sides (2s in 1st place facing down & 1s in 2nd place facing up)
9-16::
    2s+1s+3s dance RSh reels of 3 on sides
17-24::
    1s followed by 2s lead down for 3, 2s divide & follow 1s back to
    top, 1s+2s retain RH & Men pass in front of Ladies as they turn
    under right arm
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7518, '2013-08-21 08:31:42.346367+00', '2023-02-04 01:22:42.411072+00', 6387, 3, NULL, 'ace', '1-8::
    All set, cross RH, set & cross RH (1s & 3s end in middle)
9-16::
    1s & 3s Slip-Step down for 2 bars & back to places, 1s+2s also 3s+4s
    turn on sides (Men LH & Ladies RH) all ending in middle facing up
17-24::
    1s+2s also 3s+4s Allemande (separately) & end with 1s & 3s turning
    3/4 RH into middle
25-32::
    1s+3s dance 1/2 reel of 4, set to partners & petronella turn to
    2nd/4th places own sides.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7519, '2013-08-21 08:31:42.356395+00', '2023-02-04 01:22:42.4441+00', 6391, 3, NULL, 'ace', '1-8::
    1s petronella turn into centre, join RH & dance 2 PdB steps down
    dance (L advances & M retires), then turn RH 1.1/4 times
9-16::
    2s+3s+4s+1s dance full reels of 4 on the sides & continue so that 3s
    & 4s end between 2s & 1s
17-24::
    2s+3s & 4s+1s dance 6 bar reels of 4 across & all turn partners RH
    to end 3 2 1 4 in Allemande hold
25-32::
    All dance Allemande to end 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (7520, '2013-08-21 08:31:42.364884+00', '2023-02-04 01:22:42.464038+00', 6393, 3, NULL, 'ace', '1-8::
    All set to corners & dance La Baratte :
::
    Men 1/2 turn opposite Lady RH & retains hand but at arms length from
    each other, Men retrace steps with Lady turning right under Man''s
    arm briefly into Allemande hold (Man behind Lady facing Ladies
    original place) & releasing Ladies RH she turns under Man''s left arm
    until almost in original places & couples change place LH to
    opposite positions & face in towards the middle of the set ie 1M in
    2nd Ladies place is facing 3L in 4th Mans place & so on
9-16::
    All turn opposite person 1/2 round with RH & remain facing this
    person Pulling R shoulder back all dance on 1 place (M clockwise, L
    anticlockwise) passing next person by RSh to meet own partners 1/2
    way round set All turn partners LH 1.1/2 times to face corner again
17-32::
    Repeat bars 1-16 from new places to return to original places & face
    in
33-40::
    1s+3s dance LH across 1.1/4 times & end in prom hold, 1s promenade
    round 4s & 3s round 2s passing by RSh to return to original places
41-48::
    2s+4s repeat above Fig 2s dancing round 1s & 4s round 3s
49-56::
    All join nearer hands with partners & set, advance into middle &
    retire with corners to corner position & set
57-64::
    All circle 8H round to left, turn partners 2H & open out to circle
    8H round to left to original places', 0);
INSERT INTO 'dancecrib' VALUES (7521, '2013-08-21 08:31:42.373643+00', '2023-02-04 01:22:42.483581+00', 12616, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on own sides (1s in & down to start)
9-16::
    1s cross RH, cast & dance 1/2 Fig of 8 round 2s
17-24::
    1s cross LH, cast down & dance 1/2 Fig of 8 round 3s
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13195, '2020-09-15 00:21:47.819451+00', '2023-02-04 01:22:42.728761+00', 16059, 3, NULL, 'ace', '1-8::
    1s+2s+3 set, 1/2 turn 2H, pull back RSh & curve to opposite side.
    All cross RH
9-16::
    1s+2s+3s dance reflection reels of 3 on own side (1s out/down, 2s
    in/up, 3s out/up). On bar 15 1s cast to face 1st corners _while_ 2s
    dance up & cast into 1st place, 3s cast into original place
17-20::
    1s set to 1st corners & 2nd corners, pull back RSh to face each
    other on the 2nd corner diagonal
21-24::
    1s set to each other, 1.1/4 turn 2H to 2nd place opposite side. 2
    (1) 3
25-28::
    All Advance for 1 step & Retire for 1 twice
29-32::
    2s+3s turn 2H _while_ 1s 1.1/2 turn 2H to finish 2nd place own side.', 0);
INSERT INTO 'dancecrib' VALUES (13095, '2020-08-10 00:21:31.773476+00', '2023-02-04 01:22:42.91259+00', 17922, 3, NULL, 'ace', '1-4::
    1s cast (2s step up) & face 1st corner
5-16::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s finish 2nd place
    opp sides (3) (1) (2)
17-24::
    Middle couple change places RH with opp dancer to right, new middle
    couple change places LH with opp dancer to left;
::
    Middle couple change places RH with opp dancer to right, all cross
    RH with partner.  2 1 3
25-32::
    1s+3s dance Chain Progression:
::
    _25-26_    1s & 3s 3/4 turn RH
::
    _27-30_    1M+3L turn LH 1.1/2 times _while_ partners chase
    clockwise 1/2 way
::
    _31-23_    3s & 1s 3/4 turn RH to end on sides in order. End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7523, '2013-08-21 08:31:42.390127+00', '2023-02-04 01:22:42.943238+00', 8954, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set, turn 2H, circle 4H once round to left
9-16::
    1s+2s also 3s+4s dance 1/2 Diamond Poussette, 1s+4s dance 1/2
    Diamond Poussette
17-24::
    4s+1s 1/2 turn RH & turning right dance into partners place, 4s & 1s
    1/2 Figs of 8 round end couple
25-32::
    All RSh reel of 4 on sides.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8641, '2015-02-13 12:48:18.578772+00', '2023-02-04 01:22:42.971077+00', 14712, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across, set, cross RH
9-12::
    1s+1st corners turn RH once round, 1s finish facing 1st corners
13-16::
    1s+1st corners dance 1/2 diagonal reel of 4. Bars 15-16 1M (from 3rd
    place) & 1L (from 1st place) cross up/down to 2nd place own sides
17-24::
    1s+2nd corners repeat 9-16 but turning LH and passing LSh to start
    reel. Bars 23-24 1M (from 1st place), 1L (from 3rd place) cross
    down/up to 2nd place own sides  (3) 1 (2)
25-32::
    3s+1s+2s chase anticlockwise 1/2 way round.  1s set and cross RH
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9489, '2016-11-09 08:49:03.20894+00', '2023-02-04 01:22:42.989209+00', 15600, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH & chase 1/2 round clockwise to own sides  3 2
    1
9-16::
    3s+2s+1s dance reels of 3 on sides (1s pass 2s RSh to start)
17-24::
    3s+2s+1s dance Set+Link for 3.  2s turn LH 1.1/4 to 2nd place own
    sides
25-32::
    1s+2s dance "Espagnole"

{{explanation}}
Note:  End of 2nd time through, 1s turn LH to 4th place as 4s step up', 0);
INSERT INTO 'dancecrib' VALUES (13350, '2020-11-02 01:22:00.520715+00', '2023-02-04 01:22:43.007961+00', 19226, 3, NULL, 'ace', '1-8::
    1s+2s+3s set twice; turn partner RH
9-16::
    1s+2s+3s set twice; turn partner LH
17-24::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s
25-32::
    1L+2s & 1M+3s dance RH across; 1s pass RSh to dance LH across with
    other couple.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7524, '2013-08-21 08:31:42.398779+00', '2023-02-04 01:22:43.03837+00', 13755, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s+4s (who dance up sides to begin) dance down the
    middle for 4 bars & cast up to place.
9-16::
    1s+2s also 3s+4s set & dance RH across 1/2 way, set & LH across back
    to place
17-24::
    1s+2s also 3s+4s dance the Bourrel (except that 1s+4s+3s end turning
    RH to face up in Allemande hold.  2s end on side at top):
::
    1M+2L also 3s+4s set advancing, 3/4 turn 2H & twirl to end BtoB
    (Lady facing up & Man down) _while_ partners chase anticlockwise 1/2
    way
::
    set & turn RH
25-32::
    1s+4s+3s dance Allemande.  Finish in order 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7525, '2013-08-21 08:31:42.40865+00', '2023-02-04 01:22:43.063501+00', 6397, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance mirror reels of 3 on sides (1s in & down to start)
    with 1s & 2s end in middle facing down/up, ready for …
9-16::
    1s+2s dance the Rondel.  1s end in 2nd place own side facig out
17-24::
    1s cast 1 place, lead down between 4s, cast up behind 4s & turn LH
    to face 1st corner (pstn) between 3s & 4s (1M facing 4L, 1L facing
    3M)
25-32::
    1s set & turn 1st corners 2H, set & turn 2nd corners 2H to end in
    3rd place on opp sides
33-40::
    3s+1s+4s circle 6H round to left back to place (6 bars) & 1s lead
    down giving LH & cross into 4th place on own side. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (11473, '2019-01-01 01:57:57.463981+00', '2023-02-04 01:22:43.087217+00', 18309, 3, NULL, 'ace', '1-8::
    1s cross RH & cast down 1 place (2s step up), dance 1/2 Fig of 8 up
    round the 2s. End  2 1 3
9-16::
    1M+3s & 1L+2s dance RH across 1.1/2 times (6 bars) to end 1L in
    centre above 1st place, 1M in centre below 3rd place, facing own
    sides; 1s cast down/up to 2nd place own sides. (2) 1 (3)
17-24::
    1s pass LSh and dance 1/2 diag reel of 4 with 1st corner positions;
    then 1s pass RSh to dance 1/2 diag reel of 4 with 2nd corner
    positions, ending in 2nd place opp sides.  3 (1) 2
25-32::
    1M+2s (at bottom) & 1L+3s (at top) dance LH across 1.1/2 times (6
    bars) to end 1L at top, 1M at bottom, facing opp sides; 1s cast
    down/up to 2nd place, opp sides.  (3) (1) (2)
33-40::
    1s pass LSh to dance 1/2 diag reel of 4 with 3rd Corners then pass
    RSh to dance 1/2 diag reel of 4 with 4th corners to end in 2nd place
    own sides. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9243, '2016-06-16 22:42:22.93124+00', '2023-02-04 01:22:43.108706+00', 16853, 3, NULL, 'ace', '1-8::
    1s+2s dance Poussette
9-16::
    1s+2s set (2 bars), dance 1/2  RH across (2 bars), turn prtnrs 2H (2
    bars) & pass  prtnrs RSh to 1s in 2nd place own side, 1L facing
    down, 1M facing up
17-24::
    2s+3s dance RSh reels of 3 on sides _while_ 1s dance 1/2 reel on own
    side, cross to 2nd place (1L from 3rd  place , 1M from  1st place)
    to dance 1/2 reel on opp sides & cross back to 2nd place own sides
25-32::
    1s+3s dance 1/2 R&L, 1s+3s turn 2H 1.1/2 times   2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7526, '2013-08-21 08:31:42.422399+00', '2023-02-04 01:22:43.242692+00', 6399, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, Set+Link to change back on sides
9-16::
    1L followed by partner casts down 2 places, crosses & dances up
    behind 3M & in to face 1st corner as 1M dances between 3s to face
    his 1st corner
17-24::
    1s dance 1/2 diagonal reels with 1st corners & 1/2 diagonal reel
    with 2nd corners 1s ending BtoB with Lady facing down
25-32::
    1s dance 1/2 diagonal reels with 3rd corners & 1/2 diagonal reel
    with 4th corners 1s ending BtoB with Lady facing down
33-40::
    1s dance Crown Triangles ending with 1s dancing petronella turn to
    2nd place own side
41-48::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7527, '2013-08-21 08:31:42.430532+00', '2023-02-04 01:22:43.265001+00', 10086, 3, NULL, 'ace', '1-8::
    1s & 3s (facing diagonally in) set, 1M+3L 3/4 turn RH & cast back to
    place _while_ partners cast to 3rd/1st place & 3/4 turn LH to
    places, 1s & 3s 1/2 turn RH to 1M+3L BtoB facing partner in diagonal
    line of 4
9-16::
    1s+3s dance RSh diagonal reel of 4 & end in original places
17-24::
    1s+2s+3s circle 6H round & back
25-32::
    1s dance 1/2 Fig of 8 round 2s, cross down to 2nd place & cast to
    3rd place', 0);
INSERT INTO 'dancecrib' VALUES (7528, '2013-08-21 08:31:42.44032+00', '2023-02-04 01:22:43.296838+00', 8085, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s
9-16::
    1s+2s+3s dance reflection reels on the side (2s out & up to start)
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7529, '2013-08-21 08:31:42.44876+00', '2023-02-04 01:22:43.32699+00', 11604, 3, NULL, 'ace', '1-8::
    1s cross RH & cast down below 3s, 1s cross LH & cast up round 3s &
    cross passing LSh to end facing 1st corners
9-16::
    1s dance reel of 4 with 1st corners & end dancing round each other
    LSh to face 2nd corners
17-24::
    1s dance reel of 4 with 2nd corners & end passing LSh to face 1st
    corners
25-28::
    1s couple turn 1st corners RH & at end of turn 1s pass RSh to face
    2nd corners
29-32::
    1s turn 2nd corners RH & at end of the turn 1s pass RSh to 2nd place
    own sides
33-40::
    2s+1s+3s circle 6H round & back.', 0);
INSERT INTO 'dancecrib' VALUES (7530, '2013-08-21 08:31:42.457075+00', '2023-02-04 01:22:43.356459+00', 14641, 3, NULL, 'ace', '1-8::
    1s+2s dance the Tournee:
::
    1s+2s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 2s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (2s RH, 1s LH) & dance
    out to places
9-16::
    1L+2s & 1M+3s dance RH acoss, 1L+3s & 1M+2s dance LH across & on bar
    16 1s pass LSh to face 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting, 1s petronella turn to 2nd place
    own side
25-32::
    1s+3s dance the Tourbillon:
::
    1s & 3s 1/2 turn ptnrs 2H, 1M & 3L lead ptnrs by nearer hand 1 place
    cl''wise to end 1s on Ladies side & 3s Men''s side, 1s set to 3s
::
    1s & 3s 1/2 turn ptnrs 2H & lead ptnrs on 1 place clockwise & 3s+1s
    cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (9420, '2016-10-06 07:19:00.619789+00', '2023-02-04 01:22:52.604015+00', 17276, 3, NULL, 'ace', '1-8::
    1L & 2M cross to opposite sides (no hands) & dance round partner RSh
    & back to places, 1M & 2L repeat passing partner LSh
9-16::
    1s cross down below 2s & cast up to 1st place on opposite sides,
    1M+2L turn LH 1.1/2 times as 1L+2M turn RH 1.1/2 times
17-24::
    2s+1s dance a Ladies'' Chain
25-32::
    1s lead up & cross & cast into 2nd place, 1s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (15240, '2022-11-03 01:21:55.352239+00', '2023-02-04 01:22:43.389478+00', 20434, 3, NULL, 'ace', '1-8::
    1s lead down; 1s change sides (Lady turns under Man''s right arm) &
    dance up to top in centre between 2s who dance up to top bars 5-6
9-16::
    1s 3/4 turn 2s nearer hand to sides (3 bars), 1M+3L turn LH _while_
    1L+3M turn RH (3 bars), 2s+1s+3s set
17-24::
    1M+2s (at top) & 1L+3s (at bottom) dance RH across, 1s pass RSh to
    dance LH across with other couple
25-32::
    1s dance 1/2 Fig 8 (1M up round 2s, 1L down round 3s); 2s+1s+3s turn
    partner 2H', 0);
INSERT INTO 'dancecrib' VALUES (7531, '2013-08-21 08:31:42.465313+00', '2023-02-04 01:22:43.415089+00', 9643, 3, NULL, 'ace', '1-8::
    1s+2s set facing in diagonally, petronella turn on 1 place to right,
    set & cast back to places
9-16::
    1L+2M turn 2H, 1M+2L turn 2H
17-24::
    1s+2s circle 4H round & back
25-32::
    1s+2s dance the Rondel', 0);
INSERT INTO 'dancecrib' VALUES (7707, '2013-08-21 08:31:47.168369+00', '2023-02-04 01:22:57.071156+00', 7530, 3, NULL, 'ace', '1‑8::
    All clap as 1s cross down & cast behind 3s, 1s cross down between 4s
    & cast up to original places
9‑16::
    1s+2s also 3s+4s dance RH across, 1s & 3s cast 1 place _while_ 2s &
    4s lead up 1 place & 1s also 3s 3/4 turn RH into line up/down middle
17‑24::
    1s+3s dance 1/2 reel of 4, set to partners & Petronella turn to end
    on own sides.  2 3 4 1
25‑32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8647, '2015-02-13 12:48:22.300869+00', '2023-02-04 01:22:57.507558+00', 15644, 3, NULL, 'ace', '1-8::
    1s+3s Adv+Ret.  1M+3L & 1L+3M change places RH turning inwards to
    face partners.  1s+3s set
9-16::
    2s+4s repeat bars 1-8
17-24::
    1s+3s set.  1L+3L changes places RH, dance clockwise 1/2 round
    outside of set to places _while_ 1M+3M cast, dance clockwise 1/2 way
    round outside of set, change place RH with each other to finish on
    Right of partner
25-32::
    All couples set to partners, turn 2H 1/2 way (skip change).  All
    circle 8H round 3/4 to Left', 0);
INSERT INTO 'dancecrib' VALUES (14441, '2021-11-06 01:13:21.779736+00', '2023-02-04 01:22:43.454603+00', 6404, 3, NULL, 'ace', '1-4::
    1s+2s set twice (Highland steps may be used)
5-8::
    1M leads 1L round 2M to face 1st corners
9-12::
    1s dance 1/2 reel of 4 with 1st corners
13-16::
    1s dance 1/2 reel of 4 with 2nd corners
17-20::
    1s dance 1/2 reel of 4 with 1st corners (3rd corner pstn)
21-24::
    1s dance 1/2 reel of 4 with 2nd corners (4th corner pstn)
25-32::
    1s lead down middle (3 bars) & back up (3 bars), 1s cast down round
    3s to end BtoB facing own side ready for…
33-40::
    1s dance Double Triangles with 3s+4s, 1s & 4s end in centre, 2H
    joined with partner, ready for …
41-48::
    1s+4s dance Poussette.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (11712, '2019-03-18 21:02:56.626665+00', '2023-02-04 01:22:43.489312+00', 19135, 3, NULL, 'ace', '1-4::
    1s+2s Petronella turn into middle & set
5-8::
    1s+2s turn partner 1.1/4 RH to finish in middle (2s face up & 1s
    face down, nearer hands joined)
9-16::
    1s+2s dance Rondel
17-24::
    2s+1s+3s dance Grand Chain
25-32::
    2s+1s+3s set, rotate (pull back RSh) & chase clockwise to form lines
    of 3 across (Men facing down & Ladies up) to flow into 6H round to
    the left to finish on own sides', 0);
INSERT INTO 'dancecrib' VALUES (7532, '2013-08-21 08:31:42.475457+00', '2023-02-04 01:22:43.513734+00', 6406, 3, NULL, 'ace', '1-8::
    1s+2L circle 3H round to left, 1s+2M circle 3H round also to left 1s
    ending the middle
9-16::
    1s lead down for 2 steps, lead up for 2 steps, cast to 2nd place,
    set advancing & turn to face own sides
17-24::
    1s dance Double Triangles ending 2nd place own sides
25-32::
    1s dance 1/2 reel of 3 across (1L+2s & 1M+3s) giving LSh to 1st
    corners & 1/2 reel of 3 with other couple, LSh to 3rd corners (2nd
    corner person)
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7626, '2013-08-21 08:31:45.773784+00', '2023-02-04 01:22:52.667107+00', 6597, 3, NULL, 'ace', '1-8::
    1s dance Inveran Reels with 2s+3s
9-16::
    1L+3M turn RH 1.1/2 & cast down/up on opp side behind 2s, cross back
    to own place _while_ 1M+3L cross, cast behind 2s & turn RH 1.1/2 to
    own place
17-24::
    1L followed by partner also 3M followed by partner cast behind 2s
    into middle to dance 1/2 LH across ending with 1s casting 1 place
25-32::
    2s+1s dance R&L', 4);
INSERT INTO 'dancecrib' VALUES (7627, '2013-08-21 08:31:45.783532+00', '2023-02-04 01:22:52.784168+00', 6599, 3, NULL, 'ace', '1-8::
    1s+2s set twice, 1M turns 2L as 1L turns 2M (1s pass RSh to turn 2s
    on sides) ending back in original places
9-16::
    1s dance RSh reels on own sides 1s ending in 2nd places
17-24::
    2s+1s circle 4H round to left twice
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7533, '2013-08-21 08:31:42.485198+00', '2023-02-04 01:22:43.643573+00', 6407, 3, NULL, 'ace', '1-8::
    1s lead round 2M LSh & dance a full Fig of 8 round 2s & end in
    original places
9-16::
    2s (Lady on Mans left) lead round 1M RSh & dance a full Fig of 8
    round 1s & end in original places
17-24::
    1M+2M lead between partners, cast round partner back to places, 1s
    lead down 1 place & cast back to places
25-32::
    1L+2L lead between partners, cast round partner back to places, 1s
    lead down 1 step, back to top & cast to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7534, '2013-08-21 08:31:42.493225+00', '2023-02-04 01:22:43.668029+00', 6410, 3, NULL, 'ace', '1-8::
    1s & 3s petronella turn into centre & set, 1s+3s dance 1/2 reel of 4
    _while_ 2s move to 3rd place
9-16::
    3s petronella turn to own side, set & turn RH _while_ 1s+2s dance
    RSh reel of 4 across (L facing L & M facing M to start & end 3 1 2
    on own sides)
17-24::
    3s+1s+2s dance Allemande, 1s ending ready for Double Triangles
25-32::
    1s dance Double Triangles, 1s end in 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7536, '2013-08-21 08:31:42.639124+00', '2023-02-04 01:22:43.699051+00', 6413, 3, NULL, 'ace', '1-8::
    1s+2s set, 1L+2M cross RH _while_ 1M & 2L set again; 1s+2s change
    places LH with partners on sides & 1s+2s join hands on sides & set
9-12::
    1L & 2L cast 1 place to finish BtoB in centre facing partner _while_
    1M & 2M move up 1/2 place to between 1st/2nd place (11-12) all in
    line across
13-16::
    1s & 2s turn partner RH 1.1/2 times into Allemande hold, 1s facing
    down on Man''s side, 2s facing up on Ladies'' side
17-24::
    1s dance Allemande down & up (pass 2s LSh) to top place opposite
    side _while_ 2s dance Allemande up & dance round to end in 2nd place
25-28::
    1s+2s set, 1s cast 1 place as 2s dance up NHJ
29-32::
    2s cast _while_ 1s cross up RH to 1st place own side, 1s cast to 2nd
    place as 2s dance up to top NHJ. End 2 1', 0);
INSERT INTO 'dancecrib' VALUES (7535, '2013-08-21 08:31:42.630864+00', '2023-02-04 01:22:43.868493+00', 14741, 3, NULL, 'ace', '1-8::
    1s dance Figs 8 own sides dancing in & down to start (giving hands
    where possible)
9-16::
    1s cross down to dance reels of 3 on opp sides (joining hands where
    possible) & 1s end facing 1st corners, 2s end in 1st place
17-20::
    1s dance Corners Pass+Turn with 1st corners (corners turn RH), pass
    RSh on bar 20 to face 2nd cnrs
21-24::
    1s dance Corners Pass+Turn with 2nd corners (corners turn RH). Pass
    RSh on bar 24 to end 2nd place own sides
25-32::
    All set, all cross RH, all chase clockwise 1/2 way round to own
    sides  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7537, '2013-08-21 08:31:42.647157+00', '2023-02-04 01:22:43.895691+00', 6412, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, lead up crossing over & cast to 2nd place
    opposite sides
9-16::
    2s+1s+3s reel of 3 on sides (1s turn RH up between 2s to start) & 1s
    cross down from 2nd place to continue reel on own side, 1s turn LH
    to face 2L
17-24::
    1s+2L circle 3H round to left, 1s turn 2H to face 2M & circle 3H to
    right, turn 2H to face 1st corners
25-32::
    1s dance reels of 3 across (1M with 3s & 1L with 2s) & turn partner
    LH to own side in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (15432, '2023-02-04 01:22:43.921007+00', '2023-02-04 01:22:43.922383+00', 19053, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides 2 1 4 3
9-16::
    1s+4s set, cross RHwith partner, Petronella turn into centre, turn
    partner 2H 1.1/2 times into line up/down middle
17-24::
    1s+4s dance RSh reel of 4 in centre to finish in Highland
    Schottische Poussette hold
25-32::
    1s+4s dance Highland Schottische poussette  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7538, '2013-08-21 08:31:42.655543+00', '2023-02-04 01:22:43.952293+00', 12453, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 on own sides dancing between 2s to start ending
    with 1L+2M changing places passing RSh
9-12::
    1M+2L & 1L+3L change places RH (diag down), 1M+3L & 1L+3M cross RH.
13-16::
    1M+2M & 1L+3L change pls LH (diag up), 1M+2M pass LSh curving round
    to partner (who step in) & end 2s facing down & 1s up in middle
17-20::
    2s+1s set advancing & pass LSh to change pls _while_ 3s 1/2 turn 2H
    to face up, 2s+3s set advancing to change pls _while_ 1s 1/2 turn 2H
    to face down
21-24::
    1s+3s set advancing to change places _while_ 2s 1/2 turn 2H to face
    up, 1s+2s set advancing to change places _while_ 3s 1/2 turn 2H to
    face down
25-28::
    3s+2s set advancing to change places _while_ 1s 1/2 turn 2H to face
    up, 3s+1s set advancing to change places _while_ 2s 1/2 turn 2H
29-32::
    2s continue turn & twirl to 1st place own side _while_ 1s turn 2H
    once round to 2nd place _while_ 3s 1/2 turn 2H & twirl out to 3rd
    place
33-40::
    1s+3s dance the Knot to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7539, '2013-08-21 08:31:42.860253+00', '2023-02-04 01:22:44.298927+00', 9895, 3, NULL, 'ace', '1-8::
    Ladies petronella turn one place to right & all set, Ladies
    petronella turn to right & all set
9-16::
    Men dance RH across 1/2 way & turn partner LH into centre, Ladies
    dance RH across 1/2 way & turn other partner LH into centre
17-24::
    Repeat bars 9-16 finishing on sidelines
25-32::
    Ladies repeat bars 1- 8 to original places
33-40::
    All chase clockwise 1/2 way round set, all join hands & circle 8H
    round to right (anticlockwise) to original places

{{explanation}}
Repeat with Men dancing petronella turn one place to right & Ladies dancing LH across at bar 9', 0);
INSERT INTO 'dancecrib' VALUES (7540, '2013-08-21 08:31:42.86841+00', '2023-02-04 01:22:44.310707+00', 8577, 3, NULL, 'ace', '1-8::
    1M dances reel of 3 on opposite side with 1L+2L (RSh to 2L)
9-16::
    1M followed by partner dances Tandem reel of 3 across with 2s (RSh
    to 2M)
17-24::
    1M followed by partner dances down the middle & leads her up to top
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7541, '2013-08-21 08:31:42.876459+00', '2023-02-04 01:22:44.328035+00', 7524, 3, NULL, 'ace', '1-8::
    1s cross down to dance mirror reels on opposite sides. 2s end in 1st
    place, 1s end in middle 2nd place, BtoB facing opposite sides
9-16::
    2s+1s+3s set as Double Triangles, 1s dance out & casts to right
    round 1st corner); 1s pass partner to end BtoB, 1L facing down, 1M
    facing up & set as Double Triangles
17-24::
    1L dances down between 3s & casts to left (round 3L) _while_ 1M
    dances up between 2s & left (round 2M) to 2nd places own side;
    2s+1s+3s turn RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14542, '2022-01-10 02:20:57.951114+00', '2023-02-04 01:22:44.345387+00', 10271, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s turn RH into prom hold facing up
9-16::
    1s in prom hold dance LSh reel of 3 across with 2s (LSh to 2M to
    start). 1s end in centre facing each other, backs to own side
17-24::
    2s+1s+3s set, with 1s pulling back RSh to face own side. 1s dance 6
    bars of Double Triangles finishing BtoB in centre facing opp side
25-32::
    1s dance 6 bar RSh reels of 3 with corners (RSh to 1st corner to
    start).  Bars 31-32 1s turn RH to own side 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (14919, '2022-06-27 00:22:08.339859+00', '2023-02-04 01:22:44.374907+00', 20880, 3, NULL, 'ace', '1-8::
    1s cross RH, cast off (2s step up); 1s turn LH to face 1st corners
9-10::
    1s+1st corners set
11-14::
    1s dance RSh round each other into 3rd corner positions (2 bars), &
    1/4 reel of 4 (2 bars), _while_ 1st corners dance 1/2 reel of 4 (4
    bars)
15-16::
    1s (in centre) turn LH _while_ corners chase clockwise 1 place round
17-24::
    Repeat bars 9-16 with dancers in 1st corner positions, bars 23-24 1s
    pass LSh to 2nd place own sides, _while_ corners chase clockwise 1
    place round
25-32::
    2s & 1s dance the Slip Knot (as standard Knot but end by passing
    Lady in front & dancing 1/2 LH across back to same places). 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7542, '2013-08-21 08:31:42.884507+00', '2023-02-04 01:22:44.406398+00', 6419, 3, NULL, 'ace', '1-8::
    1s promenade anticlockwise round outside of set
9-16::
    1L dances reel of 3 with 3s (passing 3L LSh) _while_ 1M dances reel
    with 2s (passing 2M RSh) & all end in original places
17-24::
    All Ladies dance RH across, pass in front of partner & behind next
    Man to end at side of remaining Man
25-32::
    All Men dance LH across, pass in front of new partner & behind next
    Lady to end beside remaining Lady

{{explanation}}
Repeat from new positions with new partners', 0);
INSERT INTO 'dancecrib' VALUES (7543, '2013-08-21 08:31:42.892647+00', '2023-02-04 01:22:44.436046+00', 6420, 3, NULL, 'ace', '1-4::
    1s+2s & 3s+4s 1/4 turn RH on sides to form line of 4 across &
    Bal-in-Line, drop LH & 1/4 turn RH to all Bal-in-Line on own sides
5-8::
    1s 1/4 turn 4s LH to Bal-in-Line across, drop RH & 1/4 LH turn to
    all Bal-in-Line on own sides ending 2 4 1 3
9-16::
    All dance RSh reels of 4 on own side. 1s+4s pass LSh at end
17-24::
    2s+4s & 1s+3s circle 4H round once to left; 4s+1s only (centre
    couples) dance LH across
25-32::
    1s+3s (bottom couples) dance 1/2 R&L & cross RH with partner to own
    side; 4s & 3s (centre couples) change places LH on side.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8070, '2013-10-01 08:47:26.92608+00', '2023-02-04 01:22:44.458619+00', 14718, 3, NULL, 'ace', '1-8::
    1s+2s dance the Knot & 1s end facing 1st corner
9-16::
    Corner Chain: 1s change pl RH with 1st crnrs, 1st crnrs turn LH in
    centre & return to places giving RH to 1s who turn LH in centre to
    face 2nd crnrs
17-24::
    1s+2nd corners dance reel of 4.  1s finish in 2nd place own side
25-32::
    1s+3s set & dance 3/4 Double Fig of 8 _while_ 3s cast up to top &
    dance down middle to bottom & cast up to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (9930, '2017-06-05 11:31:50.019187+00', '2023-02-04 01:22:44.485552+00', 16495, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s turn RH, cast, turn 1.1/4 LH to face 1st corners (2s step up 3-4)
9-10::
    1s+1st corners change places RH _while_ 2nd corners set advancing
    slightly to centre
11-12::
    1st+2nd corners dance 1/2 LH across _while_ 1s chase clockwise to
    next corner place
13-14::
    1L+3M & 1M+2L change places RH _while_ 3L & 2M cast right to opp
    corner place
15-16::
    1st+2nd corners chase clockwise to next corner _while_ 1s turn 1.1/2
    LH to face 1st corners (in 2nd corner position)
17-24::
    Repeat 9-14 then 1s turn 3/4 LH to 2nd place own side _while_
    1st+2nd corners chase clockwise to next corner
25-28::
    _1/2_ Diag R&L (1L+3L & 1M+2M cross RH)
29-32::
    _1/2_ Diag R&L (1L+3M & 1M+2L cross RH)

{{title}}
Jig

33-64::
    1s repeat 1-32 from 2nd place (may replace LH turn 15-16 with change
    places LH)', 0);
INSERT INTO 'dancecrib' VALUES (14227, '2021-08-14 00:22:05.756726+00', '2023-02-04 01:22:44.50366+00', 12423, 3, NULL, 'ace', '1-8::
    1s turn LH (4 bars); 1M followed by partner casts behind 2M, cross
    to 2nd place opposite side. 1M faces out (2s step up bars 7-8)
9-16::
    2s+1s dance Ladies'' Chain, 1M finishes facing out
17-24::
    1M followed by partner casts up round 2L & dances down to finish 1M
    between 3s at the bottom,1L between 2s at the top, all facing down;
    All dance down the middle for 4 bars
25-32::
    All dance up for 4 bars; 1L followed by partner casts round 2M,
    crosses to finish in 2nd place own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9931, '2017-06-05 11:31:50.027218+00', '2023-02-04 01:22:44.529777+00', 16496, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 1/2 RH across.  2M followed by 2L casts, crosses
    below 3s to 3rd place own side (1s+3s step up 7-8)
9-16::
    1s+3s set, dance 1/2 LH across.  3L followed by 3M casts, crosses
    below 2s (3rd place) to original places (1s+2s step up 15-16)
17-24::
    1s set, dance in & cast, meet below 3s & dance up to 2nd place in
    middle (2s step up 21-22)
25-28::
    1M+2M+3M dance LH across as 1L+2L+3L dance RH across
29-32::
    1s dance up, cast to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (7544, '2013-08-21 08:31:42.900792+00', '2023-02-04 01:22:44.549602+00', 12019, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s dance down between 3s & cast to 2nd
    place opposite sides
9-16::
    All 1/2 turn & twirl to change places, all turn RH into allemande
    hold (2s & 3s face down, 1s face up)
17-24::
    All dance Circulating Allemande:
::
    1s dance normal Allemande ending in 2nd place _while_ 2s+3s
    Allemande (down) & up to 3rd/1st places.  (3)1(2)
25-32::
    1s dance 1/2 Fig of 8 up between 3s, all turn 2H 1.1/2 times to own
    sides to end 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (12749, '2020-04-11 10:53:13.757429+00', '2023-02-04 01:22:44.686752+00', 19904, 3, NULL, 'ace', '{{explanation}}
3s+4s start on opp sides

1-4::
    1s+4s NHJ dance down/up 1 place & turn 2s/3s with nearer hand. 2s/3s
    finish in 1st/4th place, 1s finish between 2s facing down, 4s
    between 3s facing up
5-8::
    1s+4s Adv+Ret down/up centre
9-12::
    1s+4s cross down/up centre, 1s NHJ passing between 4s, 4s+1s dance
    between 2s/3s, turning 2s/3s with nearer hand to finish on sides 2
    (4) 1 (3)
13-16::
    4L+1M & 4M+1L (middle couples) Adv+Ret
17-20::
    4s+1s cross, 4M+1L (middle couple Ladies'' side) NHJ dancing between
    4L+1M & turn corners into lines across, 4s (between 2s) facing 1s
    (between 3s)
21-24::
    1s+4s turn person opposite 2H opening into …
25-32::
    8H round and back 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (13639, '2021-02-04 01:21:56.248974+00', '2023-02-04 01:22:44.735048+00', 15238, 3, NULL, 'ace', '1-8::
    All dance 8H round & back
9-16::
    _9-10_    1s make arch & dance down Men''s side (1M on outside of
    set)
::
    _11-14_  1s turn LH (or birl), make arch & dance up Ladies'' side (1L
    on outside of set)
::
    _15-16_  1s turn LH (or birl) to end in 1st place own side
17-20::
    All join hands in circle (retain until bar 24), 4s make arch, 1s
    dance under & dance down with 2s+3s+4s following going under arch
21-24::
    1s raise joined hands, turn away from each other to make arch over
    other couples & dance up to place
25-28::
    2s+3s+4s make arches across set & 1s dance down
29-32::
    All turn RH (or birl) moving up 1 place.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7546, '2013-08-21 08:31:42.916785+00', '2023-02-04 01:22:44.768397+00', 7282, 3, NULL, 'ace', '1-8::
    1s dance in & cast to 3rd place, 2s+1s turn partners RH 1.1/4 times
    to form a line up & down middle of set (Men facing down Ladies up)
9-16::
    2s+1s dance reel of 4 up & down middle of set ending with 2M facing
    Ladies side & 1L facing Men''s side
17-24::
    2s+1s chase round clockwise 1/2 way, 1s+3s+2s Adv+Ret
25-32::
    3s+2s (bottom 2 couples) 1/2 turn partners RH, dance RH across 1/2
    way, 1s+2s (top 2 couples) 1/2 turn partners RH & dance RH across
    1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (7547, '2013-08-21 08:31:42.924997+00', '2023-02-04 01:22:44.798325+00', 11480, 3, NULL, 'ace', '1-4::
    1s+2s+3s set & turn partners 2H, remain in middle facing up with
    nearer hands joined
5-8::
    1s cast down to 3rd place, 2s dance up & cast to 2nd place, 3s cross
    up to 1st place
9-16::
    3s+1s dance Ladies'' Chain (up & down) & end on sides (3) 2 1
17-24::
    2s petronella turn & all set in lines across, 2s petronella turn to
    opposite sides & all set.  (3)(2) 1
25-32::
    2s+1s dance RH across 1/2 way, 3s+1s dance LH across 1/2 way,
    1s+3s+2s set & turn partners RH for…
33-40::
    1s+3s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (6935, '2013-08-21 08:31:33.329998+00', '2023-02-04 01:22:44.831142+00', 13555, 3, NULL, 'ace', '1-8::
    1L followed by 1M casts 1 place & crosses to opposite sides, 1s turn
    RH
9-16::
    All circle 6H round & back
17-24::
    1s dance reels of 3 across (1L with 2s, 1M with 3s)
25-32::
    1s set & cast to bottom & dance 1/2 Fig of 8.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7548, '2013-08-21 08:31:42.941563+00', '2023-02-04 01:22:44.861335+00', 11294, 3, NULL, 'ace', '1-8::
    1s set, cross RH, 1s+2s Set+Link
9-12::
    2s+1s circle 4H round to left 1/2 way, Men turn Ladies 2H into
    diagonal line between 1M & 2L positions (Ladies BtoB)
13-16::
    1s+2s dance 1/2 diagonal reel of 4 with 1L ending in original place
    & 2L in partners original place (2s on Men''s side)
17-24::
    1s+2s dance R&L
25-32::
    1s+2s dance the Tournee :
::
    1s+2s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 2s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (2s RH, 1s LH) & dance
    out to places', 0);
INSERT INTO 'dancecrib' VALUES (9416, '2016-10-06 07:18:58.874776+00', '2023-02-04 01:22:44.89756+00', 17275, 3, NULL, 'ace', '1-8::
    2s turn RH & turn LH _while_ 1s & 3s chase clockwise back to place.
    1s & 2s end in centre ready for…
9-16::
    1s+2s dance Allemande
17-24::
    1s dance Figures of 8, 1L round 2s & 1M round 3s
25-32::
    1s+3s dance the Knot.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (15433, '2023-02-04 01:22:44.933807+00', '2023-02-04 01:22:44.93503+00', 21141, 3, NULL, 'ace', '1-4::
    1s+2s dance 1/2 R&L (2) (1) 3
5-8::
    2s+1s set, 2s cross LH _while_ 1s turn 3/4 LH to face 1st corners
9-16::
    1s+1st corners dance Corner Chain with setting:
::
    _9-12_    1s change places RH with 1st corners who turn LH in centre
    _while_ 1s set facing each other diagonally
::
    _13-16_  1s change places RH with 1st corners & 1s turn LH to face
    2nd corners
17-20::
    1s & 2nd corners dance Pass+Turn. 1s finish in 2nd place in centre
    RSh to partner facing own sides NHJ
21-24::
    1s 1/2 turn RH to face partner in centre & Petronella turn to 2nd
    place own sides
25-32::
    2s+1s+3s set, cast by RSh & chase clockwise once round', 0);
INSERT INTO 'dancecrib' VALUES (13096, '2020-08-10 00:21:33.284497+00', '2023-02-04 01:22:44.960069+00', 17609, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp side

1-8::
    1s & 4s set, turn partner RH; 1L followed by 1M casts behind Ladies''
    side to 4th place (Men''s side) _while_ 4L followed by 4M casts up
    behind Men''s side to 1st place (Ladies'' side).  4 2 (3) (1)
9-16::
    4s & 1s set, change places & repeat back to place _while_ 2s dance
    Fig 8 round 1st place & 3s dance Fig 8 round 4th place
17-24::
    2s+3s dance RH across; 4 couples turn partner RH to end 4s+2s facing
    up & 3s+1s facing down (on opp sides) in allemande hold
25-32::
    4s+2s allemande up (normal) _while_ 3s+1s allemande starting down.
    End 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (11713, '2019-03-18 21:02:57.106081+00', '2023-02-04 01:22:44.980811+00', 17469, 3, NULL, 'ace', '1-8::
    All set, 1M+2M Petronella-in-tandem & 3M casts _while_ 1L casts &
    2L+3L Petronella in Tandem to lines across (2L between 3s at top &
    2M between 1s), 2s dance 1/2 Diag R&L (up/down)
9-16::
    All set, 1M+2M Petronella-in-Tandem 3M casts _while_ 1L casts &
    2L+3L Petronella-in-Tandem (2M between 1s on Men''s side, 2L between
    3s on Ladies'' side), 2s dance 1/2 Diag R&L (across) (3L & 1M face
    out) (3)(2)(1)
17-24::
    3s+2s+1s dance reels of 3 on sides, each couple crossing down from
    2nd place to 3rd place on own side. At end 1s loop to face up & in 3
    2 1
25-32::
    2s+1s dance Rose Progression:
::
    _25-26_   2M+1L facing in diagonally set _while_ 2L+1M change places
    RH to face out
::
    _27-28_   2M+1L 1/2 turn 2H to face each other as 2L+1M dance into
    partners place
::
    _29-30_   2M+1L cast into each others place as 2L+1M 1/2 turn 2H to
    face each other
::
    _31-32_   2M+1L dance into 3rd/2nd place own side _while_ 2L+1M cast
    to right to new places   3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (12750, '2020-04-11 10:53:13.935609+00', '2023-02-04 01:22:45.012835+00', 15425, 3, NULL, 'ace', '1-8::
    1s dance Fig 8, 1M round 4s, 1L round 2s, 1L crossing ahead of 1M to
    begin, 1s ending in partner''s place
9-12::
    1s set, 1/2 turn 2H to end on sides facing in
13-16::
    1s+3s dance 1/2 R&L, (omit polite turn) & finish facing 2s+4s
17-24::
    1s+2M+4L, also 3s+2L+4M, dance reels of 4 across set (all pass
    corner RSh to start).  Bar 24 1s+3s join LH as they pass (Men polite
    turn)
25-28::
    1s+3s dance LH across 3/4 round to finish with 1s facing 4s & 3s
    facing 2s
29-32::
    1s & 3s pass 4s & 2s RSh, dance out and chase clockwise to places
33-40::
    1s+2s+3s+4s circle 8H round and back

{{explanation}}
Repeat with new couple leading (2s, 3s then 4s) When 2s and 4s lead, reels of 4 will be up/down set', 0);
INSERT INTO 'dancecrib' VALUES (15359, '2022-12-19 01:22:14.238069+00', '2023-02-04 01:22:45.054198+00', 13396, 3, NULL, 'ace', '1-8::
    1s set, cross RH & cast (2s step up); 1s 1/2 turn LH to end
    side-by-side, Lady facing up, Man down (LSh to partner)
9-12::
    1L+2L+3L also 1M+2M+3M dance RH across
13-16::
    1L dances out of top of set, 1M out of bottom & cast to 2nd place
    own sides to end in centre facing opp sides (LSh to partner) _while_
::
    2L+3L also 2M+3M change places RH & face in diagonally & set
17-20::
    1L+3s (at top) & 1M+2s (at bottom) dance RH across
21-24::
    1s dance out of opp sides & cast (1L up, 1M down) into lines of 3
    across (1L between 2s at top, 1M between 3s at bottom) _while_
::
    2s+3s 1/2 turn partner RH, face diagonally & set
25-32::
    All Advance, join hands briefly; all Retire; 1s turn 1.1/4 RH to 2nd
    place own side _while_ 3s & 2s chase clockwise 1/2 round.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14543, '2022-01-10 02:20:58.279415+00', '2023-02-04 01:22:45.079726+00', 17975, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance RSh reels of 3 on sides (1s RSh to 2s to start). 1L &
    2M face out
9-16::
    1s+2s change places dancing the »Maurice Progression«:
::
    _9-12_    1M+2L dance DoSiDo _while_ 1L+2M cast 1 place (1 bar) &
    Adv to centre & face partner (1 bar), Adv as partners Ret to form
    line on 1st corner diagonal ready for …
::
    _13-16_  1s+2s dance 1/2 Poussette.  End 2 1 3
17-20::
    1s dance 1/2 Fig 8 down round 3s finishing between 3s facing down,
    2s step in & face down on bar 20
21-24::
    1s join NH with 3s & 3M+1L+1M+3L join NH & dance down followed by
    2s. Bar 24: 3s dance in behind 1s & face up as 2s+1s face up
25-28::
    2s followed by 1s+3s dance up, 1s cast to 3rd place opp sides, 2s to
    1st place & 3s to 2nd place. 2 3 (1)
29-32::
    1s cross up to dance 1/2 Fig up round 3s. 2 3 1
33-36::
    2s+3s+1s set advancing, pass partner LSh, pull back RSh & curve back
    out to place
37-40::
    2s+3s+1s turn partner RH
41-48::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7549, '2013-08-21 08:31:43.077285+00', '2023-02-04 01:22:45.099284+00', 6431, 3, NULL, 'ace', '1-8::
    1L+2L also 3M+4M Adv+Ret for 2 steps, pass partner by LSh & cast to
    left (to change places)
9-16::
    1M+2M also 3L+4L Adv+Ret, pass opposite dancer by RSh & cast to
    right (all opposite partners in order 3 4 1 2)
17-24::
    All set, all circle 8H round to left 1/2 way & set
25-32::
    1s+4s+3s (bottom 3 couples) turn RH & dance up between 2s & cast to
    end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7550, '2013-08-21 08:31:43.445625+00', '2023-02-04 01:22:45.96678+00', 6432, 3, NULL, 'ace', '1-8::
    All set twice, turn partners 2H to end 1s & 2s facing up, 3s & 4s
    facing down (nearer hands joined), 1s & 4s cast in 1 pl _while_ 2s &
    3s lead up/down
9-16::
    2s+1s also 4s+3s dance double Fig of 8 (1s cross up & 4s cross down
    to start)
17-24::
    1s+4s Adv+Ret twice, lead up/down & cast to 2nd/3rd places
25-32::
    All dance Grand Chain
33-40::
    1s+4s+3s (bottom 3 couples) dance 1/2 reel of 3 on sides (1s & 4s
    pass RSh to start), 2s+3s also 4s+1s circle 4H round to left.  2 3 4
    1', 0);
INSERT INTO 'dancecrib' VALUES (13925, '2021-04-05 00:21:59.622748+00', '2023-02-04 01:22:45.997638+00', 14603, 3, NULL, 'ace', '1-8::
    1s+2s set & dance 1/2 RH across; 1s+3s set & dance 1/2 RH across.
    (2) (3) 1 4
9-16::
    Set+Link for 4 couples:
::
    _1-2_   All set
::
    _3-4_   3L+2L & 1L+4L Petronella in Tandem _while_ 2M+3M & 4M+1M
    cast in tandem to end in lines across 4L+1L+1M+4M facing down,
    2M+3M+3L+2L facing up
::
    _5-8_   Repeat 1-4 ending on sides. (4) (1) 3 2
17-24::
    4s+1s dance RH across; 4s+1s turn partner 1.1/2 RH remaining in
    middle facing up, 3s step in ready for …
25-32::
    4s+1s+3s dance Allemande.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (7551, '2013-08-21 08:31:44.263805+00', '2023-02-04 01:22:46.027408+00', 9940, 3, NULL, 'ace', '1-8::
    All set & 1s+2s also 3s+4s dance 1/2 RH across as 5s cross RH, all
    set & 2s+4s+5s cross RH as 1s+3s set Advg & turn about to face 1st
    crnr (pstn)
9-16::
    1s & 3s dance Pass+Turn with 1st corners & pass RSh to face 2nd
    corners, dance Pass+Turn with 2nd corner (pstn) & end facing 3rd
    corners (pstn)
17-24::
    1s & 3s dance ''Hello-Goodbye'' setting & end advancing to face
    opposite sides LSh to LSh
25-32::
    1s & 3s dance RH across (Lady up & Man down), 1s & 3s 3/4 turn LH &
    cast 1 place', 0);
INSERT INTO 'dancecrib' VALUES (7552, '2013-08-21 08:31:44.272289+00', '2023-02-04 01:22:46.050599+00', 9097, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 RH across, 1s+3s dance LH across once round, 2s+1s
    dance 1/2 RH across
9-16::
    1L followed by partner cast into centre below 3s, 1s dance up the
    middle & turn 2H to face 1st corners
17-24::
    1s turn corners 2H open out to circle 3H round with 1st & 2nd
    corners & turn 2nd corners 2H
25-32::
    1s dance reels of 3 on sides giving LSh to 1st corners & cross RH to
    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (11714, '2019-03-18 21:02:57.41374+00', '2023-02-04 01:22:46.063996+00', 8987, 3, NULL, 'ace', '{{explanation}}
5 person square set: 1 at top, 5 in middle facing 1

{{title}}
`	…..3

{{title}}
`	2…5…4

{{title}}
`	…..1

{{title}}
`	.TOP

1-8::
    _5_ dances Fig 8 round 1 & 3 passing 1 RSh to start
9-16::
    _2_+5+4 dance LSh reel of 3 across, 5 passing 4 LSh to start
17-24::
    _5_+1 turn RH (4 bars); 5+3 turn 1.1/2 LH (3 now in middle)
25-32::
    _3_ sets  _while_ 4+1+2+5 chase 1 place clockwise, face in & set;  3
    stands _while_ 2+5+4+1 Adv+Ret.  End 2 5 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8071, '2013-10-01 08:47:27.575021+00', '2023-02-04 01:22:46.090019+00', 14942, 3, NULL, 'ace', '1-8::
    1L followed by partner cast to 3rd place & cross to opposite sides
    as 4M followed by 4L cast to 2nd place, 4s+1s dance RH across
9-16::
    4L followed by 1L & 1M followed by 4M dance LSh alternating tandem
    reels on opposite sides
17-24::
    4s dance 1/2 Fig of 8 round 2s as 1s dance 1/2 Fig of 8 round 3s, 4s
    & 1s turn RH  2 4 1 3
25-32::
    2s+4s & 1s+3s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7553, '2013-08-21 08:31:44.281995+00', '2023-02-04 01:22:46.111021+00', 6443, 3, NULL, 'ace', '1-8::
    1s cross down below 2s & cast up to top; cross RH & set
9-16::
    2s cross up & cast down; cross RH & 1s+2s set
17-24::
    1s followed by 2s lead down the middle, 2s followed by 1s lead up to
    1st/2nd places
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7554, '2013-08-21 08:31:44.290208+00', '2023-02-04 01:22:46.136501+00', 6444, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, cross passing LSh & dance RSh round 1st corner
    to end in centre side by side - M facing up & L down
9-16::
    1s dance RH across with corners, turn LH 1.1/2 times _while_ corners
    dance clockwise 1/2 way
17-24::
    1s repeat above Fig & end facing 1st corners
25-32::
    1s dance ''Hello-Goodbye'' setting & end facing 3rd corners
33-40::
    1s dance reels of 3 (RSh to 3rd corner) on own sides & 3/4 turn LH
    to end in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (13442, '2020-12-02 01:21:57.481764+00', '2023-02-04 01:22:46.161845+00', 20137, 3, NULL, 'ace', '1-4::
    1s dance in & cast _while_ 3s dance 1/2 Fig 8 up round 2s (Bars:
    3-4: 1s are briefly following 3s dancing down sides)
5-8::
    1s meet below 2s NHJ, dance up & cast to 2nd place in centre facing
    up in prom hold (2s dance in & up to 1st place 7-8 _while_ 3s dance
    in left foot to face down in prom hold bar 8). 1s & 3s now BtoB in
    centre
9-12::
    1s & 3s dance 4 bars allemande  (1s up, 3s down) to change places,
    1s in 3M''s place facing down, 3s in 2L''s place facing up
13-16::
    3s+1s dance LH across.  End 3s in 3rd place own side, 1s facing 2nd
    corners
17-24::
    1s turn 2nd corner RH, partner LH, 1st corner RH, partner LH.  1s in
    2nd place own side face out
25-32::
    2s+1s+3s dance mirror reels of 3 on sides giving hands (1s down/out
    to start). 2 1 3

{{explanation}}
Note:	2nd time through 1s & 4s dance 6 bar reel & dance on 1 place to end 4s in 3rd place, 1s in 4th place.', 0);
INSERT INTO 'dancecrib' VALUES (13443, '2020-12-02 01:21:57.51362+00', '2023-02-04 01:22:46.18181+00', 17801, 3, NULL, 'ace', '1-8::
    1s dance down, out below 2s, behind 3s, down between 4s & cast up
    round 4s, dance up between 3s & behind 2s back to 1st place
9-16::
    1s+2s also 3s+4s dance reels of 4 across (1L/3L cast down, 2M/4M
    cast up, 1M+2L & 3M+4L pass LSh to start)
17-24::
    1s take prom hold & dance reel of 3 across with 2s (RSh to 2M). 1s
    end in centre 2nd place 2H joined, 3s step in ready for …
25-32::
    1s+3s dance Poussette
33-40::
    1s take prom hold & dance reel of 3 across with 4s (RSh to  4M). 1s
    end in 4th place own side
41-48::
    2s+3s+4s+1s circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7555, '2013-08-21 08:31:44.298388+00', '2023-02-04 01:22:46.200245+00', 6448, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast 1 place & turn LH to face 1st corners
9-16::
    1s dance RSh reel of 4 with 1st corners & end with a LH turn to face
    out to opposite sides between 2s+3s
17-24::
    1s dance Fig of 8 round 2nd+1st corners (LSh to 2nd corner to start)
    & turn LH to face 4th corner
25-32::
    1s dance reel of 4 with 4th corners & pass LSh to end Lady between
    2s & Man between 3s
33-40::
    1s dance reel of 3 across giving LSh to 1st corner & end in 2nd
    place own sides
41-48::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7556, '2013-08-21 08:31:44.306611+00', '2023-02-04 01:22:46.218078+00', 6451, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to 2nd place own side (2s step up
    3-4)
9-16::
    1s dance 1/2 LSh reels of 3 across, passing 1st corners LSh;
::
    1s dance 1/2 RSh reels of 3 on opposite sides (Man up, Lady down).1s
    end in 2nd place opp sides, all dancing loops into place
17-24::
    1s dance 1/2 LSh reels of 3 across (Man up Lady down);
::
    1s dance 1/2 RSh reels of 3 on own sides (Man down, Lady up). End 2
    1 3 4
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (11474, '2019-01-01 01:57:59.096732+00', '2023-02-04 01:22:46.513971+00', 18951, 3, NULL, 'ace', '1-8::
    All dance interlocking reels of 4 (RSh to partner)
9-16::
    Men dance into next Man''s place to right & all Rotate (2 PdeB ob
    spot pulling back RSh), Ladies dance into Ladies place to left & all
    Rotate
17-24::
    Couples in 1st & 3rd place dance 1/2 Ladies'' Chain; Couples in 2nd &
    4th place dance 1/2 Ladies'' Chain
25-40::
    All Balance (PdB forward & back with RH joined - no jeté) & dance
    Grand Chain 1/4 way.
::
    Repeat 3 more times', 0);
INSERT INTO 'dancecrib' VALUES (7557, '2013-08-21 08:31:44.550631+00', '2023-02-04 01:22:46.542712+00', 13137, 3, NULL, 'ace', '1-8::
    1s & 3s set, cast 1 place (2s & 4s step up); 1s & 3s dance 1/2 Fig
    of 8 (1s round 2s, 3s round 4s) to end 2 (1 )4 (3)
9-16::
    Ladies dance diagonal reel of 4 (2L+1L also 4L+3L pass LSh to
    start).  1L& 4L dance into place at end
17-24::
    Men dance diagonal reel of 4 (2M+1M also 4M+3M pass RSh to start).
    1M & 4M dance to place at end, 1M facing out
25-28::
    1M followed 1L dances behind 4L, across set to 4th place (1M facing
    clockwise) _while_ 3L followed by 3M dances up behind 4M across to
    2nd place (3L facing anticlockwise)
29-32::
    2s+3s dance LH across _while_ 4s+1s dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (14134, '2021-07-07 00:21:35.523579+00', '2023-02-04 01:22:46.5673+00', 6455, 3, NULL, 'ace', '1-8::
    1s cross RH & cast (2s step up); 1s cross LH, 1L casts up to end
    between 2s facing down, 1M casts down to end between 3s facing up
9-16::
    1s pass RSh & 1M+2s also 1L+3s dance RH across; 1s pass RSh to dance
    LH across with other couple & 1s end BtoB in centre facing own side
17-24::
    1s dance Double Triangles & end BtoB in centre facing own side
25-32::
    1s turn person on right RH (1M+2M, 1L+3L), pass RSh & turn person on
    left LH (1M+3M & 1L+2L). 1s end in 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13351, '2020-11-02 01:22:03.59633+00', '2023-02-04 01:22:46.5881+00', 16900, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s turn 1.1/2 LH
9-16::
    1L+2L+3L & 1M+2M+3M dance RH across; 1s turn 1.1/2 LH
17-24::
    1M followed by 1L dances out between 2L & 3L, cast right, dances
    across & out between 2M & 3M, casts up into centre 2nd place in prom
    hold (1L on 1M''s right) _while_ 2s+3s dance R&L. 2s face down, 3s
    face up NHJ
25-32::
    2s & 3s make arches, 1s dance down under arch made by 3s, divide,
    cast up, meet in prom hold, dance up under arch made by 2s, 1s cross
    & all  cast, 1s to 2nd place own side, 2s into 1st place, 3s cast up
    into 3rd place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12944, '2020-07-01 00:21:41.08595+00', '2023-02-04 01:22:46.611154+00', 19992, 3, NULL, 'ace', '1-8::
    1s+2s+3s+4s dance RSh reels of 4 on sides
9-16::
    1s+2s (also 3s+4s) dance Non-Progressive Tourbillon:
::
    _9-10_    1s+2s set
::
    _11-12_  1s+2s 1/2 turn 2H. Bar 12: 1M drops LH to dance to 2L''s
    place _while_ 1L dances to original place &  2L drops LH to dance in
    1M''s place _while_ 2M dances to original place
::
    _13-16_   Similar to bars 9-12 but turning person opposite 2H and
    moving on
17-24::
    1s+2s also 3s+4s dance Poussette
25-28::
    1s+2s also 3s+4s dance Progressive Set+Link for 2 couples:
::
    _25-26_   All set on sides
::
    _27-28_   Set+Link as normal except 1s & 4s link 2 places as 2s & 3s
    link to adjacent place
29-32::
    All turn partner RH.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13352, '2020-11-02 01:22:03.643657+00', '2023-02-04 01:22:46.638547+00', 20097, 3, NULL, 'ace', '1-8::
    2L sets to 1M, 2L dances Adv+Ret diagonally & sets _while_ 1M dances
    Adv+Ret diagonally to 2L & sets & casts down 1 place (2M steps up
    7-8)
9-16::
    2M sets to 1L, 2M Adv+Ret & sets _while_ 1L Adv+Ret & sets & casts
    down 1 place (2L steps up 15-16) 2 1 3
17-24::
    1s+3s dance double fig of 8 (1s cross down, 3s dance up to start)
25-32::
    1s dance reflection reels of 3 on the sides (1s in & up, 2s out &
    down to start)', 0);
INSERT INTO 'dancecrib' VALUES (7558, '2013-08-21 08:31:44.560486+00', '2023-02-04 01:22:46.672902+00', 8792, 3, NULL, 'ace', '{{explanation}}
5 person diamond set with 5th person in centre facing 1st person at top

1-8::
    _5_+1+2 dance RH across (3 bars), dance in & turn left about to
    dance LH across back to places
9-16::
    _1_+5+3 dance reel of 3 (1s+5s pass LSh to start)
17-24::
    _5_+1 set & 1/2 turn RH, 1+4 set & 1/2 turn RH
25-32::
    _4_+3 set & 1/2 turn RH, 3+2 set & 1/2 turn RH', 0);
INSERT INTO 'dancecrib' VALUES (8790, '2015-06-15 11:41:15.071103+00', '2023-02-04 01:22:46.728867+00', 16118, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up) turn 1st corners RH & finish facing 1st
    corners
9-16::
    1s dance 1/2  diag reel of 4 with 1st corners, pass LSh, dance 1/2
    diag reel of 4 with 2nd corners & turn 3/4 LH
17-24::
    1L+3s (at top) & 1M+2s dance RH across, 1s ending LSh to LSh in
    centre facing opp sides. 1s petronella turn to 2nd opp sides;
    3s+1s+2s set
25-32::
    3s+1s+2s turn partners RH 1/2 way, face partner, pull back RSh and
    dance out to own sides & 1s+2s dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (7561, '2013-08-21 08:31:44.598382+00', '2023-02-04 01:22:46.769841+00', 6461, 3, NULL, 'ace', '1-4::
    1s+3s set & chase clockwise 1/4 way
5-8::
    1s+3s dance 1/2 RH across & chase clockwise back to places _while_
    2s+4s set & chase anticl''wise 1/4 way into longways set  (1)(2) 4 3
9-16::
    All dance reels of 4s up/down
17-24::
    1s +2s & 4s+3s RH across, 2s+4s dance 1/2 LH across & chase
    anticlockwise back to orig places dancing into promenade hold
25-32::
    2s dance reel of 3 (up/down) with 1M+3L as 4s reels with 3M+1L & all
    end in original places
33-64::
    All repeat bars 1-32 but with 4s+2s leading  & reeling across set.
65-72::
    All Set+Link, dance Schiehallion reel 1/4 way (Ladies leading)
73-80::
    All Set+Link, dance Schiehallion reel 1/4 way (Men leading)
81-88::
    All dance 1/2 interlocking reels of 4 giving LH in centre & end
    turning partner RH to original places
89-96::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7560, '2013-08-21 08:31:44.579668+00', '2023-02-04 01:22:46.79987+00', 6460, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, 3/4 turn RH to face own sides & set turning
    right about to face 1st corners
9-16::
    1s dance reels of 3 on opposite sides (RSh to 1st corner) & end in
    2nd place own side facing out
17-24::
    1s dance reels of 3 across passing 4th corner LSh & end in 2nd place
    own side facing out
25-32::
    1s dance reels of 3 on own sides (RSh to 3rd corner) & end in 2nd
    place opposite side facing out
33-40::
    1s dance reels of 3 across passing 2nd corner LSh & end in middle
    facing 1st corners
41-48::
    1s turn 1st corners RH, passing RSh turn 2nd corner RH & pass RSh to
    2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7562, '2013-08-21 08:31:44.606704+00', '2023-02-04 01:22:46.882164+00', 6464, 3, NULL, 'ace', '{{explanation}}
Couples stand in 2 parallel sets facing partners with 1L & 2M, 3L & 4M, 5L & 6M BtoB

1-8::
    1M+3L+6M also 1L+4M+6L dance 1/2 diagonal reels of 3 (1M giving RSh
    to 3L & 4M RSh to 6L), 2L+4M+5L also 2M+3L+5M dance 1/2 reel of 3 on
    other diagonal (4M gives RSh to 2L & 3L gives RSh to 5M)
9-16::
    3s+4s dance reel of 4 across
17-24::
    All set to partners, 3s+6s also 1s+4s dance 1/2 RH across _while_
    2s+5s change places RH with partner, all set, 6s+2s also 5s+1s dance
    1/2 LH across _while_ 3s & 4s change LH with partner (now in order 3
    2 6 parallel with 1 5 4 with 1M+3L BtoB)
25-32::
    Middle dancers (1M+5M+4M+3L+2L+6L) dance 6H round & back
33-40::
    Middle couples cast to right & dance DoSiDo with partner, all change
    places RH with partner to end on opposite sides 3 2 6 parallel with
    1 5 4', 0);
INSERT INTO 'dancecrib' VALUES (7564, '2013-08-21 08:31:44.707433+00', '2023-02-04 01:22:46.973136+00', 10174, 3, NULL, 'ace', '1-8::
    1s+3s dance 1/2 R&L, set to partner & 1/2 turn RH to face out in
    prom hold
9-16::
    1s & 3s dance reels of 3 across (1s RSh to 4L & 3s RSh to 2L to
    start)
17-24::
    1s & 3s Promenade clockwise back to places _while_ 2s+4s dance 1/2
    R&L, 2s & 4s set to partner & 1/2 turn RH to face out in prom hold
25-32::
    2s & 4s dance reels of 3 up & down (2s RSh to 1L & 4s RSh to 3L to
    start)
33-40::
    2s & 4s Promenade clockwise back to places _while_ 1s+3s dance RH
    across, all set to partner & turn RH,
41-48::
    All set to corner & change places LH, set to next dancer & change
    places RH
49-56::
    Repeat bars 41-48 to end in opposite places
57-72::
    All dance full Schiehallion reels
73-80::
    All dance Grand Chain
81-88::
    All dance interlocking Reels of 4
89-96::
    All circle 8H round & back

{{explanation}}
Repeat in reel time', 0);
INSERT INTO 'dancecrib' VALUES (7565, '2013-08-21 08:31:44.718408+00', '2023-02-04 01:22:47.011828+00', 12901, 3, NULL, 'ace', '1-8::
    1s lead down the middle, lead up crossing & cast round 3s into 2nd
    place middle RSh to RSh (facing own sides)
9-16::
    1s turn 2s (Ladies LH & Men RH), 1s turn 3s (Ladies LH & Men RH)
    ending in middle RSh to RSh (facing opposite sides)
17-20::
    1s dance out b''tw''n 2s & 3s, cast round 1st corners (pstn) into
    middle RSh to RSh (1L facing down & 1M up) _while_ 2s & 3s cross RH
    & set
21-24::
    1s dance up/down & cast round 2nd corners (pstn) into middle RSh to
    (RSh facing own sides) _while_ 2s+3s change places LH on sides & set
25-28::
    1s dance out b''tw''n 2s & 3s, cast round 3rd corners (pstn) into
    middle RSh to RSh (1L facing up & 1M down) _while_ 2s & 3s cross RH
    & set
29-32::
    1s dance up/down & cast round 4th corners (pstn) 2nd place own sides
    _while_ 2s+3s change places LH on sides & set', 0);
INSERT INTO 'dancecrib' VALUES (12121, '2019-09-01 20:49:59.371148+00', '2023-02-04 01:22:47.169658+00', 19586, 3, NULL, 'ace', '1-8::
    All set & cross RH; all set & cross LH
9-16::
    1s set, cast 1 place (2s step up); 1s dance RH across, 1L with 2s,
    1M with 3s, finishing with 1s joining LH in centre of set
17-24::
    1s turn LH to own sides & cast 1 place (3s step up); 1s dance RH
    across, 1L with 3s, 1M with 4s, finishing with 1s joining LH in
    centre of set
25-32::
    1s turn LH to own sides & cast 1 place (4s step up); all turn
    partner RH', 3);
INSERT INTO 'dancecrib' VALUES (7566, '2013-08-21 08:31:44.732357+00', '2023-02-04 01:22:47.317198+00', 6471, 3, NULL, 'ace', '1-8::
    1M+2L turn RH & LH
9-16::
    1L+2M turn RH & LH to end in a diagonal line holding partners RH
17-24::
    Bal-in-Line twice, 1L+2M turn LH
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (7567, '2013-08-21 08:31:44.740549+00', '2023-02-04 01:22:47.347317+00', 6472, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s turn 1.1/2 RH to end in 2nd place opp
    sides (Man facing down Lady up)
9-16::
    2s+1s+3s dance reels of 3 on sides1s pass 1st corner RSh to start
17-24::
    1s set to & turn 1st corners; set to & turn 2nd corners, ending in
    2nd place opp sides
25-32::
    1s+2s+3s dance reels of 3 across (1M+2M & 1L+3L pass LSh to start).
    1s end BtoB in middle, 1M facing up, 1L facing down
33-40::
    1s dance Double Triangles, 1s end in 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (7568, '2013-08-21 08:31:44.750498+00', '2023-02-04 01:22:47.380403+00', 12534, 3, NULL, 'ace', '1-8::
    All dance reels of 4 on sides, (1s & 3s dancing in to start) with 1s
    crossing over at bottom to reel on opposite sides (1s end 1st pl opp
    side)
9-16::
    1s lead down & back crossing to face 2s at top (Man facing Man)
17-24::
    1s+2s dance reel of 4 across (1s end 2nd place own side) _while_
    3s+4s cross RH, chase clockwise 1/2 way & set
25-32::
    1M+3L change places RH, 1L+3M change places LH, 3s+1s cross RH & all
    set.
33-40::
    All circle 8H round & back.', 0);
INSERT INTO 'dancecrib' VALUES (11215, '2018-09-30 22:20:37.702192+00', '2023-02-04 01:22:47.417274+00', 18656, 3, NULL, 'ace', '1-8::
    1s dance in & cast (2s step up); 1s turn LH to face 1st corners
9-16::
    1s dance 4 bars "Hello-Goodbye" setting to face 2nd corners; 1s
    dance 1/2 diag reel of 4 with 2nd corners & finish facing 2nd corner
    pstn again (1s do not pass in centre)
17-24::
    1s dance 4 bars "Hello-Goodbye" setting to face 3rd corner pstn; 1s
    dance 1/2 diag reel of 4 & finish in 2nd place own side (1M face
    up/1L face down)
25-32::
    2s+1s+3s chase clockwise 1/2 round; all turn partners RH (2s & 3s
    once round, 1s turn 1.1/2)  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7569, '2013-08-21 08:31:44.758434+00', '2023-02-04 01:22:47.456392+00', 12904, 3, NULL, 'ace', '1-8::
    All set HS, petronella turn into middle & petronella turn to
    partner''s place
9-16::
    Repeat back to places
17-24::
    1s+2s turn RH, dance RH across & turn RH
25-32::
    1s dance down to bottom, all set & turn partners 2H', 0);
INSERT INTO 'dancecrib' VALUES (7570, '2013-08-21 08:31:44.774317+00', '2023-02-04 01:22:47.673692+00', 9417, 3, NULL, 'ace', '1-8::
    2s set, 2M casts up & 2L down to positions above/below 1s/3rd
    couples & dance RH across (2M with 1s & 2L with 3s)
9-16::
    2s set advancing down/up & turn 2H to end in centre 2M facing up &
    2L facing down & dance LH across (2M with 1s & 2L with 3s)
17-24::
    All dance the Knot ending 3 2 1
25-32::
    2s cross RH, cast down to bottom & dance 1/2 Fig of 8 round couple
    above (1s).  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7571, '2013-08-21 08:31:44.78446+00', '2023-02-04 01:22:47.704858+00', 6478, 3, NULL, 'ace', '1-8::
    1s dance RSh reels of 3 on own sides
9-16::
    1s set, 1/2 turn 2H, lead down LH, cross below 3s & cast to 2nd
    place own sides
17-24::
    1s dance towards 1st corner & turn RH, pass RSh & turn 2nd corner RH
    to end 1M between 2s & 1L between 3s to form lines across
25-32::
    2s+1s+3s advance (up/down) & retire, 1s turn RH to 2nd place own
    sides & 2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (7572, '2013-08-21 08:31:44.792626+00', '2023-02-04 01:22:47.732067+00', 9141, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH, slip step down 2 bars (2s step up), slip step up 2
    bars & dance down NHJ 2 bars to end BtoB facing 2nd place opposite
    sides
9-12::
    1s+corners set as Double Triangles, 1s face each other joining 2H
    with 2nd corners behind in »butterly hold« & set _while_ 1st corners
    change places RH
13-16::
    1M facing up, 1L down, set as Double Triangles, 1s face each other
    joining 2H with 1st corners behind in »butterly hold« & set _while_
    2nd corners change places RH
17-24::
    1s face own sides & set as Double Triangles, 1s dance 1/2 reel of 4
    with 1st corners (3rd corner pstn). 1M facing down, 1L facing up,
    set as Double Triangles
25-32::
    1s dance 1/2 reel of 4 with 2nd corners (4th corner pstn), 1s turn
    LH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (7573, '2013-08-21 08:31:44.800736+00', '2023-02-04 01:22:47.76785+00', 6481, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 3/4 R&L & set
9-16::
    1s & 3s petronella turn into middle & set, turn LH 1.1/4 times.
    2(1)4(3)
17-24::
    2s+1s also 4s+3s dance Men''s Chain
25-32::
    1s+3s dance 1/2 double Fig of 8 round 4s (1s cross down to start),
    1s lead down to 4th place _while_ 3s cast up to 2nd place & all set', 0);
INSERT INTO 'dancecrib' VALUES (9417, '2016-10-06 07:18:59.622472+00', '2023-02-04 01:22:47.796243+00', 17239, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross over RH & face clockwise and chase 1/2 way round
    set
9-16::
    1s+2s+3s set, cross over LH & face anticlockwise and chase 1/2 way
    round set back to places
17-24::
    1s turn RH, cast 1 place (2s step up 3-4), take nearer hands to
    dance down below 3s, cast up into 2nd place
25-32::
    1L with 2s at top also 1M with 3s, dance RH across, finish on
    sidelines.  2s+1s+3s turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (7574, '2013-08-21 08:31:44.808913+00', '2023-02-04 01:22:47.873655+00', 6484, 3, NULL, 'ace', '1-8::
    1s set, cross down RH & face partner, set & turn LH to face 1st
    corners
9-16::
    1s set to 1st corners, full turn corner RH to dance 1/2 diagonal
    reel of 4 with 1st corners & pass LSh to face 2nd corners
17-24::
    1s set to 2nd corners, full turn corner RH to dance a 1/2 diagonal
    reel of 4 with 2nd corners & into centre
25-32::
    1M dances RH across with 3s (in 1st place) & 1L dances with 2s, 1s
    end in 2nd place opposite sides & 2s+1s+3s chase clockwise 1/2 way', 0);
INSERT INTO 'dancecrib' VALUES (7575, '2013-08-21 08:31:44.822919+00', '2023-02-04 01:22:47.921621+00', 10756, 3, NULL, 'ace', '1-8::
    All set, 1L+2M also 3L+4M change places passing LSh, 1L+4M turn LH
    _while_ 2M+3L chase anticlockwise 1/2 way
9-16::
    All set, 1M+2L also 3M+4L change places passing RSh, 1M+4L turn RH
    _while_ 2L+3M chase clockwise 1/2 way
17-24::
    All circle 8H round & back
25-32::
    1s dance 1/2 Fig of 8 round 3s _while_ 4s dance 1/2 Fig of 8 round
    2s, 1s+4s dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (11216, '2018-09-30 22:20:37.783169+00', '2023-02-04 01:22:47.9539+00', 18668, 3, NULL, 'ace', '1-8::
    1s+2s 1/2 turn partners RH & dance RH across 1/2 way, 2s & 1s turn
    partners RH.  2 1 3
9-16::
    1s dance 1/2 reels of 3 across (Lady with 2s & Man with 3s) & 1/2
    reels of 3 on opposite sides
17-24::
    1s dance 1/2 reels of 3 across (Man up Lady down) & 1/2 reels on own
    sides & 1s end side by side facing down
25-32::
    1s dance down & cast up own side. 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (7576, '2013-08-21 08:31:44.938312+00', '2023-02-04 01:22:48.065024+00', 6489, 3, NULL, 'ace', '1-8::
    1M+2L lead down the middle & back ending in 2nd places opposite
    sides
9-16::
    1s+2s Adv+Ret, turn other partner RH to end with 1s in original
    places & 2s in 2nd place opposite sides
17-24::
    1s+2s Adv+Ret, turn own partners RH (2s turn 1.1/2 times) & end in
    middle for Poussette
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (13771, '2021-03-02 01:22:07.550496+00', '2023-02-04 01:22:48.09266+00', 12356, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    1s dance reels of 3 on own side (1s dancing in to begin)
17-24::
    1s followed by 2s+3s lead down the middle, 2s+3s divide & 1s
    followed by 2s+3s lead back up. 1s+2s stay in centre, 3s return to
    sides
25-32::
    1s+2s dance Allemande 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15153, '2022-10-05 00:22:09.948958+00', '2023-02-04 01:22:48.125879+00', 10849, 3, NULL, 'ace', '1-8::
    All cross RH. 3L & 1M dance clockwise to change places _while_
    others dance RH across
9-16::
    All cross LH. 1L & 3M dance anti-clockwise to change places _while_
    others dance LH across (3) 2 (1)
17-24::
    Meanwhile:
::
    3s Birl 1.1/2 moving down to 3rd place; separate & cast up to 1st
    place on own sides.
::
    2s cross down through 3rd place & cast up to 2nd place; Set & cross
    RH
::
    1s cast up to 1st place and Birl down to 3rd place 3 2 1
25-32::
    3s+2s dance a Chain progression:
::
    3s+2s 3/4 turn RH, 3M+2L turn LH 1.1/2 times as partners chase
    clockwise 1/2 way, 2s+3s turn 3/4 RH to end on sides in order 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (12653, '2020-03-02 01:54:21.359676+00', '2023-02-04 01:22:48.158292+00', 17043, 3, NULL, 'ace', '1-8::
    1s set, 1s+2s+3s Adv+Ret, 1s cast to 2nd place (2s step up)
9-16::
    1L+2s (at top) & 1M+3s (at bottom) dance RH across; 1s pass RSh to
    dance LH across with other couple
17-24::
    All step in (1 bar) to meet partner, 2s followed by 1s+3s lead up,
    cast (2s bar 20, 1s bar 21, 3s bar 22) & lead down to end 3 1 2 on
    own sides
25-32::
    3s+1s+2s dance 6 bars 1/2 Grand Chain (3s cross, 1s+2s change place
    on side to start) & all cross LH with partner.  2 1 3
33-40::
    All circle 6H all way round to Left, on bar 38 all pull back RSh &
    dance out to own sides.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14810, '2022-05-05 00:21:59.46528+00', '2023-02-04 01:22:48.332507+00', 17119, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across & LH across back to place
9-12::
    1s+3s - Men pull back RSh, Ladies pull back LSh & dance 1/2 round
    set, Men give RH to Ladies as they pass and turn partner RH into
    place _while_ 2s & 4s Adv+Ret
13-16::
    2s+4s - Repeat 9-12 _while_ 1s+3s Adv+Ret.  3 4 1 2
17-24::
    All dance RH across  (Ladies join RH in centre, LH with partner) &
    LH across (Men join LH in centre, RH with partner)
25-32::
    All set advancing into centre NHJ with partner & retire with corner;
    all turn corner twice 2H, flowing into …
33-40::
    All circle 8H round & back. 3 4 1 2

{{explanation}}
Repeat from new positions', 0);
INSERT INTO 'dancecrib' VALUES (7577, '2013-08-21 08:31:44.946642+00', '2023-02-04 01:22:48.363268+00', 6492, 3, NULL, 'ace', '1-8::
    1s cross RH to 2nd pl (opp sides), set to each other & turn R to
    BtoB position, set as in Double triangle & turn 2s into centre (1s
    behind them)
9-16::
    2s cross below 3s & dance Fig of 8 round 3s to end in 1st place (own
    sides) as 1s dance down, cast to 2nd pl & turn RH to face 1st crnrs
17-24::
    1s dance ''Hello-Goodbye'' setting, 1s change places RH to face 4th
    corners
25-32::
    1s dance RSh reels of 3 across to 2nd place opposite sides & cross
    RH', 0);
INSERT INTO 'dancecrib' VALUES (7578, '2013-08-21 08:31:44.952901+00', '2023-02-04 01:22:48.414637+00', 7970, 3, NULL, 'ace', '1-8::
    1s set to 2s & cross down to 2nd place to face 3s, 1s set to 3s &
    turn 3s (1s dancing between 3s to start)
9-16::
    1s dance reflection reels of 3 on opposite sides (1s dancing up
    between 2s to start) & end turning partner LH to face 1st corners
17-24::
    1s dance 1/2 Reel of 4 with 1st corners & 1/2 reel of 4 with 2nd
    corners 1s end in 2nd place opp side.  (3)(1)(2)
25-32::
    All set & 1s cast up to 1st place as 3s step down to face 2s, all
    dance Grand Chain 1/2 way (1s start giving RH to partner.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (9758, '2017-04-06 08:40:19.729888+00', '2023-02-04 01:22:48.440611+00', 8166, 3, NULL, 'ace', '1-8::
    1s Adv+Ret 2 steps. 2s repeating on bar 3, 3s repeat on bar 5 & 4s
    repeat on bar 7
9-16::
    _While_ 4s complete their Adv+Ret, 1s start a Snowball Grand Chain
    to end 3(2)4(1)
17-24::
    3s+2s & at the same time 4s+1s dance Ladies'' Chain
25-26::
    3s cross RH,
27-28::
    3s+2s dance RH across 1/2 way (2 bars) _while_ bars 27-30 4s turn RH
    for 4 bars
29-32::
    1s turn 1.1/2 times for 4 bars  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7581, '2013-08-21 08:31:44.980137+00', '2023-02-04 01:22:48.524055+00', 10473, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH, cast 1 place, cross LH & Ladies casts up & Men
    down for reels of 3 at ends & reel of 4 in centre (1M+3L pass LSh)
9-16::
    All dance reels across 1s & end facing partner up/down set
17-24::
    1s & 3s set, petronella turn to 2nd/4th place opposite sides, set &
    1/2 turn RH for Poussette (4s+5s step in)
25-32::
    1s+4s & 3s+5s dance Poussette to end 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (7582, '2013-08-21 08:31:44.988328+00', '2023-02-04 01:22:48.559573+00', 13446, 3, NULL, 'ace', '1-8::
    1s dance down below 3s & cast up to 2nd place; 2s+1s+3s set & 1/2
    turn partner RH to end facing down in Allemande hold
9-16::
    2s+1s+3s dance Allemande (down to start).  (3)(1)(2)
17-24::
    3s+1s+2s dance 1/2 reel of 3 with 3s & 1s crossing down from top; 2s
    turn RH 1.1/2 times _while_ 1s+3s turn on sides (Men LH, ladies RH)
    2 1 3
25-32::
    2s+1s+3s circle 6H round & back

{{explanation}}
Note: dance included in Inverness Diamond Jubilee Collection with the title "The Telford Hornpipe"  The deviser''s preferred title is "Away Tae Moray"', 0);
INSERT INTO 'dancecrib' VALUES (13354, '2020-11-02 01:22:04.81651+00', '2023-02-04 01:22:48.589656+00', 14527, 3, NULL, 'ace', '{{explanation}}
2s start on opp sides

1-8::
    1s+2s dance R&L. Men end facing out
9-12::
    1s+2s dance 1/2 Ladies'' Chain ending in line across, Ladies RH
    joined
13-20::
    1s+2s dance ''The Targe'':
::
    _13-14_   Ladies 3/4 turn RH _while_ Men dance 1/4 way round
    anticlockwise
::
    _15-16_   Men turn partner once round LH
::
    _17-18_   Repeat 1-2
::
    _19-20_   Men turn partner 3/4 LH onto side lines (1s on Ladies''
    side, 2s on Men''s side)
21-24::
    1s+2s dance 1/2 Ladies'' Chain. 2 (1) 3
25-32::
    RSh reels of 3 on sides, 1s dance down passing 3s RSh to start
33-56::
    1s+3s repeat 1-24 but with Men & Ladies swapped over i.e. R&L Ladies
    face out; Ladies Chain with Men crossing RH to start, etc
57-64::
    RSh reels of 3 on sides, 3s dancing up passing 2s at top RSh to
    start.  End 2 (3) 1', 0);
INSERT INTO 'dancecrib' VALUES (6008, '2013-08-21 08:31:17.954297+00', '2023-02-04 01:22:48.707005+00', 3562, 3, NULL, 'ace', '{{explanation}}
2 couples facing 2 couples in lines of 4 across, Ladies on partners right, 1s on right of 2s & 1s face 3s as 2s face 4s

1-8::
    1s+4s dance RH across & LH back to places
9-16::
    2s+3s repeat above Fig
17-24::
    All 4 couples set to partner twice & turn 2H
25-32::
    All 4 couples slip step across (Men pass BtoB) & back to places
    (Ladies BtoB)
33-40::
    1s+3s also 2s+4s circle 4H round to left & LH across back to places
41-48::
    All 4 couples Advance 2 steps & Retire 1 step, clap 3 times, 1s+2s
    dance under 3s+4s arms to face next 2 couples', 0);
INSERT INTO 'dancecrib' VALUES (8850, '2015-08-13 20:34:09.857875+00', '2023-02-04 01:22:48.726378+00', 13126, 3, NULL, 'ace', '{{explanation}}
Square set:  5M in centre with back to 3s, 5L with back to 1s

1-8::
    5M dances between 1s, 5L between 3s & they chase clockwise 1/2 round
    set & back into centre (5M thro'' 3s, 5L thro'' 1s) _while_ 2s & 4s
    set, turn prtnr RH, set, turn LH
9-16::
    5s Tulloch Turn _while_ 1s+2s+3s+4s dance interlocking reels of 4
    round set
17-24::
    5M+4M+1L also 5L+2M+3L set as Double Triangles, 5s pull back RSh
    dance 1/4 round to right. 5M+1M+2L also 5L+3M+4L set as Double
    Triangles.  5s finish in centre facing 1s
25-40::
    5s+1s dance 1/2 R&L, then 1s+2s, 2s+3s etc 1/2 R&L until 4s in
    centre', 0);
INSERT INTO 'dancecrib' VALUES (11090, '2018-09-09 19:56:15.511367+00', '2023-02-04 01:22:48.75057+00', 18566, 3, NULL, 'ace', '1-8::
    1L+2M also 3L+4M cross RH & set, 1M+2L also 3M+4L cross RH & set
9-16::
    2s+1s also 4s+3s dance 1/2 R&L, 1s lead cross down below 3s & cast
    to 2nd place opposite sides
17-24::
    1s dance 1/2 Reflection reels of 3 on sides (1s in & up to start),
    1s with LH joined lead down, cross below 4s & cast up to 3rd place
    own sides
25-32::
    1s dance 1/2 Reflection reels of 3 on own sides (1s in/up to start),
    1M+2M also 1L+2L set to each other & change places LH  3 4 2 1', 0);
INSERT INTO 'dancecrib' VALUES (7583, '2013-08-21 08:31:45.032455+00', '2023-02-04 01:22:48.771549+00', 12450, 3, NULL, 'ace', '1-8::
    1s cross RH & cast to bottom, dance ''High 5'' & cast back to places
9-16::
    All dance DoSiDo twice
17-24::
    All dance down middle, 1s make an arch & 2s+3s+4s dance up.  2 3 4 1
25-32::
    2s+3s also 4s+1s dance RH across & LH back', 0);
INSERT INTO 'dancecrib' VALUES (15434, '2023-02-04 01:22:48.801382+00', '2023-02-04 01:22:48.803051+00', 18285, 3, NULL, 'ace', '1-8::
    1s+4s cross RH, set, cross back LH & set (1 bar across, then turning
    to face next couple)
9-10::
    1s facing 2s & 3s facing 4s, change places RH
11-16::
    1s facing 4s set (1 bar up/down, 1 bar facing across), 1s+4s cross
    LH & set. 2 (1) (4) 3
17-24::
    2s+1s also 4s+3s dance RH across; 1s+4s dance LH across
25-28::
    1s+4s dance RSh round nearest corner (1L round 2M, 1M round 2L, 4L
    round 3M, 4M round 3L)
29-32::
    4s+1s dance 1/2 RH across & set.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7584, '2013-08-21 08:31:45.040888+00', '2023-02-04 01:22:48.831985+00', 10601, 3, NULL, 'ace', '1-8::
    1s & 2s turn 2H (2 bars) into 4H round to left & turn partners 2H
9-16::
    1s+2s dance Diamond Poussette
17-24::
    1s+2s dance the Knot with 1M ending on Ladies side (L on M''s on
    right) in "Backwards Prom hold" (LH normal & Mans RH behind Ladies
    back)
25-32::
    1s (in back-prom-hold) dance 1/2 Fig of 8 round 2M (LSh), dance up
    to top, split & cast to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7585, '2013-08-21 08:31:45.050792+00', '2023-02-04 01:22:48.942465+00', 6505, 3, NULL, 'ace', '1-8::
    1s turn RH 2.1/2 times ending on opposite sides
9-16::
    1s+2s turn LH 1.1/2 times on sides & dance 1/2 Ladies'' Chain ending
    1s in top place Ladies'' side & 2s in 2nd place Men''s side ready for…
17-24::
    1s+2s dance modified Poussette: 2 bars to cross to sides, 1 bar 1/4
    turn,1 bar progress up/down & 1/4 turn, 1 bar into centre, 1 bar 1/2
    turn, 2 bars retire to sides', 0);
INSERT INTO 'dancecrib' VALUES (7586, '2013-08-21 08:31:45.059155+00', '2023-02-04 01:22:48.970204+00', 6506, 3, NULL, 'ace', '1-8::
    All set to partners & dance 1/2 Grand Chain, turn partners RH to end
    Ladies in centre facing partners
9-16::
    Ladies pass partners RSh & dance round clockwise to original places
    to meet ''new'' partner
17-24::
    All circle 8H round & back
25-32::
    Men dance RH across 1/2 way, all turn original partners LH, 1/2 turn
    corners LH & face in diagonally with corner
33-40::
    1M+3M with corners Adv+Ret, 2M+4M with corners dance 1/2 R&L (end
    facing corner in 2 diagonal lines between corner''s partners)
41-48::
    All dance diagonal reels of 4 (LSh to corner to start)
49-56::
    1M & 3M followed by their corners dance clockwise round outside to
    next corner position _while_ 2M & 4M with corners dance LH across
    3/4 way to face original partners in 2 diagonal lines, all change
    places with partners RH to face in on sides & set
57-64::
    1L followed by 1M+4L+4M cast & dance clockwise to original pstns
    _while_ 3L followed by 3M+2L+2M cast & dance clockwise to original
    pstns, all turn partners RH

{{explanation}}
Repeat in reel time but omit setting on bars 1-2, dancing half Grand Chain in six bars', 0);
INSERT INTO 'dancecrib' VALUES (9932, '2017-06-05 11:31:51.211902+00', '2023-02-04 01:22:49.003103+00', 17741, 3, NULL, 'ace', '{{explanation}}
 2 chords - 2nd chord 3s & 4s cross to opp sides

1-8::
    All set.  1s+2s also 3s+4s dance 3/4 double Figs 8 (1s & 4s cast, 2s
    & 3s cross up/down).  All finish on sides facing in.  2 (1) 4 (3)
9-16::
    1s+4s dance 1/2 RH across, turn corner LH (4s+2s, 1s+3s).  4s+1s
    dance 1/2 RH across, turn corner LH (1s+2s, 4s+3s). 1s & 4s take
    prom hold with partner & face
17-18::
    1s+4s set Advancing, pass LSh to face »corners« on diagonal (4s+2M
    at top, 1s+3M at bottom)
19-24::
    RSh promenade reels of 3 across (4s+2s, 1s+3s).  End 4s facing 1s in
    centre (4s face down 1s face up)
25-32::
    4s+1s dance RH across, dance out of end (4s at top, 1s at bottom)
    cross & cast to 2nd/3rd place.  End 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (8705, '2015-03-03 08:48:07.252337+00', '2023-02-04 01:22:49.11972+00', 16052, 3, NULL, 'ace', '1-8::
    2s & 3s turn RH, 2s & 3s cast to ends _while_ 1s+4s cross RH down/up
    1 place to face each other up/down as 2s & 3s face partner across &
    all set
9-16::
    1s & 4s facing up/down dance 6 bars of R&L (starting on sides)
    ending on own sides facing up/down & set to 2s/3s
17-24::
    2s+1s also 4s+3s dance RH across & LH back
25-32::
    1s+4s dance RH across & LH back
33-40::
    1L+4L also 1M+4M Set+Link, 1s & 4s dance DoSiDo.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14544, '2022-01-10 02:21:00.519854+00', '2023-02-04 01:22:49.157736+00', 19771, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 up round 2s
9-16::
    Mirror reels of 3 on sides (1s in/down, 2s cast to start) 2s & 3s
    loop into place at end, 1s finish facing 1st corners
17-24::
    1s dance Corner Pass+Turn with 1st corners (corners turn 2H), pass
    RSh & dance Corner Pass+Turn with 2nd corners. 1s pass RSh at end,
    to 2nd place, 1M curving into place facing in ready for …
25-32::
    1s+3s dance Espagnole:
::
    _25-26_   1s+3s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _27-28_   1s+3s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _29-32_   3s turn RH as 1s turn LH to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7587, '2013-08-21 08:31:45.091432+00', '2023-02-04 01:22:49.187617+00', 10941, 3, NULL, 'ace', '1-8::
    1M & 2L also 3M & 4L cross & cast RSh to change places, 1s+2s also
    3s+4s dance RH across
9-16::
    1L & 2M also 3L & 4M cross & cast LSh round opposite person to
    change places, 2s+1s also 4s+3s dance LH across
17-24::
    All set to partners & turn 2H to 2s/4s facing down & 1s/3s facing
    up, 2s+1s also 4s+3s circle 4H round to left
25-32::
    All dance reels of 4 on sides but at the end 1s & 4s do not pass LSh
    to finish 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9418, '2016-10-06 07:18:59.887597+00', '2023-02-04 01:22:49.217886+00', 17148, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast (2s step up 5-6), & 1s turn 3/4 RH to
    diagonal line joining LH with 2nd corners, RH with partner
9-16::
    1s dance ''The Spoke'' with 2nd, 1st, 4th & 3rd corner but 1s set on
    spot bars 15-16
17-24::
    Reels of 3 across, 1M+2s (1M+2L pass RSh) & 1L+3s (1L+3M pass RSh).
    1s pass RSh to 2nd place opp side in middle BtoB facing out
25-32::
    2s+1s+3s dance 4 bars ''Double Triangles'' with 1s petronella turn to
    2nd place own sides (4 bars).  All turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (13926, '2021-04-05 00:22:02.171057+00', '2023-02-04 01:22:49.419441+00', 6515, 3, NULL, 'ace', '1-8::
    1s clap 3 times & cast to 2nd place (2s step up). 2s clap 3 times &
    cast one place to face up (1s step up & face down)
9-12::
    1M+2M also 1L+2L turn RH, 1s+2s turn partner LH
13-16::
    1s+2s repeat bars 9-12
17-24::
    1s dance down the middle & back
25-32::
    1s+2s Adv+Ret; 1s+2s turn partner RH, 1s cast _while_ 2s dance up
    the middle to top', 0);
INSERT INTO 'dancecrib' VALUES (7588, '2013-08-21 08:31:45.099649+00', '2023-02-04 01:22:49.439173+00', 6518, 3, NULL, 'ace', '1-8::
    1s lead down the middle for 3 steps, back to top & cast to 2nd
    places
9-16::
    2s repeat bars 1-8
17-24::
    1M+2M cross between 1L+2L & cast round partner back to places, 1L+2L
    repeat
25-32::
    1s+2L dance a diagonal reel of 3, 1s giving RSh to start
33-40::
    1s+2M dance a diagonal reel of 3, 1s giving LSh to start
41-48::
    1s+2s set, cross RH & dance 1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (11475, '2019-01-01 01:58:00.053117+00', '2023-02-04 01:22:49.458188+00', 6520, 3, NULL, 'ace', '{{explanation}}
5 couples arranged in a circle, Lady on Man''s right

1-8::
    All circle 10H round and back
9-16::
    All set twice, pulling back RSh (bar 11) to face out; All dance out
    (2 bars) then dance towards and face partner
17-24::
    All set twice to partner, all Adv+Ret
25-32::
    All dance DoSiDo with partner,  turn partner 1.1/4 RH into promenade
    hold facing anticlockwise (Men on inside)
33-48::
    All promenade anticlockwise once round (12 bars) ending in original
    circle
49-56::
    Ladies join RH in centre, LH with partner & dance RH across (6
    bars), Bar 55 Men cross Lady in front to original places but Lady on
    Man''s left
57-64::
    All turn partners 1.1/2 RH; all turn partner LH to original places
::
    Repeat 1 more time', 0);
INSERT INTO 'dancecrib' VALUES (7589, '2013-08-21 08:31:45.107644+00', '2023-02-04 01:22:49.480657+00', 13473, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 round 2s
9-16::
    1s cross down to dance reels of 3 on opposite sides
17-24::
    1s cross down to dance reels of 3 on own sides
25-32::
    1s dance down between 3s & cast up to 2nd place, 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (7590, '2013-08-21 08:31:45.11798+00', '2023-02-04 01:22:49.696416+00', 9478, 3, NULL, 'ace', '1-8::
    1s set & cross to 2nd place _while_ 2s cross RH & cast up, 2s+1s
    dance double 1/2 Fig of 8 (1s cast)
9-16::
    2s+1s+3s dance Grand Chain
17-24::
    2s+1s+3s circle 6H round to left, pivot & chase back to places
25-32::
    1s dance reels of 3 across (Lady with 2s & Man with 3s)', 0);
INSERT INTO 'dancecrib' VALUES (10103, '2017-09-03 23:45:30.34975+00', '2023-02-04 01:22:49.71956+00', 6522, 3, NULL, 'ace', '1-8::
    1s dance down below 2s & cast up to place, 1s+2s turn RH into prom
    hold
9-16::
    1s+2s Promenade
17-24::
    1s dance down below 3s, cast up 1 place, dance up between 2s & cast
    to 2nd place
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10104, '2017-09-03 23:45:30.357174+00', '2023-02-04 01:22:49.750201+00', 6521, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L ending with 1M & 2L facing out (no polite turn)
9-16::
    Reels of 3 on sides, 2s+3s pass RSh to start
17-24::
    1s cross RH, cast as 2s dance up to top.  2s cast as 1s cross up to
    top place own side.  1s 1/2 turn 2s (Men LH, Ladies RH)
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8851, '2015-08-13 20:34:09.969142+00', '2023-02-04 01:22:49.794872+00', 14282, 3, NULL, 'ace', '1-8::
    1L+1M+2M dance RH across (Men''s side); 1M+1L+2L dance LH across
    (Ladies'' side)
9-16::
    1s+2s dance 1/2 R&L.  1M+2L cross RH & set _while_ 1L+2M set & cross
    RH
17-24::
    1s dance Fig 8 round 2s, stay in centre facing up, 2s step in for
    ...
25-32::
    1s+2s Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7592, '2013-08-21 08:31:45.134946+00', '2023-02-04 01:22:49.93243+00', 6523, 3, NULL, 'ace', '1-8::
    1s cast down behind own lines & cast back up to places
9-16::
    1s cross down (passing RSh), 1M turns 2L RH 1.1/2 times as 1L turns
    2M RH 1.1/2 times to end in 2nd pl opp sides: 1M turns 3L LH as 1L
    turns 3M LH, 1s end facing 1st crnrs
17-24::
    1s dance ''Hello-Goodbye'' setting & set to partner turning about to
    1M facing up & 1L down
25-32::
    1s dance reel of 3 on sides (giving RSh to 2nd corner) & cross RH to
    places', 0);
INSERT INTO 'dancecrib' VALUES (9419, '2016-10-06 07:18:59.937644+00', '2023-02-04 01:22:49.960582+00', 17134, 3, NULL, 'ace', '1-8::
    1s dance in & cast 2 places (2s+3s step up bars 3-4). 1s set, lead
    up to face 1st corners (3s step down bars 7-8)
9-16::
    1s+1st corners dance Corners Pass+Turn, 1s pass RSh & repeat with
    2nd corners, 1s finish passing RSh to 2nd place own sides
17-24::
    2s+1s+3s set, pull back RSh, dance 2 steps clockwise into circle 6H
    round to left to own sides  2 1 3
25-28::
    1s+3s dance RH across finishing in middle NHJ facing up
29-32::
    1s cast to 3rd place _while_ 3s dance up, curving into 2nd place.
    3s+1s set', 0);
INSERT INTO 'dancecrib' VALUES (7285, '2013-08-21 08:31:38.388187+00', '2023-02-04 01:22:49.988977+00', 12568, 3, NULL, 'ace', '1-8::
    1s dance Figs of 8 on sides (dance between 2s to start) giving hands
9-16::
    1s+2s+3s dance reels of 3 on sides (1s dance between 2s to start)
17-24::
    1s+2s dance double Figs of 8 (2s casting to start)
25-32::
    1L+2L turn LH 1.1/2 times _while_ 1M+2M turn RH 1.1/2 times, 1L+3L
    turn RH 1.1/2 times _while_ 1M+3M turn LH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (3884, '2013-08-21 08:30:38.306593+00', '2023-02-04 01:22:50.0285+00', 6532, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All dance interlocking Reels of 4
9-12::
    1s & 3s 3/4 turn RH & prom clockwise 1/2 round to opp side _while_
    2s & 4s & Petronella turn & set
13-16::
    1s & 3s dance 1/2 RH across in centre back to places as 2s & 4s
    Petronella turn to partners original place & change places RH
17-24::
    Repeat with 2s & 4s promenading _while_ 1s & 3s dance petronella
    turns
25-32::
    All circle 8H round & back
33-40::
    All set to partner & turn RH & set to corners & turn LH
41-56::
    All dance full Schiehallion Reel
57-64::
    All turn partner RH, corner LH, partner RH & corner LH

{{title}}
Reel

1-64::
    Repeat in Reel time but end by turning partners only RH & LH', 0);
INSERT INTO 'dancecrib' VALUES (3885, '2013-08-21 08:30:38.317983+00', '2023-02-04 01:22:50.085291+00', 7333, 3, NULL, 'ace', '1-8::
    1s set, petronella turn into centre, taking 2H dance down 1 place
    (Man backwards) & face opposite sides
9-16::
    1s set as Double Triangles & dance 1/2 reels of 3 on opp sides (RSh
    to 1st crnr) to end turning 2nd crnr (pstn) LH as 1st crnrs (pstn)
    change pl RH
17-24::
    1s dance 1/2 reels of 3 across (RSh to 3rd corner pstn) & passing
    LSh dance 1/2 diag reel of 4 with 1st corner (pstn) to end LH to
    prtnr & RH to 1st crnr
25-32::
    1s Bal-in-Line with 1st corners & Bal-in-line with 2nd corners, 1s
    turn LH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (7593, '2013-08-21 08:31:45.175896+00', '2023-02-04 01:22:50.157386+00', 9014, 3, NULL, 'ace', '1-8::
    1s cross down (each couple cross down as they reach top place) to
    dance reels of 4 on sides
9-16::
    1L+2M also 3L+4M set & change places RH, 1M+2L also 3M+4L set &
    change places LH.  2 1 4 3
17-24::
    2s+1s also 4s+3s dance Diamond Poussette
25-32::
    1s & 3s 1/2 turn 2H & dance up to top & cast on opposite sides (1s
    to 4th place & 3s to 2nd place), 1s & 3s cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (14165, '2021-07-22 09:47:04.045259+00', '2023-02-04 01:22:50.192107+00', 6536, 3, NULL, 'ace', '{{explanation}}
Round the Room 2 facing 2

1-8::
    All set NHJ with partner, Ladies change places RH; all set NHJ with
    ''new partner'' & Men change places RH
9-16::
    All dance RH across once round, turn partners RH to end Men
    back-to-back facing partners
17-24::
    All dance diagonal RSh reel of 4, Men ending beside partner facing
    next couple
25-32::
    All dance R&L with new couple', 0);
INSERT INTO 'dancecrib' VALUES (10105, '2017-09-03 23:45:30.489617+00', '2023-02-04 01:22:50.223394+00', 6540, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig 8 round 2s.  1s+2s dance1/2 R&L
9-16::
    1s+2s dance Ladies'' Chain
17-24::
    1M+2L also 1L+2M set, turn RH (2 bars). 1s+2s set to partners &
    cross LH, 1s end facing 1st corners
25-32::
    1s turn 1st corner RH, partner LH, 2nd corner RH & cross LH to own
    side 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (7594, '2013-08-21 08:31:45.186165+00', '2023-02-04 01:22:50.329347+00', 6539, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & 1s cast to 2nd place, 1s+3s dance LH across
    & 1s cast to 3rd place
9-16::
    1s set, lead up to top, cast to 2nd place & turn RH to end facing
    1st corners
17-24::
    1s dance RSh round 1st corner, dance round partner LSh, dance round
    2nd corner RSh & turn partner LH to face 1st corner again
25-32::
    1s dance ''Hello-Goodbye'' setting turning RH to places', 0);
INSERT INTO 'dancecrib' VALUES (7595, '2013-08-21 08:31:45.194496+00', '2023-02-04 01:22:50.36052+00', 11829, 3, NULL, 'ace', '{{explanation}}
4 dancers in square numbered clockwise from 1M position

1-8::
    _1_ & 4 dance 1/2 Fig of 8 round 2/3 (4 passing in front of 1) to
    change places & dance 1/2 R&L (up/down to start) to end 3 1 4 2
9-16::
    _3_+1 also 2+4 Set+Link & continue turn to end in line of 4 up/down
    & dance 1/2 reel of 4 to end 2 4 3 1 up/down set
17-24::
    All set advancing towards & pass facing person, 2+1 turn 3/4 2H
    _while_ 4+3 dance clockwise 1/4 to form line of 4 across, all set
    advancing towards & pass facing person, 3+4 turn 3/4 2H _while_ 2+1
    chase clockwise 1/4 to end 2 4 3 1 up/down set
25-32::
    _2_+4 also 3+1set & 3/4 turn 2H to end with 2+4 at top facing up &
    3+1 facing down, all dance in & cast to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7596, '2013-08-21 08:31:45.202731+00', '2023-02-04 01:22:50.394963+00', 10775, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across & turn partners RH to face up in prom
    hold
9-16::
    1s+2s dance Allemande but 1s end turning LH in centre to Lady facing
    up & Man down
17-24::
    1s dance RH across (Lady with 2s, Man with 3s & end 2nd place own
    sides), 1s dance 1/2 reels of 3 on sides (giving LSh to 3rd corner)
25-32::
    1s dance 1/2 reels of 3 across (Lady with 3s at top & Man with 2s)
    into 1/2 reels of 3 on opposite sides to end 2 1 3 all on opp sides

{{explanation}}
Repeat with the set reversed ie. the new 1st couple is the couple at the other end of the set & reverse after each 32 bars', 0);
INSERT INTO 'dancecrib' VALUES (7597, '2013-08-21 08:31:45.212693+00', '2023-02-04 01:22:50.436089+00', 6541, 3, NULL, 'ace', '1-8::
    1M dances round partner RSh back & turns partner 2H
9-16::
    1M+2M dance round partners RSh & 1s+2s circle 4H round
17-24::
    1s followed by 2s dance down for 3 bars, 2s followed by 1s dance up
    (2s cast to 1st pl), 2s+1s also 3s+4s set facing on sides.  2 1 3 4
25-32::
    All dance RSh reels of 4 on sides
33-40::
    1s dance up to top & cast to 4th place & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (7598, '2013-08-21 08:31:45.2224+00', '2023-02-04 01:22:50.540148+00', 6552, 3, NULL, 'ace', '1-8::
    1s petronella to opposite side
9-16::
    1s petronella to 2nd place own side
17-24::
    2s+1s+3s Adv+Ret twice
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14228, '2021-08-14 00:22:10.809772+00', '2023-02-04 01:22:50.571059+00', 15479, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1L+2s & 1M+3s dance RH across.  1s end
    facing 1st corners
9-16::
    1s dance path of diagonal reel of 4 with 1st corners _while_ 2s+3s
    dance R+L  round them. 1s end BtoB in centre 2nd place ready for …
17-24::
    1s dance Double Triangles ending with Petronella turn to 2nd place
    own side & face down
25-32::
    1s dance down between 3s, cast up, meet & dance up, cast round 2s to
    2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7599, '2013-08-21 08:31:45.230487+00', '2023-02-04 01:22:50.603606+00', 6545, 3, NULL, 'ace', '1-8::
    1L & 4M dance 1/2 reels of 3 across with 2s/3s, 1L & 4M pick up
    partners in prom hold & complete reel
9-16::
    1s+4s lead down/up, set & dance RH across
17-24::
    1s & 4s lead out of ends & cast to 2nd/3rd place opposite sides,
    1L+4L also 1M+4M turn RH
25-32::
    1s+4s set, dance 1/2 R&L & set.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8642, '2015-02-13 12:48:20.390146+00', '2023-02-04 01:22:50.629775+00', 15574, 3, NULL, 'ace', '1-4::
    1s also 4s set & cast 1 place
5-8::
    1s & 4s Petronella turn to end between 2s/3s & 5s/6s then all set
    forming two 3 couple sets across with the "top" on the Ladies side
9-20::
    All dance Interlocking 3 couple R&L:
::
    All dance normal 3 Couple R&Ls but when changing places LH (bars 11,
    15 & 19) the centre dancer in each of the middle 2 rows change
    places with the person diagonally to left in the other set (e.g. at
    bar 11, 1L+6L & 2M+4M change places)
21-24::
    All Set+Link for 3 ending on sidelines  6(4)5 3(1)2
25-32::
    4s dance 1/2 Figs of 8 round 6s/5s _while_ 1s dance 1/2 Figs of 8
    round 3s/2s (Ladies up. Men down), all turn partners RH.  6 4 5 3 1
    2', 0);
INSERT INTO 'dancecrib' VALUES (7709, '2013-08-21 08:31:47.184599+00', '2023-02-04 01:22:57.300775+00', 6711, 3, NULL, 'ace', '1-8::
    1M casts 1 place & turns 3L LH, 1L casts 1 place & turns 3M RH, 1s
    end 2nd place opposite sides
9-16::
    2s+1s+3s circle 6H round & back (1s end facing 1st corners)
17-24::
    1s set & turn 1st corners, set & turn 2nd corners (1s end between
    corners)
25-32::
    2s+1s+3s Adv+Ret, 1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (7600, '2013-08-21 08:31:45.264729+00', '2023-02-04 01:22:50.814666+00', 6549, 3, NULL, 'ace', '1-8::
    1s set, dance between 2s, behind 3s to meet & dance up to top
9-16::
    1s+2s Promenade
17-24::
    All dance 4 couple Poussette to 2 3 4 1
25-32::
    All circle 8H round & Back', 0);
INSERT INTO 'dancecrib' VALUES (7601, '2013-08-21 08:31:45.27287+00', '2023-02-04 01:22:50.844703+00', 13820, 3, NULL, 'ace', '1-8::
    3s step in to form 2H arch as 1M followed by 1L chase down middle,
    1s turn & 1L leads up t places ( 3s step back)
9-16::
    1s+2s dance RH across & LH back
17-24::
    1s+2s chase anticlockwise 1/2 way, 2s+1s set & 2s cross LH to own
    sides as 1s turn LH to face 1st corner
25-32::
    1s turn corners RH & RSh to face 2nd corner, turn corners RH & pass
    RSh to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7602, '2013-08-21 08:31:45.280893+00', '2023-02-04 01:22:50.874647+00', 6550, 3, NULL, 'ace', '1-8::
    1s lead down crossing below 3s & cast up to 2nd place, dance up
    between 2s & cast back to 2nd place
9-16::
    1s turn 3s on sides (LH Ladies side & RH Men''s side), 1s turn 2s on
    sides (RH Ladies side & LH Men''s side)
17-24::
    1s dance RH across Man with 2s & Lady with 3s, 1s dance 1/2 Figs of
    8 giving RSh to 4th corner
25-32::
    2s+1s+3s set, dance DoSiDo with partner & set', 0);
INSERT INTO 'dancecrib' VALUES (11476, '2019-01-01 01:58:00.667423+00', '2023-02-04 01:22:50.923567+00', 18962, 3, NULL, 'ace', '1-4::
    1s turn RH & cast 1 place
5-12::
    1s dance Fig of 8 round 1st & 2nd corners (pass 1st corner LSh) &
    end 2nd place opposite sides
13-24::
    2s+1s+3s dance 3 couple R&L
25-32::
    1s dance 1/2 RSh reels of 3 on opposite sides, 1L dance 1/2 LSh
    reels of 3 across (1M up with 3s, 1L down with 2s).  (3) 1 (2)
33-40::
    All dance Diag R&L.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7603, '2013-08-21 08:31:45.389357+00', '2023-02-04 01:22:50.950051+00', 9220, 3, NULL, 'ace', '1-8::
    1s set, dance down, cast down behind 3s & lead up (RH joined) to
    face 2L (Mans 2nd corner) in prom hold
9-16::
    1s dance diagonal reel of 3 with 2nd corners
17-24::
    1s dance LH across with 2M (1L leading), RH across with 3L & 1s
    dance out 2nd place opposite sides into…
25-32::
    1s dance LSh reels of 3 on opposite sides (1M up & 1L down) & cross
    diagonally to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7604, '2013-08-21 08:31:45.398888+00', '2023-02-04 01:22:50.982081+00', 11498, 3, NULL, 'ace', '1-8::
    1L+2L dance Figs of 8 round 1M+2M (cross between Men to start)
9-16::
    1M+2M repeat
17-24::
    1s lead down middle & back
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7605, '2013-08-21 08:31:45.408052+00', '2023-02-04 01:22:51.011286+00', 8853, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, 1L+3L also 1M+3M turn LH then RH
9-16::
    2s+1s+3s circle 6H to left 1/2 way & turn partners 2H
17-24::
    3s+1s+2s dance 1/2 reels on opposite sides (1s RSh to person on
    right), turn partners 2H.  (2)(1)(3)
25-32::
    2s+1s+3s Set & Rotate for 3 couples on opp sides -
::
    Set & rotate singly & chase 1 place clockwise, all change places
    with opposite person & chase clockwise to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7606, '2013-08-21 08:31:45.416307+00', '2023-02-04 01:22:51.041078+00', 6556, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s set, 1/2 turn LH, 1L followed by partner dances out between
    2M+3L & cast to 4th place Men''s side as partner returns to place
    _while_ 4s dance similarly 4L ending in 1st place Ladies side & 4M
    in original place
9-16::
    1L+4M also 1M+4L turn RH 1.1/2 times, 1s+4s cast to centre _while_
    2s & 3s cross LH up/dn, 1s+4s dance RH across 1/2 way _while_ 2s &
    3s set
17-24::
    1s (in prom hold) dance reel of 3 with 2L+3M (RSh to 2L to start)
    _while_ 4s dance reel of 3 with 2M+3L (RSh to 3L to start)
25-32::
    1s+4s dance RH across 1/2 way, give LH to crnr & Balance in St
    Andrews Cross, 1s+4s dance 1/2 RH across & all change pl with ptnrs
    2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (7607, '2013-08-21 08:31:45.424562+00', '2023-02-04 01:22:51.06377+00', 9013, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, all set & 1/2 turn RH into allemande hold
    facing down
9-16::
    All dance reversed Allemande (dance down & round) 1s end facing 3rd
    corners (pstn)
17-24::
    1s dance ''Hello-goodbye'' setting & end in lines across, all set
25-32::
    All cross RH up/down, 1s cast round 2nd corner positions to 2nd
    place opposite sides, all cross RH & 1s+3s change places LH on sides', 0);
INSERT INTO 'dancecrib' VALUES (14135, '2021-07-07 00:21:38.946326+00', '2023-02-04 01:22:51.097534+00', 6558, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH & cast in 1 place (2s/3s step up/down); 1s face 2s,
    4s face 3s & all set, 2s+1s & 4s+3s turn 3/4 RH into 2 lines across
    & retain RH as  1L+2L & 3M+4M join LH in middle
9-16::
    All Bal-in-Line, drop LH in middle & 1/2 turn RH to reform lines
    across (1M+2M & 3L+4L join LH in middle); All Bal-in-Line, drop LH
    in middle & turn 1/4 RH to sides.  (1) 2 3 (4)
17-24::
    All turn partner RH (1s & 4s turn partner 1.1/2 RH to own sides); 1s
    cross & cast (2s step up).  2 (1) 3 4
25-32::
    1s set, cast (3s step up); 1s cross RH, cast (4s step up). 2 3 41', 0);
INSERT INTO 'dancecrib' VALUES (7608, '2013-08-21 08:31:45.432606+00', '2023-02-04 01:22:51.123086+00', 7527, 3, NULL, 'ace', '1-8::
    1M also 2L cross passing their standing partner by RSh & cast 1
    place, 1M+2L turn 1.1/2 RH back to places
9-16::
    1L+2M repeat passing partner LSh & turning LH
17-24::
    1s slip step down the middle & back
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (13355, '2020-11-02 01:22:06.719139+00', '2023-02-04 01:22:51.148024+00', 20094, 3, NULL, 'ace', '1-8::
    1s cross RSh, cast (2s step up 3-4) & dance 1/2 Fig of 8 round 2s to
    finish facing 1st corners
9-16::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh, dance 1/2
    diag reel of 4 with 2nd corners.  (3) (1) (2)
17-24::
    1s dance 1/2 reels of 3 on sides giving LSh to 1st corners, 1s dance
    1/2 reels of 3 across giving LSh to 3rd corners.  2 1 3
25-32::
    2s+1s+3s Adv+Ret; all dance RSh round partner.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13356, '2020-11-02 01:22:06.753677+00', '2023-02-04 01:22:51.17598+00', 17402, 3, NULL, 'ace', '1-8::
    1L+2M dance DoSiDo; dance towards each other, pull back RSh & cast
    (1M & 2L step down/up)
9-16::
    2L+1M dance DoSiDo; dance towards each other, pull back RSh & cast
    (2M & 1L step down up)
17-24::
    1s+2L circle 3H round to left; 1s+2s circle 4H round to right. 1s+2s
    finish in centre joining 2H with partner ready for …
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (7609, '2013-08-21 08:31:45.442439+00', '2023-02-04 01:22:51.196212+00', 6560, 3, NULL, 'ace', '1-8::
    1s dance Fig of 8 on sides round standing 2s+3s (1s dance in to
    start) & end in centre facing 2s (who face up)
9-16::
    1s+2s dance the Rondel, 1s ending BtoB in middle facing own sides
17-24::
    1s dance Double Triangles & end on own sides in 2nd place
25-32::
    1s dance RH across (Lady with 2s & Man with 3s), pass RSh & dance LH
    across with other couple', 0);
INSERT INTO 'dancecrib' VALUES (7610, '2013-08-21 08:31:45.452248+00', '2023-02-04 01:22:51.21276+00', 6563, 3, NULL, 'ace', '1-8::
    All set, 1M & 3M cast down 1 place _while_ 2L & 4L cast up 1 place
    into middle, 1M+2L also 3M+4L turn RH
9-16::
    2L+4L+1M+3M dance reel of 4 in middle ending with 2L in 1st place 1M
    in 2nd place, 4L in 3rd place, 3M in 4th place, all on wrong sides
17-24::
    1L+2M also 3L+4M turn RH 1.1/2 times to change places, 2s+1s also
    4s+3s circle 4H round to left
25-32::
    1s+4s (centre couples) dance 1/2 R&L _while_ 2s & 3s set & cross RH,
    2s+4s also 1s+3s dance RH across', 0);
INSERT INTO 'dancecrib' VALUES (7611, '2013-08-21 08:31:45.460843+00', '2023-02-04 01:22:51.236008+00', 9089, 3, NULL, 'ace', '{{explanation}}
4s & 5s & 6s start on opp sides

1-8::
    1L+2L+3L+4M dance RSh reel of 4 on sides _while_ 3M+4L+5L+6L also
    dance RSh reels of 4
9-16::
    1M+2M+3M+4L dance RSh reels of 4 _while_ 3L+4M+5M+6M also dance reel
    of 4
17-24::
    All dance Double Snowball for 6 cpls to end 3(2)6(1)5(4) :
::
    1s & 6s cross RH & change places LH on side with 2s/5s
::
    2s & 5s cross RH _while_ 1s+3s also 4s+6s change places RH
::
    2s+3s also 1s+6s also 4s+5s change places LH.  3(2)6(1)5(4)
25-32::
    End couples (3s & 4s) set to partners & cross RH; end 2 couples
    (3s+2s also 5s+4s) set to partners & dance 1/2 RH across  2 3
    6(1)(4)(5)', 0);
INSERT INTO 'dancecrib' VALUES (7612, '2013-08-21 08:31:45.469123+00', '2023-02-04 01:22:51.281377+00', 12016, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on sides (1s in & down to
    start)
9-16::
    1s+2s dance double Fig of 8 (1s cross down to start) _while_
    3s+4s+5s dance reflection reels of 3 on sides (3s in & down to
    start)
17-22::
    1s cross down to 3rd place, cast up to 2nd place opp sides & cross
    RH _while_
::
    2s set, cross down to 3rd place & cross RH
::
    3s cast up to 1st place & turn RH
23-24::
    3s+1s+2s set
25-32::
    2s+4s+5s repeat bars 17-24 from 3rd, 4th & 5th places.  End 3 1 5 2
    4', 0);
INSERT INTO 'dancecrib' VALUES (5525, '2013-08-21 08:31:08.817608+00', '2023-02-04 01:22:51.308015+00', 6566, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret 1 step twice, circle 6H round to left 1/2 way
9-16::
    3s+2s+1s Adv+Ret 1 step twice, circle 6H round to right 1/2 way back
    to places
17-24::
    1s+2s circle 4H round to left 1/2 way & change places RH with
    partners, 1s+3s circle 4H round to left & change places RH with
    partners
25-32::
    1s set, cast up to 2nd place, 2s+1s+3s turn RH', 0);
INSERT INTO 'dancecrib' VALUES (7613, '2013-08-21 08:31:45.48837+00', '2023-02-04 01:22:51.331205+00', 6568, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All dance RH across & LH back
9-16::
    All turn 2H to left for 4 steps & turn right back to places
17-24::
    1s dance Figs of 8 Man round 2s & Lady round 3s
25-32::
    Each couple dances All Round Diamond Poussette to end facing partner
    in original pstns

{{title}}
Reel

1-8::
    All petronella turn, All set to partners (Men high cuts & Ladies
    points), petronella turn to partners place & 1/2 turn RH
9-24::
    All dance Schiehallion reels (4 places) to end 1 place to right
25-32::
    All dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13444, '2020-12-02 01:22:01.528121+00', '2023-02-04 01:22:51.36069+00', 17799, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cast _while_ 2s dance up & face out; 1/2 mirror reels
    of 3 on sides giving hands (1s in/down to start).  1s end facing 1st
    corner pstn
9-16::
    1s set to 1st corner, set to 2nd corner (pstn) & end on opp sides;
    3s+1s+2s circle 6H 1/2 round, ending all in line in centre facing
    partner (2M & 3M facing up, 1M facing down)
17-24::
    1s turn 1/2 RH _while_ 2s+3s set to partner, all Petronella turn to
    opp sides; all turn partner 2H 1.1/2 to own sides. 2 1 3
25-32::
    2s+1s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7614, '2013-08-21 08:31:45.496688+00', '2023-02-04 01:22:51.396331+00', 6569, 3, NULL, 'ace', '1-8::
    1s+2s+3s set advancing to partner & 3/4 turn 2H (to form line
    up/down), set to partner & 3/4 turn 1s+2s facing up & 3s down
9-16::
    1s+2s+3s dance reflection reels of 3 on sides (1s & 3s cast) but all
    cross RH when dancing up thru 2nd pl, 2s end facing 1st crnrs
17-24::
    2s dance ''Hello-Goodbye'' setting & end by turning RH to face out
    between 1s & 3s on own sides
25-32::
    2s cast down 1 place, 1s+3s+2s 1/2 turn partners LH to face down,
    dance down cross over & dance up own side to 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7717, '2013-08-21 08:31:47.264566+00', '2023-02-04 01:22:57.639711+00', 6720, 3, NULL, 'ace', '1-8::
    1L+2L advance to partners & set, 1L+2L retire & set
9-16::
    1M+2M repeat bars 1- 8
17-24::
    1s followed by 2s lead down the middle, 2s followed by 1s lead back
    up 2s casting to original places
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7615, '2013-08-21 08:31:45.504966+00', '2023-02-04 01:22:51.422938+00', 10514, 3, NULL, 'ace', '1-8::
    1s+2s+3s cross RH & set, 1s & 3s 3/4 turn RH to form line in middle
    _while_ 2s cross RH & all set
9-16::
    1s+3s dance 1/2 reel of 4 (ending 1L facing 2M, 3M facing 2L),
    1L+3M+2s dance 1/2 reel of 4 across (1L+3M end facing partners in
    middle)
17-24::
    1s+3s dance 1/2 reel of 4, turn RH to original places & all set.
    1(2)3
25-28::
    1s+2s dance 1/2 RH across as 3s cross LH, 1s+3s dance 1/2 LH across
    as 2s cross RH (2)3 1
29-32::
    2s+3s dance 1/2 RH across as 1s cross LH, 2s+1s dance 1/2 LH across
    (3)1(2)
33-40::
    1s dance Diag R&L (1M down, 1L up).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7744, '2013-08-21 08:31:47.661648+00', '2023-02-04 01:22:58.063484+00', 6771, 3, NULL, 'ace', '1-8::
    1s lead down for 3 steps, back to top & cast to 2nd places
9-16::
    1s dance RH across (Lady with 2s & Man with 3s) & LH across with
    other couple
17-24::
    2s+1s+3s Adv+Ret & dance DoSiDo
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7616, '2013-08-21 08:31:45.513166+00', '2023-02-04 01:22:51.453114+00', 11534, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH, cast down 1 place, lead down between 4s/5s & cast
    up 1 place
9-16::
    All dance RH across (1M with 2s, 1L & 3M with 4s, 3L with 5s), 1s &
    3s dance LH across with other couple & end in double triangle
    position
17-24::
    1s & 3s dance Double Triangles & end facing 3rd corners _while_ 2s,
    4s & 5s petronella on 1 place anticlockwise on bar 19 & again on bar
    23
25-32::
    1s & 3s dance 1/2 reel of 4 with 3rd corners & 1/2 reel with 4th
    corners
33-40::
    1s & 3s dance 1/2 reel of 4 with 1st corners & 1/2 reel with 2nd
    corners
41-48::
    1s & 3s cross LH, cast down 1 place & all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (7617, '2013-08-21 08:31:45.576478+00', '2023-02-04 01:22:51.478057+00', 14681, 3, NULL, 'ace', '1-4::
    1s cross down to 4th place (no hands) _while_ 2s+3s+4s face & dance
    up 1 place, 1s cross RH _while_ 2s+3s+4s set
5-16::
    Repeat bars 1-4 3 times with each new top couple to end all in
    original places
17-24::
    All Adv+Ret, 1s set & cast to bottom
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8072, '2013-10-01 08:47:28.915217+00', '2023-02-04 01:22:51.681897+00', 15128, 3, NULL, 'ace', '1-8::
    All set & turn 2H, 1s+2s also 3s+4s circle Left, ending joing 2H
    with partner ready for…
9-16::
    1s+2s also 3s+4s dance 1/2 Poussette; 1s+4s dance 1/2 Poussette to
    end 2 4 1 3 with 4s facing 1s as 2s & 3s face partner
17-24::
    All dance interlocking reels of 4 around set with 2s & 3s dancing
    across set as 4s+1s dance on own side.:
::
    All pass person facing RSh & all dance LSh round next person at
    corner & pass RSh again then dance LSh round next corner person to
    end 2 4 1 3 with 1M followed by 4M & 4L followed by 1L facing own
    sides
25-32::
    All dance Alternating Tandem reels of 3 on own sides.  End 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7722, '2013-08-21 08:31:47.305342+00', '2023-02-04 01:22:57.717593+00', 12906, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH & cast in 1 place, petronella 2 places
    anticlockwise.  2 4 1 3
9-16::
    4L+1L also 1M+4M dance Tandem 1/2 reels of 3 on own sides (Ladies
    RSh to 2L & Men RSh to 3M), 1L+4L also 4M+1M Set+Link.  2 4 1 3
17-24::
    4s & 1s Set+Link (across), 1L+4L also 4M+1M dance Tandem 1/2 reels
    of 3 on opp sides (Ladies RSh to 3M & Men RSh to 2L).  2(1)(4)3
25-32::
    1s+4s set advancing, dance 1/2 RH across, set & turning right about
    set advancing to places.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11478, '2019-01-01 01:58:05.116435+00', '2023-02-04 01:22:59.900195+00', 18954, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 2s+1s+3s 1/2 turn RH, pull back RSh
    & dance out to opp sides (2) 1 (3)
9-16::
    2s+1s+3s Set & Rotate for 3 couples:
::
    All Set & Rotate singly & chase clockwise to form lines of 3 across
    facing partners
::
    All change places with partner & chase clockwise    to end (3) 1 (2)
17-24::
    1s dance 1/2 Fig 8 (1M up round 3s, 1L down round 2s); 3s+1s+2s 1/2
    turn partner RH, pull back RSh & dance out to own sides. 3 1 2
25-32::
    All set, cross RH & chase clockwise 1/2 round to own sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12827, '2020-05-14 23:16:31.493156+00', '2023-02-04 01:22:51.812836+00', 15247, 3, NULL, 'ace', '1-4::
    All set, 1s & 4s cast in 1 place _while_ 2s dance up to 1st place,
    3s down to 4th place
5-8::
    1s+4s dance LH across ending on sides. 2 1 4 3
9-16::
    Reels of 4 on sides. At end 1M+4M pass RSh _while_ 1L+4L pass LSh to
    end 2 1 4 3 with 4s facing out
17-24::
    1s+4s+3s dance Promenade (Chaperoned) Chain Progression:
::
    _17-18_    1s & 3s 3/4 turn partner RH into middle _while_ 4s dance
    clockwise 1/4 round the set picking up 1L/3M …
::
    _19-22_    who promenade 1/2 way clockwise _while_ middle people (1M
    + 3L) turn LH 1.1/2.
::
    _23-24_    1s & 3s turn partner RH 3/4 to own sides _while_ 1s dance
    clockwise 1/4 round to end in 2nd place. 3 4 1
25-32::
    All dance RSh 3/4 round partner to end in centre,  Men facing up,
    Ladies down & all set; All dance RSh 3/4 round partner to opp sides
    & cross RH to own side.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7618, '2013-08-21 08:31:45.586181+00', '2023-02-04 01:22:51.996745+00', 6575, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance DoSiDo & cross RH
9-16::
    1s+2s+3s repeat
17-24::
    1s+2s+3s dance RH across & LH back
25-32::
    1s weave ''out & in'' around 2s+3s+4s on own sides back to place
33-40::
    1s cast to bottom on own sides followed by 2s+3s+4s, form an arch &
    2s+3s+4s dance under to new places', 0);
INSERT INTO 'dancecrib' VALUES (7619, '2013-08-21 08:31:45.59245+00', '2023-02-04 01:22:52.033026+00', 13688, 3, NULL, 'ace', '1-8::
    1s dance down the middle, set to partner & face up, 1M dances LH
    across with 2M+3M _while_ 1L dances RH across with 2L+3L
9-16::
    1s dance up & cast 1 place to end LSh to LSh facing opposite sides,
    1L dances RH across with 2s as 1M dances RH across with 3s
17-24::
    1s dance ''Hello-Goodbye'' setting ending with 3/4 RH turn to 2nd
    place own side
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (7620, '2013-08-21 08:31:45.600542+00', '2023-02-04 01:22:52.069962+00', 6577, 3, NULL, 'ace', '1-8::
    1L+2L+3L Adv+Ret & set; _while_ Men set & Adv+Ret; 1s+2s+3s cross RH
    to opposite sides
9-16::
    All set; petronella turn to centre; turn prtnrs 2H & petronella turn
    to pl (1L+2M end face out)
17-24::
    1s+2s dance reel of 4 across dance (1M+2L pass LSh to start & 1L+2M
    pass partners RSh)
25-32::
    1s+2s dance the Rondel', 0);
INSERT INTO 'dancecrib' VALUES (7621, '2013-08-21 08:31:45.608563+00', '2023-02-04 01:22:52.088408+00', 7975, 3, NULL, 'ace', '1-8::
    1s & 3s dance Double Figs of 8 round 2s (1s cross down to start)
9-16::
    1M+2L change places RH then 1M+3M change places LH, 1L+2M change
    places RH then 1L+3L change places LH.  (2)(3)1
17-24::
    3M+2s also 3L+1s circle 3H round to left, 3s pass RSh to circle
    round to right with other couple
25-32::
    2s & 1s set & cross RH, 3s & 1s set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (7775, '2013-08-21 08:31:48.261152+00', '2023-02-04 01:23:00.414084+00', 6830, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    1s turn 1st corner RH & return to 2nd place, 1s turn 2nd corner LH &
    return to 2nd place
17-24::
    1s set to 1st corner, turn RH 1/2 way & dance RH across with 1st
    corners 1/2 way back to own sides, 1M+2M also 1L+3L change places on
    sides
25-32::
    1s repeat with 2nd corners & dance LH across 1/2 way to own sides,
    1L+2L also 3M+1M changing places on sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7622, '2013-08-21 08:31:45.616791+00', '2023-02-04 01:22:52.298786+00', 9532, 3, NULL, 'ace', '{{explanation}}
	1s & 3s stand as for a normal square set. 2L stands in 2nd couples place & 2M stands in 4th couples place

1-4::
    2s set & cast anticl''wise to end 2L in 1st place & 2M in 3rd pl
    _while_ 1s & 3s dance RH across ending in centre facing 2L/2M (now
    in 1st/3rd pls)
5-8::
    2L+1s also 2M+3s dance LH across
9-12::
    2L+1s dance 1/2 reel of 3 (2L RSh to 1L) _while_ 2M+3s dance 1/2
    reel of 3 (2M RSh to 3L)
13-16::
    2s turn RH to end facing up (Lady facing lady, Man facing man) to 1s
    _while_ 1s & 3s turn partner RH to finish in partner''s original
    place
17-20::
    1s+2s dance 1/2 R&L (1s end facing 3s)
21-24::
    1s+3s dance 1/2 R&L (1s end in 3rd place, 3L in 2nd place & 3M in
    4th place)
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8365, '2014-07-29 12:59:34.072964+00', '2023-02-04 01:22:52.316262+00', 15226, 3, NULL, 'ace', '{{title}}
Start

::
    _9_··8··7
::
    _6_··5··4
::
    _3_··2··1
::
    ··Top
1-8::
    Dancers 1+2+4 also 6+8+9 dance RH across & LH back _while_ 3+5+7
    dance RSh reel of 3 (3+5 pass RSh). 2+5+8 face 1+4+7 and 3+6+9 face
    in
9-16::
    All set, 2+5+8 & 1+4+7 turn opp. person 1/2 RH, 1+4+7 & 3+6+9 turn
    opp. person 1/2 LH, all face in (6-middle person face up), all set
17-24::
    _3_+6 changes places RSh, then 3+5 change places RSh, then 5+9, then
    9+4.  Finish with 4 in centre
25-32::
    _4_ dances setting steps finishing facing position 3 _while_ others
    dance 8H round & back

{{title}}
End

::
    _7_··5··8
::
    _9_··4··3
::
    _1_· 6··2', 0);
INSERT INTO 'dancecrib' VALUES (10106, '2017-09-03 23:45:31.251738+00', '2023-02-04 01:22:52.342492+00', 6582, 3, NULL, 'ace', '1-8::
    Centre person dances Fig of 8, begin by passing end person on right
    RSh
9-16::
    Reel of 3, centre person passes end person on right RSh
17-24::
    Centre person turns end person on right RH then turns person on left
    1/2 LH
25-28::
    End persons change sides, person on right dancing in front of new
    centre person, and end person on left behind.
29-32::
    End persons Adv+Ret (towards/away from centre place) _while_ centre
    person Ret+Adv (up/down)

{{explanation}}
Note:	Original text:  1-8  1 dances Fig 8 round 2 & 3 (RSh to 2)  :  9-16  3 dances Fig 8 round 2 & 1 (RSh to 2)  :  16-32  As above', 0);
INSERT INTO 'dancecrib' VALUES (7623, '2013-08-21 08:31:45.62489+00', '2023-02-04 01:22:52.37002+00', 6583, 3, NULL, 'ace', '{{explanation}}
Round the room, 3 facing 3

1-8::
    All dance reels of 3 with centre Man giving RSh to 1L (on right)
9-16::
    M+1L slip-step to 2L & set to 2L, M+2L slip-step to 1L place & set
    (Man turning to face 1L)
17-24::
    M+1L turn RH, M+2L turn LH into triangle Man facing partners
25-32::
    All set, dance forward to invert triangle, set & all dance on to
    meet new partners (Men dancing clockwise & Ladies anticlockwise)', 0);
INSERT INTO 'dancecrib' VALUES (13772, '2021-03-02 01:22:10.538393+00', '2023-02-04 01:22:52.470033+00', 6585, 3, NULL, 'ace', '{{explanation}}
Line of three ‑ Man between 2 Ladies. Man holds handerchiefs (or ribbons) for Ladies to hold in nearer hand

{{title}}
Strathspey

1-8::
    Lady on left dances clockwise round outside, Lady on inside
    anticlockwise, dancing under arch made by others.  Man turns slowly
    under arch in same direction as Lady on right.  All end in place
    (strathspey travelling steps throughout)
9-16::
    All set with Highland setting steps
17-48::
    Repeat twice more

{{title}}
Reel

1-48::
    Repeat 1-16 3 times with Highland reel setting steps', 0);
INSERT INTO 'dancecrib' VALUES (14739, '2022-04-01 00:22:01.033689+00', '2023-02-04 01:22:52.485666+00', 14490, 3, NULL, 'ace', '1-6::
    1s cross down LH to dance 1/2 reels of 3 (1M+3L pass LSh, 1L+2M pass
    RSh), Bar 3: 1s pass LSh to swap reels.  All end in original places
7-8::
    All turn partners 2H & face partner
9-16::
    All dance Poussette for 3 couples: couples move independently round
    the set and end Men facing in, Ladies facing out
::
    Deviser''s note:  Think clockface  1s (top) start at 12 o''clock and
    move to 9, 6, 3 back to 12
::
    2s move from 4 to 1, 10, 7 back to 4;  3s from 8 to 5, 2, 11 back to
    8
17-32::
    All dance Schiehallion reels moving 4 places, ending 1 place
    anticlockwise from start.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7624, '2013-08-21 08:31:45.632958+00', '2023-02-04 01:22:52.501881+00', 6586, 3, NULL, 'ace', '1-8::
    1s & 5s turn RH, cast in 1 place, 1s+3s+5s dance 1/2 reels of 3 on
    sides (3s in & up to start) 5s & 1s end facing 1st corners
9-16::
    5s & 1s turn 1st corners RH, partner LH, 2nd corner RH & 5s cross LH
    to dance between 3s _while_ 1s cross LH to own sides
17-24::
    5s dance out down round 4s, up behind 3s, between 2s & cast to 2nd
    place _while_ 1s dance up behind 3s, between 2s, cast & dance down
    between 3s+4s & cast up to 4th place.  2 5 3 1 4
25-32::
    2s+5s dance R&L _while_ 3s+1s+4s set, cross RH & circle 6H round to
    left 1/2 way.  2 5 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9246, '2016-06-16 22:42:25.356092+00', '2023-02-04 01:22:52.513153+00', 16275, 3, NULL, 'ace', '1-8::
    1s cross down to dance mirror reels of 3 on opp sides
9-16::
    1s cross down to dance mirror reels of 3 on own sides
17-24::
    1s dance down middle NHJ (3 bars), rotate 1/2 way (1L dances round
    in front of 1M who pivots) to face up.  1s dance up (4 bars) to top
    place opp sides facing out
25-28::
    1s turn 2s 1.1/2 times (1M+2L RH, 1L+2M LH)
29-32::
    1s dance 1/2 Fig 8 round 3s', 0);
INSERT INTO 'dancecrib' VALUES (7625, '2013-08-21 08:31:45.640981+00', '2023-02-04 01:22:52.523883+00', 6592, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place & turn LH to face 1st corner
9-16::
    1s dance track of reel of 4 with 1st corners _while_ 2s+3s dance R&L
    End 1M between 2s facing down & 1L between 3s facing up
17-24::
    1s turn RH, cast RSh round 2nd corner & turn LH to face 2nd corners
25-32::
    1s dance track of reel of 4 with 2nd corners _while_ 2s+3s dance R&L
    (start on sides) End in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (12107, '2019-08-30 09:55:06.473199+00', '2023-02-04 01:22:57.743007+00', 19062, 3, NULL, 'ace', '1-8::
    1s cross down to dance reels of 3 on opp sides. 1s end in centre,
    opp sides, NHJ with partner facing down _while_ 3s end in centre
    facing partner
9-16::
    1s Adv+Ret, Adv & 1/2 turn LH to 2nd place own side _while_
::
    3s 1/2 turn RH to face up, Adv+Ret, 1/2 turn LH back to place
::
    Bars 9-10: 2s dance up to 1st place.  2 1 3
17-20::
    1s+2M+3L (top 2 Men, bottom 2 Ladies) dance 1/2 R&L
21-24::
    1s+2L+3M (top 2 Ladies, bottom 2 Men) dance 1/2 R&L  (3) 1 (2)
25-32::
    3s+1s+2s set, 1s turn RH _while_ 2s & 3s dance anticlockwise 1/2
    round set (4 bars), 2s+1s+3s set.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9933, '2017-06-05 11:31:51.944186+00', '2023-02-04 01:22:52.537485+00', 14140, 3, NULL, 'ace', '{{title}}
Fig 1

1-8::
    1s+3s dance ''Chain Progression'':
::
    _1- 2_    1s & 3s 3/4 turn RH
::
    _3- 6_    1L+3L turn LH 1.1/2 times _while_ partners chase clockwise
    outside set 1/2 way
::
    _7- 8_    3s & 1s 1.1/4 turn RH to end in opp places from original
    positions, facing corners
9-16::
    1s & 3s change places LH with corners, turn next person RH (2 bars)
    all round, change places with corner again LH & all set to parners
17-32::
    2s+4s repeat 1-16

{{title}}
Fig 2

1-8::
    1s+3s turn 3/4 RH into reel of 4 (Ladies pass LSh).  1M+3M end BtoB
    facing partners
9-16::
    1s+3s set, turn partners 2H 1.3/4 to face in & set
17-32::
    2s+4s repeat 1-16

{{title}}
Fig 3

1-8::
    Ladies dance 1/2 RH across, turn opp Man LH, dance 1/2 RH across &
    turn partners LH
9-16::
    1s+3s dance 1/2 R&L, change places RH with corners & all set
17-24::
    2s+4s repeat 1-16
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14380, '2021-10-11 22:42:14.839443+00', '2023-02-04 01:22:52.576004+00', 19551, 3, NULL, 'ace', '1-8::
    1s cross RH, cast off 2 places (2s+3s step up on bars 3-4), 1s cross
    RH & cast up to 1st place (2s+3s step down on bars 7-8)
9-16::
    1s+2s dance Poussette 1 2 3
17-24::
    1s+2s+3s dance the Slip Knot:
::
    _17-22_ All 3 couples dance first 6 bars of standard knot
::
    _23-24_ 1s (at bottom) turn LH to own side _while_ 3s+2s dance 1/2
    LH across to end on own side 2 3 1
25-32::
    All set, all turn partner 2H (4 bars), all set 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (9491, '2016-11-09 08:49:05.095989+00', '2023-02-04 01:22:52.629337+00', 15020, 3, NULL, 'ace', '1-8::
    1s set, dance down & cast behind 3s (2s step up), dance up ending
    BtoB facing own sides
9-16::
    1s dance 4 bars "Crown Triangles" (1M+2M+3M then 1M+2s, 1L+2L+3L
    then 1L+3s). 1s pass 2nd corner RSh to dance 1/2 reels of 3 across.
17-24::
    1s dance 4 bars "Crown Triangles" (1M+2s then 1M+2L+3L, 1L+3s then
    1L+2M+3M). 1s pass 1st corner RSh to dance 1/2 reels of 3 on sides.
    End 1L at top, 1M in 3rd place in middle
25-32::
    1s cross LH. 1M+3s (at top) also 1L+2s (at bottom) dance RH across.
    1s turn 3/4 LH remaining in middle facing opp sides as 3s & 2s 1/2
    turn RH
33-40::
    1M+3L+2L also 1L+3M+2M dance RH across. 1s cross LH to 2nd place own
    sides as 3s & 2s 1/2 turn RH on sides. 2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (7628, '2013-08-21 08:31:45.791501+00', '2023-02-04 01:22:52.807861+00', 6600, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s cast 1 place & petronella turn into lines
    across (Lady between 2s & 1M between 3s)
9-16::
    1s dance RSh reels of 3 across & 1s end with RH joined facing 2nd
    corners
17-24::
    1s set to 2nd corners, set to 1st corners, turn RH to end Lady
    between 2s & Man between 3s
25-32::
    2s+1s+3s advance 1s change places, retire with opposite couple & 1s
    turn RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7629, '2013-08-21 08:31:45.799619+00', '2023-02-04 01:22:52.829145+00', 6601, 3, NULL, 'ace', '1-8::
    1s cross to 2nd place, cast down behind 3s, dance up crossing to 2nd
    place & cast to top _while_ 2s cast to top then follow 1s to
    original places
9-16::
    1s cross RH, 1s+2s+3s set, petronella to centre, set & Ladies turn
    on last bar to end in front of partner (1s face down & 2s+3s up) &
    Men puts hands on partners waist
17-24::
    1s+2s+3s dance reel of 3 & 3s return to place as 1L & 2M dance to
    face partners for Poussette
25-32::
    1s+2s dance Poussette.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7630, '2013-08-21 08:31:45.807657+00', '2023-02-04 01:22:52.860221+00', 8527, 3, NULL, 'ace', '1-8::
    2s followed by 1s lead down, 1s cross below 4s & cast up to 3rd
    place, 2s lead up to top as 1s dance 1/2 reel of 3 with 3s+4s (1s
    dance in & up to start).  End 2 (1) 4 3
9-16::
    1s+4s dance LH across, 1s+2s also 4s+3s dance RH across
17-24::
    1s+4s dance R&L
25-32::
    1s dance 1/2 Fig of 8 round 4s, lead down to 4th place & turn RH to
    own side _while_ 3s cast up to 2nd place.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7631, '2013-08-21 08:31:45.817438+00', '2023-02-04 01:22:52.895457+00', 12842, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 RH across, 1s dance down LSh around 3s back to 2nd
    place opp sides, 2s+1s dance 1/2 RH across back to original places
9-16::
    2s+3s dance 1/2 LH across, 3s dance up RSh around 1s back to 2nd
    place opp sides; 3s+2s dance 1/2 LH across back to original places
17-24::
    1s cross RH, cast 1 place, 1s dance 1/2 Figs of 8 (1M up round 2s &
    1L down round 3s)
25-32::
    1s dance 6 bar reels of 3 across (1L with 2s, LSh to 2M & 1M with
    3s, LSh to 3L to start) & all set. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7632, '2013-08-21 08:31:45.913248+00', '2023-02-04 01:22:53.274304+00', 11440, 3, NULL, 'ace', '1-8::
    1s+2s set & 1/2 turn RH to end in middle facing down in prom hold,
    1s+2s dance down & 2s cast up behind 3L to end 2L in 1st place & 2M
    in Ladies 2nd place _while_ 1s cast up behind 3M to end 1M in 1st
    place & 1L in 2nd place
9-16::
    1s+2s dance Ladies'' Chain
17-24::
    1s+2s set then 1M+2M change places RH. 1s dance 1/2 RSh reels of 3
    across (1L RSh to 2L, 1M RSh to 3M)
25-32::
    1s dance 1/2 RSh reels of 3 across (1L RSh to 3L, 1M RSh to 2L). 1s
    turn RH & end 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (14545, '2022-01-10 02:21:03.098516+00', '2023-02-04 01:22:53.312913+00', 17976, 3, NULL, 'ace', '1-8::
    1s cast followed by 2s+3s+4s (who dance up to start), dance down
    below 5th place, meet partner & dance back up to place
9-16::
    1s+3s lead down (2 bars), set to partner, lead up (2 bars) & cast,
    1s to 2nd place, 3s to 4th place (2s & 4s step up 15-16)
17-24::
    All 5 couples Adv+Ret; all dance DoSiDo with partner
25-32::
    1s+3s cross RH, cast 1 place (4s & 5s step up); 1s+3s dance 1/2 Fig
    round couple above.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (7633, '2013-08-21 08:31:45.929099+00', '2023-02-04 01:22:53.341168+00', 6609, 3, NULL, 'ace', '1-16::
    1L followed by partner casts down 2 places, 1L crosses to opposite
    side, set, lead to top, cross Lady in front into prom hold &
    Promenade to 2M''s place & stand for 4 bars _while_ 2s stand for 2,
    dance up for 2, 2L followed by partner casts down 2 places, 2L
    crosses to opposite side, set, lead up to 2L place & face in prom
    hold _while_ 3s stand for 2, dance up for 2, stand for 2, dance up
    for 2, 3L followed by partner casts down 2 places, cross to opposite
    side, set, lead to top & face 1s in prom hold
17-24::
    3s dance LSh reels of 3 across set with 1s+2s to end facing up 3 1 2
25-32::
    3s+1s+2s Promenade for 6bars, 3s cast to 3rd place as 1s lead to top
    & cast to 2nd place as 2s dance to top', 0);
INSERT INTO 'dancecrib' VALUES (14546, '2022-01-10 02:21:03.133627+00', '2023-02-04 01:22:53.368869+00', 17977, 3, NULL, 'ace', '1-4::
    1s+2s also 3s+4s set, 1s/3s cast 1 place, 2s/4s dance up 1 place. 2s
    & 4s face out
5-8::
    2s followed by 1s & 4s followed by 3s dance down behind own lines
9-12::
    All cast away from partner & dance up to original places
13-16::
    1s & 3s turn partner RH moving down to face 1st corners (2s & 4s
    step up 15-16)
17-24::
    1s & 3s dance Corner Pass+Turn with 1st corners, pass RSh & dance
    Corner Pass+Turn with 2nd corners.  2 1 4 3 5
25-32::
    1s/3s cast into 3/4 Fig 8 round couple below them & cross RH with
    partner to own side. (4s+5s step up 29-30)
33-40::
    All circle 10H round & back.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (7634, '2013-08-21 08:31:45.937098+00', '2023-02-04 01:22:53.38816+00', 13462, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH & cast 1 place, 1s & 3s cross LH & cast up 1 place.
9-16::
    2s & 4s cross RH & cast up 1 place, 2s & 4s cross LH, cast down 1
    place
17-24::
    1s dance down the middle NHJ & dance up to cast round the 4s to 4th
    place
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (15081, '2022-09-05 00:22:10.773345+00', '2023-02-04 01:22:53.409761+00', 14994, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 Double Fig 8 (1s cross down, 2s dance up); 1s+2s+3s
    dance 1/2 mirror reels of 3 on sides (1s in/down to start).  3 (2)
    (1)
9-16::
    2s+1s dance 1/2 Double Fig 8 (1s cross up, 2s dance down); 3s+2s+1s
    dance 1/2 mirror reels of 3 on sides (1s in/up to start).  1 2 3
17-24::
    1s dance down NHJ (2s step up) & 1s turn 3s nearer hand; 1s turn 2s
    other hand & all 3 couples set. 2 1 3
25-32::
    1s+3s dance the Tourbillon:
::
    _25-28_  1s & 3s 1/2 turn ptnrs 2H, 1M & 3L lead ptnrs by nearer
    hand 1 place cl''wise to end 1s on Ladies side & 3s Men''s side, 1s
    set to 2s
::
    _29-32_  1s & 3s 1/2 turn ptnrs 2H & lead ptnrs on 1 place clockwise
    & 3s+1s cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (10342, '2017-12-22 15:45:10.39938+00', '2023-02-04 01:22:53.441644+00', 9785, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up), cross LH & cast to Left (1M down, 1L
    up) to end 1M between 3s, 1L between 2s
9-16::
    1s turn LH _while_ 2s & 3s turn RH (4 bars).  1s dance out of end
    (1M down, 1L up), cast Left to 2nd place opp sides _while_ 2s+3s set
    & petronella turn into centre
17-24::
    1s turn LH _while_ 2s & 3s turn RH (4 bars). 1s cast (1M up, 1L
    down) dance across (1M between 2s, 1L between 3s) to 2nd place own
    sides _while_ 2s & 3s set & petronella turn to opp sides (2)(1)(3)
25-32::
    2s+3s set & dance La Baratte  _while_ 1s petronella turn to into
    centre, set advancing, join RH to join last 4 bars of La Baratte.
::
    _27-28_   Man 1/2 turns opposite Lady RH & retains hand but at arm''s
    length from each other
::
    _29-30_   Man retraces steps with Lady turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies original
    place) & releasing Ladies RH she turns under Mans left arm until
    almost in original places
::
    _31-32_   Couple change places LH to opposite places  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7635, '2013-08-21 08:31:45.945197+00', '2023-02-04 01:22:53.476287+00', 11983, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s set, cast 1 place turn LH
9-16::
    1s dance 1/2 reels of 3 on own sides (Lady RSh to 2L & Man RSh to
    3M) & dance 1/2 reels of 3 across (Lady LSh to 3M at top & Man LSh
    to 2L) ending 2nd place opposite sides
17-24::
    3s+1s+2s Set+Link for 3 twice
25-32::
    2s+1s+3s circle 6H round & back

{{title}}
Reel

{{explanation}}
Repeat from 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (8643, '2015-02-13 12:48:21.005247+00', '2023-02-04 01:22:53.498613+00', 15285, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig. 8 round 2s, 1s dance 1/2 Fig. 8 round 3s (2s step
    up 7-8)  2 1 3
9-16::
    1s turn 3/4 RH, 1st crnr 3/4 LH, ptnr 3/4 RH, 2nd crnr 3/4  LH to
    end 1L between 3s, 1M between 2s
17-24::
    1M+2s also 1L+3s Adv+Ret, 1s cross RH and cast to Right (1L round
    2L, 1M round 3M) into 2nd place own side
25-32::
    2s+1s+3s Adv+Ret,  & turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (7636, '2013-08-21 08:31:45.953264+00', '2023-02-04 01:22:53.523869+00', 6613, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, cross down RH & cast up to 2nd place opposite
    sides
9-16::
    1s dance reflection reels with 2s+3s (1s dance in & up to start) &
    end facing 1st corners
17-24::
    1s set & turn 1st corners RH, set & turn 2nd corners RH
25-32::
    1s dance LSh reels of 3 across dance (M with 2s & L with 3s), 1s end
    in centre facing own sides
33-40::
    1s dance Double Triangles & end in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7637, '2013-08-21 08:31:45.961307+00', '2023-02-04 01:22:53.554774+00', 7528, 3, NULL, 'ace', '1-8::
    1s dance reflection reels on own sides dancing in/down between 2s to
    start
9-12::
    1M+2L set advancing, turn 3/4 RH to end 1M in 2M place & 2L in 1L
    place as 1L & 2M cast down/up.  2 1 3
13-16::
    1L+2M repeat set advancing & turn RH once round.  2 1 3
17-24::
    1s+3s circle 4H round & back
25-32::
    1s dance Fig of 8 round 2s.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9492, '2016-11-09 08:49:05.256287+00', '2023-02-04 01:22:53.586379+00', 17360, 3, NULL, 'ace', '1-8::
    1s turn RH to face out, 1s+2s change places on sides (Men LH, Ladies
    RH).  1s dance 1/2 Fig 8 down round 3s
9-16::
    2s+1s+3s dance 1/2 Diag R&L twice (1M crossing up, 1L crossing down
    to begin both times).  1s finish facing out  (3) (1) (2)
17-24::
    3s+1s change places on sides (Men LH, Ladies RH).  3s+2s change
    places on sides (Men RH, Ladies LH). All set. _While_ 3s cross RH,
    1s+2s turn 1/2 RH remaining in centre for...
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7638, '2013-08-21 08:31:45.969275+00', '2023-02-04 01:22:53.616243+00', 6614, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place (2s step up); 2s+1s+3s turn RH, 2s & 1s
    cast 1 place _while_ 3s lead to top & face out
9-16::
    3s+1s dance double Fig of 8 round standing 2s (3s cast down,1s cross
    up to start).  3s finish facing in
17-24::
    3s turn RH & cast 1 place, (2s step up); 2s+3s+1s turn RH, 2s & 3s
    cast 1 place _while_ 1s lead to top, 2s dance in, ready for …
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7639, '2013-08-21 08:31:45.977331+00', '2023-02-04 01:22:53.648151+00', 6615, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, 2s+1s+3s set, 3s lead up to top _while_ 1s+2s
    cast down 1 place
9-16::
    3s+1s dance 3/4 double Fig of 8 round 2s (1s cross up to start), 3s
    cross RH & all end in centre facing up
17-24::
    1s+2s+3s dance Allemande
25-32::
    3s+2s+1s dance Progressive Grand Chain:
::
    _25-26_   3s (at top) turn once round RH as 2s+1s change places RH
    on sides
::
    _27-28_   2s (at bottom) turn once round LH as 1s+3s change places
    LH on sides
::
    _29-30_   1s (at top) turn once round RH as 3s+2s change places RH
    on sides
::
    _31-32_   3s (at bottom) turn once round LH as 1s+2s change places
    LH on sides to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7640, '2013-08-21 08:31:45.98554+00', '2023-02-04 01:22:53.704263+00', 6616, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s & 4s set, 1M & 4L cast 1 place (M down, L up) to face partner in
    diagonal line, 1s & 4s set to partners, turn 2H to end in diag line
9-16::
    1s+4s dance a diagonal reel of 4 ending in original places

{{title}}
Reel

17-24::
    1s & 4s set, cast in 1 place & dance RH across
25-32::
    1s & 4s set, cast back to places & dance LH across with 2s/3s

{{title}}
Strathspey

33-48::
    1L & 4M repeat bars 1-16

{{title}}
Reel

49-56::
    1s+2s set, dance 1/2 RH across, 1s+3s set & dance 1/2 LH across
57-64::
    1s+4s set, dance 1/2 RH across, all set & cross to own sides Ladies
    pass under arches made by Men', 0);
INSERT INTO 'dancecrib' VALUES (13357, '2020-11-02 01:22:08.781508+00', '2023-02-04 01:22:53.716842+00', 8578, 3, NULL, 'ace', '1-4::
    1L+2M turn RH _while_ 1M+2L chase clockwise 1/2 round to change
    places
5-8::
    2L+1M turn RH _while_ 1L+2M chase clockwise 1/2 round to change
    places. (2) (1)
9-16::
    2s+1s circle 4H round & back
17-24::
    2s+1s chase anticlockwise 1/2 round to original places; 1s+2s change
    places on sides turning 1.1/2 LH.  2 1 3
25-32::
    2s+1s+3s dance RSh reels of 3 on sides (1s pass 3s RSh to start).  2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (7641, '2013-08-21 08:31:45.996221+00', '2023-02-04 01:22:53.72961+00', 6618, 3, NULL, 'ace', '1-4::
    1s & 4s set advancing & lead down/up to meet each other (2 bars
    PdeB).  2s & 3s step up/down bars 3-4
5-8::
    1s+4s dance RH across to end in 2nd/3rd places. 2 1 4 3
9-16::
    2s & 4s repeat bars 1-8.  All end in original places
17-24::
    All set, 1s+2s also 3s+4s dance 1/2 R&L; all cross RH with 2s ending
    in 1st place but 1s+4s+3s retain partner''s RH & remain in middle
    facing up
25-32::
    1s+4s+3s dance Allemande.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7642, '2013-08-21 08:31:46.004294+00', '2023-02-04 01:22:53.741102+00', 6621, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, face partner retaining hands with
    other person; 1s+2s set & turn partner with crossed hands to face up
9-16::
    1s+2s dance Allemande, 1s end by turning with crossed hands to face
    1st corner
17-20::
    1s set to 1st corners, turn them clockwise with crossed hands to
    face 2nd corner
21-24::
    1s set to 2nd corners & turn them anticlockwise with crossed hands
    to end own 3rd corner (1M+2M, 1L+3L)
25-28::
    1s dance RSh round corner & dance down up middle to 2nd place own
    side _while_ corners advance to partner, Ladies dance under Man''s
    Right arm & dance to place as Men retire
29-32::
    All turn partners clockwise with crossed hands (1s turn 1.3/4 times)', 0);
INSERT INTO 'dancecrib' VALUES (13773, '2021-03-02 01:22:11.715053+00', '2023-02-04 01:22:53.864598+00', 13381, 3, NULL, 'ace', '1-4::
    1s+2s  also 4s+5s   dance 1/2 RSh Tandem reels of 3  with 3M/3L on
    own side, 2s+3s pass RSh to start. End: 4s pull back RSh to face
    down
5-8::
    Top 4 couples: 4s+5s+3s+1s dance 1/2 LSh reels of 4 on the sides.  1
    3 5 4 2
9-12::
    Top 3 couples: 1s+3s+5s dance 1/2 LSh reels of 3 on the sides. 1s+3s
    pass LSh to start.  5 3 1 4 2
13-14::
    Top 2 couples: 5s+3s change place LH on sides _while_ Bottom 3
    couples: 1s+4s+2s set.  3 5 1 4 2
15-16::
    All couples chase anticlockwise 2 places (Men''s side: 5L 3L 3M 5M
    1M, Ladies'' side: 1L 4L 2L 2M 4M)
17-20::
    Top 4 on Men''s side + bottom 4 on Ladies'' side, set & cross RH
    diagonally
21-24::
    Top 4 on Ladies'' side + bottom 4 on Men''s side, set & cross LH
    diagonally
25-28::
    Top 4 on Men''s side + bottom 4 on Ladies'' side, set & cross RH
    diagonally.  2 4 1 5 3
25-29::
    All dance Allemande Turn right:  advance to take partner''s RH,  Lady
    dances under Man''s arm. Lady curves out to place as Man retires.  2
    4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (14740, '2022-04-01 00:22:02.200967+00', '2023-02-04 01:22:53.900243+00', 18302, 3, NULL, 'ace', '1-8::
    4s dance in & lead up to top (1s+2s+3s step down 3-4); 4s turn 2H
    twice round & face up
9-16::
    4s cast to dance Fig 8 round 1s (in 2nd place)
17-20::
    All join hands on sides & 4s lead lines across & down partners'' side
    (Ladies dancing in front of Men). At end of bar 20: pause in lines
    on opp sides
21-24::
    Continue figure, 4s lead lines across & up own sides to end 4 1 2 3
25-32::
    4s+1s also 2s+3s dance Double Figs 8 across (Ladies cross 1L in
    front of 4L, 3L in front of 2L _while_ Men dance across to start).
    End 4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (12877, '2020-06-03 16:28:03.805007+00', '2023-02-04 01:22:53.929886+00', 13928, 3, NULL, 'ace', '1-4::
    1s followed by 2s dance down, Bar 4: 1M dances below 1L who dances
    under 1M''s arm to change sides & 1s face up, 2s divide & dance below
    1s
5-8::
    1s followed by 2s dance up, Bar 8: 1M dances above 1L who dances
    under 1M''s arm to change sides, 2s dance out to place
9-16::
    1s+2s turn on sides 1.1/2 (Men RH, Ladies LH). 1s dance down between
    3s, cast up, take prom hold with partner facing 2L
17-24::
    1s+2nd corners dance diag RSh reel of 3.  1s end in centre facing 2M
25-32::
    1s+1st corners dance diag LSh reel of 3.  1s end in 2nd place own
    side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8329, '2014-07-29 12:59:07.093128+00', '2023-02-04 01:22:53.950582+00', 15066, 3, NULL, 'ace', '1-8::
    Men dance diagonally 1 place to right, dance round Ladies passing
    RSh, repeat to finish opposite original places
9-16::
    Ladies repeat 1-8 dancing to left, dancing round Men LSh, to join
    partner opposite original places
17-24::
    1M+3M+2L+4L dance RH across, 1L+3L+2M+4M dance LH across
25-32::
    All circle 8H round 1/2 way to Right, all couples set &
    Petronella-in-Tandem to next place anticlockwise. 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7643, '2013-08-21 08:31:46.01408+00', '2023-02-04 01:22:53.973974+00', 9128, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH & cast in, 1s & 4s dance 1/2 Figs of 8 round 2s/3s
    & end in the middle BtoB facing corner just passed
9-16::
    1s+4s dance "Hello-Goodbye«-setting & end on opposite side.
    2(4)(1)3
17-24::
    All dance reels of 4 on sides (4M starting RSh to 2L, 1M RSh to 3L,
    4L RSh to 2M, 1L RSh to 3M
25-32::
    4s+1s set & dance 1/2 RH across, 1L+4L also 1M+4M turn RH 1.1/2
    times.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7644, '2013-08-21 08:31:46.02211+00', '2023-02-04 01:22:54.007329+00', 11295, 3, NULL, 'ace', '1-8::
    1s set & dance down below 3s, cast up round 3s & turn RH to give LH
    to 1st corner
9-16::
    1s Bal-in-line & turn corners LH to give RH to 2nd corners & partner
    LH, 1s Bal-in-line & turn corners RH & end in 2nd place opposite
    sides
17-24::
    2s+1s+3s dance reels of 3 on sides giving LSh to 1st corners & cross
    RH to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7645, '2013-08-21 08:31:46.038624+00', '2023-02-04 01:22:54.036835+00', 6627, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on sides (1s in & down to
    start) with 1s & 3s ending in centre facing down/up
9-16::
    1s+3s set, dance 1/2 RH across & dance clockwise round 2s back to
    places
17-20::
    1M+2M change places RH with 2L+3L, top 2 on Ladies side change
    places LH with ''bottom'' 2 on Men''s side
21-24::
    Top 2 on Men''s side change places RH with ''bottom'' 2 on Ladies side
    & all cross RH with partners
25-32::
    3s+2s+1s chase clockwise 1/2 way, 1s turn RH & cast to 2nd place
    _while_ 2s turn RH & lead up _while_ 3s turn RH for 4 bars', 0);
INSERT INTO 'dancecrib' VALUES (9047, '2015-11-30 09:00:23.741821+00', '2023-02-04 01:22:54.059192+00', 16729, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, end facing down/up. 1s and 2s set. 1s
    cast off _while_ 2s dance up and cast into place.
9-16::
    1s turn RH 1.1/4 1L dances down and casts up round 3L, _while_ 1M
    dances up and casts off round 2M, _while_ 2s+3s dance R&L starting
    LH on the side.
17-24::
    2s+1s+3s dance RSh reels on side (1M and 3M pass RSh to start, 1L
    and 2L pass RSh to start ).  1M & 3M also 1L & 2L pass RS.
25-32::
    1s+3s dance Tournée', 0);
INSERT INTO 'dancecrib' VALUES (7646, '2013-08-21 08:31:46.047012+00', '2023-02-04 01:22:54.075098+00', 6629, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1‑8::
    All dance RSh reels of 4 on side with 2s+3s passing RSh to end in
    original places
9‑16::
    2s+3s 1/2 turn RH on sides, 3s+2s dance RH across, 1s+3s & 2s+4s 1/2
    turn LH on sides (end in St Andrews Cross 1s+4s giving RH in centre)
17‑24::
    All Bal-in-Line twice, 1s & 4s turn 3s/2s LH to end (3) 1 (4) 2
25‑32::
    1s+4s dance RH across, 1s lead up to top & cast to 2nd pl _while_ 4s
    lead down & cast to 3rd place
33‑40::
    1M+4L & 1L+4M slip step across (Men pass BtoB), set, slip step back
    again (Ladies pass BtoB) & set _while_ 2s & 3s set adv, slip step
    up/dn (Men pass BtoB), set & slip step back (Ladies pass BtoB)
41‑48::
    All circle 8h to left 1/2 way, set, end couples (2s & 3s) cross RH
    _while_ middle couples set', 0);
INSERT INTO 'dancecrib' VALUES (7647, '2013-08-21 08:31:46.073359+00', '2023-02-04 01:22:54.096438+00', 10933, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH
9-16::
    1s lead down & back to 2nd places
17-24::
    1s+3s circle 4H round & back
25-32::
    1s lead up to top, cast 1 place, cross down & cast up to 2nd places
33-40::
    2s+1s+3s Adv+Ret, 1s turn RH 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (11218, '2018-09-30 22:20:39.36041+00', '2023-02-04 01:22:54.114066+00', 17459, 3, NULL, 'ace', '1-8::
    1s dance in & cast 1 place (2s step up), dance down between 3s &
    cast up to 2nd place
9-16::
    2s+1L also 1M+3s dance RH across & 1s pass RSh to dance LH across
    with other couple, 1s end back to back in the middle (1M facing up,
    1L down) facing 2s/3s (2s facing down, 3s up NHJ)
17-20::
    All set, 2s & 3s make arches, dance down/up to meet as 1s dance
    under arches. Finish 1M in 1st place, 1L in 3rd place (facing
    down/up) & 2s & 3s back to back in middle NHJ (2s facing up, 3s
    down).
21-24::
    All set, 2s & 3s making arches dance to ends & cast into reel
    _while_ 1s dance under arch passing LSh and finish between end
    couple facing 1st crnr
25-32::
    2s+1L also 1M+3s dance LSh reels across (2s+3s make loops into the
    reel) to end 2 1 3. All set

{{explanation}}
Note: after 2nd time through 1s may repeat bars 1-4 to get to 4th place', 0);
INSERT INTO 'dancecrib' VALUES (7648, '2013-08-21 08:31:46.083404+00', '2023-02-04 01:22:54.132335+00', 9181, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, dance DoSiDo with partner & set
9-16::
    1s lead down for 4 steps followed by 2s+3s, change places with
    partner & lead up to order 3 2 1
17-24::
    3s giving RSh to 2s dance reels of 3 on opposite sides
25-32::
    2s+1s change places LH on sides, set to partner, 1s cross RH & set
33-40::
    1s dance Diag R&L to end 3 1 2 4

{{explanation}}
2nd time through ends 3 4 1 2, 1s step to bottom & 3s become new 1s', 0);
INSERT INTO 'dancecrib' VALUES (12878, '2020-06-03 16:28:04.036941+00', '2023-02-04 01:22:54.152243+00', 13929, 3, NULL, 'ace', '1-8::
    1s+3s petronella turn to centre & set (2s & 4s step up 1-2); 1s+3s
    1/2 turn partner LH, cast (1L/3L LSh round 2L/4L, 1M/3M LSh round
    2M/4M), pass partner LSh & finish in centre in 1st/3rd place facing
    opp sides
9-16::
    1s+2s also 3s+4s dance RSh reels of 4 across. Bars 15-16: 1s & 3s
    turn partner 3/4 RH to line of 4 up/down centre (Men face up, Ladies
    down)
17-24::
    1s+3s dance 1/2 RSh reel of 4; 3s+2s also 1s+4s dance RH across
25-32::
    3s & 1s set advancing, turn partner 3/4 2H to face up NHJ between
    2s/4s; 3s & 1s cast to 2nd/4th place & all set.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12879, '2020-06-03 16:28:04.060113+00', '2023-02-04 01:22:54.175328+00', 6631, 3, NULL, 'ace', '1-8::
    All Adv+Ret, turn partners RH, finish 1s+3s face down NHJ, 2s+4s
    face up NHJ
9-16::
    All Adv+Ret, 1s+2s also 3s+4s turn RH on sides retaining hands
17-24::
    1s+2s also 3s+4s dance RH across & LH back, 1M finishes facing out
25-32::
    1M (followed by partner) casts 1 place, crosses over, casts 2
    places, crosses over & both end in 4th place own side (2s+3s+4s step
    up bars 31-23)
33-40::
    All circle 8H round & back. End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7649, '2013-08-21 08:31:46.091438+00', '2023-02-04 01:22:54.196531+00', 6632, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 2 places _while_ 2s & 3s set & cross up 1 place
    (no hands), 2s cross RH & cast 2 places _while_ 3s & 1s set & cross
    up.  3 1 2
9-16::
    1s+2s dance RH across, 3s+1s dance LH across 1s end facing 1st
    corner pstns
17-24::
    1s dance ''Hello-Goodbye'' setting & end setting to partner (1M
    between 3s facing down 1L between 2s facing up)
25-32::
    3s+1s+2s Adv+Ret (up/down), change places RH with opposite person &
    1s cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (9934, '2017-06-05 11:31:52.275765+00', '2023-02-04 01:22:54.233616+00', 16497, 3, NULL, 'ace', '1-8::
    1s lead down (3), lead up (3) to top & face out.  1s change places
    with 2s (Men LH, Ladies RH)
9-16::
    Mirror reels of 3 on sides (1s in/down to start).  End with 2s &3s
    curving into place
17-22::
    1L+2M also 1M+3L dance modified La Baratte (omit initial 2 bar
    setting) as follows
::
    _17-18_    Man 1/2 turns opposite Lady RH & retains hand but at
    arm''s length from each other
::
    _19-20_    Man retraces steps with Lady turning right under Man''s
    arm briefly into Allemande hold (Man behind Lady facing Lady''s
    original place) & releasing Lady''s RH she turns under Man''s left arm
    until almost in original places
::
    _21-22_    Couple change places LH to opposite places (2M & 3L omit
    polite turn)
23-24::
    1L+3L also 2M+1M change places RH
25-32::
    _3_ couples Set+Link.  1s petronella turn to 2nd place opp sides
    _while_ 2M+3M & 2L+3L cross RH.  All set
33-38::
    1L+3M also 1M+2L dance modified La Baratte (as 17-22)
39-40::
    1L+2L also 3M+1M change places RH', 0);
INSERT INTO 'dancecrib' VALUES (7650, '2013-08-21 08:31:46.099465+00', '2023-02-04 01:22:54.266599+00', 6634, 3, NULL, 'ace', '1-8::
    1s+2s dance a reel of 4 across the dance (1L & 2M pass LSh, 1M & 2L
    dance to their Left to start). 1s end in 2nd place. 2 1 3
9-16::
    2s+1s+3s dance Grand Chain
17-24::
    2s+1s dance R&L
25-32::
    1s dance down below 3s, cast up on own sides, dance up between 2s &
    cast to 2nd places on own sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14442, '2021-11-06 01:13:29.907504+00', '2023-02-04 01:22:54.335712+00', 14680, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s cross LH & cast (3s step up).  2
    3 1
9-16::
    2s+3s+1s circle 6H round & back
17-24::
    1s cross RH, cast up (3s step down); 1s cross LH & cast up (2s step
    down).  1 2 3
25-32::
    1s+2s+3s circle 6H round & back
33-40::
    1s+2s dance Modified Allemande:
::
    As per Allemande except bars 35-36 1s dance down 2 places below 3s
    _while_ 3s step up.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7652, '2013-08-21 08:31:46.115786+00', '2023-02-04 01:22:54.360418+00', 9897, 3, NULL, 'ace', '1-8::
    1s+2s set on sides, turn 2H & open out into 4H round to left
9-12::
    All set & dance Triple Petronella: 1s & 3s petronella turn to next
    corner _while_ 2s petronella turn into lines across (L facing down M
    facing up)
13-16::
    All set & repeat to end opposite sides (3)(2)(1)
17-24::
    All set, cross (3s & 1s with RH & 2s with LH), 2s dance RH across
    (Lady with top couple & Man with bottom couple)
25-32::
    3s+2s set, Petronella-in-tandem, change places RH with person facing
    & Petronella-in-tandem to own sides.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7653, '2013-08-21 08:31:46.123744+00', '2023-02-04 01:22:54.376289+00', 6638, 3, NULL, 'ace', '1-8::
    1s & 3s turn RH & cast down 1 place, lead down between next couple &
    cast up to face 1st corners
9-16::
    1s & 3s set to & turn 1st corner, set to & turn 2nd corner (end on
    sides between corners)
17-24::
    All Adv+Ret, 1s & 3s cross RH & change places LH on sides with 4s/5s
25-32::
    All circle 10H round & back.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (7654, '2013-08-21 08:31:46.131782+00', '2023-02-04 01:22:54.390052+00', 6640, 3, NULL, 'ace', '1-8::
    All set to partner, 1M & 2L also 3M & 4L turn 3/4 RH & dance out to
    sideline (Men 1 place down & Ladies 1 place up) _while_ partners
    cast 1 place (Order 2 1 4 3), repeat last 2 bars & all set (Now back
    in original places)
9-16::
    1s & 4s cross RH & cast in 1 place _while_ 2s & 3s step up/down,
    1s+4s 1/2 R&L to end on sides
17-24::
    Reel of 4 on sides
25-32::
    2s+4s also 1s+3s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7655, '2013-08-21 08:31:46.140117+00', '2023-02-04 01:22:54.411991+00', 7980, 3, NULL, 'ace', '1-8::
    1s+3s 3/4 turn RH, Ladies pass LSh into reel of 4 & Men end
    back-to-back facing partners
9-16::
    1s+3s set, turn 2H into circle for 4H round to left ending in
    original places
17-32::
    2s+4s repeat bars 1-16
33-40::
    All Ladies dance in (1 step), cast round partner RSh, dance
    clockwise, round next Man RSh to end in opposite places
41-48::
    Men repeat but dancing anticlockwise
49-64::
    Ladies repeat & Men repeat back to original places
65-72::
    1s+3s Adv+Ret & turn corners with nearer hand 1.1/2 times
73-80::
    Couples at top & bottom (2s+4s) Adv+Ret & turn corners 1.1/2 times
    to face own partners
81-88::
    All set to partners, petronella turn, set & turn RH into prom hold
    facing anticlockwise
89-96::
    All Promenade round & turn partners into centre for bow & curtsey', 0);
INSERT INTO 'dancecrib' VALUES (7656, '2013-08-21 08:31:46.154581+00', '2023-02-04 01:22:54.449534+00', 3252, 3, NULL, 'ace', '1-8::
    1s & 3s lead down & up to 2nd/4th places BtoB facing own sides
9-16::
    All dance Double Triangles with 1s & 3s ending in middle facing up
17-24::
    1s & 3s dance up between 2s/4s & cast down 1 place, dance down
    between lower couple & cast up to 2nd/4th places
25-32::
    1s+4s also 3s+5s dance Poussette.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (7657, '2013-08-21 08:31:46.162762+00', '2023-02-04 01:22:54.485804+00', 6644, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance »Inveran« Reels, 1s+3s finishing in centre,1s in 1st
    place facing down, 3s in 3rd place facing up
::
    _1- 4_   1s cross down to 2nd place opposite sides & dance 1/2 reel
    of 3 on opposite sides
::
    _5- 8_   1s cross up to 2nd place own sides (from 3rd place) & dance
    1/2 reel of 3 on own sides.
9-16::
    1s+3s set & dance RH across 1/2 way, retain RH and both couples face
    up; 3s cross & cast to 3rd place followed by 1s who cross up & cast
    to 2nd places to face 1st corners (2s step up 15-16)
17-24::
    1s dance Pass+Turn with 1st corners & pass RSh to face 2nd corners,
    1s dance Pass+Turn with 2nd corners. 1s pass RSh to finish BtoB in
    centre facing own sides
25-32::
    1s dance Double Triangles finishing in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7658, '2013-08-21 08:31:46.170869+00', '2023-02-04 01:22:54.51637+00', 7529, 3, NULL, 'ace', '1-8::
    1s followed by 2s & 3s lead down the middle, 3s+2s+1s set to
    partners & 3s lead back to top for Allemande
9-16::
    3s+2s+1s dance Allemande
17-24::
    1s cast 2 places, dance up the middle to 1st place & cast to bottom
25-32::
    All 4 couples turn partners RH & LH', 0);
INSERT INTO 'dancecrib' VALUES (10343, '2017-12-22 15:45:10.76649+00', '2023-02-04 01:22:54.549832+00', 6646, 3, NULL, 'ace', '1-8::
    1s & 3s Petronella turn, set (2L steps up, 2M steps down).  1s+2L
    also 3s+2M dance RH across into lines across, 2L between 1s at top,
    2M between 3s
9-16::
    All set, dance reels of 3 across, 2s passing person on Right by RSh
17-24::
    2s Petronella turn to opp sides (1)(2)(3).  All set, turn partners
    1.1/2 RH, 3s end on own sides, 1s+2s remain in centre retaining
    hands ready for ...
25-32::
    1s+2s Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7659, '2013-08-21 08:31:46.178975+00', '2023-02-04 01:22:54.572565+00', 10488, 3, NULL, 'ace', '1-4::
    1s+2s Set+Link
5-12::
    2s+1s dance the Bourrel :
::
    2M+1L set advancing, 3/4 turn 2H & twirl to end BtoB (Lady facing up
    & Man down) _while_ partners chase anticlockwise 3/4 way,
::
    set to partners & turn 2H to own sides having changed places
13-16::
    1s+2s Set+Link
17-24::
    1s petronella turn into centre & set, turn partner RH 1.3/4 times to
    face 1st corners
25-32::
    1s dance reels of 3 on opposite sides (RSh to 1st corners to start)
    & cross to 2nd place own sides', 4);
INSERT INTO 'dancecrib' VALUES (10344, '2017-12-22 15:45:10.781848+00', '2023-02-04 01:22:54.598871+00', 16960, 3, NULL, 'ace', '1-8::
    1L dances RSh round 2M & taking prom hold with partner, 1s+2s dance
    1/2 reel of 3 across (1s pass 2L LSh)
9-16::
    1s (prom hold) followed by 2s NHJ dance down below 3s, separate &
    cast up on opp sides (1)(2)3.  1s+2s dance 1/2 R&L.   2 1 3
17-24::
    3M dances RSh round 1L (2L place) & taking prom hold with partner
    (3L on 3M''s left), 3s+1s dance 1/2 reel of 3 across (3s pass 1M LSh)
25-32::
    3s (prom hold) followed by 1s NHJ dance up, separate & cast round 2s
    to opp sides 2(1)(3).  3s+1s dance 1/2 R&L.  End  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (14688, '2022-03-07 02:22:04.060653+00', '2023-02-04 01:22:54.626295+00', 14789, 3, NULL, 'ace', '1-8::
    1s cross down to dance mirror reels of 3 on opposite sides
9-16::
    1s cross down to dance mirror reels of 3 on own sides
17-24::
    1s followed by 2s & 3s lead down the middle, crossing over in 3rd
    place & dance up opposite sides (1) (2) (3)
25-32::
    2s+3s dance 3/4 R&L, all set (1) (3) (2)

{{explanation}}
On repeat, bottom of set is now the top with 2s the dancing couple. After 6 times through, each couple has dance from each side & position', 0);
INSERT INTO 'dancecrib' VALUES (10107, '2017-09-03 23:45:31.688849+00', '2023-02-04 01:22:54.65844+00', 6654, 3, NULL, 'ace', '1-8::
    1s+2s dance R&L
9-16::
    2s+3s dance RH across & LH back
17-24::
    1s lead down the middle for 3 bars, up to top & cast to face 1st
    corners (2s step up 7-8)
25-32::
    1s turn 1st corner RH, partner LH, 2nd corner RH & cross LH to own
    side', 0);
INSERT INTO 'dancecrib' VALUES (13774, '2021-03-02 01:22:12.274537+00', '2023-02-04 01:22:54.817959+00', 13704, 3, NULL, 'ace', '1-4::
    1L followed by 2L+3L+4L cast behind own line & curve into place
    _while_ 1M followed by 2M+3M+4M dance down middle & curve into
    place. 4 3 2 1
5-8::
    All 4 couples turn partner RH
9-12::
    Top 3 on Men''s side & bottom 3 on Ladies'' side Adv+Ret diagonally
13-16::
    Top 3 on Ladies'' side & bottom 3 on Men''s side Adv+Ret diagonally
17-20::
    Middle 2 couples: 3s+2s mirror Set+Link on sides (2L pulls back LSh,
    2M pulls back RSh & cast up)
21-24::
    Top 2 couples: 4s+2s mirror Set+Link
25-32::
    4s+3s dance ''Tornado'':
::
    _25-28_   4s+3s circle 4H 1/2 round, 3M+4M making arch dance across
    & 3L+4L NHJ dance across under the arch
::
    _29-32_   3L followed by 3M casts to left & 4L followed by 4M casts
    to right to opp sides. 3s 1/2 turn LH & 4s 1/2 turn RH to own sides.
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7660, '2013-08-21 08:31:46.257804+00', '2023-02-04 01:22:54.972163+00', 6655, 3, NULL, 'ace', '1-8::
    1s & 4s cast into centre, dance RH across, dance out ends & cast
    back to place
9-16::
    1s+2s also 3s+4s set facing on sides, turn 2H twice & set
17-24::
    All dance 1/2 reels of 4 on sides & 1/2 Grand Chain
25-32::
    1s+2s dance 1/2 RH across, 1s+3s 1/2 LH across, 1s+4s 1/2 RH across
    & all set to partners', 0);
INSERT INTO 'dancecrib' VALUES (11715, '2019-03-18 21:02:59.703681+00', '2023-02-04 01:22:54.995319+00', 18287, 3, NULL, 'ace', '1-8::
    1s cross RH, cast off and turn 1.1/4 RH to lines across 1M/1L
    between 3s/2s
9-12::
    All set, 2s & 3s pull RSh back & rotate 1 place clockwise _while_ 1s
    set adv to partner, pull back RSh to face 4th corner (pstn)
13-16::
    1s set to 4th corners, pull back RSh & dance out to 2nd corner
    (pstn) _while_ 4th corners dance in, pull back RSh to face partner
    in 1st corner (pstn)
17-20::
    4th corners (3L & 2M) repeat bars 13-16 with 1st corners (3M and 2L)
    who end facing 1s
21-24::
    1st corners (3M & 2L) repeat bars 13-16 with 1s who end passing RSh
    to the sides 213
25-32::
    All circle 6H to the left (4 bars) & pull back LSh, step over &
    circle 6H back to the right 213', 0);
INSERT INTO 'dancecrib' VALUES (8644, '2015-02-13 12:48:21.295796+00', '2023-02-04 01:22:55.026528+00', 15310, 3, NULL, 'ace', '{{explanation}}
3s and 4s start on opposite sides

1-8::
    1s+4s cross RH, cast to 2nd/3rd places, 1s+4s dance LH across
    remaining in middle with 1s facing 2s, 3s facing 4s
9-12::
    1s+2s also 3s+4s turn RH once round. 1s+4s in middle chase
    anticlockwise 1 place round to finish BtoB in centre with1s facing
    Men''s side, 4s facing Ladies'' side
13-16::
    1s+4s set to corners and partner (as »Hello-Goodbye«) to finish BtoB
    in centre with 4s facing up, 1s facing down
17-28::
    All dance Interlocking diagonal reels of 4 giving LH across in
    centre.  Finish as end bar 16
29-36::
    1s+4s dance RSh round »corner« into centre, dance RH across, retain
    ptnr''s hand with 1s turning to face down/ 4s face up
37-40::
    1s+4s cross out of ends and cast up/down to finish 2 4 (1) (3)
41-48::
    All turn partner RH, all circle 8H round 1/2 way to finish 3 1 (4)
    (2)', 0);
INSERT INTO 'dancecrib' VALUES (7661, '2013-08-21 08:31:46.266137+00', '2023-02-04 01:22:55.056729+00', 13077, 3, NULL, 'ace', '1-8::
    1s cross & cast 1 place, 1s dance LH across (1L with 2s, 1M with 3s)
    & end facing 4th corner
9-16::
    1s set to corners then to partner up/down the dance & end facing 1st
    corners, turn corners RH & pass partner LSh to face 2nd corners
17-24::
    1s dance 1/2 diagonal reel of 4 with 2nd corners & pass LSh to face
    3rd corners, 1s set to corners then set to partner across the dance
    & end facing 4th corners
25-32::
    1s turn 4th corner (pstn) RH & pass partner LSh to face 1st corners,
    1s dance 1/2 diag reel of 4 with 1st corners & pass RSh to BtoB (1M
    facing up)
33-40::
    1s dance RSh round 2nd corners & 1/2 Fig 8 (1L up, 1M down) _while_
    2s+3s set & cross RH, set (facing up/down) & change pl RH on sides.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7662, '2013-08-21 08:31:46.350332+00', '2023-02-04 01:22:55.08739+00', 6657, 3, NULL, 'ace', '1-4::
    1s+3s set, cast & dance clockwise round to 2nd/4th places _while_
    2s+4s advance into centre, set & turn about to face 1s/3s
5-12::
    All dance RSh reels of 4 across dance
13-16::
    1s+2s also 3s+4s dance LH across 1/2 way, 1s+3s dance RH across 3/4
    way to partners place
17-24::
    All dance Grand Chain (start RH with partner)
25-48::
    Repeat bars 1-24 with 2s+4s setting & 1s+3s advancing
49-56::
    Ladies dance RH across 1/2 way, turn opposite Man RH, Ladies dance
    LH across 1/2 way & turn partner RH into centre
57-64::
    Men repeat bars 49-56 to places
65-80::
    All dance full Schiehallion Reel back to places
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7663, '2013-08-21 08:31:46.360386+00', '2023-02-04 01:22:55.198199+00', 6658, 3, NULL, 'ace', '1-8::
    1s holding nearer hands set twice to 2L & circle 3H round to left
9-16::
    1s holding nearer hands set twice to 2M & circle 3H round to left
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7664, '2013-08-21 08:31:46.368468+00', '2023-02-04 01:22:55.210823+00', 6661, 3, NULL, 'ace', '1‑8::
    1s cross RH, cast 1 place & turn LH
9-16::
    1M+2s & 1L+3s dance RH across; 1s pass RSh to dance LH across with
    other couple. 2 (1) 3
17‑24::
    1s dance reels of 3 on opp sides, RSh to 2nd corners (who cast into
    reels), 1s pass RSh to end BtoB facing own sides (2s & 3s loop round
    into place)
25‑32::
    1s dance Double Triangles.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13196, '2020-09-15 00:21:57.299785+00', '2023-02-04 01:22:55.228396+00', 19998, 3, NULL, 'ace', '1-8::
    1s cross down (touch RH briefly) to BtoB in centre facing opp sides,
    1s+corners set as in Double Triangles; 1s+1st corners dance 1/2 diag
    reel of 4. End 1L in middle at top, 1M in middle 3rd place
9-16::
    1s cross down (touch RH briefly) to BtoB in centre, 1M facing up, 1L
    down, 1s+corners set as in Double Triangles; 1s+2nd corners dance
    1/2 diag reel of 4. 1s end in 2nd place opp sides. (3) (1) (2)
17-24::
    3s+1s+2s Adv+Ret; 1s petronella turn (1M between 3s at top, 1L
    between 2s at bottom) _while_ 2s & 3s set, rotating in place (pull
    back RSh) & all set
25-32::
    All Adv+Ret (up/down); 1s petronella turn to 2nd place own side
    _while_ 2s & 3s set, rotating in place (pull back RSh) & all set
33-40::
    1s dance diag R&L (1M down, 1L up).  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7665, '2013-08-21 08:31:46.3766+00', '2023-02-04 01:22:55.249237+00', 6662, 3, NULL, 'ace', '1‑8::
    1M+2M+3M dance to partner, about turn & dance back to place, 1M+2L
    also 2M+3L also 3M+4L turn RH
9‑16::
    1L+2L+3L dance to partner, about turn to join RH with 2M/3M/4M, turn
    under Mans right arm & dance back to place
17‑24::
    1s+2s change places on sides (Ladies RH & Men LH), 1s followed by 2s
    cast 2 places, 2 dance back up to top _while_ 1s dance up middle to
    2nd pl
25‑32::
    1L dances RH across with 2L+3L as 1M dances LH across with 2M+3M, 1L
    LH across with 3L+4L as 1M RH across with 3M+4M & 1s end 4th pl', 0);
INSERT INTO 'dancecrib' VALUES (7666, '2013-08-21 08:31:46.38485+00', '2023-02-04 01:22:55.276913+00', 9242, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s dance RH across, 2s+3s dance 1/2 R&L
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1L+3L also 2L+4L cross passing partner LSh & dance down/up side to
    change places, 1M+3M also 2M+4M cross passing partner RSh & dance
    down/up side to change places.  2 4 1 3
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7668, '2013-08-21 08:31:46.527748+00', '2023-02-04 01:22:55.327691+00', 11044, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place (2s step up) & turn 1.1/4 LH to face 1st
    corners
9-16::
    1s dance DoSiDo with 1st corners, turn 1st corners RH & pass partner
    LSh to face 2nd corners
17-24::
    1s dance DoSiDo with 2nd corners, turn 2nd corners RH & pass partner
    RSh to 2nd places
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7669, '2013-08-21 08:31:46.536328+00', '2023-02-04 01:22:55.362796+00', 12619, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, set & petronella turn into lines of 3 across
    (1M between 3s, 1L between 2s)
9-16::
    2s+1s+3s set, 1s turn 3/4 RH to opposite sides, all set & 1s turn
    3/4 RH to face Men''s side NHJ
17-24::
    1s dance out between 2M & 3M, divide, cast (1M up, 1L down) & into
    centre; 1s dance out Ladies'' side, divide & cast (1M up, 1L down),
    to end 1M between 2s facing down & 1L between 3s facing up
25-32::
    2s+1s+3s set & 1s turn 1.1/4 RH to 2nd place opp sides; all set & 1s
    cross RH to 2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13358, '2020-11-02 01:22:10.003282+00', '2023-02-04 01:22:55.388585+00', 16825, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s cross LH round 3s & cast up to
    2nd place own sides
9-12::
    2s+3s dance 1/2 Double Fig 8 (2s cross down, 3s dance up to start).
    (2) 1 (3)
13-24::
    2s+1s+3s dance R&L for 3 couples
25-32::
    1s dance diag R&L (1M down, 1L up).  End 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7764, '2013-08-21 08:31:48.066254+00', '2023-02-04 01:22:59.602616+00', 6817, 3, NULL, 'ace', '1-8::
    1s+2s set twice & turn RH
9-16::
    1s set twice to 2s on sides & turn partners LH
17-24::
    1s+2s circle 4H round & dance DoSiDo with partner
25-32::
    1s lead down the middle for 3 steps, back to top & cast to 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (7983, '2013-08-21 08:31:52.33365+00', '2023-02-04 01:23:14.881223+00', 7206, 3, NULL, 'ace', '1‑4::
    1s+5s 3/4 turn RH to form line up/down middle, 1M+5L turn LH to face
    1st corners (2s+4s acting as corners _while_ 3s, 1L & 5M stand)
5‑16::
    5L+1M turn 1st corner RH, ''partner'' LH, 2nd corner RH , ''partner''
    LH, then 1s+5s  turn partners RH 1.1/2 times back to places
17-24::
    3s stand _while_ 1s+2s & 4s+5s dance interlocking reels of 3 round
    standing 3s (1s+2s also 4s+5s pass each other RSh to start)
25‑32::
    1s slip step down for 2 bars _while_ 2s+3s+4s+5s step up, 1s slip
    step back up & dance out between 2s+3s on own sides, in between
    3s+4s & cast round 5s to 5th place', 0);
INSERT INTO 'dancecrib' VALUES (14229, '2021-08-14 00:22:14.827413+00', '2023-02-04 01:22:55.424217+00', 13777, 3, NULL, 'ace', '1-8::
    1s+2s also 4s+5s Poussette,  Bars 7-8; instead of retiring, 1M & 5L
    pull back LSh _while_ 1L & 5M pull back RSh to end BtoB with partner
    facing own side.  2 1 3 5 4
9-16::
    All dance »Double-Double-Triangles« (3s are shared), Bars 15-16:  1s
    & 5s Petronella turn to right  to end facing partners up/down centre
    of set, in order 1L 1M 5L 5M
17-20::
    1s & 5s dance 1/2 reel of 4 up/down centre passing partner LSh to
    start, end facing partners again
21-24::
    All dance 1/2 reels across (5M+2s, 5L+1M+3s,1L+4s) passing person on
    right by RSh to start. 1s & 5s continue looping to right until they
    face partners again in centre
25-28::
    1s & 5s dance 1/2 reel of 4 up/down centre passing partner RSh to
    start, end facing partners again
29-32::
    All dance 1/2 reels across (1L+2s, 1M+5L+3s, 5M+4s) passing person
    on left by LSh to start. 1s & 5s continue looping to left until they
    face partners again in centre
33-36::
    1s & 5s join partners in prom hold (1L & 5M on left) and dance
    anticlockwise out through own sides (1s up behind 2s & 5s down
    behind 4s) and round to top & bottom to end in original places (2s &
    4s step down/up bars 35-36), 1 2 3 4 5
37-40::
    All 5 couples set twice.
41-48::
    2s+3s also 4s+5s dance R&L but moving up 1/2 place on each crossing
    RH _while_ 1s »weave down« own sides to bottom, starting by dancing
    behind 2s.  End 2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (14689, '2022-03-07 02:22:04.671497+00', '2023-02-04 01:22:55.473251+00', 20644, 3, NULL, 'ace', '1-4::
    1s lead down RH, cross below 3s, cast up to end 1M facing 2L, 1L
    facing 2M at top  (2s step up 3-4)
5-8::
    1s turn 2s (1M RH, 1L LH), 1s pass RSh to 1M facing 2M, 1L facing 2L
9-16::
    1s+2s dance RSh reel of 4 across
17-24::
    1s dance round 2s RSh to end 1M facing 3L, 1L facing 3M; 1s turn 3s
    (1M LH, 1L RH), 1s pass RSh to 1M facing 3M, 1L facing 3L
25-32::
    1s+3s dance RSh reel of 4 across.  1s end in 2nd place own side.  2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (7670, '2013-08-21 08:31:46.546639+00', '2023-02-04 01:22:55.499049+00', 6666, 3, NULL, 'ace', '1-8::
    3s 3/4 turn RH & dance Crown Triangles with 2s+4s _while_ 1s & 5s
    chase clockwise all the way round
9-16::
    1s+2s+4s+5s dance reel of 4 (2s+4s face & pass LSh to start) _while_
    3s dance out ends (Man up, Lady down), chase 1/2 way clockwise,
    dance up/down centre & pass RSh to…
17-24::
    3M with 2s+3s also 3L with 4s+5s dance RH across & LH back (spare
    hand on shoulder in front) ending in original places
25-32::
    1s dance down to 5th place under arches made by others & all turn RH', 0);
INSERT INTO 'dancecrib' VALUES (14230, '2021-08-14 00:22:14.876292+00', '2023-02-04 01:22:55.523375+00', 19856, 3, NULL, 'ace', '1-8::
    1s+3s set advancing, 1/2 turn opposite dancer 2H to finish on sides
    (Men have changed places); 2s+4s repeat
9-12::
    All Set with ''new partner'', pull back LSh & chase anticlockwise 1
    place round
13-16::
    All Set+Link, Ladies casting to corner to their left _while_ Men
    finish BtoB in centre facing Ladies (1M facing 2L at corner between
    1st/2nd place)
17-20::
    All 1/2 turn 2H, Men dance clockwise 1 place to next corner _while_
    Ladies dance anticlockwise in centre to face original partner
21-24::
    Repeat 17-20 from new positions to end facing dancer as at bar 17
    (1M facing 2L) now 1 place round anticlockwise
25-28::
    All 1/2 turn 2H, Ladies dance to next corner clockwise round _while_
    Men dance in, pull back RSh to join RH with partner.  1 2 3 4
29-32::
    All dance RHJ 1/4 clcockwise round & all turn partner 3/4 RH to form
    square set again.  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (7671, '2013-08-21 08:31:46.556811+00', '2023-02-04 01:22:55.552686+00', 6671, 3, NULL, 'ace', '1-8::
    All dance 1/2 reels of 4 on sides, 4s+3s also 2s+1s dance RH across
9-16::
    Repeat bars 1-8
17-24::
    1s+2s+3s circle 6H round to left 1/2 way as 4s turn 2H 1.1/2 times,
    all petronella turn twice to own sides.  3 2 1 4
25-32::
    3s+2s also 1s+4s dance the Knot to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12160, '2019-09-04 08:30:44.13827+00', '2023-02-04 01:22:55.605159+00', 19625, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place (2s step up); 1 dance 1/2 Figs of 8 (1L round
    2s, 1M round 3s)
9-16::
    1s dance reels of 3 on own sides giving LSh to 3rd corner. 1s end in
    2nd place own side
17-24::
    1s dance reels of 3 across giving RSh to 2nd corner & 1s cross to
    face 1st corner
25-32::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH to 2nd
    place own sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7672, '2013-08-21 08:31:46.602179+00', '2023-02-04 01:22:55.641317+00', 5487, 3, NULL, 'ace', '1-8::
    1s & 3s set & cross RH, all set, 1M & 3M cast down 1 place _while_
    2M & 4M cast up 1 place & Ladies cross to end beside partners facing
    out
9-16::
    1s+2s also 3s+4s dance Men''s Chain
17-24::
    All dance reels of 4 on sides
25-32::
    3s followed by 4s+1s+2s dance down the middle, on bars 28-29 Men 1/2
    turn Ladies under their arms to face up & all dance up to 2 1 4 3
33-40::
    Middle couples (1s+4s) set & dance RH across 1/2 way, 1/2 turn
    partners RH & twirl to own sides
41-48::
    All circle 8H round & back.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11716, '2019-03-18 21:02:59.943331+00', '2023-02-04 01:22:55.660517+00', 17474, 3, NULL, 'ace', '1-8::
    All Set+Link for 4 couples:
::
    All set, 1M+2M dance down & curve into 2nd/4th places as 3M+4M cast
    up to 1st/3rd places _while_ 1L+2L cast off to 2nd/4th places as
    3L+4L dance up and curve into 1st/3rd places. All chase clockcwise
    1/2 way to finish on opposite sides
9-16::
    All reverse Set+Link for 4 couples:
::
    All set, 2M+1M dance down & curve into 2nd/4th places as 4M+3M cast
    up to 1st/3rd places _while_ 2L+1L casts to 2nd/4th places as 4L+3L
    dance up & curve into 1st//3rd places. All chase anticlockwise 1/2
    way to finish 1 3 2 4
17-24::
    1s+4s set _while_ 3s+2s cross RH to opposite sides & face out. 1s+3s
    & 4s+2s dance 3/4 double fig of 8 (1s cross down, 3s dance up to
    begin, 2s dance down & 4s cross up). 1s & 4s face out 3 1 4 2
25-32::
    3L+1L turn LH _while_ 3M+1M turn RH & 4L+2L turn RH as 4M+2M turn
    LH, 1s+4s finish in middle of set (1s face down, 4s face up) 1s+4s
    dance RH across.  End 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (7673, '2013-08-21 08:31:46.733474+00', '2023-02-04 01:22:55.685702+00', 12038, 3, NULL, 'ace', '1-8::
    1s set & turn LH, cast to 2nd place & turn RH to face 1st corners
9-16::
    1s turn corners LH & partner RH to face 2nd corners, 1s turn corners
    LH & partner RH into prom hold facing 2M
17-24::
    1s (prom hold) dance 1/2 reel of 3 with 1st corners & face 3M, 1s
    dance 1/2 reel of 3 with 2nd corners & end 1L facing her 3rd corner
    with 1M behind her
25-32::
    1s dance Alternating Tandem 1/2 RSh reel of 3 with crnrs & end
    facing 1Ms 4th crnr, Altntg Tandem 1/2 LSh reel of 3 with crnrs &
    end 2nd pl own sides', 0);
INSERT INTO 'dancecrib' VALUES (7674, '2013-08-21 08:31:46.742756+00', '2023-02-04 01:22:55.70244+00', 6675, 3, NULL, 'ace', '1-8::
    1s+2s set, 1s cross down to 2nd place _while_ 2s cast up, 1s turn
    2nd corners LH, pass by right & turn right about (touching LH)
9-16::
    1s dance RH across with sides (1L with 2M+3M & 1M with 2L+3L), dance
    Pass+Turn with 2nd corners, pass by right & turn right about to face
    opposite sides
17-24::
    1s dance RH across with ends (1L with 2s & 1M with 3s), Pass+Turn
    with 1st crnrs, pass by right to face down on own sides (1M turns
    right about)
25-32::
    1s dance down between 3s, divide & cast up, dance up between 2s &
    cast to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7675, '2013-08-21 08:31:46.75295+00', '2023-02-04 01:22:55.718388+00', 7564, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s petronella turn into centre & all set in diamond formations,
    1s+2s & 3s+4s dance RH across once round
9-16::
    1s+4s dance 1/2 reel of 4 up/down middle; pass partner by RSh, turn
    to the right & turn person on right RH (1M+3L, 1L+3M, 4M+2L & 4L+2M)
    to end BtoB between 3s/2s
17-24::
    4s+2s & 1s+3s dance reels of 4 across, 1s & 4s end turning RH to
    form line up/down centre with Ladies in centre LH joined
25-32::
    4s+1s Bal-in-Line, turn ptnr 3/4 RH, dance out to ends, turn & face
    2s/3s who have danced in (2s face up & 3s down), 4s+2s also 3s+1s
    set
33-36::
    4s+2s & 3s+1s dance a Half Rondel :
::
    4s/3s dance down under the arch made by 2s/1s who dance up, Ladies
    cross in front of Men & all cast to meet the other Lady or Man on
    the opposite side
37-40::
    All join nearer hands on sides, set & cross RH back to own sides.
    End 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (8792, '2015-06-15 11:41:16.947894+00', '2023-02-04 01:22:55.878591+00', 16204, 3, NULL, 'ace', '1-8::
    1s cross LH & cast 1 place (2s step up 3-4), 1s set & Twirl (pull
    back RSh - 1L full turn, 1M turns 1.1/2 times)
9-16::
    2s+1s dance Ladies'' Chain
17-24::
    1s dance reels of 3 on opposite sides (RSh to 3s to start) & cross
    RH to own sides
25-32::
    1s set (1 bar) & dance 6H round (3 bars) to left, pivot (crossing R
    foot over L) & chase back to place', 0);
INSERT INTO 'dancecrib' VALUES (13097, '2020-08-10 00:21:41.251122+00', '2023-02-04 01:22:55.90704+00', 6677, 3, NULL, 'ace', '1-8::
    2s+3s dance RH across; 2L followed by 2M cast to 4th place _while_
    3M followed by 3L cast up to 1st place (1s/4s step down/up 7-8). 3s
    face 1s, 4s face 2s on sides  (3) 1 4 (2)
9-16::
    3s+1s also 4s+2s Poussette across set (couples on Men''s side move
    down, Ladies'' side up to start).  Couples have changed sides 3 (1)
    (4) 2
17-24::
    All dance reels of 4 on sides
25-32::
    1s lead up, cross & cast to 2nd place _while_ 4s lead down, cross &
    cast up to 3rd place; all 4 couples turn partner RH.  3 1 4 2
33-40::
    All circle 8H round & back.  End 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (7676, '2013-08-21 08:31:46.794163+00', '2023-02-04 01:22:56.001472+00', 7544, 3, NULL, 'ace', '1-8::
    All dance in, pivot to right & dance out thru next place on right
    back to own places & chase clockwise 1/2 way to 4 3 2 1 on opposite
    sides
9-16::
    All dance PdB Coupe
17-24::
    All dance RSh reels of 4 on sides with 2s+3s passing RSh at end of
    reel
25-32::
    4s+3s dance LH across _while_ 2s+1s RH across once round & change
    wheels beginning with 2L passing in front of 3L to end 1 2 3 4 opp
    sides
33-40::
    All set, cross RH & turn RH into prom hold
41-48::
    1s+2s also 3s+4s Promenade (separately) with 1s following 4s to the
    bottom as 2s complete their promenade.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7677, '2013-08-21 08:31:46.802544+00', '2023-02-04 01:22:56.052704+00', 8110, 3, NULL, 'ace', '1-8::
    1s turn RH 1.1/2 times, cast 1 place & turn LH to face 1st corners
9-16::
    1s dance 1/2 reel of 4 with 1st corners, pass LSh & dance 1/2 reel
    of 4 with 2nd corners end facing 3rd corners (1st corner person)
17-24::
    1s set & turn 3rd corners, set & turn 4th corners & end facing 3rd
    corners
25-32::
    1s dance reel of 3 on sides giving LSh to 3rd corners & cross to 2nd
    place opposite sides
33-40::
    2s+1s+3s circle 6H round 1/2 way to left & turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (7678, '2013-08-21 08:31:46.813075+00', '2023-02-04 01:22:56.121372+00', 6680, 3, NULL, 'ace', '1-8::
    1L crosses down & casts up round 2M as 1M dances across & cast down
    1 place, 1s turn LH to end between 2s facing other partner
9-16::
    1s+2s dance reel of 4 across & 1s end without passing LSh to…
17-32::
    1s repeat bars 1-16 with 3s
33-48::
    1s repeat bars 1-16 with 4s & end 1/2 turn LH
49-56::
    1s lead up to top, cross & cast on own sides to 4th place
57-64::
    2s+3s+4s+1s circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7679, '2013-08-21 08:31:46.821274+00', '2023-02-04 01:22:56.1509+00', 6682, 3, NULL, 'ace', '1-8::
    1s & 3s dance in & cast 1 pl into BtoB position in centre (Ladies
    face up & Men down), all dance 3H/4H round to left (3H at ends)
9-16::
    1s & 3s dance LSh round 1st crnrs to BtoB position (having changed
    places with ptnr), all dance 3H/4H round to left, 1s & 3s end facing
    2nd crnrs
17-24::
    1s & 3s set to 2nd corners, set to 1st corners, turning to right
    turn partner RH 1.1/4 times to end facing 4th corner
25-32::
    1s & 3s set to 4th corner, set to 3rd corner, turning to right turn
    partner RH & cast 1 place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (7680, '2013-08-21 08:31:46.835136+00', '2023-02-04 01:22:56.272226+00', 6683, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 around 2s to face 1st
    corners
9-16::
    1s turn 1st corner RH, pass RSh & turn 2nd corner RH, retaining hold
    with corner give LH to 3rd corner
17-24::
    1s dance Double Triangles (up/down)
25-32::
    1s dance RH across (1L with 2s & 1M with 3s), 1s pass RSh for LH
    across with other couple & 1s end in 2nd place own side
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7681, '2013-08-21 08:31:46.843369+00', '2023-02-04 01:22:56.291644+00', 6685, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place into centre (2s step 3-4) & 1s dance RH across
    (Lady with 2s & Man with 3s)
9-12::
    1s+1st corners in prom hold (corners on outside) dance round
    clockwise 1M+3L to 2nd place Men''s side, 1L+2M to 2nd place Ladies''
    side
::
    _while_ 2nd corners dance RSh round each other in centre to end 3M
    facing down, 2L facing up
13-14::
    1s+1st corners dance 1/2 RH across _while_ 2nd corners chase
    clockwise round to place (2L dances up & casts right, 3M down & to
    right)
15-16::
    1s continue turning 3/4 RH to end BtoB in centre, 1M facing up, 1L
    facing down
17-20::
    1s dance LH across (Man with 2s & Lady with 3s)
21-24::
    1s+2nd corners in prom hold (corners on outside) dance round
    anticlockwise 1M+2L to 2nd place Men''s side, 1L+3M to 2nd place
    Ladies'' side
::
    _while_ 1st corners dance LSh round each other in centre to end 3L
    facing down, 2M facing up
25-26::
    1s+2nd corners dance 1/2 LH across _while_ 1st corners chase
    anticlockwise round to place (2M dances up & casts left, 3L down &
    to left)
27-28::
    1s continue turning 1/2 LH to 2nd place own side
29-32::
    2s+1s+3s turn RH.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14014, '2021-05-03 00:21:57.776789+00', '2023-02-04 01:22:56.309982+00', 12632, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s set, cast (2s step up); 1s turn LH to face 1st corners
17-24::
    1s dance diag RSh reel of 4 with 1st corners & end facing 1st
    corners again
25-32::
    1s dance RSh reels of 3 on opp sides (1s RSh to 1st corner to
    start).  Bars 31-32: 1s dance across to 2nd place own side, 1L from
    3M''s place, 1M from 1L''s place)
33-40::
    2s+1s+3s set twice; 2s+1s+3s turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (7682, '2013-08-21 08:31:46.8537+00', '2023-02-04 01:22:56.336331+00', 6686, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place & dance 1/2 Fig of 8 round 2s
9-16::
    2s+1s+3s dance DoSiDo & turn RH into prom hold
17-24::
    2s+1s+3s dance Allemande 1s ending facing opposite as for double
    triangles
25-32::
    All set, 1s 1/2 turn 1st corner RH into centre, all set, 1st corner
    persons 1/2 turn 2nd corners RH into centre
33-40::
    All set, 2nd corner person 1/2 turn 1s into centre, all set & 1s
    dance round each other RSh to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (7683, '2013-08-21 08:31:46.863483+00', '2023-02-04 01:22:56.366442+00', 6687, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back ending in centre for Poussette
9-16::
    1s+2s dance Poussette & 1s turn to face out on own sides
17-24::
    1s dance reels of 3 across Man with 2s giving RSh to 2M & Lady with
    3s giving RSh to 3L
25-32::
    1s turn RH 1.1/4 times to 2nd place opposite sides as 2s+3s dance
    1/2 R&L, 3s+1s+2s chase clockwise to places', 0);
INSERT INTO 'dancecrib' VALUES (10345, '2017-12-22 15:45:11.30057+00', '2023-02-04 01:22:56.399162+00', 18092, 3, NULL, 'ace', '1-4::
    1s+4s take nearer hand with ptnrs & cpls dance towards each other &
    set. (2s & 3s step up or down on 3-4)
5-8::
    Retaining hands with ptnrs. 1s+4s pass each other LSh and turn top &
    bottom cpls with appropriate hand onto side lines. 2413
9-16::
    4L & 1L followed by ptnrs dance between end cpls, round end ladies,
    across between end cpls, round end men to finish on own sides.
17-24::
    2s+4s+1s dance the Knot to finish on own sides, ladies facing up,
    men down.
25-32::
    1s+4s+2s chase anticlockwise 1/2 way to opposite sides & cross over
    giving L hand & set. End  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8645, '2015-02-13 12:48:21.929589+00', '2023-02-04 01:22:56.424352+00', 6689, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up), meet to lead down, cross below 3s & cast
    up into 2nd place opp. sides
9-16::
    2s+1s+3s advance (2 steps), retire (2 steps). 1s turn RH to face up
    in promenade hold (1L on right of 1M)
17-24::
    1s+2s dance 1/2 RSh reel of 3 (1s pass 2L RSh), 1s+3s dance 1/2 RSh
    reel (1s pass 3M RSh)
25-32::
    1s (in prom. hold) dance up, cross, cast to 2nd place opp. sides
    (2) (1) (3);  2s+1s+3s turn partners RH 1.1/2 times to own sides', 0);
INSERT INTO 'dancecrib' VALUES (7684, '2013-08-21 08:31:46.871575+00', '2023-02-04 01:22:56.447358+00', 10977, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 2s followed by 1s dance down below 3s & cast up own
    sides 2s to top & 1s to 2nd place
9-16::
    2s+1s+3s set, 1s followed by 3s dance up to top & cast down own
    sides 1s to 3rd place & 2s to 2nd place
17-24::
    1s cross RH, cast up 1 place, lead down crossing & cast up to 2nd
    place own sides.  2 1 3
25-32::
    2s+1s turn on sides (Men LH & Ladies RH), 1s+3s turn on sides (Men
    RH & Ladies LH) but second time through turn 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (7685, '2013-08-21 08:31:46.879599+00', '2023-02-04 01:22:56.48004+00', 10524, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig of 8 (1s cross down to start)
9-16::
    1s cross down to dance reels of 3 on opposite sides & end facing 1st
    corners
17-24::
    1s turn 1st corner RH, partner LH, 2nd corner RH & pass RSh to 2nd
    place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14301, '2021-09-08 00:22:08.748586+00', '2023-02-04 01:22:56.50933+00', 20355, 3, NULL, 'ace', '1-8::
    1s lead down middle & back, remaining in  centre facing up
9-16::
    1s cast 1 place, meet & cross RH below 3s; 1s cast up 1 place, meet
    & cross up RH to 1st place facing out
::
    _while_ 2s cross up LH, cast 1 place, meet, cross LH below 3s & cast
    up to 2nd place facing up
17-24::
    Reels of 3 on sides giving hands (1s out/down, 2s in/up, 3s out/up
    to start). 1s end in 1st place facing up
25-32::
    1s cast to 2nd place _while_ 2s dance up to 1st place, 2s+1s dance
    RH across, 2s+1s+3s set', 0);
INSERT INTO 'dancecrib' VALUES (7686, '2013-08-21 08:31:46.88914+00', '2023-02-04 01:22:56.529749+00', 9584, 3, NULL, 'ace', '{{explanation}}
1s & 3s start on opp sides

1-8::
    2s+3s dance Ladies'' Chain
9-16::
    1s+2s also 3s+4s dance RH across & LH back
17-24::
    1s dance in & cast to bottom (2s+3s+4s step up), all set & cross RH
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7687, '2013-08-21 08:31:46.897133+00', '2023-02-04 01:22:56.556372+00', 9686, 3, NULL, 'ace', '1-8::
    1s cross down to double triangle position & set, 1s cast up & cross
    RH to original places facing out
9-16::
    1s+3s dance Fig of 8 round 2s (1s casting to start)
17-24::
    1M followed by partner casts below 3s, crosses, casts up 1 place &
    crosses to own side to end in 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7688, '2013-08-21 08:31:46.905692+00', '2023-02-04 01:22:56.589637+00', 9770, 3, NULL, 'ace', '1-8::
    1s set, cast 2 places & lead up to top _while_ 2s (bar 3) set, cast
    1 place & lead up to 2nd place _while_ 3s (bar 5) set, cast into
    middle
9-16::
    1s+2s+3s Promenade & end with 1s casting to 2nd place
17-24::
    1s cross down, cast up behind 3s, cross up & cast to 2nd place
25-32::
    All petronella turn into middle, set & turn partner RH 1.1/4 times', 0);
INSERT INTO 'dancecrib' VALUES (9935, '2017-06-05 11:31:52.921338+00', '2023-02-04 01:22:56.631297+00', 16456, 3, NULL, 'ace', '{{explanation}}
2 chords - 2nd chord 3s & 4s cross to opp sides

1-8::
    2s+3s set, dance La Baratte:
::
    _3-4_    Man 1/2 turns opposite Lady RH & retains hand but at arm''s
    length from each other
::
    _5-6_    Man retraces steps with Lady turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies original
    place) & releasing Ladies RH she turns under Mans left arm until
    almost in original places
::
    _7-8_    Couple change places LH to opposite places.  End 2L
    followed by 2M facing 1M, 3L followed by 3M facing 4M
9-16::
    Double diag alternating tandem reels of 4
::
    1s & 4s dance in, 1/2 LH across, dance out to opp place, loop round
    & dance back similarly _while_
::
    2s & 3s dance out to corner, change lead, dance back in, pass LSh,
    2s facing 1L, 3s facing 4L and dance last half of reel in same way.
    End 3L followed by 3M facing Men''s side, 2L followed by 2M facing
    Ladies'' side
17-20::
    1s+4s chase 1/2 round clockwise _while_ 3s+2s dance LH across.  End
    in centre 3s facing 4s (up), 2s facing 1s (down)
21-24::
    3M+4L, 3L+4M, 2M+1L & 2L+1M set, change places RH
25-28::
    3s+2s chase 1/2 round clockwise  _while_ 4s+1s dance LH across.  4s
    face up, 1s down NHJ with partner
29-32::
    2s+3s set, cross RH _while_ 4s+1s dance up/down out of ends & cast
    to 2nd/3rd place.  End 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (8366, '2014-07-29 12:59:35.130338+00', '2023-02-04 01:22:56.655269+00', 14541, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 1L followed by 1M+2M+3M casts off 2 places, dances
    across set, up Men''s side to 1M place (1M in 2M place, 2M in 3M
    place, 3M just past 3L)
9-16::
    3M (beckons) followed by 3L+2L+1L dance across below 3rd place,
    behind Men''s line, across set, down Ladies'' side to original places
    (1M+2M step up 15-16)
17-24::
    1s cross RH & cast off 1 place, 1s+3s dance LH across
25-32::
    2s+1s dance RH across, 1s turn RH 1.1/2 times     2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (7689, '2013-08-21 08:31:46.919208+00', '2023-02-04 01:22:56.675858+00', 13233, 3, NULL, 'ace', '1-8::
    All Ladies set & cast behind partner, dance RH across 1/2 way &
    dance LSh round opposite Man to end on his right
9-16::
    All Men set & cast behind other partner, dance LH across 1/2 way &
    dance RSh round own partner to end on her left
17-24::
    All set & turn partner RH, all set & turn corner LH
25-32::
    All dance 1/2 Schiehallion reel (2 places,Men leading) to original
    places
33-40::
    1s+3s dance RH across & end facing corner, 1M+3L+2s also 3M+1L+4s
    dance LH across
41-48::
    1s & 3s dance 3/4 Figs of 8 round facing couples & dance back to
    original places
49-56::
    2s+4s dance RH across & end facing corner, 2M+4L+3s also 4M+2L+4s
    dance LH across
57-64::
    2s & 4s dance 3/4 Figs of 8 round facing couples & dance back to
    original places
65-72::
    1s+3s also 2s+4s dance (interlocking) R&L (2s+4s change places RH on
    sides to start)
73-80::
    All dance Grand Chain (start RH to corner) 1/2 way, set & turn
    corner LH
81-88::
    All dance Grand Chain (start RH to partner) 1/2 way, turn partner RH
89-96::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7690, '2013-08-21 08:31:46.933685+00', '2023-02-04 01:22:56.694979+00', 13623, 3, NULL, 'ace', '{{explanation}}
3s &4s start on opp sides

1-8::
    1s & 4s 1/2 turn 2H in middle (1s facing down, 4s up) & join hands
    with 2s/3s, all set then advance 1 step & retire
9-16::
    1s & 4s dance reel of 4 down/up middle with Ladies passing LSh to
    start as partners set & Men dance LSh round each other then pass
    other Lady RSh to meet partner & turn RH 1.1/4 times to face 2s/3s
    (Man facing Lady)
17-24::
    1s+2s also 4s+3s dance reels of 4 across & 1s end 2nd place opposite
    sides as 4s end 3rd place own sides
25-32::
    1s+4s Set+Link & circle 4H round to left.  2 4(1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (7691, '2013-08-21 08:31:46.942282+00', '2023-02-04 01:22:56.810635+00', 9687, 3, NULL, 'ace', '{{explanation}}
2s & 4s start on opp sides

1-8::
    1s+2s also 3s+4s dance RH across & LH back
9-16::
    1s+2s also 3s+4s dance Ladies'' Chain to end 1s & 3s facing down, 2s
    & 4s facing up
17-24::
    All dance LSh reels of 4 on sides
25-32::
    All set to partner, dance 1/2 R&L & set
33-40::
    1s & 4s lead out nearer end of set, cross, cast 1 place & turn
    person approaching on side 1.1/2 times LH to end 2 (4) 1 (3)', 0);
INSERT INTO 'dancecrib' VALUES (8646, '2015-02-13 12:48:22.017375+00', '2023-02-04 01:22:56.821137+00', 14970, 3, NULL, 'ace', '1-8::
    All 4 couples Adv+Ret. All 1/2 turn partner RH, face, pull back RSh
    and dance out to partner''s place.
9-16::
    1s+2s also 3s+4s dance Spiral Progression:
::
    ''9-12    1M+2L turn RH, give LH to partner, Bal-in-Line, 1L+2M pull
    back LSh to join nearer hands with partners
::
    ''13-14   1s+2s, in diag. line, dance clockwise 1 place round
::
    ''15-16   1L+2M drop hands, dance on to next place on side _while_
    1M+2L continue RH turn to own sides opposite partners
::
    ''3s+4s dance similarly to finish 2 1 4 3
17-24::
    Reel of 4 on sides (2s+1s also 4s+3s pass RSh).  At end do not pass
    LSh but 4L+1L also 4M+1M 1/2 turn LH to finish on sides, Men facing
    in/down, Ladies facing in/up
25-28::
    2s+3s set and cross RH _while_ 1L followed by 4L dances 1/2 Fig 8
    round 2s as 4M followed by 1M dances 1/2 Fig 8 round 3s  (2) (4) (1)
    (3)
29-32::
    All set and cross RH', 0);
INSERT INTO 'dancecrib' VALUES (13640, '2021-02-04 01:22:05.344015+00', '2023-02-04 01:22:56.831178+00', 9446, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place (2s step up bars 3-4); 1s dance 1/2 Figs of 8
    (1L down round 3s, 1M up round 2s) to finish facing 1st corners
9-16::
    1s dance 1/2 LSh diagonal reel, 1s pass LSh to face 2nd corners; 1s
    dance 1/2 RSh diagonal reel. End: 1s pass RSh to face 1st corner
    pstn
17-24::
    1s set to corners, pull back RSh dance round each other to face 2nd
    corners pstn; 1s set to corners. 1s pull back RSh & dance round each
    other to 2nd place own side
25-32::
    1s set pulling back RSh to face clockwise _while_ 3s+2s cross RH,
    all chase 1/4 way clockwise to lines across; all cross RH with
    partner, all chase 1/4 way clockwise to end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7692, '2013-08-21 08:31:47.045283+00', '2023-02-04 01:22:56.842688+00', 14668, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place, set & cross RH to face out
9-16::
    2s+1s+3s dance reels on the sides giving RSh to 1st corner & end
    BtoB ready for….
17-24::
    1s dance Double Triangles & end in middle on opposite sides facing
    down
25-32::
    1s lead down between 3s crossing & cast up behind 3s, dance up
    between 2s & cast to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (12946, '2020-07-01 00:21:48.532569+00', '2023-02-04 01:22:56.852416+00', 17610, 3, NULL, 'ace', '1-8::
    1s+2s set, dance 3/4 R&L (1L no polite turn)
9-16::
    RSh reels of 3 on sides (1L down, RSh to 3L, 1M up, RSh to 2M)
17-24::
    2s+1s+3s+4s circle 8H round & back
25-32::
    1s set, cast to 4th place (3s+4s step up); all 4 couples turn
    partner 2H.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7693, '2013-08-21 08:31:47.051106+00', '2023-02-04 01:22:56.862128+00', 10865, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All set, cross RH, set & cross back RH
9-16::
    All circle 8H round to left for 3 bars, pivot left & dance back to
    places
17-24::
    1s+2s also 3s+4s dance Allemande
25-32::
    2s+1s also 4s+3s dance RH across, middle couples (1s+4s) dance LH
    across

{{title}}
Reel

{{explanation}}
As per Strathspey except bars 9-12 where 6 slip steps are danced', 0);
INSERT INTO 'dancecrib' VALUES (12751, '2020-04-11 10:53:22.090155+00', '2023-02-04 01:22:56.872031+00', 9655, 3, NULL, 'ace', '1-8::
    2L+1s & 2M+3s dance RH across; 2s pass RSh to dance LH across with
    other couple
9-10::
    1s+3s turn partner 3/4 RH into centre, Men facing up, Ladies facing
    down (2s step down)
11-14::
    1s+3s dance 1/2 RSh reel of 4
15-16::
    3s+1s turn partner 3/4 RH staying in centre facing up, Ladies on
    right of partner, ready for …
17-24::
    3s+1s dance Allemande
25-32::
    1s+3s+2s set and cross RH & circle 6H 1/2 round to own sides.  End 2
    3 1', 0);
INSERT INTO 'dancecrib' VALUES (14741, '2022-04-01 00:22:04.744376+00', '2023-02-04 01:22:56.882019+00', 14494, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    1s cast behind 2s (2s step up), dance in & touch hands, dance behind
    3s, dance in & touch hands; 1s cast & retrace steps to 1st place, 1L
    facing out (2s step down bar 8)
9-16::
    1L followed by 1M dances behind 2L, across set, behind 3M & 1s dance
    up NHJ to end BtoB in 2nd place facing own side (2s step up 11-12)

{{title}}
Reel

17-20::
    2s+1s+3s set (Double Triangles) & 1s PdB out turning right about to
    face in _while_ 2s+3s PdB in turning right about to face 1s
21-24::
    2s+1s+3s set (Inverted Triangle formation) & 1s PdB continue setting
    _while_ 2s+3s PdB to places & face in.  2 1 3
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7694, '2013-08-21 08:31:47.059709+00', '2023-02-04 01:22:56.891947+00', 10778, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    All Ladies dance RH across 1/2 way, dance LH across 1/2 way with
    opposite Man on right hand to end Ladies (BtoB) facing Men
17-24::
    All set, Ladies 1/2 turn Men into middle & Men dance LH across 1/2
    way to end in original places facing partner
25-32::
    All dance Grand Chain
33-40::
    1s+3s dance into middle, lead with opposite partner out thru sides,
    cross & cast to opposite places & turn partner RH 1.1/2 times
41-48::
    2s & 4s repeat
49-56::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L to end in original places
57-64::
    All dance Allemande anticlockwise

{{explanation}}
Repeat as reel', 0);
INSERT INTO 'dancecrib' VALUES (7695, '2013-08-21 08:31:47.069838+00', '2023-02-04 01:22:56.901934+00', 13394, 3, NULL, 'ace', '1-8::
    1s dance Inveran reels with 2s+3s
9-20::
    _1_+2s+3s dance 3 couple R&L
21-24::
    _1_+2s+3s set & 1s cast down 1 place as 2s dance up to top.  2 1 3
25-32::
    1s+3s dance the Espagnole to end 2 3 1:
::
    _25-26_   1s+3s cross (Ladies lead across RH passing between Men)
    with Ladies changing places RH
::
    _27-28_   1s+3s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _29-32_   3s turn RH as 1s turn LH to places', 0);
INSERT INTO 'dancecrib' VALUES (7696, '2013-08-21 08:31:47.078254+00', '2023-02-04 01:22:56.912122+00', 12905, 3, NULL, 'ace', '1-8::
    1s+3s dance reel of 4, (Men pass LSh to start as Ladies dance into
    partners place) & Men end in own places as Ladies end crossing to
    own places
9-16::
    1M+2L+3M+4L dance diag reel of 4, (Ladies pass LSh to start as Men
    dance into crnrs pl) & Ladies end in own pls as Men end cross to pls
17-24::
    2s+4s repeat reel of 4 in bars 1-8
25-32::
    2M+3L+4M+1L repeat bars 9-16
33-40::
    1s & 3s 3/4 turn partners RH & Men cast clockwise 1/4 way as Ladies
    turn LH 3/4 way, 1s+2s also 3s+4s dance RH across
41-48::
    Then dance LH across, 1L+3L 3/4 turn RH as Men cast to own places &
    turn partner LH to places
49-64::
    2s & 4s repeat bars 33-48
65-72::
    Ladies dance Fig of 8 dancing in front of partner & behind next Man
73-80::
    Men dance Fig of 8 dancing in front of partner & behind next Lady
81-88::
    Men set advancing turning right about to face partner & set, all
    change places with partner & set
89-96::
    All turn partners RH & LH & end with Bow & curtsey (Ladies BtoB in
    centre)', 0);
INSERT INTO 'dancecrib' VALUES (7697, '2013-08-21 08:31:47.086633+00', '2023-02-04 01:22:56.921819+00', 7273, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, set again & turn RH to face 1st corners
9-16::
    1s 3/4 turn 1st corners LH & retaining hands set, 1s+1st corners
    dance 1/2 Diag R&L & 1s end facing 2nd corners
17-24::
    1s 3/4 turn 2nd corners RH & retaining hands set, 1s+2nd corners
    dance 1/2 Diagonal L&R
25-32::
    1s turn LH _while_ corners chase 1/2 way clockwise, 1s dance RH
    across (1L with 2s, 1M with 3s) ending in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (7698, '2013-08-21 08:31:47.094665+00', '2023-02-04 01:22:56.931302+00', 14201, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance 1/2 R&L, 1s+4s dance 1/2 R&L as 2s & 3s cross
    RH
9-16::
    All set & 2s+4s also 1s+3s dance 1/2 RH across & chase clockwise
    back to own sides
17-24::
    2s+4s also 1s+3s circle 4H round & back
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7699, '2013-08-21 08:31:47.102719+00', '2023-02-04 01:22:56.940884+00', 6701, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, turn RH 1.1/2 times to end in promenade
    hold facing 2M
9-16::
    1s dance 1/2 RSh reel of 3 on Man''s side, cross to face 3L & dance
    1/2 RSh reel on Ladies'' side 1s end facing 3L (in top place), still
    in prom hold
17-24::
    1s set to 3L, swivel right & set to 2L, set to 2M, set to 3M (2s+3s
    set advancing into centre) ready for …
25-32::
    3s+1s+2s Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7700, '2013-08-21 08:31:47.111263+00', '2023-02-04 01:22:56.950526+00', 8558, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s turn RH & cast in 1 place, dance LH across 1/2 way & 1/2
    turn corners RH
9-16::
    2s+4s & 1s+3s dance reels of 4 across dance.  End 2 4(1)(3)
17-24::
    4s & 1s cross to face partners corners on the diag & set, 1/2 turn
    corners RH, 2s+3s join LH to form St Andrew''s cross & all
    Bal-in-Line
25-32::
    2s & 3s 1/2 turn corners RH with 1s & 4s turning to face partners
    (in middle) & all set, 4s & 1s lead out of ends, cross & cast to
    2nd/3rd places', 0);
INSERT INTO 'dancecrib' VALUES (14231, '2021-08-14 00:22:16.547277+00', '2023-02-04 01:22:56.960141+00', 12410, 3, NULL, 'ace', '{{explanation}}
Dawn of the Century

1-8::
    1M sets, 1s set; 1s+2L set, 1s+2s set

{{explanation}}
The pace quickens

9-16::
    1s cross down to dance reels of 3 on opposite sides (1L LSh to 3M,
    1M RSh to 3L)
17-24::
    1s cross down to dance reels of 3 on own sides (1M LSh to 3M, 1L RSh
    to 3L)

{{explanation}}
Showing off its achievements

25-32::
    1s+2s+3s dance Allemande 3 2 1 4

{{explanation}}
A lively close

33-36::
    1s cross, cast 1 place (4s step up bars 35-36), 2s cross & cast 1
    place (3s step down 1 place 35-36)
37-40::
    1s+2s dance Reel of Tulloch turns with partner to finish on own
    side.

{{explanation}}
Note: 2s must finish on side by bar 40 as 2M has to be in place to start the dance next time through', 0);
INSERT INTO 'dancecrib' VALUES (7701, '2013-08-21 08:31:47.119585+00', '2023-02-04 01:22:56.969951+00', 14460, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place to meet in middle facing 2L (nearer hands
    joined), 1s set to 2L & turn inwards & set to 3M
9-16::
    1s+3M dance RH across, 1s+2L dance LH across & 1s end facing out in
    2nd place opposite sides
17-24::
    1s cast down below 3s & dance up to face 2M (nearer hands joined).
    1s set to 2M & turn inwards & set to 3L
25-32::
    1s+3L dance RH across, 1s+2M dance LH across
33-40::
    1s dance reels of 3 on sides giving LSh to 1st corner to start & 1s
    cross RH', 0);
INSERT INTO 'dancecrib' VALUES (7702, '2013-08-21 08:31:47.127634+00', '2023-02-04 01:22:56.97971+00', 11915, 3, NULL, 'ace', '1-8::
    2s & 3s dance 1/2 Figs of 8 round 1s/4s, cross (Ladies under Men''s
    arch) & turn corners with nearer hand into lines across facing other
    line of 4
9-16::
    All Coupe PdB twice, all Ladies dance 1/2 R&L _while_ Men also dance
    1/2 R&L (cross up/down to start), 2s & 3s end facing corners
17-24::
    All dance reels of 4 across & end with 2s in1st place & 3s in 4th
    place
25-32::
    1s+4s dance RH across _while_ 2s+3s set & change places RH on sides,
    4s & 1s dance out of ends & cast in to 2nd/3rd places.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8793, '2015-06-15 11:41:17.20424+00', '2023-02-04 01:22:56.990027+00', 16122, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, 1s face out & cast (2s step up) & 1s turn RH
    to face out on opp sides  (2) (1) (3)
9-16::
    Promenade (Chaperoned) Chain progression:
::
    _9-10_       2s & 3s 3/4 turn partner RH into middle _while_ 1s
    dance clockwise 1/4 round the set picking up 2M/3L …
::
    _11-14_     who promenade  1/2 way clockwise  _while_ middle people
    (3M + 2L) turn LH 1.1/2 .
::
    _15-16_     2s & 3s turn partner RH 3/4 to own sides _while_ 1s
    dance clockwise 1/4 round to join RH in centre & LH with 1st crnr
    pstn.
17-24::
    1s dance The Spoke
::
    _17-18_     Bal-in-Line with 1st corner positions, drop LH & dancing
    couple move clockwise to next corner
::
    _19-24_     Repeat with next 3 corners (all couples PdeB for 8 bars)
    (3) (1) (2)
25-32::
    3s+1s+2s dance LSh reels of 3 on opp sides (1L up, LSh to 3L, 1M
    down, LSh to 2M). 1s end in 2nd place opp sides
33-40::
    3s+1s+2s Set+Link twice.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7703, '2013-08-21 08:31:47.135649+00', '2023-02-04 01:22:56.999587+00', 6705, 3, NULL, 'ace', '1-8::
    1s+2s  dance double Fig 8 (1s cast & cross up, 2s dance up to 1st
    place & cast to start) 2s end in 2nd place on opp side
9-16::
    1s+2s dance Ladies'' Chain.
17-24::
    1s dance down the middle & back to 2nd place _while_ 2s set, cross
    down below 3s & cast up to 1st place own side
25-32::
    2s+1s+3s dance reels of 3 on own sides (1s dance out & up to start)', 0);
INSERT INTO 'dancecrib' VALUES (15082, '2022-09-05 00:22:14.409876+00', '2023-02-04 01:22:57.009808+00', 20799, 3, NULL, 'ace', '1-8::
    1s dance down middle & back
9-16::
    1s cast (2s step up), 1s+3s dance RH across, 2s+1s+3s+4s set
17-24::
    1s dance down, out between 3s & 4s on own side & into 4th place (3s
    & 4s step up 19-20); 1s+4s dance LH across
25-32::
    All 4 couples Adv+Ret; all turn partners 2H.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7704, '2013-08-21 08:31:47.143786+00', '2023-02-04 01:22:57.020064+00', 6707, 3, NULL, 'ace', '1-8::
    3s dance petronella to opposite sides
9-16::
    All set, dance DoSiDo & set
17-24::
    3s dance reels of 3 across, 3L with 2s (RSh to 2L) & 3M with 4s (RSh
    to 4M)
25-32::
    3s dance reels of 3 across, 3L with 1s (RSh to 1L) & 3M with 5s (RSh
    to 5M) & 3s end in centre at top/bottom facing down/up
33-40::
    3s set twice advancing towards each other & turn 2H ending in 2nd
    place own side _while_ 1s set twice & cast to 5th place', 0);
INSERT INTO 'dancecrib' VALUES (7705, '2013-08-21 08:31:47.152008+00', '2023-02-04 01:22:57.047948+00', 14748, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 1 place, 1s cross LH & cast to bottom then cross
    up 2nd place opposite sides facing up
9-16::
    1L dances LH across with 2M+3M _while_ 1M dances RH across with
    2L+3L, 1s lead up to top crossing & cast to 2nd place own sides
17-24::
    1s dance reflection reels of 3 on own sides (1s dance in & down)
25-32::
    All Adv+Ret, 1s turn RH & cast to bottom
33-40::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7706, '2013-08-21 08:31:47.160169+00', '2023-02-04 01:22:57.059144+00', 14244, 3, NULL, 'ace', '1-8::
    All set & cross RH, all set & 1s+3s 3/4 turn RH into middle _while_
    2s cross RH
9-16::
    All dance a Weasel Reel : 1s+3s dance part reel of 4 up/down middle
    but when reaching either end they dance clockwise to top/bottom to
    re-enter reel _while_ 2s dance clockwise to replace the dancer
    leaving the reel & all end where they started
17-24::
    1M also 3L followed by partners chase round clockwise to end on
    opposite sides  (1)2(3)
25-32::
    2s dance Diag R&L (M down) to 3 2 1
33-40::
    1s set & cast up 1 place, all turn RH

{{explanation}}
Note - (Weasel Reel - Men always reel down middle & dance up Mens side while Ladies always reel up middle & dance down Ladies side)', 0);
INSERT INTO 'dancecrib' VALUES (7708, '2013-08-21 08:31:47.176508+00', '2023-02-04 01:22:57.082605+00', 6710, 3, NULL, 'ace', '1-8::
    1s cast 1 place & turning to Right form lines of 3 across (1L with
    2s & 1M with 3s), lines Adv+Ret (up/down)
9-16::
    1s cast round behind person on their Left & cross to other couple
    (changing places with partner), lines again Adv+Ret
17-24::
    1s set advancing for 2 steps, set retiring & cast round behind
    person on their left to 2nd places opposite sides
25-32::
    2s+1s dance R&L
33-40::
    2s+1s dance DoSiDo with partner then DoSiDo with 2s on the sides
41-48::
    1s cross RH & cast up to top, set & cast back to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7710, '2013-08-21 08:31:47.192589+00', '2023-02-04 01:22:57.31181+00', 10168, 3, NULL, 'ace', '1-8::
    1s dance Inveran reels with 2s+3s
9-16::
    1s & 3s set, turn 2H & end 1s facing 2L & 3s facing 2M, 2L dances
    under arch made by 1s (to 2L+1L+1M on Ladies side) _while_ 2M dances
    under arch made by 3s (to 3L+3M+2M on Men''s side) & all chase for 2
    steps to 3 2 1
17-24::
    3s+2s+1s lead down & back
25-32::
    3s+2s dance Allemande.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (9421, '2016-10-06 07:19:02.303323+00', '2023-02-04 01:22:57.326556+00', 17141, 3, NULL, 'ace', '1-8::
    1s set, 1M sets twice _while_ 1L dances round 1M passing RSh & back
    to place. 1s cross RH, 1L ends facing up
9-16::
    1s+2s dance Men''s Chain up/down set finishing on sidelines
17-24::
    1s+2s set, pull back RSh, dance 1 place clockwise into 1s+2s dance
    RH across
25-32::
    1s+2s change places RH on sides with partner, chase 1 place
    clockwise. 1s turn 1.1/2 RH

{{explanation}}
Each 2nd repetition modify as follows:

::
    _1-8_    1s set, 1L sets twice _while_ 1M dances round 1L passing
    LSh & back to place. 1s cross LH, 1M ends facing up
::
    _9-16_  1s+2s dance Ladies'' Chain up/down set finishing on sidelines

{{explanation}}
Note:	Bars 3-6      1M or 1L may use highland setting

::
    Bars 29-32  1s may use pivot turn (Right elbow grip)', 0);
INSERT INTO 'dancecrib' VALUES (7711, '2013-08-21 08:31:47.200738+00', '2023-02-04 01:22:57.336423+00', 11170, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    All dance reels of 4 on sides
9-16::
    1s+2s also 3s+4s circle 4H round to left, 1s & 4s cast in 1 place &
    lead up/down to places _while_ 2s & 3s cross up/down & cast in 1
    place
17-24::
    All dance interlocking Allemandes:
::
    1s+3s dance Allemande up to end in 3rd/1st places _while_ 2s+4s
    Allemande down to end 4th/2nd places.  3(4)1(2)
25-32::
    4s+1s dance the Bourrel :
::
    4L+1L set advancing, 3/4 turn 2H & twirl to end BtoB (1L facing up &
    4L down) _while_ partners chase anticlockwise 1/2 way to face
    partners
::
    1s+4s set to partners & 3/4 turn 2H to sides having changed places.
    3 1 (4) (2)', 0);
INSERT INTO 'dancecrib' VALUES (7712, '2013-08-21 08:31:47.210646+00', '2023-02-04 01:22:57.347818+00', 6712, 3, NULL, 'ace', '1-4::
    1s & 4s cross RH _while_ 2s+3s dance 1/2 RH across, 1s+3s & 2s+4s
    change places LH on sides
5-16::
    Repeat 1-4 another 3 times (end cpls cross RH, middle cpls 1/2 RH
    across;  cpls in 1st+2nd place also 3rd+4th place change places LH)
    All finish in original places
17-24::
    1s set to 2s & cross over to face 3s (2s dance up), set & cross to
    face 4s (3s dance up)
25-32::
    1s set to 4s & cross over to 4th place on opposite sides (4s dance
    up), all Adv+Ret 2 steps & 1s change places RH (2H popular) to
    retire to own sides', 0);
INSERT INTO 'dancecrib' VALUES (7713, '2013-08-21 08:31:47.218682+00', '2023-02-04 01:22:57.357117+00', 6713, 3, NULL, 'ace', '1-8::
    1s lead up (for 2) & back _while_ 4s lead down & back, 1s & 4s cross
    RH & cast in 1 place to face corners & all set
9-16::
    All 1/2 turn corners RH & Bal-in-Line, 1/2 turn RH & Bal-in-Line
17-24::
    1s+4s dance LH across, 1s+4s dance 1/2 R&L
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7317, '2013-08-21 08:31:38.86172+00', '2023-02-04 01:22:57.366575+00', 10501, 3, NULL, 'ace', '1-8::
    1s set, cross down RH to double triangle position with 2s+3s & set,
    1s turn 1st corners RH into 2nd place opposite sides
9-16::
    1s dance reels of 3 on sides passing 2nd corners LSh & end crossing
    to 2nd place own sides
17-24::
    1s dance reels of 3 on own sides passing 3rd corner RSh
25-32::
    1s turn 3rd crnrs RH into lines of 3 across (1M between 2s facing
    down & 1L between 3s facing up) & all set, 1s pass RSh & cast to 2nd
    pl
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7807, '2013-08-21 08:31:48.88677+00', '2023-02-04 01:23:02.71665+00', 6885, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette finishing back on sides
9-16::
    1s take prom hold (Lady on Man''s right) & dance a Fig of 8 round the
    2s passing 2L RSh
17-24::
    1s lead down the middle & back
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7714, '2013-08-21 08:31:47.234612+00', '2023-02-04 01:22:57.376381+00', 12528, 3, NULL, 'ace', '1-8::
    All dance interlocking reels of 4
9-16::
    1s+3s dance RH cross & LH back
17-24::
    1s+3s Allemande hold dance in, Men passing LSh & dance LH across for
    4 bars & twirl to face 2s/4s (1s & 3s BtoB with partner)
25-32::
    All dance reels of 4 across
33-40::
    1s & 3s dance between 2s/4s crossing LH & dance back to places &
    turn partner RH
41-72::
    2s+4s repeat bars 9-40
73-80::
    All dance in nearer hand joined with partner, set & turn right
    about, dance out with corner, set & turn right about
81-88::
    All dance in nearer hand joined with corner, set & turn right about,
    dance out with partner, set & turn right about
89-96::
    All Promenade round back to places', 0);
INSERT INTO 'dancecrib' VALUES (9493, '2016-11-09 08:49:06.379436+00', '2023-02-04 01:22:57.478759+00', 15437, 3, NULL, 'ace', '1-8::
    1L followed by 2L+3L dance across top, down behind Men & back to
    place
9-16::
    3M followed by 2M+1M dance across, up behind Ladies & down middle of
    set.  Bar 16 Ladies dance in to join RH with partner, all facing
    down
17-24::
    All lead down & back,  3s dancing to place _while_ 1s+2s remain in
    middle ready for...
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (12116, '2019-09-01 13:59:07.702966+00', '2023-02-04 01:22:57.491065+00', 19583, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s lead down, cross below 3s (2s step up 9-10), 1/2 turn 3s (1M+3L
    LH, 1L+3M RH) &  dance 1/2 Fig of 8 round 3s to end in 2nd place own
    sides
17-24::
    1s followed by 2s lead down the middle, 2s divide to let 1s lead
    back up, staying in the middle ready for …
25-32::
    1s+2s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7715, '2013-08-21 08:31:47.242838+00', '2023-02-04 01:22:57.518439+00', 13745, 3, NULL, 'ace', '1-8::
    1s cross RH & cast below 3s, cross LH & cast up round 3s to face 1st
    corners
9-16::
    1s dance 1/2 RSh reel of 4 with 1st corners & turn LH to face 2nd
    corners
17-24::
    1s dance 1/2 reel of 4 with 2nd corners & turn LH 1.1/2 times in
    middle to end facing opposite sides
25-28::
    1s dance RH across (1L with 3s at top, 1M with 2s) with 1s ending
    2nd place opposite sides
29-32::
    3s+1s+2s chase clockwise 1/2 way to 2 1 3 on own sides', 0);
INSERT INTO 'dancecrib' VALUES (7716, '2013-08-21 08:31:47.250808+00', '2023-02-04 01:22:57.528039+00', 3300, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1L followed by 2L+3L dances across, 1L followed by 3L only dances
    down behind 1M, in front of 2M & behind 3M _while_ 2L dances down
    behind Men''s line & up Ladies side followed by 1L+3L to end 2L 1L 3L
17-24::
    1M followed by 2M+3M repeat
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7718, '2013-08-21 08:31:47.270673+00', '2023-02-04 01:22:57.647086+00', 11586, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, 2s+1s+3s Adv+Ret
9-16::
    1s cross LH & 1L casts up to end between 2s _while_ 1M casts down to
    end between 3s & 2s+1s+3s Adv+Ret
17-24::
    1s dance reels of 3 across (RSh to person on right) & end facing 1st
    corners
25-32::
    1s turn 1st corners RH, passing RSh turn 2nd corner RH & pass RSh to
    2nd places own sides', 0);
INSERT INTO 'dancecrib' VALUES (7719, '2013-08-21 08:31:47.27875+00', '2023-02-04 01:22:57.656505+00', 6721, 3, NULL, 'ace', '1-8::
    1s+2s set twice & cross RH
9-16::
    1L+2L turning towards each other cast & cross to stand beside
    partner on Ladies side, 1M+2M turn towards each other & cross back
    to places
17-24::
    1s lead down the middle below 3s, cast up 1 place & lead up between
    2s to places
25-32::
    1s cross RH, cast 1 place & turn 2H 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (7720, '2013-08-21 08:31:47.289+00', '2023-02-04 01:22:57.668403+00', 7992, 3, NULL, 'ace', '1-8::
    1s turn RH, dance down & dance 1/2 Fig 8 round 3s.
9-16::
    1s dance 1/2 Fig 8 round 2s & turn LH 1.1/4 times to face 1st
    corners
17-24::
    1s diagonal reel of 4 with 1st corners, pass RSh & end facing 2nd
    corners
25-32::
    1s dance reels of 3 on opposite sides (RSh to 2nd corners) end
    passing RSh to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (9759, '2017-04-06 08:40:22.244815+00', '2023-02-04 01:22:57.678023+00', 6722, 3, NULL, 'ace', '1-8::
    1s lead down and back, remaining in centre facing up
9-16::
    1s cast behind 2s, meet, dance down between 3s, cast up & cross to
    face 1st corners (2s step up 9-10)
17-24::
    1s set to 1st corner, turn 2H, set to 2nd corner, turn 2H to end on
    sides between corners
25-32::
    1s cross RH, 2s+1s+3s dance RH across once round to Left', 0);
INSERT INTO 'dancecrib' VALUES (13445, '2020-12-02 01:22:06.997704+00', '2023-02-04 01:22:57.68753+00', 6725, 3, NULL, 'ace', '1-8::
    1s turn 2H (skip change) & face up NHJ; 1s cast, dance in between 2s
    & 3s, cast up round 3s into 2nd place (2s step up 7-8)
9-16::
    1s turn 2H (skip change) & face up; 1s lead up, cast round 2s to
    face 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting ending with Petronella turn to 2nd
    place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13098, '2020-08-10 00:21:43.139032+00', '2023-02-04 01:22:57.697139+00', 7994, 3, NULL, 'ace', '1-8::
    Top 3 Men & bottom 3 Ladies set & change places RH diagonally;
    3L+1M+4L+2M (middle couples) dance 1/2 RH across
9-16::
    Top 3 Ladies & bottom 3 men set & change places LH diagonally (all
    now  facing partners on opp sides); 1s+4s (middle couples) dance 1/2
    LH across.  (2) 4 1 (3)
17-24::
    4M+1L change places RH, 1M+4L change places LH; All 4 couples set,
    turn partner RH remaining in centre ready for Poussette.  2 1 4 3
25-32::
    2s+1s & 4s+3 dance Poussette.  1 2 3 4
33-40::
    1s & 3s slip step down middle (4 steps), set (2s & 4s step up); 1s &
    3s slip step up to 2nd/4th place in centre (4 steps) & set _while_
    4s set advancing to partner & 1s+4s+3s face up
41-48::
    1s+4s+3s dance allemande.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7721, '2013-08-21 08:31:47.297188+00', '2023-02-04 01:22:57.706943+00', 8367, 3, NULL, 'ace', '1-8::
    1s set & 1/2 turn 2H, 1s dance down to 2nd place & dance RSh round
    1st corners to face 2nd corners
9-16::
    1s 1/2 turn 2nd corners 2H & 1s+2nd corners pass RSh to dance 3/4
    reel of 4 with original 2nd corner persons ending in diagonally
    opposite corners then 1s pass LSh to face 1st corners
17-24::
    1s 1/2 turn 1st corners 2H & 1s+1st corners pass RSh to dance 3/4
    reel of 4 with original 1st corner persons ending in diagonally
    opposite corners then 1s pass LSh to face 4th corner (pstn)
25-28::
    1s dance RSh round 4th corners & pass RSh to face 1st corner (pstn)
    as original 2nd corner persons dance back to places with a 1/2 turn
    & twirl
29-32::
    1s dance RSh round 1st corners & pass RSh to 2nd place own sides as
    original 1st corner persons dance back to places with a 1/2 turn &
    twirl', 0);
INSERT INTO 'dancecrib' VALUES (7723, '2013-08-21 08:31:47.317969+00', '2023-02-04 01:22:57.73276+00', 7557, 3, NULL, 'ace', '1-8::
    1s set & dance down between 2s, dance out behind 3s & dance up
    between 3s to face 1st corners
9-16::
    1s set & turn 1st corners RH to face 4th corner, 1s dance 1/2 LSh
    reel of 3 across & 3/4 turn LH to face 3rd corner (pstn)
17-24::
    1s set & turn 3rd corners RH to face 2nd corner (pstn), 1s dance 1/2
    LSh reel of 3 across & end 2nd place own sides
25-32::
    1s set & cross RH, set again & cross RH _while_ 2s+3s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (8413, '2014-10-02 21:08:36.709591+00', '2023-02-04 01:22:57.752771+00', 802, 3, NULL, 'ace', '1-8::
    1s set & 1/2 turn LH, lead down below 3s, cross & cast up round 3s
    to give LH to partner in diag line between 1st corners
9-16::
    1s dance Corner Targe with 1st corners :
::
    _9-12_   corners chase clockwise to next corner _while_ 1s 3/4 turn
    LH & 1s turn 1st corners (in 4th corner pstn) RH _while_ 2nd corners
    set
::
    _13-16_   corners chase clockwise to next corner _while_ 1s 3/4 turn
    LH & 1s turn 1st corners (in 3rd corner pstn) RH to end between 2nd
    corners _while_ 2nd corners set
17-24::
    1s dance Corner Targe with 2nd corners, 1s finish in 2nd place
    opposite sides
25-32::
    2s+1s+3s dance 6H round and back (6 bars), end of bar 6 all drop
    hands, 1s dance round each other by LSh to own side 2nd place
    _while_ 2s+3s chase anticlockwise to 1st & 3rd place', 3);
INSERT INTO 'dancecrib' VALUES (11219, '2018-09-30 22:20:40.734817+00', '2023-02-04 01:22:57.762342+00', 18590, 3, NULL, 'ace', '{{explanation}}
1s+2s also 4s+5s face on sides, 3s face in ready for chord

1-12::
    1s+2s+4s+5s dance 12 bar RSh reel of 4 around standing 3s (all pass
    3s LSh)
13-16::
    3s turn RH & face out
17-24::
    1s+2s also 4s+5s set, dance 1/2 RH across; set, dance LH across
    _while_
::
    3s dance clockwise 1/2 round set to 3rd place opp sides (6 bars),
    pass RSh to own side & face in
25-32::
    1s set, cast to 3rd place (2s+3s step 27-28); set, cast to 5th place
    (4s+5s step 31-32).  2 3 4 5 1

{{explanation}}
Note:  Each repeat the top 2 & bottom 2 couples dance reel around standing middle couple', 0);
INSERT INTO 'dancecrib' VALUES (14381, '2021-10-11 22:42:20.280366+00', '2023-02-04 01:22:57.771673+00', 17886, 3, NULL, 'ace', '1-4::
    All set & cross RH with partner.
5-8::
    All set & cross RH with partner
9-16::
    1s lead down the middle & back
17-24::
    1s+2s dance Allemande 2 1 3
25-32::
    All circle 6H round & back 2 1 3

{{explanation}}
Note: 1s repeat from 2nd place, with 1s+3s dancing Allemande, 1s finish in 3rd place for the circle. Begin with new 1st couple.', 0);
INSERT INTO 'dancecrib' VALUES (7725, '2013-08-21 08:31:47.336095+00', '2023-02-04 01:22:57.782693+00', 15027, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret for 2 steps, cross RH & chase clockwise to end
    facing partner in lines across
9-16::
    1s+2s+3s Adv+Ret for 2 steps, change places with partner LH & chase
    anticlockwise back to original places
17-24::
    1s+2s+3s circle 6H round & back
25-32::
    1s dance 1/2 Figs of 8 round 2s, cross RH & cast 1 place', 0);
INSERT INTO 'dancecrib' VALUES (7726, '2013-08-21 08:31:47.414683+00', '2023-02-04 01:22:57.792416+00', 6734, 3, NULL, 'ace', '1-8::
    1s set, cast 2 places & dance up to top (end with 2s stepping in
    below 1s)
9-16::
    1s+2s dance Poussette (end with 1s facing 1st corners)
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners, pass LSh & dance
    1/2 reel with 2nd corners (1s end 2nd place opposite side)
25-32::
    3M+1M+2M petronella turn into centre & set _while_ 3L+1L+2L set &
    petronella turn into centre, all turn partners RH (end in Allemande
    hold)
33-40::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7727, '2013-08-21 08:31:47.423045+00', '2023-02-04 01:22:57.801947+00', 6736, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, dance down between 3s & cast up on
    opposite sides to face 1st corners
9-16::
    1s set to 1st corner, set to 4th corner & turn RH to end on sides,
    2s+1s+3s set
17-24::
    1s dance reels of 3 across, 1M with 2s & 1L with 3s
25-32::
    2s+1s+3s dance Allemande
33-40::
    1s cross RH, 3L+2M change places RH, 3M+2L change places RH &
    2s+1s+3s cross back RH', 0);
INSERT INTO 'dancecrib' VALUES (7728, '2013-08-21 08:31:47.431116+00', '2023-02-04 01:22:57.811783+00', 9046, 3, NULL, 'ace', '1-8::
    1s+2s set & dance RH across 1/2 way, 1s+2s set & cross RH 1s remain
    facing out
9-14::
    1L casts below 3L & dances across below 3M & casts up to 2nd place
    opp side as 1M casts up & dances across above 2L & cast to 2nd pl
    opp side
15-24::
    1s turn LH to face 1st corner & dance LSh reels of 3 on sides & 1s
    cross RH to 2nd place own side
25-32::
    1s+2s+3s dance 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14136, '2021-07-07 00:21:44.955036+00', '2023-02-04 01:22:57.821272+00', 6738, 3, NULL, 'ace', '1-8::
    1s cross RH & cast (2s step up); 1s turn 1.1/2 RH remaining in
    centre in prom hold facing 2L
9-12::
    1s dance 1/2 reel of 3 across with 2s (RSh to 2L to start)
13-20::
    1s dance reel of 3 across with 3s (RSh to 3M to start)
21-24::
    1s dance 1/2 reel of 3 across with 2s (LSh to 2L to start). 1s end
    in centre LHJ facing Ladies'' side
25-32::
    1s lead out between 2L & 3L, 1M casts down, 1L casts up; 1s dance
    up/down centre passing LSh & cast left (1M round 2M, 1L round 3L) to
    2nd place own side.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7729, '2013-08-21 08:31:47.43732+00', '2023-02-04 01:22:57.828506+00', 11536, 3, NULL, 'ace', '1-16::
    All Ladies cast & dance clockwise round outside of set back to
    places Men repeat dancing anticlockwise round set
17-32::
    1s+3s dance RH across, 1M+3L also 1L+3M dance out thru side couples
    & cast to places 2s+4s repeat
33-40::
    1s+3s dance 1/2 R&L, 2s+4s dance 1/2 R&L
41-56::
    All turn corners RH, set to partner, dance Grand Chain, set to
    partner & turn 2H
57-64::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (9769, '2017-04-06 09:58:01.237779+00', '2023-02-04 01:22:57.83922+00', 14903, 3, NULL, 'ace', '1-8::
    1s turn RH, cast (2s step up) then 1L+2s & 1M+3s dance RH across.
    1s end facing 1st corners
9-16::
    1s dance Corner Pass+Turn with 1st corners, pass RSh & repeat with
    2nd corners. 1s pull back RSh to end BtoB in centre facing opp sides
17-24::
    2s+1s+3s dance Double Triangles. Bars 23-24 1s petronella turn to
    2nd place own sides
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (7730, '2013-08-21 08:31:47.445462+00', '2023-02-04 01:22:57.84845+00', 6739, 3, NULL, 'ace', '1-8::
    1s set, cross RH, 1s set to 2s on sides & turn RH on sides
9-16::
    1s+2s dance reel of 4 across (Ladies pass LSh & Men dance up/dn on
    sides) & Men end turning LH to face ptnrs, as Ladies dance to
    1st/2nd pl
17-20::
    1s turn RH 1.1/2 times _while_ 2s turn twice to end in a diagonal
    line.
21-24::
    1s+2s dance 1/2 Diamond Poussette.', 0);
INSERT INTO 'dancecrib' VALUES (7731, '2013-08-21 08:31:47.523492+00', '2023-02-04 01:22:57.857917+00', 6743, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s cross RH, cast in 1 place & dance RH across
9-16::
    1s & 4s lead out ends, cast to centre & 2s+1s also 4s+3s dance 1/2
    R&L
17-24::
    1s+2s & 3s+4s dance 1/2 Ladies'' Chain, 2s+1s & 4s+3s dance 1/2 Men''s
    Chain
25-32::
    Top 3 on Ladies'' side & bottom 3 on Men''s side dance LSh reels of 3
    on sides (1s & 4s pass LSh to start)
33-40::
    Top 3 on Men''s side & bottom 3 on Ladies'' side dance LSh reels of 3
    on sides (1s & 4s pass LSh to begin) & 1s+4s pass LSh to end 2 4 (1)
    (3)', 0);
INSERT INTO 'dancecrib' VALUES (7732, '2013-08-21 08:31:47.532+00', '2023-02-04 01:22:57.867697+00', 10068, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s cross RH & cast in 1 place, 1s & 4s dance 1/2 Figs of 8
    round 2s/3s _while_ 2s & 3s set & cross RH & on bar 8 1M+4L (prom
    hold) end facing down to 3M with their partners (prom) facing up to
    2M
9-16::
    All dance RSh promenade reels of 3 on sides
17-24::
    2s+1s also 4s+3s dance double Fig of 8 (1s & 4s cross up/down to
    start)
25-28::
    1s+4s dance LH across to end BtoB facing corners (1M+2L, 1L+2M,
    4L+3M, 4M+3L)
29-32::
    1s & 4s turn corners RH to end BtoB facing corners again
33-40::
    1s set to corners, set on sides/ends, set to next corner & into
    centre facing ''new'' corner (Hello-Goodbye Setting)
41-48::
    1s & 4s change places with ''new'' corner RH, 2s+3s (in circle) set,
    opening out to face partner across set & cross RH & cast up/down to
    2 4 (1)(3)', 0);
INSERT INTO 'dancecrib' VALUES (15154, '2022-10-05 00:22:18.002562+00', '2023-02-04 01:22:57.878797+00', 21028, 3, NULL, 'ace', '1-8::
    All dance RSh reels of 4 on sides
9-12::
    1s set to 2s on the sides. 1s cross down to 2nd place opp sides
    _while_ 2s dance up to top. 2 (1) 3 4
13-16::
    1s & 3s repeat bars 9-12
17-20::
    1s & 4s repeat bars 9-12.  2 3 4 (1)
21-24::
    2s+3s+4s turn RH _while_ 1s turn 1 1/2 RH
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7733, '2013-08-21 08:31:47.540166+00', '2023-02-04 01:22:57.888091+00', 12637, 3, NULL, 'ace', '1-8::
    1s cross down RH to face out between 2s & 3s giving hands (as double
    triangles) & set, 1s cast round 1st corner to end diagonally facing
    1st corners
9-16::
    1s dance diagonal reel of 4 with 1st corners & turn LH to face 2nd
    corners
17-24::
    1s dance diagonal reel of 4 with 2nd corners & end 2nd place own
    side
25-32::
    2s+1s+3s circle 6H round to left, pivot & chase back to places', 0);
INSERT INTO 'dancecrib' VALUES (11002, '2018-08-17 07:53:07.119532+00', '2023-02-04 01:22:57.898134+00', 17122, 3, NULL, 'ace', '1-8::
    1s Adv+Ret (1 step each) taking RH briefly, 1s 1/2 turn LH, cross
    down between 2s & cast up to place
9-16::
    1s+2s dance the Knot. 1s end facing 1st corners
17-24::
    1s dance Corners Pass+Turn with 1st corners, pass RSh, Repeat with
    2nd corners & 1s pass RSh into 2nd place own sides (corners turn 2H
    in centre)
25-32::
    All chase clockwise 1/2 round to opp sides, all 1/2 turn 2H, pull
    back RSh & dance out to own sides  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7734, '2013-08-21 08:31:47.548423+00', '2023-02-04 01:22:57.907691+00', 13547, 3, NULL, 'ace', '{{explanation}}
Dance 3 times Strathspey & 3 times Reel

1-4::
    Men dance to Lady on right _while_ Ladies cast into prtnrs place,
    Ladies dance to Lady''s place on right _while_ their prtnrs cast into
    Mans place
5-8::
    Repeat bars 1-4
9-16::
    1s+3s (2nd/1st pl) dance 1/2 Men''s Chain, 1M+3L(1st pl)+2s(3rd pl)
    dance 1/2 Men''s Chain
17-24::
    Ladies petronella turn into Lady''s pl to right & set, Ladies repeat
    (to partner)
25-32::
    All circle 6H round & back.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7735, '2013-08-21 08:31:47.556521+00', '2023-02-04 01:22:57.917016+00', 6748, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to top, 1M presenting 1L to 2M
9-16::
    1L+2M with nearer hands joined dance down the middle followed by 1M,
    1L+2M turn inwards (holding hands) & with crossed arms gives LH to
    partner, 1M+2M join free hands in arch over Ladies head & all 3
    dance up in "Triumph", 2M returns to place
17-24::
    1s dance special Poussette (1/4 turn, travel, 1/4 turn, 1/4 turn,
    travel, 1/4 turn, 1/2 turn) down the middle to 4th place as 2s+3s+4s
    step up', 0);
INSERT INTO 'dancecrib' VALUES (13359, '2020-11-02 01:22:12.770347+00', '2023-02-04 01:22:57.926786+00', 20058, 3, NULL, 'ace', '1-8::
    1s set twice with 1L pulling back RSh on bar 4 to face out, 1L
    followed by partner casts down & dances across the set to 2nd place
    opp sides (2s step up bars 7-8)
9-16::
    Corners chase clockwise once round _while_ 1s dance DoSiDo & join
    the chase for bars 13-16.   2 1 3
17-24::
    1s & 1st corners Adv+Ret, 1s & 2nd corners Adv+Ret
25-32::
    1s dance RSh 1/2 round partner to face them, pull back RSh dance out
    to 2nd place opp sides & face out; 1s chase clockwise round 1/2 way
    to 2nd place own sides 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13641, '2021-02-04 01:22:07.08726+00', '2023-02-04 01:22:57.936364+00', 15234, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up) & face 1st corners; 1s set to & turn 1st
    corner RH to face 2nd corners
9-16::
    1s set to & turn 2nd corner LH into lines of 3 across (1M between
    2s, 1L between 3s); Set+Link for 3.  (2) (1) (3)
17-24::
    Reels of 3 on sides (6 bars) 1s LSh to 1st corner to start, 1s turn
    1.1/4 RH to face 4th corner (pstn)
25-32::
    1s set to & turn 4th corner LH into lines of 3 across (1L between
    2s, 1M between 3s); Set+Link for 3.  2 1 3
33-40::
    1s dance 1/2 Figs 8 (1L down round 3s, 1M up round 2s); 1s cross &
    cast (3s step up)
41-48::
    All circle 6H round & back.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7736, '2013-08-21 08:31:47.564672+00', '2023-02-04 01:22:57.946134+00', 6751, 3, NULL, 'ace', '1-8::
    All set, turn RH ending in prom hold with 1s & 3s facing down & 2s &
    4s facing up
9-16::
    All in prom hold dance reel of 4
17-24::
    1s+2s also 3s+4s dance RH across ending in centre, 1s cast on own
    sides below 2nd place, dance in & up to 2nd place BtoB in centre
    facing opposite sides _while_ 2s+4s lead up 1 place & stand for 2
    bars _while_ 3s cast to 4th place & cross RH
25-32::
    1s holding hands as in Double Triangles, set with 2s+4s 1/4 turning
    to right 4 times
33-40::
    1s dance out & cast to right (Lady around 4M & Man around 2L) to
    meet in middle & lead down to bottom, cross & cast to 3rd place
41-48::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7737, '2013-08-21 08:31:47.573+00', '2023-02-04 01:22:57.955806+00', 6756, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, Set+Link again back to original places
9-16::
    1M & 2L cross RH & set _while_ 1L & 2M set & cross RH, repeat back
    to places
17-24::
    1s+2s dance RH across & LH back to end in line of 4 in middle facing
    partners (Ladies facing down & Men up)
25-32::
    1s+2s dance Highland Schottische Poussette:
::
    1s set HS step with both hands joined dancing out to Men''s side
    _while_ 2s set & dance out to Ladies side ending with a 1/4 turn to
    right
::
    1s dance HS down Men''s side & 2s up Ladies side ending with a 1/4
    turn to right
::
    1s+2s dance HS into centre to reform line of 4 in middle with
    couples having changed places, Men facing down, Ladies facing up
::
    2s+1s 3/4 turn partners 2H to own sides, 1s ending in 2nd place own
    side', 0);
INSERT INTO 'dancecrib' VALUES (9760, '2017-04-06 08:40:22.539828+00', '2023-02-04 01:22:57.967058+00', 6758, 3, NULL, 'ace', '1-8::
    1s+2s dance LH across (4 bars) opening into 4H round to Right
    _while_ 3s+4s dance RH across (4 bars) opening into 4H round to Left
9-16::
    1s+4s set advancing to form circle with other couples (8H) & all
    set.  1s+4s set retiring to places as 2s+3s set & then all set on
    sides
17-24::
    1s+2s dance 1/2 R&L, then 1s+3s dance 1/2 R&L
25-32::
    1s+4s dance 1/2 R&L.  All turn partners 1.1/2 RH', 0);
INSERT INTO 'dancecrib' VALUES (7738, '2013-08-21 08:31:47.581405+00', '2023-02-04 01:22:57.976563+00', 13260, 3, NULL, 'ace', '1-8::
    1s dance in & dance down to 2nd place, out own side & cast round to
    left into middle & turn RH to face down
9-16::
    1s followed by 2s dance down the middle & back (2s to top)
17-24::
    1s+3s dance RH across for 3 bars & LH back, 1s cast to 3rd place as
    2s dance up
25-28::
    1L followed by partner dances down to 4th place opposite sides
    _while_ 4M followed by partner dances up to 3rd place opposite sides
29-32::
    All turn RH (4s & 1s 1.1/2 times) to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7739, '2013-08-21 08:31:47.58938+00', '2023-02-04 01:22:57.98606+00', 6763, 3, NULL, 'ace', '1-8::
    1s cross down (1 step) to dance parallel reels of 3 on opposite
    sides (RSh to 2s) and cross back to own sides on bar 8
9-16::
    1s dance parallel reels of 3 on own sides (RSh to 2s)
17-24::
    1s lead down the middle & back to top
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (9938, '2017-06-05 11:31:54.62361+00', '2023-02-04 01:23:01.493018+00', 14139, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig 8 round 2s, turn LH to end 1L facing 2M, 1M facing
    2L
9-24::
    1s dance the ''Spurtle''
::
    _9-12_    1s dance 1/2 RSh reel of 4 with 2s & turn RH to face 3s (M
    facing L)
::
    _13-16_   Repeat to end facing 4s
::
    _17-20_   Repeat to end on opposite sides in 4th place  (2) (3) (4)
    (1)
::
    _21-24_   All couples set & cross RH
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7740, '2013-08-21 08:31:47.597563+00', '2023-02-04 01:22:57.995646+00', 6764, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All in prom hold weave in & out round set back to place with 1s & 4s
    also 2s & 3s passing RSh to start
9-16::
    Men cast & dance clockwise round set _while_ Ladies dance RH across
    & LH back to places
17-24::
    All set to corners & turn RH, set to partner & turn RH
25-32::
    All set to partners (H S step) & turn twice round with 2H

{{title}}
Reel

1-16::
    As Strathspey but end with Ladies facing out all holding hands in a
    circle
17-24::
    All set & 1/2 turn partner RH to form circle with Men facing out,
    all set & 1/2 turn partner to link right arms in Tulloch hold
25-32::
    All turn partners to right, change to left arm hold & turn partner
    to left', 0);
INSERT INTO 'dancecrib' VALUES (7741, '2013-08-21 08:31:47.605746+00', '2023-02-04 01:22:58.005032+00', 6767, 3, NULL, 'ace', '1-8::
    1s & 3s set, cross RH, all set, 1M & 3M cast 1 place _while_ 2M & 4M
    cast up 1 place & all Ladies dance across to be on right of partner
9-16::
    1s+2s also 3s+4s dance RH across, Men dance out round Lady in front
    & dance LH across (end in own pstns with 2s & 4s opp sides)
17-24::
    1s+2s+3s set, circle 6H to left for 4 bars, each Men turns Lady on
    his right 2H (2 bars) & complete circle to places (2 bars)
25-32::
    1L followed by partner casts 1 place, cross to 3rd place opp sides
    _while_ 3M followed by partner casts up & crosses to top place opp
    sides, 3s+2s also 1s+4s dance 1/2 R&L.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9048, '2015-11-30 09:00:25.020819+00', '2023-02-04 01:22:58.0163+00', 16725, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 1s cast as 2s dance up. 1L+2s also 1M+3s dance RH
    across
9-16::
    2s +1s dance double Fig 8 (1s cross up, 2s cast off), 1s finish in
    middle facing down, 3s step in to face.
17-24::
    1s+3s dance Rondel.
25-32::
    2s+3s+1s circle 6H round and back.', 0);
INSERT INTO 'dancecrib' VALUES (7742, '2013-08-21 08:31:47.613829+00', '2023-02-04 01:22:58.025643+00', 6768, 3, NULL, 'ace', '1-8::
    3s set advancing & turn right about to face own sides, 2s+3s+4s
    dance 6 bars of Double Triangles
9-16::
    3s dance diag RSh reel of 4 with 1st corners 3s & end 3s dancing
    round each other RSh (LSh - popular variation) to face 2nd crnrs
    _while_ 2L dances reel of 3 with 1s as 4M dances reel of 3 with 5s,
17-24::
    3s dance diagonal reel with 2nd corners _while_ 2M dances reel of 3
    with 1s also 4L dances reel of 3 with 5s & all end in original
    places
25-32::
    All set, 1s+2s & 3s+4s dance 1/2 RH across as 5s cross LH, 1s+4s &
    3s+5s dance 1/2 LH across as 2s cross RH & all set.  2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (9248, '2016-06-16 22:42:27.27906+00', '2023-02-04 01:22:58.034816+00', 17028, 3, NULL, 'ace', '1-8::
    Men making arches cross as Ladies dance under (pass partner RSh) &
    all set turning to face in, repeat but Ladies make arches
9-24::
    All dance under & over (1s & 3s dance under 2s/4s to strart) with
    each couple setting as they turn about at the ends all ending in
    original places
25-32::
    1s cross RH & cast to 4th place _while_ 2s+3s+4s turn 1.1/2 times
    (RH elbow grip) moving up 1 place. all set & cross RH to end 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7743, '2013-08-21 08:31:47.653437+00', '2023-02-04 01:22:58.044349+00', 9833, 3, NULL, 'ace', '1-8::
    1L+2L 1/2 turn LH _while_ partners 1/2 turn RH to end in double
    triangle position, 2s+1s+3s set, 1s dance out of sides, cast below
    3s & cross up to double triangle position facing opposite side
9-16::
    2s+1s+3s set, 1s dance out of sides, cast to right, turn RH to
    double triangle position up/down & set (1L with2s & 1M with 3s)
17-24::
    1s turn right about to face other couple, set, 1s dance out of ends
    & cast to right to 2nd place on opposite sides
25-32::
    2s+1s+3s dance reels of 3 on sides (1s giving LSh to 1st corners to
    start), 1s cross RH to own side', 0);
INSERT INTO 'dancecrib' VALUES (9936, '2017-06-05 11:31:53.760804+00', '2023-02-04 01:22:58.054135+00', 10534, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set+Link. 2s+1s also 4s+3s circle 4H round to Left
    to end on sidelines
9-16::
    All couples dance 5 couple "Eddy":
::
    _9-12_    All couples, NHJ, Advance (2 steps), Retire (1 step) & set
    to Left (1 step)
::
    _13-16_  All pass partner RSh, & curve to Right.  2s, 4s & 5s return
    to 1st, 3rd & 5th places _while_ 1s+3s continue to pull back RSh to
    end in middle - 1L between 2s facing 2M, 1M facing 4L BtoB with 3L
    facing 4M & 3M between 5s facing 5L
17-24::
    1L+2s dance RSh reel of 3 _while_ 1M+4s+3L dance RSh reel of 4
    _while_ 3M+5s dance RSh reel of 3.  1s+3s pass LSh to face 1st
    corners
25-28::
    1s & 3s dance Corner Pass+Turn with 1st corners, pass RSh to face
    2nd corners
29-32::
    1s & 3s dance Corner Pass+Turn with 2nd corners, pass RSh to end on
    sides, 1s in 2nd place, 3s in 4th place
33-40::
    1s+4s also 3s+5s dance ''Tourbillon'':
::
    _33-36_   1s+4s (3s+5s) 1/2 turn ptnrs 2H, 1M & 4L (3M+5L) lead
    ptnrs by nearer hand 1 place cl''wise to end 1s (3s) on Ladies'' side
    & 4s (5s) on Men''s side, 1s (3s) set to 4s (5s)
::
    _37-40_   1s+4s (3s+5s) 1/2 turn ptnrs 2H & lead partners on 1 place
    clockwise & couples cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (13446, '2020-12-02 01:22:07.848515+00', '2023-02-04 01:22:58.079667+00', 19164, 3, NULL, 'ace', '1-8::
    All set, 1s+2s+3s 1/2 turn partner 2H; repeat
9-16::
    1L dances behind own line & up middle _while_ 1M dances down middle
    & up behind own line to 1st place.  1s face down
17-24::
    1s+2s+3s dance reels of 3 on sides (1s RSh to 2s to start)
25-28::
    All set, 1s+2s circle 4H 1/2 round to left _while_ 3s 1/2 turn 2H.
    (2) (1) (3)
29-32::
    All set, 1s+3s (bottom couples) circle 4H 1/2 round to left _while_
    2s 1/2 turn 2H.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7745, '2013-08-21 08:31:47.669627+00', '2023-02-04 01:22:58.090489+00', 6775, 3, NULL, 'ace', '1-8::
    2s & 4s cross RH, cast to right & turn partner LH to face 1st
    corners
9-16::
    2s & 4s dance diagonal RSh reels of 4 with 1st corners & end facing
    2nd corners
17-24::
    2s & 4s dance reels of 4 with 2nd corners & end in original places
25-32::
    1s+2s also 3s+4s dance RH across 1/2 way _while_ 5s cross RH & all
    set, 1s+4s also 3s+5s dance LH across _while_ 2s cross LH & all set', 0);
INSERT INTO 'dancecrib' VALUES (9937, '2017-06-05 11:31:53.780679+00', '2023-02-04 01:22:58.100485+00', 10533, 3, NULL, 'ace', '1-8::
    1s+2s dance ''Chain Progression'':
::
    _1- 2_   1s & 2s 3/4 turn RH
::
    _3- 6_   1M+2L turn LH 1.1/2 times _while_ partners chase clockwise
    1/2 way
::
    _7- 8_   2s & 1s 3/4 turn RH.  End 2s in 1st place, 1s facing 2nd
    corners
9-12::
    1M+2s & 1L+3s dance 1/2 reels of 3 across (RSh to 2nd corner to
    start).  1s end in 2nd place opp sides
13-16::
    _1/2_ reels of 3 on opp sides (1M+3M pass LSh on Ladies'' side, 1L+3L
    pass LSh on Men''s side to start)
17-24::
    All Set+Link for 3 twice
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (10455, '2018-02-24 07:53:27.194415+00', '2023-02-04 01:22:58.112517+00', 18242, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 down round 2s
9-16::
    1s+2s circle 4H round and back _while_ 3s dance Fig 8 down round 4s
17-24::
    1s+2s Set+Link twice _while_ 3s+4s circle 4H round and back
25-32::
    1s+2s change places RH on sides; 1s+3s change places LH on sides;
    1s+4s change places RH on sides; All set.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (4883, '2013-08-21 08:30:56.392787+00', '2023-02-04 01:22:58.123392+00', 6783, 3, NULL, 'ace', '1-8::
    1s set, cross down to 2nd place (2s step up bars 3-4), set & cross
    RH and face out
9-16::
    1s dance reels of 3 on own sides (RSh to 3rd corners) & end giving
    RH to turn to face 1st corners
17-24::
    1s dance reels of 3 across (RSh to 1st corner) & end giving RH to
    face down
25-32::
    1s followed by 2s lead down between 3s, cast up, meet & lead up
    between 2s & cast, 1s to 2nd place, 2s end in 1st place

{{explanation}}
Second time through bars 31-32 1s cast to 4th place as 4s step up', 0);
INSERT INTO 'dancecrib' VALUES (7746, '2013-08-21 08:31:47.677653+00', '2023-02-04 01:22:58.133859+00', 8975, 3, NULL, 'ace', '1-8::
    1s dance down to 2nd pl as for Double Triangles, 2s+1s+3s set, 1s
    dance out & turn R about to face in as 2s & 3s dance in & turn to
    face out & set
9-16::
    1s dance reels of 3 across (Lady with 2s & Man with 3s)
17-24::
    1s dance reels of 3 on own sides (Lady in & up, Man in & down to
    start)
25-32::
    1s+2s dance the Slip Knot (usual Knot but end by passing Lady in
    front & dancing 1/2 LH across back to same places)', 0);
INSERT INTO 'dancecrib' VALUES (9049, '2015-11-30 09:00:25.093292+00', '2023-02-04 01:22:58.148232+00', 16784, 3, NULL, 'ace', '1-8::
    1s lead down middle & back remaining in middle with 2s stepping in
    behind them
9-16::
    1s+2s dance Allemande ending on sides 2 1 3 4
17-20::
    1s cast & chase clockwise to change places as 2s+3s set advg &
    circle 4H round to left 1/2 way & retire to diag opposite place.
    (3)(1)(2)
21-24::
    1s dance LH across (1L with 3s at top, 1M with 2s)
25-32::
    1s dance RSh reels of 3 on opposite sides (M up, L down) & 1s set
    advg & turn about to face 1st corners (pstn)
33-40::
    1s 1/2 diag reel of 4 with 1st crnrs, set advg & turn about to face
    4th crnr (pstn), 1s 1/2 diag reel of 4 with crnrs & 1s dance down to
    bottom.  2 3 4 1
::
    Note - new top couple starts each time but all couples dance twice', 0);
INSERT INTO 'dancecrib' VALUES (7747, '2013-08-21 08:31:47.708653+00', '2023-02-04 01:22:58.16904+00', 6785, 3, NULL, 'ace', '1-8::
    1s set & cast to face 1st corners, 1s set to 1st corners (HS)
9-16::
    1s dance round 1st corners RSh & dance down/up centre & pass RSh to
    face 2nd crnrs, set to 2nd corners (HS)
17-24::
    1s dance round 2nd corners RSh & down/up sides to end above/below
    2s/3s _while_ crnrs dance RH across, 1s dance RH across with 2s/3s
25-32::
    1s dance down/up for 2 bars to meet, turn right about, dance into
    2nd places own sides & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (10108, '2017-09-03 23:45:33.159789+00', '2023-02-04 01:22:58.201227+00', 6787, 3, NULL, 'ace', '1-8::
    1s dance down between 2s & cast up on own sides, 1s turn 2H (Pas de
    basque)
9-16::
    2s dance up between 1s & cast down on own sides, 2s turn 2H (Pas de
    Basque)
17-24::
    1s cross RH, cast down 1 place (2s step up 3-4), 1s dance 1/2 fig of
    8 round 2s
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7748, '2013-08-21 08:31:47.716751+00', '2023-02-04 01:22:58.227158+00', 6791, 3, NULL, 'ace', '1-4::
    1L & 3L cast 1 place & dance into centre to face up _while_ 2M & 4M
    cast up 1 place & dance into centre to face ladies
5-16::
    2M+1L+4M+3L dance RSh reel of 4 in centre, 2M+1L also 4M+3L 3/4 turn
    RH to places
17-24::
    1M+2L & 3M+4L turn RH & back to places, 1s+2s also 3s+4s circle 4H
    round to left
25-32::
    All Adv+Ret, 1s lead down to 4th place _while_ others step up', 0);
INSERT INTO 'dancecrib' VALUES (7749, '2013-08-21 08:31:47.725134+00', '2023-02-04 01:22:58.250534+00', 6792, 3, NULL, 'ace', '1-8::
    1M dances reel of 3 with 2s giving LSh to 2L & picks up his partner
    in prom hold to end in 1M''s place
9-16::
    1s dance down (opposite sides), 1L dances under 1M arm as he dances
    round below her & dance back to own places
17-24::
    1s set, dance down below 3s, cast up to 2nd place, dance in back to
    top _while_ 2s stand for 2 bars, set, dance down & cast up round 3s
    to own places _while_ 3s stand for 4 bars, set, dance in (touch
    hands) & out to own place facing out
25-32::
    1s+2s+3s dance reels of 3 on sides (1s dancing out & down to start)
    end 1s turning to face down as 2s dance in to face up
33-40::
    1s+2s dance a Half Rondel to change places :
::
    1s dance down under the arch made by 2s who dance up, Ladies cross
    in front of Men & all cast to meet the other Lady or Man on the
    opposite side & join nearer hands, set on opposite sides of the
    dance & cross LH back to own sides', 4);
INSERT INTO 'dancecrib' VALUES (7750, '2013-08-21 08:31:47.733131+00', '2023-02-04 01:22:58.280723+00', 6793, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on own sides (between 2s to start)
9-16::
    1s dance down between 2s & cast back to places, lead down between 2s
    (2s step up) & cast up round 3s to 2nd place own side
17-24::
    1s dance RH across (1L with 2s & 1M with 3s) & pass RSh to dance LH
    across with other couple
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7751, '2013-08-21 08:31:47.748293+00', '2023-02-04 01:22:58.302413+00', 11229, 3, NULL, 'ace', '1-8::
    1M+2M also 2L+3L Set Link _while_ 3M+1L set & change places RH,
    1s+2s+3s chase clockwise 1/2 way
9-16::
    Repeat back to original pstns
17-24::
    2s dance reels of 3 across (2M with 1s & 2L with 3s)
25-32::
    1M+2M also 2L+3L turn LH, 1s+2s cross RH & dance 1/2 RH across to
    end 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7752, '2013-08-21 08:31:47.758315+00', '2023-02-04 01:22:58.324696+00', 10497, 3, NULL, 'ace', '1-8::
    1s turn 2H 1.1/2 times & cast 1 place then dance LSh round partner
    to face 1st corners
9-24::
    1s dance Corner Chain with 1st & 2nd corners :
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end turning LH to 2nd places
    opp sides
25-32::
    2s+1s+3s circle 6H to left 1/2 way (2 bars) & Men turn Lady on right
    2H, circle left to place & 1s cross RH', 0);
INSERT INTO 'dancecrib' VALUES (7753, '2013-08-21 08:31:47.768026+00', '2023-02-04 01:22:58.456946+00', 6797, 3, NULL, 'ace', '1-12::
    1M+2L turn RH (1M ends in 2nd place), 1L+2M turn LH (1L ends in 2nd
    place)
13-24::
    1s+3s dance R&L (3 steps per hand) 1s end facing 1st corners
25-36::
    1s turn 1st corner RH, partner LH, 2nd corner RH & partner LH to end
    in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (7823, '2013-08-21 08:31:49.170704+00', '2023-02-04 01:23:03.799685+00', 8466, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance R&L
9-16::
    1s & 3s dance Figs of 8 round couple below
17-24::
    2s & 4s dance Figs of 8 round couple above
25-32::
    1s cast to 4th place & all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (7754, '2013-08-21 08:31:47.778908+00', '2023-02-04 01:22:58.483428+00', 13210, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s, 1s cross RH back to place then 1s &
    2s set to partner
9-16::
    1s & 2s 3/4 turn RH & 1M+2L turn 1.1/2 times LH _while_ 1L+2M chase
    1/2 way then 2s &  1s 3/4 turn RH
17-24::
    1s dance 1/2 reel of 3 on sides (RSh to 3rd corner), 1s cross
    up/down to continue reel on opposite sides & end in middle BtoB (1L
    facing up)
25-32::
    1s dance 4 bars of Crown Triangles ending 2nd place own sides, all
    turn partners RH.  2 1 3
33-40::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7755, '2013-08-21 08:31:47.787381+00', '2023-02-04 01:22:58.510574+00', 6798, 3, NULL, 'ace', '{{explanation}}
6 couples: couples 1, 2, 3 & 4 make square set, couples 5s & 6s in middle, 5s facing 1s, 6s facing 3s

1-8::
    1s+2s+3s+4s circle 8H left 1/2 way, set adv, turn right & dance out
    (to new places) _while_ 5s+6s set to ptnr, set facing diagonally in
    to centre & dance LH across
9-16::
    3s+5s+6s+1s dance parallel reels of 4, 3s & 1s ending in place &
    5s+6s omit LSh pass to end facing 2s & 4s
17-24::
    4s+5s+6s+2s dance parallel reels of 4, 4s & 2s ending in places &
    5s+6s omit LSh ready for…
25-28::
    5s & 6s dance RH across with nearest corners (i.e. groups of three
    dancers)
29-32::
    5s+6s dance 1/2 LH across in centre _while_ 1s+2s+3s+4s circle 1/4
    round to left and 2s+5s also 6s+4s dance RH across 1/2 way (to put
    new couples - 2s & 4s - in centre) _while_ 1s & 3s turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (8852, '2015-08-13 20:34:12.190524+00', '2023-02-04 01:22:58.525722+00', 16271, 3, NULL, 'ace', '1-8::
    1s & 3s set, cross RH, cast, turn RH to finish RSh to RSh facing 1st
    corners (2s & 4s step up 5-6)
9-16::
    1s & 3s dance Corner Pass+Turn with 1st corners, pass RSh, dance
    Corner Pass+Turn with 2nd corners.  Finish in centre shoulder to
    shoulder, Man above Lady
17-24::
    1M+2s, 1L+4s+3M, 3L+5s dance RH across, 1s & 3s pass prtnr RSh,
    dance LH across with other couple. 1s & 3s end in 2nd/4th place opp
    sides
25-32::
    1s & 3s set, cast, turn 2H 1.1/2 times to own sides (4s & 5s step up
    27-28)  End 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (7840, '2013-08-21 08:31:49.597578+00', '2023-02-04 01:23:05.268847+00', 6946, 3, NULL, 'ace', '1-8::
    1s & 4s cast in 1 place, dance RH across & cast back to places
9-16::
    1s+2s also 3s+4s set on sides & change places RH, set to partner &
    turn RH
17-24::
    2s & 3s cast in 1 place, dance RH across & cast back to ends
25-32::
    1s+4s+3s dance Allemande.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12108, '2019-08-30 09:55:06.875455+00', '2023-02-04 01:22:58.556229+00', 15378, 3, NULL, 'ace', '1-8::
    1s+3s dance RH across; 1L+3M+4s & 3L+1M+2s dance LH across
9-16::
    1L followed by 3M cast anticlockwise behind 4s to end 1L facing 2M,
    3M facing 4L _while_ 3L followed by 1M dance similar behind 2s to 3L
    facing 4M, 1M facing 2L. Bar 16: 2s & 4s turn BtoB to face 1s/3s
    [now in longwise set]
17-24::
    LSh reels of 4 on sides
25-32::
    All Adv+Ret; top 2 couples also bottom 2 couples dance 1/2 R&L
33-36::
    All dance DoSiDo across set
37-40::
    1s+3s set, pull back RSh & dance clockwise to original places
    _while_ 2L+4M also 4L+2M 1/2 turn RH, pull back RSh & cast to
    original places [now square set]
41-80::
    All repeat bars 1-40 with 2s & 4s leading
81-96::
    All dance Schiehallion reel.  End facing partner, RH in air, LH
    across body, "Olé"', 0);
INSERT INTO 'dancecrib' VALUES (7756, '2013-08-21 08:31:47.797456+00', '2023-02-04 01:22:58.596253+00', 10959, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Fig of 8 round 2s _while_ 2s set & cross RH, 1s in prom
    hold dance 1/2 reel of 3 across with 2s giving RSh to 2L (on Men''s
    side)
9-16::
    1s followed by 2s lead down the middle & 2s followed by 1s lead up
17-24::
    2s cast to 2nd place, cross up & ''cast'' to 1st place _while_ 1s
    cross up & cast to 2nd places, 2s+1s set & turn 2H to face down/up
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7757, '2013-08-21 08:31:47.805581+00', '2023-02-04 01:22:58.624567+00', 6801, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s+2s turn RH 1.1/4 times on sides to form
    lines of 4 across (Lady facing Lady & Man facing Man)
9-16::
    1s+2s dance reel of 4 across, 1s end facing 1st corners & 2s end in
    1st place own sides
17-24::
    1s set to 1st corners, set to 2nd corners & turn right to face each
    other (Man up & Lady down), 1s set & turn 2H to face down on own
    sides
25-32::
    1s dance reel of 3 on own sides dancing in between 3s to start, 1s
    end in 3rd place & 3s in 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (7758, '2013-08-21 08:31:47.813775+00', '2023-02-04 01:22:58.652094+00', 6800, 3, NULL, 'ace', '1-8::
    1s cast on own sides followed by 2s+3s (with hands joined on each
    side), cross below 3rd place & dance up to places on opposite sides
9-16::
    1s+2s+3s dance Allemande to the right
17-24::
    1s cast up on opposite sides followed by 2s+3s (with hands joined on
    each side), cross at top, dance down own sides into centre for
    Allemande
25-32::
    3s+2s+1s dance Allemande to the left
33-40::
    1s dance down the middle below 3s, cast up 1 place, dance up to top
    & cast to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (15241, '2022-11-03 01:22:09.490452+00', '2023-02-04 01:22:58.682549+00', 20459, 3, NULL, 'ace', '1-8::
    1s dance in & cast (2s step up); 1s dance down NHJ, cast up round 3s
    & cross passing LSh to face 1st corners
9-16::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh & dance 1/2
    diag reel of 4 with 2nd corners. 3s face down, 2s face up
17-20::
    1s turn 3/4 RH & set _while_ 2s+3s set & change places RH on sides
21-24::
    1s turn 3/4 RH & set _while_ 2s+3s set & cross RH with partners
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10531, '2018-03-20 06:27:29.053483+00', '2023-02-04 01:22:58.87246+00', 16508, 3, NULL, 'ace', '1-8::
    1s+2s dance the Knot
9-16::
    1s dance down below 3s (2 bars), turn 2H (2 bars), dance up to 2nd
    place (2 bars), 1/2 turn 2H (1 bar) & cross passing RSh to own side
    2nd place, facing out
17-24::
    Promenade (Chaperoned) Chain progression:
::
    _17-18_    2s & 3s 3/4 turn partner RH into middle _while_ 1s dance
    clockwise 1/4 round the set picking up 2L/3M
::
    _19-22_    who promenade 1/2 way clockwise _while_ middle people (2M
    + 3L) turn LH 1.1/2
::
    _23-24_    2s & 3s turn partner RH 3/4 to own sides _while_ 1s dance
    clockwise 1/4 round to end in 2nd place. 3 1 2
25-32::
    1s+2s dance Diamond Poussette.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (12478, '2020-01-05 00:39:48.023738+00', '2023-02-04 01:22:58.897023+00', 19808, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance "Slip Knot":
::
    _1-6_   All 3 couples dance first 6 bars of standard Knot
::
    _7-8_   3s (top place) turn LH to own side _while_ 2s+1s dance 1/2
    LH across to end on own side, 1s facing out.  3 1 2
9-12::
    3s+1s+2s dance 1/2 LSh reels of 3 on sides (1M down, 1L up) 1s face
    out;
13-16::
    2M+1M also 1L+3L turn 1.1/2 RH to end - Men''s side:1M 2M 3M,
    Ladies''s side: 2L 3L 1L
17-24::
    All 3 couples dance Bourrel. end 3 1 2
25-32::
    3s+1s+2s dance 1/2 RSh reels of 3 on side (1L up, 1M down));
    3s+1s+2s turn RH, remain in centre facing partner pull back RSh &
    dance out to place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7759, '2013-08-21 08:31:47.935058+00', '2023-02-04 01:22:59.114659+00', 10424, 3, NULL, 'ace', '1-8::
    1s & 4s dance in & cast in 1 place & turn 2H
9-16::
    1s+4s dance 1/2 diamond Poussette, all set, 2s+4s also 1s+3s change
    places 2H on sides
17-24::
    All dance reels of 4 on sides
25-32::
    4s & 1s petronella turn & 1/2 turn partner 2H, petronella turn & all
    set.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8367, '2014-07-29 12:59:35.99243+00', '2023-02-04 01:22:59.259073+00', 14352, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH, cast down/up & dance RH across to end holding RH
    1s facing up & 4s facing down
9-12::
    1s lead up, cross & cast to 2nd place _while_ 2s cast down 1 place &
    cross up LH to 1st place as 4s lead down, cross & cast to 3rd place
    _while_ 3s cast up 1 place & cross down RH to 4th place.
13-16::
    1s+4s dance 1/2 R&L
17-24::
    All Set+Link for 4 twice:
::
    All set
::
    The 2 dancers at left end of lines dance to the right & curve round
    to face up/down _while_ the other 2 dancers cast & chase clockwise
    to form lines across with the other pair of dancers
::
    All set in lines across the dance
::
    The 2 dancers at left end of lines dance to the right & curve round
    to their own sides _while_ the other 2 dancers cast & chase
    clockwise to their own sides 3 1 4 2
25-32::
    All dance 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7760, '2013-08-21 08:31:48.01957+00', '2023-02-04 01:22:59.282889+00', 9439, 3, NULL, 'ace', '1-4::
    1s & 3s dance RSh round partners 1.1/4 times to end in middle 1M
    facing down, 1L facing 2M, 3L facing up & 3M facing 2L
5-20::
    1s+2s+3s dance Star Reel (similar to Schiehallion reel with 1L
    followed by 1M dancing round 2M position as 3M followed by 3L
    dancing round 2L position _while_ 2M also 2L loop round to right
    round into middle - repeat this figure 3 more times to all ending
    were they started)
21-24::
    1s & 3s 3/4 turn RH & 1s cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (8368, '2014-07-29 12:59:36.074801+00', '2023-02-04 01:22:59.315509+00', 15227, 3, NULL, 'ace', '1-8::
    1s cast 2 places & cross RH as 2s+3s turn RH 1.1/2 times moving up 1
    place; 2s+3s+1s dance 1/2 reflection reels on side (2s cast, 3s
    dance up & in, 1s cast out & up)  (1) (3) (2)
9-16::
    Repeat bars 1-8 from new places
17-22::
    1s+3s dance 3/4 double Fig 8 round 2s (1s cast & 3s cross up to
    start)   3 2 (1)
23-24::
    3s cast to 2nd place as 2s dance up and face out also 1s cross RH
    and face out   2 3 1
25-32::
    2s+3s+1s dance reflection reels (2s out & down, 3s in & down, 1s out
    & up)', 0);
INSERT INTO 'dancecrib' VALUES (7915, '2013-08-21 08:31:51.26372+00', '2023-02-04 01:23:11.608067+00', 12639, 3, NULL, 'ace', '1-4::
    1s cross RH & cast to 2nd place
5-16::
    2s+1s+3s dance R&L for 3 couples
17-24::
    1s cross RH & cast right, pass RH up/down set & cast to right & end
    BtoB facing own sides
25-28::
    2s+1s+3s set (as in Double Triangles) 1s PdB out & turn right about
    to face in _while_ 2s & 3s PdB in & turn right about to face out
29-32::
    2s+1s+3s set (Inverted Double Triangle formation) & PdB to new
    places', 0);
INSERT INTO 'dancecrib' VALUES (12109, '2019-08-30 09:55:07.265972+00', '2023-02-04 01:22:59.351478+00', 19285, 3, NULL, 'ace', '1-6::
    1s+2s cross RH, 1L+2L also 1M+2M turn 3/4 LH on the side to finish
    in balance in line across the set & all set
7-8::
    1M+2L cast by the right to finish 1M in 2nd place and 2L in 1st
    place own side
::
    _while_ 1L+2M dance round each other to finish 1L in 2nd place and
    2M in 1st place, 1s face up
9-16::
    1s dance up, round 2s by RSh (1L in front of 2L, 1M behind 2M) & 1L
    followed by 1M dances down the middle, 1L casts up round 3L to 2nd
    place _while_ 1M casts up round 3M to 2nd place
17-20::
    2s+1s+3s Advance for 2 steps, set and turn to right (Ladies facing
    up, Men facing down);
21-24::
    2L followed by 1L+3L dance up a little & cast to 3rd place _while_
    3M followed by 1M+2M casts up through 3rd place to 1st place (3s &
    2s face clockwise)
25-28::
    3s+2s chase clockwise round outside of the set for 4 bars
29-32::
    2M+3L curve in to finish in a line in centre 2L above 2M, 3L above
    3M and turn partner 1.1/4 RH to finish in the side lines. On bar 29
    1s turn RH. End  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (13099, '2020-08-10 00:21:45.320029+00', '2023-02-04 01:22:59.374426+00', 20043, 3, NULL, 'ace', '1-4::
    1s+2s cross RH, face down/up sides & turn 3/4 LH to finish 2M+1L
    BtoB in centre 2M facing 1M, 1L facing 2L
5-8::
    All set, all pull back RSh and 1L followed by 2L, 2M followed by 1M
    chase clockwise round to own sides, 2s at top, 1s in 2nd place
9-16::
    1s petronella turn & set; turn RH 1.1/4 to 2nd place own side, 1M
    facing up, 1L facing down
17-24::
    Promenade (Chaperoned) Chain progression:
::
    _25-26_    2s & 3s 3/4 turn partner RH into middle _while_ 1s dance
    clockwise 1/4 round the set taking NH with 2L/3M …
::
    _27-30_    who dance 1/2 way clockwise _while_ middle people (2M +
    3L) turn LH 1.1/2.
::
    _31-32_    2s & 3s turn partner RH 3/4 _while_ 1s dance clockwise
    1/4 round. All end in centre NHJ facing up. 3 1 2
25-32::
    3s followed by 1s+2s dance up 1 step then cast outside own side line
    to 3rd place;  2s+1s+3s turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (13447, '2020-12-02 01:22:09.266863+00', '2023-02-04 01:22:59.394947+00', 20139, 3, NULL, 'ace', '1-8::
    »Twisted Rights & Lefts«:
::
    _1-6_   1s+2s cross RH, 1L+2L also 1M+2M turn 3/4 LH on the side to
    finish in balance in line across the set & all set
::
    _7-8_   1M+2L cast by the right to finish 1M in 2nd place and 2L in
    1st place own side
::
    _while_ 1L+2M dance round each other to finish 1L in 2nd place and
    2M in 1st place, 1s face up
9-16::
    2s+1s+3s chase 1/2 round (4 bars); 1s contine to dance 1/2 Fig 8 (1L
    up round 3s, 1M down round 2s)
17-20::
    3s+1s+2s dance 4 bars Set & Rotate for 3 couples (1M now in centre
    1st place facing down, 1L in 3rd place facing up)
21-24::
    _While_ 3s+2s chase clockwise (2 bars) & stand (2 bars), 1s 1/2 turn
    RH, 1L casts round 2s at top, 1M round 3s to 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11477, '2019-01-01 01:58:04.935829+00', '2023-02-04 01:22:59.416858+00', 18948, 3, NULL, 'ace', '1-8::
    1s dance reels of 3 on own sides (1s between 2s to start)
9-16::
    1s set, cast 1 place, cross down below 3s & cast up to 2nd place
    opposite sides
17-24::
    1s dance 1/2 reel of 3 across (Man with 2s & Lady with 3s) into 1/2
    reel of 3 on own sides
25-32::
    All chase clockwise 1/2 way & 1s turn 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (7761, '2013-08-21 08:31:48.039786+00', '2023-02-04 01:22:59.442386+00', 6813, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance double Fig of 8  (1s & 4s cast to start & end
    facing out)
9-16::
    1s & 4s cast 1 place & turn partners 2H, open out into 4H round to
    left & end 1s & 4s turning right about to face corners (M face M & L
    face L)
17-24::
    1s+4s dance "Hello-Goodbye" setting. 1s+4s end in centre facing
    diagonally opposite "corner"
25-32::
    4s turn 2s NH (at top) as 1s turn 3s NH (at bottom - i.e. 4s & 1s
    dancing out of ends) to 2 (4) (1) 3;  4s & 1s dance 1/2 Figs of 8
    round ends.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7762, '2013-08-21 08:31:48.048215+00', '2023-02-04 01:22:59.471748+00', 6814, 3, NULL, 'ace', '1-8::
    1s+3s dance double Fig of 8 round 2s (1s crossing down to start)
9-16::
    1s cross down (each couple cross down as they reach top place) to
    dance reels of 3 on sides
17-24::
    1s+2s dance RH across for 3 bars & back for 3, 1s cast to 2nd place
    _while_ 2s cross up LH to top place on own side
25-32::
    1s+3s dance RH across for 3 bars & back for 3, 1s cast to 3rd place
    _while_ 3s cross up LH to 2nd place on own side
33-40::
    1s cross RH, cast up 1 place, lead up between 2s & cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (7763, '2013-08-21 08:31:48.056499+00', '2023-02-04 01:22:59.498941+00', 6816, 3, NULL, 'ace', '1-8::
    1s cross RH & cast to meet in centre of giving RH to partner & LH to
    1st corner, Bal-in-Line & turn corners to end 2nd place opp sides
9-16::
    1s cross, cast (M up L down) to meet RH with partner & LH to 2nd
    crnr, Bal-in-Line & turn crnrs to end 1M between 2s & 1L between 3s
17-24::
    1s set adv & turn right about to end BtoB 1M facing 2s as 1L faces
    3s & all set (as Double Triangles), 1s change places & set to other
    couple
25-32::
    1s dance reels of 3 on sides passing 1st corners LSh to start & 1s
    cross RH to 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (8648, '2015-02-13 12:48:23.086742+00', '2023-02-04 01:22:59.622563+00', 15311, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig 8, 2s dancing up to start & finish facing
    out/up
9-16::
    1s+2s+3s dance »Inveran Reels« on sides, each couple crossing down
    from 1st place & crossing up from 3rd place (1s cross down, 2s dance
    up, 3s cross up to start)
17-24::
    1s cross RH, cast (2s step up), 1s cross down LH between 3s, cast up
    passing LSh to face 1st corners
25-32::
    1s dance  Pass+Turn with 1st and 2nd corners, pass RSh to 2nd place
    own sides
33-40::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7765, '2013-08-21 08:31:48.075095+00', '2023-02-04 01:22:59.639609+00', 6823, 3, NULL, 'ace', '1-8::
    1s & 3s set to opp person, change places RH (in middle), set again &
    Ladies turn right to end in own places _while_ Men end in each
    others place
9-16::
    2s & 4s repeat
17-24::
    1s+3s 1/2 Ladies'' Chain, 2s+4s 1/2 Ladies'' Chain
25-32::
    All dance 1/2 Grand Chain (RH to corners), all promenade
    anticlockwise to end opposite original prtns with Ladies in centre
    facing partners
33-40::
    All petronella turn to Men in centre facing anticlockwise & Ladies
    facing clockwise on outside
41-48::
    Ladies dance 1/4 round _while_ Men dance 1/2 LH across, all 1/2 turn
    new partner & Men dance 1/4 round _while_ Ladies dance 1/2 LH
    across, all 1/2 turn new partners (Ladies into centre)
49-56::
    Repeat with Ladies ending on partners right in square formation
57-64::
    Men dance in front of partner, behind next Lady to opposite place,
    Ladies dance in front of their new partner, behind next Man to
    partner''s right
65-96::
    Repeat bars 1-32', 0);
INSERT INTO 'dancecrib' VALUES (7766, '2013-08-21 08:31:48.083376+00', '2023-02-04 01:22:59.662377+00', 9899, 3, NULL, 'ace', '1-8::
    1L followed by partner casts 1 place, crosses up between 2s, casts
    round 2M & crosses to 2nd place own side (1M ends in 2nd place own
    side)
9-16::
    1s lead down & back up. On bars 15-16 Lady turns under Man''s right
    arm as he turns right about, 1s end facing 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting ending with a clap & petronella
    turn to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14547, '2022-01-10 02:21:07.929084+00', '2023-02-04 01:22:59.689114+00', 20606, 3, NULL, 'ace', '1-8::
    1s lead down middle & back finishing in 1st place facing out
9-13::
    1s followed by 2s (who dance up to start) cast through 2nd place (2
    bars), 1M+2M+3M dance RH across _while_ 1L+2L+3L dance LH across (3
    bars)
14-16::
    1s+2s join NH with partner on meeting & dance up & cast to end 2 1 3
17-24::
    1s+3s dance »Bankette«:
::
    1s+3s set, 1M+3L change places RH; 1L+3M change places LH, 3s+1s
    cross RH with partner to own side.  2 3 1
25-32::
    2s+3s+1s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7767, '2013-08-21 08:31:48.091426+00', '2023-02-04 01:22:59.71986+00', 9943, 3, NULL, 'ace', '1‑8::
    1s set, lead down for 2 steps, 1/2 turn RH (Lady turning under Mans
    arm to end facing up), 1s dance up to end facing up between 2s
9‑16::
    1L+2M 3/4 turn LH _while_ 1M+2L 3/4 turn RH, 1s 1/2 turn 2H to face
    down, 1M+3M 3/4 turn RH _while_ 1L+3L 3/4 turn LH & 1s 1/2 turn 2H
    to face up
17‑24::
    1s dance up & cast to start reels of 3 on opposite sides
25‑32::
    1s dance up & cast to 2nd place _while_ 2s & 3s set & cross RH,
    2s+1s+3s set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (7768, '2013-08-21 08:31:48.101027+00', '2023-02-04 01:22:59.823765+00', 6824, 3, NULL, 'ace', '1-8::
    1L+2L+3L cross & dance RSh round partners, back to places & set
9-16::
    1M+2M+3M cross & dance RSh round partners, back to places & dance in
    to meet partner for Promenade
17-24::
    1s+2s+3s Promenade
25-32::
    1s cross down turning 3s RH (1M turns 3L & 1L turns 3M) & cross back
    to turn 2s LH (1M turns 2M & 1L turns 2L) to end in 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (13927, '2021-04-05 00:22:12.373225+00', '2023-02-04 01:22:59.849957+00', 19484, 3, NULL, 'ace', '1-8::
    1s dance down (2s step up) to BtoB in centre 2nd place, facing own
    side, 2s+1s+3s dance 6 bars of Double Triangles.  1s end in centre
    facing opp sides
9-16::
    1L+2s & 1M+3s dance reels of 3 across (1L+2L & 1M+3M pass RSh to
    start).  1s end in 2nd place opp sides, 1L facing down, 1M facing up
17-20::
    1s dance out of ends & cast left to 2nd place own side
21-28::
    1L+2s & 1M+3s dance RH across & LH across
29-32::
    2s+1s+3s turn partners LH.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7769, '2013-08-21 08:31:48.109104+00', '2023-02-04 01:22:59.870629+00', 10578, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, cross RH, set & 1/2 turn partners LH into prom hold
    facing up
9-16::
    1s+2s+3s dance Allemande
17-24::
    All set, 1/2 turn partners RH, 3s+2s also 1s+4s circle 4H round to
    left
25-32::
    All dance reels of 4 on opposite sides ending 3 2 1 4 on opposite
    sides

{{explanation}}
Repeat with ''up-side down'' set & 4s leading', 0);
INSERT INTO 'dancecrib' VALUES (11479, '2019-01-01 01:58:05.125646+00', '2023-02-04 01:22:59.926213+00', 18953, 3, NULL, 'ace', '1-8::
    1s dance in & cast to face 1st corners (2 step up); 1s set to & turn
    1st corners 2H
9-16::
    1s+1st corners dance 1/2 diag reel of 4, 1s pass RSh & dance 1/2
    diag reel of 4 with 2nd corners. pass RSh to face 4th corner
    positions
17-24::
    1s set to & 3/4 turn 4th corners 2H; 1s dance 1/2 Fig 8 (1M up round
    3s, 1L down round 2s).  End (3) (1) (2)
25-32::
    All set, cross RH & chase clockwise 1/2 round to own sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7770, '2013-08-21 08:31:48.119517+00', '2023-02-04 01:22:59.951466+00', 12998, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & dance La Baratte:
::
    _2-4_   Men 1/2 turn opposite Lady RH & retains hand but at arm''s
    length from each other
::
    _5-6_   Men retrace steps with Lady turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies original
    place)
::
    &   releasing Ladies RH she turns under Mans left arm until almost
    in original places
::
    _7-8_   Couple change places LH to opposite places
9-16::
    1s+2s+3s Set+Link for 3 twice to end 3 2 1
17-20::
    3s+2s Set+Link
21-32::
    All dance 3 couple R&L.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7771, '2013-08-21 08:31:48.128813+00', '2023-02-04 01:22:59.986829+00', 13455, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across, 1s dance in & cast to 3rd place.  2 3 1 4 5
9-12::
    2M+1L & 1M+5L change places (passing RSh) to face out on opposite
    sides & change places LH with person on left
13-16::
    2M+1L & 1M+5L change places (passing LSh) to face out & change
    places RH with person on right.  2 3 1 4 5
17-20::
    2L+1M & 1L+5M change places (passing LSh) to face out & change
    places RH with person on right
21-24::
    2L+1M & 1L+5M change places (passing RSh) to face out & change
    places LH with person on left.  2 3 1 4 5
25-32::
    1s dance in & cast to 5th place, 5s+1s dance LH across.  2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (12560, '2020-02-02 02:49:59.349228+00', '2023-02-04 01:23:00.015061+00', 19839, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reels of 3 on opp side, each couple crosses from 1st
    place. End in centre with partner facing down ready for allemande.
    (1) (2) (3)
9-16::
    3s leading, with 2s+1s following, dance allemande (down).  (3) (2)
    (1)
17-24::
    3s+2s cross RH & dance 1/2 RH across; 3s+1s dance LH across.  (2)
    (3) (1)
25-32::
    2s+3s+1s dance La Baratte:
::
    _25-26_   All set
::
    _27-28_   Man 1/2 turns opposite Lady RH & retains hand but at arm''s
    length from each other
::
    _29-30_   Man retraces steps with Lady turning right under Man''s arm
    briefly into Allemande hold (Man behind Lady facing Ladies'' original
    place) Man release Ladies'' RH & she turns under Man''s left arm until
    almost in original places
::
    _31-32_   Couple change places LH to opposite places.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7772, '2013-08-21 08:31:48.137055+00', '2023-02-04 01:23:00.043513+00', 13762, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s set & cross RH
9-16::
    1s dance reels of 3 on opposite sides giving RSh to 1st corner
17-24::
    1s set & cast 1 place, 1s cross RH & cast up to 2nd place as 3s
    dance in down to 3rd place
25-32::
    1s dance reflection reels of 3 on own sides (1s in & up to start)', 0);
INSERT INTO 'dancecrib' VALUES (7773, '2013-08-21 08:31:48.242592+00', '2023-02-04 01:23:00.280964+00', 9159, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s circle 4H round, turn partners 2H & chase clockwise
    1/2 way (in 2 separate groups of 4)
9-16::
    1s+4s dance LH across _while_ others chase clockwise to opposite
    ends, 1s & 4s lead out of ends of set, cross & cast to end 3 1 4 2
17-24::
    1s+4s dance the Knot to end 3 4 1 2
25-32::
    Top 3 Men turn bottom 3 Ladies RH & 4s+1s turn partner LH, top 3
    Ladies turn bottom 3 Men RH & 4s+1s 3/4 turn partner LH to end in
    line in middle Men facing up Ladies down
33-40::
    4s+1s set, dance 1/2 reel of 4 & 3/4 turn partners RH to end 3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (12880, '2020-06-03 16:28:10.267344+00', '2023-02-04 01:23:00.309035+00', 13918, 3, NULL, 'ace', '1-4::
    1s followed by 2s dance down, Bar 4: 1M dances below 1L who dances
    under 1M''s arm to change sides & 1s face up, 2s divide & dance below
    1s
5-8::
    1s followed by 2s dance up, Bar 8: 1M dances above 1L who dances
    under 1M''s arm to change sides, 2s dance out to place
9-12::
    1s+2s turn on sides 1.1/2 (Men RH, Ladies LH). 1s briefly join
    nearer hands in centre to face each other
13-16::
    1s set, turn 3/4 RH to end in centre facing 4th corners
17-24::
    2s+1s+3s dance reels of 3 on sides (1s+4th corners pass RSh); Bar
    20: 1s pass RSh to continue reel on opp sides. 1s end facing 2nd
    corners
25-32::
    1M+2s & 1L+3s dance reels of 3 across, 1s pass 2nd corner RSh to
    start.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (15083, '2022-09-05 00:22:18.124061+00', '2023-02-04 01:23:00.330115+00', 20919, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s circle 4H round to left, face on sides; set & turn
    RH on sides & face again
9-16::
    All dance 4 1/2 reels of 4 around set:
::
    1s+2s also 3s+4s dance 1/2 RSh reels of 4 on sides & start to pass
    RSh to form lines across & dance 1/2 RSh reel of 4 across & start to
    pass RSh to form lines on sides
17-24::
    All repeat 9-16 to end in original places (Note: always start reels
    facing same person)
25-32::
    1s set, cast (2s step up); dance in front of 3s (3s step up) &
    behind 4s (4s step up).  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7774, '2013-08-21 08:31:48.252893+00', '2023-02-04 01:23:00.360848+00', 6829, 3, NULL, 'ace', '1-8::
    All dance Interlocking reels of 4
9-16::
    All turn partners RH 1.3/4 times, Ladies dance LH across _while_ Men
    chase clockwise 1/2 way
17-24::
    All turn facing dancer RH 1.1/2 times, Men dance LH across _while_
    Ladies chase clockwise 1/2 way
25-32::
    All turn partners RH & set (HS) for 4 bars & turn 2H
33-40::
    1s+2s also 3s+4s circle 4H to left & open into 8H round to left 1/2
    way
41-48::
    All set (HS) on sides, 1s+3s dance 1/2 R&L
49-56::
    All set (HS) on sides, 2s+4s dance 1/2 R&L
57-64::
    All dance Grand Chain ending with Ladies in centre (RH across) & Men
    on outside in St Andrews Cross
65-72::
    All dance 1/2 way round & turn partner 2H onto sides
73-80::
    All set (HS) to partner & turn RH 1.3/4 times (Lady into centre) for
    bow & curtsy', 0);
INSERT INTO 'dancecrib' VALUES (8369, '2014-07-29 12:59:36.278645+00', '2023-02-04 01:23:00.427734+00', 15060, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place (4 bars), turn 2H to face 1st corners (2s step
    up 5-6)
9-24::
    Interlocking Cloverleaf Reels:
::
    _9-12_    1s pass 1st corner RSh and curve back to middle, turn LH
    to face 4th corner _while_ corners dance to middle, dance RH across
    (briefly) and dance out to next corner anticlockwise, face in
::
    _13-24_   Repeat bars 9-12 3 more times (corners back in original
    places)
25-32::
    1s dance RSh round 1st corners, turn 2H 1.1/4 times, finish in 2nd
    place own side.
::
    (Variation for 3 Couple set:  1s dance RSh round 1st corners, meet,
    dance to 3rd place, all set)', 0);
INSERT INTO 'dancecrib' VALUES (13775, '2021-03-02 01:22:17.25418+00', '2023-02-04 01:23:00.440968+00', 12357, 3, NULL, 'ace', '1-8::
    All set twice; 1s & 4s turn partner RH
9-16::
    1s & 4s turn partner LH into centre (1s facing down, 4s facing up),
    1s+4s dance 1/2 R&L up/down  (4) 2 3 (1)
17-20::
    4s & 1s cast down/up 1 place (2s/3s step up/down), 1s turn 4s (4M+1M
    LH, 4L+1L RH).  2 (4) (1) 3
21-28::
    Reels of 4 on sides
29-32::
    4s cross down to 3rd place _while_ 1s cross down to 4th place
    _while_ 3s cast up to 2nd place & all set.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (11003, '2018-08-17 07:53:08.499265+00', '2023-02-04 01:23:00.501526+00', 18409, 3, NULL, 'ace', '1-8::
    1s+2s dance Double Fig 8 (1s cross down, 2s dance up).  2s end
    facing out
9-12::
    _1/2_ mirror reels of 3 on sides (1s in/down to start). 2s face out
13-16::
    1s turn RH _while_ 2s+3s turn 1.1/2 on sides (Ladies LH, Men RH)  2
    3 1 4
17-24::
    1s+4s set, dance DoSiDo; 1M & 4L set on sides _while_ partners set
    advancing to face partner on diagonal
25-32::
    1s+4s dance "Hello-Goodbye Poussette":
::
    _25-26_    All set moving on 2nd step into lines across (1M+4L BtoB)
::
    _27-28_    Repeat, moving on 2nd step into diagonal lines between 3L
    & 4M place (1L+4M BtoB)
::
    _29-30_    Repeat, moving on 2nd step into line up/down (4L+1M BtoB)
::
    _31-32_    4s+1s drop hands & petronella turn to sides  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7777, '2013-08-21 08:31:48.277224+00', '2023-02-04 01:23:00.527708+00', 10525, 3, NULL, 'ace', '1-8::
    1s dance down, 1/2 turn 2H & dance up to face 1st corners
9-16::
    1s set & turn 1st corners 2H & set & turn 2nd corners 2H ending 2nd
    place opposite sides
17-24::
    1s cross passing RSh, 1L followed by partner casts below 3s, dances
    across, up behind 3M+2M & across to end in own places
25‑32::
    All dance 1/2 RSh reels of 4 on sides, top 3 couples dance 1/2 reels
    of 3
33-40::
    2s+3s also 4s+1s dance Diamond Poussette', 0);
INSERT INTO 'dancecrib' VALUES (12753, '2020-04-11 10:53:26.092764+00', '2023-02-04 01:23:00.640962+00', 13468, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across; 1s turn RH 1.1/4 to finish 1L between 2s, 1M
    following
9-16::
    2s+1L in a line of 3 across dance down, followed by 1M; 2s turn
    inwards & join hands with 1M, 2s+1M in a line of 3 across, dance up
    to finish 2s in 1st place
17-24::
    1M followed by 1L casts round 2L and across to own sides in 2nd
    place; 2s+1s circle 4H round to Left
25-32::
    2M+1L RH; 2L+1M turn LH.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (7778, '2013-08-21 08:31:48.285161+00', '2023-02-04 01:23:00.663091+00', 8368, 3, NULL, 'ace', '1-8::
    1s dance 1/2 Figs of 8 round 2s, 1s+2s Adv+Ret
9-16::
    1s+2s 1/2 turn partner RH, twirl & dance out, 1s+2s dance RH across
    once round
17-24::
    1s+2s dance Men''s Chain
25-32::
    1M+2L & 1L+2M in prom hold change places (Men passing LSh) & turn to
    left to face in, 1s dance 1/2 Figs of 8 round 2s to end in 2nd
    places', 0);
INSERT INTO 'dancecrib' VALUES (7779, '2013-08-21 08:31:48.334408+00', '2023-02-04 01:23:00.787157+00', 6833, 3, NULL, 'ace', '1-8::
    1L dances Fig of 8 round 2s _while_ 1M sets & dances 1/2 Fig of 8
    round 2s & dances across to own place
9-16::
    1s+2s+3s dance LSh reel of 3 on sides, 1s+2s change places LH on
    sides
17-24::
    1M dances full Fig of 8 round 3s _while_ 1L sets & dances 1/2 Fig of
    8 round 3s & dances across to 2nd place on own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7780, '2013-08-21 08:31:48.342549+00', '2023-02-04 01:23:00.815184+00', 13933, 3, NULL, 'ace', '1-4::
    1M+3L Adv to centre & set turning right about to face partner
5-8::
    1M & 3L 1/2 turn partner RH retaining hold & Bal-in-line in diagonal
    lines of 3 (1s with 2M, 3s with 2L)
9-16::
    1s+2M & 3s+2L dance parallel reels of 3 (1s & 3s giving Rsh to
    partner to start
17-24::
    1M & 3L (followed by partner) chase clockwise to 3rd/1st places &
    all turn RH into Allemande hold.  3 2 1
25-32::
    3s+2s+1s dance Allemande but on bars 31/32 1s cast to 2nd place as
    2s dance up to 1st place).  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10109, '2017-09-03 23:45:33.898219+00', '2023-02-04 01:23:00.841135+00', 6837, 3, NULL, 'ace', '1-8::
    1s+2s cross over (Men making arches), repeat back to place (Ladies
    making arches)
9-16::
    1s+2s dance RH across & LH back
17-24::
    1s lead down 3 bars, up to top & cast to 2nd place (2s step up 7-8)', 0);
INSERT INTO 'dancecrib' VALUES (7781, '2013-08-21 08:31:48.350782+00', '2023-02-04 01:23:00.867353+00', 8842, 3, NULL, 'ace', '1-8::
    1s & 4s set (facing down/up), 1s & 4s NHJ change places with 1s
    dancing under 4s arch, both Ladies dance under Mens arm crossing
    over & 1s also 4s cast in 1 pl on opp sides  2(4)(1)3
9-16::
    2s & 3s repeat above Fig to end (4)(3)(2)(1) all on opposite sides
17-24::
    4s followed by 3s+2s+1s cast to own places (on opposite sides) & all
    turn RH
25-32::
    1s & 2s also 3s & 4s cross to own sides (Ladies dancing under arches
    made the Men), 2s & 3s dance under arches made by 1s & 4s to change
    places, 1s+4s cross RH & dance 1/2 RH across to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7946, '2013-08-21 08:31:51.645849+00', '2023-02-04 01:23:13.121193+00', 7147, 3, NULL, 'ace', '1-8::
    1s+3s set advancing & Bal-in-Line (Man above Lady), turn partners RH
    & 1s cast to 3rd place _while_ 3s lead up to 1st place
9-16::
    3s+1s set advancing & Bal-in-Line (Man above Lady), turn partners RH
    & 3s cast to 3rd place _while_ 1s lead up to 1st place
17-24::
    1s lead down & back to 2nd place
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7782, '2013-08-21 08:31:48.360653+00', '2023-02-04 01:23:00.902152+00', 9900, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & circle 6H round to left _while_ 4s+5s set across, set
    down/up & dance RH across
9-16::
    1s & 3s (in prom hold Lady on M''s right) dance RSh reels of 3 across
    (1s with 2s & 3s with 4s), 2s & 4s dance up 1place as 1s & 3s face
    1st crnrs
17-24::
    1s also 3s turn corner RH, partner LH, 2nd corner RH & pass partner
    RSh to face own side
25-32::
    1s also 3s dance Crown Triangles & end (BtoB with partner) with
    Ladies facing up & Men facing down
33-36::
    All dance LH across (1L with 2s, 1M+3L with 4s & 3M with 5s)
37-48::
    1s+3s dance reel of 4 in the middle. 1s+3s turn partners RH & cast
    down 1 place', 0);
INSERT INTO 'dancecrib' VALUES (7783, '2013-08-21 08:31:48.368834+00', '2023-02-04 01:23:00.935715+00', 7531, 3, NULL, 'ace', '1-8::
    1M+3M turn RH & chase clockwise 1/2 way round outside to opposite
    places
9-16::
    1L+3L turn LH & chase anticlockwise 1/2 way round outside to
    opposite places
17-32::
    2s+4s repeat bars 1- 16
33-40::
    1s+3s in prom hold Adv+Ret & promenade 1/2 way round & end facing
    3s/1s
41-48::
    1s+3s dance RH across & LH back to end in original places
49-64::
    2s+4s repeat bars 33-48
65-72::
    All Men dance in front of partner, behind next Lady, in front of
    next Lady & behind next Lady back to places
73-80::
    All Ladies repeat dancing in front of partner to start
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8370, '2014-07-29 12:59:36.375817+00', '2023-02-04 01:23:00.956996+00', 15286, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & dance LH across 1/2 way, 1s+2s change places
    LH on the sides
9-16::
    1s+2s+3s dance LSh parallel reels of three on the sides
17-24::
    1L & 2L and also 1M & 2M set and petronella-in-tandem, repeat
25-32::
    2s+1s+3s Adv+Ret for 2 steps &  turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (8706, '2015-03-03 08:48:10.102578+00', '2023-02-04 01:23:00.986414+00', 16119, 3, NULL, 'ace', '1-8::
    1s set, turn RH 1/2 way, dance down NHJ below 3s, cast up into 2nd
    place opp. sides (2s step up 5-6)
9-16::
    2s+1s+3s dance mirror reels on sides (1s in & up to start), 1s end
    in 2nd place opp. sides
17-24::
    1s petronella turn (1M between 2s facing down, 1L between 3s facing
    up), 1s set, change places RH, cast to Right into 2nd place own
    sides
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (11174, '2018-09-30 16:46:35.095621+00', '2023-02-04 01:23:01.012634+00', 18670, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & 1s+2s dance RH across 1/2 way _while_ 3s cross RH, 1L
    followed by prtnr cast up round 2L & dance down to L b''tw''n 3s,1
    b''tw''n 2s
9-16::
    2s+1s+3s dance down the middle & back (top line face down)
17-24::
    2s+1s+3s set & change places RH with opposite person & 1s cast to
    2nd place own sides
25-32::
    1s dance diag R&L', 0);
INSERT INTO 'dancecrib' VALUES (8853, '2015-08-13 20:34:12.757101+00', '2023-02-04 01:23:01.049512+00', 14291, 3, NULL, 'ace', '1-8::
    1s lead down middle & back
9-16::
    1s+2s dance the Knot, 1s end in centre in promenade hold facing up,
    2s in 1st place
17-24::
    1s dance reel of 3 across passing 2L RSh to start (6 bars); 1s dance
    up to top & face out, 2s into 2nd place
25-28::
    1s+2s change place (1M+2M LH, 1L+2L RH), 1s+3s change place other
    hand, 1s+4s change place other hand
29-32::
    All 4 couples turn partners 2H twice round', 0);
INSERT INTO 'dancecrib' VALUES (7784, '2013-08-21 08:31:48.394383+00', '2023-02-04 01:23:01.08046+00', 12416, 3, NULL, 'ace', '1-8::
    1s 1/2 turn 2s on sides (Men RH, Ladies LH) into position for &
    dance Double Triangles
9-16::
    1s dance RH across (1L with 2s, 1M with 3s), 1s dance LH across with
    other couple & end in middle RH joined facing 1st corners
17-24::
    1s set to 1st corners & turn RH to face 2nd corners, set to 2nd
    corners & full turn RH into…
25-32::
    1s dance reels of 3 across (1M with 2s, 1L with 3s) to end 2nd place
    own side', 0);
INSERT INTO 'dancecrib' VALUES (11220, '2018-09-30 22:20:41.954281+00', '2023-02-04 01:23:01.110845+00', 18509, 3, NULL, 'ace', '{{explanation}}
Round the Room - 3 facing 3  
2 chords: middle dancer honour RH partner, then LH partner & remain facing each other

1-8::
    LSh reels of 3 across
9-16::
    Middle dancer LSh reel of 3 with 2 dancers on Right (LSh to dancer
    opposite to Right)
17-24::
    All circle 6H round & back
25-32::
    All set, 1/2 turn opp person, pull back RSh & set (if close to next
    line of 3) or dance on to meet new line of 3 (2 bars)', 0);
INSERT INTO 'dancecrib' VALUES (12947, '2020-07-01 00:21:53.086276+00', '2023-02-04 01:23:01.136378+00', 6843, 3, NULL, 'ace', '1-4::
    1s cast to 2nd place & lead back up to 1st place as 2s lead up &
    cast back to 2nd place _while_
::
    3s lead down to 4th place & cast back up to 3rd place as 4s cast up
    to 3rd place & lead back down to 4th place
5-8::
    1s+2s also 3s with 4s dance RH across
9-16::
    2s+3s cast round their corners (2 bars) (2M&3L pass corner RSh,
    2L&3M pass corner LSh), meet partner in centre, 2s lead down under
    arch made by 3s who dance up (4 bars), 2s+3s cast round corners (2
    bars)
17-20::
    2M+3M make arch & cross over, 2L+3L dancing under arch (2 bars),
    2s+3s cast round corners (2 bars)
21-24::
    3s dance down under arch made by 2s who dance up
25-28::
    2s+3s cast round their corners (2 bars), 2M+3M make arch & cross
    over, 2L+3L dancing under arch (2 bars)
29-32::
    1s+2s also 3s+4s dance RH across, all couples finishing facing up in
    centre ready for…
33-40::
    1s+2s also 3s+4s dance allemande.  End 2 1 4 3
::
    Repeat with new 2nd & 3rd couples', 0);
INSERT INTO 'dancecrib' VALUES (7785, '2013-08-21 08:31:48.40243+00', '2023-02-04 01:23:01.163855+00', 6845, 3, NULL, 'ace', '1-8::
    1s turn RH, 1L+3M set & cast to 2nd place
9-16::
    1L+3M dance 1/2 Figs of 8 round partners to change sides, 1s+2s+3s
    dance 1/2 reels of 3 on sides giving RSh to 2nd corners
17-24::
    All dancers cross with opp dancer RH, dancers in 2L+3L places cross
    diag LH with dancers in 1M+2M pl, all dancers cross & repeat
25-32::
    1s+2s set & dance 1/2 RH across, 1s set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (7786, '2013-08-21 08:31:48.410474+00', '2023-02-04 01:23:01.199017+00', 6846, 3, NULL, 'ace', '1-8::
    1s dance Inveran reels with 2s+3s
9-16::
    1s (NHJ) set to 2L _while_ 3s set to 2M, 1s set to 3s _while_ 2s set
    across, 1s set to 2M _while_ 3s set to 2L, 1s set to 3s _while_ 2s
    set across
17-24::
    1s & 3s change places RH with opposite person into RH across 1/2 way
    & chase clockwise 1/2 way (outside 2s)
25-32::
    3s+2s+1s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7787, '2013-08-21 08:31:48.4204+00', '2023-02-04 01:23:01.223895+00', 13445, 3, NULL, 'ace', '1-8::
    3s set & cast up behind 2s, dance up between 1s (2s step down) &
    cast to 2nd place own sides  1 3 2
9-16::
    3s dance 1/2 reels of 3 across (3M at top, 3L at bottom, RSh to 2nd
    corner) & dance 1/2 reels of 3 across with other couple (RSh to 4th
    corner)
17-24::
    1s+3s Set+Link, 1s+2s Set+Link.  3 2 1
25-32::
    2s followed by 3s dance Fig of 8 round 1s to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7788, '2013-08-21 08:31:48.428627+00', '2023-02-04 01:23:01.241999+00', 6847, 3, NULL, 'ace', '1-8::
    1s+4s 3/4 turn RH to end in line up & down (Men facing up & Ladies
    down) & dance 1/2 RSh reel of 4, 3/4 turn ptnrs RH to end on sides.
    4 2 3 1
9-16::
    4s+2s also 3s+1s dance double Fig of 8 (4s & 1s cast to start)
17-24::
    All set, Ladies dance round partners LSh & back to place
25-32::
    All set & Men dance round partners RSh & back to place
33-40::
    4s+2s also 3s+1s dance RH across (3 bars) & LH back, 4s & 1s cast in
    1 place _while_ 2s & 3s dance to ends.  2 4 1 3
41-48::
    1s+4s dance R&L starting on the sides', 0);
INSERT INTO 'dancecrib' VALUES (7789, '2013-08-21 08:31:48.43656+00', '2023-02-04 01:23:01.260326+00', 6848, 3, NULL, 'ace', '1-8::
    1s cast down behind own lines, turning out cast back to top.  Bar 8
    all 3 couples dance in ready for ...
9-16::
    1s+2s+3s Promenade, 1s cast & face 1st corners, 2s dance up to 1st
    place
17-24::
    1s set to 1st corners, set to 2nd corners, pull back RSh turning
    into 2nd place opposite sides, 2s+1s+3s circle 6H round to left (4
    bars - quick)
25-32::
    2s+1s+3s Adv+Ret & turn 2H 1s ending in 2nd place own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14811, '2022-05-05 00:22:11.488247+00', '2023-02-04 01:23:01.457977+00', 6849, 3, NULL, 'ace', '1-8::
    1s set, cast 2 places, meet below 3s & lead up to top. Finish in
    centre facing down NHJ
9-12::
    1s make arch & dance down _while_ 2s+3s lead up under arch (2 bars),
    1s turn inwards, dance up to face 2s _while_ 3s cast to 3rd place. 2
    1 3
13-16::
    2s+1s circle 4H round to left
17-20::
    1s NHJ face 3s (who step in to face up NHJ) & set to them, 1s+3s set
    to partners & 1s end facing up, 3s retire back to side
21-24::
    1s NHJ face 2s (who step in to face down NHJ) & set to them, 2s+1s
    set to partners & both couples retire to sides
25-32::
    1s+3s circle 4H round to left; 2s+1s dance LH across.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8649, '2015-02-13 12:48:23.46586+00', '2023-02-04 01:23:01.518942+00', 10857, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH, set & cross back RH
9-16::
    1M followed by partner casts 1 place & cross to opposite side, 2s+1s
    set to partners & 2s+1s set to each other on sides
17-24::
    2s+1s dance Ladies'' Chain
25-32::
    1s set, 1L followed by partner, casts up & cross to own side, 1L
    casts to 2nd place _while_ 1M dances down middle to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (7790, '2013-08-21 08:31:48.444564+00', '2023-02-04 01:23:01.539339+00', 8955, 3, NULL, 'ace', '1-8::
    1s set & cross RH, 1s+2s turn LH 1.1/2 times on sides
9-16::
    2s+1s dance Ladies'' Chain
17-24::
    2s+1s+3s set & dance reels of 3 on own sides (1s cross down to 3rd
    place to start)
25-32::
    2s+1s+3s dance Grand Chain', 0);
INSERT INTO 'dancecrib' VALUES (7791, '2013-08-21 08:31:48.452571+00', '2023-02-04 01:23:01.570194+00', 6853, 3, NULL, 'ace', '1-8::
    1s set advancing, turn 2H & lead down between 2s & cast down behind
    3s & 4s to 4th place
9-12::
    2s+3s & 4s+1s dance 1/2 R&L
13-16::
    All cross diag to left pass diag opp person RSh & loop to right to
    face partner NB top L & bottom M pass person in next set if present
17-24::
    3s+2s & 1s+4s dance 1/2 R&L & repeat bars 13-16
25-32::
    2s+3s & 4s+1s circle 4H round to left & all turn partner RH', 0);
INSERT INTO 'dancecrib' VALUES (7792, '2013-08-21 08:31:48.477043+00', '2023-02-04 01:23:01.592428+00', 10300, 3, NULL, 'ace', '1-8::
    All dance DoSiDo, Men dance LH across in centre 2 places _while_
    Ladies dance clockwise 1 place, turn partner RH
9-16::
    Repeat last 4 bars twice back to original places
17-24::
    All set to corners & 1/2 turn RH, set to next person & 1/2 turn LH
25-32::
    All advance into centre with ''new'' partner & retire with original
    partner, all dance 1/2 Grand Chain (RH to corner person to start)
    back to places
33-40::
    All circle 6H round to left, set (in circle) & circle right for 4
    bars to end 3 1 2

{{explanation}}
Note: may be danced as Strathspey or Medley', 0);
INSERT INTO 'dancecrib' VALUES (7793, '2013-08-21 08:31:48.491427+00', '2023-02-04 01:23:01.620718+00', 8996, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1M & 4M cast in 1 place, set to each other & turn RH
9-16::
    1L & 4L repeat turning LH
17-24::
    2s+1s also 4s+3s dance RH across, 1s+4s dance LH across to end BtoB
    in centre facing corners (Men face Men)
25-32::
    1s & 4s dance ''Hello-Goodbye'' setting (set to corners, set on sides,
    set to next corner & into centre facing ptnr) & petronella turn to
    pl 2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (7794, '2013-08-21 08:31:48.500873+00', '2023-02-04 01:23:01.645215+00', 7558, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret & dance RH across
9-16::
    1s+2s dance DoSiDo with partners & dance LH across
17-24::
    1s dance down, 1L turns under 1M right arm & dance up to 2nd place
    in middle facing up
25-32::
    1L dances LH across with 2M+3M as 1M dances RH across with 2L+3L, 1s
    lead up crossing & cast to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (13360, '2020-11-02 01:22:16.312988+00', '2023-02-04 01:23:01.785996+00', 14577, 3, NULL, 'ace', '1-8::
    1s+3s 1/2 turn RH, pull back RSh & dance out to opp sides; 1s+3s
    cast (2s & 4s step up). 1s+3s turn 3/4 LH to face 1st corners
9-16::
    1s+3s dance ''Hello-Goodbye'' setting (HS) & face 3rd corners
17-24::
    1s dance ''Corner Pass+Turn'':
::
    1s+3s dance a loop RSh round 3rd corner _while_ 3rd corners turn
    each other RH & return to places, 1s+3s pass RSh in the middle &
    repeat with 4th corners.  1s+3s end RHJ with partner on opp sides
    facing down
25-32::
    1s+3s lead down, change sides (Lady dances under Man''s arm); 1s+3s
    lead up & cast off 1 place to 3rd/5th place (4s & 5s step up). End 2
    4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (13448, '2020-12-02 01:22:11.329634+00', '2023-02-04 01:23:01.798582+00', 6858, 3, NULL, 'ace', '1-8::
    1s dance Fig 8 on opp sides (1s cross down to start, 2s step up
    1-2). 1s end between 2s facing down (1M with 1L on his right)
9-16::
    1s dance Fig 8 on own sides (1s cross down to start). 1s end between
    2s facing down NHJ (1M with 1L on his left)
17-24::
    1s 3/4 turn 3s (Ladies LH, Men RH). 1s end between 2s facing up NHJ;
    1s 3/4 turn 2s (Ladies RH, Men LH). 1s end in 2nd place own side
25-32::
    1s+3s Set & Rotate

{{explanation}}
Note:	For each couple, second time through 1-8: Reels of 3 on opp sides; 9-16: reels of 3 on own side; 17-32: as above', 0);
INSERT INTO 'dancecrib' VALUES (8707, '2015-03-03 08:48:10.208654+00', '2023-02-04 01:23:01.810517+00', 12767, 3, NULL, 'ace', '1-8::
    1s+2s+3s cross RH & chase clockwise 1/2 way round, 3s+2s+1 cross RH
    to opp sides (3) (2) (1)
9-16::
    1s set, cast up 1 place (2s step down 11-12); 1s lead up, cross &
    cast to 2nd place own side (3) 1 (2)
17-24::
    1s dance RH across (1L with 3s at top, 1M with 2s in 3rd place), 1s
    swap ends to dance LH across with other couple
25-32::
    1s dance Diag R&L (1M down, 1L up)  Finish 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10633, '2018-04-16 21:42:44.136162+00', '2023-02-04 01:23:01.854889+00', 6859, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, circle 6H 1/2 round to Left; 1M casts up to top place
    followed by 2M+3M _while_ 3L casts to 3rd place followed by 2L+1L &
    all cross RH to own sides 1 2 3
9-16::
    1s turn RH & cast (2s step up); 2s+1s+3s set & cross RH
17-24::
    2s+1s+3s set, circle 6H 1/2 round to own sides; 1s turn LH (4 bars),
    1M faces down, 1L faces up _while_ 2s+3s dance clockwise 1/2 round
    1s to end (2) 1 (3)
25-32::
    2s+3s 1.1/2 turn partners 2H to own side _while_ 1s dance
    anticlockwise round 2s / 3s to 2nd place opp sides, set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (10634, '2018-04-16 21:42:44.144437+00', '2023-02-04 01:23:01.875921+00', 13869, 3, NULL, 'ace', '1-8::
    Mirror reels of 3 on sides (2 cross up - no hands, 1s & 3s cast to
    start) 1s & 3s curve into place at end of reels
9-16::
    1s+2s+3s Set+Link for 3, flowing into circle 6H 1/2 round to left
17-24::
    Repeat 9-16
25-28::
    2s dance 1/2 diag reel of 4 with 1st corners (pstn), approach each
    other & pull back RSh to face 4th corners (pstn)
29-32::
    2s dance 1/2 diag reel of 4 with 4th corners.  End on sides, 1s
    facing across, 2s facing down, 3s facing up
33-40::
    All dance Progressive Grand Chain:
::
    _33-34_    1s (at top) turn once round RH as 2s+3s change places RH
    on sides,
::
    _35-36_    2s (at bottom) turn once round LH as 1s+3s change places
    LH on sides,
::
    _37-38_    3s (at top) turn once round RH as 1s+2s change places RH
    on sides,
::
    _39-40_    1s (at bottom) turn once round LH as 2s+3s change places
    LH on sides to end 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7796, '2013-08-21 08:31:48.526986+00', '2023-02-04 01:23:01.887536+00', 6860, 3, NULL, 'ace', '1-8::
    1s cross down below 2s to dance Figs of 8 on opposite sides.  (1) 2
    3
9-16::
    1s cross down below 2s to dance reels of 3 on own side with 2s & 3s
    also crossing down from the top position.  1 (2) (3)
17-24::
    1s set advancing & turn 2H to face up, 1s cast to 2nd place &
    petronella turn into middle BtoB facing own sides
25-32::
    1s dance Double Triangles ending 2nd place own sides except 2s+3s
    set & cross RH to own sides on bars 27/28', 0);
INSERT INTO 'dancecrib' VALUES (7797, '2013-08-21 08:31:48.535247+00', '2023-02-04 01:23:01.901571+00', 6862, 3, NULL, 'ace', '1-8::
    1s+2s dance double Fig of 8 (1s cross down to start)
9-16::
    1s dance 1/2 reel of 3 on sides (1s dancing between 2s to start), 3s
    (1st place) set _while_ 2s+1s change places on side (Ladies RH, Men
    LH), 2s (in 3rd place) set _while_ 1s+3s change places on side
    (Ladies LH, Men RH)
17-24::
    1s & 2s 3/4 turn RH into centre (M facing up, L down) & set _while_
    3s cast to dance clockwise between 1s/2s & into centre (M facing up
    & L down), 1s+3s+2s turn RH 1.1/4 times to end facing up in centre
25-32::
    1s+3s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7798, '2013-08-21 08:31:48.543322+00', '2023-02-04 01:23:01.924127+00', 13582, 3, NULL, 'ace', '1-8::
    1s set & turn 2H to face down, 1s dance down below 3s & cast up to
    2nd place
9-16::
    2s+1s dance double Fig of 8  (1s cross up to start) & 1s end facing
    1st corners
17-20::
    1s set to 1st corners as 2nd corners set diagonally. 1s dance RSh
    round each to face 2nd corners (now in 1st corner pstns) _while_
    2s+3s dance clockwise 1 place
21-24::
    1s set to corners as 1st corners set diagonally. 1s dance RSh round
    each other into 2nd place opp sides _while_ 2s+3s dance clockwise 1
    place (3)(1)(2)
25-32::
    3s+1s+2s 1/2 turn RH & face partners. All set in lines of 3 to
    finish facing up NHJ, 3s followed by 1s+2s dance up & cast to new
    positions.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7799, '2013-08-21 08:31:48.55336+00', '2023-02-04 01:23:01.94626+00', 8635, 3, NULL, 'ace', '1-8::
    1s lead down for 2 steps & lead to cast to 2nd place, dance down &
    cross below 3s & cast up to 2nd place opposite sides
9-16::
    1s dance reels of 3 across (1M+2s & 1L+3s) & start by crossing to
    give RSh to 3rd corner, 1s end between 2s/3s facing up/down
17-24::
    All set & 2s+3s change pl RH up/down as 1s turn 3/4 RH, all set
    across & 2s also 3s cross RH with ptnrs as 1s turn 3/4 to end in
    lines across
25-32::
    All set & 2s+3s change pl up/down as 1s cast round their 1st corner
    (pstn), all advance (& kiss?) then 1/2 turn partner with crossed
    hands then all loop right to 2nd place on own sides', 0);
INSERT INTO 'dancecrib' VALUES (8371, '2014-07-29 12:59:36.519462+00', '2023-02-04 01:23:02.150305+00', 15472, 3, NULL, 'ace', '1-8::
    All set & 1s+4s turn RH, 1s+4s cast in 1 place & change places LH on
    sides
9-16::
    All dance reels of 4 on sides
17-24::
    2s+4s also 1s+3s dance double Fig of 8  across (4s cross up & 1s
    cross down to start)
25-40::
    All dance 4 Couple Rights & Lefts:
::
    _25-26_     All cross RH
::
    _27-28_    Dancers in 1M & 2M places also 3L & 4L places change
    places LH on sides _while_ dancers in 1L & 3M places cross
    diagonally LH as dancers in 2L & 4M place cross diagonally LH
::
    _29-40_    Repeat Bars 25-28 three more times ending facing own
    partner.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7800, '2013-08-21 08:31:48.59068+00', '2023-02-04 01:23:02.164835+00', 12626, 3, NULL, 'ace', '1-8::
    All dance Grand Chain
9-16::
    All set & turn partner RH, set & turn partner LH
17-24::
    Ladies dance double Ladies'' Chain (1/2 RH across in centre)
25-32::
    All 3/4 turn corner RH & Promenade anticlockwise 7/8 round with Men
    ending with new partner having progressed 1 place clockwise', 0);
INSERT INTO 'dancecrib' VALUES (13642, '2021-02-04 01:22:11.150566+00', '2023-02-04 01:23:02.181369+00', 15243, 3, NULL, 'ace', '1-8::
    1s+2s & 3s+4s dance 1/2 R&L; 1s+4s dance 1/2 R&L (cross RH on side
    to start).1s & 4s face out
9-12::
    2s+4s & 1s+3s dance 1/2 double Fig 8 (1s+4s cast, 2s+3s cross
    down/up to start. At end 1L+4M dance towards each other
13-16::
    4L cast up round 2M into line of 3 across between 2s at top _while_
    1M casts down round 3L to between 3s _while_ 4M+1L turn RH to face
    partner in centre
17-24::
    1s+4s dance reel of 4 up/down centre
25-28::
    1s+4s join RH with partner & Bal-in-Line of 4, 1s+4s 1/2 turn RH
29-32::
    4M+2s (at top) & 1L+3s (at bottom) dance LH across _while_ 4L+1M (in
    centre) turn 1.3/4 LH.  All end on own side 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7801, '2013-08-21 08:31:48.608439+00', '2023-02-04 01:23:02.220572+00', 6870, 3, NULL, 'ace', '1-8::
    1L & 3M change places RH & cast to 2nd place, turn LH in middle to
    end BtoB facing partners
9-16::
    1L+3M dance diagonal reel of 4 with corners
17-24::
    1s & 3s set to partners, 1M & 3L set again _while_ partners turn to
    right & dance to original places, 1s+2L also 3s+2M dance RH hands
    across
25-32::
    1s+2s+3s Promenade & 1s cast to 2nd place _while_ 2s step up', 0);
INSERT INTO 'dancecrib' VALUES (9422, '2016-10-06 07:19:04.317091+00', '2023-02-04 01:23:02.253843+00', 17265, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s dance 1/2 Fig of 8 (1L up round 2s, 1M
    down round 3s)
9-16::
    1s dance 1/2 Diag R&L (1s dance to Right to start); Set+Link for 3
    ending in lines across
17-24::
    1s dance 1/2 Diag R&L (1s dance to Left to start); Set+Link  for 3
    ending on sides
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12828, '2020-05-14 23:16:40.549277+00', '2023-02-04 01:23:02.278804+00', 14472, 3, NULL, 'ace', '1-8::
    1L & 3M set _while_ 1M & 3L dance in to LSh to LSh 3L facing up, 1M
    down, 1s+3s dance 1/2 diag reel of 4, 1M & 3L dance out to partner
    place _while_ 3M & 1L cast (3M down, 1L up) to partner''s place
9-16::
    Repeat bars 1-8 from new positions, to finish 1L facing out, 1M
    facing in
17-24::
    1s turn 2s 1.1/2 RH, 1s meet in centre; 1s dance down between 3s &
    cast up to 2nd place.  2 1 3
25-28::
    All dance Allemande Right:
::
    2s+1s+3s advance for 2, give RH to partner & Lady turns under Man''s
    arm, Lady dances back to place as Man retires
29-32::
    All turn partners RH.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7802, '2013-08-21 08:31:48.697986+00', '2023-02-04 01:23:02.308017+00', 6873, 3, NULL, 'ace', '1-8::
    All set on sides, 1s+4s cast in 1 place, all Adv+Ret
9-16::
    1s+4s cross (Ladies between Men) & turn corner person (1s+4s dance
    out) to end 1s between 2s as 4s end between 3s, 1s+2s also 3s+4s
    Adv+Ret up/down
17-24::
    All set, 1s+4s dance 1/2 R&L (up/down to start) & end on sides, all
    set
25-32::
    All circle 8H round to left, remaining in circle all Adv+Ret
33-40::
    All circle 8H round to right, remaining in circle all Adv+Ret to
    sides.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7803, '2013-08-21 08:31:48.706131+00', '2023-02-04 01:23:02.343924+00', 10169, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 2s set _while_ 1M & 3L 3/4 turn RH to end in 3rd/1st
    place own side _while_ 1L casts to 3rd place & 3M casts to 1st
    place, all chase clockwise to end with Ladies in line across at top
    facing Men who face up
9-16::
    1s+2s+3s set to partners, 2s set _while_ 1M & 3L 3/4 turn LH to
    3rd/1st place own side _while_ 1L casts to 1st place on Men''s side &
    3M to 3rd place on Ladies side, 1s+2s+3s chase anticlockwise to end
    in original places
17-24::
    1s set & cross RH down to 2nd place, cast to top & cross down to 2nd
    place own side _while_ 2s cross RH, cast to top, cross RH down to
    2nd place & cast to top
25-32::
    2s+1s+3s dance Grand Chain', 0);
INSERT INTO 'dancecrib' VALUES (7804, '2013-08-21 08:31:48.860561+00', '2023-02-04 01:23:02.369556+00', 11221, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 2M+1L turn RH
9-16::
    2s+1s Set+Link, 1M+2L turn RH to end in centre facing partners
17-24::
    1s+2s dance diagonal RSh reel of 4 (6 bar), 1M+2L end (pass RSh)
    dancing out to partners place & 1s+2s chase clockwise 1/2 way
    (2)(1)
25-32::
    2s+1s dance RH across, retain RH with partners 1/2 turn & set', 0);
INSERT INTO 'dancecrib' VALUES (13100, '2020-08-10 00:21:48.029307+00', '2023-02-04 01:23:02.40745+00', 6876, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set & dance 1/2 RH across; 1s+4s dance LH across.
    1s face 2s, 4s face 3s.  (2) (1) (4) (3)
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1s lead up & cast to 2nd place _while_ 4s lead down & cast up to 3rd
    place; All turn partner RH 1.1/2, 2s end in top place _while_
    1s+4s+3s remain in centre ready for …
25-32::
    1s+4s+3s dance allemande.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7805, '2013-08-21 08:31:48.868707+00', '2023-02-04 01:23:02.441361+00', 12246, 3, NULL, 'ace', '1-8::
    1M+2L also 3M+4L set & change places RH, Men cross to own side &
    cast up to places _while_ Ladies cross to own side & cast down to
    places
9-16::
    All dance RSh reels of 4 on sides
17-24::
    1s+2s also 3s+4s dance RH across, 2s+3s dance LH across
25-32::
    1s cross RH & cast to 2nd place _while_ 4s cross RH & cast up to 3rd
    place, 1s+4s dance 1/2 R&L.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14382, '2021-10-11 22:42:25.227813+00', '2023-02-04 01:23:02.65787+00', 20486, 3, NULL, 'ace', '1-8::
    Ladies circle 4H round to left & back _while_ Men chase clockwise
    3/4 round
9-16::
    Men circle 4H round to left & back _while_ Ladies chase clockwise
    3/4 round. 2 3 4 1
17-24::
    3s+1s (side couples) 1/2 turn opp Man/Lady RH, pull back RSh & dance
    out to opp side; 1s+3s Set+Link
25-32::
    4s+2s 1/2 turn opp Man/Lady RH, pull back RSh & dance out to opp
    end; 2s+4s Set+Link.  4 1 2 3', 0);
INSERT INTO 'dancecrib' VALUES (7806, '2013-08-21 08:31:48.878842+00', '2023-02-04 01:23:02.682945+00', 11765, 3, NULL, 'ace', '{{title}}
Strathspey

1-8::
    All petronella turn & set, petronella turn & set to end on opposite
    sides
9-16::
    1s 3/4 turn RH, retain hands & change places with Lady turning under
    Man''s arm & 1/4 turn RH back to original places _while_ 4s dance
    similarly with LH. All set
17-18::
    All dance small circles around current place ("turn single") with 1L
    & 2L also 3M & 4M turning to right & others to left
19-20::
    2s+3s change places LH on sides
21-24::
    2s+3s dance 1/2 R&L & end facing end persons (2s facing 1s, 3s
    facing 4s)
25-32::
    All dance RSh reels of 4 on sides.  1 2 3 4

{{title}}
Reel

1-8::
    1s+2s also 3s+4s face on sides & dance 4 slips steps out to side &
    back twice
9-14::
    All 1/2 turn facing person on sides LH, 1s+4s dance RH across
15-16::
    2s+1s turn LH on sides to end 1s in middle (Lady at top facing down
    & Man between 3s facing up) _while_ 4s+3s 1/2 turn LH on sides
17-24::
    1L advances as 1M retires, 1L joins hands with 3s, 1M advances as 1L
    retires, 1M joins hands with 2s; repeat. (2s & 3s set throughout)
25-32::
    1s 1/2 turn 2H, cross up & cast to 4th place (2s+3s+4s step up
    31-32).  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (13361, '2020-11-02 01:22:17.068581+00', '2023-02-04 01:23:02.700246+00', 16792, 3, NULL, 'ace', '1-16::
    Ladies »weave« to bottom, up to top & across to own side dancing
    modified ''Sheepskin Hey'':
::
    1L followed by 2L+3L crosses, casts behind 1M, in front of 2M &
    dances LSh round 3M _while_ trailing 3L, on arriving below 2M, casts
    up round 2M to take lead
::
    3L followed by 1L+2L dances behind 2M, LSh round 1M _while_ trailing
    2L, on arriving above 2M dances down in front of 2M to take lead
::
    2L followed by 3L+1L dances behind 3M & leads 3L+1L across & back up
    own side to end 2L 3L 1L
17-32::
    Men repeat 1-16 to end 2 3 1
33-40::
    2s+3s dance RH across; 3s+1s dance LH across
41-48::
    Reels of 3 on sides (2s+3s - top 2 couples - pass RSh to start).
    End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (10635, '2018-04-16 21:42:44.393764+00', '2023-02-04 01:23:02.738563+00', 6887, 3, NULL, 'ace', '1-8::
    1s+3s set, cross RH; 1/2 Mirror reels of 4 on sides (1M+2L, 3M+4L
    pass RSh, 1L+2M, 3L+4M pass LSh to start)
9-16::
    4s+3s also 2s+1s dance Ladies Chain
17-24::
    1s+3s set, cross RH; 1/2 Mirror reels of 4 on sides (4M+3M, 2M+1M
    pass RSh, 4L+3L, 2L+1L pass LSh to start). All end in centre joining
    2H with partner
25-32::
    _4_ couple Poussette.  End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7808, '2013-08-21 08:31:48.894782+00', '2023-02-04 01:23:02.754076+00', 11400, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s dance down between 4s & cast to top & end 1s
    dancing down to 2nd place in centre facing down, 2s in 1st place, 3s
    in 3rd place
9-16::
    2s+1s+3s dance hands across on own side (Men RH, Ladies LH)  & back
    (Men LH, Ladies RH) Finish 2s at top facing out, 1s in 2nd place in
    centre facing up
17-24::
    1s in prom hold dance reels of 3 across (RSh to 2L), 1s finish in
    2nd place in centre facing up
25-32::
    1s lead up to top, cast to 3rd place (3s step up 27-28) & 1s turn 4s
    (1L+4L RH & 1M+4M LH) 1.1/2 times', 0);
INSERT INTO 'dancecrib' VALUES (8030, '2013-09-09 06:48:05.053417+00', '2023-02-04 01:23:02.778953+00', 14975, 3, NULL, 'ace', '1-8::
    1s & 5s cross RH as 3s set. 3s dance up, curving into 1st place &
    set (2s+4s step down bars 3-4) _while_ 1s & 5s chase clockwise to
    4th/2nd place, 5s & 1s turn partners RH to face 1st corners.
9-16::
    5s & 1s dance Corner Chain with setting with 1st corners:
::
    5s/1s change pl RH with 1st crnrs & set, 1st crnrs turn LH in middle
    & return to places giving RH to 5s/1s who turn LH in middle to face
    2nd crnrs
17-24::
    5s/1s repeat with 2nd crnr & end 5s/1s turning partners LH in middle
    to end side by side facing opposite sides
25-32::
    All dance RH across (3s+5L, 2s+5M+1L, 1M+4s), 5s+1s give LH to
    Bal-in-Line then turn partners LH to own sides.  3 5 2 1 4', 0);
INSERT INTO 'dancecrib' VALUES (8854, '2015-08-13 20:34:13.134115+00', '2023-02-04 01:23:02.811304+00', 16273, 3, NULL, 'ace', '1-8::
    1s+2s set, 2s followed by 1s dance down below 3s & cast up  2 1 3
9-16::
    1s turn 1/2 RH, turn 1st corner LH, turn each other RH, turn 2nd
    corner LH to finish between 1M between 2s , 1L between 3s, facing
    own sides
17-24::
    1M+2s also 1L+3s dance RSh reels of 3 across. Finish 1M between 2s,
    1L between 3s facing down/up
25-28::
    1s dance towards each other & turn 3/4 RH to 2nd place own sides
29-32::
    2s+1s+3s Advance diagonally (Men up, Ladies down - no hands)
    approaching partner''s RSh and then Retire to places', 0);
INSERT INTO 'dancecrib' VALUES (7809, '2013-08-21 08:31:48.973311+00', '2023-02-04 01:23:02.949704+00', 8162, 3, NULL, 'ace', '1-8::
    All Adv+Ret 2 steps twice
9-16::
    All turn partner RH & turn partner LH
17-24::
    All turn partner 2H & dance DoSiDo
25-32::
    1s slip step down the centre & back
33-40::
    1s followed by 2s+3s+4s cast to bottom & 1s form arch as 2s+3s+4s
    dance under arch & up to top', 0);
INSERT INTO 'dancecrib' VALUES (13928, '2021-04-05 00:22:14.996445+00', '2023-02-04 01:23:02.984744+00', 20197, 3, NULL, 'ace', '1-4::
    1s dance in & cast to face 1st corners
5-16::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s finish facing 3rd
    corner (pstn).  (3) 1 (2)
17-24::
    3s+1s+2s dance reels of 3 on sides, 1s+3rd corner (pstn) pass RSh to
    start.  1s end in 2nd place own side facing out
25-32::
    3s+2s dance RH across _while_ 1s chase clockwise round to 2nd place
    opp sides; all pass partner RSh to own side & set.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7810, '2013-08-21 08:31:48.981616+00', '2023-02-04 01:23:03.008269+00', 10602, 3, NULL, 'ace', '1-8::
    1M followed by partner casts 1 place, crosses below 2s, casts up &
    crosses back to place
9-16::
    1s+2s circle 4H round & back ending in centre 1s facing down & 2s up
17-24::
    1s dance down the set under an arch made by 2s (who dance up) & 1s
    dance back up to 2nd place
25-32::
    2s+1s Promenade', 0);
INSERT INTO 'dancecrib' VALUES (7811, '2013-08-21 08:31:48.989768+00', '2023-02-04 01:23:03.040622+00', 9078, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & 1L+3M turn RH end facing opp sides as 2L+3L cast up &
    1M+2M cast down, 1L dances LH across with 1M+2M & 3M with 2L+3L
9-16::
    3M followed by 2L+3L dance diagonally down to 3M place & up to 1M
    place _while_ 1L followed by 2M+3M dances diagonally up (passing 3M
    RSh)  to 1L place & down to 3L place, all set & 1L+3M turn LH to
    face opp sides _while_ 2L+3L cast up & 1M+2M cast down
17-24::
    1L dances RH across with 2L+3L _while_ 3M dances RH across with
    1M+2M, 1L followed by 2L+3L dances diagonally down to 3L place & up
    to own places _while_ 3M followed by 2M+1M dances diagonally up
    (passing 1L LSh)  to 1M place & down to own places
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7812, '2013-08-21 08:31:48.997858+00', '2023-02-04 01:23:03.065559+00', 14699, 3, NULL, 'ace', '1-8::
    1s set & turn 2H into centre, set & turn 2H back to place _while_
    2s+3s dance Tourbillon:
::
    _1-4_   2s & 3s 1/2 turn ptnrs 2H, 2M & 3L lead ptnrs by nearer hand
    1 place cl''wise to end 2s on Ladies side & 3s Men''s side, 2s set to
    3s
::
    _5-8_   2s & 3s 1/2 turn ptnrs 2H & lead ptnrs on 1 place clockwise
    & 3s+2s cross RH to own sides
9-16::
    All set & petronella turn to face partner (up/down), set &
    petronella turn to opposite sides
17-24::
    All Set+Link for 3 twice
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7813, '2013-08-21 08:31:49.007655+00', '2023-02-04 01:23:03.111866+00', 6894, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, cross LH, cast down 1 place & lead up to
    face 1st corners
9-16::
    1s turn 1st corners RH, turn partner LH _while_ corners dance on 1
    place clockwise, 1s turn 1st corner person RH & curve into 2nd place
    opposite sides _while_ corners dance on 1 place clockwise
17-24::
    3s+1s+2s set & petronella turn into centre to face partner, set &
    turn RH into Allemande hold
25-32::
    3s+1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7814, '2013-08-21 08:31:49.017496+00', '2023-02-04 01:23:03.153233+00', 10917, 3, NULL, 'ace', '1-4::
    All set to partners, 3/4 turn RH
5-16::
    All dance double reels of 4 (giving LH in centre) & end in original
    places
17-24::
    All set (facing in), 1s & 3s slip step 1 place to right _while_ 2s &
    4s slip step left (1s & 4s pass outside) & repeat but continue in
    same direction
25-32::
    Repeat bars 17-24 back to places
33-40::
    All set to corners & turn RH, Men dance on to next Lady (opposite
    Lady), turn & Men dance to next Lady (Ladies remain in orig place)
41-48::
    Men turn Ladies & dance to next Lady (partner), all set & 1/2 turn
    partner RH into new places (1 place to right of original)', 0);
INSERT INTO 'dancecrib' VALUES (7815, '2013-08-21 08:31:49.025472+00', '2023-02-04 01:23:03.179752+00', 12696, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, dance down between 3s & cast up 1 place to end
    in middle LSh to LSh
9-16::
    1s dance RH across (Lady with 2s & Man with 3s), pass RSh to dance
    LH across with other couple & end passing LSh to face 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting & end BtoB (Man facing up)
25-32::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corners &
    cross RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7816, '2013-08-21 08:31:49.031659+00', '2023-02-04 01:23:03.209249+00', 13930, 3, NULL, 'ace', '1-8::
    1s set & turn 2H, 1s cast 1 place & 1s+3s turn on sides (Men RH,
    Ladies LH)
9-16::
    1s dance reels of 3 on sides crossing up to start.  2(1)3
17-24::
    All cross RH & chase clockwise 1/4 way to end in lines of 3 across,
    all change RH up/down & chase clockwise 1/4 way to end (3)1(2)
25-32::
    1s dance Diag R&L.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14302, '2021-09-08 00:22:15.797144+00', '2023-02-04 01:23:03.231039+00', 20210, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L; 1s+3s dance 1/2 R&L.  (2) (3) 1
9-16::
    1s set, lead up to top, cross & cast to 2nd place opp side (3s step
    down. (2) (1) (3)
17-24::
    Mirror reels of 3 on sides giving hands (1s in/down to start)
25-28::
    1L+3s & 1M+2s dance 1/2 reels of 3 across (LSh to 3rd corner pstn to
    start). 2 1 3
29-32::
    1s turn RH twice round (or birl)', 0);
INSERT INTO 'dancecrib' VALUES (7817, '2013-08-21 08:31:49.094988+00', '2023-02-04 01:23:03.357401+00', 7532, 3, NULL, 'ace', '1-8::
    1s dance down below 2s & cast back to place, 1s+2s turn RH into…
9-16::
    1s+2s dance Allemande ending with 1s turning RH to…
17-24::
    1s Bal-in-Line with 1st corners & 3/4 turn RH, Bal-in-Line with 2nd
    corners & turn RH to 2nd place own sides
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7818, '2013-08-21 08:31:49.103524+00', '2023-02-04 01:23:03.383731+00', 6897, 3, NULL, 'ace', '1-8::
    1s cast 1 place & lead down between 3s, cast up to 2nd place & turn
    LH to end BtoB facing own sides
9-16::
    1s dance RH across (1M with 2M+3M & 1L with 2L+3L), 1s passing RSh
    dance RH across with other side (1s end facing 1st corners)
17-24::
    1s dance 1/2 diagonal reel of 4 with 1st corners & pass LSh, 1/2
    reel of 4 with 2nd corners & end facing 3rd corner (pstn)
25-32::
    1s+3rd corners 1/2 turn RH & corners turn LH 1.1/2 times in centre
    to face opp corner, 1s+corners 1/2 turn RH & 1s turn LH to face 4th
    corners
33-40::
    1s+4th corners 1/2 turn RH & corners turn LH 1.1/2 times in centre
    to face opp corner, 1s+corners 1/2 turn RH & 1s turn LH to 2nd
    place.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7820, '2013-08-21 08:31:49.120029+00', '2023-02-04 01:23:03.603133+00', 6902, 3, NULL, 'ace', '1-8::
    1s set, petronella turn into centre, set Man turning about & both
    dance down centre so that 1M faces 4M & 1L faces 3M
9-16::
    1s dance 2 diagonal parallel RSh reels of 3 (1L+3M+2L & 1M+4M+3L)
17-24::
    1s repeat with other diagonals (1L+2M+3L & 1M+3M+4L) 1s end facing
    out on Men''s side
25-32::
    1M dances out between 3M & 4M _while_ 1L dances out between 2M & 3M
    Cast down 1 place to meet in centre & turn RH to 4th places', 0);
INSERT INTO 'dancecrib' VALUES (9050, '2015-11-30 09:00:26.278271+00', '2023-02-04 01:23:03.624277+00', 16113, 3, NULL, 'ace', '1-4::
    1s cross down, cast up round 2s & dance into middle BtoB between 2s,
    1L facing 2M & 1M facing 2L _while_ 3s+4s dance similarly
5-8::
    All set, turn person facing 2H to sidelines (1) 2 (3) 4 with Ladies
    facing in diagonally, Men face out
9-12::
    1L+2L also 3L+4L dance DoSiDo _while_ partners dance clockwise 1/2
    way round them
13-16::
    1M+2M also 3M+4M dance Do-si-Do _while_ partners dance clockwise 1/2
    way round them   (2) 1 (4) 3
17-20::
    1s (2nd place) 1/2 turn RH, lead down to 4th place _while_ 3s (4th
    place) cross RH & cast up to 2nd place, all on opp sides  (2) (3)
    (4) (1)
21-24::
    All cross RH to own sides & set
25-32::
    2s+3s also 4s+1s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (9939, '2017-06-05 11:31:55.134943+00', '2023-02-04 01:23:03.642777+00', 16498, 3, NULL, 'ace', '1-4::
    2s+3s+4s dance 1/2 reels of 3 on sides (2s cross down to start).
    End 2s in 4th place facing in/down
5-8::
    3s+2s+5s  dance 1/2 reels of 3 on sides (3s out/down, 2s in/down, 5s
    out/up).  3s end curving into 5th place, 5s in 3rd place facing out
9-12::
    4s+5s+2s dance 1/2 reels of 3 on sides (4s in/down, 5s out/down, 2s
    cross up to own sides).  2s end in 2nd place facing in/up
13-16::
    1s+2s+5s dance 1/2 reels of 3 on sides (1s out/down, 2s in/up, 5s
    out/up).  5s & 1s end curving into place
17-24::
    2s+1s also 4s+3s Set & Rotate
25-32::
    All circle 10H round and back.  End 5 1 2 3 4', 0);
INSERT INTO 'dancecrib' VALUES (11480, '2019-01-01 01:58:06.258372+00', '2023-02-04 01:23:03.661016+00', 18976, 3, NULL, 'ace', '1-8::
    1s cast to bottom as 4s dance up to top, 4s+2s also 3s+1s dance RH
    across
9-16::
    4s cast to bottom as 1s dance up to top, 1s+2s also 3s+4s dance LH
    across
17-24::
    1s+2s also 3s+4s dance 1/2 R&L, 1s+4s dance 1/2 R&L
25-32::
    1s+3s dance 1/2 R&L, top & bottom couples (2s & 1s) cross RH as
    middle couples change places RH on sides & all set.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7821, '2013-08-21 08:31:49.154471+00', '2023-02-04 01:23:03.687759+00', 9579, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-16::
    1s dance Fig of 8 round 2s
17-24::
    1s+2s circle 4H round to left, petronella turn into centre & set to
    partners (up & down dance)
25-32::
    1s+2s dance 1/2 reel of 4, petronella turn to own side & set to
    partners', 0);
INSERT INTO 'dancecrib' VALUES (13368, '2020-11-02 01:22:28.531571+00', '2023-02-04 01:23:16.272543+00', 18091, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s dance down, cast up round 3s to face
    1st corners
9-16::
    1s set to & turn 1st corner RH; 1s turn 1.1/2 LH to face 2nd corners
17-24::
    1s set to & turn 2nd corner RH; 1s turn 1.1/2 LH to 2nd place own
    side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7822, '2013-08-21 08:31:49.162629+00', '2023-02-04 01:23:03.71631+00', 6904, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link, 1M followed by partner cast up round 2M & dance down
    middle to 1M between 3s & 1L between 2s
9-16::
    2s+1s+3s dance down the middle & back, 2s+1L pull back RSh to face
    down
17-24::
    2s+1s+3s set & change places RH with opposite person; all set &
    3s+2s change places RH with opposite person _while_ 1s 3/4 turn LH
    to end 1M facing up, 1L facing down
25-32::
    1M +2L+3L also 1L+2M+3M dance RH across on sides; 1M with 2s (at
    top) also 1L with 3s (at Bottom) dance LH across 1s ending 2nd place
    own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8708, '2015-03-03 08:48:10.670695+00', '2023-02-04 01:23:03.742375+00', 16127, 3, NULL, 'ace', '1-8::
    1s+3s petronella turn into centre (2s+4s step up).  All set, 1s+2s
    also 3s+4s dance RH across, 1s+3s remain in centre in line of 4 as
    2s/4s dance out to 1st/3rd places
9-16::
    1s+3s dance 1/2 reel of 4, finish facing partners.  1s+3s change
    places RH with partner (1M+3L face clk''wise).  1L+3M turn LH 3/4 to
    face out (opp sides) _while_ partners dance clk''wise round to meet.
    1s+3s take prom. hold, 1L on 1M R facing up, 3L on 3M L facing down
17-24::
    Reels of 3 on sides (1s+2M, 3s+4L pass RSh)  1s finish between 4s
    facing up, 3s between 2s facing down
25-32::
    Lines of 4 advance (2), retire (2).  1s+3s turn back-to-back with
    partners and all set to opp. person. All turn 3/4 (Ladies RH, Men
    LH) to sides 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8227, '2014-03-31 14:46:24.900471+00', '2023-02-04 01:23:03.770022+00', 15123, 3, NULL, 'ace', '{{explanation}}
3s+4s start on opp. sides

1-4::
    1s+4s cross RH _while_ 2s+3s change place RH on side (dancers moving
    clockwise end on nearest corner, dancers moving anticlockwise finish
    in centre facing nearest corner, all Ladies on 1st corner diagonal,
    all Men on 2nd corner diagonal), & all set
5-8::
    Ladies dance 1/2 RSh diagonal reel of 4 as Men set to facing Man and
    turn RH
9-12::
    Repeat bars 5-8 with Men dancing 1/2 diagonal reel and Ladies
    setting and turning RH.  Finish 2M+4L, 3M+1L in middle in promenade
    hold, Men LSh to LSh
13-16::
    2M+4L dance out of Men''s side, 3M+1L out of Ladies'' side casting to
    left to enter top/bottom of set
17-18::
    2M+4L+3M+1L dance 1/2 RH across, stay in centre
19-20::
    2M+4L & 3M+1L turn RH to sides (all on sides next to partner, Lady
    on Man''s left)
21-24::
    2s+4s & 1s+3s set, chase 1/4 clockwise (men cast into chase)
25-28::
    4s+1s set, turn partner 1/2 LH, Ladies face out
29-32::
    4s dance LSh round 2s (4L round 2L, 4M round 2M) as 1s dance
    similarly round 3s    End  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (7824, '2013-08-21 08:31:49.178732+00', '2023-02-04 01:23:03.825655+00', 6912, 3, NULL, 'ace', '1-8::
    1s+2s Set & Rotate :
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
9-16::
    2s+1s+3s set, 1/2 turn 2H in middle, set & turn right about & dance
    out to partners place
17-24::
    2s+1s+3s circle 6H round & back
25-32::
    2s+1s+3s set, petronella turn into middle, set & petronella turn to
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (7825, '2013-08-21 08:31:49.18667+00', '2023-02-04 01:23:03.844617+00', 6913, 3, NULL, 'ace', '1-8::
    1s+2s dance Diamond Poussette
9-16::
    1L+2M set advancing & turn RH back to place, 1M+2L set advancing,
    turn RH back to place
17-24::
    1s dance Fig of 8 round 2s
25-32::
    1s+2s dance Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7842, '2013-08-21 08:31:49.619517+00', '2023-02-04 01:23:05.37596+00', 6952, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round & back
9-16::
    1s lead down for 3 steps, back to top & cast to 2nd places
17-24::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (7867, '2013-08-21 08:31:50.102705+00', '2023-02-04 01:23:08.151007+00', 10404, 3, NULL, 'ace', '1-10::
    1s 1/2 turn & twirl to opposite side & dance down outside, cross RH
    below 3s & dance up own side to original places
11-20::
    1s+2s dance 1.1/4 double Fig of 8 (1s cross down to start) 2s ending
    at top & 1s in 2nd place opposite sides
21-30::
    2s+1s+3s dance reels of 3 (8 bar) on sides (1s out & down to start)
    & 1s+3s continue reel to change places
31-40::
    3s+1s dance 1.1/4 double Fig of 8 (1s in & up to start) to end 2 1 3
    on own sides', 0);
INSERT INTO 'dancecrib' VALUES (7868, '2013-08-21 08:31:50.112464+00', '2023-02-04 01:23:08.18574+00', 6149, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s set & dance 1/2 RH across, all set & cross LH
9-16::
    1s+4s (middle couples) circle 4H round & back _while_ End couples
    chase anticlockwise once round
17-24::
    End couples (2s & 3s) set, cross RH, set & cross back RH _while_ 1s
    & 4s dance Figs of 8 round End couples
25-32::
    1s+4s dance Poussette', 0);
INSERT INTO 'dancecrib' VALUES (7869, '2013-08-21 08:31:50.120424+00', '2023-02-04 01:23:08.207739+00', 9901, 3, NULL, 'ace', '1-8::
    1s dance RSh reels of 3 on sides & end with 1s passing 2s RSh to
    change places
9-16::
    1s+3s dance 1/2 LH across, 1M+3M also 1L+3L turn LH, 3L+1M set
    advancing, 1/2 turn 2H & turn to right to end BtoB in middle with 1M
    facing up _while_ partners dance anticlockwise to end facing
    partners
17-24::
    1s+3s set to partners, turn 1.1/4 times 2H to own sides opening up
    for 4H round', 0);
INSERT INTO 'dancecrib' VALUES (7952, '2013-08-21 08:31:51.796512+00', '2023-02-04 01:23:13.486196+00', 7161, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s Set+Link, 2s+1s & 4s+3s circle 4H left
9-16::
    1s & 3s turn 1st corners RH, 1M dances LH across with 2s as 3L
    dances LH across with 5s ending with 1M & 3L in centre facing opp
    side _while_ 1L & 3M dance LH across with 4s for 2 steps, 1L & 3M
    continue to turn as 4s dance out of wheel turning right & dance to
    opposite side
17-24::
    End trios dance 6 bar snake : 1M leads 2M+2L out & down to bottom 1M
    ends in 4M place _while_ 3L leads 5L+5M out & up to top 3L ends in
    2L place _while_ 1L+3M+4s dance 1/2 reel of across set in 3rd place
    & 1L dances to 4L place, 4L to 3L place, 3M to 2M place & 4M to 3M
    place, all join hands in circle & set.  5 3 4 1 2
25-32::
    All circle 10H round & back', 4);
INSERT INTO 'dancecrib' VALUES (7955, '2013-08-21 08:31:51.820045+00', '2023-02-04 01:23:13.581877+00', 12909, 3, NULL, 'ace', '1-8::
    1s+2s set, cross RH, set & cross back RH
9-16::
    1s dance down the middle & back
17-24::
    1s & 2s 3/4 turn RH, dance 1/2 reel of 4 up/down middle & 3/4 turn
    RH
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7964, '2013-08-21 08:31:51.904354+00', '2023-02-04 01:23:14.026599+00', 7182, 3, NULL, 'ace', '1-8::
    1s lead down for 3 steps, lead back to top of set & cast into 2nd
    place on own sides (2s step up)
9-16::
    1s dance reels of 3 across, (1M with 2s & 1L with 3s), RSh to 2nd
    corner
17-24::
    1s turn 1st corner, partner, 2nd corner, partner
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7975, '2013-08-21 08:31:51.996392+00', '2023-02-04 01:23:14.381978+00', 11537, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, cross RH & cast to 3rd place opposite sides
9-16::
    3s+1s dance 1/2 R&L, 2s+1s dance 1/2 R&L
17-24::
    1s+2s+3s dance DoSiDo, set & 1/2 turn RH into prom hold facing up
25-32::
    1s+2s+3s Promenade & 1s cast to 2nd place', 0);
INSERT INTO 'dancecrib' VALUES (8003, '2013-08-21 08:31:54.263446+00', '2023-02-04 01:23:16.111601+00', 12063, 3, NULL, 'ace', '1-8::
    1s & 3s 1/2 turn & twirl to opposite sides, 1s & 3s repeat back to
    places
9-16::
    1s cast 1 place, dance round each other RSh; 1M+2s (at top) &1L+3s
    (at bottom) dance LH across
17-24::
    1s lead down middle & back to 2nd place own side
25-32::
    2s+1s dance Diamond Poussette. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8010, '2013-08-21 08:31:54.412043+00', '2023-02-04 01:23:16.503809+00', 7262, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back to places
9-16::
    1s dance down middle & back
17-24::
    1s cast behind 2s, in front of 3s, behind 4s & dance DoSiDo
25-32::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (12110, '2019-08-30 09:55:08.549419+00', '2023-02-04 01:23:03.857818+00', 19235, 3, NULL, 'ace', '{{explanation}}
Start:  3 couples in Triangular set with 4th Lady in middle  
2 chords - 1st chord all bow/curtsey to 4L, 2nd chord bow/curtsey to partner

1-4::
    1s+2s+3s face partner, join 2H & away from centre & back into place
    (HS - Ladies left foot, Men right foot start) _while_ 4L faces 1s &
    sets (HS setting)
5-8::
    1s turn 2H twice _while_ 4L dances round them by RSh into middle to
    face 3s
9-16::
    4L+2s+3s (both in prom hold) dance reel of 3 (4L LSh to 3s).  4L end
    in middle facing 1s
17-24::
    4L sets to 1s, then 3s, then 2s & faces 1s, 1s+2s+3s turn partner
    3/4 2H to end NHJ facing anticlockwise (Ladies on left of partners)
    _while_ 4L dances LSh round 1s to join LH with 1M''s RH
25-28::
    All dance 2 places anticlockwise round
29-32::
    2s+3s turn partners 1.1/4 2H (in 3rd/1st place) _while_ 1s+4L circle
    3H 1/2 round to left (2 bars), 1L pulls back RSh , dances into
    middle to face up as 1M+4L 1/2 turn 2H to become new 2nd couple.
    End 3s [4L+1M] 2s with 1L in centre

{{explanation}}
Repeat 3 times - each Lady has turn in centre.  End - all bow/curtsey to 4L in centre', 0);
INSERT INTO 'dancecrib' VALUES (14591, '2022-02-05 02:22:06.057439+00', '2023-02-04 01:23:03.879712+00', 18513, 3, NULL, 'ace', '1-8::
    1s cross RH & cast (2s step up); 1s cross LH & set
9-16::
    1s dance diag R&L (Man down, Lady up) to end (3) 1 (2)
17-24::
    All Adv+Ret twice
25-28::
    All cross RH, 1s cast right into lines of 3 across (1L between 3s at
    top,1M between 2s at bottom) _while_ corners set facing up/down
29-32::
    All cross LH, 1s cast left to 2nd place on side _while_ corners set
    to partners.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14592, '2022-02-05 02:22:06.108525+00', '2023-02-04 01:23:03.945213+00', 18515, 3, NULL, 'ace', '1-4::
    2s followed by 1s lead down (2 bars), 2s cast back up while1s
    continue to lead down (2 bars)
5-8::
    2s followed by 1s lead back up finishing on sides.  2 1 3
9-12::
    2s+1s+3s 1/2 turn partner 2H (PdeB) & pull back RSh & dance out to
    partner''s place. (2) (1) (3)
13-24::
    All dance R&L for 3 couples
25-32::
    All set advancing, pull back RSh & dance out to opp sides; all 1/2
    turn partners 2H (PdeB) & pull back RSh & dance out to own side.  2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (14593, '2022-02-05 02:22:06.131457+00', '2023-02-04 01:23:03.970296+00', 18518, 3, NULL, 'ace', '1-8::
    1L followed by other Ladies dances across, down behind Men, across &
    up own side to place
9-16::
    Men repeat 1- 8
17-24::
    All dance DoSiDo with partner & turn partner 2H
25-32::
    1s »weave« down own side to bottom, in front of 2s, behind 3s, in
    front of 4s & behind 5s, all step up bars 31-32', 0);
INSERT INTO 'dancecrib' VALUES (14594, '2022-02-05 02:22:06.157168+00', '2023-02-04 01:23:03.993242+00', 18279, 3, NULL, 'ace', '1-8::
    1s dance down between 2s, cast back to place; 1s dance down between
    3s, cast up to 2nd place (2s step up 7-8)
9-16::
    2s+1s+3s dance mirror reels of 3 on sides giving hands (1s in/up to
    start, corners loop into place). 1s end in centre joining RH with
    partner, LH with 3rd corner
17-24::
    1s dance the Spoke: 1s Bal-in-Line with 3rd corners, then 2nd, 1st &
    4th corners.  1s end in 2nd place own side
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (14595, '2022-02-05 02:22:06.184981+00', '2023-02-04 01:23:04.006279+00', 18514, 3, NULL, 'ace', '1-12::
    2s & 4s dance 1/2 diag R&L for 3 couples 3 times (polite turns) to
    end 5 (2) 3 (4) 1
13-16::
    All Adv+Ret (1 step each) twice
17-24::
    3s+[2s+5s]+[4s+1s] following dance Tandem reels of 3 on sides (3s
    RSh to [2s+5s] to start). End (2) 5 3 1 (4)
25-28::
    All set, 2s (at top) & 4s (at bottom) cross RH _while_ 3s (middle)
    turn RH once round
29-32::
    3s cast 1 place (1s step up) & all set.  2 5 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (14596, '2022-02-05 02:22:06.212206+00', '2023-02-04 01:23:04.016559+00', 18517, 3, NULL, 'ace', '1-8::
    Ladies dance RH across to place facing out; All dance 1/4
    Schiehallion reel (1 place round).  Men face in, Ladies out
9-16::
    Men dance RSh round partners* ;  All dance 1/4 Schiehallion reel.
    Men face in, Ladies out
17-24::
    Ladies dance RSh round partners* ; All dance 1/4 Schiehallion reel.
    Men face in, Ladies out
25-32::
    Ladies chase clockwise round outside set _while_ Men chase
    anticlockwise round inside set. 4 1 2 3
33-40::
    Men dance LH across to place facing out; All dance 1/4 Reverse
    Schiehallion reel (Ladies dance diag to left, Men start out & follow
    partner)
41-48::
    Ladies dance LSh round partners* ; All dance 1/4 Reverse
    Schiehallion reel
49-56::
    Men dance LSh round partners* ; All dance 1/4 Reverse Schiehallion
    reel
57-64::
    Ladies chase clockwise round inside _while_ Men chase anticlockwise
    round outside set. 1 2 3 4
65-72::
    All dance Double Men''s Chain (Men LH across in centre, Ladies polite
    turn ** )
73-80::
    All dance Double Ladies'' Chain (Ladies RH across in centre)
81-96::
    All dance complete Reverse Schiehallion reel (moving 4 places).  End
    1 2 3 4

{{explanation}}
Note *	Bars 9-12, 17-20, 41-44 & 49-52 - standing partner may rotate with 4 PdeB to follow dancing partner  
Note **	Bars 71-72 - easier for couples to turn 2H & face in to avoid Ladies giving RH twice from 1 chain to other', 0);
INSERT INTO 'dancecrib' VALUES (7897, '2013-08-21 08:31:50.70783+00', '2023-02-04 01:23:09.999626+00', 7043, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    All set, 1s & 4s cross RH _while_ 2s+3s dance RH across 1/2 way, all
    set & cross RH
9-16::
    All circle left for 2 bars, Men turn Lady behind 2H once round & all
    circle left for 4 bars.  1 (3) 2 (4)
17-24::
    1s & 3s turn 2H 1/2 way to face up, 1s cast 1 place on opposite
    sides _while_ 3s dance up to top, 1s+2s dance RH across 1/2 way & 1s
    cross down to bottom _while_ 2s cross up to top.  2 3(4)(1)
25-32::
    1s & 2s cast into centre, dance RH across 1/2 way, 1M+2L lead out
    Men''s side cross & cast to ends & cross over RH _while_ 1L+2M dance
    similarly on Ladies side _while_ 3s+4s dance towards each other &
    turn 2H on sides.   2 3 (4)(1)', 0);
INSERT INTO 'dancecrib' VALUES (7898, '2013-08-21 08:31:50.723686+00', '2023-02-04 01:23:10.024964+00', 13767, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 R&L, 1s+3s dance 1/2 R&L.
9-16::
    All dance parallel reels of 3 on sides (2s give RSh to 3s to start)
17-24::
    All dance Grand Chain with 2s+3s changing places on side as 1s cross
    to start
25-32::
    1s lead up to top cross & cast to 2nd place opposite sides (3s+4s
    step down 27-28); 2s+1s+3s set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (10346, '2017-12-22 15:45:15.840443+00', '2023-02-04 01:23:10.049068+00', 7045, 3, NULL, 'ace', '1-8::
    1s 1/2 turn RH moving down 1 place in centre (2s step up 1-2), 1s
    set, cross RH & cast, 1M up, 1L down into centre (top/bottom)
9-12::
    1s cross RH up/down, cast to Right, 1M round 3M, 1L round 2L to 2nd
    place own side _while_ 2s & 3s set, cross RH to face out  (2) 1 (3)
13-16::
    _1/2_ LSh reels of 3 on sides (1s pass 3rd corner LSh to start - 1M
    up, 1L down).  End 2s facing up, 3s down  (3) 1 (2)
17-20::
    1s cross RH, cast to Right round 1st corner pstn into centre facing
    up/down _while_ 3s set to 2s on side & change places RH, 2s face up,
    3s down
21-24::
    _1/2_ LSh reels of 3 across, 1L+2M & 1M+3L pass LSh to start.  1s
    end LSh to LSh in centre, 1M facing up, 1L down, 2L & 3M face out
25-32::
    RH across, 1M+2L+3L (Ladies'' side) 1L+2M+3M .  LH across, 1M+2s (at
    top), 1L+3s (at Bottom)   2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9052, '2015-11-30 09:00:27.914795+00', '2023-02-04 01:23:10.084901+00', 16699, 3, NULL, 'ace', '1-8::
    1s 1/2 turn & twirl (pull back RSh) & dance out to opposite sides,
    2s repeat
9-16::
    3s repeat (all now on opp sides).  1s+2s+3s 1/2 turn & twirl to own
    sides
17-24::
    1s slip step down the middle & back to end at top facing down
25-32::
    1M+2M RH 1.1/2 times _while_ 1L+2L turn LH 1.1/2,  1M+3M LH 1.1/2
    times _while_ 1L+3L turn RH 1.1/2  times to end 2 3 1
::
    (A variation on "The Belfast Hornpipe" differing only in bars 25-32)', 0);
INSERT INTO 'dancecrib' VALUES (7899, '2013-08-21 08:31:50.739009+00', '2023-02-04 01:23:10.11104+00', 7049, 3, NULL, 'ace', '1-8::
    1s+2s dance 1/2 double Fig of 8 (1s cross down, 2s cast up),
    1s+2s+3s dance 1/2 reels of 3 on sides (1s in/down, 2s out/up, 3s
    in/up to start)
9-16::
    2s+1s dance 1/2 double Fig of 8 (1s cross up, 2s cast down),
    3s+2s+1s dance 1/2 reels of 3 on sides (1s in/up, 2s out/down, 3s
    in/down ).  1 2 3
17-24::
    2s continue reel dancing out/up to 1st place _while_ 1s dance down
    to 2nd place BtoB facing own side (as double triangles) & all set;
    1s turn 3rd corner RH to end 1M between 2s facing down & 1L between
    3s facing up & all set
25-32::
    1s pass RSh to face other couple (as double triangles) & all set,
    turn 4th corner RH to end 2nd place own side & all set. End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12114, '2019-09-01 11:18:27.49959+00', '2023-02-04 01:23:10.144836+00', 19579, 3, NULL, 'ace', '1-8::
    1s cross down to dance reflection reels of 3 on opposite sides (All
    take hands where possible)  (1)2 3
9-16::
    1s cross RH & cast 1 place, 1s cross RH & cast round their 1st
    corners to face 4th corner
17-24::
    1s dance LSh reels of 3 across (1L with 2s, 1M with 3s) & 1s end
    BtoB in middle facing up/down
25-32::
    1L+2s also 1M+3s circle round & back.', 0);
INSERT INTO 'dancecrib' VALUES (7900, '2013-08-21 08:31:50.858025+00', '2023-02-04 01:23:10.164503+00', 7534, 3, NULL, 'ace', '1-8::
    1M also 2L dance across passing partner RSh & cast to change places,
    1s+2s petronella turn 1 place anticlockwise & set (1s+2s on opp
    sides)
9-16::
    1L+2M repeat back to original places
17-24::
    1s+2s circle 4H round & back
25-32::
    1s+2s dance the Tournee :
::
    1s+2s dance into prom hold (Men with prtnr on right, 1s face M''s
    side & 2s L''s side), couples 1/2 wheel anticl''wise & Men turn Ladies
    into middle, both couples turn 1.1/2 times (2s RH, 1s LH) & dance
    out to places', 0);
INSERT INTO 'dancecrib' VALUES (11483, '2019-01-01 01:58:09.352457+00', '2023-02-04 01:23:10.179215+00', 18964, 3, NULL, 'ace', '1-8::
    2s+3s dance RH across once round & face corners, all set & 2s+3s 1/2
    turn corners to change places
9-24::
    1s+4s dance RSh round all 4 (new) corners - starting with the person
    just turned then dance RSh round each corner anticlockwise to end in
    a line across - 1M on Ladies side & 4L on Men''s side with 1L & 4M
    (BtoB) facing own partner
25-32::
    1s+4s dance RSh reel of 4 across (1M & 4L end facing out)
33-40::
    1M & 4L followed by partners cast to left & cross to original places
    as 2s & 3s step down/up; all Adv+Ret
41-48::
    1s+2s dance 1/2 RH across, 1s+3s dance 1/2 RH across, 1s+4s dance
    1/2 RH across & all cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (7901, '2013-08-21 08:31:50.974136+00', '2023-02-04 01:23:10.19647+00', 11112, 3, NULL, 'ace', '1-8::
    1s+2s turn RH & 1s cast to 2nd place as 2s lead up, 1s+3s turn RH &
    1s cast to 3rd place as 3s lead up
9-16::
    2s+3s+1s dance reflection reels of 3 on sides (2s down between 3s to
    start) & 1s end facing 1st corners as 3s cast to 3rd place
17-24::
    1s dance ''Hello-Goodbye'' setting & end BtoB (Man facing up, Lady
    down)
25-32::
    1s dance reels of 3 across (RSh to 2nd corner to start) & 2s+1s+3s
    set', 0);
INSERT INTO 'dancecrib' VALUES (14599, '2022-02-05 02:22:11.595243+00', '2023-02-04 01:23:10.207015+00', 20608, 3, NULL, 'ace', '{{explanation}}
Round the Room - 2 face 2, 1s face clockwise, 2s face anticlockwise

1-8::
    1s NHJ dance between 2s & cast back to place; all circle 4H round to
    left
9-16::
    2s NHJ dance between 1s & cast back to place; all circle 4H round to
    right
17-24::
    Ladies pull back RSh to turn about & cross RH to change places; Men
    repeat, pulling back LSh & crossing LH
25-32::
    All Adv+Ret NHJ with partner; retain hands & pass opposite couple
    LSh & turn partner 2H opening out to face new couple', 0);
INSERT INTO 'dancecrib' VALUES (7902, '2013-08-21 08:31:51.136139+00', '2023-02-04 01:23:10.348396+00', 7055, 3, NULL, 'ace', '1-8::
    1s cross down & dance reflection reels of 3 on opposite sides
9-16::
    1s cross down to dance reflection reels of 3 on own sides
17-24::
    1s lead down the middle & back to top (1s end facing 2s diagonally)
25-32::
    1s set to 2s & dance down to 4th place (2s+3s+4s step up 27-28),
    4s+1s circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (7903, '2013-08-21 08:31:51.144481+00', '2023-02-04 01:23:10.37088+00', 7061, 3, NULL, 'ace', '1-8::
    1M+2L turn RH, 1L+2M turn RH 1.1/2 times end facing partner ready
    for diagonal reel of 4
9-16::
    1s+2s dance diagonal reel of 4
17-24::
    1s+2s Set & Rotate :
::
    Set (facing diagonally opp dancer), rotate singly & dance on 1 place
    clockwise, change places RH on sides & dance on 1 place to own sides
    (1s in 2nd pl)
25-32::
    2s+1s dance R&L', 0);
INSERT INTO 'dancecrib' VALUES (15435, '2023-02-04 01:23:10.400528+00', '2023-02-04 01:23:10.401762+00', 20304, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up); 1s dance 1/2 Fig 8 (Man up round 2s,
    1L down round 3s), 1s end facing 1st corners
9-16::
    1s dance 1/2 diag reel of 4 with 1st corners, turn LH to face 4th
    corners; 1s dance 1/2 diag reel of 4 with 4th corners, turn LH to
    face 3rd corners (pstn)
17-20::
    1M+3s (at top) & 1L+2s (at bottom) dance RH across, 1s face 3rd
    corner (pstn)
21-28::
    1s dance 1/2 diag reel of 4 with 3rd corners (pstn), turn LH to face
    2nd corners (pstn); 1s dance 1/2 diag reel of 4 with 2nd corners,
    turn LH to face 1st corners
29-32::
    1L+2s (at top) & 1M+3s (at bottom) dance RH across.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9053, '2015-11-30 09:00:28.382372+00', '2023-02-04 01:23:11.538063+00', 9808, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance RH across, 2s+3s dance LH across (2M & 3L end
    facing out)
9-16::
    2M & 3L, followed by partners, cast to right into 1st / 4th place
    opp sides (1s+4s step down/up bars 11-12). 2s+1s also 1s+4s dance RH
    across
17-24::
    1s+4s dance LH across (1M & 4L end facing out).  1s+4s repeat bars
    9-12 (2s & 3s step down/up) to end in 1st / 4th place opp sides (1)
    (2) (3) (4)
25-32::
    All set & cross. 1s+4s dance in then cast to 2nd/3rd place (2s+3s
    step up/down bars 31-32)
33-40::
    1s+4s dance Espagnole:
::
    _33-34_     1s+4s dance across to opp sides (Ladies lead across RH
    passing between Men) with Ladies changing places RH
::
    _35-36_     1s+4s dance across to own sides (Men lead across RH
    between Ladies) with Men changing places RH
::
    _37-40_     4s turn RH as 1s turn LH to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7913, '2013-08-21 08:31:51.237954+00', '2023-02-04 01:23:11.555024+00', 9903, 3, NULL, 'ace', '1-8::
    1s+4s set, 1/2 turn 2H in centre & face down/up;0 1s+4s dance
    down/up towards each other & cast out to 2nd/3rd place opp sides
    _while_ 2s+3s set & cast up/down to 1st/4th places
9-16::
    2s+1s dance RH Ladies'' Chain _while_ 4s+3s dance LH Ladies'' Chain
17-24::
    All 4 couples set, 1s+4s dance 1/2 Fig of 8 round end couples (1s
    round 2s, 4s round 3s), 1s+4s+3s set advancing & end ready for
    Allemande
25-32::
    1s+4s+3s dance Allemande.  2 3 4 1

{{explanation}}
Note: This dance, previously titled "Where The River Almond Flows", was renamed by the deviser February 2017', 0);
INSERT INTO 'dancecrib' VALUES (7914, '2013-08-21 08:31:51.24606+00', '2023-02-04 01:23:11.577027+00', 7088, 3, NULL, 'ace', '1-8::
    1M sets advancing to 2L also 3L sets advancing to 2M & they 1/2 turn
    RH.  3L+1L+2M also 2L+1M+3M dance RH across
9-16::
    1L sets advancing to 2M also 3M sets advancing to 2L & they 1/2 turn
    LH.  2L+3s also 2M+1s dance LH across.  2s face out  to end (3) 2
    (1)
17-24::
    2s dance LSh reels of 3 on sides (2M down LSh to 1L, 2L up LSh to
    3M)
25-32::
    3s & 1s set, 3s cross & cast to 3rd place _while_ 1s 1/2 turn RH,
    dance up to top & cast to 2nd place (2s step up)', 0);
INSERT INTO 'dancecrib' VALUES (6983, '2013-08-21 08:31:34.073985+00', '2023-02-04 01:23:11.591861+00', 5497, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, set & cast back to original places
9-16::
    1M (followed by partner) casts 1 place, dances up between 2s & casts
    down behind 2L, crosses over & both end in 2nd place own side
17-24::
    1L (followed by partner) casts up to top, dances down between 2s &
    casts up behind 2M & crosses over & both end in original places
25-32::
    1s reel with 2M on Men''s side (1M & 2M pass LSh & 1L dances to 2nd
    pl on Men''s side to pass ptnr RSh (1L ends in own pl & 1M in 2nd pl)
33-40::
    1s reel with 2L on Ladies side (1L & 2L pass RSh & 1M dances to 2nd
    pl on Ladies side to pass ptnr LSh (1s end in 2nd place own side)', 0);
INSERT INTO 'dancecrib' VALUES (7916, '2013-08-21 08:31:51.271804+00', '2023-02-04 01:23:11.621607+00', 7090, 3, NULL, 'ace', '1-8::
    1s set advancing & turn individually, slip step down below 3s & cast
    up to 2nd place
9-16::
    1M dances RH across with 3s & 1L with 2s, 1s dance round 2nd corners
    LSh to end in prom hold facing 3L
17-24::
    1s dance 1/2 RSh reel of 3 across with 3s, separate & dance 1/2
    reels of 3 on own sides to end in prom hold with ptnr facing 3L (in
    1M place)
25-32::
    1s dance 1/2 reel of 3 across with 3s (in 1st place), separate &
    dance 1/2 reels of 3 on own sides to end in 2nd place own side', 0);
INSERT INTO 'dancecrib' VALUES (13365, '2020-11-02 01:22:24.533302+00', '2023-02-04 01:23:11.641585+00', 17391, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s+4s set advancing, turn partner 2H; dance out of ends & cast into
    centre (2s/3s step up/down), 1s+4s turn partner 2H to face up/down
    in prom hold
9-16::
    _1/2_ reels of 3 across, 1s pass 2L RSh, 4s pass 3L RSh; 1s+4s pass
    RSh to dance 1/2 reel of 3 across with other couple. At end 1s & 4s
    turn inwards to form lines across 4s between 2s (at top) facing
    down, 1s between 3s facing up (Men on right)
17-24::
    4s+1s dance RH across & LH across back [Optional: 2s+3s dance R&L
    round 4s+1s starting crossing RH on sides]
25-32::
    2L+4L+1M (top 3 Ladies'' side) also 4M+1L+3L (bottom 3 Men''s side)
    dance reels of 3 on sides (2L+4L also 1L+3L pass RSh to start). 2 4
    (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (7917, '2013-08-21 08:31:51.27979+00', '2023-02-04 01:23:11.660104+00', 7092, 3, NULL, 'ace', '1-8::
    All turn RH, 1s cast, dance between 3s & cast down behind 4s to
    bottom (in & out of the windows)
9-16::
    2s cast & ''in & out of the windows'' to bottom, 3s cast & ''in & out
    of the windows'' to bottom.  4 1 2 3
17-24::
    All circle 8H round & back
25-32::
    All cross RH, set, 4s+1s cross & cast to 3rd & 4th places _while_
    2s+3s 1/2 turn RH & lead up to 1st & 2nd places.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (7918, '2013-08-21 08:31:51.287943+00', '2023-02-04 01:23:11.687535+00', 7093, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, 1L dances up between 2s & casts round 2L
    to face 2M _while_ 1M dances between 3s & casts up round 3M to face
    3L
9-16::
    1s turn 1st corners RH, turn partner LH into 1/2 diagonal reel of 4
    with 2nd corners (1s end facing 4th corner - 2nd corners persons)
17-24::
    1s turn 4th crnrs RH, turn partner LH into 1/2 reel of 4 with 1st
    crnr (1s end in lines across - 1L between 3s in 1st place & 1M
    between 2s)
25-32::
    3s+1s+2s set, 1s 3/4 turn RH to opposite sides _while_ 3s+2s change
    places RH on sides, 2s+1s+3s set & change places with partner RH', 0);
INSERT INTO 'dancecrib' VALUES (9251, '2016-06-16 22:42:30.83993+00', '2023-02-04 01:23:11.929224+00', 16281, 3, NULL, 'ace', '1-6::
    1s cross passing RSh, cast (2s step up), pass RSh, turn Right about
    & face own sides
7-8::
    1s cast to Right, to finish 1M between 2s facing down, 1L between 3s
    facing up _while_ 1st corners (2M+3L) cross passing RSh
9-12::
    1s pass RSh, turn Right about to face ends & cast to Right to 2nd
    place own sides _while_ 2nd corners (2L+3M) cross passing RSh
13-16::
    1s pass RSh, turn Right about to face opp sides, cast to Right to
    finish 1L at top, 1M at bottom _while_ 1st corner places (3L+2M)
    cross RSh
17-20::
    1s pass RSh, turn Right about to face ends & cast to Right to 2nd
    place opp sides _while_ 2nd corner places (3M+2L) cross RSh
21-28::
    1s dance Diag R&L
29-32::
    All set, pass partners RSH to own sides 3 1 2

{{explanation}}
Repeat from new positions 5 more times', 0);
INSERT INTO 'dancecrib' VALUES (7919, '2013-08-21 08:31:51.296037+00', '2023-02-04 01:23:11.954105+00', 10170, 3, NULL, 'ace', '1-8::
    1s & 3s petronella turn into centre, set twirling to right,
    petronella turn to opposite side & set twirling
9-16::
    All change places with partners with 1/2 RH turn & twirl, 1M+2L also
    2M+1L prom hold dance clockwise 1/2 way _while_ 3M+4L & 4M+3L dance
    similarly to end (2 (1) 4 (3)
17-24::
    1s & 3s dance 1/2 Figs of 8 round couple above them & all turn
    partners RH
25-32::
    4s followed by 1s cross down between 3s & cast to 2nd/3rd place,
    4s+1s dance 1/2 Fig of 8 round 2nd/3rd couple to end 2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11745, '2019-03-26 02:06:15.308946+00', '2023-02-04 01:23:11.978126+00', 13729, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, dance RH across (Lady with 2s & Man with
    3s) & end facing 1st corners
9-16::
    1s dance reel of 4 with 1st corners & end turning RH to Man facing
    up & Lady down
17-24::
    1s dance RSh round 2nd corners, pass LSh in centre to dance RH
    across (Lady with 3s & Man with 2s) & end facing 2nd corners
25-32::
    1s dance reel of 4 with 2nd corners & end in 2nd place own sides

{{explanation}}
This is the "energetic" version of the strathspey "Windmills" devised by Derek Haynes', 0);
INSERT INTO 'dancecrib' VALUES (7924, '2013-08-21 08:31:51.338273+00', '2023-02-04 01:23:12.086494+00', 7107, 3, NULL, 'ace', '1-8::
    1s+2s dance Espagnole:
::
    _1-2_   1s+2s cross (Ladies lead across RH passing between Men) with
    Ladies changing places RH
::
    _3-4_   1s+2s cross back (Men lead across RH between Ladies) with
    Men changing places RH
::
    _5-8_   2s turn RH as 1s turn LH
9-16::
    1s+3s dance Espagnole
17-24::
    _17-20_   1L+4L also 1M+4M turn (Ladies LH & Men RH), 1L+3L also
    1M+3M 3/4 turn (Ladies RH & Men LH) _while_ 4s cast up, dancing
    behind 3s ready for …
::
    _21-24_   Ladies dance RH across _while_ Men LH across for 2 bars,
    1s+2s change places on sides (Ladies LH & Men RH) _while_ 3s+4s
    continue turning to places
25-32::
    1s followed by 2s+3s+4s dance down, 1s followed by 2s+3s+4s dance up
    under arches made by others all ending in centre
33-40::
    1s cast to 4th place _while_ others turn LH & move up 1 place, all
    turn RH', 0);
INSERT INTO 'dancecrib' VALUES (9252, '2016-06-16 22:42:30.903751+00', '2023-02-04 01:23:12.2137+00', 14666, 3, NULL, 'ace', '1-8::
    1s turn RH & cast to 2nd place, turn 1.1/2 LH to end between 2s
    facing opposite sides
9-16::
    1s+2s dance Reel of 4 across & 1s pass RSh to face 1st corners
17-24::
    1s turn corner, partner, corner, partner to end between 3s facing
    opposite sides
25-32::
    1s+3s dance Reel of 4 across & 1s end in middle between 3s & 4s
33-40::
    1s turn LH & cast up to 2nd place own side & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (9146, '2016-05-22 16:37:02.381575+00', '2023-02-04 01:23:12.28048+00', 16953, 3, NULL, 'ace', '1-8::
    1s followed by 2s+3s+4s cast to 4th place, dance up & cast back into
    places
9-16::
    1s+2s also 3s+4s Set+Link, 2s+1s also 4s+3s circle 4H round to left
17-24::
    2s+1s also 4s+3s dance the Knot with 1s ending between 2s
25-32::
    1s dance the Spurtle: 1s dance 1/2 reel of 4 with 2s & turn partner
    RH to face 3s, 1s dance 1/2 reel of 4 with 3s & turn partner RH to
    face 4s
33-40::
    1s dance 1/2 reel with 4s & turn RH to 4th place opposite sides, all
    set & cross RH 1s ending in 4th place', 0);
INSERT INTO 'dancecrib' VALUES (8923, '2015-09-22 21:07:43.877436+00', '2023-02-04 01:23:12.315047+00', 16770, 3, NULL, 'ace', '1-8::
    2s followed by 1s dance down & cast up behind 3s with 2s ending in
    1st place & 1s end 2nd pl, 1s dance 1/2 fig of 8 (1L round 2s, 1M
    round 3s)
9-16::
    1s dance Reels of 3 on opposite sides (1L RSh to 3M, 1M RSh to 2L)
17-24::
    1s with 1st corners dance RH across, 1s with 2nd corners dance LH
    across
25-32::
    1L dances 1/2 fig of 8 round 3s as 1M dances 1/2 fig of 8 round 2s,
    1s followed by 3s dance up between 2s & cast off (1s to 3rd place &
    3s to 2nd pl)', 0);
INSERT INTO 'dancecrib' VALUES (7926, '2013-08-21 08:31:51.388041+00', '2023-02-04 01:23:12.340411+00', 7109, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & cross RH, set & cross back RH
9-16::
    1s lead down the middle for 4 bars & back to top, remaining in
    centre facing up
17-24::
    1s cast (slow) to 2nd place on own sides (4 bars) & circle 4H round
    to the left with 3s
25-32::
    2s+1s dance R&L.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14383, '2021-10-11 22:42:34.218073+00', '2023-02-04 01:23:12.369871+00', 18047, 3, NULL, 'ace', '1-8::
    1s lead down the middle, on bar 3 1s change sides with Lady dancing
    under Man''s right arm, lead up & on bar 7 1s change sides again, 2s
    step in
9-16::
    1s+2s dance Allemande, 1s finish facing 1st corners
17-20::
    1s dance clockwise round 1st corners _while_ 1st corners Adv+Ret. 1s
    pass RSh to face 2nd corners
21-24::
    1s dance clockwise round 2nd corners _while_ 2nd corners Adv+Ret. 1s
    end 2nd place opposite sides
25-32::
    1s dance LSh reels of 3 across the dance (1s give LSh to 3rd corners
    to begin). On bars 31-32, 1s cross RH _while_ 2s+3s loop into place', 0);
INSERT INTO 'dancecrib' VALUES (7927, '2013-08-21 08:31:51.396197+00', '2023-02-04 01:23:12.392661+00', 7110, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s (facing on sides) set, pass giving RH, 1s+4s set
    (facing on sides) & pass LH _while_ 2s & 3s set to partners & cross
    LH
9-16::
    2s+4s+1s+3s dance RSh reels of 4 on sides
17-24::
    4s+1s dance RH across & dance 1/2 R&L.  (2)(1)(4)(3)
25-32::
    All circle 8H round to left for 4 steps (to own sides), 1s turn RH &
    1/2 turn 2s LH on sides.  3 4 2 1', 0);
INSERT INTO 'dancecrib' VALUES (7928, '2013-08-21 08:31:51.404616+00', '2023-02-04 01:23:12.42219+00', 7111, 3, NULL, 'ace', '1-8::
    1s turn RH & cast to 2nd place, turn 1.1/2 LH to end between 2s
    facing opposite sides
9-16::
    1s+2s dance Reel of 4 across, 1s pass RSh to face 1st corners
17-24::
    1s turn corner, partner, corner, partner, to end between 3s facing
    opposite sides
25-32::
    1s+3s dance Reel of 4 across, 1s end in middle between 3s & 4s
33-40::
    1s turn LH, cast to 4th place on own side & turn RH', 0);
INSERT INTO 'dancecrib' VALUES (7929, '2013-08-21 08:31:51.413057+00', '2023-02-04 01:23:12.45215+00', 7112, 3, NULL, 'ace', '1-8::
    1s+3s set, dance 1/2 R&L & turn partners RH _while_ 2s+4s dance R&L
9-16::
    All dance Double Reel of 4 (Ladies start dancing in) all touching LH
    in centre
17-24::
    All circle 8H round to left for 2 bars, turn partner 2H, circle 8H
    round for 2 Bars & again turn partners 2H ending in original places
25-32::
    All dance Grand Chain 1/2 way, 1s+3s promenade back to places
    passing LSh _while_ 2s & 4s turn RH
33-64::
    Repeat bars 1-32 with 2s & 4s as leading dancers
65-72::
    All in Allemande hold promenade round set & end turning Ladies LH
    into centre for RH across (facing clockwise & Men on outside)
73-80::
    All dance RH across 1/2 way, all change places with partners
    advancing 1 place & change places again advancing 1 more place
81-88::
    Repeat bars 73-80
89-96::
    All set to partners HS & turn partners 2H to end Ladies BtoB facing
    partners', 0);
INSERT INTO 'dancecrib' VALUES (7930, '2013-08-21 08:31:51.421109+00', '2023-02-04 01:23:12.519966+00', 7113, 3, NULL, 'ace', '1-8::
    1s+2s Adv+Ret for 1 step, cross RH to face down/up, 1s+2s Adv+Ret
    for 1 step (down/up) & change places RH on sides
9-16::
    2s+1s Adv+Ret for 1 step, cross RH & turn partner RH
17-24::
    1s dance Fig of 8 round 2s
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7931, '2013-08-21 08:31:51.429331+00', '2023-02-04 01:23:12.544566+00', 7118, 3, NULL, 'ace', '1-8::
    1L followed by 2L dance Fig of 8 round 1M+2M, LSh round 2M to start
    & end each others place
9-16::
    1s+2s dance RH across & LH back
17-24::
    1M followed by 2M dance Fig of 8 round 2L+1L RSh (round 1L in 2nd pl
    to start) & end in each others place
25-32::
    2s+1s circle 4H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7932, '2013-08-21 08:31:51.437561+00', '2023-02-04 01:23:12.573656+00', 13052, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across 1/2 way & 1/2 turn partner RH, 1s dance 1/2
    Fig of 8 round 2s
9-12::
    2s+1s+3s set & 1s cast clockwise _while_ 2s & 3s petronella turn
    into middle
13-16::
    1s cross between 2s/3s _while_ 2s+3s set, 1s dance clockwise to 2nd
    pl _while_ 2s+3s 1/2 turn partner RH to end Men facing down & Ladies
    up
17-24::
    2s+1s+3s dance a ''Weasel Reel'':
::
    2s+3s dance part reel of 4 up/down middle but when reaching either
    end they dance clockwise to top/bottom to re-enter reel _while_ 1s
    start by dancing clockwise to replace dancer leaving the reel. All
    end where they started
25-28::
    2s+3s 1/2 turn partner RH & set _while_ 1s dance clockwise & cross
    between 2s/3s
29-32::
    1s dance clockwise to 2nd place (opp side) _while_ 2s+3s 3/4 turn RH
    to opposite sides & all cross RH

{{explanation}}
Note - Weasel Reel - Dancers facing down, reel down middle & dance up Men''s side while those facing up reel up middle & dance down Ladies'' side', 0);
INSERT INTO 'dancecrib' VALUES (13197, '2020-09-15 00:22:11.928336+00', '2023-02-04 01:23:12.603713+00', 19999, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret; all dance DoSiDo
9-16::
    1s+2s+3s Set+Link for 3 twice (3M & 1L face out) (3) (2) (1)
17-22::
    »Rosewood JEM« figure:
::
    1L & 3M cast up/down 2 places (2 bars) & dance towards each other,
    turn right about to end BtoB (2 bars) & dance into their original
    places (2 bars)
::
    _while_ partners dance towards each other (2 bars), turn right
    about, dance out to right (2 bars) & cast up/down to their original
    places (2 bars)
23-24::
    All set. 1 (2) 3
25-32::
    1s+2s dance modified Tournee:
::
    _25_       1s+2s dance into prom hold (1M+2M dance in & turn about
    to end in centre LSh to LSh, 1M facing Men''s side, 2M facing Ladies''
    side)
::
    _26-28_  Both couples wheel anticlockwise 1/2 way & Men turn Ladies
    into middle
::
    _29-32_  Both couples turn 1.1/2 times (2s RH, 1s LH) & dance out to
    places.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7933, '2013-08-21 08:31:51.516157+00', '2023-02-04 01:23:12.63279+00', 7120, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place (2s step up), cross RH cast 1 place Lady up &
    Man down turning in to face 1st corners
9-16::
    1s dance 1/2 diagonal reel of 4 with 1st corners & 1/2 reel of 4
    with 2nd corners to end facing 3rd corner (pstn)
17-24::
    1s dance 1/2 diagonal reel of 4 with 3rd corners & 1/2 reel of 4
    with 4th corners. 1s end in centre Lady facing up & Man down
25-32::
    2s+1L circle 3H round to left as 1M+3s circle 3H round to left, 1s
    swop places & circle to the right', 0);
INSERT INTO 'dancecrib' VALUES (7934, '2013-08-21 08:31:51.526008+00', '2023-02-04 01:23:12.66756+00', 7121, 3, NULL, 'ace', '1-8::
    1s+2s set, dance RH across 1/2 way, 1s+3s set & dance LH across 1/2
    way
9-16::
    1L followed by partner cast up to 2nd place, cross, cast up to top &
    dance down centre to end 1L between 3s & 1M between 2s
17-24::
    All dance down the middle & back, 1M+2s turning to face down
25-32::
    1s dance 1/2 diagonal reel of 4 with 2L+3M (1s give RSh to person on
    right to start), 1s pass L to dance 1/2 diagonal reel of 4 with
    2M+3L (1M+3L & 1L+2M pass RSh to start) ending on sides 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7935, '2013-08-21 08:31:51.53413+00', '2023-02-04 01:23:12.682972+00', 1784, 3, NULL, 'ace', '1-8::
    1s set, dance 1/2 Fig of 8 round 2s & cross down to double triangle
    positions
9-16::
    All set & 1s turn 3rd corners RH, 1s dance 1/2 diagonal reel of 4
    with 1st corners (RSh) ending on opposite sides in double triangle
    position
17-24::
    All set & 1s turn 2nd corners LH, 1s dance 1/2 diagonal reel of 4
    with 4th corners (RSh) ending 2nd place opposite sides
25-32::
    1s dance 1/2 reels of 3 on sides giving LSh to 2nd corner (pstn),
    all set & cross RH', 0);
INSERT INTO 'dancecrib' VALUES (7936, '2013-08-21 08:31:51.542273+00', '2023-02-04 01:23:12.696149+00', 7124, 3, NULL, 'ace', '1-8::
    1s+2s Set+Link & dance RH across once round
9-16::
    1s set & dance 1/2 LSh reel of 3 across (Lady with 2s & Man with 3s)
    into 1/2 reels on the sides (1s end 2nd place opposite sides)
17-24::
    2s+1s+3s Set+Link for 3 once, turn opposite dancer RH (up/down set)
    once round
25-32::
    2s+1s+3s Set+Link for 3 once & turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (7937, '2013-08-21 08:31:51.550414+00', '2023-02-04 01:23:12.706607+00', 7129, 3, NULL, 'ace', '1-8::
    1L+2M change places RH & set _while_ partners set & change places
    RH, 1s+3s dance 1/2 R&L
9-16::
    1s lead to top, cross & cast to 2nd pl, 2s+1s+3s set, 1s dance in &
    turn about to face opp sides in double triangle position _while_ 2s
    & 3s cross to own sides
17-24::
    1s dance Double Triangles & end facing 1st corners
25-32::
    1s dance 6 bar reels of 3 on opp sides giving LSh to 1st corners to
    start & 1s cross to own side on bars 31-32', 0);
INSERT INTO 'dancecrib' VALUES (7938, '2013-08-21 08:31:51.558685+00', '2023-02-04 01:23:12.720271+00', 12908, 3, NULL, 'ace', '1-8::
    1s & 3s 1/2 turn RH, pull back RSh & dance out to opposite sides,
    1s+2s+3s set, 1s & 3s cross RH
9-16::
    1s+2s Set & Rotate:
::
    Set, rotate singly & dance on 1 place clockwise, change places RH on
    sides & dance on 1 place to own sides (1s in 2nd pl)
17-20::
    1s set to 2nd corner, turning to face 4th corner & change places LH
    with 4th corner
21-24::
    1s+1st corners Petronella turn into middle & set
25-28::
    1s change places with other person RH, _while_ 2L & 3M dance round
    to right into middle to face partner & all change places with
    partner LH
29-32::
    2s+1s+3s petronella turn to own sides & set', 0);
INSERT INTO 'dancecrib' VALUES (7939, '2013-08-21 08:31:51.566688+00', '2023-02-04 01:23:12.732513+00', 12535, 3, NULL, 'ace', '1-12::
    1s+2s+4s+5s reel of 4 on sides (3s standing)
13-16::
    1s & 5s cross RH & cast in 1 place
17-24::
    3s dance diag R&L.  2 5 3 1 4
25-32::
    5s+3s also 1s+4s dance 1/2 R&L, 3s+5s+4s+1s cross RH & 5s+4s change
    places LH on sides.  2 3 4 5 1', 0);
INSERT INTO 'dancecrib' VALUES (7940, '2013-08-21 08:31:51.574939+00', '2023-02-04 01:23:12.764803+00', 7135, 3, NULL, 'ace', '1-8::
    All set, cross RH, set & 1s+2s also 3s+4s dance 1/2 RH across to end
    2 1 4 3
9-16::
    All dance RSh reels of 4 on sides to end with 1s & 4s BtoB in centre
    facing diagonally
17-24::
    1s & 4s dance "Hello-Goodbye" setting to end facing opposite corners
25-32::
    1s & 4s turn corners RH, pass partners RSh to end on own side & turn
    partners RH
33-40::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7776, '2013-08-21 08:31:48.269218+00', '2023-02-04 01:23:12.79441+00', 7139, 3, NULL, 'ace', '1-8::
    1s & 4s cross RH & cast 1 place, dance 1/2 Fig of 8 round end
    couples into centre facing corner just passed
9-16::
    1s & 4s dance ''Hello-Goodbye'' setting to face diagonally opposite
    corner
17-24::
    1s & 4s turn corner person RH & dance LH across once round to end on
    opposite sides
25-32::
    Bottom 2 couples dance 1/2 R&L, then middle 2 couples dance 1/2 R&L', 0);
INSERT INTO 'dancecrib' VALUES (7941, '2013-08-21 08:31:51.597537+00', '2023-02-04 01:23:12.816018+00', 9534, 3, NULL, 'ace', '1-8::
    1s turn LH, cast 1 place & turn RH to face 2nd corners
9-16::
    1s turn 2nd corners LH, turn partner RH, turn 1st corners LH &
    partner RH to end facing 2nd corners
17-24::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corners &
    end crossing LH to own sides
25-32::
    2s+1s+3s circle 6H to right & back', 0);
INSERT INTO 'dancecrib' VALUES (7942, '2013-08-21 08:31:51.605843+00', '2023-02-04 01:23:12.833669+00', 11762, 3, NULL, 'ace', '1-8::
    1s set & cast 1 place, 1s dance 1/2 Fig of 8 down through 3s
9-12::
    1s set & turn RH to end facing 3rd corners
13-16::
    1s dance 1/2 LSh reel of 4 with 3rd corners & pass LSh to face 2nd
    corners
17-20::
    1s dance 1/2 LSh reel of 4 with 2nd corners & end 1L in middle in
    3rd place facing up & 1M in middle in 2nd place facing down
21-24::
    1s turn LH 3/4 way round to 2nd place opp sides
25-32::
    All cross passing partner LSh & dance anticlockwise 1/2 way round &
    cross LH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (7943, '2013-08-21 08:31:51.61559+00', '2023-02-04 01:23:12.931352+00', 7143, 3, NULL, 'ace', '1-8::
    1s+2s circle 4H round to left, 1s cast to 2nd pl as 2s lead up to
    1st pl, 1s+3s circle 4H round to left & 1s cast to 3rd pl as 3s
    dance up to 2nd pl
9-16::
    1s lead up between 3s, cast up behind 2s to top, lead down below 3s
    & cast back to top
17-24::
    1s lead down between 2s, cast down behind 3s then lead up to face
    1st corners, set to 1st corners & set to 2nd corners
25-32::
    1s dance reels of 3 on opposite sides giving RSh to 2nd corners &
    cross RH to 2nd places', 0);
INSERT INTO 'dancecrib' VALUES (7963, '2013-08-21 08:31:51.895557+00', '2023-02-04 01:23:14.011646+00', 11617, 3, NULL, 'ace', '1-8::
    1s set, 1L followed by partner casts 2 places, 1L crosses (below 3s)
    & casts up on Men''s side to partners place _while_ 1M dances round
    3L & up the middle to partners place facing out
9-16::
    1s dance reel of 3 on sides (RSh to 2s to start)
17-24::
    1M followed by partner casts 2 places, 1M crosses (below 3s) & casts
    up on Men''s side to original place _while_ 1L dances round 3L & up
    the middle to original place & 1s set
25-32::
    1s+2s dance the Chain Progression :
::
    1s & 2s 3/4 turn RH, 1M+2L turn LH 1.1/2 times _while_ partners
    chase clockwise 1/2 way, 2s & 1s 3/4 turn RH to end on sides in
    order 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (10347, '2017-12-22 15:45:17.140917+00', '2023-02-04 01:23:12.95931+00', 7145, 3, NULL, 'ace', '1-4::
    All  Adv+Ret (1 step each) & cross RH.
5-8::
    1s+2s also 3s+4s Adv+Ret diagonally (1 step each). 1s+2s also 3s+4s
    change places LH on sides (2L polite turn)
9-12::
    1s+4s+3s dance 1/2 reel of 3 on sides (1s+4s pass RSh to start).
13-16::
    All set, cross RH back to own sides.  2 3 4 1
17-20::
    2s lead down _while_ 1s lead up (3s step up / 4s step down) & 2s+1s
    dance 1/2 RH across to end 3 (1) (2) 4
21-24::
    NHJ 3s dance down _while_ 4s dance up (1s step up / 2s step down) &
    3s+4s circle 4H 1/2 round to end (1)(4)(3)(2)
25-28::
    1s+4s also 2s+3s circle 4H once round, 3s & 4s drop partner''s hand
    to form large circle
29-32::
    All continue circle 8H 1/2 round to Left to end on own sides  2 3 4
    1', 0);
INSERT INTO 'dancecrib' VALUES (7944, '2013-08-21 08:31:51.624661+00', '2023-02-04 01:23:12.979006+00', 8650, 3, NULL, 'ace', '1-8::
    1s & 3s cross RH & cast 1 place, 2s+1s also 4s+3s dance RH across
    1/2 way & all set.  1(2)3(4)
9-12::
    All cross RH & 1s+2s also 3s+4s change places LH on sides.  2(1)4(3)
13-16::
    All cross RH & 1s+4s change places LH on sides _while_ 2s+3s (end
    couples) change places LH on sides (dancing outsides 1s+4s).
    3(4)1(2)
17-20::
    All cross RH & 3s+4s also 1s+2s change places LH on sides.  4(3)2(1)
21-24::
    All cross RH & 3s+2s change places LH on sides _while_ 4s+1s (end
    couples) change places LH on sides (dancing outsides 3s+2s).
    1(2)3(4)
25-32::
    1s dance in as 2s+4s cross RH, 1s cast to bottom as 2s+3s+4s step up', 0);
INSERT INTO 'dancecrib' VALUES (7945, '2013-08-21 08:31:51.633021+00', '2023-02-04 01:23:13.011497+00', 7539, 3, NULL, 'ace', '1-8::
    1s & 3s turn RH 1.1/4 times, Men followed by ptnrs dance thru cpl to
    their right (1s thru 4s & 3s thru 2s) & cast anticl''wise to change
    pl (Ladies on L)
9-16::
    2s & 4s repeat
17-24::
    1s & 3s repeat but with Ladies Leading
25-32::
    2s & 4s repeat (all back in original places)
33-36::
    1s+3s set to partners & change places RH
37-40::
    All 4 Ladies dance 1/2 R&L on the 1st corner diagonal
41-44::
    All 4 Men dance 1/2 R&L on 2nd corner diagonal
45-48::
    2s+4s set to partners & change places RH
49-52::
    1s+3s set to partners & change places RH
53-56::
    All 4 Ladies dance 1/2 R&L on the 2nd corner diagonal
57-60::
    All 4 Men dance 1/2 R&L on 1st corner diagonal
61-64::
    1s+3s set to partners & change places RH
65-72::
    All Ladies dance a Fig of 8 round their partner & next Man passing
    in front of partner to start & behind next Man
73-80::
    All Men dance Figs of 8 round partner & next Lady passing in front
    of partner to start & behind next Lady
81-88::
    All circle 8H round & back', 0);
INSERT INTO 'dancecrib' VALUES (7947, '2013-08-21 08:31:51.654146+00', '2023-02-04 01:23:13.137918+00', 7152, 3, NULL, 'ace', '1-8::
    1L followed by 1M dances Fig of 8 on Ladies side, (in front of 2L,
    out round 3L, in & out behind 2L) ending in centre (opp sides)
    facing 4s, _while_ 4s dance similarly on Men''s side ending facing 1s
9-16::
    1s+4s set facing each other _while_ 2s join 1s as 3s join 4s to form
    lines across, all set & dance RH across with opposite 2 dancers
17-24::
    All dance full reels of 4 across dance, 1s & 4s end in centre
    holding RH facing opposite sides (as Wild Geese) 2s & 3s end in
    1st/4th places
25-32::
    1s+4s Bal-in-Line in centre of dance, 3/4 turn partner RH, 1s & 4s
    lead up to top, 1s cast to 3rd place & 4s cast to 2nd place.  2 4 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (9426, '2016-10-06 07:19:07.419471+00', '2023-02-04 01:23:13.171591+00', 17120, 3, NULL, 'ace', '{{explanation}}
Only Ladies progress, Men maintain position & shape of set

1-8::
    All set to partner & turn RH. Men dance LH across in centre back to
    place
9-16::
    All set to partner & turn LH. Ladies dance RH across in centre
    flowing into …
17-20::
    Ladies pass partner RSh, pass next person LSh & turn next person 2H
    once round
21-24::
    Repeat bars 17-20. Ladies have moved 1 place clockwise to dance with
    new partner. (1L with 2M, 2L with 3M, 3L with 1M)
25-32::
    All set in circle, circle 6H round for 2 bars, dance into centre,
    pull RSh back and spiral out & chase round following each other into
    place

{{explanation}}
(Men in original places, Ladies have progressed)', 0);
INSERT INTO 'dancecrib' VALUES (7948, '2013-08-21 08:31:51.763825+00', '2023-02-04 01:23:13.286247+00', 10361, 3, NULL, 'ace', '1-8::
    1s set then set advancing to partner, turn 2H & cast 1 place
9-16::
    1s dance reflection reels of 3 on sides (in & down to start) & end
    facing 1st corners
17-24::
    1s dance ''Hello-Goodbye'' setting
25-32::
    1s+3s dance the Knot', 0);
INSERT INTO 'dancecrib' VALUES (14015, '2021-05-03 00:22:13.627212+00', '2023-02-04 01:23:13.319992+00', 19824, 3, NULL, 'ace', '1-8::
    1s turn RH (2 bars), cast 1 place (2s step up); 1s dance down NHJ
    between 3s & cast up round 3s to finish in 2nd place in the middle
    facing up
9-16::
    2s+1s+3s dance reels of 3 on the sides (2s out & down, 1s dance up
    NHJ, 3s out & up to start). 1s finish facing 1st corners, 2s & 3s
    loop into place
17-24::
    1s set to 1st corners, 1s cast, dance out to 3rd corner positions,
    across the set, round 2nd corners to finish facing 2nd corners
    _while_ 1st corners dance path of 1/2 reel of 4 & set
25-32::
    1s set to 2nd corners, 1s cast, dance out to 4th corner positions,
    behind lines (1M up, 1L down), round 3rd corners to finish 1M
    between 3s (in 1st place) facing down & 1L between 2s (in 3rd place)
    facing up _while_ 2nd corners dance path of 1/2 reel of 4 & set
33-40::
    All Adv+Ret; 1s change places RH & cast round 4th corners to 2nd
    place _while_ 3s+2s dance 1/2 R&L changing places on the sides to
    begin', 0);
INSERT INTO 'dancecrib' VALUES (14920, '2022-06-27 00:22:36.037085+00', '2023-02-04 01:23:13.346536+00', 16574, 3, NULL, 'ace', '1-8::
    1s set, lead down, cross & cast up round 3s, turn LH to end facing
    1st corners
9-16::
    1s dance Corner Pass+Turn with 1st corners, repeat with 2nd corners
    & 1s pass RSh to 2nd place own side
17-20::
    2s+1s+3s 1/2 turn partner RH, pull back RSh & dance out to opp side
21-24::
    1M+2s dance 1/2 reel of 3 across (1M+2L pass LSh) _while_ 1L+3s
    dance 1/2 reel of 3 across (1L+3M pass LSh).  2 1 3
25-32::
    2s+1s circle 4H round to left; 1s & 3s cross RH with partner then
    dance 1/2 RH across.  End 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7949, '2013-08-21 08:31:51.772214+00', '2023-02-04 01:23:13.376856+00', 7153, 3, NULL, 'ace', '1-8::
    1s & 3s lead down middle; 1s & 3s lead up, 1s dance out between
    2s+3s & up to 1st place  3s dance out below 4s & cast up to 3rd
    place
9-16::
    1M+2L also 3M+4L change places RH & set  1L+2M also 3L+4M set &
    change places RH; repeat back to original places
17-24::
    All circle 8H round & back
25-28::
    1M dances behind own line to 4th place as 4M dances up middle to 1st
    place _while_ 1L dances down middle to 4th place as 4L dances up
    behind own line to top place
29-32::
    4s+2s also 3s+1s dance 1/2 Diamond Poussette.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (9941, '2017-06-05 11:31:58.491804+00', '2023-02-04 01:23:13.404809+00', 17743, 3, NULL, 'ace', '1-4::
    All set.  1s & 3s 1/2 turn RH moving down 1 place (2s & 4s step up)
5-8::
    All set.  1s & 3s 3/4 turn RH .  End 4s facing out & to their Right
9-16::
    2s+4s+5s dance reels of 3 on sides (4s RSh to 2M/5L) _while_ 1s+3s
    dance reel of 4 in the middle. 1M & 3L end facing out at top/bottom
    of set, 1L+3M end by turning 3/4 LH to face 4M/4L
17-24::
    1s & 3s dance RSh Figs 8 across (1M round 2s, 1L & 3M round 4s, 3L
    round 5s)
25-28::
    RH across, 1L+2s, 1M+4s+3L, 3M+5s
29-32::
    1s & 3s turn LH & cast to end 2 4 1 5 3', 0);
INSERT INTO 'dancecrib' VALUES (7950, '2013-08-21 08:31:51.780286+00', '2023-02-04 01:23:13.434235+00', 7157, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & dance reels of 3 on sides (1s & 3s cast to start & 1s
    end facing out)
9-16::
    1s cast, dance 1/2 Fig of 8 round top place _while_ 2s cross up,
    cast & cross up to top place, 1s turn RH to end facing out in 2nd
    place opp side
17-24::
    1s cast round 1st corner (pstn), turn RH & dance RSh round their 4th
    corner (pstn) to 2nd place own side _while_ 2s & 3s cross RH
    (joining hands on side), set twice & cross RH
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (13538, '2021-01-09 01:22:14.288737+00', '2023-02-04 01:23:14.065625+00', 17691, 3, NULL, 'ace', '1-6::
    1s+2s dance 6 bars of Tourbillon:
::
    1s & 2s 1/2 turn ptnrs 2H, 1M & 2L lead ptnrs by nearer hand 1 place
    cl''wise (end 1s on Ladies'' side & 2s Men''s side), 1s set to 2s
::
    1s & 2s 1/2 turn ptnrs 2H & lead ptnrs clockwise to 2s in 1st place
    & 1s in 2nd place (2) (1) 3
7-8::
    2s cross RH _while_ 1s turn 1.1/4 LH & pull back LSh to face 2nd
    corner
9-12::
    1s change places RH with 2nd corners _while_ 1st corners set. 1s &
    1st corners chase 1/4 clockwise _while_ 2nd corners turn 3/4 LH to
    face 3rd corners
13-20::
    Repeat bars 9-12 two times to finish 1 3 2 on Men''s side & 3 2 1 on
    Ladies'' side
21-24::
    All turn opposite person RH
25-32::
    All dance 3 couple Bourrel:
::
    _25-28_   1M+2L also 3M+1L set advancing & 3/4 turn 2H & twirl to
    line up/down middle _while_ 2M & 3L chase 3/4 anticlockwise to face
    them
::
    _29-32_   All set & turn 2H to own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7966, '2013-08-21 08:31:51.920946+00', '2023-02-04 01:23:14.089433+00', 7189, 3, NULL, 'ace', '1-8::
    1M+2L & 3M+4L passing RSh dance diagonal reel of 4
9-16::
    2M+1L & 4M+3L passing RSh dance diagonal reel of 4
17-24::
    1s+4s turn RH & cast in 1 place, 1s+4s circle 4H round to left
25-32::
    2s in top place stand _while_ 1s+4s+3s dance 1/2 reel of 3 on sides
    (1s RSh to 4s), 2s+3s & 4s+1s circle 4H round to left', 0);
INSERT INTO 'dancecrib' VALUES (7967, '2013-08-21 08:31:51.929235+00', '2023-02-04 01:23:14.115523+00', 7190, 3, NULL, 'ace', '1-8::
    _1_ cross RH & cast 1 place as 2s dance up to top place & face out,
    1s dance 1/2 reflection reels of 3 on sides (1s dance in & down to
    start)
9-16::
    3s+1s+2s dance 6H round & back
17-24::
    1s turn LH & face out (still on opposite sides) 1s cast to right &
    cross & casts up/down to 2nd place own side
25-32::
    3s+1s+2s turn 2H 1/2 way & to twirl & dance out to opposite sides &
    face partners, all set & turn partners RH 1/2 way to end in middle
    facing up
33-40::
    All dance 3 couple Allemande', 0);
INSERT INTO 'dancecrib' VALUES (7968, '2013-08-21 08:31:51.937805+00', '2023-02-04 01:23:14.144095+00', 9905, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place & dance 1/2 Figs of 8 round 2s
9-16::
    2s+1s+3s dance 1/2 reels of 3 on sides with 1s giving RSh to 2nd
    corners, 1s dance 1/2 reels of 3 across Lady with 2s (in 3rd pl) &
    Man with 3s
17-20::
    1s turn RH to face 3rd corners (pstn)
21-32::
    Dance to Corners & Set: (12 bars)
::
    Couple in middle change places with corners passing RSh, corners
    pass RSh in middle with a 1/4 turn to right to face next corner
    _while_ supporting corners set (2 bars).  Repeat 5 more times to end
    with corners in diagonally opposite place and 1s meet in middle
    again & face 1st corners (pstn)
33-40::
    1s dance RSh round 1st corners to 2nd place own sides & 2s+1s+3s all
    turn RH', 0);
INSERT INTO 'dancecrib' VALUES (7969, '2013-08-21 08:31:51.947942+00', '2023-02-04 01:23:14.17425+00', 11640, 3, NULL, 'ace', '1-8::
    All set, cross RH, 1s+2s also 3s+4s dance RH across 1/2 way & all
    set
9-16::
    1s+4s turn partner 2H into centre & dance 1/2 Poussette.  2 4 1 3
17-24::
    2s+4s also 1s+3s dance double Fig of 8 (4s & 1s start crossing to
    ends)
25-32::
    All dance 8H round & back.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7970, '2013-08-21 08:31:51.956292+00', '2023-02-04 01:23:14.206055+00', 10776, 3, NULL, 'ace', '1-8::
    1s turn RH, cast 1 place, dance RH across (Lady with 2s & Man with
    3s) & end facing 1st corners
9-16::
    1s dance reel of 4 with 1st corners & end turning RH to Man facing
    up & Lady down
17-24::
    1s dance RSh round 2nd corners, pass LSh in centre to dance RH
    across (Lady with 3s & Man with 2s) & end facing 2nd corners
25-32::
    1s dance reel of 4 with 2nd corners & end in 2nd place own sides

{{explanation}}
Energetic dancers may wish to dance this as a reel - "The Whirlwind"', 0);
INSERT INTO 'dancecrib' VALUES (7971, '2013-08-21 08:31:51.96422+00', '2023-02-04 01:23:14.240953+00', 7193, 3, NULL, 'ace', '1-8::
    1M+2L also 3M+4L set & turn RH, 1s+2L also 3M+4s dance RH across
9-16::
    1L+2M also 3L+4M set & turn LH, 1s+2M also 3L+4s dance LH across
17-24::
    1s set, dance down to 3rd place (2s+3s up), 2s+3s also 1s+4s dance
    RH across
25-32::
    2s+3s also 1s+4s circle 4H round to left, 1s+4s set facing on sides
    & change places RH', 0);
INSERT INTO 'dancecrib' VALUES (7972, '2013-08-21 08:31:51.97399+00', '2023-02-04 01:23:14.279177+00', 9906, 3, NULL, 'ace', '1-8::
    1s & 4s turn RH into centre & dance RH across _while_ 2s & 3s chase
    clockwise to opposite ends
9-16::
    1s & 4s dance 1/2 Figs of 8 round end couples & dance LH across & …
17-24::
    1s & 4s pick up corners to dance St Andrews cross once round
25-32::
    1s & 4s face crnrs & all dance the Olé: turn singly to right with RH
    in air & LH on hip (Flamenco style), turn crnrs & cross to own
    sides.  3 1 4 2', 0);
INSERT INTO 'dancecrib' VALUES (13929, '2021-04-05 00:22:25.031222+00', '2023-02-04 01:23:14.303798+00', 19489, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1s Petronella turn into lines of 3 across
    & set
9-16::
    1s cross RH, cast round 2nd corners to 2nd place opp sides &
    2s+1s+3s dance 1/2 reels of 3 on sides (1s LSh to 1st corners)
17-24::
    1s cross RH, cast round 3rd corners into lines of 3 across & dance
    1/2 reels of 3 across (1s LSh to 2nd corner pstn). 1s end facing 3rd
    corner (pstn)
25-32::
    1s dance 1/2 diag reel of 4 on 1st corner diagonal, pass LSh to face
    4th corner (pstn) & dance 1/2 diag reel of 4 on 2nd corner diagonal.
    2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7973, '2013-08-21 08:31:51.982131+00', '2023-02-04 01:23:14.334802+00', 7195, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s & 4s cross down/up 1 place & cast back to ends to meet partners
    in centre in prom hold, 1s+4s dance RSh round each other & face
    up/down
9-16::
    1s dance RSh reel of 3 across with 2s _while_ 4s dance reel across
    with 3s, 1s & 4s dance back to original places _while_ 2s & 3s dance
    into middle
17-24::
    2s+3s dance RH across & LH back to end facing corner persons
25-32::
    All set, change places LH & 1s+4s circle left to end 2 1 (4) (3)
33-40::
    1s+4s dance 1/2 R&L & all set twice to partners.  2 4 (1) (3)', 0);
INSERT INTO 'dancecrib' VALUES (7974, '2013-08-21 08:31:51.990278+00', '2023-02-04 01:23:14.364414+00', 13934, 3, NULL, 'ace', '1-8::
    1L+3M passing LSh dance diagonal full reel of 4 with 1M+3L who dance
    into partners place to dance 1/2 reel & cast to original places
9-16::
    1s+2s dance the Tournee :
::
    _9-12_  1s+2s dance into prom hold (Men with partner on right, 1s
    face Men''s side & 2s face Ladies side), both couples wheel
    anticlockwise 1/2 way & Men turn Ladies into middle
::
    _13-16_  Both couples turn 1.1/2 times (2s RH, 1s LH) & 1s end
    facing 1st corners
17-24::
    1s dance "Hello-Goodbye" setting ending in 2nd place own sides
25-32::
    2s+1s+3s dance reflection reels of 3 (1s out & down to start) ending
    with 1s+3s dancing an extra pass to change places.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7976, '2013-08-21 08:31:52.005161+00', '2023-02-04 01:23:14.40905+00', 8835, 3, NULL, 'ace', '1-8::
    1s set advancing, 1/2 turn 2H, set to 2s & turn 2s on sides with
    nearer hand
9-16::
    1s+2s dance double Fig of 8 (1s crossing down to start)
17-24::
    1s followed by 2s lead down for 3 steps, 1/2 turn RH (2s divide) &
    1s lead back to top
25-32::
    1s+2s dance Poussette.  2 1', 0);
INSERT INTO 'dancecrib' VALUES (15437, '2023-02-04 01:23:14.944163+00', '2023-02-04 01:23:14.945039+00', 18277, 3, NULL, 'ace', '1-8::
    2s+3s dance the Knot 1 3 2
9-12::
    3s dance 1/2 Fig of 8 (3L up round 1s, 3M down round 2s). 1 (3) 2
13-16::
    All cross RH, all set (1) 3 (2)
17-20::
    1L dances RSh round 3L _while_ 2M dances RSh round 3M to finish BtoB
    facing partner on 2nd corner diagonal
21-24::
    1s+2s dance 1/2 diagonal RSh reel of 4. 1L+2M finish reel by dancing
    across, 1L to 1M''s place, 2M to 3L''s place
25-28::
    2L dances LSh round 3M _while_ 1M dances LSh round 3L to finish BtoB
    on 1st diagonal, 2L faces1L as 1M faces 2M
29-32::
    2s+1s dance 1/2 diagonal LSh reel of 4. 2L+1M finish reel by dancing
    across, 2L to 1L''s place, 1M into 3M''s place 2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (12829, '2020-05-14 23:16:50.130833+00', '2023-02-04 01:23:14.442153+00', 19894, 3, NULL, 'ace', '1-8::
    1M+3L set, cast to 2nd place (2s step up/down 3-4), 1M+3L cross RH,
    3 couples dance clockwise 2 places.  3 (2) 1
9-16::
    3M+1L set, cast to 2nd place (2s step up/down 11-12), 3M+1L cross
    RH, 3 couples dance clockwise 2 places to orig. places. 1 2 3
17-20::
    1M+3L change places RH staying in the middle facing end of set then
    curve round to the left, 1M facing up, 3Lfacing down
::
    _while_ 3M+1L cast clockwise behind 2s, meet in the middle and
    change places RH to all finish in a line of 4 up/down the middle of
    the set M facing M and L facing L.
21-24::
    1s+3s dance variant of 1/2 LSh Reel of 4 (1M+3L give RH in passing
    and then turn partners LH at the ends & cast out of own sides into…
25-32::
    _6_ bar Mirror Reels of 3 on own sides  (1s out/down, 2s in/up, 3s
    out/up), Bars 31-32 1s & 2s continue reel to change places. End 2 1
    3', 0);
INSERT INTO 'dancecrib' VALUES (7977, '2013-08-21 08:31:52.09613+00', '2023-02-04 01:23:14.618006+00', 13886, 3, NULL, 'ace', '1-8::
    1s cast & dance Fig of 8 on own sides
9-16::
    1s & 2s set & turn 2H, 1s+2s circle left
17-24::
    1s+2s+3s dance the Knot
25-32::
    All set & 3s+2s also 1s+4s dance 3/4 R&L.  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (9942, '2017-06-05 11:31:58.826945+00', '2023-02-04 01:23:14.629794+00', 16499, 3, NULL, 'ace', '1-8::
    1s set, cross RH, cast 2 places, cross up to 2nd place facing out
    (2s step up 5-6)
9-12::
    1s turn 3s (Men LH, Ladies RH)  1s meet & dance up
13-16::
    1s turn 2s (Men LH, Ladies RH)  1s set advancing to end BtoB facing
    1st corners
17-20::
    Corner Pass & Twirl with 1st corners
::
    1s pass corners RSh, dance round corner place, pass each other LSh
    to face 2nd corners _while_
::
    1st corners dance in, 1/2 turn 2H, face & pulling back RSh dance out
    to opp corner place
21-24::
    Corner Pass & Twirl with 2nd corners.  1s end LSh to LSh in middle
    facing own side
25-28::
    1s turn 1.1/2 LH _while_ 3s+2s chase clockwise 1/2 way round
29-32::
    1L+2s & 1M+3s dance RH across.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (14237, '2021-08-14 00:22:33.989683+00', '2023-02-04 01:23:14.640999+00', 20000, 3, NULL, 'ace', '1-4::
    1s+3s 1/2 turn 2H & chase 1/2 round clockwise. 3M followed by 1L &
    1M followed by 3L facing sides
5-8::
    3M+1L & 1M+3L chase clockwise 1/2 round RSh round 2s/4s. Men end
    BtoB in centre facing Ladies _while_ 2s & 4s repeat bars 1-4
9-12::
    3M+1L & 1M+3L set, Adv+Ret (1 step each) _while_ 2s & 4s repeat bars
    5-8 dancing through setting couples. All Men end BtoB in centre
13-16::
    3M+1L & 1M+3L dance DoSiDo _while_ 2s & 4s dance bars 9-12
17-20::
    All dance 1/2 intersecting RSh reels of 4 (1/2 LH across in centre)
21-24::
    Men set advancing to next place in centre to left & face out _while_
    Ladies chase 1/4 round clockwise, all turn partners 3/4 RH, Ladies
    face out
25-32::
    Corner Schiehallion Reels:
::
    _25-26_   Men dance straight across & face out to left _while_
    Ladies loop left round corner & face in
::
    _27-32_   Repeat 3 more times from new positions. End 2 3 4 1 facing
    partner', 0);
INSERT INTO 'dancecrib' VALUES (7978, '2013-08-21 08:31:52.104427+00', '2023-02-04 01:23:14.650768+00', 7201, 3, NULL, 'ace', '1-8::
    1s & 3s set, 3/4 turn RH. 1M+3L turn LH 1.1/2 times _while_ partners
    dance clockwise (behind 2s) to face partner in centre
9-16::
    3s+1s dance reel of 4 up/down centre finishing in same places as
    start of reel
17-24::
    3s & 1s set to partners, petronella turn to own sides.  3s+2s+1s
    turn LH ready for promenade
25-32::
    3s+2s+1s Promenade ending with 3s casting to 3rd place. End  2 1 3

{{explanation}}
Note: 2nd time through original 4s cast to 3rd place while original 1s stay in 4th place', 0);
INSERT INTO 'dancecrib' VALUES (15436, '2023-02-04 01:23:14.661177+00', '2023-02-04 01:23:14.661744+00', 21142, 3, NULL, 'ace', '{{explanation}}
3s and 4s start on opposite sides

1-8::
    1L+4L dance RSh round partner, face partner, pull back RSh (twirl)
    to face own sides _while_ 1M+4M stand still for 2 bars, set. 1s+4s
    (Lady leading) chase 1/2 way clockwise to change places. 4L+1L face
    out 4 2 (3) (1)
9-16::
    4s+2s+3s+1s dance RSh reel of 4 on the sides. 2M+3M end facing out
17-24::
    2s+3s dance a Ladies'' chain
25-28::
    All set, turn partner 3/4 RH to line up/down centre
29-36::
    4s+2s also 3s+1s dance half Celtic reels:
::
    _29-32_   4s+2s (3s+1s) pass partners RSh, 4M+2L (3L+1M) dance
    clockwise 1/4 way _while_ 4L+2M (3M+1L) dance 3/4 LSh round each
    other to face partners in lines across the set
::
    _33-36_   4s+2s (3s+1s) pass partners RSh, 4L+2M (3M+1L) dance
    clockwise 1/4 way _while_ 4M+2L (3L+1M) dance 3/4 LSh round each
    other to face partners in line up/down
37-40::
    All turn partners 3/4 RH to finish on the sides & all set 2 4 (1)
    (3)', 0);
INSERT INTO 'dancecrib' VALUES (12948, '2020-07-01 00:22:04.232599+00', '2023-02-04 01:23:14.673695+00', 19993, 3, NULL, 'ace', '1-8::
    1L casts, cross up between 2s, casts behind 2M, crosses set to 2nd
    place own side facing out _while_ 1M sets, dance across, casts
    behind 2L & crosses down to 3rd place facing out.  (2s step up 5-6,
    3M steps up 7-8)
9-16::
    1s+2s+3s dance RSh reels of 3 on sides (1s RSh to person on right -
    1L down, 1M up).  1s end facing out
17-24::
    1L casts, dances up middle to top & casts to left behind 2M into 2nd
    place opp side _while_ 1M casts up, dances 1/2 Fig up between 2s &
    into 2nd place opp side & sets.  (3M steps down 17-18)
25-26::
    1s turn 3/4 RH _while_ 2s+3s chase 1 place clockwise (2 bars), with
    1L dancing down between 3L+2L, 1M up between 2M+3M all facing
    clockwise
27-32::
    All 3 couples continue chase back to own side.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7979, '2013-08-21 08:31:52.112519+00', '2023-02-04 01:23:14.683712+00', 8084, 3, NULL, 'ace', '1-8::
    1s also 2s set twice & dance DoSiDo
9-16::
    1s cross RH & cast 1 place, 1s turn RH 1.1/2 times
17-24::
    1s+2s circle round & back', 0);
INSERT INTO 'dancecrib' VALUES (7980, '2013-08-21 08:31:52.122336+00', '2023-02-04 01:23:14.695591+00', 9907, 3, NULL, 'ace', '1-4::
    Ladies dance 1/2 R&L with 1L+2L & 3L+4L crossing RH to start
5-8::
    Men dance similarly 1/2 R&L ending with all Men facing out
9-16::
    All dance Double Ladies'' Chain
17-19::
    Men turn partner LH 1/2 way into prom hold
20-22::
    All Promenade 1/4 quarter way round anticlockwise & end facing
    partner
23-24::
    Men set _while_ Ladies turn under Man''s Right arm
25-32::
    All dance interlocking reels of 4 round set passing partner RSh

{{explanation}}
Note: Bars 1-4 & 5-8 are always danced by same couples from their new positions', 0);
INSERT INTO 'dancecrib' VALUES (8922, '2015-09-22 20:53:38.42127+00', '2023-02-04 01:23:14.814905+00', 16769, 3, NULL, 'ace', '1-8::
    1s & 4s turn 2H 1.1/4 times into line in middle & dance 1/2 reel of
    4 ending on opp sides, 4s & 1s set as 2s+3s dance LH across 1/2 way
    (4)(3)(2)(1)
9-16::
    All chase 1/2 way to original places, all dance DoSiDo
17-24::
    2s dance Fig of 8 round 1s _while_ 3s dance Fig of 8 round 4s
25-32::
    1s change places with 2s (1M RH, 1L LH) & change places with 3s
    (other hand), 1s change places with 4s (1M RH, 1L LH) & 1s set', 0);
INSERT INTO 'dancecrib' VALUES (12830, '2020-05-14 23:16:50.517118+00', '2023-02-04 01:23:14.824829+00', 11822, 3, NULL, 'ace', '1-8::
    1s & 3s turn partner 3/4 2H, set (HS 4 bars), turn partner 3/4 2H
    picking up 2s to form circle.  (1) 2 (3)
9-16::
    All circle left (2 bars), Men turn Lady on right once round (2H),
    reform circle, circle left (2 bars) to sides & all set
17-20::
    2s dance 1/2 Diag R&L with 1L & 3M (2M down, 2L up)
21-24::
    2s dance 1/2 Diag R&L with 1M & 3L (2M down, 2L up).  3 2 1
25-28::
    2s+1s set, turn partners 2H moving clockwise to 2s on Ladies'' side,
    1s on Men''s side

{{title}}
`	3L…2L…2M

{{title}}
`	3M...1L…1M

29-32::
    2s+1s set, 1L & 2M cross to own sides _while_ 1M casts up to 2nd
    place, 2L casts to 3rd place. 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (7990, '2013-08-21 08:31:54.151909+00', '2023-02-04 01:23:15.126255+00', 7227, 3, NULL, 'ace', '1-8::
    All circle 8H round & back
9-16::
    1s+3s dance 1/2 R&L turning Ladies into centre (Ladies BtoB), set,
    turn partners RH into prom hold to 1s facing 2M & 3s face 4M
17-24::
    3s dance RSh reel of 3 across with 4M+2L (start RSh to 4M) _while_
    1s dance reel of 3 across with 2M+4L (start RSh to 2M)
25-32::
    1s+3s dance 1/2 R&L back to original places, all set to partners &
    turn RH
33-40::
    Ladies dance Fig of 8 round partner & corner (pass behind partner to
    start) _while_ Men Adv+Ret for 2 steps twice
41-48::
    All turn partners RH & dance DoSiDo with partners
49-56::
    Men cast to dance Fig of 8 round corner & partner (pass behind
    corners to start) as Ladies Adv+Ret twice
57-64::
    All turn corners RH (4 bars) & partners LH (4 bars)
65-128::
    Repeat with 2s+4s leading with 2s facing 3M & 4s facing 1M', 0);
INSERT INTO 'dancecrib' VALUES (7991, '2013-08-21 08:31:54.160078+00', '2023-02-04 01:23:15.149544+00', 8498, 3, NULL, 'ace', '1-8::
    1s dance Inveran reels with 2s+3s
9-16::
    1s lead down for 3 bars, lead up & cast to 2nd place
17-24::
    1s dance Figs of 8 own sides (b''tw''n 3s to start)& end facing 1st
    corners _while_ crnrs set facing on sides & change pl RH, set to
    prtnr & change pl RH
25-32::
    1s dance 1/2 reel of 4 with 1st corners, pass RSh & dance 1/2 reel
    with 2nd corners ending 2nd place own sides
33-40::
    2s+1s+3s circle 6H round to left & back', 0);
INSERT INTO 'dancecrib' VALUES (14016, '2021-05-03 00:22:15.237909+00', '2023-02-04 01:23:15.176343+00', 19822, 3, NULL, 'ace', '1-8::
    1s dance down NHJ between 2s, cast down round 3s (2s&3s face down
    bar 4). 1s followed by 3s & 2s (who dance down) lead up to top. All
    take promenade hold facing up 1 3 2 ready for …
9-16::
    All dance Promenade, on bar 15 1s cast to 2nd place _while_ 3s dance
    up to 1st place 3 1 2
17-24::
    3s+1s+2s dance the Knot to finish 1s facing 1st corners & 2s+3s
    facing out
25-32::
    2s+1s+3s dance 6 bar reels of 3 on sides (1s give LSh to 1st corners
    & 3s pass 2s RSh to start), 1s cross RH 2 1 3
33-40::
    1s+3s set, 1/2 turn partner 2H, circle 4H round 1/2 way & set', 0);
INSERT INTO 'dancecrib' VALUES (8652, '2015-02-13 12:48:28.408521+00', '2023-02-04 01:23:15.20852+00', 14972, 3, NULL, 'ace', '1-4::
    1s+2s dance double 1/2 Fig 8 (1s cross down, 2s dance up)
5-8::
    1s+2s+3s dance 1/2 reels of 3 on sides, 1s crossing down thru 2nd
    place, 2s dance up and crossing down to 2nd place, 3s dance in and
    up  3 2 1
9-12::
    2s+1s dance double 1/2 Fig 8 (2s dance down, 1s cross up)
13-16::
    3s+2s+1s dance 1/2 reels of 3 on sides, 3s dancing in and down, 2s
    dance down then cross up to 2nd place, 1s cross up thro'' 2nd place
    1 2 3
17-24::
    1s+2s+3s dance 1/2 mirror (reflection) reels on sides (1s dance in
    and down to start). 1s set, cast up 1 place (2s step down bars
    23-24)
25-28::
    3s+1s dance 1/2 R&L (no polite turns) 1s finish facing in, 3s facing
    down
29-32::
    1s+3s+2s dance 1/4 Grand Chain (2 steps to each hand)   2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (7992, '2013-08-21 08:31:54.173786+00', '2023-02-04 01:23:15.366421+00', 7229, 3, NULL, 'ace', '1-8::
    1s turn RH 1.1/2 times, 1M followed by partner casts down behind 2L
    crosses to end 2nd place own sides
9-16::
    2s+1s dance RH across & LH back
17-24::
    1s dance reels of 3 across (1L with 2s & 1M with 3s)
25-32::
    1s turn LH 1.1/2 times, 1L followed by partner casts down behind 3M
    & crosses to 3rd place own sides
33-40::
    1s dance RSh reels of 4 on sides & 1s end facing 4s
41-48::
    1s+4s set twice & turn RH 1.1/2 times on sides  2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (12479, '2020-01-05 00:40:01.363714+00', '2023-02-04 01:23:15.381586+00', 19809, 3, NULL, 'ace', '1-8::
    1s+2s+3s set, 1s+2s dance 1/2 RH across; 2s+1s+3s set, 2s+1s cross
    RH
9-16::
    2s+1s+3s dance Set & Rotate for 3 couples.  3 1 2
17-24::
    3s+1s+2s circle 6H round and back
25-32::
    3s+1s+2s dance "Slip Knot":
::
    _25-30_   All 3 couples dance first 6 bars of standard Knot
::
    _31-32_   2s (top place) turn LH to own side _while_ 1s+3s dance 1/2
    LH across to end on own side.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (7993, '2013-08-21 08:31:54.182028+00', '2023-02-04 01:23:15.397561+00', 7230, 3, NULL, 'ace', '1-8::
    1s cross down RH, cast down behind 3s, cross up & cast up behind 2s
    to top
9-16::
    1s+2s+3s set, petronella turn into centre, turn partner 2H &
    petronella to opposite sides
17-24::
    1s+2s+3s circle 6H round & back
25-28::
    1s lead down LH to 3rd pl, cross & cast up to 2nd pl _while_ 2s set
    & cross LH to 3rd pl _while_ 3s cast up to 1st pl & cross LH (as
    Muirland Willie)
29-32::
    3s+1s+2s dance 1/2 reel of 3 on sides (1s in & up to start)', 0);
INSERT INTO 'dancecrib' VALUES (7994, '2013-08-21 08:31:54.189989+00', '2023-02-04 01:23:15.423376+00', 11607, 3, NULL, 'ace', '{{explanation}}
3s & 4s start on opp sides

1-8::
    1s dance down middle as  4s dance up & set to partners, 1s dance up
    & cast to 2nd places as 4s dance down & cast up
9-16::
    2s+1s also 4s+3s dance Diamond Poussette
17-24::
    1s & 4s dance 1/2 Fig of 8 round 2s/3s, 1L+4M also 1M+4L turn RH
    1.1/2 times
25-32::
    2s+4s+1s+3s Adv+Ret, all turn partners RH', 0);
INSERT INTO 'dancecrib' VALUES (7995, '2013-08-21 08:31:54.198126+00', '2023-02-04 01:23:15.447837+00', 8200, 3, NULL, 'ace', '{{explanation}}
4s & 5s & 6s start on opp sides

1-8::
    All set & cross RH, all set & 1/2 RH turn partner to end in middle
    in Allemande hold.  Top 3 facing up, bottom 3 facing down
9-16::
    1s+2s+3s also 4s+5s+6s dance Allemande.  3 2 1(6)(5)(4)
17-24::
    1s & 6s cross RH & cast 1 place away from the centre, cross LH &
    cast to ends.  1 3 2(5)(4)(6)
25-28::
    1s+3s also 4s+6s dance 1/2 R&L & end 1s facing 2s & 6s facing 5s
    (3)(1)2(5)6 4
29-32::
    3s & 4s cross RH as 1s & 2s also 5s & 6s change place RH on sides,
    3s & 2s also 1s & 6s also 5s & 4s change LH on sides.  2 3
    6(1)(4)(5)', 0);
INSERT INTO 'dancecrib' VALUES (7996, '2013-08-21 08:31:54.206132+00', '2023-02-04 01:23:15.483668+00', 11475, 3, NULL, 'ace', '1-8::
    1s set then dance down middle & cast up behind 3s+2s
9-16::
    1s+2s dance Diamond Poussette
17-24::
    1s dance Fig of 8 round 2s
25-32::
    1s dance down middle to 2nd place & turn 2H, 1s+3s circle left', 0);
INSERT INTO 'dancecrib' VALUES (13366, '2020-11-02 01:22:27.835827+00', '2023-02-04 01:23:15.502175+00', 19543, 3, NULL, 'ace', '1-8::
    1s+2s dance first 6 bars of Poussette, turn partner 1/4 2H, continue
    the turn individually to end in line of 4 up/down centre facing opp
    side (Lady above Man)
9-16::
    1s+2s dance ''The Targe'':
::
    _9-10_    1M+2L 3/4 turn RH _while_ 1L+2M dance 1/4 way round
    anticlockwise
::
    _11-12_   All turn partner once round LH
::
    _13-14_   Repeat 9-10
::
    _15-16_   All turn partner 3/4 LH onto side lines (2) (1)
17-24::
    2s+1s circle 4H round to right; 2s cross down & cast up to top
    _while_ 1s cast up & dance down to end BtoB between 3s facing opp
    side
25-32::
    1s+3s dance ''Celtic Reel'':
::
    _25-28_  1s+3s pass RSh as for reel of 4, 1s dance clockwise 1/4 way
    _while_ 3s dance 3/4 LSh round each other to face up/down in line of
    4
::
    _29-32_  1s+3s pass RSh as for reel of 4, 3s dance clockwise 1/4 way
    _while_ 1s dance 3/4 LSh round each other to face across in line of
    4
33-40::
    1s+3s pass RSh.  1s now on own sides, 3s in centre facing partner,
    1s+3s set; 3s cross down LH & cast up to 2nd place own side.  2 3 1', 0);
INSERT INTO 'dancecrib' VALUES (12469, '2020-01-02 07:01:59.025208+00', '2023-02-04 01:23:15.529164+00', 12827, 3, NULL, 'ace', '1-8::
    1s+3s petronella turn & set _while_ 2s & 4s step up 1 place & set;
    1s+2s also 3s+4s dance RH across
9-16::
    1s+3s dance reel of 4 up/down centre. Bars 15-16 1M+3L pass RSh to
    end BtoB
17-24::
    All 4 couples petronella turn & set (1s & 3s now in original
    position but opp sides, 2s & 4s in centre); 1s+2s also 3s+4s dance
    RH across
25-32::
    2s+4s dance reel of 4 up/down centre. Bars 15-16 2M+4L pass RSh to
    end BtoB
33-40::
    2s+4s petronella turn (1) (2) (3) (4), all set; all turn partners RH
41-48::
    1L+2M cross RH
::
    1L+3L also 1M+2L cross LH
::
    1L+4M also 1M+3M cross RH
::
    1M+4L cross LH. End 2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (14691, '2022-03-07 02:22:23.406809+00', '2023-02-04 01:23:15.569668+00', 20516, 3, NULL, 'ace', '1-4::
    All set, 1s cast to 2nd place (2s step up bars 3-4)
5-16::
    All dance 3 couple R&L, at end 1s pass LSh to finish back to back,
    1M facing down, 1L facing up
17-24::
    1M+3s & 1L+2s join in crown triangle position. 2s+3s set for full 8
    bars _while_ 1s set right & _while_ setting on left foot pull back
    LSh to 1/4 turn anticlockwise to form double triangle position
    facing opp sides. Repeat this move to finish 1L/1M facing down/up.
    1s dance another 1/4 turn to face own sides. On bars 23-24, 1s set
    advancing, pull back RSh to finish 2nd place own sides.
25-32::
    All circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (10022, '2017-07-23 15:59:09.717232+00', '2023-02-04 01:23:15.587368+00', 17787, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up) & dance 1/2 Fig 8 round 3s
9-16::
    2s+1s+3s cross passing partner by RSh & dance clockwise round set to
    lines of 3 across, Ladies facing down, Men up.  All Adv+Ret
17-24::
    All cross up/down passing partner by RSh and dance clockwise round
    set to opp sides facing in.  3s+1s+2s Adv+Ret
25-32::
    1s dance 1/2 diag RSh reel of 4 with 1st corners (in 3rd corner
    pstn), 1s pass RSh, dance 1/2 diag RSh reel of 4 with 2nd corners
    (4th corner pstn) ending in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (11485, '2019-01-01 01:58:11.877131+00', '2023-02-04 01:23:15.613326+00', 18548, 3, NULL, 'ace', '1-8::
    All set to partner, Ladies cast in & to right into next Ladies''
    place; all set to ''new'' partner & turn 2H. Finish facing ''new''
    partner
9-16::
    All dance interlocking RSh reels of 4 & end by turning ''new'' partner
    3/4 RH to bring Men into centre
17-24::
    Men dance LH across 1.1/3 round finishing in triangular set facing
    original partner; all dance DoSiDo passing LSh. 2 3 1
25-32::
    All Set+Link; Ladies followed by partners chase clockwise 1 place &
    on bar 32 all pass partner RSh to form triangular set facing
    partners. 3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (11486, '2019-01-01 01:58:11.886518+00', '2023-02-04 01:23:15.644041+00', 18944, 3, NULL, 'ace', '1-8::
    1s cross RH, cast (2s step up 3-4). 2s+1s dance LH across, Men end
    facing out
9-16::
    RSh reels of 3 on sides (6 bars) , 1s+3s passing RSh to start.
    1M+3L also 1L+3M turn 1/2 RH to end in prom hold 1M+3L facing diag
    up, 1L+3M diag down
17-24::
    LSh reels of 3 across, 1M+3L pass 2M LSh _while_ 1L+3M pass 4L LSh
    to start
25-32::
    1s cross RH, cast (4s step up 27-28).  4s+1s dance LH across', 0);
INSERT INTO 'dancecrib' VALUES (7998, '2013-08-21 08:31:54.220744+00', '2023-02-04 01:23:15.66799+00', 10262, 3, NULL, 'ace', '1-8::
    1s lead down the middle & back to face 1st corners
9-12::
    1s change places with 1st corners RH, 1s change places with opposite
    person LH _while_ original 1st corners 3/4 turn LH to face 2nd
    corner pstns
13-16::
    Original 1st corners change places RH with 1s (in 2nd corners),
    corners change pls on sides LH _while_ 1s turn LH to end BtoB in
    middle (L facing up)
17-24::
    1s dance reels of 3 on own sides (RSh to 3rd corners) ending in 2nd
    place
25-32::
    1s dance Diag R&L.  2 1 3 4', 0);
INSERT INTO 'dancecrib' VALUES (7999, '2013-08-21 08:31:54.228865+00', '2023-02-04 01:23:15.692796+00', 10474, 3, NULL, 'ace', '1-8::
    1s cast down behind own side for 4 bars, turn out & dance back
9-16::
    1s dance down the middle & turn 3s with nearer hand, dance up & turn
    2s with nearer hand to end in 2nd place own side
17-24::
    1s dance LSh round 1st corner, LSh round 3rd corner to end LSh to
    LSh facing opposite sides
25-32::
    1s dance RH across (Lady with 2s & Man with 3s), pass RSh & dance LH
    across with other couple to end in 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (9770, '2017-04-06 09:58:07.447803+00', '2023-02-04 01:23:15.721806+00', 14820, 3, NULL, 'ace', '1-8::
    1s+2s, 3s+4s set & dance RH across. 1s cast, 2s dance up, 4s cast up
    & 3s dance down.  2 1 4 3
9-12::
    1L+2M Allemande Right (Adv, take RH, Lady dances under Man''s arm &
    out to place as Man retires) _while_ 4L+3M Allemande Left and 1M,
    2L, 4M & 3L set twice
13-16::
    1M+2L Allemande Left _while_ 4M+3L Allemande Right and 1L, 2M, 3M &
    4L set twice. 2 1 4 3
17-24::
    Reels of 4 on sides. 1s & 4s face each other on sides
25-28::
    1s+4s set on sides & change places LH.  2 4 1 3
29-32::
    2s+4s also 1s+3s circle 4H round to Left', 0);
INSERT INTO 'dancecrib' VALUES (14921, '2022-06-27 00:22:38.419144+00', '2023-02-04 01:23:15.750738+00', 20886, 3, NULL, 'ace', '1-8::
    1s set, cast (2s step up); 1/2 turn RH, face each other, pull back
    RSh & dance out to 2nd place opp sides  2 (1) 3
9-12::
    1s dance out round 4th corners (3), turn RH (1- quick) _while_ 2nd
    corners 1/2 turn RH, face, pull back RSh & dance out to opp corners
13-16::
    1s dance out round 3rd corners, to 2nd place opp sides, _while_ 1st
    corners 1/2 turn RH, face, pull back RSh & dance out to opp corners
    (3) (1) (2)
17-24::
    3s+1s+2s dance Set+Link for 3 twice
25-32::
    2s+1s+3s circle 6H round & back', 0);
INSERT INTO 'dancecrib' VALUES (8000, '2013-08-21 08:31:54.237122+00', '2023-02-04 01:23:15.779976+00', 7239, 3, NULL, 'ace', '1-8::
    1s cross RH, cast 1 place, 1L dances a 1/2 Fig of 8 round 2s _while_
    1M dances 1/2 Fig of 8 round 3s
9-24::
    1s dance Corner Chain with 1st & 2nd corners :
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end turning LH 3/4 to face 1st
    corner
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners &
    cross to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8001, '2013-08-21 08:31:54.24537+00', '2023-02-04 01:23:15.943047+00', 7242, 3, NULL, 'ace', '1-8::
    1s+2s set twice, 1M+2L also 1L+2M turn 2H (1M dances across the top
    to turn 2L on Ladies side & crosses up diagonally to own place to
    face out _while_ 1L dances down diagonally to turn on Men''s side
    crossing back to own place to face in)
9-16::
    1M casts down own side as 1L dances down the middle, dance round the
    3s & 1M dances up the middle as 1L casts up own side, cross RH at
    top & cast to face 1st crnrs
17-24::
    1s turn 1st corners RH, partner LH, 2nd corner RH, partner LH to
    face 1st corners
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners &
    cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8002, '2013-08-21 08:31:54.253461+00', '2023-02-04 01:23:16.080535+00', 7245, 3, NULL, 'ace', '1-8::
    1s set, cast 1 place, 2s set & cast back to place
9-16::
    1s+2s dance RH across 1/2 way, set, dance LH across 1/2 way, 1s cast
    to end facing 1st corners _while_ 2s dance up
17-24::
    1s set & turn 1st corners, set & turn 2nd corners
25-32::
    1s dance reels of 3 on opposite sides giving LSh to 1st corners, 1s
    cross RH to 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8004, '2013-08-21 08:31:54.271626+00', '2023-02-04 01:23:16.136752+00', 7247, 3, NULL, 'ace', '1-8::
    1s lead down below 2s & turn with RH,
9-16::
    1s dance DoSiDo & turn RH to end in 2nd place
17-32::
    2s repeat above Fig
33-40::
    1s cast 1 place, lead up the middle, turn RH to 1st places
41-48::
    1s dance DoSiDo & cross over RH to change places
49-64::
    1s turn next dancer on sides RH 1.1/2 times, turn 3rd dancer LH
    1.1/2 times, turn 4th dancer RH 1.1/2 times & cross RH to 4th places', 0);
INSERT INTO 'dancecrib' VALUES (8653, '2015-02-13 12:48:28.519165+00', '2023-02-04 01:23:16.16355+00', 15621, 3, NULL, 'ace', '1-8::
    1s cross down into reels of 3 on opp. side (6 bars), 2s cast up
    while1s dance down to finish back-to-back in middle facing opp.
    sides
9-16::
    Set twice as in Double Triangles, 1s cast round 1st corners, meet,
    pull back RSH to finish back-to-back in middle, 1M facing down/1L up
17-24::
    Set twice as in Double Triangles, 1s cast round 4th corners to
    finish in 2nd place own sides
25-32::
    2s+1s+3s circle 6H round and back', 0);
INSERT INTO 'dancecrib' VALUES (13367, '2020-11-02 01:22:28.453864+00', '2023-02-04 01:23:16.181762+00', 16159, 3, NULL, 'ace', '1-8::
    1s set, 1L casts behind 2L+3L + dances up middle to place _while_ 1M
    dances down middle & casts up behind 3M+2M to place
9-16::
    1s+2s set, pull back RSh & chase 1 place round clockwise; 1s+2s
    dance 1/2 RH across, 1M+2L set _while_ 1L+2M change places RH.  2 1
    3
17-24::
    1s dance Fig 8 on own side dancing under arches made by 2s & 3s (1s
    dance down between 3s to start) Bar 1: 3s make arch, Bar 5: 2s make
    arch, Bar 8: 2s+3s drop hands.  1s end in centre, 2nd place facing
    up ready for …
25-32::
    2s+1s+3s dance Allemande.  End 3 1 2

{{explanation}}
Note:	Dance 3 times as Strathspey then 3 times as Reel', 0);
INSERT INTO 'dancecrib' VALUES (8005, '2013-08-21 08:31:54.281396+00', '2023-02-04 01:23:16.214056+00', 7252, 3, NULL, 'ace', '1-8::
    1s+2s also 3s+4s dance Diamond Poussette
9-16::
    1s lead down the middle & back _while_ 2s+3s+4s set on sides with
    hands joined making arches
17-24::
    1s dance down between 2s, out behind 3s, up between 3s, out & behind
    2s to top & face down, 2s+3s+4s join nearer hands with partners
    facing up
25-32::
    All set with 1s passing each couple LSh until reaching the bottom &
    all turn 2H', 0);
INSERT INTO 'dancecrib' VALUES (8654, '2015-02-13 12:48:28.538891+00', '2023-02-04 01:23:16.241156+00', 12695, 3, NULL, 'ace', '1-8::
    1s cross RH & cast 2 places (2s+3s step up 3-4).  2s cross RH & cast
    2 places (3s+1s step up 7-8)
9-12::
    1s followed by 2s dance 1/2 Fig 8 crossing up between 3s.  1s meet
    in middle in 3rd place facing up
13-16::
    1s dance up (as 2s dance down to 3rd place), cast to 2nd place own
    sides   3 1 2
17-24::
    All set, 3s+1s+2s turn 1/2 RH to face clockwise, chase clockwise to
    own sides, 1s finish facing 1st corners
25-28::
    1s set to 1st corner, set to 2nd corner, finishing back-to back (1M
    facing up, 1L facing down)
29-32::
    1s dance out of ends of set, cast to Left into 2nd place own sides', 0);
INSERT INTO 'dancecrib' VALUES (8912, '2015-09-21 22:02:06.130452+00', '2023-02-04 01:23:16.292144+00', 16761, 3, NULL, 'ace', '1-8::
    1s+2s+3s set & cross RH, repeat back to places
9-16::
    1s lead down the middle then lead up to 2nd places
17-24::
    2s+1s turn (Men RH, Ladies LH), 1s+3s turn (Men LH, Ladies RH)
25-32::
    2s+1s+3s dance reflection reels of 3 on sides with 2s dancing in &
    down to start (2nd time through the 1s continue the reel into 4th
    place)', 0);
INSERT INTO 'dancecrib' VALUES (14304, '2021-09-08 00:22:27.70214+00', '2023-02-04 01:23:16.307733+00', 20435, 3, NULL, 'ace', '1-8::
    1s+2s+3s Adv+Ret; 1s dance in & cast (2s step up)
9-16::
    2s+1s+3s Adv+Ret; 1s turn RH (birl) to finish facing 1st corners
17-32::
    1s dance Corner Chain with 1st & 2nd corners:
::
    1s change pl RH with 1st crnrs, 1st crnrs turn LH in centre & return
    to places giving RH to 1s who turn LH in centre to face 2nd crnrs
::
    1s change places RH with 2nd crnrs, 2nd crnrs turn LH in centre &
    return to places giving RH to 1s & 1s end with a 1/2 turn LH to 2nd
    place own sides.  End 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (12431, '2019-12-05 01:32:40.783805+00', '2023-02-04 01:23:16.327021+00', 17523, 3, NULL, 'ace', '1-8::
    1s set, cross down RH to 2nd place opp sides to face 1st corners (2s
    step up); 1s+corners set, turn 3/4 RH to 1L between 2s facing down,
    1M between 3s facing up
9-16::
    1s turn 1.1/4 LH to face 2nd corners; 1s+corners set, turn 3/4 LH to
    1M between 2s facing down, 1L between 3s facing up
17-24::
    All Adv+Ret; 1/2 diag R&L (1M+3M & 1L+2L cross RH to start). End 1L
    between 2M+3M facing down, 1M between 2L+3L facing up
25-32::
    All set, all cross RH with partner; all chase clockwise 2 places, 2s
    at top, 1s in 2nd place opp sides & 3s in 3rd place, 1s cross RH. 2
    1 3', 0);
INSERT INTO 'dancecrib' VALUES (8006, '2013-08-21 08:31:54.377719+00', '2023-02-04 01:23:16.351101+00', 10150, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across 1/2 way, 2s turn 1.1/2 times to own sides
    _while_ 1s turn 1.3/4 times to face 1st corners
9-16::
    1s dance 1/2 diag reel of 4 with 1st corners, pass RSh & dance 1/2
    diag reel of 4 with 2nd corners 1s ending 2nd place opposite sides
17-24::
    3s+1s+2s set, 1L+3M also 1M+2L change places RH, 1L+2L also 1M+3M
    change places LH on sides, top 3 couples set
25-32::
    1L+3L also 1M+2M change places RH, 1L+2M also 1M+3L change LH on
    sides, 2s+1s+3s set & 1s cross RH to own sides', 0);
INSERT INTO 'dancecrib' VALUES (8007, '2013-08-21 08:31:54.387734+00', '2023-02-04 01:23:16.379013+00', 7257, 3, NULL, 'ace', '1-8::
    1s+2s+3s dance reflection reels of 3 on own sides (1s in & down to
    start)
9-16::
    1s followed by 2s lead down for 3 steps, 2s divide to follow 1s back
    to top, 1s cast to 2nd place as 2s dance to top
17-24::
    2s+1s dance 1/2 double Fig of 8 (1s cross up to start), 1s+3s dance
    1/2 double Fig of 8 (1s cross down to start) _while_ 2s set & cross
    RH
25-32::
    2s+1s circle 4H round to left _while_ 3s set & cross RH, 1s+3s
    circle 4H round to right', 0);
INSERT INTO 'dancecrib' VALUES (9254, '2016-06-16 22:42:33.772171+00', '2023-02-04 01:23:16.420796+00', 12959, 3, NULL, 'ace', '1-8::
    1s lead down below 3s, lead up , dance out between 2s & 3s, cast up
    to original places facing in/down
9-16::
    1s+3s dance double Fig 8 round 2s (1s cross down, 3s cast  up)
17-24::
    1s+2s circle 4H round to Left.  1s+2s set, 1s cast to 2nd place as
    2s dance up to top & face out
25-32::
    Mirror reels of 3 on sides (2s out/down, 1s in/down, 3s out/up)  2 1
    3 4', 0);
INSERT INTO 'dancecrib' VALUES (8008, '2013-08-21 08:31:54.395845+00', '2023-02-04 01:23:16.445212+00', 10961, 3, NULL, 'ace', '1-8::
    2s/3s cross up/down & cast to 2nd/3rd places, 1s+2s also 3s+4s dance
    RH across
9-16::
    All dance reels of 4 on sides with 2s+3s ending 1/2 turn 2H on sides
    to face across
17-24::
    All circle 8H round & back
25-32::
    1s/4s cross RH & cast to 2nd/3rd pl _while_ 2s/3s set & cross
    up/down, 4s followed by 1s lead down (LH) between 3s & cast up to
    2nd/3rd pl.  2 4 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8009, '2013-08-21 08:31:54.403967+00', '2023-02-04 01:23:16.472165+00', 7260, 3, NULL, 'ace', '1-8::
    1s+4s also 3s+6s set facing in diagonally, 1M+4L also 3M+6L 3/4 turn
    RH, 1M & 4L dance out thru 4M/6M places as 1L & 4L dance out thru
    4L/6L places & cast back to place _while_ 1L & 3L cast to 4L/6L
    places as 4M & 6M cast up to 1M/3M places & 4M+1L also 6M+4L 3/4
    turn RH (similar to MacLeod''s Fancy)
9-16::
    1s+2s+3s also 4s+5s+6s dance reels of 3 on sides (1s+2s also 5s+6s
    pass RSh to start)
17-24::
    1s+2s also 3s+4s also 5s+6s dance reels of 4 across (1M+2L, 3M+4L &
    5M+6L pass LSh to start) & 1L+2M, 3L+4M & 5L+6M omit last LSh pass
    to all end in original places
25-32::
    1s+2s & 3s+4s & 5s+6s dance RH across 1/2 way, set & 2s & 5s (now
    end couples) cross LH _while_ 1s+4s & 3s+6s dance LH across 1/2 way
    & all set', 0);
INSERT INTO 'dancecrib' VALUES (13539, '2021-01-09 01:22:16.510756+00', '2023-02-04 01:23:16.714219+00', 17703, 3, NULL, 'ace', '1-8::
    1s+2s dance RH across & LH back
9-16::
    1s+3s set advancing slightly to the right, join hands in a line in
    the middle & set, 1s+3s turn partner 3/4 LH to finish on own sides 1
    2 3. All set
17-24::
    2s followed by 1s dance full Fig of 8 round 3s, 2s dancing up to 1st
    place 2 1 3
25-32::
    1s lead down for 2 bars, Lady turns to right under arms _while_ Man
    dances to the left to finish both facing up (Lady on Man''s left). 1s
    lead up, retaining right hands, turn round into 2nd place opposite
    sides facing out
33-40::
    2s+1s+3s dance LSh reels of 3 on opp sides (1L+3M, 1M+2L pass LSh to
    begin). 1s cross to 2nd place own side bars 39-40  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8011, '2013-08-21 08:31:54.420117+00', '2023-02-04 01:23:16.733736+00', 7265, 3, NULL, 'ace', '1-8::
    1s+2s petronella turn & set, 3/4 turn RH into 1/2 RH across
9-16::
    1s cross down RH through 3rd place to dance reel of 3 with 2s+3s on
    opp sides (2s+3s start passing RSh on Ladies'' side & LSh on Men''s
    side). 1s end facing 2nd crnrs
17-24::
    1s dance 1/2 reel of 4 with 2nd corners, pass LSh round each other
    to 1/2 reel with 1st corner & passing LSh 1M faces 3s (at top) 1L
    faces 2s
25-32::
    3s+1s+2s set & 3s+1M also 1L+2s circle 3H round to left, 1M leads 3s
    down Ladies side _while_ 1L leads 2s up Men''s side & circle 6H round
    1/2 way.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (11005, '2018-08-17 07:53:14.332317+00', '2023-02-04 01:23:16.763437+00', 18410, 3, NULL, 'ace', '1-8::
    1s+2s dance the Tourbillon
9-12::
    1s set advancing to 1st corners & turn corners 2H into lines of 3
    across, 1L between 2s, 1M between 3s
13-16::
    1s set advancing to 2nd corners & turn corners 2H to end 1s in 2nd
    place opp sides
17-24::
    1s pass LSh to dance 1/2 diag reel of 4 with 3rd corners, pass LSh
    to dance 1/2 diag reel of 4 with 4th corners. 1s end in 2nd place
    own sides
25-30::
    1L+3s (at top) & 1M with 2s (at bottom) dance 3H round to Left (3
    bars), 1s drop LH and 1L leads 3s down Ladies'' side, 1M leads 2s up
    Men''s side into circle 6H 1/2 round to Left.  2 (1) 3
31-32::
    1s cross RH to own sides. 2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8012, '2013-08-21 08:31:54.428209+00', '2023-02-04 01:23:16.820925+00', 7267, 3, NULL, 'ace', '1-8::
    1s set, cross down to 2nd place opposite sides, cast round to right
    & change places with partner RH to face up/down
9-16::
    1s dance reels of 3 across (RSh to 3rd corner - 1M with 2s & 1L with
    3s) & 1s end in lines across 1M between 2s &1L between 3s
17-24::
    2s+1s+3s set, all change pl RH with opposite person, set, 1s cast
    clockwise to outside 2nd place own sides as 2s+3s full turn 2H on
    sides & face out
25-32::
    Men also Ladies circle 3H round to left on own sides & 2L/3M lead
    into 6H round to left to places.  3 1 2', 0);
INSERT INTO 'dancecrib' VALUES (13778, '2021-03-02 01:22:31.89565+00', '2023-02-04 01:23:16.841138+00', 13513, 3, NULL, 'ace', '{{explanation}}
2 chords:  2nd chord 1s & 3s face down, 2s & 4s face up

1-8::
    1s+2s also 3s+4s set &  turn RH, 2s face down, 3s face up;  2s+3s
    set & turn RH (Men''s side right arm elbow turn as »Buchan Eightsome
    Reel«)
9-16::
    1s cross, cast (2s step up); 1s cross, cast (3s step up).  2 3 1 4
17-20::
    1M sets advancing to 4L & they change places RH _while_ 2s+3s dance
    RH across
21-24::
    1L sets advancing to 4M & they change places RH _while_ 2s+3s dance
    LH across.  2 3 (4) (1)
25-32::
    1s dance 1/2 Fig 8 up round 4s; 4s dance1/2 Fig 8 up round 3s.  End
    2 3 4 1', 0);
INSERT INTO 'dancecrib' VALUES (8013, '2013-08-21 08:31:54.447222+00', '2023-02-04 01:23:16.86543+00', 13590, 3, NULL, 'ace', '1-8::
    1s cross down between 2s+3s & cast to right to face 2L/3M, dance 1/2
    LSh reel of 3 across (1L with 2s, 1M with 3s) & end facing 1st
    corner (pstn)
9-16::
    1s dance 1/2 diagonal reel of 4 & pass RSh to face 2nd corner
    (pstn), 1s dance 1/2 diagonal reel & end in double triangle
    positions (facing opp sides)
17-24::
    1s dance Double Triangles & end in middle facing opposite sides RSh
    to RSh
25-32::
    1s dance LH across (M with 3s at top & L with 2s), 1M followed by
    3M+3L also 1L followed by 2L+2M pass RSh diagonally across to change
    ends & loop round to right to end on own sides.  2 1 3', 0);
INSERT INTO 'dancecrib' VALUES (8014, '2013-08-21 08:31:54.455333+00', '2023-02-04 01:23:16.891104+00', 11554, 3, NULL, 'ace', '1-8::
    1s dance Inveran reels with 2s+3s & end facing 2s
9-16::
    1s+2s set, Petronella-in-tandem to sides, cross RH with other
    partner & chase 1 place clockwise
17-24::
    2s+1s dance RH across, 1+3s dance LH across
25-32::
    1s cast LSh round 1st corners & LSh round 3rd corners to 2nd place
    own sides', 0);
INSERT INTO 'dancecrib' VALUES (8015, '2013-08-21 08:31:54.465273+00', '2023-02-04 01:23:16.912607+00', 4799, 3, NULL, 'ace', '1-8::
    1s turn RH & cast 1 place (2s step up), 1s turn LH to face 1st
    corners
9-12::
    1s 1/2 turn 1st corners RH _while_ 2nd corners set. 1s+2nd corners
    chase 1 place clockwise round _while_ 1st corners 3/4 turn LH to
    face 1s again (on "2nd corners diagonal")
13-16::
    Repeat bars 9-12 from new positions to end 1s facing 3rd corner
    positions
17-24::
    Repeat bars 9-16 (same people - opposite positions) & 1s end turning
    LH to 1M below 1L in centre facing 1st corners
25-32::
    1s dance RH across (1L with 2s at top, 1M with 3s), pass RSh & dance
    LH across with other couple 2 3 1
::
    Note:   Bars 9-24 The path of 1s is - OUT to 1st corner, IN from 4th
    corner, OUT to 3rd corner, IN from 2nd corner (positions). 1s & 1st
    corner people are moving in/out _while_ 2nd corner people set &
    chase throughout.', 0);


--
INSERT INTO 'dancecribsource' VALUES (6, '2012-07-15 14:57:13.919859+00', '2012-07-16 09:23:51.651886+00', 'Skua Dubh', 'Tim Hoffmann', 'sd', '', '', 2);
INSERT INTO 'dancecribsource' VALUES (4, NULL, '2013-01-12 21:53:08.734978+00', 'Keith Rose''s Diagrams', 'Keith Rose', 'kr', '', 'keith@krose.plus.com', 3);
INSERT INTO 'dancecribsource' VALUES (2, NULL, '2013-04-10 06:17:55.982017+00', 'SCDDB Contributed Cribs & Diagrams', 'SCDData', 'scddb', 'http://my.strathspey.org/dd/', 'webmaster@my.strathspey.org', 1);
INSERT INTO 'dancecribsource' VALUES (7, '2013-04-10 06:23:39.038334+00', '2013-04-10 06:23:39.038338+00', 'Heiko''s Diagrams', 'Heiko', 'heiko', '', 'heiko.schmidt@univie.ac.at', 4);
INSERT INTO 'dancecribsource' VALUES (3, NULL, '2014-02-10 10:29:52.95737+00', 'MiniCribs', 'MiniCrib', 'minicrib', 'http://www.minicrib.org.uk/', 'minicrib@minicrib.org.uk', NULL);
INSERT INTO 'dancecribsource' VALUES (1, NULL, '2018-03-14 22:52:41.210241+00', 'E-cribs', 'Eric Ferguson, Roland Telle, Murrough Landon', 'etf', 'http://my.strathspey.org/u/anselm/stories/etf-cribs/', 'team@e-cribs.org', NULL);
INSERT INTO 'dancecribsource' VALUES (9, '2018-07-25 18:19:34.351895+00', '2018-07-25 18:19:47.741957+00', 'Anton Korobeynikov''s Diagrams', 'Anton Korobeynikov', 'ak', '', 'anton@korobeynikov.info', 5);
INSERT INTO 'dancecribsource' VALUES (10, '2021-03-22 21:33:13.158876+00', '2021-03-22 21:38:00.574548+00', 'The MacNab Dances in Diagrams (Angus Henry)', 'Angus Henry', 'macnab_ah', '', 'admin@strathspey.org', 1);
INSERT INTO 'dancecribsource' VALUES (11, '2021-11-14 22:19:39.721901+00', '2021-11-14 22:19:39.721901+00', 'Yutaka Shimizu''s Diagrams', 'Yutaka Shimizu', 'ys', '', 'yutaka.shimizu69@mbr.nifty.com', NULL);
INSERT INTO 'dancecribsource' VALUES (12, '2022-11-27 17:14:25.254111+00', '2022-11-27 17:14:34.373697+00', 'Viktor''s Diagrams', 'Viktor Lehmann', 'vl', '', 'info@tone2tone.com', 7);


--
INSERT INTO 'dancesformationsmap' VALUES (2, 5, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5, 11, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6, 12, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11, 17, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13, 19, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15, 23, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16, 25, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17, 28, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20, 31, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22, 33, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23, 34, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24, 36, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25, 37, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (26, 39, 41, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28, 42, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (35, 58, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (39, 65, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13164, 10508, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43, 74, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44, 75, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (50, 84, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (51, 85, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (52, 86, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (60, 102, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (63, 108, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (65, 110, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (66, 113, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (70, 118, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (71, 119, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (72, 120, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (73, 121, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (74, 122, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (75, 125, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13165, 10508, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (81, 136, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (82, 138, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (86, 142, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (87, 143, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (88, 145, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (89, 147, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (90, 149, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12963, 5813, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12965, 7515, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12966, 6213, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12968, 6335, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12970, 6351, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12971, 8713, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17685, 6869, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17687, 6194, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17688, 6194, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17689, 5353, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17690, 3078, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17691, 5294, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17692, 2031, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17693, 2031, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17694, 125, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17695, 5112, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17696, 5112, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17697, 5112, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17698, 944, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17699, 944, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17700, 6480, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17701, 6480, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17702, 6480, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29201, 17007, 94, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (17719, 3090, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17720, 3090, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10932, 9968, 91, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (10933, 9968, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22113, 9968, 58, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (22114, 9968, 49, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3, 6, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (95, 156, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (96, 158, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (101, 165, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (106, 182, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (58, 97, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (114, 193, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (115, 194, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (118, 201, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (121, 211, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (125, 215, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (127, 221, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (130, 227, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (68, 116, 65, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (62, 105, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17686, 423, 376, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (98, 161, 257, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34, 57, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (112, 190, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (79, 132, 79, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (105, 178, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (113, 192, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (132, 231, 78, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (17684, 1912, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1, 2, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30, 44, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (69, 117, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (17716, 2393, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (117, 200, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17717, 2393, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17718, 2393, 273, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27, 40, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22117, 12983, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (128, 222, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (116, 195, 54, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (46, 78, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (83, 139, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32, 51, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22115, 14403, 105, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (18, 29, 86, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31, 45, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12967, 6234, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (110, 188, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (103, 173, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41, 67, 52, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (12, 18, 10, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22106, 14401, 262, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (134, 233, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (136, 236, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (138, 238, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (139, 239, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (141, 244, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (144, 247, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (145, 248, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12962, 5410, 58, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (111, 189, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (108, 184, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (91, 150, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9, 15, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (122, 212, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31398, 18245, 92, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (76, 128, 296, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (55, 91, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (104, 174, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (67, 114, 83, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (4, 9, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21, 32, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (49, 83, 114, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45, 76, 45, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (64, 109, 58, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (56, 92, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10, 16, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8, 14, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33, 55, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (53, 88, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (59, 98, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (94, 155, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (119, 202, 30, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (124, 214, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (85, 141, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17714, 6932, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12969, 6336, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12964, 5904, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (126, 218, 2, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (100, 164, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36, 59, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (137, 237, 19, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (80, 135, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (61, 103, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48, 82, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47, 81, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (135, 235, 103, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (84, 140, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17703, 11899, 230, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (146, 251, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (151, 267, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (153, 272, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (159, 284, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (163, 290, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (166, 293, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (37, 60, 86, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (123, 213, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14, 20, 6, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38, 64, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (120, 209, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (109, 185, 18, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (131, 230, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7, 13, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17711, 2704, 131, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12961, 5176, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (168, 296, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (169, 298, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (171, 302, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (172, 305, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (174, 309, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (178, 315, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (180, 317, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (184, 325, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12937, 8677, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12940, 3752, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12941, 3822, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12942, 7449, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12943, 3960, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12946, 10130, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12947, 4275, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (12959, 5067, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12960, 8694, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12973, 8716, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12974, 6855, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12976, 6908, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12978, 6940, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12981, 7154, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12984, 5086, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12985, 5086, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12986, 5626, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12948, 4304, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22112, 9946, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (150, 265, 84, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (188, 330, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (189, 331, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (196, 341, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (197, 343, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (198, 347, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (199, 348, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (200, 350, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (203, 356, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (204, 360, 79, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (205, 362, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (206, 363, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (209, 369, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (211, 372, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (213, 375, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (216, 381, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (221, 391, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (223, 393, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (230, 402, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (231, 403, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (232, 408, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (233, 409, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (236, 415, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (238, 425, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (239, 426, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (244, 434, 79, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (245, 435, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (246, 436, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (247, 437, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (251, 446, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (253, 449, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (256, 459, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (261, 466, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (263, 468, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (264, 469, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (265, 470, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (225, 395, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (187, 329, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (177, 314, 55, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (12992, 5395, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (271, 486, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (273, 490, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (274, 493, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12944, 4010, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (147, 261, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (164, 291, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (160, 286, 89, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (182, 319, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (181, 318, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12982, 3715, 188, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (207, 364, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (234, 410, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12958, 4925, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (212, 373, 69, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (269, 476, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31901, 13826, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (260, 465, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22119, 12983, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (208, 367, 16, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12979, 6956, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (179, 316, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (149, 264, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (202, 355, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (143, 246, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12972, 6640, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (133, 232, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (192, 336, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (252, 447, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (227, 398, 39, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (218, 385, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (156, 278, 45, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (255, 457, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (186, 328, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (275, 494, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (277, 496, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12991, 1999, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12993, 5663, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13033, 10489, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13034, 10489, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13035, 10489, 77, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13036, 10489, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13037, 10490, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13038, 10490, 148, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (259, 464, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (258, 463, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (176, 313, 93, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (12975, 6885, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (162, 289, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (152, 271, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (183, 324, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (210, 371, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (224, 394, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (228, 399, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (242, 431, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (262, 467, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (201, 352, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12956, 4816, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (167, 295, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (140, 240, 84, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13333, 10540, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12994, 10475, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12945, 4152, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12949, 8968, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12980, 7016, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12977, 6913, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (235, 414, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (194, 339, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12957, 4865, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12955, 4809, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12953, 4752, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12952, 4677, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12951, 4565, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12939, 3678, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12938, 3317, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12936, 2742, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12987, 1959, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (157, 281, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (241, 430, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (268, 475, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (267, 474, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12990, 443, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (250, 442, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (249, 440, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (248, 439, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (237, 420, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (229, 400, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (226, 397, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (217, 382, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (215, 378, 56, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (214, 377, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (191, 335, 79, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (185, 326, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (173, 306, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12954, 4800, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13039, 10490, 27, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (22120, 930, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (280, 500, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (282, 507, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (286, 514, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (287, 515, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (288, 517, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (289, 518, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (291, 520, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (295, 525, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (296, 528, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (170, 301, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (240, 427, 300, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (148, 262, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (165, 292, 18, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (220, 390, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (266, 473, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (283, 508, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12996, 10476, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (154, 275, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12950, 4411, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (257, 461, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (298, 531, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (299, 532, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (306, 552, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (307, 553, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (308, 554, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (309, 555, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (313, 561, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (314, 563, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (315, 564, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (317, 569, 89, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (322, 575, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (324, 577, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (326, 582, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (329, 591, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (330, 593, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (339, 607, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (340, 608, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (342, 612, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (343, 613, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (345, 616, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (346, 622, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (349, 628, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (351, 631, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (352, 632, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (353, 634, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (354, 635, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (356, 639, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (359, 643, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (360, 646, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (362, 648, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (366, 653, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (369, 657, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (371, 661, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (344, 615, 8, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (293, 522, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13004, 10479, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13005, 10479, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13006, 10479, 198, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13009, 10481, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13010, 10481, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13019, 10484, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13020, 10484, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13021, 10485, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13022, 10485, 82, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (13023, 10486, 198, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13024, 10486, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13027, 10487, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13028, 10487, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13029, 10487, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (284, 509, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13040, 10490, 221, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13041, 10490, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13042, 10455, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13043, 10455, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13044, 10455, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (328, 588, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22121, 930, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12999, 10477, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13000, 10477, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13002, 10478, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13003, 10478, 197, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (357, 640, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31402, 18246, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13077, 7671, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (281, 504, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (276, 495, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (337, 604, 91, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (332, 595, 189, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13081, 8671, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13082, 8671, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12997, 693, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12998, 693, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13065, 9445, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13066, 9445, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13063, 9444, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13064, 9444, 365, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13078, 7671, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13079, 7671, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (358, 642, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (316, 567, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (294, 523, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13073, 10498, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13074, 10498, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (321, 573, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13071, 10496, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (310, 556, 69, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13075, 10499, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13076, 10499, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13059, 9437, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13058, 9436, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13072, 10496, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (374, 666, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (375, 668, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (376, 669, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (380, 678, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (387, 688, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (388, 689, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (396, 706, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (404, 718, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (405, 719, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (406, 720, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (407, 728, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13090, 8702, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (347, 624, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (365, 652, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (320, 572, 87, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (300, 533, 120, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (279, 498, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13007, 10480, 4, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (311, 557, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (318, 570, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (439, 784, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (301, 535, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (323, 576, 125, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (348, 625, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (395, 704, 41, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (336, 603, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (327, 583, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (285, 513, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13050, 10494, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13045, 10491, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (399, 712, 51, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13068, 9451, 30, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13069, 9451, 134, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (389, 690, 16, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (410, 735, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (403, 717, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (386, 687, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (379, 672, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (378, 671, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (372, 662, 96, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (370, 660, 45, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (368, 655, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (367, 654, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (364, 650, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (350, 629, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (333, 596, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (325, 578, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (319, 571, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (304, 547, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (303, 543, 9, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (302, 540, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (297, 530, 265, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (290, 519, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13047, 10492, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13008, 10480, 9, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (338, 605, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (411, 736, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (452, 816, 324, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (414, 740, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (415, 741, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (417, 749, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (423, 757, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (424, 758, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (430, 771, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (433, 777, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (438, 783, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (440, 789, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (441, 792, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (448, 804, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (453, 817, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (457, 826, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (463, 835, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (401, 714, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13030, 10488, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (292, 521, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (335, 599, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (363, 649, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (392, 698, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13060, 9442, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13054, 9440, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13053, 9438, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (361, 647, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13015, 10483, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13016, 10483, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13017, 10483, 52, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (355, 636, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (451, 815, 185, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (426, 762, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (425, 760, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22122, 714, 134, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22123, 9970, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (444, 796, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (464, 840, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13131, 8842, 183, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (473, 856, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (475, 864, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (481, 879, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (494, 901, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13132, 8842, 7, 3, 6);
INSERT INTO 'dancesformationsmap' VALUES (496, 903, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (421, 754, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (398, 711, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (381, 679, 81, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (435, 779, 55, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (503, 911, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (506, 918, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (508, 922, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (509, 923, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (514, 933, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (391, 696, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (409, 731, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (501, 909, 311, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (431, 773, 80, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (493, 900, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (482, 881, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (487, 891, 20, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (450, 812, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (518, 939, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13084, 8671, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (480, 878, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (383, 682, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (412, 738, 164, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (455, 820, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (489, 894, 234, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (478, 873, 13, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13119, 10166, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (484, 887, 265, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (505, 917, 85, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (331, 594, 101, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13123, 5593, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (479, 877, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (427, 763, 95, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (390, 691, 90, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (419, 751, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13091, 8702, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13092, 8702, 112, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (13093, 8702, 71, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (418, 750, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (460, 829, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (522, 943, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (524, 947, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (525, 949, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (529, 957, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (532, 960, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (535, 967, 41, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (546, 990, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (548, 993, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (549, 996, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (553, 1005, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (554, 1006, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (561, 1023, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (567, 1031, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (569, 1036, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13162, 10508, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (572, 1043, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (573, 1044, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13163, 10508, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13102, 10305, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (13104, 10299, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (551, 1001, 281, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (483, 886, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (422, 755, 85, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (377, 670, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (456, 824, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (442, 794, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (492, 899, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (397, 707, 226, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (373, 665, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (385, 686, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (446, 800, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (466, 843, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (497, 904, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (552, 1004, 43, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (564, 1027, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (498, 905, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (485, 888, 80, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (434, 778, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (420, 752, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13115, 4494, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (13116, 4494, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13101, 10308, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13133, 10300, 37, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (13098, 8502, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13099, 8502, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13094, 9200, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13095, 9200, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13100, 8502, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13086, 10367, 55, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (443, 795, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (472, 855, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (516, 935, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13105, 3559, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13106, 3559, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (13107, 3559, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13109, 4048, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13110, 4048, 7, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (502, 910, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (568, 1034, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (565, 1029, 45, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (547, 992, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (539, 974, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (530, 958, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (537, 971, 3, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (520, 941, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (507, 919, 120, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (486, 889, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (477, 871, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (476, 867, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (471, 853, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (470, 852, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (465, 841, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (454, 819, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (447, 803, 314, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (445, 797, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (428, 765, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (402, 715, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (384, 685, 37, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (382, 680, 312, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13125, 359, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13158, 10507, 76, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (461, 830, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (459, 828, 79, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (468, 849, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (542, 981, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (512, 930, 35, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22124, 9905, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13148, 433, 168, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13149, 433, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13150, 433, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (575, 1049, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (578, 1052, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (579, 1057, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (585, 1067, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (588, 1070, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (593, 1083, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (598, 1090, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (601, 1094, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (603, 1098, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (606, 1101, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (608, 1109, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (610, 1115, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (612, 1122, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (615, 1130, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (617, 1132, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (618, 1135, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (619, 1137, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (620, 1138, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (583, 1064, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (437, 782, 86, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (499, 907, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (517, 936, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (597, 1089, 17, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (500, 908, 78, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (31821, 13913, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (490, 895, 307, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13103, 10500, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13140, 10502, 43, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (474, 862, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13111, 4283, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (558, 1019, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (581, 1059, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (533, 962, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (550, 998, 12, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (527, 954, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (515, 934, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (511, 925, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (469, 850, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (462, 834, 75, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (458, 827, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (429, 767, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (621, 1140, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (623, 1144, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (625, 1146, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (628, 1149, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (629, 1150, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (634, 1157, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (636, 1159, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (638, 1166, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (639, 1168, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (642, 1175, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (644, 1177, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (647, 1184, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (648, 1185, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (562, 1024, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (635, 1158, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (654, 1199, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (659, 1208, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (660, 1209, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (661, 1210, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (662, 1212, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (663, 1213, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (665, 1216, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13166, 8846, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13167, 8846, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13168, 8846, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (495, 902, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (543, 984, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (614, 1128, 9, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (536, 970, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13169, 10509, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (652, 1197, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (582, 1062, 324, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13170, 10509, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (605, 1100, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (627, 1148, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (563, 1025, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (531, 959, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (571, 1040, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (523, 945, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13138, 1873, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (653, 1198, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31403, 18246, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (587, 1069, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31404, 18246, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (534, 965, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (504, 916, 307, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13134, 6209, 260, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (657, 1204, 90, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (656, 1202, 176, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (626, 1147, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (580, 1058, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (576, 1050, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (574, 1045, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (555, 1007, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (566, 1030, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (519, 940, 12, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (13174, 7657, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13175, 7657, 46, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13176, 7657, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13177, 7657, 182, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13186, 10511, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13161, 8376, 225, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13159, 8386, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13160, 8386, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (666, 1217, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (668, 1222, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (675, 1239, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (676, 1241, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (680, 1249, 101, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (683, 1254, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (691, 1276, 80, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (694, 1279, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (698, 1284, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (672, 1231, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (673, 1234, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (693, 1278, 21, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (643, 1176, 56, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (13146, 10505, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13144, 10504, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (609, 1114, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (528, 956, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (544, 985, 43, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (526, 950, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (592, 1077, 37, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (557, 1013, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (759, 1413, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (697, 1283, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (591, 1075, 4, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (637, 1162, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13199, 10514, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (577, 1051, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13151, 10506, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13152, 10506, 45, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13153, 10506, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (658, 1207, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13128, 10501, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (467, 845, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (611, 1119, 83, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (13181, 8946, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13182, 8946, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13183, 8946, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (604, 1099, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (682, 1252, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (645, 1180, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (679, 1246, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (649, 1192, 27, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (664, 1215, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (640, 1171, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (650, 1194, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (632, 1154, 37, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (631, 1153, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (630, 1152, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (622, 1141, 24, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (616, 1131, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (607, 1103, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (602, 1096, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (600, 1093, 109, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (594, 1084, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (589, 1072, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (586, 1068, 30, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (590, 1073, 181, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (560, 1022, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (559, 1020, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (556, 1008, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (521, 942, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13155, 10507, 112, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13187, 10512, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13188, 10512, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13189, 10512, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13194, 10513, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13195, 10513, 56, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13196, 10513, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (701, 1291, 79, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (702, 1294, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (704, 1297, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (705, 1299, 65, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (707, 1301, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (710, 1312, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (717, 1334, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (718, 1336, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (720, 1340, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (722, 1346, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (723, 1347, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (724, 1348, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (726, 1351, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (729, 1360, 46, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (731, 1365, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (735, 1369, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (736, 1373, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (737, 1374, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (740, 1377, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (742, 1379, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (743, 1380, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (744, 1381, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (747, 1386, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (751, 1391, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13213, 8928, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13214, 8928, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13215, 8928, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (685, 1260, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (738, 1375, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13235, 10517, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13236, 10517, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13237, 10517, 17, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13238, 10517, 69, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (687, 1264, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (678, 1244, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (762, 1418, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (684, 1259, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (570, 1039, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31822, 13913, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (599, 1091, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (756, 1405, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13180, 1390, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (709, 1307, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (699, 1285, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (677, 1242, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (655, 1200, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (651, 1195, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (646, 1182, 273, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (624, 1145, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (595, 1085, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (541, 977, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (763, 1422, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (764, 1423, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (688, 1267, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (771, 1433, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (772, 1436, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (773, 1440, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13172, 9231, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (667, 1218, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22125, 988, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (769, 1430, 77, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (692, 1277, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (690, 1274, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (761, 1417, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (749, 1388, 7, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (670, 1227, 119, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (671, 1229, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13220, 8923, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13221, 8923, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (757, 1406, 214, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (712, 1318, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13184, 10510, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13185, 10510, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (754, 1399, 79, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (752, 1393, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (741, 1378, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (713, 1319, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (696, 1282, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (681, 1251, 38, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13206, 10515, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13207, 10515, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13208, 10515, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (13228, 8193, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13229, 8193, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (700, 1288, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (748, 1387, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (765, 1424, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (674, 1235, 273, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (774, 1442, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (775, 1444, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (778, 1448, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (779, 1450, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (786, 1459, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31275, 18232, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (806, 1490, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (807, 1497, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (816, 1514, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (817, 1517, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (820, 1523, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (853, 1582, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (823, 1527, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (825, 1532, 79, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (827, 1536, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (829, 1542, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (832, 1545, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (834, 1548, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (840, 1557, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (845, 1565, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (849, 1574, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (689, 1273, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (791, 1469, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (750, 1389, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13231, 10516, 81, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13232, 10516, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (708, 1304, 64, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13203, 9046, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13204, 9046, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13202, 10514, 183, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (13216, 8941, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13217, 8941, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13211, 8937, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13212, 8937, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13209, 8929, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13210, 8929, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13227, 8178, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (13178, 1383, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (13179, 1383, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (715, 1329, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13239, 4677, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (848, 1573, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (596, 1087, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (706, 1300, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13240, 4677, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13241, 4677, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (843, 1560, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (811, 1505, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (846, 1567, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (844, 1564, 183, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (841, 1558, 173, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (837, 1553, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (833, 1547, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (822, 1526, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (808, 1498, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (800, 1481, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (795, 1474, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (790, 1467, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (784, 1457, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13197, 9343, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (777, 1446, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (770, 1431, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (767, 1427, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (758, 1409, 77, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (755, 1402, 145, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (739, 1376, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (733, 1367, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (732, 1366, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (728, 1359, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (727, 1353, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (716, 1331, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (703, 1296, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (695, 1280, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (669, 1223, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (734, 1368, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (814, 1511, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (725, 1349, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (780, 1451, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (824, 1528, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (819, 1520, 71, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (799, 1480, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (855, 1585, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (858, 1589, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (860, 1592, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (861, 1593, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (862, 1594, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (865, 1598, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (802, 1485, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (870, 1612, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (879, 1627, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (880, 1628, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (882, 1631, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (883, 1632, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (887, 1640, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (889, 1644, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (891, 1649, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (857, 1588, 134, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (842, 1559, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (892, 1650, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (893, 1651, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (896, 1658, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (897, 1659, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (898, 1663, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (901, 1667, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (903, 1669, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (909, 1682, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (910, 1683, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (911, 1693, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (915, 1699, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (917, 1702, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (904, 1672, 91, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (866, 1600, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13250, 4954, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (881, 1629, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (785, 1458, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (803, 1486, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (776, 1445, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (818, 1518, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (753, 1398, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (839, 1556, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (874, 1618, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31823, 13913, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13223, 8925, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (787, 1460, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (895, 1657, 45, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (719, 1338, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (788, 1461, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13265, 8107, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (876, 1622, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (913, 1697, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (906, 1678, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (902, 1668, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (888, 1643, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (885, 1635, 45, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (869, 1608, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (836, 1552, 63, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (826, 1535, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (821, 1524, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (797, 1476, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (781, 1452, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (768, 1428, 18, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (746, 1384, 202, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (745, 1382, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (686, 1261, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (760, 1415, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (783, 1456, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (838, 1554, 224, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (871, 1613, 188, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (793, 1471, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (792, 1470, 125, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13251, 7946, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13252, 7946, 66, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13253, 7946, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13266, 10147, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13267, 10147, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13268, 10147, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (872, 1615, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (907, 1679, 80, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (828, 1539, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (813, 1510, 58, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (798, 1477, 71, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (805, 1489, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (894, 1654, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (835, 1551, 7, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (782, 1454, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (918, 1704, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (919, 1705, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (920, 1706, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (924, 1714, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (927, 1721, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (929, 1725, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (931, 1727, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (932, 1728, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (934, 1730, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (937, 1738, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (939, 1745, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (940, 1746, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13287, 9975, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13288, 9975, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13289, 9975, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13290, 10526, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13291, 10526, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13292, 10526, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13298, 1798, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13299, 10527, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13300, 10527, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13301, 10527, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13302, 10527, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13303, 10527, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13304, 10528, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13305, 10528, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13306, 10528, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13307, 2359, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13308, 2359, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13309, 10529, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13310, 10529, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13311, 10529, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13312, 10530, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13313, 10530, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31272, 18232, 364, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31273, 18232, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31274, 18232, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13325, 10538, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13326, 10538, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13327, 2120, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (946, 1761, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (912, 1696, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13316, 2580, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (899, 1664, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (878, 1625, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (847, 1569, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (873, 1616, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (854, 1584, 39, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13257, 4784, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (801, 1483, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (859, 1591, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (914, 1698, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (948, 1765, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (950, 1768, 65, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13283, 10525, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13279, 10524, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13277, 10523, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13278, 10523, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13274, 10522, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13275, 10522, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13276, 10522, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13271, 10521, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13272, 10521, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13273, 10521, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13260, 10520, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13261, 10520, 111, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (13262, 10520, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13245, 10519, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13246, 10519, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13247, 10519, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (13248, 10519, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13249, 10519, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (13244, 10518, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (13254, 7547, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (850, 1577, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (831, 1544, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13258, 4784, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (13259, 4784, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (916, 1701, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13317, 2580, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13318, 2580, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13319, 2580, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (953, 1774, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (943, 1756, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (936, 1733, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (928, 1722, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (923, 1712, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (921, 1707, 112, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (905, 1677, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (864, 1596, 175, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (852, 1579, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (830, 1543, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (815, 1513, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (796, 1475, 96, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (13314, 203, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13315, 203, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1057, 1969, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (956, 1778, 79, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (959, 1785, 79, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (966, 1799, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (970, 1809, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (971, 1810, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (973, 1812, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (978, 1824, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (979, 1825, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (981, 1828, 101, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (988, 1839, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (992, 1845, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13293, 1546, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1001, 1859, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1004, 1863, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1045, 1940, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1006, 1865, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (930, 1726, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1010, 1871, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1011, 1874, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (942, 1752, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1017, 1887, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1018, 1889, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1021, 1893, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1022, 1895, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1028, 1904, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (974, 1817, 25, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1032, 1910, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1036, 1923, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1041, 1933, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1042, 1935, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1043, 1936, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1044, 1939, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1026, 1902, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1051, 1953, 7, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1058, 1971, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (964, 1795, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (922, 1708, 5, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1054, 1957, 226, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1033, 1912, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1012, 1876, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (976, 1821, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (890, 1647, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (933, 1729, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1035, 1916, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1029, 1906, 77, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (863, 1595, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (856, 1586, 73, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (949, 1766, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (867, 1603, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (984, 1831, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (995, 1850, 72, 45, 2);
INSERT INTO 'dancesformationsmap' VALUES (1053, 1955, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1048, 1949, 77, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1037, 1927, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (996, 1851, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (990, 1842, 112, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (991, 1843, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (967, 1801, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (908, 1681, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (954, 1776, 4, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (884, 1634, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (851, 1578, 16, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (809, 1499, 5, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (804, 1488, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (955, 1777, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (965, 1796, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1049, 1951, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1000, 1858, 56, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (962, 1792, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1034, 1913, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7958, 7785, 265, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (7959, 7785, 43, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (935, 1731, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (925, 1716, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (985, 1833, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (986, 1834, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13294, 1546, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1060, 1976, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1061, 1978, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13328, 2120, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1063, 1986, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1064, 1987, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1065, 1988, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1069, 1993, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1073, 1999, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1077, 2007, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1082, 2015, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1088, 2031, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1094, 2040, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1096, 2043, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1102, 2053, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1103, 2055, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1108, 2065, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1109, 2066, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1112, 2074, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1116, 2080, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31902, 13826, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1118, 2085, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (1120, 2090, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1126, 2114, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1127, 2115, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1128, 2116, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1129, 2117, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1130, 2122, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1134, 2132, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1135, 2133, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1136, 2136, 73, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (958, 1782, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (969, 1806, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (952, 1773, 79, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1123, 2102, 103, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13334, 10541, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (977, 1823, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (960, 1786, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (994, 1848, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (972, 1811, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1050, 1952, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1025, 1901, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1078, 2008, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1110, 2069, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1113, 2076, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1020, 1892, 176, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13348, 5647, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1009, 1869, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (961, 1790, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (975, 1818, 20, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1080, 2013, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13346, 10545, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13342, 10543, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13343, 10543, 221, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (13337, 10542, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13338, 10542, 123, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (13332, 10540, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13320, 10537, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13286, 10525, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (1038, 1928, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1023, 1896, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1003, 1862, 296, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (951, 1770, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1071, 1997, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1133, 2130, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1115, 2079, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (1105, 2060, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1074, 2000, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1059, 1974, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1056, 1966, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1039, 1931, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1031, 1909, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1030, 1908, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1024, 1897, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1016, 1884, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1007, 1866, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (999, 1857, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (993, 1847, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (998, 1856, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (983, 1830, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (982, 1829, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (980, 1826, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (968, 1804, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1107, 2064, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1013, 1878, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (957, 1780, 96, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (947, 1762, 30, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (945, 1760, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (944, 1757, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1014, 1882, 83, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (1097, 2044, 30, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1076, 2006, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1002, 1861, 16, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1052, 1954, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1046, 1943, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1098, 2045, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1141, 2143, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1142, 2146, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1144, 2152, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1149, 2165, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1150, 2166, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1151, 2167, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13367, 10558, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13368, 10558, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13374, 10561, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13375, 10561, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1090, 2034, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1152, 2168, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13395, 10568, 105, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1137, 2138, 49, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7962, 7451, 188, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (1155, 2174, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1157, 2178, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1159, 2181, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1160, 2184, 80, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1161, 2185, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1164, 2197, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1169, 2209, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1170, 2210, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1172, 2213, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1173, 2214, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1174, 2218, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1175, 2219, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1176, 2221, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1066, 1989, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1062, 1981, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13349, 10553, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1167, 2206, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1104, 2056, 185, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1099, 2048, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1083, 2018, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1143, 2148, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1140, 2141, 72, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (1168, 2208, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13364, 10557, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13365, 10557, 93, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (13366, 10557, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (1119, 2089, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1101, 2052, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1081, 2014, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13393, 10567, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13394, 10567, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1122, 2101, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1179, 2224, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1182, 2234, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1186, 2240, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1189, 2249, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1191, 2252, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1196, 2262, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1198, 2264, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1200, 2272, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1201, 2273, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1204, 2277, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1206, 2283, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1208, 2287, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1086, 2026, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1132, 2125, 316, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13380, 10563, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (31824, 13913, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (1138, 2139, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (963, 1793, 96, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (1171, 2211, 55, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1165, 2199, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1131, 2124, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1124, 2103, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1121, 2095, 114, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1087, 2030, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1111, 2072, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1068, 1992, 56, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (1008, 1868, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (997, 1852, 36, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (1216, 2299, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1220, 2309, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1224, 2320, 79, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1226, 2325, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1229, 2330, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1234, 2343, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13411, 10574, 168, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1294, 2445, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1291, 2436, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13426, 10581, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13427, 10581, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13428, 10581, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13429, 10581, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13430, 10581, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13431, 10581, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13436, 10582, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13437, 10582, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13438, 10582, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13439, 10583, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13440, 10583, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13441, 10583, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22133, 8012, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22134, 8012, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22135, 8012, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1248, 2366, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1250, 2369, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1252, 2374, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1253, 2375, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1221, 2310, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13353, 10554, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1180, 2229, 145, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1079, 2010, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1264, 2396, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1125, 2110, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1145, 2153, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1085, 2024, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13390, 10566, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13391, 10566, 33, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (1139, 2140, 80, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1146, 2156, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1158, 2180, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1093, 2039, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1117, 2084, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1188, 2244, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1190, 2250, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13387, 10565, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13388, 10565, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13345, 9446, 186, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13406, 10572, 36, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (13407, 10572, 33, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13383, 10564, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13384, 10564, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13385, 10564, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13376, 10562, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13377, 10562, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13378, 10562, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13379, 10562, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13372, 10560, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13373, 10560, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13362, 10556, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13363, 10556, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (13329, 10539, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1067, 1990, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13396, 9539, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13397, 9539, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13398, 9539, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (1219, 2306, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1249, 2367, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1166, 2205, 84, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (1178, 2223, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1260, 2389, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1231, 2333, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1242, 2356, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1238, 2350, 96, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (1209, 2288, 36, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1184, 2237, 59, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1163, 2196, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1162, 2189, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1153, 2169, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (1154, 2173, 189, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1148, 2162, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1147, 2157, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1106, 2063, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1095, 2042, 96, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1089, 2033, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1075, 2004, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1156, 2177, 4, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1193, 2255, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1265, 2397, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1267, 2400, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1268, 2404, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1269, 2405, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1270, 2406, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1271, 2407, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1274, 2412, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1276, 2417, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1278, 2420, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1280, 2422, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1247, 2365, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1282, 2426, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1284, 2429, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1289, 2434, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1272, 2408, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1290, 2435, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1293, 2444, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1295, 2451, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1296, 2452, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1298, 2455, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1302, 2460, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1310, 2476, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1312, 2483, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1313, 2486, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1316, 2489, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1266, 2399, 103, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1211, 2291, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1187, 2242, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1181, 2231, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13412, 10575, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1183, 2235, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1241, 2355, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1217, 2301, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1255, 2379, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1311, 2481, 84, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1185, 2238, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1261, 2391, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1292, 2443, 77, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1197, 2263, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1321, 2503, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1235, 2344, 27, 10, 2);
INSERT INTO 'dancesformationsmap' VALUES (1287, 2432, 356, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1207, 2284, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1251, 2370, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13415, 10576, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13404, 10571, 9, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13405, 10571, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1303, 2462, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1288, 2433, 58, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1254, 2376, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1228, 2329, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1222, 2313, 202, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1318, 2493, 30, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (1323, 2505, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1374, 2600, 48, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1328, 2511, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1330, 2515, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1331, 2517, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1332, 2520, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1337, 2532, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13442, 6900, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13443, 6900, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13444, 7927, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13445, 7927, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13446, 7927, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13447, 10584, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13451, 10585, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13455, 7982, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1227, 2328, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1258, 2386, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1225, 2323, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13432, 6678, 168, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1263, 2395, 84, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13358, 10555, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13359, 10555, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13360, 10555, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13420, 10579, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13421, 10579, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1232, 2337, 45, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1230, 2332, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1314, 2487, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1236, 2345, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1336, 2530, 119, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (1322, 2504, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1315, 2488, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1256, 2380, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1233, 2342, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1215, 2298, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1214, 2297, 221, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1210, 2289, 76, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (1212, 2294, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13422, 9809, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (13456, 7982, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13457, 10586, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13458, 10586, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13466, 8347, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13467, 8347, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13468, 8347, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13469, 8350, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13470, 8350, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13471, 8350, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13473, 8353, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13474, 8353, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13480, 8358, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13481, 8358, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13482, 8358, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22136, 8012, 119, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22137, 8012, 69, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22138, 8012, 28, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (13448, 8384, 114, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13449, 8384, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13450, 8384, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1341, 2537, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1343, 2539, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1346, 2546, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1347, 2547, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1348, 2548, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1349, 2549, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1351, 2553, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1354, 2560, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1355, 2561, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1360, 2570, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1362, 2576, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1368, 2590, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1369, 2592, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1373, 2598, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1375, 2603, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1377, 2605, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1381, 2612, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1384, 2618, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1385, 2620, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1386, 2622, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1387, 2626, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1240, 2354, 6, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1352, 2556, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1237, 2349, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1194, 2257, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1372, 2596, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1203, 2276, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1279, 2421, 19, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1286, 2431, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1317, 2492, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1239, 2353, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13403, 10570, 32, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (1327, 2510, 172, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1309, 2475, 8, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (13423, 10580, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1275, 2415, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1285, 2430, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13400, 10569, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1335, 2529, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13401, 10569, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1383, 2617, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1243, 2357, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1244, 2360, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13459, 8367, 84, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (13461, 8345, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13462, 8345, 56, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (13452, 7970, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13453, 7970, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13454, 7970, 175, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (1297, 2453, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1299, 2456, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1363, 2578, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1359, 2568, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1345, 2543, 51, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1342, 2538, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1333, 2525, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (1320, 2495, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1307, 2471, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1306, 2469, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1305, 2465, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1304, 2464, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1281, 2423, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1277, 2419, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1246, 2364, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1213, 2295, 7, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (1205, 2278, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1202, 2275, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1195, 2258, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1192, 2254, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1358, 2566, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1300, 2457, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1329, 2513, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1388, 2629, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1389, 2630, 45, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1283, 2428, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1392, 2634, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1356, 2562, 9, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (1399, 2650, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1401, 2653, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1404, 2658, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1406, 2663, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1412, 2680, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1414, 2685, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1417, 2689, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1418, 2693, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1420, 2696, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1422, 2699, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1425, 2703, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13479, 8357, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1319, 2494, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1430, 2710, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13490, 8362, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13491, 8362, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13492, 8362, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1426, 2705, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13499, 8369, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13500, 8369, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1390, 2631, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1366, 2585, 42, 21, 4);
INSERT INTO 'dancesformationsmap' VALUES (1429, 2708, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1357, 2563, 119, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1402, 2654, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1273, 2409, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1350, 2551, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1405, 2661, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1413, 2683, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1423, 2701, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13475, 8356, 124, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1365, 2583, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1403, 2657, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1344, 2540, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13464, 8346, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (13465, 8346, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (1364, 2582, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13472, 8351, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13476, 8356, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13513, 10640, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13514, 10640, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13515, 10640, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13521, 10643, 186, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13522, 10643, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13523, 10643, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13526, 10645, 105, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13527, 10645, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13528, 10646, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13529, 10646, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13533, 10648, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13534, 10648, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13535, 10648, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13536, 10648, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1439, 2726, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1441, 2728, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1442, 2729, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1444, 2733, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1446, 2735, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1449, 2740, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1457, 2750, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1459, 2755, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1460, 2756, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1462, 2758, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1463, 2759, 37, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1465, 2761, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1466, 2763, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1467, 2766, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1470, 2771, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1471, 2774, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1476, 2784, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1478, 2802, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1379, 2608, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1371, 2595, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1339, 2535, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1434, 2716, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1433, 2714, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1424, 2702, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1419, 2695, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1408, 2667, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1376, 2604, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1382, 2613, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1380, 2610, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1361, 2573, 9, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1334, 2526, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1308, 2472, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (1223, 2317, 87, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1483, 2808, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1468, 2767, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1487, 2817, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1495, 2829, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1530, 2908, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1501, 2837, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1503, 2841, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1505, 2844, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1509, 2863, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1511, 2869, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1513, 2875, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1514, 2876, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1516, 2879, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1519, 2885, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1522, 2889, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1527, 2904, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1533, 2916, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1536, 2921, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1540, 2927, 30, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1545, 2937, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13483, 8360, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1486, 2815, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13497, 8368, 53, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13498, 8368, 43, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (1370, 2593, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1428, 2707, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1409, 2671, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1523, 2890, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1353, 2557, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1489, 2821, 30, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1481, 2806, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1461, 2757, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1443, 2730, 95, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1416, 2688, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31408, 4585, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31407, 5674, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1325, 2507, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1367, 2589, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1525, 2900, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13507, 10601, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1396, 2644, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1378, 2607, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13518, 10642, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13519, 10642, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13510, 10602, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13511, 10602, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13512, 10602, 7, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13504, 10600, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13505, 10600, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13506, 10600, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13516, 9193, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13517, 9193, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1539, 2926, 76, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (1531, 2910, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13493, 8364, 265, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (13494, 8364, 145, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (13495, 8364, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13501, 8352, 9, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13502, 8352, 112, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1400, 2651, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1394, 2639, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1502, 2840, 145, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1391, 2632, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1427, 2706, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1411, 2675, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1407, 2666, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13530, 9192, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13531, 9192, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1529, 2906, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1526, 2903, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1515, 2878, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1518, 2882, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (1512, 2871, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1508, 2859, 96, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1493, 2826, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1474, 2781, 74, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1447, 2736, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1445, 2734, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1440, 2727, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1395, 2642, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1398, 2649, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1544, 2936, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1393, 2636, 80, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1500, 2836, 145, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1482, 2807, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1546, 2939, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1541, 2930, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13538, 9194, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (1551, 2954, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1556, 2964, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1506, 2853, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13542, 10665, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13543, 10670, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13548, 10676, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13549, 10717, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13550, 10717, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13551, 10717, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13552, 10717, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13553, 10717, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13554, 10717, 121, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13555, 10717, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13556, 10717, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13557, 10717, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13558, 10718, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22139, 265, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1558, 2971, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1553, 2956, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1570, 2994, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1571, 2995, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1573, 2998, 46, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1575, 3000, 74, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13545, 10681, 92, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1431, 2711, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1436, 2718, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1454, 2746, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1498, 2833, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1497, 2831, 324, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1397, 2645, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (1488, 2820, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1567, 2988, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1532, 2913, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1537, 2924, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1469, 2768, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1565, 2983, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (1538, 2925, 1, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (1455, 2747, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1548, 2943, 58, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1479, 2803, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13540, 9449, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13524, 10644, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (1535, 2920, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1559, 2974, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1504, 2842, 168, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1492, 2825, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1475, 2782, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1464, 2760, 185, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1451, 2743, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1577, 3004, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1578, 3005, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1579, 3007, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1582, 3015, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1587, 3024, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1590, 3028, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1591, 3029, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1599, 3050, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1604, 3056, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1605, 3060, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1606, 3061, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1612, 3070, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1614, 3072, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1615, 3073, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1616, 3076, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1617, 3079, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1619, 3082, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1624, 3095, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1627, 3103, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1635, 3120, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1637, 3125, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1639, 3130, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1645, 3138, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13559, 10718, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13560, 10718, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1517, 2880, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1437, 2723, 10, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1507, 2858, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1542, 2931, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1458, 2752, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (1415, 2687, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1601, 3052, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1586, 3022, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13573, 10548, 110, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1496, 2830, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1485, 2814, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1534, 2918, 188, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (1647, 3142, 101, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1633, 3113, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1634, 3114, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1564, 2981, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1547, 2941, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1494, 2828, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (1456, 2749, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1421, 2698, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13561, 10718, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13562, 10718, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1585, 3021, 10, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (22140, 265, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22141, 265, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13580, 10771, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13582, 10771, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13581, 10771, 92, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1560, 2975, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1648, 3144, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1651, 3148, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1652, 3150, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1653, 3151, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1655, 3153, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1657, 3156, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1658, 3157, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1659, 3158, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1660, 3159, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1661, 3164, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1663, 3166, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1666, 3170, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1668, 3175, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1672, 3185, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1594, 3037, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1480, 2805, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13568, 10546, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1218, 2305, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1524, 2896, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1521, 2887, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1643, 3136, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1656, 3154, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1569, 2992, 76, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1510, 2868, 149, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1555, 2962, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1632, 3111, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13547, 10675, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1561, 2978, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1472, 2777, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1477, 2801, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13598, 10778, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1602, 3053, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1600, 3051, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13577, 10770, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13578, 10770, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13579, 10770, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13563, 10672, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13564, 10672, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13546, 10669, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13570, 10547, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13571, 10547, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1654, 3152, 7, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1649, 3145, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1631, 3109, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1572, 2997, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13595, 10776, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13596, 10776, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1528, 2905, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1484, 2813, 81, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13566, 10544, 43, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (13567, 10544, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1629, 3105, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1621, 3084, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1618, 3080, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1603, 3054, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1598, 3047, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1574, 2999, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1568, 2990, 34, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1557, 2970, 30, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1552, 2955, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1554, 2957, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1453, 2745, 96, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (1450, 2742, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1642, 3135, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1597, 3046, 16, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1611, 3069, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1623, 3094, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1607, 3063, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1593, 3036, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1581, 3014, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1673, 3187, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1676, 3198, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1662, 3165, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1640, 3131, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1669, 3176, 176, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1589, 3027, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1620, 3083, 145, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1644, 3137, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1679, 3203, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1680, 3204, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1681, 3205, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1682, 3206, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1684, 3208, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1685, 3211, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1686, 3212, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1687, 3213, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1688, 3215, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1693, 3223, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1700, 3237, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1702, 3239, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1703, 3240, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1704, 3243, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1707, 3248, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1710, 3255, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1713, 3258, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1716, 3262, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1719, 3269, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13640, 10790, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1595, 3038, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1613, 3071, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13544, 10684, 10, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (1583, 3017, 52, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1628, 3104, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1566, 2984, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13585, 10773, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13586, 10773, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1596, 3045, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1692, 3221, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1638, 3127, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1691, 3220, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1622, 3092, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1714, 3260, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1690, 3219, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1674, 3188, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1678, 3202, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1721, 3279, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1724, 3283, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1727, 3286, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1732, 3292, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1733, 3294, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1734, 3295, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1736, 3303, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1737, 3304, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1738, 3307, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1741, 3312, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13620, 10785, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13621, 10785, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13622, 10785, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13623, 10786, 77, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13624, 10786, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13625, 10786, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13602, 10779, 42, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (13603, 10779, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22107, 13682, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22142, 13682, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22144, 13328, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22145, 13328, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22167, 14418, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22154, 14269, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22155, 14269, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22161, 14406, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22162, 14406, 185, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22163, 14406, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1744, 3315, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1745, 3316, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1747, 3319, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1752, 3330, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1755, 3335, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1760, 3341, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1763, 3347, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1765, 3350, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1770, 3359, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1772, 3361, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1773, 3362, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1777, 3369, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1641, 3133, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1697, 3234, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1742, 3313, 17, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1636, 3122, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13597, 10777, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13576, 10769, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1699, 3236, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1775, 3365, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1766, 3351, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1764, 3349, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1705, 3245, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1698, 3235, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1696, 3233, 82, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1689, 3218, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1646, 3140, 77, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1665, 3169, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1520, 2886, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (1491, 2823, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1779, 3374, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1780, 3376, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1784, 3384, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1785, 3385, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1790, 3394, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1791, 3395, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1796, 3401, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1802, 3410, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13626, 10787, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1808, 3419, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1810, 3423, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1813, 3427, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1818, 3439, 74, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1821, 3445, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1712, 3257, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13574, 10549, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1771, 3360, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13583, 10772, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13636, 10789, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1811, 3424, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1588, 3026, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13604, 10780, 199, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1709, 3254, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31409, 276, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1650, 3147, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1608, 3065, 38, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1723, 3282, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1731, 3291, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1739, 3309, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (1580, 3010, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (13631, 10788, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1701, 3238, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1778, 3373, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1789, 3390, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13643, 10791, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1626, 3102, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13632, 10788, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13633, 10788, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13616, 10784, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13614, 10783, 373, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (13615, 10783, 117, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (13609, 10782, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13610, 10782, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13591, 10775, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13592, 10775, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13607, 10760, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13608, 10760, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13619, 10760, 200, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13629, 10653, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1783, 3382, 90, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1675, 3197, 13, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1806, 3416, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1671, 3180, 87, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1694, 3225, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1610, 3067, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1822, 3446, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1801, 3409, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1762, 3345, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1728, 3287, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1757, 3338, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1759, 3340, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1751, 3329, 54, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1746, 3317, 134, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1743, 3314, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1722, 3280, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1718, 3267, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1715, 3261, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1683, 3207, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1711, 3256, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1708, 3250, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1677, 3200, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1670, 3177, 95, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (1729, 3288, 16, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1774, 3364, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (1706, 3246, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1825, 3450, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1833, 3468, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13618, 1998, 200, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22146, 8294, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1805, 3413, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22164, 12538, 23, 26, 8);
INSERT INTO 'dancesformationsmap' VALUES (1832, 3466, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22151, 14405, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22152, 14405, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13669, 9888, 39, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (1807, 3418, 1, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (1768, 3357, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1800, 3408, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13613, 10402, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1823, 3448, 30, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1809, 3420, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13611, 9907, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13653, 10794, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13654, 10794, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13612, 9907, 209, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13659, 10797, 62, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1788, 3389, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1781, 3378, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1776, 3368, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1769, 3358, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1767, 3352, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1792, 3396, 83, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1725, 3284, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1794, 3398, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1717, 3265, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1740, 3310, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13673, 10801, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13674, 10801, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22143, 13683, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22156, 13850, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22157, 13850, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22158, 13850, 63, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1812, 3426, 222, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1816, 3435, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1873, 3549, 92, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (13656, 10795, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13657, 10795, 279, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13666, 10796, 43, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (13667, 10796, 39, 45, 2);
INSERT INTO 'dancesformationsmap' VALUES (1838, 3476, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1844, 3491, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1847, 3494, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1848, 3495, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1849, 3497, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1854, 3505, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22168, 14418, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (1877, 3560, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1879, 3565, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1883, 3576, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1888, 3581, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1850, 3498, 58, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1899, 3599, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1901, 3603, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22169, 14418, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (1911, 3621, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1914, 3630, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1922, 3639, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1923, 3643, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1926, 3647, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13689, 10805, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13690, 10805, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13691, 10806, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13692, 10806, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13693, 10808, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13694, 10808, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13695, 10809, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13696, 10811, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13697, 10812, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13698, 10813, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13699, 10814, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13700, 10814, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1919, 3636, 273, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1866, 3536, 52, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13701, 10815, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13702, 10815, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1884, 3577, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1814, 3431, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31903, 13826, 193, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14334, 2310, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22159, 13850, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22160, 13850, 38, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13661, 5952, 56, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1797, 3402, 18, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1827, 3453, 76, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1803, 3411, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13658, 7530, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13662, 10800, 201, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13663, 10800, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1895, 3592, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1917, 3634, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1891, 3586, 64, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1875, 3553, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1885, 3578, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1867, 3537, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1865, 3529, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1858, 3511, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1815, 3433, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1799, 3407, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1758, 3339, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1753, 3331, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1720, 3277, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1625, 3101, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22170, 2268, 225, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22171, 2268, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22172, 2268, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22173, 11277, 54, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22174, 11279, 117, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22177, 11287, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14681, 11288, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22178, 11288, 20, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22183, 13071, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1839, 3479, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1916, 3632, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1912, 3626, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1795, 3400, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1878, 3562, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1726, 3285, 64, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1748, 3320, 82, 10, 2);
INSERT INTO 'dancesformationsmap' VALUES (1749, 3325, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13710, 10820, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1852, 3502, 101, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1857, 3510, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13647, 10792, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1874, 3552, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1735, 3299, 53, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1820, 3444, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1843, 3486, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1863, 3525, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1882, 3570, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1829, 3459, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1905, 3611, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13644, 10791, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13648, 10792, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13672, 10799, 43, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (13703, 10817, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13704, 10817, 183, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (22148, 13982, 19, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22149, 13982, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1887, 3580, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13705, 10818, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13706, 10818, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13605, 10781, 13, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13606, 10781, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13686, 10803, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13684, 9000, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13685, 9000, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1835, 3473, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1870, 3542, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1817, 3436, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1842, 3485, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1924, 3645, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1886, 3579, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (1881, 3569, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1872, 3544, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1868, 3538, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1864, 3528, 76, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (1851, 3499, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1845, 3492, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1828, 3454, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1804, 3412, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1786, 3387, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1761, 3342, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1925, 3646, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1890, 3584, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1826, 3452, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13713, 10051, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (1871, 3543, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1913, 3629, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1859, 3514, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1896, 3593, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22176, 4165, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13676, 8998, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22179, 14419, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22180, 14419, 36, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22175, 5407, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1798, 3405, 120, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1841, 3483, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13707, 10819, 43, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (1918, 3635, 4, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (1853, 3503, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22188, 13726, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1902, 3607, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1856, 3509, 85, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1909, 3617, 317, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1920, 3637, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1840, 3482, 7, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1860, 3517, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1855, 3506, 83, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22184, 13593, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22185, 13593, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22186, 13593, 94, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1889, 3583, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13660, 10798, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1819, 3441, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1900, 3601, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1894, 3590, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1961, 3715, 8, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (1927, 3648, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1929, 3652, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1935, 3661, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1938, 3670, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1939, 3671, 102, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1941, 3676, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1957, 3709, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1962, 3718, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2058, 3897, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1968, 3727, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1975, 3736, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1978, 3740, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1983, 3758, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1991, 3772, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1992, 3773, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2002, 3790, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2006, 3802, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2008, 3804, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2010, 3810, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2011, 3811, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1974, 3735, 29, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (2016, 3819, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2018, 3822, 80, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2019, 3823, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2020, 3827, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2029, 3843, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2032, 3849, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2033, 3850, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2040, 3865, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2042, 3868, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2044, 3871, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2045, 3872, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2046, 3874, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2047, 3875, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1931, 3654, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1965, 3724, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13747, 10846, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2053, 3890, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1928, 3650, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2056, 3895, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2060, 3902, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2061, 3905, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2065, 3911, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2067, 3914, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2071, 3919, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2072, 3920, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1933, 3658, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2076, 3930, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2086, 3951, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2081, 3940, 16, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2085, 3949, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2088, 3954, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2090, 3958, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2091, 3961, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1979, 3743, 78, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (2094, 3969, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2017, 3821, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2095, 3972, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1945, 3685, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2068, 3915, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2080, 3938, 29, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (2057, 3896, 9, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1999, 3787, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1958, 3710, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1862, 3524, 69, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13738, 10843, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13739, 10843, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13740, 10843, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2064, 3910, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1903, 3608, 37, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1948, 3692, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13665, 10800, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1793, 3397, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1985, 3762, 95, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (1944, 3684, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2049, 3882, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2005, 3800, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1976, 3737, 30, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1951, 3699, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1967, 3726, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1946, 3689, 74, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1880, 3567, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1824, 3449, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1987, 3765, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1996, 3782, 17, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1897, 3594, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1930, 3653, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (1993, 3774, 7, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1997, 3784, 82, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2012, 3813, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13722, 10823, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (2028, 3842, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2069, 3916, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2083, 3943, 119, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13724, 9532, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13717, 10822, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1982, 3748, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13682, 9742, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1846, 3493, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1915, 3631, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2015, 3818, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2050, 3885, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13718, 10822, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13714, 10821, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13715, 10821, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13679, 9740, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2014, 3816, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13725, 4774, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1907, 3615, 96, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2078, 3932, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2063, 3908, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2059, 3900, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2037, 3859, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2030, 3845, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2023, 3830, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2022, 3829, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2021, 3828, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2003, 3792, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1995, 3781, 33, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1988, 3767, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1986, 3763, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1972, 3731, 96, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (1969, 3728, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1964, 3723, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1963, 3722, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1952, 3702, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1950, 3698, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1934, 3660, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1910, 3620, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1898, 3595, 134, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (1906, 3613, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1893, 3589, 65, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1869, 3541, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1942, 3679, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1837, 3475, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2084, 3944, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2034, 3852, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2000, 3788, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13726, 4774, 221, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1981, 3746, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2075, 3924, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2074, 3922, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2025, 3836, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22189, 13726, 53, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2031, 3846, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2093, 3967, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2038, 3862, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1960, 3713, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2007, 3803, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1956, 3708, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2039, 3864, 82, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (2073, 3921, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2001, 3789, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1980, 3745, 202, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1947, 3690, 281, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (2089, 3955, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2092, 3965, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2097, 3975, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2100, 3982, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2101, 3983, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2102, 3984, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2103, 3985, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2109, 3991, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2112, 4001, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2114, 4004, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2116, 4006, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2117, 4009, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2119, 4012, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2203, 4179, 75, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2122, 4021, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2128, 4034, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2133, 4050, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2136, 4053, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2137, 4055, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2138, 4056, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2145, 4069, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13748, 10846, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13749, 10846, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13750, 10846, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13751, 10846, 175, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13752, 10846, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13760, 10850, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13761, 10850, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13778, 10867, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13779, 10867, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13780, 10867, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2139, 4057, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2147, 4071, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2149, 4074, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2150, 4077, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2151, 4079, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2152, 4080, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2155, 4089, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2156, 4090, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2157, 4091, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2159, 4093, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2164, 4104, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2167, 4107, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2170, 4114, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2178, 4139, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2183, 4148, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2184, 4150, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2189, 4157, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2191, 4159, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2193, 4164, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2195, 4167, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2202, 4177, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2205, 4184, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2206, 4189, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2208, 4195, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2210, 4197, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2214, 4203, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2215, 4206, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2216, 4207, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2219, 4212, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2221, 4218, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2222, 4219, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2223, 4220, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2224, 4221, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2229, 4228, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2232, 4235, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2233, 4236, 16, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2236, 4247, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2118, 4010, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2212, 4199, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2079, 3934, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2087, 3953, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2041, 3866, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2104, 3986, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31411, 2671, 176, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (1973, 3732, 84, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2036, 3857, 88, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (1998, 3786, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13787, 2597, 192, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2013, 3814, 356, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2162, 4100, 83, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2099, 3980, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2120, 4018, 356, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2127, 4033, 58, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2192, 4160, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13764, 9059, 93, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (2126, 4026, 120, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2048, 3876, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1904, 3609, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22193, 13594, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1936, 3665, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2220, 4217, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (13753, 10847, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2168, 4110, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2165, 4105, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13758, 10849, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13759, 10849, 21, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2110, 3998, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2043, 3870, 306, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2176, 4131, 356, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1970, 3729, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2062, 3906, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13769, 10861, 42, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (13756, 10848, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13754, 10847, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2141, 4063, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2113, 4002, 145, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2052, 3888, 18, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2026, 3837, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2188, 4156, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1994, 3776, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2024, 3833, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1949, 3697, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2004, 3798, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (2200, 4175, 20, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (2226, 4223, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2190, 4158, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1990, 3770, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1955, 3706, 183, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (13783, 10878, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13784, 10878, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13775, 10866, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13776, 10866, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13777, 10866, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13772, 10864, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13773, 10864, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13774, 10864, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13770, 10862, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13771, 10862, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2185, 4151, 164, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2179, 4141, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2009, 3805, 38, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13732, 10842, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13788, 2597, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (1954, 3705, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2132, 4047, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13786, 4439, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (2228, 4227, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2225, 4222, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2209, 4196, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2204, 4183, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2201, 4176, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2198, 4173, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (2196, 4169, 75, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2187, 4155, 30, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (2180, 4142, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2172, 4119, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2171, 4115, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2166, 4106, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2144, 4068, 45, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2121, 4019, 189, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2077, 3931, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2070, 3918, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2051, 3887, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2035, 3854, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1989, 3769, 307, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1959, 3711, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1953, 3704, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2173, 4123, 18, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2160, 4097, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2230, 4231, 28, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (1932, 3656, 34, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2131, 4046, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2213, 4201, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22182, 14419, 76, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (2129, 4037, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2108, 3990, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13762, 10852, 16, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2154, 4086, 77, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2124, 4023, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2130, 4039, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14678, 11289, 168, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2158, 4092, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14679, 11289, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (2186, 4154, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2098, 3978, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2175, 4127, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13781, 10797, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2153, 4085, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2143, 4065, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2111, 3999, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2169, 4112, 7, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (2237, 4250, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31412, 5084, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2182, 4146, 31, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2246, 4269, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (102, 169, 25, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2249, 4275, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2252, 4285, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2253, 4288, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2255, 4292, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2257, 4294, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2258, 4295, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2259, 4296, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2266, 4308, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2271, 4314, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2264, 4304, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2275, 4325, 16, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2276, 4328, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2277, 4331, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2278, 4332, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2282, 4338, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2283, 4341, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2284, 4342, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2285, 4345, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2293, 4357, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2296, 4360, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2279, 4333, 9, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (2298, 4364, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2301, 4367, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2302, 4372, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2304, 4375, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2305, 4376, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2306, 4379, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2310, 4385, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2317, 4400, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2319, 4406, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2321, 4408, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2322, 4413, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2323, 4414, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2324, 4415, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2268, 4310, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2280, 4334, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2325, 4419, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13838, 10899, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13839, 10899, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2235, 4239, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13849, 10901, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13850, 10902, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2316, 4399, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2315, 4396, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13802, 10531, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13867, 9198, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13868, 9198, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13869, 9198, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13870, 9198, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13871, 9198, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13873, 9049, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2107, 3989, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2161, 4098, 119, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (2505, 4796, 87, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2181, 4144, 45, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2261, 4301, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13836, 10898, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13837, 10898, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2123, 4022, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2330, 4427, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2309, 4384, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2291, 4354, 10, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (2148, 4073, 33, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2273, 4320, 183, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (2314, 4394, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (2308, 4382, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (2318, 4404, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2199, 4174, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13840, 10900, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13833, 10896, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13831, 10895, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13832, 10895, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13828, 10894, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13829, 10894, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13825, 10893, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13826, 10893, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13819, 10891, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (13820, 10891, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13821, 10891, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (13815, 10889, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13816, 10889, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (13817, 10889, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (13813, 10888, 30, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (13814, 10888, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13810, 10887, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13811, 10887, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13806, 10886, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13742, 10844, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13745, 10845, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2307, 4381, 16, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2241, 4257, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2287, 4348, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2211, 4198, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2243, 4263, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2254, 4290, 31, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2265, 4306, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2312, 4389, 45, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (13835, 10897, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13842, 10879, 23, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (13793, 5511, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2294, 4358, 19, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (2260, 4299, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2197, 4170, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2115, 4005, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1971, 3730, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2146, 4070, 120, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (13846, 10883, 7, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (13807, 10886, 56, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13808, 10886, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13794, 9331, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13795, 9331, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13796, 9331, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13851, 9196, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13852, 9196, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13853, 9196, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2082, 3941, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13862, 9051, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13863, 9051, 105, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13864, 9051, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13865, 9051, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (13790, 2597, 130, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (13791, 2597, 22, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (13792, 2597, 86, 73, 2);
INSERT INTO 'dancesformationsmap' VALUES (13859, 9197, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13860, 9197, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13861, 9197, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2218, 4211, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2286, 4346, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2303, 4374, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2272, 4318, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13797, 2253, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (2263, 4303, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2329, 4426, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2250, 4278, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2242, 4262, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2234, 4238, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13866, 4140, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2177, 4136, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2174, 4126, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2140, 4058, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2134, 4051, 18, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2125, 4024, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2096, 3973, 248, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2326, 4421, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2270, 4313, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2105, 3987, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2251, 4280, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (2290, 4352, 365, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2240, 4253, 20, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2244, 4266, 58, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13799, 10535, 9, 15, 4);
INSERT INTO 'dancesformationsmap' VALUES (13800, 10535, 77, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5535, 5006, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2299, 4365, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22195, 5006, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2239, 4252, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2292, 4355, 55, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2328, 4425, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2194, 4165, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2311, 4388, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12117, 433, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22202, 12334, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22203, 12334, 75, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22204, 12334, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22210, 10354, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22211, 10354, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2331, 4429, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2347, 4460, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2358, 4496, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2362, 4503, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2370, 4524, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2374, 4533, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2376, 4541, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2379, 4548, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2391, 4568, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2392, 4570, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2394, 4576, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2399, 4588, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2400, 4589, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2408, 4603, 46, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2409, 4604, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2410, 4605, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2411, 4609, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2413, 4611, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2414, 4613, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2416, 4615, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2420, 4623, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2422, 4627, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13882, 10868, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13883, 10868, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13884, 10868, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13885, 10870, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13886, 10870, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13887, 10871, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13888, 10871, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13891, 10873, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13892, 10873, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13893, 10873, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13894, 10876, 165, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13895, 10876, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13896, 10874, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13897, 10874, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2350, 4470, 50, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2367, 4514, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2382, 4553, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2443, 4667, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22212, 10354, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2418, 4619, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13908, 10853, 78, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (2425, 4631, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2434, 4645, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2446, 4671, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2451, 4676, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2453, 4681, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2334, 4434, 96, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (2430, 4639, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2415, 4614, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2405, 4596, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2427, 4636, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2384, 4556, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22205, 14420, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2365, 4511, 54, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (2395, 4579, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13898, 10875, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13899, 10875, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (2386, 4560, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1695, 3231, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2385, 4558, 367, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2383, 4555, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2452, 4679, 18, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (2429, 4638, 30, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22200, 6133, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2217, 4209, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13910, 10855, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2377, 4543, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22207, 14421, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2340, 4442, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13874, 9049, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2295, 4359, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2373, 4531, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2426, 4632, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2397, 4585, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2432, 4642, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (2269, 4312, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2341, 4444, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2343, 4447, 9, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (2351, 4476, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2352, 4477, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2361, 4500, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2369, 4521, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2412, 4610, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2419, 4620, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13909, 10854, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (2378, 4544, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2454, 4684, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13841, 10900, 260, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2438, 4655, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13818, 10890, 15, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (13902, 10877, 34, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13903, 10877, 64, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13804, 10885, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2142, 4064, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2355, 4486, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2450, 4675, 34, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2428, 4637, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13913, 10857, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13889, 10872, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2449, 4674, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2448, 4673, 112, 5, 6);
INSERT INTO 'dancesformationsmap' VALUES (2445, 4669, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2423, 4628, 278, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2441, 4663, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2417, 4617, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2407, 4602, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2390, 4564, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2389, 4563, 18, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (2375, 4537, 20, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2359, 4498, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2360, 4499, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (2313, 4393, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2281, 4336, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2262, 4302, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2248, 4273, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2238, 4251, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13872, 4121, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13843, 10882, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13847, 10884, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2256, 4293, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2372, 4529, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13914, 10858, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13879, 9052, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6510, 1907, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13880, 9052, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13875, 9199, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13876, 9199, 78, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13877, 9199, 52, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13915, 10858, 142, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13916, 10858, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2288, 4350, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2455, 4685, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2364, 4508, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2387, 4561, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2435, 4646, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2442, 4666, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2406, 4597, 189, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2404, 4595, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2396, 4581, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2366, 4512, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2335, 4436, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2349, 4466, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2345, 4451, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2344, 4450, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2339, 4441, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2338, 4440, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2337, 4439, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2336, 4438, 2, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2300, 4366, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2245, 4268, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2247, 4270, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2402, 4591, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2274, 4324, 317, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2348, 4464, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22206, 14420, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2380, 4550, 76, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (11495, 10256, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2398, 4586, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11496, 10256, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22198, 10256, 222, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22199, 6035, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (2447, 4672, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2444, 4668, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2439, 4661, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2437, 4654, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2393, 4575, 340, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (2353, 4479, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4923, 3231, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13905, 10148, 119, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13906, 10148, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2456, 4687, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2460, 4699, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2464, 4713, 80, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2466, 4718, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2467, 4719, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2472, 4730, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2473, 4731, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2476, 4743, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2480, 4748, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2487, 4761, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2492, 4775, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2493, 4776, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2495, 4778, 79, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2497, 4780, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2499, 4786, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2500, 4787, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2502, 4790, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2504, 4794, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2512, 4810, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2516, 4817, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2520, 4824, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2521, 4826, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2525, 4833, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2530, 4843, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2534, 4849, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2536, 4856, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2542, 4867, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2543, 4870, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2546, 4876, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2511, 4808, 112, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (2551, 4883, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2553, 4885, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2556, 4900, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2557, 4901, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2558, 4902, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2559, 4905, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2563, 4909, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2564, 4910, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2526, 4834, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2566, 4913, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2567, 4915, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2513, 4814, 91, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2549, 4881, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2465, 4715, 144, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (2470, 4726, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2570, 4918, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2573, 4921, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2575, 4926, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2584, 4942, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2586, 4944, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2587, 4946, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2595, 4962, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2596, 4963, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2597, 4964, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2599, 4972, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2601, 4977, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2608, 4993, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2609, 4994, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2612, 5002, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2613, 5003, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2614, 5004, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2619, 5015, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2518, 4820, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2623, 5024, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2624, 5025, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2494, 4777, 225, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2628, 5030, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2585, 4943, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2620, 5016, 234, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (2611, 5000, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2523, 4830, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2482, 4750, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2440, 4662, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2622, 5023, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2582, 4938, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2565, 4911, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2431, 4641, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2462, 4707, 20, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2421, 4625, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2594, 4959, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2483, 4751, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2363, 4506, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2581, 4935, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2469, 4725, 64, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2561, 4907, 31, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (2583, 4940, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2510, 4806, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2540, 4864, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2490, 4767, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2356, 4489, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2401, 4590, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2461, 4701, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2539, 4863, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2545, 4875, 80, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2604, 4988, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2515, 4816, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2522, 4828, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2471, 4728, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2627, 5028, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2602, 4982, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2484, 4752, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13918, 10859, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2544, 4871, 77, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (2538, 4862, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2616, 5007, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13917, 10858, 39, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (2509, 4805, 162, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2489, 4765, 83, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2498, 4782, 16, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2381, 4552, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2606, 4991, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2491, 4769, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2496, 4779, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2610, 4995, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2589, 4950, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2621, 5019, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (2568, 4916, 71, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2532, 4845, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2474, 4734, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2403, 4594, 314, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2593, 4956, 77, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2459, 4697, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2458, 4695, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13920, 10903, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13933, 10909, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13929, 10908, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13930, 10908, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13924, 10905, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13921, 10904, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2354, 4484, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2626, 5027, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2590, 4951, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2588, 4948, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2580, 4932, 45, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2569, 4917, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2508, 4804, 7, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2560, 4906, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2550, 4882, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2548, 4879, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2541, 4865, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2531, 4844, 12, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (2562, 4908, 81, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2485, 4755, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2478, 4746, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2477, 4744, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2468, 4720, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2388, 4562, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2535, 4853, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2346, 4455, 85, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2368, 4517, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2457, 4688, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2479, 4747, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2503, 4792, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (2571, 4919, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2506, 4800, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2528, 4837, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2552, 4884, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2574, 4924, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2603, 4984, 6, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2617, 5009, 143, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (2591, 4953, 1, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (2501, 4789, 112, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2519, 4821, 84, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2529, 4841, 89, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2607, 4992, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (2517, 4818, 112, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2592, 4954, 18, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2629, 5031, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2638, 5047, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2639, 5048, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2640, 5051, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2641, 5052, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13939, 10911, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13940, 10911, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13941, 10911, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2659, 5084, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22213, 10354, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22214, 10354, 38, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2644, 5056, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2645, 5057, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2650, 5068, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2651, 5069, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2652, 5071, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2653, 5073, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2654, 5074, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2655, 5075, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2656, 5077, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2657, 5078, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2663, 5094, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2667, 5101, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2669, 5105, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2671, 5108, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2673, 5112, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2674, 5114, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2675, 5115, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2679, 5121, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2681, 5124, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2683, 5130, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2684, 5131, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2685, 5133, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2686, 5135, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2690, 5145, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2694, 5153, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2680, 5122, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (2697, 5156, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2700, 5164, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2704, 5173, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2706, 5180, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2707, 5183, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13976, 10921, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13953, 10913, 82, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (13954, 10913, 103, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2711, 5190, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2712, 5192, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2713, 5194, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2714, 5195, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2717, 5201, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2718, 5202, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2720, 5205, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2723, 5212, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2725, 5218, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2729, 5228, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2730, 5229, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2731, 5231, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14013, 10939, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14014, 10939, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14015, 10939, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13973, 10920, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13966, 7018, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2721, 5207, 18, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (2733, 5234, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13988, 8986, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2682, 5126, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2615, 5006, 263, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2688, 5137, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2643, 5055, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2630, 5033, 7, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2661, 5090, 336, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2572, 4920, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2524, 4832, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2463, 4709, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2735, 5236, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2647, 5063, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2600, 4975, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13950, 10912, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2715, 5198, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2724, 5217, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2579, 4931, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2578, 4930, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2687, 5136, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2537, 4858, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2634, 5040, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2727, 5223, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14008, 10937, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14009, 10937, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14003, 10936, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14004, 10936, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14005, 10936, 38, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (14000, 10935, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14001, 10935, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14002, 10935, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13997, 10934, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13998, 10934, 168, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (13999, 10934, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13993, 10933, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13994, 10933, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13995, 10933, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13996, 10933, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (13989, 10931, 43, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (13990, 10931, 185, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (13991, 10931, 202, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (13992, 10931, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13981, 10927, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13982, 10927, 87, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13983, 10927, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13967, 10918, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13968, 10918, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13969, 10918, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13958, 10915, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13959, 10915, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13960, 10915, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13948, 10782, 23, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (13949, 10782, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2677, 5118, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13945, 8857, 92, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13946, 8857, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2689, 5142, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13984, 10928, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2710, 5188, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2605, 4990, 386, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2701, 5165, 58, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14012, 10938, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2547, 4877, 77, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13925, 10906, 143, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13965, 10917, 117, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13961, 10916, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2705, 5176, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2695, 5154, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2678, 5120, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2658, 5083, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2648, 5064, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2642, 5053, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2637, 5046, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2514, 4815, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (2703, 5172, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13935, 10910, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13938, 790, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13942, 1914, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (2719, 5203, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2554, 4888, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13943, 1914, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2699, 5160, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2692, 5151, 81, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (2691, 5147, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2668, 5102, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2666, 5099, 1, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (2660, 5088, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2646, 5061, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2633, 5039, 119, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (2632, 5037, 56, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2631, 5034, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (2708, 5186, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2598, 4968, 96, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (2670, 5106, 131, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13980, 10924, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2527, 4835, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13962, 1247, 83, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2555, 4890, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2665, 5097, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2698, 5158, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13971, 10919, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2664, 5095, 64, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2722, 5208, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2676, 5117, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2297, 4361, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22215, 4361, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22216, 4361, 33, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2734, 5235, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2649, 5065, 76, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (2693, 5152, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2738, 5240, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2741, 5251, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2743, 5254, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31415, 3549, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2749, 5263, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2750, 5266, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2751, 5269, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2757, 5280, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2760, 5283, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2762, 5285, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2763, 5287, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2764, 5288, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2765, 5290, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2767, 5293, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2768, 5294, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2770, 5299, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2773, 5304, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2776, 5309, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2778, 5313, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2779, 5314, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2781, 5319, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2783, 5321, 101, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2786, 5333, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2787, 5340, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2788, 5341, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2789, 5342, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2793, 5348, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2794, 5349, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2796, 5353, 74, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2798, 5357, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2802, 5363, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2805, 5369, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2810, 5379, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2811, 5380, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2815, 5394, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2819, 5400, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2820, 5401, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2824, 5405, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2825, 5406, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2863, 5468, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2756, 5277, 55, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13977, 10921, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2806, 5373, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2864, 5469, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2737, 5239, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2754, 5275, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2807, 5374, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2816, 5395, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2830, 5416, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2831, 5417, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2832, 5419, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2834, 5423, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2835, 5424, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2836, 5425, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2838, 5428, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2840, 5432, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2842, 5435, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2843, 5439, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2846, 5442, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2851, 5449, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2853, 5452, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2854, 5454, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2856, 5457, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2858, 5461, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2867, 5477, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2868, 5479, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2850, 5446, 185, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (2826, 5407, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2769, 5296, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2808, 5376, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22217, 2984, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2744, 5256, 145, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (2766, 5291, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2752, 5271, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2761, 5284, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2797, 5355, 28, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2844, 5440, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2790, 5344, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2702, 5168, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14036, 10948, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14037, 10948, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14025, 10944, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14026, 10944, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14038, 10948, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2852, 5451, 90, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (2732, 5232, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2742, 5252, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2800, 5359, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14050, 10960, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2865, 5471, 90, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2636, 5044, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2862, 5465, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2792, 5347, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (2753, 5272, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2784, 5330, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2777, 5310, 95, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14052, 10961, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2739, 5243, 265, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2782, 5320, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2847, 5443, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2736, 5237, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14047, 10959, 265, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14048, 10959, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14049, 10959, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14039, 10949, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14040, 10949, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14041, 10949, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14032, 10947, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14033, 10947, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14034, 10947, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (14035, 10947, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14030, 10946, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14031, 10946, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (14028, 10945, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (14029, 10945, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14023, 10943, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14024, 10943, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14020, 10942, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14021, 10942, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (14022, 10942, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (14017, 10941, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (14018, 10941, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14019, 10941, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13986, 10929, 176, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13987, 10929, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13956, 10914, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2837, 5426, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2848, 5444, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2745, 5257, 38, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2785, 5332, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2812, 5385, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2772, 5303, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2833, 5421, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2817, 5398, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2821, 5402, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2803, 5364, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2795, 5350, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2801, 5362, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2747, 5260, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2855, 5455, 112, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2774, 5307, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2728, 5225, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14043, 10958, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2841, 5434, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2740, 5244, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2780, 5317, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14059, 10968, 278, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (2845, 5441, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14016, 10940, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2849, 5445, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2827, 5412, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2662, 5093, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2726, 5219, 9, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (2799, 5358, 30, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2759, 5282, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2771, 5300, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2758, 5281, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2818, 5399, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14060, 10978, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2822, 5403, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2829, 5414, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2828, 5413, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2823, 5404, 52, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2813, 5387, 22, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (2809, 5377, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2791, 5345, 16, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (2746, 5259, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2870, 5488, 68, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2972, 5673, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2879, 5507, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2881, 5510, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2882, 5512, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2884, 5514, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2885, 5517, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2889, 5526, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2892, 5533, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2894, 5535, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2896, 5537, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2898, 5541, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2901, 5545, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2902, 5546, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2904, 5550, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2905, 5551, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2906, 5553, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2909, 5556, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2913, 5563, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2916, 5570, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2918, 5572, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14062, 10716, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14063, 10716, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14064, 10716, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14077, 11034, 124, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14078, 11034, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14079, 11034, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14080, 11035, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14081, 11035, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2929, 5590, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2878, 5506, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14095, 11040, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14096, 11040, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14097, 11040, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22220, 14423, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22221, 14423, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22222, 14423, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2926, 5583, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2927, 5585, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2931, 5592, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2932, 5595, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2934, 5598, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2935, 5599, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2936, 5603, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2938, 5606, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2939, 5608, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2941, 5614, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3017, 5755, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2948, 5626, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2950, 5631, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2951, 5633, 74, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3006, 5734, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2958, 5651, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2959, 5653, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2964, 5663, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2965, 5664, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2966, 5665, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2969, 5670, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2971, 5672, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2974, 5675, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2979, 5683, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2985, 5692, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2986, 5695, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2988, 5698, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2989, 5702, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2991, 5705, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2992, 5706, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2996, 5714, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2983, 5690, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3000, 5725, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3002, 5729, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3005, 5733, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3008, 5738, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3009, 5740, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3011, 5747, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2908, 5555, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2857, 5460, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2895, 5536, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2860, 5463, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14068, 11030, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (2928, 5589, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2887, 5522, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (14084, 11037, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14065, 11029, 90, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14066, 11029, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14070, 11031, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14071, 11031, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14075, 11033, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14076, 11033, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14098, 11041, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14099, 11041, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14100, 11041, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14087, 11038, 149, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14088, 11038, 52, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (14089, 11038, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (14101, 11042, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14102, 11042, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14103, 11042, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2995, 5713, 176, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14082, 11036, 91, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14069, 11030, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14091, 11039, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14092, 11039, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14093, 11039, 19, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2875, 5498, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2839, 5430, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2975, 5677, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2981, 5686, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2945, 5619, 85, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2877, 5502, 112, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (2880, 5509, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2963, 5662, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2933, 5597, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2999, 5723, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2923, 5580, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2943, 5616, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2874, 5497, 79, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (2921, 5576, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2973, 5674, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3004, 5732, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2876, 5500, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2962, 5661, 296, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2866, 5474, 56, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2873, 5495, 356, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2886, 5519, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2900, 5543, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2949, 5628, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2920, 5575, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14073, 11032, 162, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14055, 10967, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2912, 5560, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2961, 5658, 61, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (2893, 5534, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3010, 5741, 16, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2997, 5717, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2993, 5710, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2990, 5704, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2984, 5691, 28, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2968, 5669, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2957, 5648, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2955, 5643, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2946, 5624, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2930, 5591, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2917, 5571, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2915, 5568, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2914, 5564, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2903, 5547, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2897, 5539, 307, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2872, 5494, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2871, 5493, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (2907, 5554, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2891, 5531, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2883, 5513, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2911, 5559, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2888, 5525, 16, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14067, 10768, 123, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2976, 5679, 185, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2937, 5604, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2869, 5480, 185, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (2925, 5582, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2980, 5685, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (2977, 5680, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2956, 5644, 102, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2960, 5654, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2922, 5579, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2899, 5542, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3007, 5736, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2952, 5638, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2924, 5581, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2970, 5671, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3013, 5751, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3015, 5753, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2953, 5640, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3019, 5758, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3021, 5760, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3022, 5761, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3023, 5762, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3031, 5777, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3032, 5784, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31416, 6169, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3034, 5790, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3042, 5805, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3045, 5813, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3049, 5827, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3055, 5834, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31417, 6169, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3063, 5849, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3064, 5850, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3066, 5855, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31418, 6169, 42, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (3072, 5866, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3073, 5867, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3077, 5877, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3079, 5880, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3080, 5881, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3081, 5883, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3086, 5891, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3087, 5892, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3093, 5903, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31419, 6169, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3098, 5909, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3099, 5912, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3100, 5913, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3101, 5914, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3103, 5920, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3105, 5922, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3106, 5923, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3108, 5925, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3111, 5930, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3104, 5921, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2987, 5697, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3089, 5894, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3014, 5752, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3114, 5935, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3119, 5941, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3120, 5943, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3123, 5947, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3127, 5953, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3130, 5958, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3131, 5960, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (3134, 5964, 9, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3135, 5965, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3137, 5968, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3138, 5973, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3139, 5974, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3142, 5977, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3091, 5898, 83, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14132, 11048, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14136, 11049, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14137, 11049, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14138, 11049, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14139, 11049, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3118, 5940, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14143, 11051, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14147, 112, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14148, 906, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14149, 906, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14150, 1929, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14151, 1929, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14152, 1929, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14153, 2623, 162, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14154, 4200, 162, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14155, 4200, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2967, 5667, 93, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (3075, 5872, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3037, 5797, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3122, 5946, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3129, 5957, 64, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (3012, 5750, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3076, 5875, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3110, 5929, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3068, 5859, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3092, 5900, 77, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (3097, 5907, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3124, 5950, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14140, 11050, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3070, 5864, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3115, 5936, 82, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (14110, 11044, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14111, 11044, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3117, 5939, 63, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3109, 5928, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3056, 5835, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3030, 5775, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3061, 5846, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3136, 5966, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3050, 5828, 78, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14156, 4200, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14159, 4891, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14160, 4989, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14161, 6398, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14162, 6398, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2942, 5615, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3113, 5934, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3084, 5889, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14131, 11047, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14104, 11043, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3018, 5757, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3025, 5765, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3078, 5878, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3125, 5951, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3035, 5794, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3132, 5961, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3029, 5773, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31829, 18284, 142, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (3116, 5937, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3052, 5830, 188, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (14125, 11046, 176, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14126, 11046, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14127, 11046, 43, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (14128, 11046, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (3121, 5945, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3095, 5905, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3112, 5932, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3094, 5904, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3083, 5888, 82, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (3090, 5897, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3071, 5865, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3024, 5763, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3088, 5893, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3062, 5848, 222, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3058, 5839, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3057, 5836, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3133, 5962, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3047, 5824, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3046, 5817, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3038, 5798, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3036, 5795, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3026, 5766, 30, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3020, 5759, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3048, 5825, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3043, 5807, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3027, 5768, 296, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (3028, 5772, 240, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3143, 5978, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (3069, 5860, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3146, 5985, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3148, 5988, 40, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3152, 5993, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2982, 5688, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3041, 5804, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3039, 5800, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3126, 5952, 8, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (14144, 9474, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14112, 11045, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14113, 11045, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3107, 5924, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3040, 5803, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22223, 14424, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22224, 14424, 33, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22225, 14424, 63, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3065, 5854, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3141, 5976, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3085, 5890, 45, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (3102, 5917, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3074, 5868, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3067, 5858, 317, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3044, 5808, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (3053, 5831, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3153, 5994, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3158, 6001, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3159, 6002, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3160, 6003, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3162, 6008, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3165, 6014, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3167, 6019, 101, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3170, 6026, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3171, 6027, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3175, 6032, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3176, 6034, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3179, 6043, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3181, 6046, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3184, 6050, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3186, 6054, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3192, 6064, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3193, 6070, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3198, 6080, 79, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3200, 6086, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3202, 6092, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3205, 6097, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3208, 6105, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3209, 6106, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3212, 6113, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3213, 6114, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3215, 6117, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3216, 6118, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3218, 6124, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3219, 6126, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3220, 6127, 80, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3225, 6137, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3226, 6139, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3227, 6142, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3229, 6144, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3230, 6145, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3232, 6147, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3245, 6169, 15, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (14167, 11052, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14168, 11052, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14169, 11052, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14170, 11053, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14171, 11053, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14172, 11054, 162, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14173, 8030, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14174, 8030, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14175, 11055, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14176, 11055, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14177, 11055, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14178, 11057, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14179, 11057, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14180, 11058, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14181, 11058, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14182, 11058, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14183, 11059, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14184, 11059, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14185, 11059, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14186, 11060, 162, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14187, 11061, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14188, 11061, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14189, 11062, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14192, 11064, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14193, 11064, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14194, 11065, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14198, 11068, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14199, 11068, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14200, 11069, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14201, 11069, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14205, 11071, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3163, 6010, 82, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (3243, 6166, 46, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3246, 6172, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3248, 6176, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3250, 6179, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3252, 6182, 46, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3256, 6190, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3258, 6193, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3259, 6194, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3261, 6198, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3263, 6200, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3264, 6201, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3265, 6202, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3269, 6208, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3271, 6211, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3274, 6215, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3275, 6216, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3194, 6073, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22227, 14425, 125, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3257, 6191, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3196, 6078, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3051, 5829, 7, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3149, 5989, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3150, 5991, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3221, 6129, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3262, 6199, 49, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14202, 11070, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3233, 6150, 297, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3234, 6151, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3169, 6023, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3228, 6143, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3144, 5983, 45, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (3254, 6187, 324, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14163, 7240, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14164, 7240, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14157, 4380, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22226, 594, 202, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3272, 6212, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3253, 6185, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3236, 6153, 87, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (3204, 6094, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3199, 6081, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3168, 6020, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3156, 5998, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3157, 5999, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3251, 6181, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3281, 6225, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3284, 6231, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3287, 6241, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3291, 6246, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3293, 6251, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3223, 6133, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3191, 6061, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14195, 11066, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3166, 6017, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3201, 6091, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (3188, 6056, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3173, 6029, 30, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3172, 6028, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3155, 5996, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3207, 6103, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3290, 6245, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3178, 6036, 7, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3247, 6173, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3214, 6116, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3260, 6197, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3280, 6224, 145, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (57, 93, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3197, 6079, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3231, 6146, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14190, 11063, 56, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3145, 5984, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3203, 6093, 77, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3270, 6210, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (3249, 6178, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3244, 6167, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3241, 6163, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3239, 6161, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3237, 6158, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (3235, 6152, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3195, 6077, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3190, 6058, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (3187, 6055, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3268, 6207, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3210, 6107, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3164, 6013, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3295, 6257, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3296, 6258, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3298, 6262, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3300, 6265, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3301, 6266, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3305, 6276, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3306, 6277, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3307, 6278, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3308, 6281, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3151, 5992, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3154, 5995, 69, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (31420, 5679, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3303, 6268, 273, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3238, 6159, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3147, 5986, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3161, 6006, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (3242, 6165, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3206, 6098, 69, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (3217, 6122, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3276, 6219, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3266, 6204, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3240, 6162, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3211, 6112, 134, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (3185, 6053, 111, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3182, 6047, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3180, 6044, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3312, 6286, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3315, 6291, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3319, 6298, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3320, 6300, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3322, 6302, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3323, 6304, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3327, 6313, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3328, 6315, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14206, 11071, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14211, 11074, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14212, 11075, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14213, 11075, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3286, 6240, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14215, 11077, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14216, 11077, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14220, 11079, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14221, 11080, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14222, 11080, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14223, 11080, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14224, 11080, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14229, 11082, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14230, 11082, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14231, 11082, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3313, 6287, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14239, 4647, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14240, 4647, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14241, 4647, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14242, 5863, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14243, 5863, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14244, 11106, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14245, 11106, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3331, 6325, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3334, 6330, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3335, 6331, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3336, 6333, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3337, 6334, 87, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3338, 6335, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3340, 6338, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3341, 6344, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3342, 6345, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3292, 6250, 15, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (3318, 6295, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3273, 6214, 185, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3345, 6350, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3346, 6351, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3347, 6352, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3348, 6356, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3353, 6365, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3354, 6366, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3357, 6370, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3359, 6372, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3361, 6374, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3363, 6376, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3364, 6377, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3396, 6433, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3369, 6385, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3379, 6400, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3380, 6403, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3385, 6408, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3386, 6411, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3387, 6415, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3388, 6418, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3391, 6421, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3393, 6425, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3398, 6437, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3400, 6440, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3401, 6441, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3404, 6445, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3405, 6446, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3411, 6454, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3417, 6462, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3410, 6453, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14214, 11076, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3407, 6449, 8, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (3333, 6328, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3279, 6223, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3394, 6430, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3414, 6459, 96, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (3277, 6220, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3282, 6229, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3339, 6337, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3376, 6395, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22229, 14426, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3304, 6271, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3267, 6205, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3283, 6230, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3390, 6420, 9, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (3366, 6382, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3402, 6443, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3395, 6432, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3362, 6375, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3177, 6035, 83, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3289, 6243, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22230, 14426, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3420, 6468, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31413, 169, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3358, 6371, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3356, 6368, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3416, 6461, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14217, 11078, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14218, 11078, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3351, 6362, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14208, 11073, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3415, 6460, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3374, 6392, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3299, 6263, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3285, 6236, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3317, 6294, 54, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3324, 6309, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14260, 9043, 184, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3408, 6450, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3397, 6434, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3360, 6373, 30, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3355, 6367, 73, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3392, 6424, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14263, 11112, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14264, 11112, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14249, 11109, 265, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (14250, 11109, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14246, 11108, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3350, 6360, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14261, 9043, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3418, 6463, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3403, 6444, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3377, 6397, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3378, 6399, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3373, 6391, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3371, 6387, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3370, 6386, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3365, 6380, 27, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (3349, 6358, 101, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3343, 6348, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3330, 6323, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3329, 6317, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3314, 6289, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (3311, 6285, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (3309, 6282, 43, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (3255, 6188, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3294, 6254, 83, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (3321, 6301, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14251, 2016, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3399, 6438, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3297, 6261, 16, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3367, 6383, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3316, 6292, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3310, 6283, 90, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14254, 1113, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14255, 1113, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (14256, 1113, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14225, 11081, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14226, 11081, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14227, 11081, 58, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3517, 6643, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14277, 11126, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14278, 11129, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14279, 11133, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14280, 11134, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14281, 11137, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14282, 11140, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14283, 11142, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14284, 11147, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14285, 11122, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14286, 11122, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14287, 11150, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14288, 11121, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14289, 11151, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3423, 6476, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3425, 6483, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3428, 6487, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3429, 6488, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3431, 6491, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3433, 6496, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3434, 6498, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3382, 6405, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3332, 6326, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3372, 6389, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3413, 6457, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3381, 6404, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (14262, 11111, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14207, 11072, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3389, 6419, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3384, 6407, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3325, 6310, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3326, 6312, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3435, 6500, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3436, 6501, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3437, 6503, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3438, 6507, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3440, 6511, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3441, 6512, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3443, 6516, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3444, 6517, 74, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3448, 6524, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3449, 6525, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3451, 6529, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3452, 6530, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3453, 6531, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3454, 6534, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31424, 6643, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3459, 6542, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3460, 6544, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3462, 6546, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3469, 6560, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3470, 6561, 80, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3471, 6562, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3473, 6564, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3479, 6572, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3480, 6573, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3482, 6576, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14267, 1375, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3368, 6384, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3409, 6451, 188, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (3487, 6589, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3488, 6590, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3489, 6591, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3497, 6608, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3499, 6610, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3507, 6626, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3513, 6635, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3514, 6636, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3519, 6648, 80, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3524, 6658, 30, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3526, 6663, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3527, 6665, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3466, 6555, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3530, 6673, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3536, 6681, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3543, 6692, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3544, 6693, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3545, 6697, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3548, 6703, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14293, 11155, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14294, 11155, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14298, 11158, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14270, 11113, 8, 3, 5);
INSERT INTO 'dancesformationsmap' VALUES (3492, 6597, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3546, 6699, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3522, 6655, 185, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3481, 6574, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3484, 6582, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3521, 6653, 1, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (3532, 6676, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14273, 11114, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3465, 6552, 54, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3503, 6615, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3512, 6633, 28, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14258, 11110, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3344, 6349, 37, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3533, 6677, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3406, 6448, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3457, 6539, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3535, 6680, 83, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (3529, 6671, 185, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (14272, 9097, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3516, 6640, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3477, 6569, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14290, 10149, 15, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3498, 6609, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14274, 11114, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14275, 11114, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22232, 14426, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (14269, 4248, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14301, 11159, 175, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14302, 11159, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31414, 169, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3554, 6719, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3557, 6723, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3558, 6726, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3559, 6727, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3561, 6730, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3562, 6732, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3563, 6733, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3565, 6735, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3567, 6737, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3570, 6742, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3572, 6745, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3573, 6746, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3574, 6747, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3575, 6750, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3422, 6473, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14276, 8932, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (3576, 6751, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3569, 6739, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3447, 6523, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3542, 6691, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3468, 6558, 9, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3490, 6592, 69, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3500, 6612, 7, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3493, 6599, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14295, 11156, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14265, 11112, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3442, 6514, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3541, 6689, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14266, 9856, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3528, 6666, 24, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3566, 6736, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3523, 6657, 87, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3501, 6613, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3496, 6606, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3538, 6683, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3531, 6675, 15, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (3525, 6661, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3510, 6631, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3506, 6621, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3556, 6722, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3502, 6614, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3495, 6601, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3494, 6600, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3472, 6563, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3464, 6551, 314, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (3463, 6550, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (3446, 6522, 64, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3432, 6492, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3445, 6518, 79, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (3426, 6484, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3424, 6481, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3421, 6471, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (3419, 6464, 114, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3504, 6616, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3537, 6682, 18, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (3439, 6510, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3456, 6536, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3486, 6587, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3577, 6753, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3578, 6754, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3581, 6759, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3586, 6770, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3589, 6776, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3590, 6777, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3591, 6778, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3599, 6789, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3600, 6790, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3603, 6793, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3604, 6794, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3607, 6799, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3610, 6802, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3612, 6808, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3613, 6810, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3614, 6812, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3621, 6821, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3623, 6827, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3626, 6831, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3627, 6832, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3632, 6842, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3639, 6851, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14311, 6425, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14312, 5652, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14313, 5652, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14317, 5280, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14318, 5280, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14320, 3820, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3461, 6545, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3534, 6679, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14303, 11107, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3491, 6596, 75, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3505, 6619, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3547, 6701, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3549, 6704, 80, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3540, 6686, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3539, 6685, 183, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (3518, 6646, 76, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (3515, 6637, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3511, 6632, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3485, 6583, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3467, 6556, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3508, 6627, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3582, 6763, 311, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14323, 6266, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14324, 6266, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14325, 3534, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14326, 1117, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14327, 1117, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14328, 1117, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14329, 1117, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14330, 1117, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14331, 2689, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14336, 3599, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14337, 620, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14338, 620, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14339, 621, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14340, 4387, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14341, 4387, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14342, 1241, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14343, 7216, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14344, 7216, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14345, 4076, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14346, 6831, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3564, 6734, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3601, 6791, 87, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3587, 6771, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (3646, 6865, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3647, 6867, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3648, 6868, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3649, 6869, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3650, 6871, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3653, 6878, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3656, 6884, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3657, 6886, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3659, 6888, 63, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3661, 6892, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3668, 6911, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3670, 6916, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3672, 6920, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3673, 6921, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3674, 6924, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3676, 6929, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3679, 6934, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3681, 6938, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3682, 6940, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3684, 6942, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14299, 11158, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (14349, 5389, 42, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (3553, 6715, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3631, 6841, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3585, 6768, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3520, 6650, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3630, 6839, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3598, 6788, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14306, 10497, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14314, 5900, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3640, 6858, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3637, 6848, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3571, 6744, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3560, 6729, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3620, 6819, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3658, 6887, 185, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3609, 6801, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3643, 6861, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14300, 11158, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (3611, 6805, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3594, 6782, 75, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3616, 6815, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3686, 6944, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3698, 6968, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3699, 6969, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3702, 6973, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3703, 6974, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3706, 6984, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3707, 6985, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3708, 6986, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3714, 7003, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3715, 7007, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3716, 7010, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3717, 7011, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3719, 7014, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3720, 7015, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3724, 7021, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3725, 7022, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3655, 6880, 56, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3680, 6936, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3625, 6830, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3709, 6990, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14321, 184, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3615, 6813, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3675, 6928, 69, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3645, 6864, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3726, 7025, 138, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3608, 6800, 5, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3568, 6738, 76, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (3593, 6781, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3618, 6817, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3711, 6996, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3664, 6901, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3728, 7030, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3644, 6862, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3696, 6965, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3677, 6930, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3552, 6710, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3583, 6766, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14309, 7723, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3718, 7013, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3727, 7028, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3712, 6997, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3688, 6952, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3683, 6941, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3678, 6931, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3671, 6919, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3654, 6879, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3660, 6890, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3652, 6876, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3642, 6860, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3638, 6849, 7, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3636, 6847, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3635, 6846, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3628, 6833, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3617, 6816, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (3605, 6797, 69, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (3595, 6783, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3580, 6758, 72, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (3584, 6767, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3555, 6720, 2, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3663, 6899, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14347, 6724, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14332, 2835, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14319, 2642, 114, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (3596, 6786, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3634, 6845, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14316, 4123, 43, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (3700, 6971, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3735, 7046, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14351, 11160, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14362, 459, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14363, 459, 43, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (14364, 3120, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14365, 3120, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14366, 3120, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14369, 6525, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14370, 5639, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14371, 5877, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14372, 348, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14373, 348, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14374, 6934, 127, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14375, 1920, 131, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14376, 6184, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14377, 4054, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14378, 2417, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14379, 5052, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14380, 4687, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14381, 4089, 203, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14382, 6411, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14383, 6132, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14384, 6132, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14385, 1462, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14386, 1462, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14387, 1462, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14388, 4801, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14389, 4056, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14390, 36, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14392, 4168, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14393, 4168, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14394, 4168, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31425, 3170, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31426, 3170, 168, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22244, 8383, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3606, 6798, 87, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (3602, 6792, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3588, 6774, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (3597, 6787, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3651, 6873, 1, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (14308, 10938, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3731, 7042, 28, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3705, 6982, 129, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3693, 6962, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3669, 6915, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (3666, 6904, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3665, 6902, 164, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3622, 6824, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3633, 6843, 4, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (14391, 3415, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22245, 8383, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22246, 8383, 157, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22251, 1244, 255, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22252, 1244, 12, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22253, 1244, 157, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3736, 7047, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3737, 7048, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3739, 7056, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3662, 6897, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (3740, 7059, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3743, 7066, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3745, 7070, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31427, 3170, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3750, 7076, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3751, 7078, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3755, 7083, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3757, 7086, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3761, 7095, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3764, 7100, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3766, 7102, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3769, 7108, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3770, 7109, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3773, 7114, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3774, 7115, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3777, 7122, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3778, 7123, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3780, 7128, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3782, 7130, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3785, 7134, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3801, 7163, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3807, 7177, 3, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3809, 7179, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3811, 7181, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3813, 7184, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3814, 7185, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3815, 7186, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3818, 7194, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3821, 7200, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3823, 7202, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3695, 6964, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3753, 7080, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3776, 7118, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3768, 7106, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3765, 7101, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3690, 6955, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3793, 7148, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3685, 6943, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14352, 4356, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22235, 14428, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14367, 5125, 46, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3822, 7201, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3694, 6963, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3796, 7153, 38, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3752, 7079, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3721, 7017, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3820, 7197, 27, 1, 5);
INSERT INTO 'dancesformationsmap' VALUES (3784, 7133, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3824, 7203, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3825, 7205, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3827, 7208, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14395, 3087, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14396, 3087, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14397, 2304, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14398, 1174, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14399, 1174, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14400, 1174, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14401, 3086, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14402, 3086, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14403, 8216, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14404, 8216, 46, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14405, 7481, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14414, 11162, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14415, 11162, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14416, 11162, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31428, 5506, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14429, 11157, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14430, 11157, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14431, 11153, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14432, 11153, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14433, 11153, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14409, 8075, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14410, 8075, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14411, 8075, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14412, 8075, 143, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22240, 8377, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22241, 8377, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22242, 8377, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22247, 8383, 234, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (3804, 7173, 74, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22243, 8380, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22250, 3980, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3758, 7087, 10, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (3691, 6957, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3689, 6954, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3697, 6967, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3730, 7037, 8, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (3733, 7044, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3734, 7045, 86, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (3744, 7068, 31, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3729, 7035, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (3741, 7062, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3756, 7084, 84, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (14434, 11154, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14435, 11154, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3819, 7195, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3808, 7178, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3797, 7157, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3802, 7164, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3790, 7143, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3789, 7142, 32, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (3781, 7129, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3771, 7110, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3759, 7088, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3754, 7081, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3749, 7075, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3747, 7073, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3746, 7071, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3704, 6981, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3723, 7020, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3803, 7172, 311, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (3791, 7144, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14361, 4879, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3787, 7138, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3775, 7116, 18, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22239, 10507, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3788, 7139, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3795, 7152, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3828, 7209, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3835, 7231, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3838, 7236, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3839, 7237, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3842, 7244, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3844, 7246, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3846, 7249, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3847, 7254, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3848, 7255, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3850, 7258, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3854, 7263, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3858, 7269, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3863, 17, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3865, 23, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3866, 25, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3868, 33, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3869, 34, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3871, 42, 12, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31429, 5506, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14413, 6057, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14407, 223, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3860, 6, 263, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3880, 65, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3884, 74, 56, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3891, 84, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3892, 85, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3893, 86, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3899, 110, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3901, 118, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3902, 119, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3903, 125, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3909, 142, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3910, 143, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3912, 145, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3913, 147, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3918, 156, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3887, 78, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14350, 6972, 9, 11, 3);
INSERT INTO 'dancesformationsmap' VALUES (3772, 7111, 83, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3763, 7099, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3836, 7233, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3817, 7193, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3816, 7190, 5, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (3805, 7174, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3798, 7159, 87, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (3732, 7043, 330, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3687, 6946, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3861, 13, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3783, 7132, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3851, 7259, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3692, 6959, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22254, 14429, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3859, 2, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14462, 9898, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14476, 11218, 181, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14477, 11218, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14478, 11218, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22248, 8385, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3870, 40, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3875, 54, 7, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (14450, 11185, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14451, 11185, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (14457, 11188, 168, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3837, 7234, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14406, 8226, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3897, 95, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3878, 57, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3911, 144, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14426, 10655, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14427, 10655, 285, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14428, 10655, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (14443, 11194, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14444, 11194, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14445, 11194, 132, 29, 3);
INSERT INTO 'dancesformationsmap' VALUES (3810, 7180, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22238, 14428, 8, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (3760, 7090, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14472, 10557, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (3873, 45, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3853, 7262, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3882, 67, 87, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (3874, 51, 336, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14420, 8043, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3831, 7218, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3925, 180, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3926, 182, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3931, 193, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3932, 194, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3933, 199, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31430, 5506, 249, 4, 4);
INSERT INTO 'dancesformationsmap' VALUES (3936, 211, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3939, 221, 103, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (3989, 395, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3946, 233, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3948, 236, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3949, 238, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4018, 480, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3952, 248, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3961, 293, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3966, 317, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3971, 330, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3976, 341, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3979, 362, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3982, 372, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3988, 393, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3993, 403, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3997, 425, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3792, 7147, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3929, 189, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3864, 22, 9, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (3834, 7226, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3830, 7215, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3914, 150, 60, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3920, 162, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14453, 11186, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3937, 212, 296, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14464, 11164, 36, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (14465, 11164, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3886, 77, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3832, 7219, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3856, 7265, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14473, 11217, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3904, 128, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (3877, 56, 16, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4053, 570, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3742, 7065, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3890, 83, 265, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (3885, 76, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22259, 14430, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3895, 92, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3962, 295, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14424, 11163, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14425, 11163, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14446, 8726, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (14447, 8726, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14474, 11217, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3862, 14, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3876, 55, 7, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3883, 73, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3896, 93, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (3898, 98, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3917, 155, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3935, 202, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14460, 11190, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14461, 11190, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3852, 7260, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3857, 7267, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3849, 7257, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3843, 7245, 45, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3841, 7242, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3833, 7220, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (3800, 7162, 188, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3995, 414, 61, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (14438, 11192, 149, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14436, 11191, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3879, 59, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14459, 11189, 69, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (3829, 7211, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3855, 7264, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3889, 82, 18, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (3907, 135, 188, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (3888, 81, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3996, 420, 42, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (3992, 400, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (3985, 382, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3984, 377, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3973, 335, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (3969, 326, 145, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (3947, 235, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3908, 140, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (3894, 89, 6, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3738, 7055, 74, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3840, 7239, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4001, 435, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4006, 446, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4007, 449, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4012, 466, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4014, 470, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3915, 152, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3900, 116, 16, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (14448, 11184, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3941, 223, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4020, 486, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4023, 494, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4024, 496, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4027, 500, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4029, 506, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4030, 507, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4033, 514, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4039, 531, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4049, 552, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4050, 553, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4051, 555, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14479, 11218, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14480, 11218, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4052, 561, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4063, 591, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22249, 8386, 157, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (4070, 608, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4071, 610, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4073, 613, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4078, 632, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4081, 639, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4083, 643, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4085, 646, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4086, 648, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4092, 657, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14458, 11188, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3974, 336, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3924, 178, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3930, 190, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3978, 353, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4009, 462, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3959, 291, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3944, 231, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4082, 640, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14335, 2310, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3934, 200, 62, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4031, 509, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14419, 4990, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3928, 185, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3953, 262, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3960, 292, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (3986, 390, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4067, 599, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3943, 230, 72, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (3872, 43, 4, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (14417, 6148, 1, 34, 2);
INSERT INTO 'dancesformationsmap' VALUES (3826, 7206, 19, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (4080, 636, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (3972, 334, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14469, 11170, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3845, 7247, 8, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (3867, 30, 72, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (3980, 364, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4011, 465, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3994, 410, 7, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (3906, 132, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3983, 373, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14470, 11216, 8, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (3981, 367, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3956, 278, 193, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4061, 588, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14494, 9898, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3998, 428, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (3965, 316, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4037, 523, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4062, 590, 24, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4056, 573, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3991, 398, 9, 19, 3);
INSERT INTO 'dancesformationsmap' VALUES (3922, 173, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (3945, 232, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4044, 544, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4017, 476, 55, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4019, 482, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3970, 328, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4093, 658, 149, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (4095, 661, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4098, 668, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4106, 688, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4117, 723, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4118, 728, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4124, 740, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4127, 749, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4133, 757, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4137, 771, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4140, 775, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4141, 777, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14506, 10332, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14507, 10318, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14530, 7344, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14531, 7344, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31431, 2038, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4125, 743, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4036, 522, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4126, 745, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4010, 464, 9, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (4074, 624, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4048, 551, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4132, 755, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4025, 497, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4000, 432, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3958, 289, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (3921, 164, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4130, 753, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4055, 572, 72, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (14524, 274, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3968, 324, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3999, 431, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4045, 547, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4186, 924, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3977, 352, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4013, 467, 65, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4075, 625, 91, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (4040, 535, 9, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4032, 513, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4068, 603, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4066, 597, 312, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4142, 778, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4077, 629, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14513, 100, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3923, 174, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14508, 11258, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14509, 11258, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14488, 11221, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14489, 11221, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14490, 11221, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14484, 11220, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14516, 10761, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14517, 10761, 28, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14497, 10533, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14498, 10533, 114, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4113, 712, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14532, 9453, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14533, 9453, 168, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14534, 9453, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4047, 550, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (3975, 339, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4005, 445, 265, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (14233, 77, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4022, 491, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4079, 633, 54, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (14495, 1829, 9, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14496, 1829, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4135, 765, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4121, 735, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4116, 717, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4105, 687, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4101, 672, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4100, 671, 45, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4096, 662, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4094, 660, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4091, 655, 72, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4088, 650, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4084, 644, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4065, 596, 7, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (4058, 578, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4054, 571, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4046, 549, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4043, 543, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4041, 540, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4038, 530, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4034, 519, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4016, 475, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4015, 474, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4004, 443, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4003, 440, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3964, 306, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3955, 271, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3954, 268, 85, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (4069, 605, 24, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4143, 779, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4145, 783, 80, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4153, 817, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4157, 826, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4160, 835, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4179, 903, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4188, 933, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4195, 943, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4197, 949, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4192, 940, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4210, 993, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4211, 996, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4213, 1006, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4222, 1023, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4111, 702, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4108, 696, 65, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4138, 773, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4177, 900, 20, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14535, 11259, 278, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4209, 987, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4196, 945, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4064, 594, 55, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4174, 891, 9, 19, 4);
INSERT INTO 'dancesformationsmap' VALUES (4170, 881, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4152, 812, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4115, 716, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4191, 939, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14491, 10703, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (4103, 682, 30, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (4072, 611, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4122, 738, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4200, 959, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4131, 754, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4169, 878, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4123, 739, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4201, 965, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4214, 1007, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4158, 829, 175, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (4155, 820, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4134, 763, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (4128, 750, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14518, 160, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14519, 160, 185, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (14520, 160, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4129, 751, 87, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4120, 732, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4182, 909, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4231, 1044, 7, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4233, 1049, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4235, 1057, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14548, 11262, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14549, 11262, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14550, 11262, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14551, 11263, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14552, 11263, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14556, 11265, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14557, 11265, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14558, 11266, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14559, 11266, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4228, 1037, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4144, 782, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3957, 282, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4035, 521, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4109, 698, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4175, 892, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14467, 11170, 85, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14565, 11268, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14566, 11268, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14567, 11268, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14576, 7568, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14577, 7568, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14578, 7568, 188, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14579, 7568, 15, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14580, 7568, 5, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (4148, 796, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4206, 981, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4243, 1081, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4244, 1083, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4245, 1090, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4247, 1094, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4248, 1098, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4249, 1101, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4230, 1040, 365, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4251, 1106, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4252, 1130, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4254, 1137, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4257, 1144, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4258, 1146, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4261, 1150, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4266, 1159, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4171, 886, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4107, 694, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4136, 769, 20, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (4198, 956, 58, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4099, 670, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4156, 824, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4147, 794, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14538, 11260, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4176, 899, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4112, 707, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4097, 665, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (4150, 800, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4162, 843, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4173, 889, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4185, 919, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4207, 985, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4212, 1004, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4225, 1027, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4216, 1013, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4180, 905, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31825, 18284, 85, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14526, 280, 372, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4172, 888, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14541, 11261, 375, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14569, 2668, 37, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4267, 1162, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14501, 10534, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14502, 10534, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14542, 11261, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14543, 11223, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14544, 11223, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14545, 11223, 114, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (14546, 11223, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14510, 11027, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14511, 11027, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (14512, 11027, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14581, 7567, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14582, 7567, 145, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14583, 7567, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14234, 77, 82, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (4166, 855, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14560, 7093, 20, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14561, 7093, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (14571, 7566, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14572, 7566, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14573, 7566, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14574, 7566, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4189, 935, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4320, 1366, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4264, 1154, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4263, 1153, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4255, 1141, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4262, 1152, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4253, 1131, 56, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4183, 910, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4246, 1093, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4239, 1068, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4241, 1073, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4227, 1034, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4226, 1029, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4221, 1022, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4220, 1020, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4218, 1018, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4217, 1017, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4215, 1008, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4204, 974, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (4203, 972, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4202, 971, 234, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (4199, 958, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4194, 942, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4193, 941, 355, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4187, 932, 145, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4168, 871, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4167, 867, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4165, 853, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4164, 852, 294, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4161, 841, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4154, 819, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4151, 803, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4149, 797, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4114, 715, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4104, 685, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4090, 654, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4159, 830, 29, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4076, 627, 55, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (4270, 1177, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4272, 1184, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4273, 1185, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4223, 1024, 33, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (4265, 1158, 134, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4276, 1199, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4277, 1209, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4278, 1210, 52, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4279, 1213, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4280, 1216, 88, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4282, 1225, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4291, 1267, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4298, 1291, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4299, 1299, 28, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4300, 1301, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4302, 1309, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4303, 1312, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4309, 1334, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4310, 1340, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4312, 1348, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4315, 1351, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4323, 1373, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4324, 1374, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4328, 1379, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4275, 1198, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14591, 3641, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14592, 3641, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14593, 3641, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14594, 3641, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14597, 1335, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14598, 3421, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14600, 5535, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14628, 11274, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14620, 11270, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14621, 11270, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14624, 11272, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14625, 11272, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14626, 11272, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4304, 1318, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14568, 5703, 120, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4178, 902, 119, 18, 2);
INSERT INTO 'dancesformationsmap' VALUES (14584, 3008, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14585, 3008, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4292, 1274, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4260, 1148, 114, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14627, 11273, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4238, 1065, 22, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4224, 1025, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14622, 11271, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14623, 11271, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4184, 916, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4240, 1069, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4327, 1378, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (4305, 1319, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4288, 1251, 6, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4259, 1147, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4236, 1058, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4234, 1050, 145, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (4232, 1045, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4297, 1288, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14632, 11276, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4286, 1244, 52, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22264, 14431, 216, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22265, 14431, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22268, 14434, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22269, 14434, 114, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22270, 14434, 58, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (4237, 1064, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4290, 1259, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4190, 936, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4181, 908, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4229, 1039, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14522, 170, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4219, 1019, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14610, 11269, 154, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (14611, 11269, 224, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14612, 11269, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4330, 1386, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4338, 1410, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4340, 1418, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4341, 1422, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4342, 1423, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4347, 1440, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4348, 1442, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4350, 1448, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4351, 1450, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4423, 1666, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4381, 1527, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4400, 1593, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4402, 1598, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4410, 1627, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4412, 1631, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4325, 1375, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4367, 1492, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4389, 1559, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4416, 1644, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4417, 1650, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4418, 1651, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4419, 1658, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4420, 1659, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4421, 1663, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14633, 11276, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4256, 1142, 202, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (4284, 1231, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (4269, 1176, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4294, 1278, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4409, 1625, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4405, 1616, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22262, 14430, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4359, 1469, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4242, 1077, 18, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (14599, 5174, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4333, 1389, 80, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4339, 1413, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4296, 1283, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14618, 1075, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14613, 9406, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14629, 11275, 202, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14630, 11275, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14553, 11264, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14554, 11264, 365, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (14555, 11264, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14615, 9407, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14616, 9407, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14606, 8992, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14607, 8992, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14608, 8992, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4307, 1329, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14614, 1907, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4163, 845, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4394, 1573, 32, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4395, 1577, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4371, 1505, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4396, 1579, 64, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14595, 4517, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (14596, 4517, 61, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (4391, 1567, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (4390, 1564, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4386, 1553, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4384, 1547, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4380, 1526, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4369, 1498, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4364, 1481, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4361, 1474, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (4358, 1467, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4353, 1457, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4301, 1304, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4346, 1431, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4344, 1427, 18, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4337, 1409, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4326, 1376, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4321, 1367, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4319, 1364, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (4318, 1359, 54, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4316, 1353, 18, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4314, 1350, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4308, 1331, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4289, 1252, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (4287, 1246, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4271, 1179, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4268, 1171, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4274, 1194, 84, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4250, 1103, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4352, 1451, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14601, 5853, 204, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14634, 11276, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14635, 11276, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14636, 11276, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4377, 1520, 119, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (3475, 6567, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4397, 1582, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3799, 7161, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14661, 11297, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14662, 11297, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14663, 11297, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14667, 11306, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14668, 11306, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14669, 11306, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14670, 11306, 121, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14671, 11306, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14672, 11307, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14673, 11307, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14674, 11307, 109, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14639, 11277, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14640, 11277, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14641, 11277, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14643, 11278, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14644, 11278, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14645, 11278, 15, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14646, 11279, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14647, 11279, 162, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14648, 11279, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14649, 11280, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14650, 11280, 156, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14651, 11280, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14652, 11280, 19, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14653, 11281, 84, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14654, 11281, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22266, 14431, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22267, 14431, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4442, 1726, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4426, 1682, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4427, 1693, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4430, 1699, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4432, 1702, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4433, 1705, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4434, 1706, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14664, 11298, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14665, 11298, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4447, 1745, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4392, 1568, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4281, 1218, 8, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (4450, 1758, 37, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4436, 1708, 69, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (4345, 1430, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22271, 14435, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (4293, 1277, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4331, 1387, 168, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (4411, 1629, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4366, 1486, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4437, 1709, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4387, 1554, 225, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4360, 1471, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4404, 1615, 20, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4444, 1731, 7, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (4440, 1716, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4425, 1679, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4414, 1638, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4407, 1621, 49, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4382, 1539, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4374, 1510, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4372, 1507, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4363, 1477, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4335, 1399, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (4332, 1388, 176, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4368, 1495, 336, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (4356, 1465, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4385, 1551, 33, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (4343, 1424, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (4460, 1785, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4467, 1799, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4349, 1445, 261, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (4415, 1639, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4376, 1518, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4334, 1398, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4388, 1556, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4399, 1586, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4453, 1766, 112, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4403, 1603, 8, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4354, 1460, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4355, 1461, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4408, 1622, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14562, 11267, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (4379, 1524, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4329, 1384, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4471, 1809, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4473, 1812, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4476, 1825, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4484, 1845, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4526, 1969, 145, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4490, 1859, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4492, 1863, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4494, 1865, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4496, 1871, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4501, 1895, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4504, 1904, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31433, 6567, 353, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4510, 1930, 24, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4511, 1933, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4512, 1935, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4513, 1936, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4528, 1976, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4529, 1987, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4622, 2291, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4537, 2015, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4546, 2040, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4548, 2043, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4514, 1940, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4543, 2034, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14642, 11278, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14683, 11290, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14684, 11290, 193, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14685, 11291, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14686, 11291, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14680, 11288, 65, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14687, 11291, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14688, 11292, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14689, 11292, 134, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14682, 11287, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4553, 2053, 61, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (4428, 1696, 149, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4544, 2035, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4422, 1664, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4393, 1569, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4431, 1701, 77, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4398, 1584, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4370, 1501, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4459, 1783, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4486, 1848, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4472, 1811, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4534, 2008, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4500, 1892, 114, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (4452, 1765, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4462, 1790, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14656, 11299, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4475, 1818, 96, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (14631, 11275, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14637, 10066, 185, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4502, 1896, 90, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (4429, 1698, 63, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (4454, 1770, 87, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4531, 1997, 87, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4532, 2000, 69, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (4527, 1974, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4509, 1928, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4505, 1908, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4485, 1847, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4479, 1830, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4478, 1829, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4477, 1826, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4458, 1780, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4497, 1878, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4456, 1774, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4451, 1760, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4449, 1757, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4448, 1756, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4445, 1733, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4441, 1722, 119, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (4439, 1712, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4435, 1707, 72, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (4401, 1596, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4383, 1543, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4365, 1483, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4362, 1475, 7, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4336, 1402, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4549, 2044, 16, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4533, 2006, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4491, 1861, 76, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (4520, 1954, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4524, 1962, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4518, 1952, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4554, 2055, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4573, 2148, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4519, 1953, 249, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4561, 2082, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14676, 11289, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4565, 2114, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4566, 2116, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4568, 2127, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4570, 2136, 30, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4574, 2152, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4580, 2166, 16, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4581, 2167, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4586, 2178, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4588, 2181, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4589, 2185, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4592, 2197, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4594, 2210, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4596, 2219, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4598, 2234, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4603, 2240, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4605, 2248, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4606, 2252, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4611, 2264, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4613, 2272, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4614, 2273, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4616, 2277, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4618, 2282, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4619, 2283, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4620, 2287, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4625, 2299, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4627, 2309, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4630, 2325, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4465, 1795, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4521, 1957, 175, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (4446, 1743, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4593, 2206, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4507, 1912, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4552, 2052, 145, 29, 3);
INSERT INTO 'dancesformationsmap' VALUES (4602, 2238, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4536, 2014, 48, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4551, 2048, 158, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4508, 1916, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4457, 1777, 36, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (4466, 1796, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4538, 2018, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4530, 1996, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4463, 1792, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4610, 2263, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4517, 1951, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4481, 1833, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4563, 2101, 336, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (4482, 1834, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4599, 2235, 59, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4631, 2330, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4716, 2600, 101, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14701, 11295, 9, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14702, 11295, 125, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14703, 11295, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14713, 11285, 59, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14728, 11352, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14729, 11352, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14730, 11352, 168, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14731, 11353, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14732, 11353, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4571, 2138, 58, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (14714, 11286, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14715, 11286, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14716, 11286, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14717, 11286, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14690, 11292, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14691, 11293, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14692, 11293, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14693, 11293, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14694, 11293, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14695, 11293, 36, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4645, 2366, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4539, 2021, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4498, 1883, 18, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (4522, 1960, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4541, 2026, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (4438, 1711, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4572, 2139, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4480, 1831, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14696, 11294, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14697, 11294, 33, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14698, 11294, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4503, 1903, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4487, 1850, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4595, 2211, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4634, 2337, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4632, 2332, 24, 18, 1);
INSERT INTO 'dancesformationsmap' VALUES (14655, 9090, 265, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (4470, 1807, 20, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (4576, 2154, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4647, 2369, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4649, 2374, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4650, 2375, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4655, 2397, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4659, 2404, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4660, 2406, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4661, 2412, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4663, 2417, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4665, 2426, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4706, 2562, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4582, 2168, 16, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (4679, 2476, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4680, 2486, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4690, 2520, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4691, 2532, 83, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4695, 2537, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4697, 2539, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4700, 2547, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4701, 2548, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4628, 2315, 78, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4515, 1946, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4455, 1773, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4685, 2498, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4654, 2396, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4564, 2102, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4688, 2510, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4575, 2153, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4607, 2257, 1, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (4540, 2024, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4461, 1786, 45, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4483, 1838, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4577, 2156, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4587, 2180, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4557, 2069, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4558, 2076, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4669, 2431, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4699, 2543, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4584, 2173, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14721, 1937, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4562, 2084, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4609, 2259, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14675, 11308, 143, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14725, 10356, 32, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4681, 2491, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4626, 2306, 9, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4646, 2367, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4597, 2223, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4673, 2456, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4696, 2538, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4677, 2471, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4676, 2469, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4675, 2465, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4652, 2389, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4633, 2333, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4641, 2356, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4637, 2350, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4624, 2295, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4621, 2288, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4617, 2278, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4608, 2258, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4601, 2237, 5, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4591, 2196, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4590, 2189, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4583, 2169, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4579, 2162, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4578, 2157, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4569, 2130, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (4560, 2079, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4555, 2060, 76, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4547, 2042, 18, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4525, 1965, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4523, 1961, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4506, 1909, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4499, 1884, 265, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (4495, 1866, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4489, 1857, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (4468, 1804, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4488, 1856, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4424, 1677, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4689, 2513, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4612, 2269, 90, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (4705, 2560, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31432, 6567, 317, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4710, 2576, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4715, 2598, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4720, 2622, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4721, 2626, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4730, 2650, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4731, 2658, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4733, 2663, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14733, 11353, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14734, 11353, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14735, 11354, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14736, 11356, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14737, 11356, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14738, 11356, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14739, 11357, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14740, 11357, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14741, 11357, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14751, 11361, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14752, 11362, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14753, 11362, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4670, 2432, 7, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4657, 2399, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4687, 2509, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4723, 2631, 1, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (22309, 3405, 7, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14754, 11363, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14755, 11363, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14756, 11363, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14742, 11358, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4640, 2355, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4732, 2661, 30, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (14718, 11296, 112, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14719, 11296, 262, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14704, 11282, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4648, 2370, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (4702, 2551, 72, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4712, 2583, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4698, 2540, 73, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4674, 2462, 6, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4671, 2433, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14705, 4165, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14720, 11296, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1550, 2951, 25, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22288, 2951, 131, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22289, 14440, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22290, 14440, 5, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22291, 14440, 59, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (4738, 2680, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4739, 2682, 16, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (4742, 2691, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4743, 2693, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4744, 2696, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4746, 2703, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4753, 2726, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4755, 2728, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4756, 2729, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4758, 2733, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4760, 2735, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4767, 2750, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4769, 2758, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4770, 2759, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4772, 2761, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4773, 2763, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4780, 2784, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4787, 2808, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4790, 2817, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4800, 2841, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4802, 2844, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4806, 2863, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4808, 2869, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4810, 2875, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4813, 2879, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4815, 2885, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4783, 2802, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4820, 2904, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4826, 2916, 9, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14814, 11401, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14815, 11401, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14816, 11401, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14757, 11364, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14773, 11370, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14745, 11359, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4636, 2349, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4814, 2880, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4567, 2125, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14711, 11284, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14712, 11284, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4804, 2858, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4651, 2386, 189, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (22276, 14436, 37, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4629, 2323, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4653, 2395, 16, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (4693, 2535, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4797, 2830, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4635, 2345, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4735, 2673, 7, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (4734, 2667, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4718, 2616, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4666, 2427, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4656, 2398, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14774, 11370, 87, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4703, 2556, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14706, 11283, 33, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14707, 11283, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4667, 2428, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4644, 2363, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4682, 2492, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4748, 2707, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4785, 2806, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4704, 2557, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4768, 2757, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4757, 2730, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (1438, 2725, 176, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4678, 2475, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3950, 240, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4736, 2674, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4662, 2415, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4793, 2822, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14813, 4477, 77, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (4727, 2644, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (14788, 11373, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (4668, 2430, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14789, 11373, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14780, 11371, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14781, 11371, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (14782, 11371, 173, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14783, 11371, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (14770, 11369, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14771, 11369, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14772, 11369, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (14767, 11368, 201, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14768, 11368, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14769, 11368, 134, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (14763, 11367, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14764, 11367, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14765, 11367, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14766, 11367, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (14799, 11187, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14800, 11187, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14801, 11187, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4811, 2877, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (4719, 2617, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4642, 2357, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4643, 2360, 86, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (4825, 2914, 87, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4726, 2639, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14810, 6386, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14811, 6386, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14812, 6386, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14805, 5204, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (14806, 5204, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (14809, 4720, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4737, 2675, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4822, 2906, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4819, 2903, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4812, 2878, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4809, 2871, 248, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4805, 2859, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4792, 2821, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4781, 2789, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4778, 2781, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4761, 2736, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4759, 2734, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4754, 2727, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4752, 2725, 58, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4741, 2688, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4722, 2629, 12, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4711, 2578, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4709, 2568, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4664, 2419, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4658, 2402, 46, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4638, 2352, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (4708, 2566, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4725, 2636, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4799, 2836, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4786, 2807, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4774, 2767, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22301, 1520, 9, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4823, 2908, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22316, 14485, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22317, 14485, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22318, 14485, 202, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14790, 11374, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (14791, 11374, 92, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14792, 11374, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4829, 2921, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4836, 2937, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4747, 2705, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4842, 2964, 62, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4850, 2994, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4853, 3000, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4683, 2493, 144, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14798, 11185, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22310, 3405, 238, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14802, 11188, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22311, 3405, 119, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (2947, 5625, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14785, 11372, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14786, 11372, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14787, 11372, 173, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4765, 2746, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4833, 2930, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4791, 2820, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4848, 2988, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4803, 2852, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4762, 2737, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4775, 2768, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4672, 2443, 55, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22297, 14482, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1892, 3588, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4766, 2747, 16, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4837, 2943, 183, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (4784, 2803, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4801, 2842, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4745, 2701, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22300, 7090, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22294, 7180, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14748, 11360, 157, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4828, 2920, 69, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (4824, 2911, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4795, 2825, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4779, 2782, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (4771, 2760, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4749, 2708, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22296, 3252, 184, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22293, 4890, 184, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4859, 3028, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4860, 3029, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4866, 3050, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4869, 3056, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4899, 3144, 61, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4872, 3060, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4873, 3061, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4875, 3064, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4878, 3070, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4879, 3072, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4880, 3073, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4881, 3076, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4884, 3086, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4886, 3103, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4897, 3138, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4902, 3151, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4904, 3156, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4905, 3164, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4909, 3175, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4913, 3187, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4914, 3198, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4916, 3204, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4917, 3205, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4919, 3215, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14830, 8944, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4906, 3165, 42, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (14794, 11376, 43, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (14795, 11376, 69, 41, 4);
INSERT INTO 'dancesformationsmap' VALUES (4910, 3176, 83, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (4858, 3027, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4896, 3137, 22, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22342, 14520, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14838, 9949, 168, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14839, 9949, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14840, 9949, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14841, 9949, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14842, 11409, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14843, 11409, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14844, 11409, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4908, 3170, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14854, 11428, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14855, 11428, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14856, 11428, 77, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14857, 11428, 27, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14858, 11429, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14831, 9946, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4855, 3021, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22302, 2857, 222, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22303, 2857, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22304, 2857, 13, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4717, 2608, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4867, 3052, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4714, 2595, 149, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4856, 3022, 27, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14819, 11403, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (4827, 2918, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4898, 3142, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22313, 4619, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22314, 4619, 39, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22319, 14485, 112, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22320, 14485, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22329, 14488, 24, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22330, 14488, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22331, 14488, 192, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (4994, 3435, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4925, 3237, 33, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4927, 3248, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4930, 3255, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4929, 3254, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22336, 14098, 119, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4862, 3037, 8, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (4789, 2815, 175, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4777, 2780, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4713, 2593, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4818, 2896, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4817, 2887, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4834, 2934, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4870, 3057, 87, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (4903, 3154, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4750, 2709, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4807, 2868, 17, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4841, 2962, 112, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4889, 3111, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4776, 2777, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14851, 11427, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14823, 11404, 7, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14824, 11404, 46, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14825, 11404, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (14820, 11402, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4874, 3063, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4782, 2801, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14832, 9947, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4846, 2980, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4851, 2997, 65, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4868, 3053, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4821, 2905, 43, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (4724, 2632, 112, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4788, 2813, 145, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (4922, 3225, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14845, 3645, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14846, 3645, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4934, 3261, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4931, 3256, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4918, 3207, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4928, 3250, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4900, 3145, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4888, 3105, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4883, 3084, 18, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (4882, 3080, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (4865, 3047, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4852, 2999, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4849, 2990, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4845, 2979, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4843, 2970, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4831, 2926, 77, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (4840, 2957, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4796, 2826, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4764, 2745, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4751, 2717, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14807, 2267, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4895, 3135, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4835, 2936, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14808, 340, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4937, 3269, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4938, 3278, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4939, 3279, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4942, 3283, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4943, 3286, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4946, 3292, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4947, 3303, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4948, 3304, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4949, 3307, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4952, 3315, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4953, 3319, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4957, 3330, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4963, 3347, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4966, 3359, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4968, 3362, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4971, 3369, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4973, 3384, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4974, 3385, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5021, 3498, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4976, 3389, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4863, 3038, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4920, 3220, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4887, 3104, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4981, 3406, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14848, 8939, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14849, 8939, 209, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4830, 2925, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4864, 3045, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4921, 3221, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4891, 3127, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4885, 3092, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4933, 3260, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4832, 2927, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4839, 2956, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (4972, 3378, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4970, 3368, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (4965, 3358, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4964, 3352, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14817, 1187, 124, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14818, 1187, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4915, 3202, 83, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4894, 3134, 84, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4984, 3410, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4989, 3419, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4992, 3427, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4999, 3445, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5008, 3468, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5036, 3549, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (5042, 3577, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5016, 3491, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5018, 3494, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5019, 3495, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5020, 3497, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5045, 3581, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5048, 3585, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14859, 11429, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14860, 11430, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14861, 11430, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14862, 11431, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14863, 11431, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14864, 11431, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14865, 11431, 175, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14866, 11431, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14867, 11432, 59, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22337, 14518, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14836, 9948, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14837, 9948, 142, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5031, 3536, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (14868, 11432, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14869, 11432, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14870, 11433, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14871, 11433, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14872, 11433, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14873, 11433, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5055, 3603, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5064, 3621, 22, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5067, 3630, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5074, 3643, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5076, 3647, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5077, 3648, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5083, 3661, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5085, 3670, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5087, 3676, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5090, 3686, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4993, 3431, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5097, 3709, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5108, 3736, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5109, 3740, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5112, 3752, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5113, 3758, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5130, 3802, 19, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (5131, 3804, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5133, 3810, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4932, 3257, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5089, 3679, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4967, 3360, 23, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (5012, 3479, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5066, 3626, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4977, 3390, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4979, 3400, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4857, 3026, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5121, 3781, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (14793, 11375, 28, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (4893, 3133, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5004, 3453, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5119, 3775, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (4985, 3411, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4890, 3122, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5073, 3642, 36, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4924, 3236, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14826, 1201, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5043, 3578, 165, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4996, 3437, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4816, 2886, 365, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (4798, 2834, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4794, 2823, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4991, 3424, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (4901, 3147, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (4876, 3065, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4945, 3291, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4950, 3309, 125, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4959, 3337, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5027, 3521, 134, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (5111, 3748, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5084, 3666, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5120, 3778, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5037, 3552, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (5014, 3485, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4941, 3281, 30, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4954, 3323, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5015, 3486, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5029, 3525, 9, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5041, 3570, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5005, 3459, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5065, 3625, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4871, 3058, 38, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4995, 3436, 175, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (4912, 3180, 90, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (4926, 3246, 7, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (5128, 3792, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5116, 3767, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5110, 3747, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5105, 3728, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5102, 3723, 58, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5101, 3722, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5094, 3702, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5088, 3678, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5044, 3579, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5040, 3569, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5035, 3544, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5032, 3538, 91, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5022, 3499, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5017, 3492, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4988, 3416, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4983, 3409, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4975, 3387, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4978, 3391, 48, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4969, 3367, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4962, 3345, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4961, 3342, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4956, 3329, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4960, 3340, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4955, 3326, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (4951, 3314, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4940, 3280, 188, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (4935, 3267, 64, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4911, 3177, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4892, 3129, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5075, 3646, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5047, 3584, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5126, 3788, 134, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5034, 3543, 249, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (22332, 14013, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5134, 3811, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5137, 3820, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5139, 3822, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5140, 3827, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14878, 11435, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14879, 11435, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14880, 11435, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14874, 11434, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5103, 3724, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5082, 3658, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5138, 3821, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5007, 3466, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14847, 10232, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (5062, 3617, 30, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4982, 3408, 84, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (5001, 3448, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5071, 3637, 19, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4987, 3413, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5023, 3506, 64, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4997, 3441, 56, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5099, 3713, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5078, 3650, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (4990, 3420, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5026, 3517, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5046, 3583, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5013, 3482, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5127, 3789, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (5070, 3635, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (5091, 3690, 185, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5024, 3509, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5054, 3601, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5050, 3590, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (22305, 2857, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22315, 5235, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22321, 14486, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22322, 14486, 90, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22323, 14486, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22343, 14521, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22344, 14521, 92, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22345, 14521, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14893, 1480, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14894, 1480, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5153, 3865, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5156, 3875, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5158, 3890, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5159, 3891, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5163, 3895, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5166, 3902, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5167, 3905, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5169, 3907, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5172, 3914, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5175, 3919, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22340, 14518, 189, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (14891, 223, 183, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (5176, 3920, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5184, 3940, 77, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (5188, 3954, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5190, 3958, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5193, 3975, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5195, 3982, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5196, 3985, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5201, 3991, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5203, 4000, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5204, 4001, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5205, 4004, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5206, 4006, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5207, 4013, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5210, 4021, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5216, 4034, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5217, 4036, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5220, 4050, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5223, 4056, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5228, 4074, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5229, 4079, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5230, 4080, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5232, 4090, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5233, 4091, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5235, 4094, 1, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (14940, 7666, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14941, 7666, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5212, 4023, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5186, 3951, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22306, 3426, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22307, 3426, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22308, 3426, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22324, 14486, 39, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (5200, 3990, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5191, 3972, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5056, 3607, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14892, 3685, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14897, 353, 24, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (5100, 3715, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5178, 3922, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5173, 3915, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (5147, 3846, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5174, 3917, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5114, 3759, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5218, 4039, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14934, 11453, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14895, 6152, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5199, 3989, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14882, 4506, 134, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5197, 3986, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (5182, 3934, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5187, 3953, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5222, 4052, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5028, 3524, 85, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5107, 3732, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5124, 3784, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5136, 3818, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (14898, 535, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5135, 3814, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14939, 1372, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4958, 3333, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22284, 14438, 58, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14925, 11450, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14956, 11461, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5057, 3608, 173, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5106, 3729, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5115, 3762, 4, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (5002, 3449, 84, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5160, 3892, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5079, 3651, 83, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (14886, 11438, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5122, 3782, 4, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5052, 3594, 27, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (5145, 3842, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5162, 3894, 162, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5194, 3980, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (5025, 3510, 8, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (14883, 11437, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5171, 3912, 4, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (14888, 8859, 36, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (4998, 3444, 72, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (5092, 3697, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5129, 3798, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5214, 4032, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5227, 4073, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5060, 3615, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5039, 3568, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (5219, 4047, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5226, 4068, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5224, 4058, 8, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (5221, 4051, 84, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (5211, 4022, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5209, 4019, 181, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (5192, 3973, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5183, 3938, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5181, 3932, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5180, 3931, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5179, 3923, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5170, 3908, 57, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5157, 3887, 22, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5165, 3900, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5151, 3861, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5150, 3859, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5146, 3845, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5143, 3830, 189, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (5142, 3829, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5141, 3828, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5125, 3787, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (5123, 3783, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5118, 3774, 64, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5096, 3706, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5098, 3711, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5095, 3704, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5063, 3620, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5053, 3595, 175, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (5059, 3613, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5049, 3589, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5033, 3541, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4986, 3412, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5011, 3475, 8, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (5236, 4097, 18, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5148, 3852, 334, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5154, 3866, 96, 14, 1);
INSERT INTO 'dancesformationsmap' VALUES (5081, 3656, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14935, 11453, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14906, 11441, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14907, 11441, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14908, 11441, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14938, 11454, 62, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14943, 11456, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14952, 11459, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14953, 11459, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14909, 11442, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14910, 11442, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14911, 11442, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14919, 11446, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14954, 11460, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14955, 11460, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14944, 11457, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14945, 11457, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14924, 11449, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14948, 11458, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14949, 11458, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14950, 11458, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14916, 11445, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14917, 11445, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14918, 11445, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14951, 11458, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14931, 11452, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14932, 11452, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14933, 11452, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14920, 11447, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14921, 11447, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14901, 11439, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14902, 11439, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14903, 11439, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14922, 11448, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14923, 11448, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5234, 4092, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5155, 3869, 32, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (5177, 3921, 60, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (5189, 3955, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (5202, 3999, 43, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (14899, 7999, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22325, 14486, 210, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22346, 14521, 72, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (5239, 4104, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5246, 4130, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5249, 4139, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5251, 4148, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5256, 4157, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5263, 4177, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5264, 4179, 172, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5266, 4184, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5271, 4203, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5272, 4206, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5273, 4207, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5276, 4212, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5277, 4219, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5283, 4236, 24, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5287, 4250, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5294, 4269, 63, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5295, 4275, 19, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (5297, 4284, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5299, 4287, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5300, 4288, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5303, 4294, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5304, 4295, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5310, 4314, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5314, 4328, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5315, 4331, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5325, 4357, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5328, 4375, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22326, 14487, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22327, 14487, 152, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22328, 14487, 193, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22347, 14522, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22348, 14522, 198, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22349, 14522, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (5316, 4333, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5329, 4376, 62, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5334, 4400, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5337, 4408, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5338, 4413, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5339, 4414, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5340, 4415, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5341, 4419, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5356, 4460, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5368, 4503, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5270, 4201, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5332, 4388, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5357, 4461, 77, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5363, 4479, 32, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (5343, 4425, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (5152, 3862, 64, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5231, 4086, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5307, 4309, 33, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5275, 4211, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14995, 11477, 175, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (5309, 4313, 93, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (5274, 4209, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5269, 4199, 89, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5164, 3896, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5360, 4471, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5351, 4442, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5305, 4301, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5326, 4359, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5161, 3893, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5279, 4225, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22333, 14013, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5258, 4160, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5345, 4432, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5261, 4175, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (5312, 4320, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5308, 4312, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5282, 4232, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5321, 4351, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5058, 3609, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14927, 11451, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5268, 4198, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5225, 4064, 18, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14912, 11443, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14913, 11443, 123, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (5247, 4131, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (5330, 4381, 265, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (5365, 4486, 77, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5290, 4257, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5319, 4348, 119, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5292, 4263, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5168, 3906, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14942, 11455, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (5331, 4383, 314, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (5255, 4156, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5333, 4394, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5367, 4500, 17, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5352, 4444, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5353, 4447, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5361, 4476, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5362, 4477, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15000, 11479, 9, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (14904, 11440, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5257, 4158, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5117, 3770, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5336, 4407, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5252, 4151, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (5348, 4436, 112, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (5359, 4466, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5354, 4450, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5350, 4439, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5313, 4324, 16, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (5318, 4346, 294, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5327, 4374, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (5311, 4318, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5198, 3987, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5306, 4303, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5344, 4426, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5293, 4268, 54, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5291, 4262, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5280, 4227, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5278, 4222, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5267, 4196, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5265, 4183, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (5262, 4176, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5260, 4173, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5259, 4169, 103, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5254, 4155, 96, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5250, 4142, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5248, 4136, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5242, 4119, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5241, 4115, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5213, 4024, 112, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (5149, 3854, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5296, 4280, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5322, 4352, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5289, 4253, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5243, 4123, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5281, 4231, 85, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (14968, 11466, 156, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5323, 4355, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5288, 4252, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (14978, 11470, 171, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14961, 11463, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14962, 11463, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14993, 11476, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14994, 11476, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22341, 14519, 262, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14969, 11466, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14970, 11466, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14983, 11473, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14984, 11473, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14985, 11473, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14987, 11474, 127, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14988, 11474, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14989, 11474, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14975, 11469, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14976, 11469, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14977, 11469, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14972, 11467, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14973, 11467, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14974, 11467, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14980, 11471, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14981, 11471, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14959, 11462, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14960, 11462, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14979, 11470, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14982, 11472, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14963, 11464, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5253, 4154, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5245, 4127, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5240, 4112, 29, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (5286, 4248, 54, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (5298, 4286, 36, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5375, 4524, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5377, 4533, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5380, 4548, 22, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5388, 4568, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5389, 4570, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5393, 4588, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5394, 4589, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5400, 4605, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5401, 4613, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5402, 4615, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5405, 4623, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5408, 4631, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5412, 4645, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5403, 4618, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5317, 4334, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22350, 14522, 15, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (5423, 4671, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5425, 4676, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5427, 4687, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5432, 4699, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5436, 4713, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5437, 4715, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5438, 4718, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5446, 4748, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5456, 4775, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5457, 4776, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5461, 4787, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5462, 4794, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5470, 4817, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5476, 4833, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5479, 4843, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5481, 4849, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5486, 4867, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5487, 4870, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5492, 4883, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5493, 4885, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5498, 4901, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5499, 4905, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5358, 4464, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (5503, 4913, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5504, 4915, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5505, 4918, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5506, 4921, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5508, 4926, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5496, 4894, 69, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5474, 4830, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5347, 4434, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5410, 4639, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5398, 4596, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5383, 4556, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5370, 4511, 175, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (5390, 4579, 58, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5418, 4662, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (5420, 4667, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5471, 4820, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5324, 4356, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5382, 4555, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5384, 4560, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5409, 4638, 79, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5378, 4543, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5237, 4098, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5448, 4751, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5369, 4506, 64, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5440, 4725, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5454, 4767, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5467, 4806, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5484, 4864, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (5488, 4871, 82, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (5392, 4585, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5411, 4642, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5433, 4701, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5485, 4865, 64, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5473, 4828, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5373, 4518, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5374, 4521, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5404, 4620, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5429, 4692, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5442, 4728, 32, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5379, 4544, 56, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (5483, 4862, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15019, 11486, 126, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15016, 11485, 145, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (15012, 11484, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15013, 11484, 93, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (15014, 11484, 112, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (15003, 11481, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15004, 11481, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14998, 11478, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14999, 11478, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14990, 11475, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15005, 11482, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15006, 11482, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5482, 4857, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5424, 4675, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (5455, 4769, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5464, 4803, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5459, 4779, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5431, 4697, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5422, 4669, 192, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (5407, 4630, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5414, 4651, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5430, 4695, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5364, 4484, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14991, 11475, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5449, 4752, 314, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (5416, 4655, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (5185, 3941, 249, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5452, 4760, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (5376, 4529, 20, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5320, 4350, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5466, 4805, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5453, 4765, 143, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5497, 4896, 296, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (5413, 4646, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5500, 4906, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5491, 4882, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (5468, 4809, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5465, 4804, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5460, 4784, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5450, 4755, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5444, 4746, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5443, 4744, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5439, 4720, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5419, 4666, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5406, 4629, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5399, 4597, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (5397, 4595, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5387, 4565, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5386, 4562, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5385, 4561, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (5355, 4455, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5302, 4291, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5342, 4421, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5428, 4688, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5396, 4591, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5445, 4747, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5463, 4800, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5417, 4658, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15035, 11491, 25, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15045, 11494, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15032, 11490, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15033, 11490, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15034, 11490, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15046, 11495, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15047, 11495, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15053, 11497, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15038, 11492, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15039, 11492, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15040, 11492, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15041, 11493, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15042, 11493, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15043, 11493, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15029, 11489, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15030, 11489, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15031, 11489, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15026, 11488, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15027, 11488, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15028, 11488, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15001, 11480, 52, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (15002, 11480, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15021, 11487, 296, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15022, 11487, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15023, 11487, 17, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5509, 4927, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5421, 4668, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5458, 4777, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (5560, 5084, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5521, 4962, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5522, 4963, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5523, 4964, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5524, 4966, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5526, 4972, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5528, 4977, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5532, 4994, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5539, 5015, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5541, 5025, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5544, 5031, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5551, 5047, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (26376, 13489, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (5552, 5048, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5553, 5052, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5557, 5069, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5558, 5074, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5561, 5086, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5469, 4814, 176, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (5490, 4881, 9, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (5441, 4726, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5563, 5094, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5568, 5104, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5569, 5105, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5570, 5114, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5571, 5115, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5573, 5121, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5574, 5127, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5575, 5132, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5578, 5145, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5582, 5153, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5588, 5164, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5591, 5173, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5593, 5180, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5595, 5194, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5554, 5055, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5598, 5201, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5600, 5205, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5603, 5212, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5604, 5216, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5608, 5228, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5609, 5229, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5614, 5241, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5617, 5251, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5621, 5263, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5622, 5266, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5628, 5285, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5629, 5288, 63, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5631, 5293, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5639, 5313, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5640, 5314, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5642, 5319, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5519, 4954, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5565, 5097, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5585, 5158, 365, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15090, 7536, 155, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15091, 7536, 206, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5514, 4938, 84, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (15100, 8867, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15101, 8867, 206, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15102, 8868, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15103, 8868, 206, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15080, 11508, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15106, 8870, 206, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15107, 8870, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15108, 8870, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15109, 8871, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15110, 8871, 206, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5540, 5016, 89, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15082, 11509, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5601, 5207, 58, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (5534, 5000, 296, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5507, 4925, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5447, 4750, 58, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15104, 8869, 206, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15060, 11499, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15061, 11500, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15054, 11497, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15055, 11497, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15095, 8849, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15096, 8849, 206, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15083, 11509, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5618, 5259, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15056, 11497, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5562, 5090, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5630, 5291, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5537, 5009, 90, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (5613, 5239, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15066, 11502, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15067, 11502, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15070, 11504, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15071, 11504, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15072, 11504, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15077, 11507, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15078, 11507, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15079, 11507, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15111, 8872, 206, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5435, 4709, 69, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (5475, 4832, 96, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5555, 5062, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5527, 4975, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (5623, 5272, 29, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (5596, 5198, 20, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5395, 4590, 77, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5592, 5174, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5515, 4941, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5529, 4988, 38, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5638, 5310, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5576, 5136, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5513, 4935, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5510, 4928, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5530, 4990, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5589, 5165, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5533, 4995, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5616, 5244, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5641, 5317, 45, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (15087, 8861, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5599, 5203, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5494, 4888, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5632, 5295, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15098, 8866, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (15049, 11496, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (5615, 5243, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (5606, 5223, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5548, 5040, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5536, 5007, 9, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15099, 8866, 207, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15086, 7465, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5577, 5142, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (5634, 5300, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5626, 5282, 18, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (5635, 5303, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5605, 5217, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5625, 5281, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5594, 5188, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5587, 5160, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5580, 5151, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5579, 5147, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5567, 5102, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5566, 5099, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (5547, 5039, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5546, 5037, 117, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5543, 5028, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5542, 5027, 58, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5525, 4968, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5517, 4951, 175, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5516, 4948, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5391, 4581, 7, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5478, 4835, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15085, 11510, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15068, 11503, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15069, 11503, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15063, 11501, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15064, 11501, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15065, 11501, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15074, 11505, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15075, 11505, 62, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15057, 11498, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15058, 11498, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15076, 11506, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5627, 5284, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5602, 5208, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5572, 5117, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5564, 5095, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (5545, 5033, 63, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5518, 4953, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5495, 4890, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5611, 5235, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22351, 14523, 143, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22352, 14523, 193, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (5556, 5065, 77, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5581, 5152, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5645, 5339, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5646, 5340, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5647, 5341, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5648, 5342, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5651, 5348, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22353, 14524, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5657, 5369, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5668, 5405, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5669, 5406, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5672, 5417, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5673, 5419, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5675, 5424, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5676, 5425, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (26372, 13489, 340, 69, 2);
INSERT INTO 'dancesformationsmap' VALUES (5678, 5432, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5679, 5435, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5680, 5436, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (5681, 5439, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5684, 5449, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5685, 5450, 9, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5687, 5457, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5693, 5477, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5694, 5479, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5696, 5488, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5702, 5507, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5703, 5510, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5705, 5514, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5706, 5517, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5624, 5277, 52, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (5708, 5523, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5710, 5526, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5712, 5533, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5714, 5541, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5716, 5545, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (26375, 13489, 176, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (5719, 5553, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5671, 5413, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5722, 5556, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5724, 5563, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5729, 5572, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5734, 5583, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15114, 8873, 206, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15115, 8873, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15116, 8874, 207, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15117, 8874, 155, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15118, 8874, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15119, 8874, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15120, 8875, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15121, 8875, 207, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15122, 8875, 138, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15123, 8875, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15124, 8875, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15125, 8876, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15126, 8876, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15127, 8876, 207, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15128, 8877, 207, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15129, 8877, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5682, 5440, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5777, 5703, 72, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (15140, 8880, 207, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15141, 8880, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15142, 8881, 207, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15143, 8881, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15144, 8881, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15145, 8882, 206, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15146, 8883, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15147, 8883, 206, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15148, 8883, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15149, 8884, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15150, 8884, 206, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15151, 8885, 206, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15152, 8885, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15153, 8886, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5658, 5374, 16, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5663, 5395, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5739, 5603, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5740, 5608, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5750, 5631, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5753, 5641, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (5757, 5651, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5758, 5653, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5760, 5664, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5761, 5665, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5769, 5683, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5773, 5692, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5774, 5695, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5776, 5698, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5779, 5705, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5780, 5706, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15135, 8879, 207, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5662, 5389, 22, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5727, 5569, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5633, 5296, 55, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (5659, 5376, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15112, 8872, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5610, 5232, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15092, 8847, 206, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15093, 8847, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (5749, 5628, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5732, 5580, 120, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (5550, 5044, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5691, 5465, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5650, 5347, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5782, 5710, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5511, 4930, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5643, 5330, 7, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (5731, 5576, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15130, 8878, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (5597, 5200, 365, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5683, 5443, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5692, 5474, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5715, 5543, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15131, 8878, 267, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5730, 5575, 52, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5677, 5426, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5781, 5707, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5644, 5332, 175, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (5661, 5385, 365, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5612, 5236, 61, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (5778, 5704, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5772, 5691, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5584, 5155, 9, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (5619, 5260, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5718, 5552, 112, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5636, 5307, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5559, 5079, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (5531, 4991, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5607, 5225, 82, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (5733, 5582, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5768, 5680, 82, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (5735, 5584, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5763, 5669, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5756, 5648, 227, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5755, 5643, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5747, 5624, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5743, 5617, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5737, 5591, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (5728, 5571, 45, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (5725, 5564, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5717, 5547, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5713, 5539, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5698, 5494, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5697, 5493, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5674, 5421, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5670, 5410, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5664, 5398, 96, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (5666, 5402, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5655, 5364, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5652, 5350, 21, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5653, 5358, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5720, 5554, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5665, 5399, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5711, 5531, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5704, 5513, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5764, 5671, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5690, 5463, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5707, 5522, 84, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5590, 5168, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5701, 5498, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5770, 5686, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5766, 5677, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5751, 5636, 45, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (5686, 5451, 10, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (5660, 5377, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5649, 5345, 87, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (5759, 5662, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5738, 5597, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5785, 5714, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5788, 5725, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5790, 5729, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5793, 5733, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5796, 5738, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5801, 5758, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5803, 5762, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5807, 5777, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5808, 5784, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5818, 5827, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5821, 5833, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5822, 5834, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5826, 5855, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15154, 8886, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5799, 5754, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5775, 5697, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5746, 5623, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5798, 5752, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26332, 13487, 244, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5752, 5640, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15187, 11518, 42, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (5794, 5734, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5832, 5867, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5836, 5881, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5843, 5903, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5847, 5912, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5848, 5914, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5851, 5925, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5858, 5947, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22356, 14525, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (5860, 5954, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31812, 13917, 23, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (5865, 5963, 16, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (5866, 5964, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (5867, 5965, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5868, 5973, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5869, 5974, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5871, 5977, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5875, 5985, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5878, 5993, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5879, 6001, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5880, 6002, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5881, 6008, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5888, 6032, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5889, 6034, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5891, 6043, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5893, 6050, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5896, 6054, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5901, 6065, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5856, 5940, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5905, 6086, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5906, 6088, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5908, 6092, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5914, 6105, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5915, 6113, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5916, 6114, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5918, 6118, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5920, 6126, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5921, 6139, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5748, 5625, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5811, 5797, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5736, 5590, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5820, 5829, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5827, 5856, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5862, 5957, 82, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (5797, 5750, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5834, 5875, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5828, 5859, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5723, 5558, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (5830, 5864, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5859, 5950, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5787, 5723, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15184, 11517, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5805, 5765, 61, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (5845, 5905, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5654, 5359, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5838, 5889, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5863, 5961, 7, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (5800, 5757, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5700, 5497, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5900, 6061, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5835, 5878, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5745, 5621, 27, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (5907, 6091, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5825, 5843, 87, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5810, 5794, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5886, 6029, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (5792, 5732, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5883, 6017, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (5887, 6030, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5912, 6103, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5791, 5731, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (5840, 5893, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5699, 5495, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15163, 11222, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5890, 6036, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5789, 5726, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5913, 6104, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5904, 6079, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5855, 5937, 9, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15170, 11513, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15195, 11521, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15196, 11521, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15191, 11520, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15192, 11520, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (15189, 11519, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15176, 11515, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15177, 11515, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15178, 11515, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15167, 11512, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15168, 11512, 59, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15169, 11512, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15159, 7647, 157, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15164, 11222, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15160, 7647, 315, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15161, 7647, 209, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (5874, 5984, 176, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (5688, 5458, 84, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5909, 6093, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5902, 6077, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5899, 6058, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5897, 6055, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5872, 5981, 18, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (5857, 5945, 36, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (5852, 5927, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5854, 5932, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5844, 5904, 134, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5831, 5865, 9, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5842, 5897, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5804, 5763, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5824, 5839, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5709, 5525, 9, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5833, 5868, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5814, 5803, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5695, 5480, 53, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5839, 5890, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5876, 5986, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5911, 6098, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5895, 6053, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5849, 5915, 90, 113, 1);
INSERT INTO 'dancesformationsmap' VALUES (5813, 5800, 286, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (5656, 5366, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5795, 5736, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15165, 11511, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5823, 5836, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15155, 4279, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5816, 5817, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5812, 5798, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5806, 5766, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5802, 5759, 65, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5786, 5717, 21, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5726, 5568, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5817, 5825, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5864, 5962, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5744, 5618, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5783, 5712, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15174, 11514, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15175, 11514, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15179, 11516, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15197, 11522, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5910, 6094, 365, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (5884, 6020, 58, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5853, 5928, 172, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5784, 5713, 157, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (5846, 5908, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5819, 5828, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5956, 6240, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22359, 14526, 134, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22360, 14526, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22361, 14526, 36, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (5829, 5860, 18, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5873, 5982, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (5882, 6010, 9, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (5923, 6144, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5927, 6166, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5929, 6172, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5933, 6182, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (5898, 6057, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5850, 5921, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15188, 11518, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5841, 5894, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5936, 6190, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5939, 6198, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5941, 6202, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5947, 6215, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5950, 6225, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5953, 6233, 16, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (5958, 6246, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5959, 6247, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5961, 6262, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5964, 6272, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5965, 6277, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5966, 6281, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5973, 6298, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5974, 6300, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5977, 6315, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5979, 6325, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5981, 6331, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5982, 6334, 76, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (5983, 6338, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5984, 6344, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5985, 6345, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5990, 6366, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5993, 6376, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5994, 6377, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6005, 6403, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6011, 6421, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6016, 6437, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6017, 6441, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6020, 6454, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6023, 6462, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6029, 6486, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6030, 6488, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6033, 6498, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6034, 6500, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6037, 6511, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6039, 6517, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6042, 6529, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6045, 6544, 101, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6046, 6546, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6051, 6560, 91, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5937, 6191, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6014, 6433, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5894, 6052, 45, 19, 4);
INSERT INTO 'dancesformationsmap' VALUES (5940, 6199, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6044, 6541, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5951, 6229, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (5963, 6271, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5952, 6230, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5954, 6234, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5995, 6382, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6002, 6395, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15232, 11498, 27, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (15204, 11524, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15198, 11522, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15199, 11522, 62, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15200, 11522, 192, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (6013, 6432, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5980, 6328, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6010, 6420, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5945, 6212, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5991, 6371, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6026, 6473, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15233, 11534, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5989, 6362, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6022, 6461, 93, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (6021, 6460, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15213, 11527, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5957, 6245, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6041, 6523, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31337, 399, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31338, 3196, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3174, 6030, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (6024, 6464, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5955, 6236, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (5962, 6263, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5972, 6294, 149, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5975, 6309, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15247, 11537, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6015, 6434, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5943, 6207, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15234, 11534, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5935, 6186, 72, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (5917, 6116, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5930, 6173, 7, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (5938, 6197, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5949, 6224, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6012, 6424, 156, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15242, 11536, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (6048, 6551, 119, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (15220, 11529, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15248, 11537, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6032, 6492, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15227, 11532, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15228, 11532, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15216, 11528, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15217, 11528, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15218, 11528, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15208, 11526, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15209, 11526, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15210, 11526, 1, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (15211, 11526, 67, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (15201, 11523, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15202, 11523, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6035, 6505, 156, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15230, 11533, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15231, 11533, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6047, 6550, 8, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (6040, 6518, 72, 47, 1);
INSERT INTO 'dancesformationsmap' VALUES (6028, 6484, 84, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (6027, 6477, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6025, 6471, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6018, 6444, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6009, 6412, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6008, 6410, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6003, 6397, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6000, 6391, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5998, 6387, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5988, 6358, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5986, 6348, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5978, 6323, 18, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5970, 6289, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5968, 6285, 30, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (5967, 6282, 63, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (5944, 6210, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5960, 6254, 4, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (5931, 6178, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5928, 6167, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5924, 6152, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5892, 6048, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (15237, 5487, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6001, 6392, 64, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5996, 6383, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5971, 6292, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (6036, 6510, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6038, 6514, 74, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5934, 6185, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5926, 6159, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15205, 11525, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5999, 6389, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6004, 6401, 45, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6006, 6404, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15223, 11530, 183, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (15224, 11530, 185, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5976, 6310, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5809, 5787, 80, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5925, 6153, 176, 45, 2);
INSERT INTO 'dancesformationsmap' VALUES (5922, 6143, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (5932, 6181, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6082, 6643, 145, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (22362, 14527, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6052, 6562, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5969, 6287, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6055, 6572, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6056, 6573, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6059, 6576, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6062, 6589, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6063, 6590, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6069, 6608, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6077, 6626, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6081, 6635, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6088, 6658, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6090, 6665, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6096, 6692, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6103, 6719, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6105, 6726, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6106, 6730, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6107, 6732, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6109, 6735, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5997, 6384, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6112, 6742, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6114, 6745, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6115, 6746, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6116, 6747, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6117, 6750, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6119, 6753, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6120, 6754, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6123, 6759, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6127, 6776, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6128, 6777, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6129, 6778, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6133, 6789, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6137, 6799, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6139, 6802, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6140, 6812, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6050, 6555, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (15256, 11410, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15257, 11410, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15258, 11410, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15259, 11539, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15260, 11539, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15261, 11540, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15262, 11540, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15263, 11540, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15264, 11541, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15265, 11541, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15266, 11542, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15267, 11542, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15268, 11542, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15269, 11542, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15270, 11542, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15275, 11545, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15276, 11545, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15277, 11545, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15280, 11547, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15281, 11547, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15282, 11547, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15283, 11548, 162, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15284, 11548, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15288, 11551, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15289, 11552, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15290, 11552, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6108, 6734, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6134, 6791, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6078, 6629, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6145, 6827, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6146, 6831, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6147, 6832, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6155, 6852, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6159, 6867, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6164, 6886, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6167, 6892, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6169, 6908, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6174, 6921, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6176, 6929, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6178, 6938, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15285, 11549, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6188, 6984, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6189, 6985, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6086, 6655, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6065, 6597, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15250, 11538, 43, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (6180, 6943, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6057, 6574, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6092, 6677, 156, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6085, 6653, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6172, 6916, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6126, 6768, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6084, 6650, 234, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (6150, 6839, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6132, 6788, 79, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5987, 6349, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6156, 6858, 94, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6153, 6848, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6019, 6448, 76, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (6185, 6963, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6182, 6956, 188, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (6143, 6819, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6113, 6744, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15291, 11553, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15292, 11553, 145, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6093, 6680, 38, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (6165, 6887, 63, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6138, 6801, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6091, 6671, 48, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6054, 6569, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6073, 6615, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6130, 6782, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6070, 6609, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6162, 6880, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6190, 6990, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6170, 6910, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6118, 6751, 24, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6141, 6813, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6175, 6928, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6163, 6885, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6111, 6739, 58, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (6080, 6634, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6183, 6957, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31339, 3196, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6144, 6826, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6186, 6967, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6149, 6838, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6168, 6901, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5992, 6373, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6043, 6532, 90, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (6066, 6599, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6158, 6862, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15295, 11554, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6076, 6624, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6095, 6689, 81, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15252, 9787, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6100, 6711, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6192, 6996, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6087, 6657, 90, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (6071, 6613, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6193, 6997, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6181, 6952, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6179, 6941, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6177, 6931, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6173, 6919, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6171, 6913, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6187, 6981, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6166, 6890, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6161, 6879, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6160, 6876, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6157, 6860, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6154, 6849, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (6152, 6847, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6151, 6846, 62, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6142, 6817, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (6136, 6797, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6131, 6783, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6110, 6736, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6104, 6720, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6099, 6710, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6094, 6683, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6089, 6661, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6079, 6631, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6072, 6614, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6068, 6601, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6067, 6600, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6058, 6575, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (6074, 6616, 43, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (6061, 6587, 58, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (6195, 7011, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6200, 7021, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6201, 7022, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6209, 7047, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6210, 7048, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6211, 7051, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6213, 7058, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6214, 7059, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6098, 6705, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6135, 6792, 172, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6064, 6596, 263, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6075, 6619, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6194, 7000, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6097, 6701, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6083, 6646, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6219, 7076, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6220, 7078, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6223, 7083, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6230, 7109, 69, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (6235, 7122, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15299, 8888, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15300, 8888, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15301, 8888, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15302, 8889, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15303, 8890, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15304, 8890, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15305, 8891, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15307, 8893, 164, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15308, 8893, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15309, 8894, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15271, 11543, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6124, 6763, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22363, 14527, 120, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22364, 14527, 110, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (15310, 8895, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15311, 8895, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15312, 8896, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15313, 8897, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15314, 8897, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15315, 8897, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15316, 8890, 211, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15317, 8891, 211, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15318, 8894, 211, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15319, 8895, 211, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15320, 8896, 211, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15321, 8897, 211, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15322, 10196, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15323, 10196, 212, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15324, 10196, 133, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15325, 10196, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15326, 10197, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15327, 10197, 212, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15328, 10197, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15333, 10200, 212, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15334, 10200, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15335, 10201, 212, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15336, 10201, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15337, 10202, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15338, 10202, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6237, 7128, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6239, 7134, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6249, 7152, 83, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6251, 7154, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6257, 7177, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6259, 7179, 64, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6260, 7181, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6262, 7186, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6267, 7205, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6276, 7236, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6277, 7237, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6279, 7246, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6280, 7249, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6242, 7139, 17, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6288, 7269, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6247, 7148, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6299, 110, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6301, 118, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6303, 147, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6309, 211, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6312, 227, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6314, 248, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6318, 362, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6324, 435, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6327, 470, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6256, 7173, 142, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15339, 10202, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6229, 7106, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15343, 10204, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15344, 10204, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15345, 10204, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15346, 10205, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15347, 10205, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15348, 10205, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15349, 10205, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15350, 10205, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15351, 10205, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6306, 190, 91, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6305, 178, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6275, 7234, 19, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6222, 7080, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (6308, 200, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15340, 10203, 262, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6266, 7201, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6311, 222, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6226, 7090, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6250, 7153, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6284, 7262, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (6292, 45, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6274, 7229, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6240, 7135, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6317, 336, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6221, 7079, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (6198, 7017, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15352, 10205, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15353, 10206, 207, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15354, 10206, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15355, 10206, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15356, 10207, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15357, 10207, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15358, 10207, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15367, 10212, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15368, 10212, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6273, 7226, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6270, 7215, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6323, 432, 91, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6271, 7219, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6224, 7087, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6202, 7025, 145, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (4146, 784, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6253, 7162, 134, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (6204, 7030, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6215, 7065, 36, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6326, 467, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6296, 83, 32, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (6298, 109, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6205, 7037, 72, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (22380, 14531, 143, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (6207, 7044, 102, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6208, 7045, 42, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (6216, 7068, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6293, 55, 52, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6243, 7141, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6297, 88, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15306, 8892, 164, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6269, 7210, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15297, 11554, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15298, 11520, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (6281, 7257, 145, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6278, 7245, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6272, 7220, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6264, 7189, 32, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (6263, 7188, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6258, 7178, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6245, 7143, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6254, 7164, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6244, 7142, 76, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (6236, 7125, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6231, 7110, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (6228, 7105, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6225, 7088, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6218, 7073, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6217, 7071, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6203, 7028, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6197, 7016, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6246, 7144, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6199, 7020, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6285, 7264, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6255, 7172, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6241, 7138, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6233, 7116, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6295, 81, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6328, 475, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6325, 442, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6321, 400, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6316, 335, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6313, 235, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6212, 7055, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (15369, 10212, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15373, 10214, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15374, 10214, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15375, 10214, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15376, 10214, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15377, 10214, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15378, 10215, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15379, 10215, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15380, 10215, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22395, 14538, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22396, 14538, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6304, 152, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6300, 116, 9, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (22365, 14527, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6331, 496, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6227, 7099, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6320, 390, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6268, 7206, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6291, 43, 149, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (15331, 10199, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6289, 30, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6333, 517, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6335, 531, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6343, 591, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6342, 588, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6353, 668, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6322, 428, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6367, 757, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6370, 775, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6371, 777, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22366, 14528, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6408, 1049, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6416, 1094, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6417, 1098, 25, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6422, 1159, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15381, 10216, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15382, 10216, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15383, 10216, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15384, 10216, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15385, 10217, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15386, 10217, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15387, 10218, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15388, 10219, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15389, 10219, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15390, 10220, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15391, 10220, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15392, 10221, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15393, 10221, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15394, 10222, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15395, 10222, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15396, 10222, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15397, 10223, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15398, 10223, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15399, 10223, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15404, 10226, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15405, 10226, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15406, 10226, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15407, 10227, 124, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15408, 10227, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15417, 10598, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15418, 10598, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15419, 10598, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22376, 5860, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22377, 5860, 225, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22397, 14538, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6374, 796, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6423, 1177, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6357, 696, 17, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6387, 909, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (15402, 10225, 267, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15403, 10225, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6395, 984, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (5942, 6205, 273, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22387, 14534, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22371, 12793, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22378, 1358, 132, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22379, 1358, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22372, 12793, 234, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15412, 10229, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15413, 10229, 119, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15365, 10210, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15366, 10211, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15362, 10209, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15363, 10209, 206, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15359, 10208, 327, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15360, 10208, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6348, 640, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (22384, 14533, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22385, 14533, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6380, 881, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15370, 10213, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15371, 10213, 206, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6319, 373, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6290, 40, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22369, 14530, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6413, 1069, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6392, 965, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19054, 12777, 20, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22370, 5430, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22388, 14534, 29, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (6409, 1058, 7, 51, 1);
INSERT INTO 'dancesformationsmap' VALUES (6378, 829, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6368, 763, 61, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (6307, 195, 90, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6349, 642, 176, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (6411, 1065, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6365, 751, 149, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (6330, 489, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6404, 1030, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6364, 750, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6426, 1213, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6434, 1299, 69, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (6436, 1309, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6440, 1334, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6441, 1340, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6466, 1551, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6448, 1373, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6449, 1379, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6452, 1442, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6369, 774, 30, 31, 2);
INSERT INTO 'dancesformationsmap' VALUES (15409, 10228, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15410, 10228, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6420, 1142, 58, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6432, 1278, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6381, 886, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6391, 956, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (6435, 1304, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6366, 753, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7351, 7490, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6346, 605, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6384, 899, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6359, 707, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6340, 572, 120, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (6337, 543, 4, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6339, 570, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6377, 819, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6388, 919, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6396, 985, 52, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6191, 6995, 183, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (6399, 1013, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6360, 712, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6345, 603, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6341, 583, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7012, 6424, 294, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6287, 7267, 30, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6451, 1409, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22382, 12569, 184, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6379, 845, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6252, 7157, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6376, 805, 54, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6447, 1367, 65, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6445, 1359, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6439, 1329, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6429, 1252, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6424, 1179, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6427, 1215, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6443, 1349, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6425, 1194, 18, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6421, 1154, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6419, 1141, 27, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6415, 1093, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6412, 1068, 181, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6405, 1034, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6403, 1029, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6401, 1022, 12, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6398, 992, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6389, 932, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6393, 971, 1, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (6375, 797, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6361, 715, 120, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6356, 687, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6355, 685, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6354, 680, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6352, 662, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6344, 596, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6338, 549, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6336, 540, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6334, 519, 21, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6363, 745, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6430, 1260, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6402, 1024, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6372, 779, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15420, 10594, 317, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (6480, 1682, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6481, 1693, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6483, 1705, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6485, 1725, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6543, 2291, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6496, 1799, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6497, 1812, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6456, 1480, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6512, 1933, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6519, 1987, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6586, 2767, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6350, 649, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6390, 936, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6358, 698, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6463, 1518, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6467, 1556, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6406, 1039, 22, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6382, 892, 4, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6511, 1932, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6549, 2332, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6400, 1019, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6525, 2043, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6528, 2114, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6529, 2116, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6536, 2219, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6579, 2705, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6542, 2282, 64, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6547, 2324, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6457, 1485, 28, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6514, 1953, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6566, 2532, 19, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6568, 2539, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6575, 2622, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6577, 2696, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6578, 2701, 16, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6585, 2761, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6588, 2784, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6431, 1277, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6418, 1100, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6489, 1758, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6583, 2747, 77, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (6428, 1218, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6385, 902, 37, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (6573, 2563, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6563, 2493, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6362, 739, 77, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6493, 1777, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6521, 2018, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6554, 2370, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6502, 1833, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6617, 3045, 58, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (6347, 611, 307, 18, 2);
INSERT INTO 'dancesformationsmap' VALUES (22411, 14543, 56, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (6437, 1319, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6450, 1388, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (6527, 2101, 21, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (6383, 894, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6539, 2246, 367, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6555, 2399, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6570, 2551, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6587, 2782, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6486, 1731, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6476, 1638, 63, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6465, 1539, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6461, 1510, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6460, 1507, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6503, 1834, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6538, 2235, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6597, 2879, 63, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6599, 2904, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6615, 3024, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6619, 3050, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6620, 3056, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6572, 2562, 101, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6625, 3070, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6628, 3103, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6635, 3138, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6576, 2675, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6472, 1584, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6462, 1513, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6564, 2498, 83, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6571, 2556, 21, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6459, 1501, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15426, 7227, 134, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6505, 1864, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6540, 2257, 61, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (6531, 2153, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6522, 2024, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6508, 1892, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6590, 2812, 58, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (6464, 1521, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6530, 2140, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6394, 975, 114, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (6414, 1077, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6534, 2180, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6552, 2363, 7, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (6562, 2492, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6589, 2806, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6584, 2757, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6621, 3057, 27, 49, 4);
INSERT INTO 'dancesformationsmap' VALUES (6561, 2475, 46, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6532, 2169, 85, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (6491, 1768, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15436, 11391, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6498, 1818, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6478, 1664, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6611, 2978, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15434, 11390, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (15435, 11390, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (6596, 2877, 33, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6471, 1577, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6553, 2367, 18, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6537, 2223, 353, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6492, 1770, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6482, 1701, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6560, 2456, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6630, 3105, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6626, 3084, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6613, 2999, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6612, 2990, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6610, 2970, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6600, 2906, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6608, 2957, 76, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (6591, 2821, 18, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (6581, 2717, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6569, 2543, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6544, 2295, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6557, 2419, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6541, 2258, 365, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (6535, 2189, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6526, 2076, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6523, 2033, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6518, 1974, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6517, 1966, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6516, 1965, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6506, 1866, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6500, 1830, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6504, 1856, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6499, 1826, 188, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (6490, 1762, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6487, 1733, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6484, 1712, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6479, 1677, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6633, 3135, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6618, 3046, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6606, 2936, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6458, 1498, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6455, 1474, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6454, 1457, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6515, 1962, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6446, 1366, 317, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (6444, 1353, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6433, 1280, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6533, 2177, 9, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (6332, 497, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6453, 1451, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15427, 268, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (6595, 2836, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6638, 3156, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6524, 2034, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6724, 3724, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6474, 1588, 93, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (6634, 3137, 76, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6556, 2408, 18, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15423, 10594, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6627, 3092, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6644, 3237, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6648, 3260, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15448, 11396, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15449, 11396, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15450, 11396, 168, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15451, 11396, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15452, 11396, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15468, 11556, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15469, 11556, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (15470, 11556, 76, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (15472, 6042, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15473, 6042, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15474, 6042, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15475, 6042, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15476, 6042, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15477, 4548, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15478, 4548, 125, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (22398, 14539, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15465, 11555, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6603, 2927, 18, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6665, 3408, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22408, 1480, 249, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (22410, 13405, 262, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (6598, 2880, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6477, 1639, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6546, 2323, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6469, 1562, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6473, 1586, 134, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6548, 2328, 355, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6386, 908, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15433, 11389, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6614, 3022, 34, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (6631, 3122, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6593, 2830, 84, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6567, 2535, 114, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6513, 1949, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (15461, 7941, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (6565, 2526, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6646, 3248, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6650, 3278, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6653, 3286, 62, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6656, 3303, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6658, 3330, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6604, 2930, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6683, 3491, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6685, 3495, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6686, 3497, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6669, 3413, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6713, 3621, 27, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6719, 3661, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6727, 3758, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6652, 3284, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6703, 3593, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6671, 3420, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6691, 3517, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6488, 1743, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6594, 2831, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15479, 1030, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6629, 3104, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22389, 14535, 71, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22390, 14535, 92, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22383, 14532, 202, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22399, 14532, 131, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6663, 3389, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15441, 11393, 61, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15442, 11393, 29, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (6580, 2711, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9336, 8956, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9337, 8956, 119, 10, 2);
INSERT INTO 'dancesformationsmap' VALUES (6641, 3202, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6602, 2925, 307, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6689, 3506, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (6607, 2943, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6643, 3221, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6676, 3448, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6681, 3482, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6661, 3358, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6601, 2911, 120, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (22412, 14543, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (22413, 14543, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6736, 3810, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15483, 11557, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15484, 11557, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15487, 11560, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15488, 11560, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15489, 11560, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15505, 11566, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6639, 3176, 76, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (6672, 3431, 19, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6694, 3536, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6647, 3257, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15500, 5615, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15439, 11392, 168, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15440, 11392, 164, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6680, 3479, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15490, 11561, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6674, 3436, 36, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6545, 2315, 19, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (6715, 3626, 103, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (6616, 3026, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6690, 3510, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (6733, 3787, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6637, 3154, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6696, 3562, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6558, 2421, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (6636, 3147, 38, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6624, 3066, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6623, 3065, 176, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (6655, 3291, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6692, 3524, 149, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6609, 2962, 114, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (6720, 3666, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6726, 3732, 32, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (6732, 3784, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6752, 3943, 119, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (6764, 4033, 55, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6651, 3281, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6675, 3444, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6693, 3525, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6699, 3570, 16, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6714, 3625, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22404, 7285, 224, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (15498, 11564, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15499, 11564, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6622, 3058, 149, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (15502, 11565, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6679, 3474, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6695, 3558, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15491, 11561, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15462, 11400, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15463, 11400, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15464, 11400, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15458, 11399, 114, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15459, 11399, 166, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (15446, 11395, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (15447, 11395, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15444, 11394, 13, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15445, 11394, 23, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (6697, 3568, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6710, 3615, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6682, 3485, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6645, 3246, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15482, 4422, 172, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6731, 3783, 43, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (6729, 3774, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6725, 3728, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6723, 3723, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6712, 3620, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6705, 3595, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6709, 3613, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6702, 3589, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6698, 3569, 29, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (6688, 3499, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6684, 3492, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6670, 3416, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (6668, 3412, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6666, 3409, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6662, 3387, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6660, 3342, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (6657, 3309, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6659, 3340, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6649, 3267, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6642, 3207, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6701, 3584, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6678, 3459, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6734, 3788, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (6605, 2934, 77, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15509, 11568, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15510, 11568, 378, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (6753, 3951, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22416, 14544, 183, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (22417, 14544, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22418, 14544, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (6673, 3435, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6687, 3498, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6700, 3577, 18, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6743, 3895, 73, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6747, 3914, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6748, 3920, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6787, 4201, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6757, 3985, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6760, 3990, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6762, 4012, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6791, 4252, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6765, 4036, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6772, 4091, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6775, 4104, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6779, 4157, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6780, 4164, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6783, 4177, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6788, 4212, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6793, 4284, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6796, 4294, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6799, 4328, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6800, 4330, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6806, 4357, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6810, 4414, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6811, 4419, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6819, 4460, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6825, 4548, 19, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (6828, 4568, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15525, 11571, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15528, 11572, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15529, 11572, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15530, 11572, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15531, 11572, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15532, 11572, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15533, 11573, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15534, 11573, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15456, 11398, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15524, 11482, 185, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6677, 3453, 102, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15492, 11562, 36, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15493, 11562, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6730, 3775, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6777, 4131, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6667, 3411, 21, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15495, 11563, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6717, 3651, 73, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (15537, 11575, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15538, 11575, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15539, 11576, 133, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15540, 11576, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15541, 11576, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15542, 11576, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15543, 11576, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15544, 11577, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15545, 11577, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15546, 11578, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15547, 11578, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15485, 11558, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6755, 3972, 77, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6739, 3821, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6721, 3685, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6722, 3715, 62, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (6792, 4266, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22386, 14533, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6826, 4556, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6706, 3607, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6820, 4461, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6829, 4579, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6808, 4388, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15517, 11570, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15518, 11570, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6822, 4479, 42, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (6728, 3759, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22414, 14543, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6804, 4355, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6812, 4425, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6773, 4092, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6741, 3834, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6749, 3921, 66, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (22415, 14543, 36, 30, 1);
INSERT INTO 'dancesformationsmap' VALUES (6761, 3999, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6790, 4248, 42, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (6794, 4286, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15548, 11578, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15549, 11578, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15550, 11578, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15551, 11579, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15552, 11579, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15553, 11579, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15554, 11580, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15555, 11580, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15556, 11580, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15557, 11581, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22419, 14544, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6831, 4589, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6833, 4605, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6837, 4645, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6845, 4718, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6844, 4715, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6848, 4726, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6801, 4334, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6859, 4833, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6883, 5065, 32, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6863, 4901, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6866, 4913, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6835, 4638, 61, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (15471, 2360, 114, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (15563, 8344, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (22392, 14536, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6759, 3989, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6786, 4199, 365, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6774, 4098, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6744, 3896, 279, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (6778, 4144, 4, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (6816, 4442, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6754, 3953, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6767, 4052, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6847, 4725, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6750, 3934, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6807, 4359, 19, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9460, 3979, 72, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6838, 4658, 66, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6814, 4427, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6836, 4642, 96, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (6738, 3818, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6746, 3912, 18, 53, 1);
INSERT INTO 'dancesformationsmap' VALUES (6798, 4320, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (6770, 4073, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6834, 4620, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15511, 11569, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15506, 11567, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15516, 11479, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15513, 11193, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (15514, 11193, 217, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6809, 4407, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6852, 4760, 9, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (6824, 4529, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15526, 8375, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15564, 8344, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6802, 4350, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6735, 3805, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6853, 4765, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (6858, 4809, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6849, 4746, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6839, 4666, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6832, 4597, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (6827, 4565, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6815, 4436, 39, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (6821, 4466, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6818, 4450, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6789, 4231, 38, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (6795, 4291, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6784, 4181, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6782, 4176, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6781, 4173, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6776, 4119, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6768, 4058, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6766, 4051, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6756, 3973, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6740, 3829, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6745, 3900, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6737, 3814, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6758, 3987, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6813, 4426, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (6803, 4352, 46, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15558, 11582, 23, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (6718, 3656, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6874, 4962, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6876, 4972, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6881, 5047, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6884, 5086, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6885, 5114, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6886, 5127, 46, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6889, 5205, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6892, 5216, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6894, 5228, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6895, 5229, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6898, 5263, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6901, 5285, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6904, 5342, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6908, 5348, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6916, 5424, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6917, 5435, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6918, 5450, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6922, 5477, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6882, 5055, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15600, 11589, 365, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15578, 10677, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15579, 10677, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15592, 1225, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15593, 1225, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15594, 1225, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6842, 4707, 119, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (6872, 4938, 76, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (22425, 9761, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22426, 3981, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22427, 3981, 54, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (22428, 3981, 183, 3, 16);
INSERT INTO 'dancesformationsmap' VALUES (22431, 5755, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22442, 14552, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22443, 14552, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6926, 5507, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6931, 5545, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6934, 5556, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6935, 5561, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6936, 5572, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6862, 4894, 87, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13641, 10790, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (13642, 10790, 260, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6742, 3862, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15588, 11587, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15589, 11587, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6850, 4750, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6912, 5389, 20, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6763, 4026, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15595, 1518, 365, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6840, 4675, 76, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6785, 4198, 55, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6896, 5244, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6707, 3608, 77, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15606, 11592, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15574, 10682, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (15575, 10682, 155, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6841, 4695, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6887, 5176, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15535, 11574, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15536, 11574, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6704, 3594, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7045, 6768, 76, 10, 4);
INSERT INTO 'dancesformationsmap' VALUES (6878, 5009, 64, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (6911, 5376, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15565, 11583, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15566, 11583, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6865, 4911, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (1984, 3759, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22424, 3759, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6771, 4086, 76, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (6868, 4927, 61, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (6805, 4356, 72, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (6890, 5207, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15522, 11480, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6830, 4586, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6905, 5344, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6924, 5498, 63, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22401, 14534, 168, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (6915, 5413, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6906, 5345, 149, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (6891, 5208, 25, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (6854, 4777, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6947, 5702, 61, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (6949, 5725, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6952, 5733, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6969, 5977, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15612, 5673, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6900, 5277, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6966, 5921, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6937, 5590, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6955, 5786, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6965, 5894, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6953, 5752, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6974, 6088, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6977, 6113, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6978, 6114, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6984, 6202, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (6986, 6215, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6988, 6262, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6990, 6272, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6994, 6344, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6998, 6366, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6843, 4709, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15590, 11588, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22402, 14536, 55, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6999, 6371, 17, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15580, 10678, 29, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (15581, 10678, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6976, 6103, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6939, 5616, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6880, 5044, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6873, 4959, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6907, 5347, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6860, 4858, 84, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6861, 4864, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6864, 4907, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (6975, 6091, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1831, 3465, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6888, 5200, 38, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (6870, 4930, 234, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6902, 5330, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6951, 5732, 7, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6989, 6263, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6950, 5731, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6925, 5500, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22403, 14537, 220, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22432, 3108, 55, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6981, 6173, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6857, 4806, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6930, 5543, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6987, 6224, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7074, 7068, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15576, 10695, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22433, 14549, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22434, 14549, 7, 17, 8);
INSERT INTO 'dancesformationsmap' VALUES (15587, 128, 120, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15570, 11585, 85, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15583, 10669, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15559, 10351, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (6751, 3941, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22438, 14551, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22439, 14551, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22440, 14551, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (6856, 4805, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7083, 7164, 48, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6919, 5458, 90, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (6995, 6348, 76, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6903, 5332, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6991, 6285, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (6980, 6167, 19, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6973, 6077, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6970, 5981, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6964, 5893, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6960, 5848, 19, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6968, 5962, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (6958, 5824, 27, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6954, 5759, 62, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (6944, 5669, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6942, 5624, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6940, 5617, 24, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6938, 5591, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6932, 5547, 365, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (6923, 5494, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6913, 5398, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6899, 5276, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6959, 5825, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6875, 4968, 4, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6957, 5807, 61, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (6933, 5554, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6929, 5531, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6927, 5513, 48, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15597, 1541, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15604, 11591, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15605, 11591, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7001, 6377, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7106, 2, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7013, 6425, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7039, 6677, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7022, 6560, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7024, 6572, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7025, 6573, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7028, 6589, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7029, 6590, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7015, 6433, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7004, 6395, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7043, 6747, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7044, 6759, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7050, 6827, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15609, 11593, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15610, 11593, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15611, 11594, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15614, 11595, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15615, 11595, 124, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15616, 11595, 157, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15617, 11595, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15618, 11595, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15619, 11596, 152, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7061, 6929, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7085, 7173, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (7073, 7051, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7075, 7078, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7081, 7154, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7086, 7179, 69, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7094, 7236, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7095, 7237, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7096, 7246, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7100, 7271, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7101, 7271, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7078, 7139, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7109, 12, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7110, 7277, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6956, 5797, 28, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (15584, 11586, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (6983, 6191, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7023, 6566, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7093, 7234, 4, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7038, 6644, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6948, 5713, 72, 65, 4);
INSERT INTO 'dancesformationsmap' VALUES (6961, 5864, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7076, 7101, 61, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (7046, 6788, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7020, 6552, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6920, 5462, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6945, 5677, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7060, 6916, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15602, 11590, 114, 9, 8);
INSERT INTO 'dancesformationsmap' VALUES (7002, 6382, 21, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6921, 5463, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7052, 6848, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15603, 11590, 45, 24, 4);
INSERT INTO 'dancesformationsmap' VALUES (7019, 6539, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7048, 6819, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7092, 7229, 85, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7014, 6432, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6893, 5225, 36, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7030, 6596, 21, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6963, 5890, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (15573, 10647, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7007, 6401, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15608, 11592, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6979, 6122, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6946, 5680, 42, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (7098, 7259, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7104, 2616, 13, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (6982, 6185, 38, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (7011, 6420, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7069, 7017, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7035, 6615, 336, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6943, 5662, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7135, 1930, 27, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7139, 7298, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7140, 7277, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7143, 7303, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7144, 7305, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15629, 11599, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15630, 11599, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15631, 11599, 141, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6992, 6287, 317, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6985, 6214, 72, 21, 4);
INSERT INTO 'dancesformationsmap' VALUES (15632, 11599, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15634, 11584, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15635, 11584, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15636, 11584, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15637, 11584, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15638, 11584, 121, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7021, 6555, 36, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15664, 11609, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22429, 3981, 176, 4, 16);
INSERT INTO 'dancesformationsmap' VALUES (7091, 7226, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15620, 11588, 152, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7089, 7215, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6877, 4975, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15653, 11605, 173, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7056, 6885, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7124, 2237, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6962, 5878, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6997, 6362, 80, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7090, 7219, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7064, 6957, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7071, 7025, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31435, 3465, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7049, 6826, 22, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (6941, 5621, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6993, 6294, 84, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (7016, 6434, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7047, 6818, 62, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7072, 7030, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7058, 6901, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7066, 6967, 30, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (7000, 6373, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31828, 18284, 121, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7127, 3373, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7031, 6599, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7121, 7285, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15621, 11597, 202, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (7088, 7210, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7065, 6965, 28, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15622, 11597, 185, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15623, 11597, 102, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15657, 11607, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15658, 11607, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15659, 11607, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15650, 11604, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15651, 11604, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15652, 11604, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15646, 11603, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15647, 11603, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15648, 11603, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15633, 11600, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15626, 11598, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15627, 11598, 114, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (15628, 11598, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7034, 6613, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7102, 5118, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7103, 5118, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7097, 7257, 32, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7079, 7143, 18, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (7077, 7129, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7068, 6996, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7063, 6941, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7062, 6931, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (7055, 6879, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7054, 6860, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7082, 7162, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7053, 6849, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (7051, 6847, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (7042, 6711, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7041, 6710, 8, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (7036, 6631, 38, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7032, 6600, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7026, 6575, 7, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (7017, 6481, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7138, 6477, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7010, 6410, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7005, 6397, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7006, 6399, 24, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7003, 6391, 6, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6967, 5945, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6971, 6037, 76, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (7080, 7144, 18, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7084, 7172, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7128, 6803, 43, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (22444, 14552, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7179, 7332, 188, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (7180, 7332, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7200, 7343, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7145, 7305, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7146, 7305, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7147, 7306, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7148, 7280, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7149, 7280, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7150, 7307, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7151, 7307, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7152, 7307, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7153, 7308, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7154, 7287, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7155, 7309, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7158, 1, 46, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7159, 7315, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7160, 7315, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7161, 7315, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7162, 7291, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7170, 7320, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7171, 7320, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7172, 7323, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7173, 7324, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7175, 6852, 101, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7176, 7325, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7177, 7329, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7178, 7330, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7183, 7329, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7184, 7323, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7187, 1, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7198, 7342, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7199, 7342, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7201, 7345, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7202, 7347, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7208, 7354, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7217, 7365, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7218, 7365, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7221, 7367, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7222, 7370, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7223, 7370, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7228, 7377, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7229, 7379, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7230, 7380, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7231, 7380, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7232, 7381, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7235, 7383, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15666, 11611, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15667, 11611, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15668, 11612, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15669, 11612, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15670, 11612, 85, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15671, 11612, 58, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (15675, 11614, 213, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7087, 7182, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7111, 7282, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7120, 7282, 1, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (7112, 7283, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (6996, 6349, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15639, 11601, 190, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (15640, 11601, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7136, 4356, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7033, 6609, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7212, 7358, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7009, 6406, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6897, 5260, 76, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (15643, 11602, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7225, 7376, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7226, 7376, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7018, 6535, 86, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (7215, 7364, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7216, 7364, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7008, 6404, 61, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (15665, 11610, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15656, 11606, 12, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (15660, 11608, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15661, 11608, 56, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (7224, 7373, 81, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7207, 7353, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7206, 7352, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7169, 7295, 265, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7123, 5911, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7131, 1854, 87, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7107, 3441, 52, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7105, 3231, 75, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7113, 7283, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7114, 7283, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15676, 11614, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15677, 11614, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15678, 11614, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15690, 11619, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15691, 11619, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15692, 11619, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15693, 11619, 83, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15694, 11619, 76, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15695, 11619, 119, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (15696, 11619, 168, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (15706, 11622, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7163, 4311, 20, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7164, 4311, 24, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7165, 4311, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15707, 11622, 168, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7238, 7386, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7242, 7391, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7243, 7393, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7244, 7393, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7245, 7394, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7246, 7395, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7247, 7396, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7249, 7398, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7250, 7398, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7251, 7399, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7255, 7402, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7256, 7403, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7257, 7407, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7260, 7410, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7261, 7411, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7262, 7411, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7263, 7413, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7067, 6995, 87, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (7248, 7397, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15700, 11621, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15701, 11621, 117, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7213, 7360, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7214, 7360, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31352, 371, 183, 41, 3);
INSERT INTO 'dancesformationsmap' VALUES (31350, 4192, 1, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (31351, 4192, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31344, 4401, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31345, 4401, 176, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31346, 4401, 39, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (31347, 4401, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31348, 4401, 365, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (7156, 7310, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (7157, 3631, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22423, 12279, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7181, 7331, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7182, 7331, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7174, 2506, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15687, 11618, 65, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15688, 11618, 24, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15689, 11618, 353, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15679, 11615, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15680, 11615, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15681, 11615, 16, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (15682, 11615, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (7168, 7319, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7233, 7382, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7099, 7267, 317, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (7234, 7382, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (7258, 7409, 324, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7266, 7416, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7259, 7409, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7236, 7385, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7237, 7385, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7197, 7340, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7195, 7338, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7219, 7366, 85, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7210, 7356, 296, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7211, 7356, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7220, 7366, 29, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (7203, 7348, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7204, 7348, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7196, 7338, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7185, 7333, 114, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (7186, 7333, 119, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (22441, 14551, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22435, 14550, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22436, 14550, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22437, 14550, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (7209, 7355, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7193, 4126, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7118, 1782, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7126, 1018, 111, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7129, 407, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7130, 407, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7268, 7417, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7269, 7418, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7270, 7422, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7271, 7422, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7274, 7424, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7275, 7424, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7276, 7424, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7277, 7425, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7278, 7425, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7279, 7426, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7280, 7427, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7284, 7430, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7285, 7430, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7290, 7434, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7291, 7434, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7294, 7437, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7297, 7439, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7298, 7439, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15686, 11617, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7306, 7445, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7307, 7445, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7308, 7447, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7309, 7447, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7310, 7447, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7312, 7449, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7313, 7452, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7314, 7452, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7315, 7453, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7316, 7453, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7322, 7456, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15713, 11624, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7205, 7349, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15736, 11628, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15737, 11628, 260, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15724, 11626, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15725, 11626, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15726, 11626, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15727, 11626, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6910, 5374, 82, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (22459, 14559, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22460, 14559, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7331, 7470, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7332, 7470, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7333, 7471, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7340, 7477, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15732, 11627, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15738, 11628, 7, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15733, 11627, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7240, 7389, 38, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7241, 7389, 120, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (7239, 7387, 26, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7323, 7457, 4, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (7295, 7438, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7296, 7438, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15714, 11625, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15715, 11625, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15716, 11625, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15717, 11625, 209, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15718, 11625, 210, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15739, 11628, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7283, 7429, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7334, 7472, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7335, 7472, 18, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (7336, 7472, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7324, 7458, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7317, 7454, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7318, 7454, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7319, 7454, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (7301, 7442, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7304, 7443, 90, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7305, 7443, 56, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (15672, 11613, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15673, 11613, 87, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7339, 7476, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7119, 7288, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (7292, 7435, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7293, 7435, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15697, 11620, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15698, 11620, 185, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7281, 7428, 45, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (7282, 7428, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (7286, 7432, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7287, 7432, 45, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (7328, 7464, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7327, 7460, 353, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (7272, 7423, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7273, 7423, 7, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (7125, 4273, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7311, 7448, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7302, 7442, 58, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (7303, 7442, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7264, 7414, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7252, 7401, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7253, 7401, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7254, 7401, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7341, 7477, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7342, 7478, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7344, 7481, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7345, 7483, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7352, 7491, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7353, 7492, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7354, 7493, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7357, 7495, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7358, 7495, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7361, 7497, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7362, 7498, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7337, 7473, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7338, 7473, 125, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7368, 7502, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7371, 7505, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7375, 7508, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7376, 7509, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7380, 7512, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7383, 7514, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7384, 7515, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7385, 7515, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7386, 7516, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15756, 9646, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7394, 7525, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7395, 7525, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7396, 7526, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7397, 7526, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7398, 7526, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7404, 7537, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7405, 7537, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7406, 7538, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7410, 7541, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7411, 7541, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15757, 7650, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15758, 10235, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31353, 371, 112, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31354, 371, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31349, 4590, 134, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (15684, 11616, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15685, 11616, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7320, 7455, 25, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7346, 7484, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7347, 7484, 22, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15752, 8331, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15753, 8331, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7359, 7496, 157, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7360, 7496, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7402, 7532, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7267, 7416, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7403, 7532, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7299, 7440, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7300, 7440, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7399, 7528, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7400, 7528, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7372, 7506, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7373, 7506, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7374, 7506, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7363, 7499, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7364, 7499, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7329, 7469, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (7330, 7469, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7418, 7368, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7419, 7368, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7416, 7350, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7417, 7350, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7412, 7337, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7413, 7337, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15743, 4853, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15744, 4853, 124, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15745, 4853, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15746, 3085, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15741, 3016, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15749, 3679, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15750, 3679, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15751, 4747, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15740, 2882, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (15747, 7852, 240, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15748, 7852, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15742, 3016, 156, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15759, 10235, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15760, 11662, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15761, 11662, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15762, 11662, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15763, 11663, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15764, 11663, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15765, 11663, 203, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15766, 11663, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15767, 11663, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15768, 11664, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15769, 11664, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15770, 11664, 59, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15771, 11665, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15772, 11665, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15773, 11665, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15774, 11666, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15775, 11666, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15776, 11666, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15777, 11667, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15778, 11667, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15779, 11667, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15780, 11668, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15781, 11668, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15782, 11668, 60, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15783, 11668, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15789, 11670, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15790, 11670, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15791, 11670, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15792, 11671, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13537, 9194, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13539, 9194, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22447, 9194, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7453, 5847, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22448, 11269, 225, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (7461, 5964, 111, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7467, 709, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7468, 709, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7469, 709, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7481, 2046, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7369, 7503, 19, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7448, 4894, 1, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (7367, 7501, 19, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7449, 5208, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7265, 7415, 8, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (7415, 7339, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7458, 7204, 112, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7459, 7204, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7460, 7204, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7450, 5208, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22461, 14560, 158, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15728, 556, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (7387, 7518, 124, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7388, 7518, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7381, 7513, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7382, 7513, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7350, 7488, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7348, 7485, 66, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7349, 7485, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7343, 7480, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7425, 7404, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7426, 7404, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15729, 556, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7482, 2046, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7483, 2046, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7484, 3825, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7485, 3825, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7490, 1210, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7494, 2166, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7495, 1478, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7496, 4325, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7497, 6233, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7498, 6182, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7500, 2682, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7506, 5641, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7507, 6658, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7508, 5436, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7509, 3802, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7510, 4195, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7511, 2053, 30, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7512, 1348, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7513, 1799, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7451, 5222, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7191, 5260, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7192, 5260, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (15730, 3561, 118, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7377, 7511, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7389, 7520, 87, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7365, 7500, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7370, 7504, 81, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7401, 7530, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7407, 7540, 134, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7408, 7540, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7424, 7388, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7440, 2700, 33, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7434, 1163, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (7515, 723, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7517, 7109, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7519, 5702, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7522, 610, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7480, 1641, 269, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7542, 651, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7543, 651, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7544, 651, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15793, 11671, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15794, 11671, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15795, 11672, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15796, 11672, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15797, 11673, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15798, 11673, 210, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15799, 11673, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15800, 11673, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15801, 11674, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15802, 11674, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15803, 11674, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15804, 11674, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15805, 11675, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15806, 11675, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15807, 11675, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7455, 6734, 112, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7559, 1, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15809, 11676, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7441, 3526, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7464, 183, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7465, 183, 183, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (7454, 6130, 149, 24, 1);
INSERT INTO 'dancesformationsmap' VALUES (7435, 1469, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31356, 3521, 365, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7518, 5731, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7492, 2250, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7476, 7239, 105, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15784, 11669, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15785, 11669, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (15786, 10599, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15787, 10599, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7491, 5007, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7431, 107, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7392, 7524, 77, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7393, 7524, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7355, 7494, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7420, 7375, 69, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7421, 7375, 52, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7457, 7188, 183, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (7561, 6285, 96, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (7523, 4782, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7562, 6058, 18, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (7548, 5741, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7526, 5591, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7585, 5326, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7586, 5326, 36, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (7446, 4440, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7539, 4068, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7443, 3861, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7444, 3861, 46, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (7445, 3861, 365, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7478, 3763, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7527, 3722, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7564, 3338, 109, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7563, 3267, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7537, 3152, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7538, 3152, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7479, 2910, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7486, 3085, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7438, 2495, 46, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7439, 2495, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7437, 2352, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7577, 1966, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7505, 2044, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7432, 848, 176, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7433, 848, 86, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (7551, 378, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (7552, 378, 138, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7472, 7558, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7473, 7558, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7470, 7557, 114, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (7504, 588, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15810, 11676, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7643, 505, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15808, 11675, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15812, 11677, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15813, 11677, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15814, 11677, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15815, 11677, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7555, 3921, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7516, 3834, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15826, 11681, 24, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7637, 4388, 122, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7525, 3972, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7640, 1708, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15819, 11679, 114, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15820, 11679, 92, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15821, 11679, 119, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7536, 1415, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7499, 5376, 30, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (7428, 7420, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7566, 3418, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (7447, 4662, 32, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (7641, 7531, 143, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (7642, 7531, 38, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (7488, 6748, 118, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7489, 6748, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7609, 6640, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (7501, 1615, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7556, 3921, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (7487, 5239, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7594, 250, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7595, 250, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7596, 250, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15827, 11681, 19, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (15828, 11681, 192, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (7571, 314, 121, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (7524, 6763, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7581, 221, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7584, 5786, 59, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22465, 14561, 158, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7675, 3252, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7646, 1435, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7647, 1435, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7648, 1435, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7670, 973, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7671, 973, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7672, 1036, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (270, 480, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6329, 480, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7687, 7788, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7688, 7788, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7689, 7788, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7724, 1478, 7, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7725, 4325, 125, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7610, 551, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7611, 551, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7602, 6823, 120, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7603, 6823, 176, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7638, 2423, 123, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7690, 3016, 124, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7614, 769, 168, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (7674, 218, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7737, 5704, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7616, 5198, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7617, 5198, 72, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7579, 4506, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7530, 4755, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7567, 4796, 39, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7560, 4103, 120, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (7632, 695, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7633, 695, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7554, 1864, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7705, 8110, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7615, 6091, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15863, 11690, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15816, 11678, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15817, 11678, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7628, 387, 210, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7629, 387, 72, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (7635, 6236, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15864, 11690, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31358, 2544, 332, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31359, 2544, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15865, 11690, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7685, 2226, 46, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7686, 2226, 20, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7502, 1931, 86, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (7605, 6862, 114, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7456, 7042, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7709, 7605, 58, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (7477, 3397, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7529, 5032, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7573, 4617, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7574, 4617, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (7514, 3236, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15838, 4215, 65, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7568, 822, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7606, 2722, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (7607, 2722, 38, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (7673, 2260, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7693, 2158, 265, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (7644, 1924, 4, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7547, 3474, 45, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15860, 11689, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7578, 4438, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7545, 7189, 114, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7565, 2453, 112, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7541, 4032, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (7589, 5612, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7590, 5612, 114, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (7591, 5612, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15861, 11689, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7520, 5141, 317, 121, 2);
INSERT INTO 'dancesformationsmap' VALUES (7521, 5141, 22, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (15872, 11694, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7636, 3336, 149, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (15866, 11692, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15867, 11692, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15868, 11692, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15845, 11684, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15846, 11684, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15847, 11684, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7618, 6621, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7619, 6621, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15839, 11682, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15840, 11682, 55, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15841, 11683, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15842, 11683, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (15843, 11683, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15851, 11686, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15852, 11686, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15853, 11686, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7722, 4293, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7531, 1501, 31, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7532, 1501, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7700, 8087, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7701, 8087, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7702, 8087, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7695, 8086, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7696, 8086, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7697, 8086, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22449, 14554, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22450, 14554, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22451, 14554, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7493, 5658, 111, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7652, 3180, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7653, 3180, 19, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7570, 2453, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (15823, 11680, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15824, 11680, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (7639, 6161, 123, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (7546, 5945, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7598, 1544, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7599, 1544, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7558, 4968, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7726, 3575, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7727, 3575, 64, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (7540, 3541, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7549, 3129, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7550, 3129, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7665, 2312, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7666, 2312, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7503, 1931, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7661, 1246, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7612, 629, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15882, 11699, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15883, 11699, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15884, 11699, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15885, 11700, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15886, 11700, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15887, 11700, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15888, 11700, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15889, 11700, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15890, 11700, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15891, 11701, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15892, 11701, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22470, 3435, 268, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22475, 14564, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22476, 14564, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22477, 14564, 49, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22480, 480, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7669, 1308, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (7582, 2437, 114, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (7654, 5846, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22468, 1647, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7676, 3252, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7720, 6459, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7721, 6459, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7608, 6035, 120, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7713, 8113, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7714, 8113, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7658, 5199, 55, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15829, 10113, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7535, 4641, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7681, 2050, 103, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7659, 5199, 72, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (7649, 4998, 176, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7650, 4998, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7682, 2050, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7683, 2050, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (7731, 1204, 130, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15834, 385, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15835, 385, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15836, 385, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7691, 358, 9, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22466, 14561, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22467, 14561, 132, 21, 4);
INSERT INTO 'dancesformationsmap' VALUES (22464, 14560, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7655, 5846, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7656, 5846, 114, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (7677, 3252, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22471, 13622, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (22472, 13622, 260, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22473, 13622, 56, 29, 4);
INSERT INTO 'dancesformationsmap' VALUES (15833, 10496, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22469, 1647, 18, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7738, 2116, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7742, 2976, 130, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7757, 7541, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7759, 1478, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7760, 5847, 139, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7761, 5450, 138, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31830, 13912, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31831, 13912, 10, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7778, 2053, 18, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7779, 1348, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7784, 5963, 125, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7785, 5963, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7786, 7109, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7788, 5963, 144, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7789, 8163, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7790, 8163, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7791, 8163, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15897, 11617, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7810, 8174, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7811, 8174, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7814, 8180, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7815, 8183, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7816, 8183, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7817, 8185, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7822, 8194, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7823, 8195, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7824, 8195, 25, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7825, 8196, 19, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7826, 7709, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7873, 8235, 10, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (22478, 14564, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7843, 3780, 60, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7844, 8212, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7845, 8213, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7847, 8216, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7857, 8223, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7859, 8225, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7860, 8225, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7732, 29, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7872, 8234, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15923, 4435, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7747, 2498, 131, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7805, 8169, 77, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7795, 8141, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7796, 8141, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7797, 8141, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7806, 8169, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7804, 8168, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7777, 2812, 138, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15831, 154, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7801, 8167, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7802, 8167, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7803, 8167, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15832, 154, 176, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (15858, 11688, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7664, 1883, 327, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15859, 11688, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15899, 9926, 83, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7848, 8217, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7849, 8217, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7730, 4781, 130, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (7828, 8199, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7717, 8103, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7718, 5170, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (7719, 5170, 103, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7746, 862, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7569, 822, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7771, 5581, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7743, 3562, 1, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (7744, 3562, 7, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (7745, 3562, 132, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (31361, 2544, 33, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (7620, 3299, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7645, 3857, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15896, 9189, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15873, 11694, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15874, 11694, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7741, 5527, 130, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15876, 11696, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15875, 11695, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15893, 11702, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15894, 11702, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15877, 11697, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15878, 11697, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15879, 11698, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15880, 11698, 189, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (15895, 11702, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15830, 9223, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7694, 8051, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7780, 6505, 120, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (15928, 8461, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15929, 8461, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15915, 8354, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15916, 8354, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7829, 8200, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7812, 8178, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7813, 8178, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7808, 8172, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7809, 8172, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7710, 8102, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7711, 8102, 72, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (22452, 14554, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (22453, 14554, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7773, 6816, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7703, 6575, 46, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7657, 6481, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7756, 5981, 58, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7764, 218, 114, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (7663, 4629, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7850, 8218, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7851, 8218, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7662, 2004, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7729, 1961, 129, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7735, 1819, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7736, 1819, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7660, 904, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7765, 523, 265, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7856, 8222, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7861, 8226, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7863, 8228, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7852, 8219, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7853, 8220, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7723, 1792, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7868, 8232, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7869, 8232, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7827, 8198, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7833, 8204, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7870, 8233, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7871, 8233, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7858, 8224, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7865, 8230, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7864, 8229, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7866, 8231, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7846, 8215, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7875, 8236, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7876, 8236, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7877, 8237, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7878, 8237, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7787, 1274, 132, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7839, 8210, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7837, 8207, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7838, 8208, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7834, 8205, 32, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7749, 2820, 7, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7782, 3834, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7854, 8221, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7855, 8221, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7783, 3834, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7769, 1537, 260, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15917, 8466, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7874, 8235, 56, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15918, 8466, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7793, 8164, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7794, 8164, 56, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7840, 8211, 143, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7841, 8211, 1, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (7751, 5693, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7752, 5693, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7818, 8193, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22474, 13622, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7879, 8239, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7880, 8239, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7883, 8267, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7884, 8270, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7885, 8270, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7886, 8269, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7887, 8269, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7890, 8272, 133, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7891, 8273, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7892, 8275, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7893, 8276, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7894, 8277, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7895, 8278, 13, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7896, 8279, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7899, 8284, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7900, 8284, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7901, 8286, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7902, 8287, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7903, 8287, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7906, 8290, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7911, 8293, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7914, 8296, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7915, 8297, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7916, 8298, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7917, 8298, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7918, 8300, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7919, 8300, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7920, 8300, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7921, 8301, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7922, 8301, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7941, 8340, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22486, 14241, 138, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (7766, 1485, 29, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (22484, 14569, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22485, 14569, 82, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (22494, 14369, 142, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22495, 14369, 69, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (22496, 14369, 52, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7923, 8302, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7924, 8303, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7925, 8306, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7926, 8308, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7927, 8308, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7930, 8311, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7933, 8316, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7934, 7977, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7935, 7977, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7936, 7977, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7939, 7697, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7940, 7839, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7942, 4740, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7943, 4740, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7944, 4740, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7945, 357, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7947, 7701, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7950, 7641, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7951, 7870, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7952, 8342, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7953, 8342, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7954, 5780, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7956, 7854, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7957, 7854, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7960, 7451, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7961, 7451, 35, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7965, 8376, 81, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7966, 8377, 5, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7967, 8377, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7963, 8374, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7964, 8374, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22481, 14568, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7533, 4928, 82, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (7768, 3383, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7758, 1562, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7830, 8201, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7831, 8201, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7897, 8283, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7821, 8112, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7807, 1841, 46, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15855, 11687, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15856, 11687, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22479, 454, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7862, 8227, 2, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7946, 7838, 70, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7836, 8206, 143, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7781, 3236, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15902, 11703, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7772, 5581, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22487, 13387, 231, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22488, 13387, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7968, 8378, 65, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7970, 8381, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7971, 8381, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7972, 8381, 38, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7973, 8382, 65, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7974, 8382, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7975, 8382, 91, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7976, 8383, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7977, 8383, 72, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (7978, 8384, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7979, 8385, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7980, 8386, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7981, 8386, 9, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7982, 7752, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7983, 7752, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7984, 7721, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7985, 7964, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7990, 8390, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7991, 8390, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7992, 8391, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7993, 8391, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7994, 8392, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7986, 8388, 189, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (7929, 8310, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7931, 8312, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7969, 8380, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22490, 14577, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7754, 4144, 60, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (15957, 8469, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15900, 8467, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7762, 3323, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15958, 8469, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15959, 8469, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15912, 8465, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15913, 8465, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (15919, 8463, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15920, 8463, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (7932, 8313, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7819, 8111, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7820, 8111, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7755, 7336, 58, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7763, 218, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7739, 2354, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (7740, 2354, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7770, 1961, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7750, 1931, 135, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (22491, 14577, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15908, 8464, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15909, 8464, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7995, 8393, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7996, 8393, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8002, 8397, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8003, 8398, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8005, 8400, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8009, 8404, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8010, 8405, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8013, 8408, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8014, 8408, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15969, 8479, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8008, 8403, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8006, 8402, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8007, 8402, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8000, 8395, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8001, 8396, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8004, 8399, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7881, 8240, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7907, 8291, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7908, 8291, 60, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7909, 8292, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (7910, 8292, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15970, 8479, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (15945, 8472, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15946, 8472, 95, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15947, 8472, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (22492, 9889, 43, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (22493, 9889, 66, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (15963, 8468, 64, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15964, 8468, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (15955, 8477, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15956, 8477, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7988, 8389, 30, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7937, 7888, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7938, 7888, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8015, 8409, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8019, 8413, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8020, 8414, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8021, 8415, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8023, 8419, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8024, 8420, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8025, 8422, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8027, 8424, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8028, 8424, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8029, 8426, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8030, 8427, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8031, 8428, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8032, 8428, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8037, 8433, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8038, 8433, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8040, 8435, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8041, 8436, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8042, 8437, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8043, 8437, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8044, 8437, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8045, 8438, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8049, 8441, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8050, 8441, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8053, 8443, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8054, 8443, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8055, 8444, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15981, 8483, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15982, 8483, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15983, 8483, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15984, 8483, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (8068, 7828, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8056, 8444, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8057, 8445, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8059, 614, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8060, 614, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8074, 8580, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8075, 5702, 120, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (8083, 70, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8084, 70, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8085, 70, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8086, 70, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8063, 7825, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8064, 7825, 145, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8117, 1593, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8126, 4069, 13, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15993, 11612, 102, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (16016, 11711, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16017, 11711, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16018, 11711, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8066, 7775, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8067, 7775, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16022, 11714, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16027, 11716, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16019, 11712, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16020, 11712, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8018, 8412, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8033, 8431, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16028, 11717, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16029, 11717, 48, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16021, 11713, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16025, 11715, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16026, 11715, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8034, 8431, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8035, 8431, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8036, 8432, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8039, 8434, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8047, 8440, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8048, 8440, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8046, 8439, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8017, 8411, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8058, 8446, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8051, 8442, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8052, 8442, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8026, 8423, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8134, 1625, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (15979, 8481, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8102, 387, 149, 47, 1);
INSERT INTO 'dancesformationsmap' VALUES (15939, 8478, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15980, 8481, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31365, 3653, 134, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8078, 5362, 132, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7904, 8289, 52, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (7753, 3659, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8022, 8418, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8076, 3775, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16015, 11710, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8011, 8407, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15932, 4403, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15933, 4403, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22489, 13387, 107, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15942, 8475, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15943, 8475, 95, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15936, 8474, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15937, 8474, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15938, 8474, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15949, 8470, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (15905, 8462, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15906, 8462, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8137, 2674, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8143, 4354, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8138, 2674, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8140, 3710, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (8141, 3710, 38, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16006, 11708, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7913, 8295, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16007, 11708, 56, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (16034, 11013, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16035, 11013, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16012, 11709, 23, 25, 8);
INSERT INTO 'dancesformationsmap' VALUES (16013, 11709, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15975, 8487, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15976, 8487, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (15966, 8486, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15967, 8486, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15985, 8485, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15986, 8485, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15987, 8485, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15953, 8476, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15954, 8476, 82, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (15950, 8473, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15951, 8473, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (15952, 8473, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15960, 8471, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15961, 8471, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15962, 8471, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7888, 8271, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7889, 8271, 34, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8080, 4782, 125, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (8124, 5848, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8125, 5848, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8115, 5741, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8130, 5188, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8139, 3454, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7997, 8394, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7998, 8394, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8079, 3046, 125, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (8090, 1429, 103, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8091, 1429, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8087, 1350, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (8088, 1232, 150, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8089, 1232, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15940, 8478, 95, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8136, 1777, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8069, 7589, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8070, 7589, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8071, 7681, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8072, 7686, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8073, 7686, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31832, 13912, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31833, 13912, 220, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (15997, 11706, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15998, 11706, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16009, 3503, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8093, 1566, 58, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8094, 1566, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8095, 1566, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8131, 354, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (8132, 354, 32, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8133, 354, 87, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (8127, 18, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8128, 18, 43, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (8098, 7744, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8119, 6897, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8120, 6897, 105, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (16045, 10419, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8245, 8584, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8159, 7011, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8160, 7011, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8161, 7208, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8162, 7208, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8166, 236, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8167, 4344, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8168, 4344, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8170, 4295, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8172, 8267, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8176, 8272, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8177, 8272, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8178, 8272, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8179, 8273, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8180, 8274, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8181, 8275, 37, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8182, 8275, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8183, 8275, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8184, 8276, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8185, 8276, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8186, 8277, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8187, 8279, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8188, 8279, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8189, 8305, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8190, 8305, 110, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8191, 8307, 40, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8192, 8307, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8193, 8307, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8194, 8307, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8195, 8308, 40, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8197, 8311, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8202, 8316, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8203, 8293, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8204, 8293, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8209, 8296, 34, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8210, 8298, 34, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8211, 8301, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8212, 8304, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21888, 13355, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8246, 8584, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8218, 8285, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8219, 8285, 152, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8220, 8286, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8221, 8287, 153, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8222, 8287, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8223, 8288, 153, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8224, 8288, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8225, 8288, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8226, 8288, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8228, 8290, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8229, 8290, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8230, 8290, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8173, 8268, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8240, 221, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16069, 11728, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16070, 11728, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16071, 11728, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16072, 11728, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16079, 11729, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16080, 11729, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16081, 11729, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16082, 11730, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16083, 11730, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16084, 11730, 162, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8171, 1528, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8266, 8593, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22497, 14369, 4, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (22498, 14369, 149, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (22499, 14369, 1, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (16085, 11731, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16086, 11731, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8241, 8583, 154, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8242, 8583, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8263, 8591, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8264, 8591, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8265, 8592, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8272, 8595, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8273, 8595, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8274, 8595, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8275, 8596, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8279, 8598, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8280, 8598, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8281, 8599, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8282, 8598, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8205, 8294, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8154, 6449, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8152, 6830, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8198, 8312, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (8121, 598, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8122, 598, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16074, 327, 339, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16008, 11708, 43, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (16001, 11707, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8118, 670, 114, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (31366, 570, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (16041, 1255, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16042, 1255, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8061, 8559, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8062, 8559, 185, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8077, 5141, 273, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (16062, 11727, 77, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (16050, 8654, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16051, 8654, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16047, 7141, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16048, 7141, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15994, 11704, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15995, 11704, 8, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (16037, 11402, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16004, 8094, 203, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (16005, 8094, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8217, 8283, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16055, 11722, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16054, 11719, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16073, 170, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15935, 4403, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15978, 8484, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16056, 11723, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16063, 11727, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8206, 8295, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8207, 8295, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16064, 11727, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16060, 11725, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16061, 11725, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16002, 11707, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16003, 11707, 203, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (16036, 11013, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8276, 8597, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8277, 8597, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15989, 8488, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15990, 8488, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15991, 8488, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15977, 8487, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8199, 8313, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8099, 8246, 71, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8100, 8246, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8112, 7189, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8151, 6675, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16087, 6299, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8129, 68, 13, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16043, 4727, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16044, 4727, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8146, 3963, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8147, 3963, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16010, 3923, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16011, 3923, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8096, 1609, 61, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16075, 1555, 265, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (16076, 1555, 203, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8101, 1223, 110, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8107, 708, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8108, 708, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8103, 485, 103, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8104, 485, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8169, 291, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8267, 8594, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8268, 8594, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8231, 8291, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8232, 8291, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8233, 8292, 60, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8234, 8292, 59, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8235, 8292, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8236, 8292, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8237, 8292, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8200, 8314, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8201, 8314, 151, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8260, 8589, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8261, 8589, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8262, 8589, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8249, 8585, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8250, 8585, 273, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8251, 8585, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8253, 8587, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8254, 8587, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8255, 8587, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8213, 8281, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8214, 8281, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8215, 8282, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8216, 8282, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8256, 8588, 155, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8257, 8588, 278, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8258, 8588, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8252, 8586, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8243, 8583, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8244, 8583, 8, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8285, 8601, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8286, 8602, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8287, 8602, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8288, 8602, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16049, 9534, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16046, 10419, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8292, 8604, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8293, 8604, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8294, 8605, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8295, 8605, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8296, 8606, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8297, 8606, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8298, 8606, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21889, 13355, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (8328, 8621, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8329, 8621, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8330, 8621, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31282, 18235, 96, 31, 2);
INSERT INTO 'dancesformationsmap' VALUES (16097, 11733, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16098, 11733, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16099, 11733, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16100, 11733, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16101, 11734, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16102, 11734, 203, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16122, 11753, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16123, 11753, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16124, 11754, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16125, 11754, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16126, 11754, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16127, 11754, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16128, 11755, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16129, 11755, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16130, 11755, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22500, 14369, 72, 61, 1);
INSERT INTO 'dancesformationsmap' VALUES (8336, 8622, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8337, 8622, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16135, 11757, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8368, 8638, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8369, 8638, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8370, 8638, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8371, 8638, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8372, 8638, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8373, 8638, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8382, 8639, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8389, 8649, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8390, 8649, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8391, 8649, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8392, 8651, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8395, 8652, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8396, 8652, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8397, 8652, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8404, 8655, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8405, 8655, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8406, 8655, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8407, 8655, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8411, 8657, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8412, 8657, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8413, 8657, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8414, 8657, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8415, 8657, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8416, 8657, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8419, 8659, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8420, 8659, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8421, 8659, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8425, 8661, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16119, 11751, 214, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8302, 8610, 2, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8303, 8610, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16114, 9504, 216, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8308, 8613, 2, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8301, 8609, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8304, 8611, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8305, 8611, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8306, 8612, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8309, 8615, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8310, 8617, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8311, 8617, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8319, 2924, 131, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8320, 2924, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16089, 6743, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16090, 6743, 120, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8149, 4211, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (16110, 4106, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16091, 6743, 121, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (16092, 6743, 86, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8283, 8600, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8284, 8600, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31826, 18284, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31827, 18284, 120, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16112, 11750, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16057, 11724, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16058, 11724, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16059, 11724, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16038, 11720, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (16104, 11749, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16105, 11749, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (16106, 11749, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16065, 9404, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16066, 9404, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16067, 9404, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16068, 9404, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16108, 9193, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8422, 8660, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8423, 8660, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8424, 8660, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8398, 8653, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8399, 8653, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8400, 8653, 119, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8347, 8629, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8227, 8289, 66, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (8402, 8590, 386, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8403, 8315, 386, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16078, 10500, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8383, 8647, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16103, 7092, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8346, 8628, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8316, 8620, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8317, 8620, 124, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8318, 8620, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8289, 8603, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8290, 8603, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8174, 8271, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (8175, 8271, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8394, 8105, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8338, 7826, 51, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8339, 7826, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16138, 11758, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8374, 6477, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8321, 5927, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8322, 5927, 30, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16111, 4106, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8148, 3963, 175, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8331, 3829, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8332, 3829, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16118, 3691, 215, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8408, 8656, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8409, 8656, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8379, 1296, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8384, 3232, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8385, 3232, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16117, 929, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8315, 8619, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8313, 8618, 153, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8314, 8618, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16120, 11752, 138, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16121, 11752, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16116, 188, 216, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8367, 8637, 74, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8326, 2344, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8327, 2344, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8357, 4335, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8358, 8631, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8359, 8631, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8360, 8631, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8361, 8633, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8363, 8634, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8365, 8636, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8366, 8636, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8417, 8658, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8418, 8658, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8354, 3020, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8355, 3020, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16131, 11756, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16132, 11756, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8341, 7745, 19, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (16161, 11767, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16162, 11767, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16163, 11767, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16164, 11767, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16165, 11768, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16167, 10234, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22501, 14575, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22502, 14575, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22503, 14575, 23, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (8426, 8661, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8427, 8661, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8428, 8661, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8429, 8662, 132, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8430, 8662, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8431, 8662, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8432, 8663, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8433, 8663, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8434, 8663, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8435, 8663, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8436, 8664, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8437, 8664, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8438, 8664, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8446, 8667, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8447, 8667, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8448, 8667, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8470, 8673, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8471, 8673, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8475, 8675, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8476, 8675, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8477, 8675, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8478, 8675, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8482, 8677, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8483, 8677, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8484, 8677, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8485, 8678, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8486, 8678, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8487, 8678, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8488, 8679, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8489, 8679, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8490, 8679, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8491, 8679, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8492, 8680, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8493, 8680, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8494, 8680, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8495, 8680, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8496, 8681, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8497, 8681, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8498, 8681, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8499, 8681, 157, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8512, 8685, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8513, 8685, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8514, 8685, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8515, 8685, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8516, 8685, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8517, 8686, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8518, 8686, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8519, 8686, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8520, 8687, 157, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8524, 8690, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8525, 8690, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8526, 8690, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8527, 8690, 47, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8528, 8690, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8529, 8691, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8530, 8691, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8531, 8691, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8540, 8694, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8541, 8694, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8542, 8694, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8543, 8694, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8544, 8695, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8545, 8695, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8546, 8695, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8547, 8695, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8548, 8696, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8549, 8696, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8554, 8698, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8555, 8698, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16179, 11776, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16180, 11776, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16181, 11778, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16182, 11778, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16183, 11778, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16184, 11778, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22504, 14575, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8556, 8698, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8557, 8699, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8558, 8699, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16149, 11761, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16150, 11761, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8381, 4356, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8442, 8666, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8444, 8666, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8445, 8666, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8532, 8692, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8533, 8692, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8380, 754, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8479, 8676, 33, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (8480, 8676, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8472, 8674, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8350, 8630, 55, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8351, 8630, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16151, 11762, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16152, 11762, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (8534, 8693, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8535, 8693, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16168, 11774, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16169, 11774, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (16170, 11774, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16160, 11765, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (16178, 10887, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16088, 6299, 30, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (8378, 3623, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8550, 8697, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8551, 8697, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8552, 8697, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8449, 8668, 29, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (8450, 8668, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8451, 8668, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8452, 8668, 70, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (8348, 8629, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8344, 8627, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8439, 8665, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8440, 8665, 308, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8441, 8665, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8345, 8627, 90, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8393, 8105, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8505, 8683, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16166, 8241, 10, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8521, 8689, 56, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8299, 8608, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8522, 8689, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8340, 7826, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8376, 7245, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8377, 7242, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16139, 11758, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16140, 11758, 117, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16141, 11758, 90, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16142, 11758, 66, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (16143, 11758, 149, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (8457, 8670, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8458, 8670, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8459, 8670, 8, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (8460, 8670, 52, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (8553, 8697, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8500, 8682, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8501, 8682, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8502, 8682, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8375, 1018, 180, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8481, 8676, 58, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (16113, 2531, 282, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (16173, 11775, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16174, 11775, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16175, 11775, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16176, 11775, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8334, 5885, 114, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8335, 5885, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16185, 11779, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8564, 8701, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8565, 8701, 52, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31834, 13909, 189, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8589, 8667, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8590, 8673, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8593, 8712, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8594, 8712, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8595, 8712, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8596, 8712, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8597, 8712, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8598, 8713, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8599, 8713, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8600, 8713, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14877, 11434, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (8610, 8716, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8611, 8716, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8612, 8716, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8613, 8717, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8614, 8717, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8615, 8717, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8616, 8717, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8624, 8721, 109, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8625, 8721, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8626, 8721, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8647, 734, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8648, 734, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8649, 734, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8650, 734, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16190, 11705, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16191, 11705, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16192, 11705, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16195, 11783, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16196, 11783, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16200, 11786, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16201, 11786, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16202, 11786, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16208, 11789, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16209, 11789, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16211, 11791, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16212, 11791, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16213, 11791, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16214, 11792, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16215, 11792, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16216, 11792, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16217, 11793, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16218, 11794, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16219, 11794, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16220, 11794, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22505, 14574, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (22506, 14574, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (22507, 14574, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8642, 548, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8643, 548, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8653, 772, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8654, 772, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8679, 1230, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8680, 1230, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8681, 1230, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8682, 1230, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16197, 11784, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8697, 1686, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8698, 1686, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8699, 1686, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8700, 1686, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8701, 1686, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8702, 1686, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8703, 1686, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8639, 541, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16198, 11784, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30833, 16956, 263, 9, 0);
INSERT INTO 'dancesformationsmap' VALUES (8693, 1549, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8694, 1549, 23, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (16189, 11782, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16223, 11796, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16224, 11796, 32, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (8570, 8705, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8656, 893, 183, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8621, 8719, 5, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8657, 893, 134, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (8606, 8715, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8607, 8715, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8352, 8630, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16144, 11759, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16145, 11759, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (8463, 8672, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8464, 8672, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8466, 8672, 7, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (16221, 11795, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16222, 11795, 202, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8665, 976, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8666, 976, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8667, 976, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (8668, 976, 1, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (16205, 11788, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16206, 11788, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16207, 11788, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (16203, 11787, 33, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (16204, 11787, 16, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16193, 11750, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16194, 11750, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8631, 219, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8632, 219, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8608, 8715, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8659, 929, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8660, 929, 123, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8661, 929, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (8566, 8703, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8567, 8703, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8568, 8703, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8561, 8700, 19, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (8562, 8700, 43, 57, 4);
INSERT INTO 'dancesformationsmap' VALUES (8563, 8700, 1, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (8453, 8669, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8454, 8669, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8455, 8669, 356, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8456, 8669, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (16229, 11769, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (16230, 11769, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16146, 11760, 225, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16147, 11760, 324, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8644, 559, 23, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (8645, 559, 165, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8646, 559, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8628, 10, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8629, 10, 157, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8580, 8707, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8581, 8707, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8582, 8707, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8691, 1496, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8692, 1496, 132, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8685, 1293, 30, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8686, 1293, 365, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8687, 1293, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8688, 1293, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8676, 1165, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8677, 1165, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8678, 1165, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8669, 1066, 18, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (8670, 1066, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8671, 1066, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8672, 838, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16225, 11797, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8673, 838, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8651, 761, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8652, 761, 158, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8584, 8708, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8585, 8708, 29, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (31441, 18248, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16210, 11790, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16199, 11785, 76, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (8601, 8714, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31436, 17753, 277, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31437, 17753, 262, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8690, 1437, 332, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (8640, 545, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8641, 545, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8655, 545, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8635, 229, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8636, 229, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8571, 8705, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8572, 8705, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8637, 502, 316, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8695, 1549, 72, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (8683, 1250, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8684, 1250, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8674, 1161, 83, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8675, 1161, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8617, 8718, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8722, 2126, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8723, 2126, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (8724, 2190, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8725, 2190, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8726, 2190, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8727, 2190, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8728, 2190, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8729, 2190, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8742, 2351, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8743, 2351, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16272, 11810, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31442, 18249, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31443, 18249, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8805, 3695, 222, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (8806, 3695, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8788, 3226, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8789, 3226, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8790, 3226, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8791, 3226, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8799, 3557, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8800, 3557, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8801, 3557, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8796, 3527, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8797, 3527, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8818, 4011, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8819, 4011, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8820, 4011, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8798, 3527, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16288, 3194, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8815, 4008, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (8816, 4008, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8817, 4008, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8780, 2933, 112, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8781, 2933, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8782, 2933, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16246, 11800, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8821, 4038, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8822, 4038, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8823, 4038, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8758, 2635, 149, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8759, 2635, 111, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8707, 1802, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8708, 1802, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8709, 1802, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16231, 11770, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16232, 11770, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8765, 2770, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (8829, 4180, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8744, 2401, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8745, 2401, 23, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (8746, 2401, 30, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8834, 4256, 176, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8830, 4180, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8831, 4180, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8795, 3504, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8747, 2401, 36, 20, 1);
INSERT INTO 'dancesformationsmap' VALUES (8749, 2499, 83, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (8750, 2499, 117, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (8751, 2499, 43, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (8752, 2499, 32, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (8738, 2336, 151, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8739, 2336, 49, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8740, 2336, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8741, 2336, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8768, 2809, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8769, 2809, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8770, 2809, 81, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (8771, 2809, 23, 25, 8);
INSERT INTO 'dancesformationsmap' VALUES (8835, 4256, 249, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (8705, 1763, 42, 25, 8);
INSERT INTO 'dancesformationsmap' VALUES (22508, 14573, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22509, 14573, 64, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22510, 14573, 95, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (8718, 2119, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8719, 2119, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8720, 2119, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8714, 2097, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8715, 2097, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8716, 2097, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8717, 2097, 257, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8710, 1934, 7, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8711, 1934, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8712, 1934, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8734, 2321, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8735, 2321, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8736, 2321, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8808, 3700, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8809, 3700, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8810, 3700, 310, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8804, 4300, 159, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8706, 1763, 77, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16279, 11812, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16280, 11812, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16281, 11812, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16275, 11811, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16276, 11811, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16277, 11811, 72, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (16268, 11809, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16269, 11809, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16270, 11809, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8704, 1747, 90, 97, 2);
INSERT INTO 'dancesformationsmap' VALUES (16252, 11802, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16253, 11802, 7, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16254, 11802, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16248, 11801, 307, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16249, 11801, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16242, 11799, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16243, 11799, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16244, 11799, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (16239, 11798, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16240, 11798, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16241, 11798, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16237, 11772, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16238, 11772, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16233, 11771, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16234, 11771, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8662, 964, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8663, 964, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8664, 964, 43, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (8826, 4087, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8827, 4087, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8772, 2846, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8774, 2846, 7, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8828, 4087, 376, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (8813, 3957, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8814, 3957, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (8811, 3701, 268, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8812, 3701, 132, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (8783, 2952, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8784, 2952, 222, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (8785, 2952, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8762, 2656, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8763, 2656, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8764, 2656, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8732, 2308, 29, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (8733, 2308, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (16265, 11808, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16266, 11808, 105, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8618, 8718, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16247, 11800, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16293, 2440, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8802, 838, 159, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16258, 11805, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16226, 11797, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16227, 11797, 83, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16259, 11805, 148, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16260, 11805, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31438, 18248, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31439, 18248, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31440, 18248, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (16250, 11777, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16262, 11806, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16263, 11806, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (16264, 11806, 296, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16289, 2410, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16290, 2410, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (8832, 4230, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8833, 4230, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16255, 11803, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16256, 11803, 30, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (16257, 11803, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8786, 3091, 318, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8777, 2922, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8778, 2922, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8779, 2922, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8757, 2501, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16294, 2440, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16295, 2442, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16296, 2442, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16297, 2466, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16298, 2466, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16299, 2466, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16300, 2474, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16301, 2474, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16302, 2474, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16305, 11325, 217, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16309, 11641, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16310, 11641, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16311, 11641, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16312, 10901, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16314, 5428, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16282, 11813, 209, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16283, 11813, 66, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16273, 11810, 127, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16274, 11810, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8838, 4260, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8839, 4260, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8840, 4260, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31835, 13909, 188, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (8867, 5157, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8868, 5157, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8869, 5157, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8870, 5157, 124, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8898, 5427, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8899, 5427, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8900, 5427, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8901, 5481, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8902, 5481, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8903, 5481, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16315, 5428, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16316, 5428, 184, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16318, 11817, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16319, 11817, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8853, 4704, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16362, 3343, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22512, 14576, 110, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22513, 14576, 103, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22514, 14576, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16361, 779, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31836, 12392, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31837, 12392, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8871, 5179, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8872, 5179, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16341, 11827, 218, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16342, 11827, 112, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8878, 5289, 71, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (8920, 5862, 20, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8922, 5862, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8879, 5289, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8933, 6141, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8934, 6141, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8935, 6141, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8923, 5862, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8924, 5862, 9, 43, 1);
INSERT INTO 'dancesformationsmap' VALUES (8926, 5862, 85, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (8927, 5862, 7, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (16350, 11830, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16352, 11830, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8954, 1302, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8955, 3068, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8957, 6773, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8958, 6773, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8959, 6773, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8972, 7213, 57, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16343, 11828, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16344, 11828, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16345, 11828, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16346, 11829, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16347, 11829, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16348, 11829, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16332, 11823, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16333, 11823, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8939, 6196, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22511, 14573, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (8940, 6196, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8941, 6196, 55, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (8874, 5189, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8882, 5354, 9, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8883, 5354, 23, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (8884, 5354, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (8885, 5354, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8886, 5354, 52, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8875, 5189, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8876, 5189, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8880, 5351, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8881, 5351, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16320, 11818, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16321, 11818, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16322, 11818, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16323, 11819, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16324, 11819, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16328, 11821, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16329, 11821, 71, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16330, 11821, 263, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16334, 11823, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16325, 11820, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16326, 11820, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16327, 11820, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16303, 11815, 101, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16304, 11815, 217, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16359, 11765, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16360, 11765, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8841, 4282, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8803, 1907, 159, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8842, 4282, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8843, 4282, 22, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (8960, 6814, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8961, 6814, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8904, 5521, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8905, 5521, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8962, 6814, 180, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31444, 7459, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31445, 7459, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8951, 6478, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8952, 6478, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8953, 6478, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8944, 6414, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8945, 6414, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8946, 6414, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8947, 6414, 134, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8942, 6336, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8943, 6336, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8906, 5744, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8907, 5744, 183, 5, 6);
INSERT INTO 'dancesformationsmap' VALUES (8908, 5744, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (8861, 5005, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8862, 5005, 27, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (8863, 5005, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8864, 5080, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8865, 5080, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8866, 5080, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8857, 4965, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8858, 4965, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8910, 5749, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8911, 5749, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8912, 5749, 55, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (8844, 4282, 132, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (8850, 4487, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8851, 4487, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8852, 4487, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8848, 4397, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8849, 4397, 62, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8846, 4300, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8847, 4300, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8928, 6038, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8929, 6038, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8930, 6038, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8931, 6038, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8976, 7384, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8977, 7384, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8978, 7441, 65, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8979, 7441, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8993, 7650, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8994, 7650, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9003, 2637, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9004, 2637, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9005, 2637, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9006, 2637, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9002, 7669, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31329, 17473, 9, 7, 4);
INSERT INTO 'dancesformationsmap' VALUES (9038, 8109, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8892, 5422, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16331, 11822, 168, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16317, 11816, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16313, 11703, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16292, 2410, 42, 6, 2);
INSERT INTO 'dancesformationsmap' VALUES (16306, 790, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16307, 790, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9017, 7966, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9018, 7966, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9019, 7966, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9020, 7966, 63, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8916, 5852, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8917, 5852, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8918, 5852, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9039, 8109, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9040, 8109, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9041, 8119, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9042, 8119, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9043, 8119, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9044, 8119, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9045, 8119, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9123, 7611, 28, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9124, 7611, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8966, 7018, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16365, 11833, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16366, 11833, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16367, 11834, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16368, 11836, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16369, 11836, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16374, 11840, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16375, 11840, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16376, 11841, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9060, 8130, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9061, 8130, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9065, 8137, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9066, 8137, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9067, 8137, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9100, 8723, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9101, 8723, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9102, 8723, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8967, 7018, 157, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (9128, 7612, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9129, 7612, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9130, 7612, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8968, 7053, 42, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (8969, 7053, 96, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (9011, 7811, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9012, 7811, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9112, 8727, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9113, 8727, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9114, 8727, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16378, 11843, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9057, 8128, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9058, 8128, 134, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (9059, 8128, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16377, 11842, 56, 41, 4);
INSERT INTO 'dancesformationsmap' VALUES (9103, 2336, 119, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (9051, 8125, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9052, 8125, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9053, 8125, 36, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (9054, 8125, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9055, 8125, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (8986, 7521, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8948, 6431, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8949, 6431, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (8950, 6431, 39, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (9131, 7612, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9132, 7612, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9145, 8735, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9146, 8735, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9147, 8735, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9148, 8735, 143, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (16380, 11844, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16381, 11844, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16382, 11845, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16383, 11846, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16384, 11847, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16385, 11848, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16386, 11848, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16387, 11849, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16388, 11850, 190, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16389, 11851, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16390, 11851, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16391, 11853, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16392, 11854, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16393, 11854, 155, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16394, 11855, 114, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16395, 11856, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9096, 6490, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9097, 6490, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9120, 8624, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9121, 8624, 114, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (9122, 8624, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9115, 4103, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9116, 4103, 121, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9034, 8088, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (9062, 8132, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9063, 8132, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (8984, 7517, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9035, 8088, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9137, 7613, 30, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9138, 7613, 125, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (9143, 8730, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (8989, 7534, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8990, 7534, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (8991, 7534, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8985, 7517, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9064, 8132, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9111, 8726, 162, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8987, 7527, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8988, 7527, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16370, 11837, 10, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (16371, 11837, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9117, 8728, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9118, 8728, 1, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (9119, 8728, 16, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9108, 8725, 20, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9109, 8725, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9080, 8562, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9081, 8562, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9075, 8348, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9076, 8348, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9077, 8348, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9078, 8348, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9072, 8173, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9073, 8173, 7, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (9046, 8120, 96, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9047, 8120, 365, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9048, 8120, 119, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (9049, 8120, 134, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (9104, 5795, 261, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9105, 5795, 114, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (9092, 5171, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9093, 5171, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9007, 7781, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9008, 7781, 123, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (9009, 7781, 262, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9010, 7781, 280, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8980, 7465, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8973, 7369, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8974, 7369, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8975, 7369, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9089, 2786, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9090, 2786, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9091, 2786, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16363, 7049, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16364, 7049, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (7325, 7459, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7326, 7459, 328, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (9028, 7980, 83, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9029, 7980, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (9030, 7980, 23, 37, 4);
INSERT INTO 'dancesformationsmap' VALUES (9094, 5171, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8995, 7652, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (8996, 7652, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8997, 7652, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8998, 7652, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16396, 11856, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16397, 11858, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16398, 11858, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16399, 11859, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16400, 11860, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16401, 11861, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16402, 11863, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16403, 11863, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16404, 11863, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16405, 11864, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16406, 11864, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16407, 11864, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31330, 17473, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16411, 11870, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16412, 11870, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16413, 11870, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16416, 11875, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16417, 11875, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16418, 11875, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16419, 11875, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16420, 11875, 69, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (31446, 17473, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9085, 8571, 134, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (9086, 8571, 8, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (9088, 8571, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31447, 17473, 318, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9162, 8742, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9163, 8742, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8981, 7475, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16372, 11839, 112, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16373, 11839, 114, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8956, 6721, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9074, 8258, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9095, 6479, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9021, 7967, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9022, 7967, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9164, 8742, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9165, 8742, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9186, 8793, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9187, 8793, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9192, 8795, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9193, 8795, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9194, 8796, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9195, 8797, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9196, 8797, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9197, 8798, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9198, 8798, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9199, 8798, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9201, 8800, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9202, 8801, 105, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9203, 8801, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9204, 8803, 162, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9205, 8804, 162, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9206, 8804, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9207, 8805, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9208, 8806, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9209, 8806, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9217, 8810, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9231, 8813, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9232, 8813, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9233, 8813, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9234, 8813, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9068, 8165, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16423, 8983, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16424, 11877, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16425, 11877, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16431, 11880, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16432, 11880, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16433, 11881, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16434, 11882, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16435, 11882, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16436, 11883, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16437, 11883, 139, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16438, 11883, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16439, 11883, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16450, 11888, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16451, 11888, 175, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16452, 11888, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16453, 11889, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16454, 11889, 209, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16421, 11876, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9178, 8792, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9179, 8792, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9212, 8809, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16379, 11843, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9180, 5536, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9181, 5536, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (9069, 8165, 157, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9182, 2883, 119, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (9183, 2883, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16414, 11872, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16415, 11872, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (16455, 11889, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16456, 11889, 210, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9249, 1582, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9264, 6233, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9268, 2682, 96, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (9269, 2682, 125, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (9271, 5847, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9272, 5847, 43, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (9273, 5641, 142, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9275, 5436, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9276, 4195, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9281, 5702, 142, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (9282, 610, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9283, 3940, 148, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9200, 8799, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9149, 8736, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9150, 8736, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9151, 8736, 36, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (9235, 8814, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9236, 8814, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9135, 2805, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9262, 3562, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9263, 3562, 143, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (22515, 14570, 7, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (22516, 14570, 9, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (9237, 8817, 124, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9238, 8817, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9280, 5731, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9139, 8729, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9140, 8729, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9255, 2250, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9136, 2709, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9216, 3544, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (9168, 2713, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9219, 7842, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9220, 7842, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16440, 11884, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (16441, 11884, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16444, 11885, 56, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (16445, 11885, 112, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16446, 11885, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9211, 5937, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16447, 11887, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16448, 11887, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16449, 11887, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16428, 11879, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16429, 11879, 58, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16430, 11879, 145, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16408, 11866, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16409, 11866, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16410, 11866, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9228, 8812, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9229, 8812, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9230, 8812, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9153, 8739, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9154, 8739, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9155, 8739, 9, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (16426, 11878, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16427, 11878, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9227, 8811, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9251, 6613, 25, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (9244, 6563, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (9245, 6563, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9246, 6563, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (9225, 4819, 30, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9226, 4819, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9171, 4422, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9172, 4422, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9210, 2419, 317, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9188, 8794, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9243, 2356, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9189, 8794, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9241, 273, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9242, 273, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9169, 684, 39, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (9170, 684, 87, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9222, 1203, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9223, 1203, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9224, 1203, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9294, 1044, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9295, 1044, 9, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (9374, 8980, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9330, 8921, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9331, 8921, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9332, 8921, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9247, 8632, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9315, 5528, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16494, 5588, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16495, 5588, 156, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16497, 7925, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16498, 7925, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16499, 7925, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16500, 5540, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16501, 8000, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16502, 8000, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16503, 8000, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9308, 2975, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9309, 2975, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9340, 8957, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9341, 8957, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9342, 8958, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9343, 8958, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9344, 8958, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9345, 8959, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9348, 8961, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9349, 8961, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9350, 8962, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9351, 8962, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9352, 8963, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9353, 8967, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9321, 5623, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9354, 8967, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9355, 8967, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9361, 8972, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9325, 5956, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9133, 7520, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9134, 7520, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9239, 5434, 375, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9240, 5434, 42, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22518, 14571, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9144, 8732, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9173, 3119, 83, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9174, 3119, 8, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (9362, 8972, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9366, 8974, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9367, 8974, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9368, 8974, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9371, 8979, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9372, 8979, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9373, 8979, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9314, 5536, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9256, 8829, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9257, 8829, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31448, 17878, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9248, 8632, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9267, 5376, 132, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16496, 6244, 327, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16504, 8006, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9296, 5998, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9297, 5998, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16486, 7359, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16487, 7359, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16488, 7359, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16489, 7359, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16491, 7617, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16492, 7617, 9, 11, 3);
INSERT INTO 'dancesformationsmap' VALUES (16493, 7617, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9253, 1716, 149, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (9254, 820, 81, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (9304, 6568, 46, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9305, 6568, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9306, 6568, 62, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9307, 6568, 192, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (9381, 8982, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9382, 8982, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9383, 8982, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9384, 8982, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9385, 8982, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9386, 8983, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9388, 8988, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9389, 8988, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9390, 8988, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9391, 8994, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9392, 8994, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9393, 8995, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9394, 31, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9396, 8999, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9409, 9044, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9410, 9044, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9411, 9044, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9412, 9044, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9413, 9045, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9400, 9040, 114, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (9414, 9048, 87, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9415, 9048, 38, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9298, 3367, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9277, 4144, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9278, 4144, 142, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9419, 9075, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31362, 2485, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9448, 1413, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9319, 6826, 62, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31363, 2485, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9456, 3979, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9457, 3979, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9317, 8859, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9318, 8859, 92, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (9289, 2244, 119, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9290, 2244, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9416, 9074, 82, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (9417, 9074, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9418, 9074, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16457, 11890, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16458, 11890, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (9421, 9076, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9422, 9076, 30, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9407, 9043, 117, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9408, 9043, 21, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9397, 9000, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9346, 8960, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9347, 8960, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9356, 8968, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9357, 8968, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9288, 3197, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9300, 6666, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9301, 6666, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9334, 8922, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9335, 8922, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9258, 5658, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9259, 5658, 1, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (9260, 5658, 7, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9252, 4350, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (9333, 7490, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9310, 7450, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (9311, 7450, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9312, 7450, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9250, 8811, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9285, 6657, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9286, 6657, 149, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9287, 6657, 38, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (9284, 4782, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9316, 7120, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (9279, 633, 60, 89, 2);
INSERT INTO 'dancesformationsmap' VALUES (9299, 3367, 145, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9395, 8996, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9363, 8973, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9364, 8973, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9365, 8973, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9274, 4324, 125, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (16477, 11896, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16478, 11896, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16464, 11893, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16465, 11893, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16467, 11894, 154, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16468, 11894, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (16479, 11897, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16480, 11897, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16462, 11892, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16463, 11892, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16471, 11895, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16472, 11895, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16482, 11898, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16483, 11898, 5, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16484, 11898, 82, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (9322, 8567, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9323, 8567, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9324, 8567, 56, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16509, 11900, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16510, 11900, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16511, 11900, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16512, 11900, 156, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16513, 11901, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16514, 11901, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16515, 11901, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16516, 11902, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16517, 11902, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16518, 11902, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16523, 3839, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16524, 3839, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16525, 3839, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16526, 6305, 162, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16527, 6305, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16528, 6554, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16529, 6554, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16530, 6475, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16531, 7008, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16532, 7008, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16533, 7008, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16534, 7008, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16535, 6752, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16536, 5634, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16537, 5634, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16538, 5634, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16546, 9782, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16550, 9786, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16551, 9786, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16552, 9786, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16553, 9786, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9436, 6794, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9437, 6794, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16558, 5262, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16555, 1588, 175, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9369, 8978, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9370, 8978, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16541, 1492, 334, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9441, 3897, 72, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (9398, 9029, 15, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (16519, 11903, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16520, 11903, 42, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (9461, 9088, 105, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (9462, 9088, 119, 33, 8);
INSERT INTO 'dancesformationsmap' VALUES (9161, 5802, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (16459, 6148, 39, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (16543, 9780, 8, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (16544, 9780, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16549, 9785, 10, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (9502, 9101, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (9449, 9084, 164, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9406, 9042, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9291, 4497, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9328, 8864, 1, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (9329, 8864, 38, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9156, 8104, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9157, 8104, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16521, 11903, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (9375, 8980, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31449, 17878, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31450, 17878, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9399, 9029, 19, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16545, 9781, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9438, 2441, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9439, 2441, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16542, 9778, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16539, 9168, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16540, 9168, 38, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9489, 9095, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9495, 9097, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9490, 9095, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (16506, 8006, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (16507, 8006, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31452, 18250, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31453, 18250, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (9551, 1453, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9540, 9116, 168, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9547, 9118, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9548, 9118, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9549, 9119, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9550, 9119, 46, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9552, 1453, 317, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31454, 18250, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31455, 18250, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16562, 11905, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16563, 11905, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16564, 11905, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16568, 11907, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16569, 11907, 203, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16570, 11907, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16573, 11909, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9541, 9117, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9571, 9125, 334, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22522, 14572, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9480, 9092, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9452, 9086, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9453, 9086, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9481, 9092, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9482, 9092, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9440, 3390, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9558, 9121, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9505, 9103, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9506, 9103, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9507, 9103, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16547, 9783, 54, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16548, 9783, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9556, 9120, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9559, 9121, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9560, 9122, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9561, 9122, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9563, 9123, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9524, 9113, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9525, 9113, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9503, 9102, 7, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (9504, 9102, 132, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9496, 9098, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9497, 9098, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9498, 9098, 85, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9486, 9094, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9487, 9094, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9488, 9094, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9483, 9093, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9484, 9093, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9478, 9091, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9479, 9091, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9463, 9089, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9465, 9089, 165, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9450, 9085, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9451, 9085, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9442, 9082, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9443, 9082, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9433, 9080, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9434, 9080, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9435, 9080, 8, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (9430, 9079, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (9431, 9079, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9432, 9079, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9428, 9078, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9429, 9078, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (9424, 9076, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9493, 9054, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9494, 9054, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9475, 9015, 9, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (9476, 9015, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9477, 9015, 167, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9472, 9002, 166, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9473, 9002, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (9474, 9002, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9468, 9001, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9469, 9001, 112, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9470, 9001, 9, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (9379, 8981, 365, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9380, 8981, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9387, 8981, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (9528, 8172, 42, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9425, 9077, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9426, 9077, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (9427, 9077, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9575, 3473, 251, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (9466, 6163, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9467, 6163, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (16554, 4451, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (9402, 9041, 46, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9403, 9041, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9404, 9041, 62, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9564, 9123, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16556, 5712, 29, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (9585, 9129, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9586, 9129, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9587, 9130, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9588, 9131, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9589, 9132, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9590, 9132, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9591, 9134, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9592, 9134, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9593, 9134, 169, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9594, 9135, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9595, 9135, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9596, 9135, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9597, 9135, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9625, 9149, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9626, 9149, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9627, 9149, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9628, 9150, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9629, 9150, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9630, 9150, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9635, 9152, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9636, 9152, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9637, 9152, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9638, 9152, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9643, 9154, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9644, 9154, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9645, 9154, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9646, 9154, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9647, 9155, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9648, 9155, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16574, 11909, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16575, 11909, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16576, 11909, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16577, 11909, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16578, 11910, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16579, 11911, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16580, 11911, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16581, 11911, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16582, 11911, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16583, 11911, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9600, 2408, 119, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9579, 8930, 8, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (16584, 11912, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16585, 11912, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16586, 11912, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16587, 11912, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16588, 11912, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16595, 11914, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16596, 11914, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16597, 11914, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16602, 11916, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16603, 11916, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16604, 11916, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9599, 1218, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9526, 9114, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9631, 9151, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9632, 9151, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9634, 9151, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16560, 11904, 222, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (9508, 9104, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16571, 11908, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16572, 11908, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9566, 4306, 92, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9649, 9156, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9501, 9100, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9499, 9099, 365, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9500, 9099, 168, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (9492, 9096, 43, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (9533, 8138, 56, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9464, 4015, 165, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9534, 8138, 58, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9598, 9136, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16561, 11904, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16565, 11906, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16566, 11906, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16567, 11906, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9573, 9126, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9574, 9126, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9639, 9153, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9640, 9153, 48, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9641, 9153, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9642, 9153, 70, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (9519, 9109, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (9609, 9159, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9610, 9159, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9611, 9159, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9618, 9163, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9619, 9163, 92, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (9620, 9163, 5, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9621, 9164, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9622, 9164, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9623, 9164, 30, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (9624, 9164, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (9567, 1465, 92, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (16605, 11917, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16606, 11917, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16607, 11917, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16608, 11917, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16609, 11918, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16610, 11918, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16611, 11918, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16612, 11920, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16613, 11921, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16614, 11921, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16615, 11921, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16616, 11921, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22528, 14241, 165, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9673, 8963, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9699, 9335, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9700, 9335, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9701, 9335, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9702, 9335, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9717, 6137, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9718, 2361, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9712, 8490, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9713, 8490, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16598, 11915, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16599, 11915, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16600, 11915, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9513, 9107, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9514, 9107, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9515, 9107, 20, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (9722, 4692, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9536, 9115, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22523, 14572, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22524, 14572, 184, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9537, 9115, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9538, 9115, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9654, 9165, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9655, 9165, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16589, 11913, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16590, 11913, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16591, 11913, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16592, 11913, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9725, 9351, 7, 32, 1);
INSERT INTO 'dancesformationsmap' VALUES (9708, 9338, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9709, 9338, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9671, 9181, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9672, 9181, 71, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9674, 9184, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9617, 9162, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (9614, 9161, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (9615, 9161, 93, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (9675, 9184, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9676, 9184, 5, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9616, 9161, 45, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9606, 9158, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9607, 9158, 162, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9608, 9158, 306, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9601, 9148, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9602, 9148, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9603, 9148, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (9581, 9128, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9582, 9128, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9517, 9108, 132, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (9576, 9127, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (9577, 9127, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9578, 9127, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9518, 9108, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9511, 9106, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9512, 9106, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9529, 8175, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9530, 8175, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9679, 8954, 58, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9680, 8954, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9531, 8175, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9532, 8175, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22530, 13449, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9669, 9180, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9670, 9180, 62, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9667, 9179, 62, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9668, 9179, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9663, 1409, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9604, 802, 317, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9731, 9357, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9732, 9357, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9733, 9357, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9738, 9359, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9739, 9359, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9740, 9359, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9741, 9359, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9742, 9359, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9743, 9359, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9744, 9359, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9745, 9359, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16617, 11921, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16618, 11922, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16619, 11922, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16620, 11923, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16621, 11923, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16622, 11923, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16623, 11923, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16624, 11924, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16625, 11924, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16626, 11924, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16627, 11925, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16628, 11926, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16629, 11926, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16630, 11926, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16631, 11927, 13, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22547, 7286, 66, 61, 1);
INSERT INTO 'dancesformationsmap' VALUES (16643, 11937, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16644, 11937, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16645, 11937, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16646, 11937, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16647, 11938, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16648, 11938, 33, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16649, 11938, 111, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (16650, 11938, 52, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16651, 11938, 29, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (9677, 9169, 93, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (9678, 9169, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22537, 3498, 58, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22538, 3498, 27, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22539, 3498, 61, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (7728, 5982, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9454, 9087, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9455, 9087, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22548, 7286, 93, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (9746, 9364, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9747, 9132, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9748, 9356, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9749, 9356, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9750, 9356, 169, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9751, 9356, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9752, 9356, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9753, 9356, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9754, 9362, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9755, 9362, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9756, 9360, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9757, 9360, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9758, 9361, 89, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22527, 54, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (9690, 6956, 134, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (16632, 11919, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16633, 11919, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16634, 11919, 27, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22544, 14593, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22545, 14593, 54, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (22546, 14593, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (9719, 9341, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9696, 9334, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (9697, 9334, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9664, 9177, 59, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9734, 9358, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9651, 9156, 120, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (9652, 9156, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9735, 9358, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9736, 9358, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9580, 3422, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (9684, 7543, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9693, 9333, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9720, 9341, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9658, 9166, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9568, 9124, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9569, 9124, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9689, 4763, 154, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (9659, 9166, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (9704, 9337, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9705, 9337, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9706, 9337, 8, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (9778, 9370, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9786, 9374, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9787, 9374, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9788, 9374, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9789, 9375, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9790, 9375, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9795, 9377, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9796, 9377, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9797, 9378, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9798, 9378, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9799, 9378, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9800, 9378, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9801, 9378, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9802, 9379, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9803, 9379, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9804, 9379, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9805, 9379, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9837, 9409, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16659, 8839, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16660, 11940, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16661, 11940, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16662, 11941, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16663, 11942, 180, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16664, 11942, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16665, 11942, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16666, 11942, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16667, 11942, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16668, 11942, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16669, 11943, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16670, 11943, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16671, 11943, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16672, 11943, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16673, 11944, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16674, 11944, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16675, 11944, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16676, 11945, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16652, 11939, 71, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16653, 11939, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31457, 18251, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16641, 11929, 42, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (16642, 11929, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9685, 9332, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9686, 9332, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9687, 9332, 38, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (9806, 9391, 109, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9727, 9353, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9728, 9353, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (9767, 8331, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9703, 9336, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9711, 4858, 168, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (9828, 9387, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9829, 9387, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16656, 11934, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16657, 11934, 119, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (16658, 11934, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16635, 11928, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16636, 11928, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (16637, 11928, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9825, 9385, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9826, 9385, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9823, 9384, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9824, 9384, 265, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (9779, 9371, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9780, 9371, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9781, 9371, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9782, 9371, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9771, 9367, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9772, 9367, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9773, 9367, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9774, 9367, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9761, 9365, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (9762, 9365, 171, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9763, 9365, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (9764, 9365, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (9726, 9351, 142, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (9707, 9223, 30, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (9710, 7105, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9816, 2387, 129, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9817, 2387, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9660, 9167, 29, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (9661, 9167, 114, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9666, 1596, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9766, 889, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9729, 9355, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9872, 9418, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9730, 9355, 193, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16677, 11945, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16678, 11945, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16679, 11945, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16686, 11946, 40, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16687, 11946, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16688, 11946, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16689, 11947, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16690, 11948, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16691, 11948, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16692, 11948, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16695, 11950, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16696, 11950, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16697, 11950, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16698, 11951, 141, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16699, 11952, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16700, 11952, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9836, 9408, 43, 21, 4);
INSERT INTO 'dancesformationsmap' VALUES (22540, 1938, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22541, 1938, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22542, 1938, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22549, 7286, 43, 53, 2);
INSERT INTO 'dancesformationsmap' VALUES (9838, 9409, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9839, 9409, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9840, 9410, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9841, 9410, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9842, 9410, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9843, 9411, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9844, 9411, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9845, 9411, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9846, 9412, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9847, 9412, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9848, 9412, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9849, 9412, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9853, 9414, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9854, 9414, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9855, 9414, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9856, 9414, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9857, 9414, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9858, 9414, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9859, 9415, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9860, 9415, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9861, 9416, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9862, 9416, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9863, 9416, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9864, 9416, 172, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9866, 9383, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9867, 9383, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9868, 9383, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9810, 9381, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9811, 9381, 29, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (9834, 9390, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (9835, 9390, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9887, 7721, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9888, 7740, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9889, 7740, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9890, 7740, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9891, 7740, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9892, 7740, 121, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9893, 7740, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9894, 7740, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9895, 7964, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9812, 9382, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9813, 9382, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9850, 9413, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9851, 9413, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (9852, 9413, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (9898, 4575, 120, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9783, 9373, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9784, 9373, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9785, 9373, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9807, 9380, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9808, 9380, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9833, 9389, 39, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9821, 7849, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9822, 7849, 101, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22565, 5168, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9759, 9363, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9760, 9363, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9768, 9366, 375, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9769, 9366, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9770, 9366, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9775, 9368, 296, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9776, 9368, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9827, 9386, 86, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (9694, 9333, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16685, 8840, 29, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (9695, 9333, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9918, 1421, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9919, 1421, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9926, 9429, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9927, 9429, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9928, 9429, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9929, 9429, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16701, 11953, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16702, 11953, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16703, 11954, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16704, 11954, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16705, 11955, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16706, 11955, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16707, 11956, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16708, 11956, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16710, 11958, 157, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16711, 11958, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16712, 11958, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16713, 11959, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16714, 11959, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16715, 11959, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16716, 11960, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16717, 11961, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16718, 11961, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16719, 11962, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16720, 11962, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16721, 11963, 164, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16722, 11963, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31838, 13906, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16727, 11965, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16728, 11965, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16729, 11965, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16730, 11965, 219, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31839, 13906, 273, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22543, 1938, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31840, 13906, 202, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22554, 14594, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9945, 8692, 120, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10012, 8831, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16709, 11957, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9950, 9441, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9951, 9441, 184, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22567, 14280, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9933, 9432, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9934, 9432, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9935, 9433, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9936, 9433, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9937, 9434, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9941, 9430, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9942, 9430, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9943, 9430, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9944, 9430, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9980, 9491, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9791, 9376, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9869, 9417, 42, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (9875, 9419, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9870, 9417, 49, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9900, 9425, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9901, 9425, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9831, 9388, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9832, 9388, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9865, 9331, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9885, 5573, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9883, 3738, 16, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9884, 3738, 125, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9886, 5573, 184, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16681, 8838, 43, 9, 8);
INSERT INTO 'dancesformationsmap' VALUES (16682, 8838, 66, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (9993, 8833, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9994, 8833, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9990, 8832, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9991, 8832, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9992, 8832, 7, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (22561, 14477, 221, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22533, 13449, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9896, 7195, 72, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16680, 7243, 356, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9915, 4677, 173, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9899, 3538, 72, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (22558, 14596, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22559, 14596, 25, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22560, 14596, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16731, 11966, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16732, 11966, 172, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16733, 11966, 156, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9938, 9435, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9939, 9435, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9897, 1760, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9878, 9422, 72, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (9879, 9424, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9880, 9424, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9881, 9424, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9871, 9417, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (9981, 9491, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22553, 14594, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10004, 8839, 65, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10005, 8839, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10009, 9498, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10010, 9498, 43, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (10011, 9498, 23, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (10020, 9502, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10021, 9502, 142, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22566, 5168, 356, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9908, 2346, 173, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9979, 9490, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9984, 9495, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9985, 9495, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10015, 9500, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10016, 9500, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10017, 9500, 30, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10025, 9504, 10, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10013, 9499, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10014, 9499, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16723, 11964, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16725, 11964, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16726, 11964, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9930, 9431, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9995, 8834, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10022, 9503, 109, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10023, 9503, 119, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10024, 9503, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9961, 9449, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9962, 9452, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9963, 9452, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9964, 9452, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9960, 9448, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9952, 9443, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9953, 9443, 36, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9975, 9488, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9982, 9493, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9983, 9494, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9967, 9485, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9968, 9485, 12, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9970, 9486, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9971, 9486, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (10001, 8837, 188, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (10002, 8837, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (9912, 458, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9931, 9431, 111, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9932, 9431, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9946, 9437, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9920, 6672, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9921, 6672, 7, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9911, 658, 296, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10036, 9516, 105, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10037, 9516, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10038, 9517, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10039, 9517, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10040, 9518, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10041, 9519, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10042, 9520, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10043, 9521, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10044, 9521, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10045, 9521, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10046, 9521, 121, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10049, 9524, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10050, 9524, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10051, 9526, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10052, 9526, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31461, 18253, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31462, 18253, 183, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (10079, 9480, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10085, 9538, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10086, 9538, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31463, 18253, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10092, 9544, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10093, 9544, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10094, 9544, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10095, 9544, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10097, 5357, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10108, 1725, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9924, 9428, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9925, 9428, 386, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9910, 5637, 173, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22550, 5637, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9947, 9438, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9948, 9438, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9916, 9427, 386, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9917, 9427, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (10084, 9537, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9996, 8835, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16750, 11631, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10123, 9551, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10124, 9551, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10125, 9551, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10128, 9553, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10129, 9553, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10132, 9555, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10133, 9555, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10134, 9555, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10135, 9555, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10136, 9556, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10137, 9556, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10138, 9556, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10139, 9556, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31464, 18253, 142, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (10130, 9554, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10131, 9554, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9882, 7019, 24, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9998, 8836, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (9999, 8836, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10000, 8836, 111, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10096, 2371, 103, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10104, 7227, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16734, 11968, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10105, 7227, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10106, 7227, 27, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9914, 6634, 173, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9907, 109, 173, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10034, 9513, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10035, 9513, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9976, 9489, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9977, 9489, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9978, 9489, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (9955, 9446, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9956, 9446, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10117, 9548, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10118, 9548, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9973, 9487, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9974, 9487, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9903, 9425, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9904, 9425, 61, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (16757, 11634, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16758, 11634, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (16751, 11632, 131, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16752, 11632, 119, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10126, 9552, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10127, 9552, 134, 17, 12);
INSERT INTO 'dancesformationsmap' VALUES (10121, 9550, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10122, 9550, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10140, 9557, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10141, 9557, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10119, 9549, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10120, 9549, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9909, 4291, 173, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10027, 9505, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10028, 9505, 16, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10029, 9505, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9957, 9447, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9958, 9447, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (9959, 9447, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10076, 1331, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (16742, 11970, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16735, 11968, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16736, 11968, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (10098, 2135, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10099, 2135, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10100, 2135, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10033, 8365, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22563, 14477, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9876, 9421, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9877, 9421, 54, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10109, 6707, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10110, 6707, 8, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (10111, 6707, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10078, 9536, 66, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (9986, 7243, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9987, 7243, 76, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9988, 7243, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9989, 7243, 29, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (10031, 2245, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10077, 1331, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16773, 11639, 143, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10074, 9534, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10075, 9534, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10114, 9546, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10115, 9546, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10151, 9559, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10152, 9559, 114, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (16784, 7213, 37, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10149, 5209, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (16790, 5569, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10087, 9540, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (10088, 9540, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10089, 9540, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (10026, 9504, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16791, 5569, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16792, 5569, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16753, 11633, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16754, 11633, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16755, 11633, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16756, 11633, 55, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16786, 6861, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16787, 2281, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16785, 5589, 145, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16788, 2281, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (16789, 2281, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16798, 3945, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16799, 3945, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16800, 3945, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22568, 10779, 36, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (10217, 9585, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10218, 9586, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10219, 9586, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10220, 9586, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10221, 9587, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10222, 9587, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10223, 9587, 175, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10224, 9588, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10225, 9588, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10226, 9588, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10227, 9588, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10228, 9588, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10229, 9589, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10230, 9589, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10231, 9589, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10232, 9586, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10233, 9590, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10237, 9592, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10238, 9592, 168, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10239, 9592, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10240, 9593, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10241, 9593, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10242, 9594, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10243, 9595, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10244, 9595, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10245, 9595, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31841, 13906, 249, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31842, 13906, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31465, 18254, 92, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31466, 18254, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31843, 13906, 32, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (14876, 11434, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16814, 113, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27730, 7161, 43, 14, 1);
INSERT INTO 'dancesformationsmap' VALUES (27731, 7161, 123, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16825, 3605, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16826, 3605, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22570, 10795, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22574, 9087, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (9665, 5107, 280, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16774, 11639, 82, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (10153, 9559, 109, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22580, 9888, 23, 21, 4);
INSERT INTO 'dancesformationsmap' VALUES (10246, 9596, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10247, 9596, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10248, 9596, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10249, 9596, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10250, 9596, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10251, 9596, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10252, 9596, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10253, 9597, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10254, 9597, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10255, 9598, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10256, 9598, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16775, 11640, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16762, 11636, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16763, 11636, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10216, 9584, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10157, 9560, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22579, 10799, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16738, 11969, 183, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (16739, 11969, 39, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16740, 11969, 220, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (10176, 4857, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22555, 14595, 307, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22556, 14595, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22557, 14595, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22572, 7530, 132, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22573, 7530, 234, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (9997, 8835, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16761, 11635, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10174, 5295, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10175, 5295, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10178, 9566, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16821, 4174, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (16776, 11640, 58, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16777, 11640, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16827, 6624, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16828, 6624, 149, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16829, 6624, 134, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (16764, 11637, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16765, 11637, 183, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (16766, 11637, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16767, 11637, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16769, 11638, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16770, 11638, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16771, 11638, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10211, 9582, 7, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (10212, 9582, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10213, 9582, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10214, 9582, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10207, 9580, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10208, 9580, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10209, 9580, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10195, 9574, 119, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (10196, 9574, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10072, 9533, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10073, 9533, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10059, 9529, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10047, 9523, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10048, 9523, 78, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16748, 11972, 112, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16749, 11972, 72, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (16745, 11971, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16746, 11971, 72, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (22564, 14477, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16841, 5648, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (10145, 6131, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10146, 6131, 119, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16797, 3957, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16811, 3957, 123, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (16794, 2571, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (16795, 2571, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16796, 2571, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10142, 2372, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10143, 2372, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10234, 9591, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10235, 9591, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10236, 9591, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10063, 9530, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10064, 9530, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16836, 1982, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16837, 1982, 154, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (16832, 10022, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10056, 9528, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10057, 9528, 262, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (10065, 9530, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10069, 9532, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10070, 9532, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10071, 9532, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10060, 9529, 58, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (10053, 9527, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10054, 9527, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10055, 9527, 5, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10257, 9598, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10258, 9599, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10259, 9599, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10260, 9599, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10261, 9600, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10262, 9600, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10263, 9601, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10264, 9602, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10265, 9602, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10266, 9603, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10267, 9603, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10268, 9604, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10269, 9605, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10270, 9605, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10271, 9604, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10272, 9606, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16819, 144, 77, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16816, 900, 148, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22581, 10102, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16817, 900, 221, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4728, 2645, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10183, 9569, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10273, 9607, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16812, 1795, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (10172, 9565, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10173, 9565, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10170, 9564, 114, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (10171, 9564, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (16820, 144, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22584, 2645, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22575, 14597, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10184, 9569, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10181, 9568, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10182, 9568, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10179, 9567, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22582, 9812, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10180, 9567, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16835, 264, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16839, 2657, 42, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (16840, 2657, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30834, 16956, 375, 25, 0);
INSERT INTO 'dancesformationsmap' VALUES (16801, 3945, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16802, 3945, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16813, 3838, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10201, 9577, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10202, 9577, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10197, 9575, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10198, 9575, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10189, 9572, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10190, 9572, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8113, 2409, 176, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8114, 2409, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22569, 2409, 33, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10278, 9644, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10279, 9644, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10280, 9644, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10281, 9645, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10282, 9645, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10283, 9645, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10301, 9666, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10302, 9666, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10303, 9666, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10321, 9673, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10322, 9673, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10323, 9673, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10329, 9678, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10330, 9678, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10331, 9678, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16847, 2893, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16848, 2893, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16849, 2893, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16850, 2893, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16854, 2558, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16864, 4203, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16866, 11974, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16867, 11974, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16868, 11974, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16869, 11974, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16870, 506, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16875, 3547, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16876, 3547, 222, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16879, 5108, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16880, 5108, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16885, 8194, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22571, 10796, 41, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (16856, 7039, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16855, 2558, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10353, 9689, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10354, 9689, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10355, 9690, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10356, 9690, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10357, 9691, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10358, 9691, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10359, 9691, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10360, 9692, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10361, 9692, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10362, 9692, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10363, 9692, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10364, 9693, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10365, 9693, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16872, 5079, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16873, 5079, 168, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16874, 5079, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (16833, 1173, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16834, 1173, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16780, 2687, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10177, 2323, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16781, 2687, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10160, 9561, 43, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (10161, 9561, 112, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10162, 9561, 114, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (10192, 9573, 59, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10193, 9573, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10194, 9573, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10346, 9686, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10203, 9578, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10312, 9670, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10314, 9670, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16831, 4484, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10366, 9693, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10367, 9693, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10368, 9694, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10369, 9694, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10370, 9694, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10371, 9695, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10372, 9696, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10333, 9680, 220, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10334, 9680, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10293, 9661, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10294, 9661, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10315, 9671, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10316, 9671, 7, 2, 6);
INSERT INTO 'dancesformationsmap' VALUES (16822, 5159, 39, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16823, 5159, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16824, 5159, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22585, 14598, 202, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22586, 14598, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10317, 9672, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10318, 9672, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10350, 9688, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10351, 9688, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10352, 9688, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10347, 9687, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10348, 9687, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10349, 9687, 72, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (10344, 9685, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10345, 9685, 119, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10342, 9684, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10343, 9684, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10304, 9667, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10305, 9667, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10306, 9667, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10296, 9662, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10297, 9662, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10210, 9581, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10186, 9571, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10187, 9571, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (10274, 9570, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10164, 9562, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10165, 9562, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16857, 7081, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16858, 7081, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16859, 6833, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16860, 6833, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16842, 6526, 30, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16845, 6317, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (16846, 6317, 145, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10199, 9576, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10200, 9576, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16844, 3908, 33, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (16871, 3767, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16830, 1782, 221, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16862, 9899, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10168, 9563, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10169, 9563, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10373, 9696, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10374, 9696, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10375, 9697, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10381, 9703, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16865, 6413, 327, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10286, 9646, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10382, 9703, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10383, 9703, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10384, 9704, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10385, 9704, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10386, 9704, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10387, 9705, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10388, 9705, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10389, 9705, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10390, 9705, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10391, 9706, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10392, 9706, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10394, 9709, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10400, 9712, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10401, 9713, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10402, 9713, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10403, 9713, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10404, 9714, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10405, 9715, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10406, 8959, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10407, 9716, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10408, 9716, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10409, 9717, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10410, 9718, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10411, 9719, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10412, 9719, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10413, 9720, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10414, 9720, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10415, 9721, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10416, 9721, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16863, 5872, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10300, 9664, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10324, 9674, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10325, 9674, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10310, 9669, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10311, 9669, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (10340, 9683, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10341, 9683, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10336, 9681, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10337, 9681, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10338, 9681, 120, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (10419, 9723, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10424, 9727, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10425, 9727, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10426, 9727, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10427, 9727, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16886, 8194, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16887, 8194, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16888, 8196, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16889, 8196, 81, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16891, 8197, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16892, 7709, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16896, 601, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16897, 601, 209, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16898, 601, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16899, 2160, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16900, 2160, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16901, 2564, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16902, 2564, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16903, 2564, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16904, 2564, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16905, 2564, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16906, 3217, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16907, 3217, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16908, 3217, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16909, 3217, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16910, 5250, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16911, 5393, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16912, 5456, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16913, 5456, 222, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16914, 5456, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16915, 6280, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16916, 6280, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16917, 6280, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16918, 6280, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16919, 2862, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16920, 2862, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16921, 2862, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16922, 2862, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16927, 6211, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10431, 9729, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10432, 9729, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10433, 9729, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10434, 9729, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10435, 9730, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10436, 9730, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10437, 9730, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10438, 8962, 165, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10441, 9732, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10442, 9732, 124, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10443, 9732, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10444, 9732, 110, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10449, 9734, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10452, 9736, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10453, 9736, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10454, 9737, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10455, 9737, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10456, 2641, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10457, 2641, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10458, 2641, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10472, 9739, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10473, 9744, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10474, 9744, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10475, 9744, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22589, 14599, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16861, 262, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10307, 9668, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16882, 8112, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16883, 8112, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10308, 9668, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10445, 9733, 24, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10423, 9726, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10393, 9708, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10339, 9682, 260, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10332, 9679, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10285, 9578, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10298, 9663, 23, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (10299, 9663, 84, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10309, 9668, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10476, 9745, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10477, 9745, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10478, 9746, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10479, 9747, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10480, 9747, 55, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10481, 9747, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10482, 9747, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10483, 9747, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10484, 9748, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10485, 9749, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10486, 9749, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10487, 9750, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10488, 9750, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10489, 9751, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10490, 9751, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10491, 9751, 5, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10495, 9754, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10496, 9754, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10497, 9754, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10514, 8780, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10515, 8780, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10516, 9763, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10517, 9771, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10518, 4691, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10519, 4691, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10450, 9735, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10520, 4691, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10451, 9735, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10526, 9773, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10417, 9722, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16851, 2966, 260, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22587, 14598, 260, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (10525, 9189, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10287, 9647, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10288, 9647, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10291, 9648, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10534, 9775, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10379, 9702, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10380, 9702, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10535, 9775, 42, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10498, 9755, 36, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (10499, 9755, 112, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (10500, 9755, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10396, 9710, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (10397, 9710, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10284, 9581, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10275, 9570, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10276, 9570, 81, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10395, 8960, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (16895, 8200, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16843, 6526, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16881, 1087, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10494, 9753, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16852, 2966, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (10527, 9773, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10528, 9773, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10542, 9777, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10543, 9777, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10544, 9777, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10545, 9777, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10550, 9707, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10551, 9707, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10422, 9725, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10376, 9701, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10439, 9731, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10440, 9731, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10502, 9756, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16893, 8198, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16894, 8198, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10547, 1128, 157, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (10548, 1128, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10549, 1128, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10377, 9701, 20, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10428, 9728, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10429, 9728, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10378, 9701, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10430, 9728, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10468, 9738, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10469, 9738, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10470, 9738, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10513, 3241, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16931, 5124, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16932, 5124, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16933, 3149, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16934, 3149, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16935, 3149, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16936, 4604, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16937, 4604, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16938, 4604, 226, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16939, 2891, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16940, 2891, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16941, 2891, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16942, 5241, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10562, 9805, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10563, 9805, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10564, 9806, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10565, 9806, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10597, 9821, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10598, 9821, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10599, 9823, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10600, 9823, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10601, 9823, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10604, 9825, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10605, 9825, 175, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10606, 9825, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10607, 9826, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10608, 9826, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10609, 9826, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10610, 9827, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16943, 5241, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16975, 5076, 227, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16976, 5076, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16977, 5076, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16978, 3149, 227, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16979, 5074, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16980, 5074, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16981, 2605, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16982, 2221, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16983, 5913, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16984, 5913, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10579, 116, 180, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16951, 9340, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16952, 9340, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16953, 9340, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22594, 548, 302, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (10645, 9842, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (10646, 9842, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (16967, 1758, 183, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (10556, 8932, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10582, 1783, 180, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7678, 1840, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7679, 1840, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16972, 8817, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16955, 11437, 224, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (10641, 9170, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10642, 9170, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10554, 9803, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10555, 9803, 62, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10578, 3281, 180, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10584, 3625, 180, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10585, 4518, 180, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10505, 9757, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16969, 9372, 224, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16970, 9372, 225, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10560, 9804, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10538, 9776, 78, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (10561, 9804, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10595, 9820, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10596, 9820, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10589, 5223, 181, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10506, 9757, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10507, 9757, 178, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16962, 10513, 224, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (10678, 9857, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10677, 9856, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10669, 9852, 171, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10670, 9852, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (10648, 9844, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10649, 9844, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10664, 9850, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10665, 9850, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (10657, 9847, 24, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10658, 9847, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10667, 9851, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10668, 9851, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10650, 9844, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16945, 9422, 143, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16963, 10051, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10651, 9844, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22591, 14599, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10635, 9838, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30915, 18078, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10569, 9810, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10629, 9638, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10460, 8965, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10523, 9772, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10625, 9832, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10624, 9831, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10464, 9352, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10465, 9352, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10466, 9352, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10638, 9840, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (10647, 9843, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (10636, 9839, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10637, 9839, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10633, 9837, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10634, 9837, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (10575, 9813, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10576, 9813, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10570, 9811, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10571, 9811, 112, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (10529, 9774, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (10530, 9774, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (10531, 9774, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10492, 9752, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10493, 9752, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10420, 9724, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10421, 9724, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10592, 9547, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10593, 9547, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (10580, 656, 180, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16923, 8855, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16924, 8855, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16925, 8855, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10521, 8741, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (10522, 8741, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10459, 4799, 177, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10661, 9848, 46, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10588, 4932, 181, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10572, 4813, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10573, 4813, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (10611, 9828, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10612, 9828, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16985, 915, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10539, 9776, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10540, 9776, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16964, 1541, 83, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10552, 9802, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10553, 9802, 192, 40, 1);
INSERT INTO 'dancesformationsmap' VALUES (10617, 590, 114, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10618, 590, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (10587, 3617, 181, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10566, 9808, 26, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10567, 9808, 43, 1, 5);
INSERT INTO 'dancesformationsmap' VALUES (10586, 1100, 181, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (16956, 11499, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16928, 2246, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16929, 2246, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10671, 9854, 38, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22595, 13450, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16959, 11468, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16960, 11468, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16961, 11454, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16965, 11456, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16966, 11456, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16973, 11494, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16974, 11494, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16949, 11472, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16950, 11472, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10672, 9854, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10673, 9854, 41, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10674, 9854, 69, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (10662, 9849, 101, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10663, 9849, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16988, 1098, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16989, 1098, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14875, 11434, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17012, 5216, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17013, 2434, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17014, 2074, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17017, 1299, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17018, 1299, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17022, 17, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17023, 3209, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17024, 3209, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17025, 2282, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17026, 2282, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17027, 5132, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22599, 796, 251, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (22604, 12309, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22605, 12309, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22606, 12309, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (22608, 6010, 72, 49, 3);
INSERT INTO 'dancesformationsmap' VALUES (10679, 8515, 15, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (17010, 1060, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (17011, 1060, 227, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31845, 4834, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23122, 14920, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23123, 14920, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10812, 9910, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10813, 9910, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10814, 9910, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10815, 9910, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10819, 2375, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22600, 12794, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10740, 9878, 142, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10741, 9878, 29, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (22611, 14602, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17004, 2983, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17005, 2983, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (17006, 2983, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (22612, 7457, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10684, 9858, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10616, 22, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10803, 9906, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10804, 9906, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17015, 3632, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (17016, 3632, 125, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (10591, 4270, 181, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6559, 2428, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22381, 14531, 29, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (22603, 14531, 23, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (16971, 8630, 224, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10619, 9829, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10620, 9829, 145, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (10628, 9833, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10590, 7210, 181, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (10737, 9877, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10738, 9877, 76, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (10818, 8365, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10754, 9883, 373, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (10794, 9902, 188, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (10795, 9902, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10782, 9894, 86, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10783, 9894, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10780, 9893, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (10776, 9891, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10777, 9891, 112, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10763, 9886, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10764, 9886, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10765, 9886, 168, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10761, 9885, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10762, 9885, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10755, 9884, 176, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10756, 9884, 52, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10757, 9884, 72, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (10749, 9881, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10750, 9881, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10739, 9877, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10719, 9871, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10720, 9871, 15, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (10721, 9871, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10722, 9871, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10714, 9870, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10715, 9870, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10716, 9870, 85, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10717, 9870, 27, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (10707, 9866, 70, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10708, 9866, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10709, 9866, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10705, 9865, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10706, 9865, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10696, 9863, 46, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10697, 9863, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10799, 9904, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10800, 9904, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16996, 6412, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10687, 9859, 285, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10461, 5307, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22592, 14599, 134, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (22593, 14599, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22596, 14458, 224, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22597, 14458, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (10785, 9897, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10744, 9880, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10745, 9880, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22601, 13576, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22602, 13576, 246, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16957, 10268, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (10793, 9901, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10779, 9892, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10751, 9882, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (10809, 9909, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10810, 9909, 193, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10811, 9909, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10622, 9830, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10623, 9830, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10734, 9875, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10735, 9875, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (10568, 9809, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10688, 9859, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10675, 9855, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10676, 9855, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10652, 9845, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10653, 9845, 21, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10630, 9834, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10631, 9834, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10602, 9824, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10603, 9824, 8, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (10786, 9899, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16997, 6412, 30, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (17001, 6158, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17007, 6254, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17002, 6158, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (17003, 6158, 110, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16946, 445, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10718, 3704, 145, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (10727, 9753, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10583, 3623, 180, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16990, 2245, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10581, 1762, 180, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16991, 1153, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16986, 915, 224, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (16987, 915, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16998, 600, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (16999, 600, 30, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16944, 157, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16947, 9047, 224, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (16948, 9047, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (22613, 7457, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10698, 2973, 112, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (10699, 2973, 145, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10700, 2973, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17008, 1298, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17009, 1298, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10806, 9907, 117, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10742, 9879, 176, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10743, 9879, 72, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (10710, 9867, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10711, 9867, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10820, 1147, 176, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22615, 14603, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (22616, 14603, 217, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10823, 4094, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10824, 4094, 9, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10825, 4094, 72, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (10826, 4094, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10831, 3130, 7, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17028, 2277, 142, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (17033, 6202, 1, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (17034, 6202, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (17035, 6793, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17036, 6793, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (17070, 11983, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17071, 11983, 92, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10801, 9905, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10802, 9905, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22607, 12309, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (10849, 8830, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10850, 8830, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10852, 9913, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10853, 9914, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10854, 9915, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10855, 9915, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10856, 9915, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10857, 9916, 186, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10858, 9916, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10859, 9917, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10860, 9919, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10861, 9920, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10862, 9921, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10865, 9923, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10866, 9925, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10872, 9950, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10873, 9950, 35, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10874, 9950, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10875, 9950, 43, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (10876, 9950, 94, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (10877, 9951, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10878, 9952, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10879, 9952, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10880, 9952, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10881, 9952, 35, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10882, 9953, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10883, 9953, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10884, 9954, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10885, 9954, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10886, 9954, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10887, 8491, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10888, 8491, 168, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10889, 8491, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10890, 8491, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10891, 9955, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10892, 9955, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10893, 9955, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10894, 9956, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10895, 9956, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10896, 9956, 168, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10897, 9957, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10898, 9957, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10899, 9958, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10900, 9958, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10901, 9958, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10902, 9960, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10903, 9960, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10904, 9960, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10905, 9961, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10906, 9961, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10907, 9961, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10908, 9962, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10909, 9962, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10910, 9962, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10911, 9962, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10912, 8711, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10913, 8711, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10914, 8711, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10915, 9964, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10916, 9964, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10917, 9964, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10918, 9965, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10919, 9965, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10920, 9965, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10921, 9965, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10922, 9966, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10923, 9966, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10924, 3259, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10851, 8831, 185, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10769, 9888, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17072, 11983, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10770, 9888, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31478, 18257, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31479, 18257, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17087, 11988, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10816, 9911, 119, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10817, 9911, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17088, 11988, 9, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (17090, 11989, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17091, 11989, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10846, 8722, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10847, 8722, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10838, 7561, 15, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (10839, 7561, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (10840, 7561, 43, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (17089, 11988, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10848, 8722, 65, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (17098, 12003, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10869, 9944, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17042, 10495, 183, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (22609, 3057, 66, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (16992, 6299, 119, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (16993, 6299, 365, 44, 1);
INSERT INTO 'dancesformationsmap' VALUES (17019, 4291, 225, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22610, 8630, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (17060, 11979, 48, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17061, 11979, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17096, 11990, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17097, 11990, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (17064, 11981, 58, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (17065, 11981, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17066, 11981, 222, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (17073, 11984, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17074, 11984, 56, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (17075, 11984, 83, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (17057, 11978, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17058, 11978, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17059, 11978, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17055, 11976, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17056, 11976, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (17044, 11832, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17045, 11832, 154, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17037, 11600, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10784, 9896, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10736, 9876, 43, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (10731, 9874, 38, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10822, 5637, 149, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (17063, 11980, 72, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (17050, 11973, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (10712, 9869, 87, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (10713, 9869, 1, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (16994, 3449, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17094, 3490, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17032, 1983, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17043, 10495, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17039, 10152, 4, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17040, 10152, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17041, 10152, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10774, 9890, 41, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10775, 9890, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10767, 9887, 112, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10768, 9887, 114, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10728, 9873, 176, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (10729, 9873, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10730, 9873, 87, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (10724, 9872, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10725, 9872, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10726, 9872, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (10868, 9865, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10863, 9922, 240, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10864, 9922, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10796, 9903, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10797, 9903, 29, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (17020, 4291, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17000, 600, 317, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (31480, 18257, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22614, 7457, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10834, 2481, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10832, 4639, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10833, 6199, 123, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10828, 7101, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10829, 7101, 9, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10830, 7101, 38, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (10827, 2443, 365, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (10771, 9888, 56, 19, 4);
INSERT INTO 'dancesformationsmap' VALUES (22636, 13473, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17029, 7118, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17030, 7118, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (17031, 7118, 142, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10773, 9889, 149, 24, 1);
INSERT INTO 'dancesformationsmap' VALUES (17078, 11986, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17079, 11986, 66, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (17080, 11986, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10821, 278, 168, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (10835, 1495, 184, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10836, 1495, 78, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22617, 14603, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17109, 8359, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17110, 8359, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17111, 11681, 76, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22638, 14606, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (10930, 9905, 13, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22619, 5384, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22620, 5384, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (22629, 7629, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22630, 7629, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22631, 7629, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22633, 14605, 30, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22634, 14605, 119, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22635, 14605, 23, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (22639, 14606, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10934, 9969, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10935, 9969, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10936, 9969, 36, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10937, 9970, 38, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10938, 9970, 12, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10939, 9970, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10942, 9971, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10943, 9971, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10944, 9973, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10945, 9975, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10948, 9976, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10949, 9977, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10950, 9978, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10951, 9979, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10952, 9979, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10953, 9981, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10954, 9981, 110, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10955, 9982, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10956, 9982, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10957, 9982, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22632, 7629, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10961, 9987, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10962, 9988, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10963, 9988, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10964, 9988, 162, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10966, 9971, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10968, 9975, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10969, 9975, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10970, 9977, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22640, 14606, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10975, 7742, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10976, 7742, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10977, 7742, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10978, 6493, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10979, 6493, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10980, 6493, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10981, 7743, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10982, 7743, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10983, 7743, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10984, 7703, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10985, 7703, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10986, 7703, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10987, 7703, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10988, 7703, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10989, 7703, 41, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10990, 7703, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10999, 9990, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11000, 9990, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11001, 9991, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11002, 9991, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11003, 9991, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11004, 9992, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11005, 9993, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11006, 9993, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11007, 9994, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11008, 9994, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11009, 9995, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11010, 9995, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11011, 9995, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11012, 9996, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11013, 9996, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11014, 9996, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11015, 9997, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11016, 9997, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11025, 10001, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11026, 10001, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31844, 4834, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10971, 9761, 317, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11027, 10001, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11028, 10001, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11029, 10001, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11030, 10002, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11031, 10002, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17115, 12008, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17116, 12008, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17117, 490, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11036, 10004, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10931, 9968, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11062, 9499, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22627, 14604, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22628, 14604, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10972, 9980, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (10991, 2484, 112, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (10992, 2484, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11065, 9504, 1, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (22625, 12243, 183, 41, 4);
INSERT INTO 'dancesformationsmap' VALUES (10967, 9972, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11063, 9503, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11064, 9503, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22626, 12243, 66, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (11039, 6135, 143, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (11040, 6135, 176, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (11046, 6186, 39, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (17114, 9353, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10996, 9989, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10997, 9989, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17112, 10799, 222, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (17113, 10799, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17126, 12015, 90, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17127, 12015, 117, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17128, 12015, 176, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (17067, 11982, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (17068, 11982, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17048, 11835, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17049, 11835, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11057, 10012, 214, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11058, 10012, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11059, 10012, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10973, 9984, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (10960, 9985, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11054, 10010, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11055, 10010, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10867, 9897, 56, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (11053, 10009, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (17038, 11806, 220, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22623, 3119, 1, 12, 1);
INSERT INTO 'dancesformationsmap' VALUES (22624, 3119, 85, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10752, 9882, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (17105, 12006, 132, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17107, 12007, 132, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17108, 12007, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17102, 12005, 132, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17103, 12005, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17101, 12004, 132, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17106, 12006, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10994, 9974, 82, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (10995, 9974, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11022, 10000, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11023, 10000, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22621, 13613, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22622, 13613, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11032, 10003, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11033, 10003, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17085, 11987, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17086, 11987, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17095, 11987, 2, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11020, 9999, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11021, 9999, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11034, 10003, 87, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17099, 12003, 221, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17100, 12003, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11037, 10004, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11038, 10004, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31481, 18258, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22637, 13473, 74, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10946, 9945, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10947, 9945, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17121, 12014, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17122, 12014, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10928, 7349, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22618, 14603, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11077, 10005, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11078, 10005, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11079, 10005, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11084, 10018, 46, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11087, 10020, 46, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11088, 10020, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11089, 10021, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11090, 10021, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11091, 10021, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11095, 10024, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11096, 10024, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11097, 10025, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11098, 10025, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11103, 10043, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11104, 10043, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11105, 10043, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11106, 10043, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11107, 10043, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11108, 10043, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11109, 10045, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11110, 10045, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11111, 10045, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11113, 10047, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11114, 10047, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17148, 12031, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17149, 12029, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17150, 12033, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22644, 14621, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22645, 14621, 93, 25, 8);
INSERT INTO 'dancesformationsmap' VALUES (22646, 14621, 43, 29, 4);
INSERT INTO 'dancesformationsmap' VALUES (22650, 14622, 58, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22651, 14622, 260, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (22652, 14622, 38, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (11156, 10064, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11157, 10064, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11066, 9741, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11099, 8524, 192, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (11068, 10013, 56, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (17161, 12054, 262, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (17162, 12054, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17144, 10102, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (17145, 10102, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (17142, 12022, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17143, 12022, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11129, 10055, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11130, 10055, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11122, 10053, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11123, 10053, 110, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11124, 10053, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (11082, 10017, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11126, 10054, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11127, 10054, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11128, 10054, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11085, 10019, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11086, 10019, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17156, 12053, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17153, 12052, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17154, 12052, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17155, 12052, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17152, 3996, 173, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17124, 11299, 56, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (17125, 11299, 185, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (17171, 12057, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (11146, 10062, 9, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11147, 10062, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11148, 10062, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17164, 12055, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17165, 12055, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17166, 12055, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (17167, 12055, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17135, 12018, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17136, 12018, 228, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17132, 12017, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17133, 12017, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (17134, 12017, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17130, 12016, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17131, 12016, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17129, 12015, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (11163, 10068, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11164, 10068, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11161, 10067, 76, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (11162, 10067, 145, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11175, 10066, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11158, 10065, 173, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11159, 10065, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11160, 10065, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11150, 10063, 176, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11151, 10063, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11152, 10063, 209, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (11153, 10063, 210, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (11143, 10061, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11144, 10061, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11145, 10061, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11172, 10061, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11142, 10060, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11171, 10060, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11140, 10059, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11141, 10059, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11170, 10059, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11137, 10058, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11138, 10058, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11139, 10058, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11168, 10058, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11169, 10058, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11117, 10049, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11118, 10049, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11119, 10049, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11093, 10023, 184, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (11094, 10023, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11069, 10014, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11070, 10014, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11071, 10014, 56, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (11047, 10007, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11048, 10007, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10958, 9983, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10959, 9983, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10941, 9843, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10965, 9843, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11177, 9760, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11178, 9760, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22641, 14607, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22642, 14607, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22643, 14607, 27, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (17118, 7125, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17119, 7125, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (11112, 10046, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11083, 2458, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11092, 10022, 33, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11120, 10051, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (17168, 12056, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17169, 12056, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17170, 12056, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11185, 10071, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (11075, 9986, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11076, 9986, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11189, 9984, 190, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (11183, 10070, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11186, 10071, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11187, 10071, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11201, 9541, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11202, 9541, 56, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (11195, 10072, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11196, 10072, 37, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (11199, 10075, 9, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11200, 10075, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11203, 9541, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11198, 9897, 190, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (11134, 10057, 72, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (11135, 10057, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17151, 8052, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17138, 12019, 228, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11131, 10056, 15, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11132, 10056, 125, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17147, 12024, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17163, 12054, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11067, 9743, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11100, 8524, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11101, 8524, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11102, 8524, 112, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (17185, 12061, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17186, 12062, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17187, 12062, 89, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17188, 12062, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17189, 12062, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17194, 12065, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17195, 12065, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17196, 12065, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17197, 12065, 148, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (17198, 12065, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17199, 12067, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17200, 12067, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17201, 12067, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17202, 12067, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17205, 12069, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17206, 12069, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17207, 12069, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17208, 3585, 148, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17212, 3144, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17213, 3144, 45, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (22647, 14621, 234, 49, 4);
INSERT INTO 'dancesformationsmap' VALUES (22648, 14621, 193, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (22649, 14621, 90, 109, 1);
INSERT INTO 'dancesformationsmap' VALUES (22653, 14623, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11247, 10090, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11248, 10091, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11249, 10091, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11250, 10091, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11263, 10098, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11264, 10098, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11265, 10099, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11266, 10099, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11267, 10099, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11268, 10100, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11269, 10100, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31848, 1264, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11317, 10121, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11318, 10121, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11319, 10122, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11320, 10122, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11321, 10123, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11322, 10123, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11323, 10124, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11324, 10124, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11325, 10124, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11326, 10125, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11327, 10125, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11328, 10127, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11329, 10127, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11330, 10128, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11331, 10128, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11332, 10128, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11334, 10130, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11335, 10130, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11336, 10132, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11337, 10132, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17218, 12072, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17219, 12072, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11276, 10105, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11277, 10105, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11274, 10104, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11275, 10104, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11294, 10113, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11309, 1486, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11290, 1330, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11291, 1330, 105, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (11292, 1330, 119, 31, 2);
INSERT INTO 'dancesformationsmap' VALUES (17192, 12064, 160, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17193, 12064, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11295, 10113, 364, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11255, 10094, 46, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11256, 10094, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17209, 8934, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17180, 12060, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17181, 12060, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17182, 12060, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17183, 12060, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17210, 8934, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17211, 8934, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17184, 10270, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (17174, 12058, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17175, 12058, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17203, 12068, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17204, 12068, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31904, 4445, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5765, 5674, 45, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17137, 11217, 228, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21691, 13830, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (17139, 12021, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17140, 12021, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17220, 12073, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17190, 12063, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17191, 12063, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17177, 12059, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (17178, 12059, 92, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (17172, 12057, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (17173, 12057, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11296, 10114, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11297, 10114, 176, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (11298, 10114, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11288, 10112, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11289, 10112, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11286, 10111, 42, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (11287, 10111, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (11282, 10108, 124, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11283, 10108, 120, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11280, 10107, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11281, 10107, 61, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (11278, 10106, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11279, 10106, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11270, 10103, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11271, 10103, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11261, 10097, 185, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11262, 10097, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11259, 10096, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11260, 10096, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11257, 10095, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11258, 10095, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11310, 10117, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11072, 10015, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11073, 10015, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11074, 10015, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17215, 7992, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (17216, 7992, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17214, 6711, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11313, 10119, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11315, 10120, 43, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (11316, 10120, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11314, 10119, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11300, 5009, 32, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (17230, 12075, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17231, 12075, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17232, 12075, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17240, 3585, 79, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17241, 3585, 79, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (11311, 10118, 386, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11188, 10073, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11212, 10078, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11050, 10008, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11226, 10082, 30, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (11180, 10069, 30, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11181, 10069, 317, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11213, 10078, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11214, 10078, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11204, 9541, 29, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11205, 10076, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11206, 10076, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11207, 10077, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11208, 10077, 42, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (11220, 10080, 143, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11221, 10080, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11227, 10083, 154, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11209, 10011, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11210, 10011, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11228, 10083, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11222, 10081, 93, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (11223, 10081, 89, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11224, 10081, 42, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (11229, 10083, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11230, 10084, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11231, 10084, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11232, 10084, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11293, 9835, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (11235, 10086, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11236, 10086, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11238, 10087, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11239, 10087, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11240, 10087, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11251, 10092, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (11234, 10085, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17259, 7502, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17260, 7535, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22654, 14624, 43, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22655, 14624, 280, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (22656, 14624, 23, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (11338, 10132, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11339, 10133, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11340, 10133, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11341, 10134, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11342, 10134, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11343, 10135, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11344, 10135, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11345, 10135, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11349, 10137, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11350, 10137, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11351, 10138, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11352, 10138, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11353, 10138, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11354, 10139, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11355, 10140, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11356, 10140, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11357, 10140, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17226, 8927, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11377, 10186, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11378, 10186, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11379, 10186, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11380, 10187, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17227, 8927, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11399, 10189, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11400, 10189, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11401, 10189, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11402, 10189, 59, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11403, 10190, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11404, 10190, 109, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11405, 10190, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11406, 10192, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11407, 10192, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17228, 8927, 17, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31482, 18258, 312, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11393, 2408, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (11427, 10230, 156, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11428, 10230, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11429, 10230, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17261, 7535, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17262, 7398, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17263, 7497, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17264, 7482, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17265, 7482, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17266, 7492, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17267, 7479, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17268, 7479, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17269, 7479, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17270, 7479, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17271, 7410, 127, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17272, 7445, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17273, 7512, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17274, 7363, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17275, 7522, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17276, 7354, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17277, 12081, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17278, 12081, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17279, 12081, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17280, 12081, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17286, 12084, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17287, 12084, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17298, 7248, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17299, 4237, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17300, 4237, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17301, 6547, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17302, 253, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11437, 8174, 188, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (11438, 8174, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11439, 1930, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11440, 1930, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17291, 12104, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17237, 713, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17238, 713, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11362, 9815, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11363, 9815, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11364, 9815, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17248, 12080, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (17249, 12080, 145, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (17288, 11259, 188, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (17239, 713, 46, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17292, 12104, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11358, 10089, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11359, 10089, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17250, 12080, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11450, 8999, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11430, 10231, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11386, 129, 175, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (17282, 9633, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (17290, 9633, 49, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (11394, 695, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17252, 3057, 43, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (22657, 14625, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11418, 10151, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11419, 10151, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11307, 10116, 29, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11308, 10116, 1, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (11387, 129, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11388, 129, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11444, 5824, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17293, 12105, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17294, 12105, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17283, 12083, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (17284, 12083, 300, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17285, 12083, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17295, 12106, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17296, 12106, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17297, 12106, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17233, 12076, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17234, 12076, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17221, 12073, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17222, 12073, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (17281, 10597, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (17289, 10597, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11414, 10195, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11415, 10195, 134, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11416, 10195, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11423, 10154, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11424, 10154, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11425, 10154, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11421, 10153, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11422, 10153, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11420, 10151, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11347, 10136, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (11348, 10136, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11301, 10115, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11302, 10115, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11397, 10052, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11398, 10052, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11392, 9857, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11373, 9819, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11374, 9819, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11375, 9819, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11360, 9814, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11361, 9814, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11370, 9022, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11371, 9022, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11372, 9022, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11431, 8853, 186, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11432, 8853, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11433, 8853, 36, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11442, 8177, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11443, 8177, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (11436, 8172, 189, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (11445, 4398, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11446, 4398, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11412, 10193, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11413, 10193, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11395, 9899, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11396, 9899, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11367, 9817, 43, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (11368, 9817, 112, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11369, 9817, 188, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (17244, 12079, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17245, 12079, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17246, 12079, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11537, 10276, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11538, 10276, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11539, 10276, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11540, 10276, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11550, 10277, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11551, 10277, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11552, 10277, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17306, 4377, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17310, 406, 2, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17311, 884, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17312, 884, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17313, 2898, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17314, 2414, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11620, 9191, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11588, 9698, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14408, 10008, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11564, 10283, 9, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (11576, 7272, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17253, 4768, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11381, 10188, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11382, 10188, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11589, 9698, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11590, 9698, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11591, 9698, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11605, 10287, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11606, 10287, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11607, 10287, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11608, 10287, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11612, 9201, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11613, 9201, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11614, 9201, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11626, 10289, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11627, 10289, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11628, 10289, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11447, 696, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17303, 1487, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17304, 1487, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17305, 1487, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11621, 9191, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11622, 9191, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11468, 10245, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17307, 123, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17308, 123, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17309, 123, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11504, 10259, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11505, 10259, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11491, 10254, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11517, 10266, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11518, 10266, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31483, 18258, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11565, 10284, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11566, 10284, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11567, 10284, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11485, 10252, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11486, 10252, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11487, 10252, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11515, 10265, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11516, 10265, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11453, 10237, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11454, 10237, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11457, 10239, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11469, 10245, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11497, 10257, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11498, 10257, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11481, 10251, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11482, 10251, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11483, 10251, 19, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11476, 10249, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11477, 10249, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11478, 10249, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11470, 10247, 16, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11471, 10247, 125, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11472, 10247, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11473, 10248, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11474, 10248, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11500, 10258, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11501, 10258, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11502, 10258, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11475, 10248, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11513, 10264, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11514, 10264, 84, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (11519, 10266, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11506, 10260, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11455, 10238, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11456, 10238, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11466, 10244, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11467, 10244, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11458, 10241, 30, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11459, 10241, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11448, 5939, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11449, 5939, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11592, 380, 90, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11593, 380, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11460, 10241, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11636, 1214, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11637, 1214, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11580, 9138, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11581, 9138, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17315, 2477, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17316, 2477, 69, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11582, 9138, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11583, 9138, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11525, 10270, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11492, 10255, 209, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11649, 9222, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11650, 9222, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11651, 9222, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11493, 10255, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11599, 9699, 90, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11600, 9699, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11601, 9699, 176, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (11533, 7544, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11534, 7544, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11571, 10286, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11572, 10286, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11464, 10243, 120, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11465, 10243, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11488, 10253, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (11489, 10253, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11490, 10253, 191, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11509, 10262, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11510, 10262, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11462, 10242, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11463, 10242, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11451, 10236, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11452, 10236, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11638, 9459, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11639, 9459, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11545, 10273, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11546, 10273, 84, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (11640, 9459, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (17332, 2497, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11511, 10263, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11512, 10263, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11547, 10279, 25, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11548, 10279, 119, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (11549, 10279, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11541, 10275, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11542, 10275, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11553, 10278, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11554, 10278, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11543, 10275, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11555, 10281, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (11556, 10281, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11559, 10274, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11560, 10274, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11557, 10282, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11558, 10282, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (11561, 10274, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11645, 9003, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11646, 9003, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11647, 9003, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11648, 9003, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11530, 8480, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11531, 8480, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11617, 9455, 7, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11618, 9455, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11619, 9455, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11631, 1074, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11632, 1074, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (11629, 842, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11630, 842, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11615, 700, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (11616, 700, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11569, 10285, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11570, 10285, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11507, 10261, 9, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (11508, 10261, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22660, 14626, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22661, 14626, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22662, 14626, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22663, 14626, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (11633, 1167, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11634, 1167, 85, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (11635, 1167, 69, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (11666, 10292, 127, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11667, 10292, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11668, 10292, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11669, 10292, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11676, 10293, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11677, 10293, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11678, 10293, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11679, 10294, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11680, 10294, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11688, 2627, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11689, 2627, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11690, 2627, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17319, 12107, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (11584, 9543, 9, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11585, 9543, 69, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (11586, 9543, 1, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (17335, 2521, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (17336, 2521, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17337, 2521, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11595, 413, 23, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (11528, 10272, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11526, 10271, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11527, 10271, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11522, 10268, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11523, 10268, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11691, 9007, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11609, 683, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11596, 413, 143, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11597, 413, 69, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (11598, 413, 1, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (11710, 10297, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11711, 10297, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17367, 12109, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17368, 12109, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17369, 12109, 76, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (17374, 12111, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17375, 12111, 109, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (17376, 12111, 19, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17377, 12112, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17378, 12112, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17379, 12112, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17380, 12112, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17381, 12113, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17382, 12113, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11624, 10288, 7, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (11712, 10298, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11684, 9465, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11708, 10296, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11709, 10296, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11659, 10291, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11573, 5430, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11574, 5430, 19, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (17322, 10161, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17323, 10161, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17363, 3009, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17364, 3009, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (17365, 3009, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17339, 2611, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17340, 2611, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17341, 2611, 43, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (17342, 2611, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11663, 2020, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (11664, 2020, 114, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11665, 2020, 24, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17383, 12113, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17384, 12113, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17385, 12113, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17386, 12114, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17387, 12114, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17388, 12115, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17389, 12115, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17390, 12115, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17391, 12115, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17392, 12116, 180, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17393, 12116, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17394, 12116, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17395, 12116, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17400, 12118, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17401, 12118, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17402, 12118, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31489, 4808, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22664, 14627, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22665, 14627, 36, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11714, 10299, 120, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11715, 10299, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31357, 3521, 175, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11641, 7575, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11642, 7575, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31355, 3968, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (11698, 10295, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11699, 10295, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (17328, 12108, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17329, 12108, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17330, 12108, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17331, 12108, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17361, 2968, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17362, 2968, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17357, 11225, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17358, 11225, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17359, 11225, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17324, 11205, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11748, 10307, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11749, 10307, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (11739, 10304, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11740, 10304, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11741, 10304, 176, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (11742, 10304, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11722, 10302, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (11723, 10302, 29, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (11726, 10302, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11719, 10301, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11720, 10301, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11721, 10301, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11716, 10300, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11717, 10300, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11718, 10300, 175, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (17345, 10180, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17346, 10180, 112, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (17351, 10177, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (17352, 10177, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (17353, 10176, 9, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17354, 10176, 265, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (17355, 10176, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11696, 9635, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11697, 9635, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11653, 9469, 145, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11654, 9469, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11692, 9466, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11693, 9466, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11694, 9466, 1, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (11672, 9463, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11673, 9463, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11674, 9463, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11675, 9463, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11681, 9205, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11682, 9205, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11683, 9205, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (11670, 2203, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11671, 2203, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11705, 9025, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11706, 9025, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11707, 9025, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11661, 9005, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11662, 9005, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17370, 12110, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17371, 12110, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11655, 7696, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (11656, 7696, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11657, 7696, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (17396, 12117, 373, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17397, 12117, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17398, 12117, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11729, 8811, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (11733, 4646, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11702, 3093, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11703, 3093, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17347, 2753, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17348, 2753, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (17349, 2753, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17350, 2753, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11685, 2587, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11686, 2587, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11687, 2587, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17333, 2497, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17334, 2497, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11770, 7763, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11771, 7763, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11772, 7763, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11773, 10313, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11774, 10313, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11775, 10313, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11776, 10313, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11777, 10314, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11778, 10314, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11779, 10314, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11780, 10314, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11784, 3867, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11785, 3867, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11786, 3867, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11802, 10318, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11803, 10318, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11804, 10318, 141, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11805, 10319, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11806, 10319, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11807, 10319, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11808, 10319, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11809, 10320, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11810, 10320, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11811, 10320, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11816, 10321, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11817, 10321, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11818, 10321, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11829, 10323, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11830, 10323, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11831, 10323, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17403, 12119, 182, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17404, 12119, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17405, 12119, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17406, 12119, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11835, 9473, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17407, 12119, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17408, 12119, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17409, 11910, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17410, 1870, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11724, 10303, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11730, 3659, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11727, 1562, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31488, 17754, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11815, 4224, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11658, 10290, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17411, 176, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17412, 176, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17413, 3440, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17414, 1995, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17415, 1995, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17416, 1042, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17417, 6935, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17418, 6935, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17419, 1984, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17420, 1984, 172, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17421, 6016, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17422, 6016, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17423, 1540, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17427, 2609, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17428, 5971, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17429, 5971, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17430, 5601, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17433, 6004, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17434, 6004, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17435, 6004, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17436, 6353, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11838, 7286, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (11839, 7286, 120, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (11840, 7286, 8, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (11841, 7286, 23, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (22666, 14628, 119, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22667, 14628, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22668, 14628, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11848, 4495, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11849, 4495, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11857, 10326, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11858, 10326, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11859, 10326, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11845, 4836, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11713, 10298, 78, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11846, 4836, 168, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11768, 9636, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11781, 3520, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (11738, 9911, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11769, 9636, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17424, 2403, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11753, 10309, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11754, 10309, 188, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (11755, 10309, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (17425, 2403, 317, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11854, 4933, 43, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (11855, 4933, 8, 43, 2);
INSERT INTO 'dancesformationsmap' VALUES (17426, 2403, 273, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11782, 3520, 356, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11783, 3520, 38, 55, 1);
INSERT INTO 'dancesformationsmap' VALUES (11792, 4111, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11793, 4111, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11850, 4929, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11851, 4929, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11852, 4929, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (11875, 10330, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11876, 10330, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11877, 10330, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11880, 10331, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11881, 10331, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11882, 10331, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11883, 10331, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11884, 10332, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11885, 10332, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11903, 10335, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11904, 10335, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11910, 8359, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11842, 10324, 58, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11843, 10324, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11844, 10324, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31905, 4445, 356, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11736, 5621, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11898, 5687, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11826, 3244, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (11827, 3244, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11812, 9008, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11813, 9008, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11814, 9008, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11870, 9215, 117, 177, 1);
INSERT INTO 'dancesformationsmap' VALUES (11871, 9215, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17437, 2873, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17438, 2873, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17439, 2873, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17445, 12120, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (11886, 10333, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11887, 10333, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11867, 10329, 176, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11868, 10329, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11869, 10329, 90, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11757, 10308, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11758, 10308, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (11750, 10307, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11751, 10307, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11752, 10307, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11746, 10306, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11789, 10163, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11790, 10163, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11791, 10163, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17441, 9026, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17442, 9026, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11832, 9010, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11833, 9010, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11834, 9010, 85, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11911, 8737, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11912, 8737, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11913, 8737, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11914, 8737, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17431, 1534, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17432, 1534, 48, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11893, 8033, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11894, 8033, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11895, 8033, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11890, 7565, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11891, 7565, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11892, 7565, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11899, 5687, 17, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11900, 5687, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11787, 10315, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11788, 10315, 62, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11865, 10328, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11866, 10328, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11819, 10322, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11820, 10322, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11821, 10322, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11905, 471, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (11906, 471, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11759, 10310, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11760, 10310, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11761, 10310, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11920, 10337, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11921, 10337, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11922, 10337, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11923, 10337, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11924, 10337, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11927, 10338, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11928, 10338, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11929, 10338, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11930, 10338, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17450, 11910, 177, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17475, 6696, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17476, 6696, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17477, 6696, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17478, 2029, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17479, 2029, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17480, 2029, 46, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17481, 2029, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17482, 1732, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17483, 3540, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17484, 3540, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17485, 5969, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17486, 5969, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17487, 538, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22669, 14629, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22670, 14629, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22671, 14629, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11956, 10340, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11957, 10340, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11958, 10340, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11959, 10340, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11964, 10342, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11965, 10342, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11982, 10346, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11983, 10346, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11984, 10346, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11993, 7989, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11994, 7989, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11995, 10343, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11996, 10343, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11997, 10343, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11998, 10347, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11999, 10347, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12000, 10348, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12001, 10348, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12002, 10348, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12003, 10348, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12005, 10349, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12006, 10349, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12007, 10349, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11897, 10334, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11734, 5525, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17440, 8933, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11822, 9009, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11847, 9011, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11933, 6051, 83, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (11945, 10339, 36, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11946, 10339, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (11947, 10339, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11896, 7501, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17468, 8492, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17469, 8492, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17470, 8492, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11952, 9476, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11863, 6052, 149, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11902, 5719, 66, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11860, 10327, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11861, 10327, 143, 18, 1);
INSERT INTO 'dancesformationsmap' VALUES (17447, 10755, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17448, 10755, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17449, 10755, 105, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (12014, 10350, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12015, 10350, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12016, 10350, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12021, 10353, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22672, 14630, 185, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12031, 9690, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12046, 10359, 184, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12047, 10359, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12048, 10359, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12049, 10359, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12050, 10359, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12054, 10360, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12055, 10360, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12056, 10360, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12058, 5021, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12059, 5021, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12060, 5021, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12064, 5745, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17488, 538, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17491, 2917, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17492, 2461, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17493, 2461, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17494, 676, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17495, 417, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17496, 417, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17497, 6120, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17498, 6120, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17499, 172, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17471, 12122, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17472, 12122, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17473, 12122, 340, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11950, 9937, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11951, 9937, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (11973, 6618, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11931, 9403, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12010, 7085, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11872, 9215, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11873, 9215, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11874, 9215, 43, 161, 1);
INSERT INTO 'dancesformationsmap' VALUES (17454, 12121, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17455, 12121, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (17456, 12121, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17446, 12120, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12040, 10357, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12041, 10357, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12042, 10357, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12023, 10356, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (11979, 10345, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (11980, 10345, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11981, 10345, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (11960, 10341, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11961, 10341, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11962, 10341, 85, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11975, 10344, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11976, 10344, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11977, 10344, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11963, 10341, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (11932, 9403, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11907, 9286, 37, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11908, 9286, 255, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11909, 9286, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11937, 8566, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11938, 8566, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11939, 8566, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12051, 8564, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12052, 8564, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12053, 8564, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11925, 8155, 1, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (11926, 8155, 162, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11988, 7564, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11989, 7564, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11990, 7564, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12030, 3180, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12011, 7085, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12012, 7085, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11985, 6638, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11986, 6638, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12008, 7031, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12009, 7031, 56, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (11987, 6638, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12037, 9536, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11974, 6618, 72, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (17462, 3470, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17463, 3470, 38, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (17464, 3470, 185, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17465, 3470, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11953, 6327, 185, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11954, 6327, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (11955, 6327, 145, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11948, 6273, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11949, 6273, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (11916, 5840, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11917, 5840, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (11918, 5840, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17466, 3502, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (17467, 3502, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17451, 3377, 70, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17452, 3377, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17453, 3377, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12103, 5438, 193, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17500, 172, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17501, 5242, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17502, 2027, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12065, 5745, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12066, 5745, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12101, 9237, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12027, 413, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (12118, 1641, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12034, 10013, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12035, 10013, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17503, 2027, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17504, 4889, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17505, 4889, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17507, 2165, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17508, 2165, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17509, 3807, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17510, 3015, 121, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17511, 6688, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17512, 1935, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17513, 2912, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17514, 2912, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17515, 5078, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17516, 5078, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17517, 539, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17518, 539, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17519, 7066, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17520, 4905, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17521, 6855, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17522, 6855, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17523, 4029, 2, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17524, 4402, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17525, 4402, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17526, 3163, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11967, 8158, 1, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (12092, 4894, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17527, 12123, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12039, 2484, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12024, 1358, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12111, 658, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (12097, 4933, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12044, 10358, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12045, 10358, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12106, 5009, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (12099, 3921, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12093, 5703, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12095, 5713, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (12110, 7262, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17506, 883, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12100, 9226, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (17489, 8235, 225, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17490, 8235, 66, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12109, 6229, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12114, 6153, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12112, 5345, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12119, 4256, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12115, 54, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12038, 3310, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12105, 7475, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11969, 9220, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12013, 10170, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12090, 5637, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12102, 9242, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12004, 7551, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (12057, 7545, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11878, 5412, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11879, 5412, 107, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17530, 6564, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12159, 1512, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12160, 1512, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12161, 5656, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12162, 5656, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12165, 1604, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12171, 4276, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12172, 5382, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12173, 5382, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12176, 4540, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12177, 4611, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12179, 21, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12180, 21, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12182, 2512, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12185, 5657, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12186, 5657, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12199, 8513, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12152, 8501, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12153, 8501, 75, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12061, 5504, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12062, 5504, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12063, 5504, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12107, 8042, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17597, 3909, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17598, 3909, 145, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12026, 3057, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17552, 4044, 84, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (17553, 4044, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12089, 2203, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12025, 1931, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12036, 9648, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12022, 7517, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12077, 197, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12078, 197, 28, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (12070, 8499, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12071, 8499, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12067, 10361, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12032, 3336, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12068, 10361, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12116, 10357, 215, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (12017, 10351, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12018, 10351, 365, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (17534, 10173, 220, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17535, 10173, 43, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (12094, 9765, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12148, 9456, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12149, 9456, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12150, 9456, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12113, 6380, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (12098, 1862, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (12163, 4274, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12129, 9289, 18, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12130, 9289, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (12131, 9289, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12145, 9454, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12146, 9454, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12147, 9454, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12096, 9102, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12108, 3941, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12033, 8627, 193, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (12195, 8568, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12196, 8568, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12132, 8554, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12133, 8554, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12083, 3791, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12135, 8555, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12136, 8555, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12137, 8555, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12084, 3791, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12085, 3791, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12154, 8501, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12155, 8501, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12139, 8500, 112, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12140, 8500, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12190, 8024, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12191, 8024, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12192, 8024, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12193, 8024, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12194, 8024, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (12200, 7631, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12201, 7631, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12202, 7631, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12203, 7631, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12088, 7375, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (12142, 9455, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (12143, 9455, 9, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (12144, 9455, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (12164, 4274, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17554, 4044, 176, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (12091, 848, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12122, 472, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12123, 472, 7, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (12124, 472, 76, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (12181, 735, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12187, 722, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12188, 722, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (12086, 300, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12087, 300, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (12079, 228, 175, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12080, 228, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12081, 228, 119, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (12072, 137, 222, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12073, 137, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12074, 157, 117, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12125, 9047, 261, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12214, 9542, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (12127, 488, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12236, 2085, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17577, 3674, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17578, 3674, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17579, 3801, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17580, 5363, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17581, 5363, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17582, 4860, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17583, 4860, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17584, 574, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17585, 574, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17586, 574, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17587, 4780, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17588, 6070, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17589, 3187, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17590, 5268, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17591, 5268, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17592, 4719, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17593, 4719, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17594, 4719, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17595, 7072, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22673, 14630, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12258, 5355, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (17529, 12123, 262, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (12266, 5872, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12224, 1507, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12223, 1204, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (12222, 1058, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (12227, 9849, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (12221, 8863, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12262, 7911, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12183, 3687, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12256, 7485, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (12218, 7351, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12232, 1854, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (12312, 9157, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12134, 8328, 76, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (31494, 18260, 27, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12184, 3687, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17544, 3959, 185, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17545, 3959, 202, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (17562, 4187, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17563, 4187, 149, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17541, 9137, 36, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17542, 9137, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17543, 9137, 72, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (12279, 7539, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (12257, 7488, 193, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (12313, 9157, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12278, 7135, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (12264, 5719, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12231, 5693, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17567, 4226, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17568, 4226, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17569, 4226, 6, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17531, 3755, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17532, 3755, 36, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (17533, 3755, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12219, 642, 193, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (12220, 751, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12178, 54, 165, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (17573, 4243, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (17574, 4243, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17575, 4243, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12268, 6087, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12281, 2838, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12282, 2838, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12283, 2838, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12285, 10362, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12286, 10362, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12252, 9876, 193, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (12157, 860, 23, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (17556, 4120, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12240, 2897, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17549, 7812, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12207, 1097, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12287, 10362, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12288, 10362, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12289, 10363, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12290, 10363, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12291, 10363, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12292, 10363, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12293, 5226, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12294, 5226, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12325, 10369, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12326, 10369, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12327, 10369, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12328, 10369, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12329, 10371, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12330, 10371, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12334, 10372, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12335, 10373, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12336, 10373, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12337, 10373, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12338, 10374, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12339, 10374, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12340, 10375, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12341, 10375, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12342, 10375, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17621, 7883, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17628, 12134, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17629, 12134, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17637, 12244, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17638, 12244, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17639, 12244, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12302, 10365, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12303, 10365, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12304, 10365, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12243, 10299, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12284, 8380, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12275, 6751, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (17546, 11226, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (17599, 3909, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12280, 7227, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17557, 4147, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12246, 3783, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12251, 4835, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12174, 5496, 72, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (12248, 9753, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17537, 3901, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12235, 1897, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (17538, 3901, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17539, 3901, 183, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (12228, 1814, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17622, 12242, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (17623, 12242, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (17630, 12149, 221, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (17631, 12149, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12272, 9896, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17547, 11226, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17548, 11226, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (17576, 9894, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (12296, 10364, 39, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12297, 10364, 72, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (12261, 9885, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12237, 9856, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12234, 9852, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12255, 9685, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12208, 9632, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12209, 9632, 23, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (12274, 9584, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12276, 9571, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12225, 9098, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12245, 8557, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12265, 8177, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12241, 8029, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12212, 7645, 36, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12213, 7645, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17616, 7532, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12216, 7340, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12259, 5444, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17564, 7256, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17565, 7256, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12233, 1896, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12277, 7031, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12391, 2171, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12269, 6135, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12226, 1544, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (12175, 5496, 10, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (17605, 11257, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (17606, 11257, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12239, 2789, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (12247, 4048, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (12320, 1653, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12321, 1653, 7, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (12298, 1237, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12299, 1237, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12215, 137, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (17615, 12106, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12305, 10365, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12249, 4618, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17636, 12107, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12318, 8514, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12344, 10377, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12345, 10377, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12346, 10377, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12347, 10378, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12348, 10378, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12349, 10378, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12350, 10379, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12351, 10379, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12357, 10383, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12361, 10385, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12362, 10385, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22695, 7139, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12378, 7694, 92, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12379, 7694, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12380, 7694, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12367, 10386, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12386, 2104, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12387, 2104, 81, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12388, 2104, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22674, 14631, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17596, 3974, 328, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22675, 14631, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12250, 4644, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (12398, 9105, 183, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (12399, 9105, 7, 1, 15);
INSERT INTO 'dancesformationsmap' VALUES (12270, 6150, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12356, 10382, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17640, 12245, 154, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (12267, 6035, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12300, 8569, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31490, 18260, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12368, 10386, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12369, 10386, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12370, 10387, 171, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12371, 10387, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12407, 9061, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17625, 12243, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17626, 12243, 29, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (17627, 12243, 154, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (12263, 9889, 193, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12408, 9061, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12409, 9061, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12416, 8504, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12417, 8504, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12310, 9157, 9, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12311, 9157, 1, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (12418, 9233, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12412, 8517, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12413, 8517, 185, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12414, 8517, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17651, 12248, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17652, 12248, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17653, 12248, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17660, 12251, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17672, 12268, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17673, 12363, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17674, 12363, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17675, 12363, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17679, 10101, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17680, 10101, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17681, 10101, 13, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17682, 3167, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17683, 4004, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22677, 14632, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22678, 14632, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22679, 14619, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22680, 14619, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22681, 14619, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12166, 4991, 36, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (12381, 1905, 365, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12254, 10010, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (12204, 9058, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12158, 860, 37, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17657, 12250, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17658, 12250, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12322, 9204, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12314, 9056, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12377, 8133, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12295, 4601, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12244, 9869, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (12331, 10370, 112, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12332, 10370, 114, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (12406, 2575, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12382, 1905, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22682, 14612, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22683, 14612, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22684, 14612, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22688, 13461, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22689, 13461, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22690, 13461, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12454, 10391, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12455, 10391, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12456, 10391, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12457, 10391, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12458, 10391, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12461, 3343, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12462, 3343, 142, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (12463, 3343, 148, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12358, 10384, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17600, 1533, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12273, 6532, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12238, 2110, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (8142, 3710, 112, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (12253, 4931, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12465, 7782, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12466, 7782, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6286, 7265, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22692, 7265, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22693, 7265, 30, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (12343, 10376, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12366, 10376, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (12355, 10381, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17654, 12249, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17655, 12249, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17656, 12249, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17632, 12201, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17633, 12201, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17634, 12201, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12372, 10388, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12373, 10388, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12365, 10356, 185, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12383, 9853, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12384, 9853, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (12385, 9853, 28, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (12446, 9467, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12447, 9467, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12448, 9467, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17676, 12406, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17677, 12406, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17678, 12406, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17669, 12290, 33, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17670, 12290, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (17671, 12290, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12400, 8977, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12401, 8977, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12363, 8975, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12364, 8975, 129, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12315, 8858, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12316, 8858, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12450, 8556, 175, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12451, 8556, 76, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (12452, 8556, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12389, 8503, 114, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12390, 8503, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12459, 8355, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12460, 8355, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12435, 8029, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12436, 8029, 56, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12437, 8029, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12429, 7569, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12430, 7569, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12431, 7569, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12402, 8516, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12403, 8516, 176, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12404, 8516, 295, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17607, 10368, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17608, 10368, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (17609, 10368, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17610, 10368, 125, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (12425, 2861, 77, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12426, 2861, 24, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12427, 2861, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12428, 2861, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12394, 2171, 221, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (17601, 1533, 93, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (17602, 1533, 224, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12523, 927, 194, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12524, 927, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12525, 996, 194, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12526, 293, 194, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12527, 6789, 194, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12528, 6789, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12529, 5201, 194, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12530, 6065, 194, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12531, 5561, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12532, 5561, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12533, 5561, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12534, 2324, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12535, 2324, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12536, 517, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12537, 4460, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12538, 3283, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12539, 180, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12540, 8115, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12546, 10393, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12547, 10393, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12551, 10396, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12552, 10397, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12553, 10397, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22685, 14616, 186, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22686, 14616, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22687, 14616, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10546, 3862, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31491, 18260, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12422, 8947, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12423, 8947, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12424, 8947, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31492, 18260, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12507, 8851, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12508, 8851, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12509, 8851, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12510, 8851, 117, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12511, 8851, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (12495, 8518, 10, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12496, 8518, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12497, 8518, 124, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12419, 9233, 56, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (12420, 9233, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12421, 9233, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (12554, 10397, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12556, 10399, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12557, 10399, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12558, 10399, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12568, 10403, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12569, 10403, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12570, 10403, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12571, 10403, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22807, 14684, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22808, 14684, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12628, 10427, 103, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12629, 10427, 19, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12630, 10427, 49, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12631, 10427, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (12632, 10427, 93, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12633, 1911, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12634, 10429, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12635, 10429, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12636, 10429, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12637, 10429, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12638, 10429, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12480, 8336, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12481, 8336, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12482, 8336, 265, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12594, 10423, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12595, 10423, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12596, 10423, 156, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12597, 10423, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12639, 10429, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12640, 10430, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12641, 10430, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12589, 10414, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17647, 12247, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17648, 12247, 112, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (31906, 4445, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31852, 2534, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31907, 4445, 365, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12584, 10408, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12582, 10407, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12577, 10405, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12583, 10407, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12376, 3033, 171, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12590, 10414, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12352, 10380, 112, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (12353, 10380, 84, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12354, 10380, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (11051, 10008, 119, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12512, 3933, 24, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12513, 3933, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12514, 3933, 69, 16, 1);
INSERT INTO 'dancesformationsmap' VALUES (12464, 3393, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12516, 3994, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17617, 11365, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17618, 11365, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17619, 11365, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12591, 10414, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12587, 10412, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12585, 10408, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12578, 10405, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12615, 7570, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12616, 7570, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12541, 8116, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12542, 8116, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12580, 9372, 134, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (12581, 9372, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12579, 10405, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (17661, 12277, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17662, 12277, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17643, 12246, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17644, 12246, 224, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12642, 10431, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12643, 10431, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12598, 10424, 58, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12603, 10438, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12604, 10438, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12605, 10438, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12606, 10438, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12599, 10424, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12572, 10404, 28, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (12573, 10404, 82, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12548, 10395, 77, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12549, 10395, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12550, 10395, 43, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (12574, 10406, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12575, 10406, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12576, 10406, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12474, 9868, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12475, 9868, 171, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12476, 9868, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12644, 9766, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12645, 9766, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12646, 9766, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (12609, 9759, 145, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12610, 9759, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12611, 9759, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12618, 9764, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12619, 9764, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12620, 9764, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12432, 9234, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12433, 9234, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12434, 9234, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12468, 8557, 56, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12469, 8557, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12470, 8557, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12504, 8951, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12505, 8951, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12489, 8533, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12490, 8533, 76, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (12498, 8519, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12499, 8519, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12500, 8519, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12543, 8117, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12544, 8117, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12545, 8117, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12493, 7795, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12494, 7795, 105, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12438, 7576, 29, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (12518, 7814, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12519, 7814, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12520, 7814, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12439, 7576, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12440, 7576, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12441, 7576, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12522, 6463, 194, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12491, 3691, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12492, 3691, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12600, 644, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12501, 3847, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12502, 3847, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12503, 3847, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (12612, 9761, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12613, 9761, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22697, 3935, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22704, 14637, 234, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (22705, 14637, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22706, 14637, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (22740, 14650, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22741, 14650, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (22742, 14650, 145, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22768, 14659, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22769, 14659, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22774, 5499, 7, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (22775, 5499, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22776, 5499, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22779, 7152, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (22780, 7152, 9, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22801, 14682, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22802, 14682, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (22803, 14682, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22809, 14684, 188, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (31495, 18261, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12559, 10400, 373, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3509, 6629, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22823, 13323, 176, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12560, 10400, 162, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12561, 10400, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22826, 14690, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31498, 17755, 85, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22778, 6964, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (31499, 17755, 145, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22711, 14641, 103, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13708, 10819, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13709, 10819, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22793, 10819, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22733, 14648, 54, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22734, 14648, 251, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22715, 14642, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12614, 9762, 188, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (22716, 14642, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22822, 6768, 183, 27, 4);
INSERT INTO 'dancesformationsmap' VALUES (22773, 2048, 162, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22701, 14636, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4060, 584, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22702, 14636, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12566, 10402, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12567, 10402, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6928, 5522, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (22786, 14661, 217, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22787, 14661, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22788, 14661, 281, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22717, 14642, 92, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22827, 14690, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22828, 14690, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12660, 10432, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12661, 10432, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12662, 10432, 19, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (12663, 10432, 30, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (12668, 836, 195, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12669, 1703, 195, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12670, 6494, 195, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22718, 14642, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12738, 7563, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12739, 7563, 75, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12740, 7563, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22723, 14645, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22724, 14645, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22725, 14645, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22743, 14650, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22772, 11731, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22771, 11731, 7, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22777, 5499, 66, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (22810, 14684, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (12744, 5476, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12745, 5476, 64, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22829, 14691, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22830, 14691, 65, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22831, 14691, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22842, 14696, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22843, 14696, 193, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12687, 7577, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12688, 7577, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12689, 7577, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12674, 10459, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12675, 10459, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12682, 4133, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12683, 4133, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12624, 10456, 152, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12625, 10456, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (12712, 3996, 112, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12713, 3996, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (12714, 3996, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22708, 14640, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22709, 14640, 36, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (22710, 14640, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22832, 14692, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22833, 14692, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22834, 14692, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22707, 6712, 183, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (9510, 9104, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11052, 10008, 112, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (22791, 1841, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12657, 9770, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12720, 8521, 43, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (12721, 8176, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (12753, 5520, 67, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22799, 14681, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22770, 3594, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12555, 10398, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12741, 5437, 112, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12742, 5437, 202, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12445, 3033, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12592, 10417, 19, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12593, 10417, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22785, 3486, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12695, 9214, 272, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12696, 9214, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12608, 10441, 345, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12704, 10462, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12705, 10462, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12680, 10109, 7, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (12718, 9475, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12719, 9475, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12654, 9769, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12655, 9769, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12621, 9765, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12622, 9765, 120, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12623, 9765, 149, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (22795, 3656, 251, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22781, 11195, 41, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12728, 9764, 9, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (22782, 11195, 229, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12711, 9162, 123, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22748, 14652, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22749, 14652, 46, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22750, 14652, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12729, 8522, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12730, 8522, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12754, 8510, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12755, 8510, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12733, 8508, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12734, 8508, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12692, 8507, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12693, 8507, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12694, 8507, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12684, 8506, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12685, 8506, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12686, 8506, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (12758, 8140, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12759, 8140, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12760, 8140, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (12699, 7835, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (12700, 7835, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12697, 7466, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12698, 7466, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22722, 14644, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12715, 5109, 43, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (12716, 5109, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12717, 5109, 296, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (12762, 6018, 42, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (12763, 6018, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12764, 6018, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12735, 5378, 134, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (12736, 5378, 112, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (12701, 4140, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12702, 4140, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (12703, 4140, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12028, 9422, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22819, 11897, 43, 7, 3);
INSERT INTO 'dancesformationsmap' VALUES (22696, 9420, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12650, 9768, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12651, 9768, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12652, 9768, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12765, 2085, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12766, 2085, 93, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (12767, 2085, 82, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (12773, 2126, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12776, 2136, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12777, 2136, 30, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (12784, 7650, 125, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (12785, 10467, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12786, 10467, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22804, 14683, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12746, 5503, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12747, 5503, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (12748, 5503, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (12743, 5473, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (12664, 10433, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12665, 10433, 159, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12666, 10433, 83, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22837, 14694, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22838, 14694, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12801, 6087, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12787, 10468, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12788, 10468, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12789, 10468, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22789, 14661, 27, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (22790, 14661, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12658, 10457, 195, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12659, 10457, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22805, 14683, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (22806, 14683, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31500, 17755, 265, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (31501, 17755, 221, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12749, 8509, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12750, 8509, 185, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12751, 8509, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12810, 7944, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12811, 7944, 124, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (12756, 7911, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12757, 7911, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12706, 7855, 83, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (12707, 7855, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (12708, 7855, 176, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (22839, 14694, 269, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12677, 10460, 261, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12678, 10460, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (12802, 6087, 176, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12836, 10472, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12837, 10472, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12838, 10472, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12839, 10472, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22726, 14645, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22754, 14654, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22755, 14654, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22756, 14654, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12782, 10463, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12783, 10463, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22840, 14695, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22841, 14695, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22865, 14698, 282, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22868, 13762, 77, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22869, 13762, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22874, 4333, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22875, 4333, 234, 29, 4);
INSERT INTO 'dancesformationsmap' VALUES (22876, 9930, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22877, 9930, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22878, 9930, 83, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22883, 14701, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22884, 14701, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22897, 14706, 145, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22898, 14706, 92, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22899, 14706, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22902, 14707, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22903, 14707, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22904, 14707, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22961, 2600, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22962, 2600, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (22932, 13615, 148, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22933, 13615, 28, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22934, 13615, 82, 10, 2);
INSERT INTO 'dancesformationsmap' VALUES (22939, 12801, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12781, 2853, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (22940, 12801, 52, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22941, 12801, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22950, 1167, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22955, 5734, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22956, 5734, 131, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22960, 3577, 148, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22967, 5152, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22968, 981, 7, 20, 1);
INSERT INTO 'dancesformationsmap' VALUES (12815, 8525, 39, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12816, 8525, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12817, 8525, 112, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12804, 9219, 56, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (12805, 9219, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12806, 9219, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12807, 9219, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12671, 10458, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7706, 8110, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7707, 8110, 77, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7708, 8110, 36, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (12858, 6687, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12859, 6687, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12860, 6687, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12861, 6687, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12862, 6687, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22936, 11795, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12797, 8511, 162, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (12870, 6853, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12871, 6853, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22736, 14649, 27, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22952, 12085, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22953, 12085, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22844, 14689, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22845, 14689, 87, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (22846, 14689, 53, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (12761, 5980, 36, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (22951, 12769, 43, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (22737, 14649, 23, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (12813, 6177, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12814, 6177, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12790, 7035, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12791, 7035, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12844, 10473, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12845, 10473, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12846, 10473, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12794, 10470, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12795, 10470, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12796, 10470, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12792, 10469, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12793, 10469, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12676, 10459, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12681, 10109, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (12768, 9811, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12852, 8527, 114, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12853, 8527, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12854, 8527, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12863, 8558, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12864, 8558, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12865, 8558, 9, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (12709, 8520, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12710, 8520, 105, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12769, 8503, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (12722, 8338, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12819, 8512, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12820, 8512, 112, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (12723, 8338, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (12856, 7529, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12857, 7529, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12877, 7533, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12878, 7533, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12724, 5261, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12725, 5261, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12726, 5261, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12866, 6764, 66, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12867, 6764, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12840, 6472, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12841, 6472, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12842, 6472, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12824, 6319, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12825, 6319, 38, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12826, 6319, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12872, 6870, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12873, 6870, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12874, 6870, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12672, 10458, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12901, 10437, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12902, 10437, 152, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12903, 10437, 43, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (12904, 10437, 176, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12905, 10437, 117, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (12906, 10437, 193, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (12907, 10437, 176, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (12909, 80, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12910, 80, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12911, 80, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12912, 80, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12914, 506, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22879, 14700, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22946, 1713, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22963, 780, 26, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22964, 780, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22719, 14643, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22720, 14643, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22721, 14643, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (9000, 7662, 42, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (9001, 7662, 112, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (22947, 1713, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22948, 1713, 147, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22957, 4511, 32, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (12913, 117, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22958, 4511, 38, 20, 1);
INSERT INTO 'dancesformationsmap' VALUES (22949, 1858, 365, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (12891, 7230, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22811, 14685, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (22880, 14700, 93, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (22881, 14700, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22882, 14700, 38, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (12892, 7230, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (17666, 12278, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17667, 12278, 173, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12829, 7578, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12830, 7578, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (12831, 7578, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (12812, 7944, 72, 53, 1);
INSERT INTO 'dancesformationsmap' VALUES (12889, 7539, 72, 37, 4);
INSERT INTO 'dancesformationsmap' VALUES (12890, 7539, 27, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (12915, 7351, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12908, 5636, 81, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (12918, 1031, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12919, 7363, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12924, 1410, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12926, 8234, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12928, 1644, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12929, 1890, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12930, 2133, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12931, 2136, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22757, 14654, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22858, 14697, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22859, 14697, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22860, 14697, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22870, 14699, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22871, 14699, 55, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22872, 14699, 92, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (22873, 14699, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22885, 14702, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22886, 14702, 75, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22887, 14702, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22900, 14706, 123, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22901, 14706, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22905, 14707, 43, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22906, 14707, 138, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (22907, 14707, 210, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (22935, 13615, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (22942, 12801, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (22943, 12801, 103, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (22969, 981, 131, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (17721, 5050, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17722, 133, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17723, 133, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17724, 2672, 131, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17725, 1917, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17726, 6905, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17727, 6905, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17728, 6905, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17729, 2738, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17730, 2738, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17731, 2738, 172, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17732, 1583, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17733, 2633, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17734, 6538, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17735, 260, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17736, 260, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17737, 6100, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17738, 3192, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17739, 3192, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17740, 3192, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17741, 6307, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12875, 6894, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12876, 6894, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17771, 9319, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17772, 9319, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17773, 9319, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17774, 9319, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17775, 9319, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17776, 9319, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17780, 9321, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17781, 9322, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17782, 9322, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17783, 9322, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17784, 9323, 203, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17785, 9323, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17786, 9323, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17787, 9324, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17788, 9324, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17789, 9324, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17751, 1198, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17752, 1198, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (17798, 9327, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17799, 9327, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17800, 9327, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17801, 9328, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17802, 9328, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17803, 9328, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17804, 9328, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17805, 9330, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17763, 5213, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12920, 1315, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22847, 14689, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22848, 14689, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12774, 2129, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12775, 2129, 162, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12833, 9895, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12834, 9895, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (31502, 16884, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31507, 17756, 321, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31508, 17756, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (22739, 14649, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22937, 2604, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22938, 2604, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12934, 9136, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17764, 5213, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (12868, 8368, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12869, 8368, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12895, 7252, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12896, 7252, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12897, 8816, 27, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12770, 2110, 168, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (11535, 7544, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (11536, 7544, 64, 40, 2);
INSERT INTO 'dancesformationsmap' VALUES (22727, 14646, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22728, 14646, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17797, 9326, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17742, 12427, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17743, 12427, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12893, 10474, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12894, 10474, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12847, 9478, 145, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12848, 9478, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12849, 9478, 214, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12899, 674, 257, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12900, 674, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (17777, 7178, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12886, 7121, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12887, 7121, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12882, 7027, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12883, 7027, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (12884, 7027, 30, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (17767, 6683, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17768, 6683, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17769, 6683, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (12880, 6961, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12881, 6961, 185, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (17761, 5088, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17762, 5088, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17765, 6399, 119, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (17766, 6399, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (17759, 4917, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17760, 4917, 162, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (12935, 2464, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12821, 6311, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12822, 6311, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12823, 6311, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17806, 9330, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17807, 9329, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17808, 9329, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17809, 9329, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17810, 9243, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17811, 9243, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17812, 9243, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22861, 14697, 49, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22862, 14697, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22888, 14703, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22889, 14703, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (22908, 14707, 220, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (22977, 14718, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22978, 14718, 105, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22979, 14718, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17813, 9243, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17814, 9244, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17815, 9244, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17816, 9244, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17821, 9246, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17822, 9246, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17823, 9246, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17824, 9247, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17825, 9247, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17826, 9248, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22815, 14686, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22866, 14244, 240, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22816, 14686, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22817, 14686, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12933, 2437, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22966, 780, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22971, 5829, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12921, 95, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22972, 14715, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17770, 7229, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17753, 1568, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12932, 2346, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12917, 939, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12916, 546, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22970, 3045, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22812, 14685, 356, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22813, 14685, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22814, 14685, 43, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (12925, 8193, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17827, 9248, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17828, 9248, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17829, 9248, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17830, 9248, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17831, 9248, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17841, 9251, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17842, 9251, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17843, 9251, 41, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17844, 9251, 210, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17845, 9251, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17846, 9252, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17847, 9252, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17848, 9252, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17849, 9253, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17850, 9253, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17851, 9253, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17852, 9254, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17853, 9254, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17854, 9254, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17867, 12403, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17868, 12403, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17869, 12403, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17870, 12403, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17871, 12403, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17872, 12403, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17873, 12400, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17874, 12400, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17875, 12400, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17879, 12405, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17880, 12405, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17881, 12405, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17882, 12405, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17883, 12405, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17884, 2601, 127, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17885, 2285, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17886, 2285, 221, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17887, 6504, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17888, 4971, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17889, 4971, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17890, 528, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17891, 6049, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17892, 6049, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17893, 6049, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17894, 5068, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17895, 3673, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17896, 3673, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17897, 4003, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17898, 4003, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17899, 4003, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17900, 1536, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17901, 6806, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17902, 12430, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17903, 12430, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17904, 12430, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17905, 12430, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22759, 14656, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22760, 14656, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22761, 14656, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22863, 14698, 103, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22864, 14698, 249, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22890, 14704, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22891, 14704, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (22892, 14704, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (22909, 14708, 24, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22910, 14708, 119, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22911, 14708, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17906, 12430, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17907, 12430, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17908, 12431, 127, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17909, 12431, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17910, 12431, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17911, 12431, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17915, 12433, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17916, 12433, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17917, 12433, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17918, 12433, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17921, 12435, 164, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17922, 12435, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17925, 12436, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17835, 9250, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12927, 3383, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17747, 12429, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17748, 12429, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22850, 14689, 43, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (22851, 14689, 162, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (17919, 12434, 37, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17920, 12434, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17817, 9245, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17818, 9245, 7, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (17819, 9245, 21, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (17820, 9245, 216, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (22758, 14655, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29266, 17022, 220, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17926, 12436, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17927, 12436, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17931, 12438, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17932, 12438, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17933, 12439, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17934, 12439, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17935, 12439, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17936, 12439, 232, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17940, 12441, 228, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17778, 9320, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17779, 9320, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17962, 12445, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12922, 8816, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22730, 14647, 202, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (22731, 14647, 234, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (22732, 14647, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (17745, 12428, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17746, 12428, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (17855, 12401, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17856, 12401, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17857, 12401, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17750, 141, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31512, 16885, 93, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (31513, 16885, 265, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (17757, 2402, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17758, 2402, 119, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (17754, 1897, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17755, 1897, 224, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (17756, 1897, 53, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12923, 1084, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17941, 12441, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17942, 12442, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17943, 12442, 91, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17944, 12442, 58, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17945, 12442, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (17946, 12442, 94, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17947, 12443, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17948, 12443, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17949, 12443, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17950, 12443, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17951, 12443, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17952, 12444, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17953, 12444, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17954, 12444, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17959, 11977, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17960, 11977, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17961, 11977, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17964, 12447, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17965, 12447, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17966, 12447, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17967, 12447, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17993, 12456, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17994, 12456, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17995, 12456, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22818, 14686, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22973, 14716, 157, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22974, 14716, 269, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17996, 12457, 112, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (17997, 12457, 23, 12, 4);
INSERT INTO 'dancesformationsmap' VALUES (17832, 9249, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17833, 9249, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17834, 9249, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17992, 12455, 281, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (22893, 14704, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22912, 14708, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22913, 14708, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (17998, 12458, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17999, 12458, 186, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18000, 12458, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18001, 12459, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18002, 12459, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18003, 12460, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18004, 12460, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18005, 12460, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18006, 12462, 164, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18007, 12462, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18008, 12463, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18009, 12463, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18010, 12463, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18011, 12464, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18012, 12464, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18013, 12464, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18014, 12465, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18015, 12465, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18016, 12465, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18017, 12467, 203, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18018, 12467, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18019, 12468, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18020, 12468, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18021, 12469, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18022, 12469, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18023, 12469, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18024, 12470, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18025, 12470, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18026, 12472, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18027, 12472, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18028, 12472, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18029, 12473, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18030, 12473, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18031, 12473, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18032, 12473, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18033, 12474, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18034, 12474, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18083, 12495, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18084, 12495, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18085, 12487, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18086, 12487, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18087, 12487, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18088, 12496, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18089, 12496, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18090, 12496, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18091, 12497, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18092, 12497, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22894, 14705, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22895, 14705, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (22896, 14705, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18142, 11768, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18144, 12503, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18145, 12503, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18146, 12503, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18147, 12503, 41, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18148, 12503, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18149, 12503, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18069, 12489, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18155, 12505, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18156, 12505, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18157, 12505, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18158, 12505, 41, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18162, 12507, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18163, 12507, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18164, 12507, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18167, 12509, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18168, 12509, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18169, 12509, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18170, 12509, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18171, 12509, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18070, 12489, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18079, 12494, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18072, 12490, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18035, 12475, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18036, 12475, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18150, 12504, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18151, 12504, 56, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (18081, 12142, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18082, 12173, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18066, 12488, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22914, 14709, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22915, 14709, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18134, 5062, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18135, 5062, 225, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18110, 769, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (18111, 769, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18159, 12506, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18160, 12506, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18133, 4864, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17985, 12454, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17986, 12454, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (17987, 12454, 25, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (18106, 83, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (31851, 2534, 145, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18037, 12476, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17971, 12449, 260, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17988, 2039, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17989, 2039, 224, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (18041, 12479, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18042, 12479, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17955, 8238, 69, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (17956, 8238, 283, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17983, 10381, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17972, 12450, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17937, 12440, 70, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (17938, 12440, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22765, 14658, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22766, 14658, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22767, 14658, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17979, 12453, 48, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (17963, 12446, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (17923, 12019, 154, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17924, 12019, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29272, 17023, 156, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (17912, 12432, 176, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17913, 12432, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17984, 10381, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18104, 12502, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18105, 12502, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18123, 3580, 131, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18124, 3580, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17969, 12448, 109, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17970, 12448, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17928, 12437, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17929, 12437, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17930, 12437, 215, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17876, 12404, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17877, 12404, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (17878, 12404, 317, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (17861, 12402, 65, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17862, 12402, 145, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18131, 11765, 233, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (18141, 10066, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18107, 442, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18108, 442, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18136, 10957, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18137, 10957, 225, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18138, 10957, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18048, 12482, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18049, 12482, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18132, 4844, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31514, 16885, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31515, 16885, 145, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (18130, 3660, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18115, 1587, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18116, 1587, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18067, 12488, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18068, 12488, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18099, 12500, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18100, 12500, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18113, 11779, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18114, 11779, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18080, 12494, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18165, 12508, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (18166, 12508, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (18125, 3601, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18051, 12483, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18052, 12483, 228, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18071, 12489, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18094, 12499, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18095, 12499, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18096, 12499, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18097, 12499, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18053, 12484, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18054, 12484, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18055, 12484, 124, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18056, 12484, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18043, 12480, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18044, 12480, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18045, 12481, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18093, 12498, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18038, 12478, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18039, 12478, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18040, 12478, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18102, 12501, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18103, 12501, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18112, 887, 32, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (18073, 12490, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18074, 12490, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22762, 14657, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22763, 14657, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (22764, 14657, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (18126, 3601, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18118, 1816, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18119, 1816, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (18120, 1816, 23, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (18172, 12509, 121, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18173, 12510, 102, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18174, 12510, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18175, 12510, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18176, 12510, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18187, 12513, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18188, 12513, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18192, 11101, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18193, 11101, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18194, 11101, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18195, 11102, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18196, 11102, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18197, 11102, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18198, 11103, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18199, 11103, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18200, 11103, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18201, 11103, 171, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18213, 12514, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18214, 12514, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18215, 12514, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18216, 12514, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18217, 12515, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18218, 12515, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18219, 12515, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18220, 12515, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18339, 12002, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18191, 11100, 327, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18211, 10594, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18212, 10594, 327, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (18255, 12525, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18256, 12525, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18257, 12525, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18258, 12525, 20, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (18340, 12002, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18341, 12002, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22918, 14710, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22919, 14710, 162, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22920, 14710, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18295, 11997, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18296, 11997, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18297, 11997, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18298, 11997, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18299, 11998, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18300, 11998, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18301, 11998, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18302, 11999, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18303, 11999, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18304, 11999, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18305, 11999, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18306, 11999, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18307, 11999, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18308, 11994, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18309, 11994, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18310, 11994, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18311, 12000, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18312, 12000, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18313, 12000, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18319, 11992, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18320, 11992, 154, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18321, 11992, 94, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18322, 11992, 81, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (18323, 11992, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18324, 11993, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18325, 11993, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18326, 11993, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18327, 11993, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18328, 11991, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18332, 11995, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18333, 11995, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18334, 11995, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18203, 11104, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18204, 11104, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18210, 10592, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18221, 12516, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18222, 12516, 142, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18346, 11746, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18347, 11746, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31516, 16889, 261, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31517, 16889, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (18189, 10632, 154, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18234, 12519, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (18227, 12518, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18228, 12518, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18235, 12519, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (18236, 12519, 71, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (18352, 10590, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18205, 11105, 138, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (18353, 10590, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18354, 10590, 145, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18077, 12493, 273, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18348, 11746, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18121, 3033, 273, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18122, 3323, 36, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (18190, 10632, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (18292, 12535, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18293, 12535, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18294, 12535, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18265, 12529, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18266, 12529, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18252, 12524, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18253, 12524, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18254, 12524, 224, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18250, 12523, 225, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18251, 12523, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18225, 12517, 24, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18226, 12517, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18282, 12533, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18349, 10591, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18057, 12485, 386, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18058, 12485, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18059, 12485, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18314, 12001, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18315, 12001, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18316, 12001, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18317, 12001, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (18318, 12001, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18335, 11996, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18336, 11996, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18337, 11996, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18338, 11996, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18350, 11747, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18351, 11747, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (18127, 3705, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18128, 3705, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (18129, 3705, 77, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18177, 12511, 87, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18178, 12511, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (18179, 12511, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18223, 12516, 56, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (18342, 12002, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31519, 16886, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31520, 16886, 313, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (18283, 12534, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18284, 12534, 83, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18285, 12534, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18286, 12534, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18272, 12531, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18273, 12531, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18274, 12531, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18275, 12531, 145, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18267, 12530, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18268, 12530, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (18269, 12530, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18270, 12530, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18241, 12521, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18287, 12528, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18288, 12528, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18289, 12528, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18290, 12528, 66, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (18242, 12521, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18243, 12521, 224, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (18244, 12521, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (18271, 12530, 124, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18371, 12536, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18372, 12536, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18373, 12536, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18374, 11739, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18375, 11739, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18376, 11739, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18377, 11739, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18378, 11740, 222, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18379, 11740, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18380, 11740, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18381, 11740, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18382, 3587, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18383, 3587, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18384, 11741, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18385, 11741, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18386, 11741, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18387, 11741, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18388, 11742, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18389, 7760, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18390, 7760, 12, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18391, 7760, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18392, 7760, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18393, 7760, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18394, 11743, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18395, 11743, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18396, 11743, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18397, 7856, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18398, 7856, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18399, 7856, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18400, 7856, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18401, 7856, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18402, 7856, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18403, 9987, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18404, 9987, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18405, 11744, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18406, 11744, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18407, 11744, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18408, 11744, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18409, 11745, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18410, 11745, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18411, 11745, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18412, 11745, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18413, 7290, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18414, 7290, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18415, 7290, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18416, 10187, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18417, 10187, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18418, 10187, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18419, 10090, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18420, 10090, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18421, 10090, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18422, 10090, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18356, 10588, 132, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18357, 10588, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18358, 10588, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18329, 11991, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18330, 11991, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18331, 11991, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18426, 12537, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18427, 12537, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18428, 12537, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18429, 12537, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18438, 12540, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18439, 12540, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18440, 12540, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18445, 12289, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18446, 12289, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18447, 12289, 184, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18448, 12541, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18449, 12541, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18450, 12541, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18451, 12541, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18459, 12543, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18460, 12543, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18461, 12544, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18462, 12544, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18463, 12544, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18464, 12544, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18477, 12570, 203, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18479, 12571, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18480, 12571, 221, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18481, 12571, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18483, 12572, 156, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18484, 12572, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18485, 12572, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18486, 12572, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18487, 12573, 235, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18488, 12573, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18489, 12573, 168, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18491, 12575, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18492, 12575, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18493, 12575, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18494, 12575, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18500, 12578, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18501, 12578, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31521, 16886, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31522, 16886, 183, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (18508, 12581, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18509, 12583, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18510, 12583, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18513, 12585, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18514, 12585, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18515, 12586, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18516, 12586, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18520, 12588, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18245, 12522, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18355, 10590, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18246, 12522, 7, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18362, 10595, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18363, 10595, 220, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18364, 10595, 225, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18365, 10595, 183, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (18277, 12532, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18495, 12576, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18496, 12576, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18497, 12576, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18517, 12587, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18490, 12574, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18518, 12587, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (18519, 12587, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18511, 12584, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18512, 12584, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18472, 12568, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18473, 12568, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18474, 12568, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18466, 12566, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18467, 12566, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18259, 12526, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18260, 12526, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18261, 12526, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18441, 12416, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18442, 12416, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18443, 12416, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18452, 12216, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18453, 12216, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18454, 12216, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18368, 11748, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18262, 12527, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18263, 12527, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (18264, 12527, 92, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (18369, 11748, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18370, 11748, 114, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18361, 10597, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18468, 12567, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (18469, 12567, 126, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18470, 12567, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18471, 12567, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18475, 12569, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18476, 12569, 58, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18143, 6756, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18279, 12532, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18280, 12532, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18521, 12589, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18522, 12589, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18523, 12590, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18524, 12590, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18525, 12591, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18526, 12591, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18527, 12591, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18528, 12592, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18529, 12592, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18530, 12593, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18535, 12597, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18482, 2447, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18503, 12579, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18504, 12579, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18505, 12580, 235, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18506, 12580, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18507, 12580, 129, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22921, 13590, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22922, 13590, 119, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22923, 13590, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22924, 13590, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18434, 12539, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18435, 12539, 82, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (18436, 12539, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18536, 12597, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18537, 12599, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18538, 12599, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18543, 12602, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18544, 12602, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18551, 12604, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18552, 12604, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18553, 12604, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18554, 12604, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18555, 12604, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18556, 12604, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18557, 12604, 121, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18558, 12605, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18559, 12605, 102, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18560, 12605, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18549, 12603, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18550, 12603, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18646, 12641, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18647, 12641, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18648, 12641, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18649, 12641, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18654, 12661, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18655, 12661, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18656, 12661, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18657, 12661, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18674, 12666, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18675, 12666, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18676, 12667, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18677, 12667, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18678, 12667, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18679, 12667, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18600, 12606, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18539, 12600, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18540, 12601, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18702, 12673, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18703, 12673, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18704, 12673, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18705, 12673, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18541, 12601, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18713, 12676, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18714, 12676, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18715, 12677, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18542, 12601, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18533, 12595, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18534, 12595, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18682, 1768, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18545, 4483, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18546, 4483, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18547, 4483, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18721, 12681, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18722, 12681, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18710, 12675, 139, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18711, 12675, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18712, 12675, 18, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18697, 12672, 56, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (18698, 12672, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18699, 12672, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18423, 10435, 224, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18650, 12642, 225, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18651, 12642, 224, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (18652, 12642, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18653, 12642, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18582, 12628, 77, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18583, 12628, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18584, 12628, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18598, 12627, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18599, 12627, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (18636, 12616, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18637, 12616, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (18638, 12616, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18588, 12624, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18589, 12624, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (18590, 12624, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18585, 12623, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18586, 12623, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18587, 12623, 78, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (18576, 12621, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18577, 12621, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18578, 12621, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18639, 12617, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18640, 12617, 54, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (18641, 12617, 224, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (18633, 12615, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18634, 12615, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18635, 12615, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (18628, 12614, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18629, 12614, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18630, 12614, 29, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (18620, 12612, 27, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (18621, 12612, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18622, 12612, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18618, 12611, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18619, 12611, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18614, 12610, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18615, 12610, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18616, 12610, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (18617, 12610, 165, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (18643, 12609, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18644, 12609, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18645, 12609, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (18610, 12608, 42, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (18611, 12608, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18612, 12608, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18604, 12607, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18605, 12607, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18606, 12607, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18607, 12607, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18562, 12584, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18498, 12577, 86, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18499, 12577, 10, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (18693, 12671, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18672, 9223, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18673, 9223, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18570, 7049, 96, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (18670, 6161, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18623, 12613, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18624, 12613, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18625, 12613, 120, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18626, 12613, 121, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18627, 12613, 87, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (18671, 6161, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (6846, 4720, 58, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18681, 1446, 173, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18561, 1096, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18691, 3391, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18692, 3391, 59, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18668, 12665, 168, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18669, 12665, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18716, 12678, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18717, 12678, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18456, 12542, 317, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18572, 12620, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18573, 12620, 183, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (18575, 12620, 58, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18595, 12626, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18596, 12626, 209, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18597, 12626, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18592, 12625, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18593, 12625, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18566, 12639, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18723, 12682, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18688, 12670, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18689, 12670, 28, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (18690, 12670, 278, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31523, 16890, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18567, 12640, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18568, 12640, 110, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18684, 12669, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18601, 12606, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18602, 12606, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18579, 12622, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18580, 12622, 165, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18581, 12622, 5, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (18763, 11735, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18764, 11735, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18765, 11736, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18766, 11736, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18767, 11736, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18768, 11736, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18769, 10350, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18770, 11737, 180, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18771, 11737, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18772, 11737, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18773, 11737, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18774, 11738, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18775, 11738, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18776, 11738, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18777, 11738, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18778, 10343, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18779, 7441, 221, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (18818, 7317, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18819, 7317, 236, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18820, 7317, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18821, 7317, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18825, 7322, 13, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18826, 7322, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18827, 7322, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18831, 7328, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18832, 7328, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18833, 8640, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18834, 8640, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18835, 8640, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18836, 8873, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18839, 6821, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18840, 961, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18841, 961, 131, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18842, 12720, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18843, 12720, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18844, 12720, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18845, 12722, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18846, 12722, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18847, 12722, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18848, 12722, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18849, 12722, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18850, 12722, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18851, 12723, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18852, 12723, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18853, 12723, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18854, 12723, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18858, 12725, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18859, 12725, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18860, 12725, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18861, 12725, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18864, 12727, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18865, 12727, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18866, 12727, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18867, 12727, 209, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18868, 12727, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18706, 12674, 143, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18881, 12730, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18882, 12730, 132, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18883, 12730, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18884, 12730, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18901, 12738, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18902, 12738, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18909, 12741, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18910, 12741, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18911, 12741, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18905, 12740, 82, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (18906, 12740, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18907, 12740, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18894, 12736, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18895, 12736, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18896, 12736, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (18788, 7301, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18789, 7301, 1, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (18790, 7301, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18828, 7326, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18829, 7326, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18830, 7326, 48, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18903, 12739, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18880, 11801, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18891, 12733, 117, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18837, 12719, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18838, 12719, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18760, 2421, 222, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18761, 2421, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18751, 12692, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18752, 12692, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18756, 12694, 82, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (18757, 12694, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18917, 12743, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18918, 12743, 181, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (18912, 12742, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18913, 12742, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18914, 12742, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18869, 9893, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (18870, 9893, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18811, 9385, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18862, 12726, 353, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18863, 12726, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18855, 12724, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18856, 12724, 36, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18857, 12724, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18753, 12693, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18754, 12693, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18755, 12693, 18, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18747, 12690, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18748, 12690, 224, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (18749, 12690, 225, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (18744, 12689, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18745, 12689, 18, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18746, 12689, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18740, 12688, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18741, 12688, 164, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18742, 12688, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18737, 12687, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18734, 12686, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18735, 12686, 225, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18736, 12686, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18731, 12685, 9, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18732, 12685, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18733, 12685, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (18729, 12684, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18730, 12684, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18724, 12683, 81, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18725, 12683, 52, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18877, 12728, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18878, 12728, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18563, 12638, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18694, 12671, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18695, 12671, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18879, 12728, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (18812, 9385, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18822, 7318, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18823, 7318, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18793, 7304, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18794, 7304, 9, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (18795, 7304, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18803, 7312, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18804, 7312, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18805, 7312, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18786, 7300, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18787, 7300, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18782, 7297, 120, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18783, 7297, 1, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (18784, 7297, 121, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18785, 7297, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18897, 12737, 234, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (18898, 12737, 112, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18899, 12737, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (18665, 12664, 224, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (18666, 12664, 69, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18667, 12664, 185, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (18661, 12663, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18662, 12663, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18663, 12663, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18664, 12663, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18658, 12662, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18659, 12662, 183, 7, 3);
INSERT INTO 'dancesformationsmap' VALUES (18904, 12739, 131, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18780, 7274, 72, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (18781, 7274, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18798, 7311, 236, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18799, 7311, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18800, 7311, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18750, 12691, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18937, 12750, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18926, 12746, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18927, 12746, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18680, 11420, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18938, 12750, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18941, 12752, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18942, 12752, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31524, 16890, 221, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31525, 16890, 278, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (31305, 18239, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19042, 8735, 29, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (19043, 8735, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19056, 12778, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19057, 12778, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19058, 12778, 215, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19062, 12780, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19067, 12782, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19068, 12782, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19069, 12783, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19070, 12783, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19084, 12787, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19085, 12787, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19086, 12788, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19000, 7296, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19071, 12784, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18988, 12767, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18989, 12767, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19072, 12784, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19073, 12784, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19096, 364, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19097, 364, 27, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (18971, 12762, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18972, 12762, 87, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18973, 12762, 103, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18813, 7316, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18814, 7316, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18815, 7316, 168, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (18999, 3506, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19001, 7296, 36, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18871, 4708, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18966, 12761, 112, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18967, 12761, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18968, 12761, 176, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (18957, 12759, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18958, 12759, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18959, 12759, 72, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (18977, 12764, 152, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18978, 12764, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18979, 12764, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18991, 12768, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18992, 12768, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18993, 12768, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18985, 12766, 15, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18986, 12766, 77, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18987, 12766, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19052, 12777, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19053, 12777, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19002, 7296, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18980, 12764, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (18974, 12763, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18975, 12763, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18976, 12763, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19100, 1414, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19101, 1414, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18981, 12765, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18982, 12765, 145, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19003, 1784, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19004, 1784, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (18983, 12765, 19, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18960, 12760, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18961, 12760, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18962, 12760, 71, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (18996, 2024, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19095, 295, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18872, 4716, 202, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18924, 12745, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18925, 12745, 204, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18921, 12744, 56, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18922, 12744, 202, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18923, 12744, 176, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18887, 12732, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18888, 12732, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18889, 12732, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18890, 12732, 224, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (18885, 12731, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18886, 12731, 81, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18738, 12687, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18739, 12687, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18726, 12683, 168, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (18727, 12683, 72, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (18728, 12683, 149, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (19011, 7293, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19036, 7107, 26, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19010, 7289, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19087, 12789, 145, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19088, 12789, 102, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19089, 12789, 51, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19037, 7107, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19038, 7107, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19090, 6837, 7, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19091, 6837, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19032, 6410, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19033, 6410, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19034, 6410, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19019, 5888, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19020, 5888, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19050, 5034, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19014, 4441, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19015, 4441, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19027, 3778, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (19028, 3778, 215, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19029, 3054, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19030, 3054, 225, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19023, 3268, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19024, 3268, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19031, 3054, 224, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19021, 2275, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19104, 2251, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19103, 1483, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19016, 1072, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19017, 1072, 23, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (19018, 1072, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18994, 1017, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18995, 1017, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18997, 980, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18998, 980, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19099, 853, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19098, 841, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19094, 271, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19059, 12779, 15, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19060, 12779, 125, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19061, 12779, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19051, 12399, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19035, 1465, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19122, 4616, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19123, 4616, 142, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19124, 4616, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19125, 4616, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (19126, 6654, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19127, 6654, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19128, 6654, 148, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19129, 6654, 19, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (19136, 5960, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19137, 5960, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19138, 5960, 27, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (19139, 5960, 7, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19163, 8044, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19164, 8044, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19165, 8044, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19166, 8044, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (19047, 2972, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19048, 2972, 143, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19049, 2972, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19158, 8041, 142, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19159, 8041, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19093, 6787, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19063, 12781, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19064, 12781, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18955, 12758, 221, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19074, 12785, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19075, 12785, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (19076, 12785, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19012, 12772, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19013, 12772, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18948, 12754, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19005, 12769, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (19006, 12769, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19007, 12769, 117, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18930, 12747, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18931, 12747, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18944, 12753, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18945, 12753, 148, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18946, 12753, 19, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18953, 12757, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18954, 12757, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18949, 12755, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18950, 12755, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18951, 12755, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18935, 12749, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18936, 12749, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18939, 12751, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18940, 12751, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18952, 12756, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18956, 12758, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18943, 12752, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18932, 12748, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18933, 12748, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18934, 12748, 373, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19160, 8041, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19147, 6771, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19148, 6771, 221, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19149, 6771, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19150, 6771, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19237, 8070, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19238, 8070, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19239, 8070, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19209, 8061, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19210, 8061, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19211, 8061, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19140, 5989, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19146, 6582, 1, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (19044, 10923, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19045, 10923, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19046, 10923, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19276, 8079, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19277, 8079, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19278, 8079, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31528, 17759, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31529, 17759, 265, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (31530, 17759, 202, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (19130, 5023, 27, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (19131, 5023, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (19172, 8047, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19173, 8047, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (19174, 8047, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19216, 8063, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19217, 8063, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19279, 8080, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19280, 8080, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19281, 8080, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19234, 8069, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19218, 8064, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19219, 8064, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19220, 8064, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19116, 3803, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19117, 3803, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19118, 3803, 134, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19282, 8081, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19298, 12219, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19299, 12219, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (19302, 12632, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19303, 12632, 84, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19300, 12219, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19183, 8050, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19184, 8050, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19235, 8069, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19236, 8069, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19161, 8042, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19261, 1088, 225, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19286, 8083, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19287, 8083, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (19022, 2275, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19105, 2251, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19315, 12636, 225, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19316, 12636, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19288, 8084, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19289, 8084, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19283, 8082, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19284, 8082, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19285, 8082, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19245, 8073, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19246, 8073, 183, 19, 3);
INSERT INTO 'dancesformationsmap' VALUES (19228, 8067, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19229, 8067, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19230, 8067, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19225, 8066, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19226, 8066, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (19227, 8066, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19207, 8060, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19208, 8060, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19205, 8059, 1, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (19206, 8059, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19199, 8057, 1, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (19200, 8057, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19201, 8057, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19196, 8056, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19197, 8056, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19180, 8049, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19181, 8049, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19182, 8049, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19155, 8040, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19156, 8040, 7, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19151, 8039, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19152, 8039, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (19153, 8039, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19109, 2651, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19110, 2651, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19145, 6522, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19144, 5996, 148, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (19132, 5061, 224, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19133, 5061, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19191, 2686, 142, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19192, 2686, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19167, 8045, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19168, 8045, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19169, 8045, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (19120, 3878, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19121, 3878, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19115, 3731, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19114, 3200, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (19111, 2955, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19112, 2955, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19318, 12637, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19319, 12637, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19186, 2513, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19187, 2513, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19273, 6347, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19274, 6347, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19275, 6347, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19213, 8062, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19214, 8062, 269, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19215, 8062, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19259, 243, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19260, 243, 111, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (19247, 8074, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19248, 8074, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19252, 8077, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19253, 8077, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19320, 7298, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19321, 7298, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19322, 7303, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19323, 7303, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19324, 7299, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19325, 7299, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19326, 7292, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19327, 7292, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19328, 7292, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19329, 7292, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19335, 12791, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19336, 12791, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19337, 12791, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19338, 12791, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19339, 12791, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19346, 12808, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19347, 12808, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19348, 12808, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19349, 12808, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19350, 12808, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19351, 2959, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19352, 2959, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19353, 2959, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19264, 1749, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19265, 1749, 69, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (19202, 8058, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19203, 8058, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19204, 8058, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19371, 10980, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19372, 10980, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19373, 10980, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19374, 10980, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19375, 12814, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19376, 12814, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19377, 12814, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19378, 12814, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19141, 5995, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19142, 5995, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19310, 11908, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19311, 11908, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19254, 8078, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19255, 8078, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19222, 8065, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19290, 12630, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19291, 12630, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19293, 12631, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19294, 12631, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19295, 12631, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19223, 8065, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19162, 7653, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19267, 5635, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19250, 8076, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19251, 8076, 111, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19240, 8071, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19195, 8055, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19194, 8054, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19190, 8053, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19170, 8046, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19171, 8046, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19268, 5635, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19379, 12814, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19380, 12815, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19381, 12815, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19382, 12815, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19383, 10985, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19384, 10985, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19385, 10985, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19424, 12826, 130, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19425, 12826, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19434, 12833, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19435, 12833, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19436, 12833, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19437, 12834, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19438, 12834, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19453, 12840, 31, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19459, 12843, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19460, 12844, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19426, 7278, 119, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19465, 12847, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19466, 12847, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31855, 13908, 193, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19470, 12849, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19471, 12849, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19472, 12851, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19473, 12851, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19478, 12854, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19341, 12793, 267, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19342, 12793, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (19461, 12845, 10, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19312, 12635, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19313, 12635, 82, 10, 2);
INSERT INTO 'dancesformationsmap' VALUES (19314, 12635, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19462, 12845, 129, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19368, 12813, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19369, 12813, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19343, 12794, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19344, 12794, 114, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19370, 12813, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19419, 12824, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19364, 12812, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19365, 12812, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19366, 12812, 120, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19367, 12812, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19420, 12824, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19421, 12824, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31531, 17759, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19176, 8048, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19177, 8048, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19178, 8048, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19231, 8068, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19304, 12632, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19232, 8068, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19233, 8068, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19479, 12854, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19480, 12854, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19485, 12857, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19486, 12857, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19487, 12857, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19488, 12858, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19489, 12858, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19490, 12859, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19491, 12860, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19492, 12860, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19463, 12846, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (19464, 12846, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19356, 12810, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19357, 12810, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19358, 12810, 36, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (19457, 12842, 183, 7, 3);
INSERT INTO 'dancesformationsmap' VALUES (19458, 12842, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19340, 12792, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (19406, 12819, 168, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (19446, 12837, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19386, 7608, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19387, 7608, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19390, 705, 192, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19391, 705, 114, 29, 6);
INSERT INTO 'dancesformationsmap' VALUES (19392, 705, 42, 41, 6);
INSERT INTO 'dancesformationsmap' VALUES (19361, 5817, 225, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19397, 12817, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19398, 12817, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (19393, 12816, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19394, 12816, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19395, 12816, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19399, 12818, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19400, 12818, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19401, 12818, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19404, 2730, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19405, 2730, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19412, 3285, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19413, 3285, 142, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (19362, 12811, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19363, 12811, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19416, 3703, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19417, 5819, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19418, 5819, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19450, 12839, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19451, 12839, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19452, 12839, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19495, 12862, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19483, 12856, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19484, 12856, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19474, 12850, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19475, 12850, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19454, 12841, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19455, 12841, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19442, 12836, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19443, 12836, 119, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (19439, 12835, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19440, 12835, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19441, 12835, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19422, 12825, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (19423, 12825, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19414, 12820, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19415, 12820, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19354, 12809, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19355, 12809, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19308, 12634, 145, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (19309, 12634, 183, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (19432, 11629, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19330, 12790, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19331, 12790, 69, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (19332, 12790, 92, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19433, 11629, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19188, 8051, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19189, 8051, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19428, 12411, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19429, 12411, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19430, 12411, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (19396, 1577, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19407, 12819, 71, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19499, 12864, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19500, 12864, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19501, 12865, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19502, 12865, 132, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31301, 18238, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31302, 18238, 8, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (19543, 12422, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19477, 12852, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19544, 12422, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19427, 10471, 82, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (19517, 12256, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (19518, 12256, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19519, 12256, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19524, 12292, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19525, 12292, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19530, 12318, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19531, 12318, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19533, 12367, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19534, 12367, 176, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19498, 12863, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19509, 12192, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19510, 12192, 185, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19511, 12192, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19538, 12423, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19539, 12423, 131, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19527, 12421, 114, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19528, 12421, 225, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19551, 12395, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19552, 12395, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19553, 12395, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19540, 12377, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19541, 12377, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (19542, 12377, 51, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19536, 12372, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19537, 12372, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19532, 12326, 224, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19529, 12314, 76, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (19512, 12194, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (19513, 12194, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19504, 12144, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19505, 12144, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19506, 12144, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19503, 12135, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31526, 17758, 75, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19493, 12861, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19494, 12861, 91, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19645, 10464, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19646, 10464, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19647, 10464, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19520, 12215, 372, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19521, 12276, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19522, 12276, 327, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19523, 12276, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19657, 12895, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19658, 12895, 72, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (19659, 12895, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19582, 12873, 183, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (19583, 12873, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19584, 12873, 176, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19562, 11800, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19661, 12896, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19662, 12896, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (19667, 12733, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19654, 12894, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19655, 12894, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19675, 12900, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19676, 12900, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19677, 12900, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19507, 12162, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19710, 12911, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19711, 12911, 172, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19587, 12874, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19588, 12874, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19712, 12911, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19713, 12911, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19717, 12914, 106, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19718, 12914, 70, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19615, 12883, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19616, 12883, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19589, 12874, 76, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (19611, 12882, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19612, 12882, 224, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19613, 12882, 225, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19614, 12882, 82, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (19635, 12889, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19636, 12889, 145, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19706, 12910, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19707, 12910, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19708, 12910, 91, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (19700, 12909, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19701, 12909, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19702, 12909, 112, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (19703, 12909, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19681, 12903, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19682, 12903, 45, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19683, 12903, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19687, 12905, 143, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (19688, 12905, 87, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (19689, 12905, 27, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (19671, 12898, 226, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19672, 12898, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19673, 12898, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19674, 12898, 111, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (19640, 12890, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19641, 12890, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19632, 12888, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19668, 12897, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19669, 12897, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (19670, 12897, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19633, 12888, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19634, 12888, 69, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (19628, 12887, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19629, 12887, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19630, 12887, 9, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (19622, 12886, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19623, 12886, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19624, 12886, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19620, 12885, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19621, 12885, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19607, 12881, 38, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19608, 12881, 209, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19609, 12881, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19602, 12880, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19603, 12880, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19604, 12880, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (19605, 12880, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19599, 12879, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19600, 12879, 225, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19601, 12879, 90, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (19593, 12876, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19594, 12876, 7, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19590, 12875, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19591, 12875, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19578, 12872, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19579, 12872, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (19580, 12872, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19574, 12871, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19575, 12871, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19576, 12871, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (19570, 12870, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19571, 12870, 9, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (19572, 12870, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19573, 12870, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19637, 12706, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19638, 12706, 172, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19508, 12162, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (19563, 12866, 225, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19564, 12866, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19496, 12862, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19497, 12862, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19568, 12869, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19569, 12869, 214, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (19639, 12706, 9, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19692, 12696, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19693, 12696, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19694, 12696, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19566, 12868, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19567, 12868, 92, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19549, 12388, 237, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19550, 12388, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19650, 12893, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19651, 12893, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19652, 12893, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19648, 12892, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19649, 12892, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19766, 9746, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19767, 9746, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19773, 12942, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19774, 12942, 164, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19775, 12942, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19776, 9748, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19777, 12943, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19778, 12943, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19779, 12943, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19780, 9749, 27, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (19781, 9749, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19788, 12945, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19789, 12945, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19790, 12945, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19791, 12945, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19793, 12946, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19794, 12946, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19795, 12946, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19796, 12946, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19797, 12946, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19803, 10464, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19806, 9292, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19807, 9292, 221, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19810, 8337, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19811, 8337, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19812, 8337, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19759, 12937, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19760, 12937, 373, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19761, 12938, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19762, 12938, 373, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19847, 12995, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19848, 12995, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19849, 12995, 105, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19850, 12995, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19851, 12995, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19852, 12993, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19853, 12993, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19854, 12993, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19855, 12993, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19856, 12993, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19857, 12985, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19858, 12985, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19859, 12985, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19860, 12985, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19861, 12986, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19862, 12986, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19863, 12987, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19864, 12987, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19865, 12987, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19595, 12877, 192, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19558, 7000, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19559, 7000, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19565, 12867, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19555, 12410, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19556, 12410, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19557, 12410, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19554, 12395, 224, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19545, 12387, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19546, 12387, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19560, 12420, 89, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (31527, 17758, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19596, 12877, 238, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19597, 12877, 239, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19830, 12998, 10, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19831, 12998, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19832, 12998, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19838, 13000, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19839, 13000, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19840, 13000, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19834, 12999, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19835, 12999, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19836, 12999, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19833, 12998, 70, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (19827, 12997, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19828, 12997, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19829, 12997, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19747, 12929, 62, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19748, 12929, 22, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19704, 10644, 145, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19705, 10644, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19792, 9575, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19821, 7849, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19808, 12996, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19814, 8329, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19815, 8329, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (19809, 12996, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19866, 12987, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19867, 12987, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19868, 12992, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19869, 12992, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19870, 12992, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19871, 12992, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19872, 12992, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19873, 12992, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19874, 12992, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19875, 12991, 101, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19876, 12991, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19877, 12989, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19878, 12989, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19879, 12989, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19880, 12984, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19881, 12984, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19882, 12984, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19883, 12984, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19884, 13047, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19885, 13047, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19886, 13048, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19887, 13048, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31496, 18261, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31497, 18261, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19890, 13050, 186, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19891, 13050, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19892, 13050, 168, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19893, 13051, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19894, 13051, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19895, 13051, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19896, 13051, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19897, 13051, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19898, 13053, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19899, 13053, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19900, 13053, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19901, 13053, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19695, 12907, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19845, 13003, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19846, 13003, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19825, 12810, 119, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (19826, 12810, 32, 8, 2);
INSERT INTO 'dancesformationsmap' VALUES (19697, 12908, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19735, 12885, 173, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19719, 12914, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19720, 12914, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19721, 12916, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19743, 12366, 87, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (19732, 12923, 24, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19744, 12366, 117, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19782, 12944, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19722, 12917, 171, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19723, 12917, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19724, 12917, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19728, 12919, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19763, 12939, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19729, 12920, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19764, 12939, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19696, 12907, 86, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19758, 12936, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19756, 12935, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19757, 12935, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19754, 12934, 210, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19755, 12934, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19737, 12925, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19738, 12925, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19739, 12925, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19816, 8368, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19730, 12921, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19751, 12930, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19752, 12930, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19731, 12921, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19765, 12939, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19736, 12924, 109, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (19733, 12923, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19734, 12923, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19698, 12908, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19783, 12944, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19784, 12944, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19740, 12927, 9, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19741, 12927, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19690, 12906, 93, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (19691, 12906, 278, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19685, 12904, 55, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19686, 12904, 224, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (19817, 4908, 114, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19818, 4908, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19902, 13055, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19903, 13055, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19904, 12990, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19905, 12990, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19906, 12994, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19768, 12940, 224, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19769, 12940, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19819, 10484, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19907, 12994, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19908, 12988, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19909, 12988, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19910, 12988, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19914, 13057, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19915, 13057, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19916, 13057, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19917, 13058, 186, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19918, 13058, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19919, 13059, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19920, 13059, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19921, 13059, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19922, 13060, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19923, 13060, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19924, 13060, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19925, 13060, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19926, 13061, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19927, 13061, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19928, 13062, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19929, 13062, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19930, 13062, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19931, 13062, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19936, 13064, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19937, 13064, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19938, 13065, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19939, 13065, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19940, 13065, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20022, 12965, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19978, 13066, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19979, 13066, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19980, 13066, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19981, 13067, 131, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19982, 13067, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19983, 13067, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19984, 13067, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19987, 13069, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19988, 13069, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19996, 13072, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20000, 13074, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20001, 13074, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20002, 12967, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20003, 12967, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20004, 12967, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20005, 12967, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20006, 12967, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20007, 12966, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20008, 12966, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20009, 12966, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20010, 12966, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20011, 12966, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20023, 12965, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20024, 12965, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20038, 12964, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20016, 12961, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20017, 12961, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20018, 12961, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20039, 12964, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20029, 12969, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20030, 12969, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20031, 12969, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19714, 12913, 386, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19680, 12902, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19804, 12948, 29, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (19805, 12948, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (20032, 12968, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20033, 12968, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20040, 12964, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20041, 12970, 273, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20042, 12970, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20043, 12970, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20055, 13078, 185, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (20056, 13078, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19932, 13063, 203, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (19933, 13063, 261, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (19813, 8328, 334, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19822, 9836, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20057, 13078, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20058, 13078, 110, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19823, 9836, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (19824, 9836, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (20086, 13084, 180, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20087, 13084, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20088, 13084, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20089, 13084, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19992, 13071, 265, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19993, 13071, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19994, 13071, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19995, 13071, 119, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (20067, 13081, 154, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (20068, 13081, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (20069, 13081, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20070, 13081, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20090, 13084, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20048, 13076, 185, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (20049, 13076, 202, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (20050, 13076, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (20051, 13076, 39, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (31534, 15321, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20093, 13086, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20094, 13086, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20095, 13086, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20096, 3712, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20097, 3712, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20098, 3712, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20099, 3712, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20100, 8018, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20101, 8018, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20102, 7609, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19989, 13070, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19990, 13070, 25, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19991, 13070, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20012, 12960, 285, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20013, 12960, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20071, 13082, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20072, 13082, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20073, 13082, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20059, 13079, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20060, 13079, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20061, 13079, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20062, 13079, 17, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (20044, 13075, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20045, 13075, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20046, 13075, 19, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (20047, 13075, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20063, 13080, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19944, 12953, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20237, 5223, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20064, 13080, 225, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20065, 13080, 224, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (20066, 13080, 39, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (19997, 13073, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19998, 13073, 24, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19999, 13073, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19985, 13068, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19986, 13068, 70, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (20025, 12962, 58, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20026, 12962, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19971, 12959, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19972, 12959, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19973, 12959, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19948, 12957, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19949, 12957, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19950, 12957, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19941, 12956, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19942, 12956, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19943, 12956, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19966, 12955, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19967, 12955, 214, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19968, 12955, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (19957, 12954, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19958, 12954, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (19959, 12954, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19960, 12954, 224, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (19911, 13056, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19912, 13056, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19913, 13056, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19951, 12951, 173, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19952, 12951, 261, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (19953, 12951, 143, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (19954, 12950, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19955, 12950, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19956, 12950, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19961, 12949, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19962, 12949, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (19963, 12949, 224, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (20019, 12971, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20020, 12971, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20021, 12971, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19945, 12952, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19946, 12952, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19947, 12952, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20103, 7609, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20107, 12973, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20108, 12973, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20109, 12973, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20124, 7618, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20125, 7618, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20126, 7618, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20127, 7726, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20128, 7726, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20129, 7726, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20130, 7726, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20131, 7726, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20132, 7771, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20133, 7771, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20134, 7771, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20135, 7771, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20136, 7771, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20141, 3587, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20142, 7993, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20143, 7993, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31857, 13908, 224, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (20153, 12979, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20154, 12979, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20155, 12979, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20156, 12972, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20157, 12972, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20158, 12972, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20159, 12972, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20160, 12975, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20161, 12975, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20162, 12975, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20163, 12976, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20164, 12976, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20165, 12976, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20166, 12976, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20167, 12980, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20168, 12980, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20169, 8815, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20170, 8815, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20171, 8815, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20172, 8818, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20173, 8818, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20174, 8818, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20175, 8818, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20176, 8820, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20177, 8820, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20178, 8820, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20179, 8819, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20180, 8819, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20181, 8819, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20182, 8819, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20183, 8821, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20184, 8822, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20185, 13105, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20186, 13105, 222, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20190, 13107, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20191, 13107, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20192, 13108, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20193, 13108, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20194, 13109, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20195, 13109, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20196, 13110, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20197, 13110, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20198, 13110, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20199, 13110, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20200, 13111, 127, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20201, 13111, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20202, 13111, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20203, 13112, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20204, 13112, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20205, 13112, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20206, 13112, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20207, 13112, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31912, 18302, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31913, 18302, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20212, 13114, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20213, 13114, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20214, 13114, 119, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (20215, 13114, 92, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (20216, 13114, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (20091, 13085, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20092, 13085, 200, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20208, 13113, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (20209, 13113, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20210, 13113, 93, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (20233, 13119, 285, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20234, 13119, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (20235, 13119, 71, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (20148, 12982, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20149, 12982, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20150, 12982, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20151, 12982, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20104, 12974, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20105, 12974, 273, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20106, 12974, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20217, 13115, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20218, 13115, 168, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20219, 13115, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20239, 13127, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20240, 13127, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20241, 13127, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (20110, 13087, 261, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20111, 13087, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20112, 13087, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20113, 13087, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20144, 13104, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20145, 13104, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20146, 13104, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20220, 13115, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31532, 15321, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31533, 15321, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20290, 12978, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20291, 12978, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20292, 12978, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20293, 12981, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20294, 12981, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20295, 818, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20296, 1005, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20297, 1184, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20298, 1416, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20299, 2091, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20300, 2091, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20301, 2091, 156, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20302, 5488, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20303, 5488, 22, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (20304, 5488, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20305, 3064, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20306, 3064, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20307, 3648, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20308, 3648, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20309, 4314, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20310, 7051, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20312, 6330, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20313, 53, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20314, 53, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20315, 53, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20316, 511, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20317, 511, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20318, 511, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20320, 9195, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20321, 9195, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20322, 9195, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20323, 9195, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20328, 692, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20329, 692, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20330, 1472, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20331, 1472, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20332, 1642, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20333, 1642, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20334, 1879, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20335, 1879, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20319, 11939, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20078, 2254, 32, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (20079, 2254, 43, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (20236, 4073, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (20244, 13128, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20245, 13128, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20117, 13089, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20118, 13089, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20119, 13089, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (20246, 13128, 36, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (20152, 9837, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20137, 5324, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20138, 5324, 224, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20082, 2254, 110, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20120, 10493, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20121, 10493, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20336, 1879, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20337, 2003, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20338, 2963, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20339, 2963, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20340, 2963, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20341, 2963, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20342, 3227, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20343, 3227, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20344, 3227, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20345, 3363, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20346, 3363, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20347, 3363, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20421, 13174, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20226, 13117, 43, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (20228, 13117, 28, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20229, 13117, 7, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (20353, 13151, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20431, 13177, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20432, 13177, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20433, 13177, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20366, 13156, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20367, 13156, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20386, 13162, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20387, 13162, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20395, 13165, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20396, 13166, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20397, 13166, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20398, 13166, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20400, 13167, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20401, 13167, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20402, 13167, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20403, 13167, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20379, 13160, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20380, 13160, 52, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20381, 13160, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20363, 13155, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20364, 13155, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20365, 13155, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20406, 13169, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20409, 13171, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20410, 13171, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20359, 13154, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20360, 13154, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20361, 13154, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20362, 13154, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20384, 13161, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20385, 13161, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20422, 13174, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20423, 13174, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20424, 13174, 143, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (20425, 13175, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20426, 13175, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20427, 13175, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20428, 13176, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20429, 13176, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20430, 13176, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20411, 13172, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20412, 13172, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20404, 13168, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20405, 13168, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20413, 13172, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20286, 72, 43, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (20287, 72, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20289, 72, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20284, 584, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20512, 5965, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20513, 5965, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (20514, 5965, 82, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20515, 3604, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20516, 3604, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20517, 3604, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20518, 4061, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20415, 13173, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20416, 13173, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20417, 13173, 154, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20351, 13150, 241, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20352, 13150, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20311, 6401, 181, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20348, 13149, 241, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20349, 13149, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20350, 13149, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20221, 13116, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20222, 13116, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20223, 13116, 262, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20324, 11303, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20325, 11303, 154, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20326, 11303, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20282, 6627, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20519, 4061, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20520, 4061, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20521, 13207, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20522, 13207, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20523, 13207, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20524, 13208, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20525, 13208, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20526, 13208, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20529, 7119, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20530, 7119, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20531, 7119, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20532, 7119, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20439, 13180, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20552, 13220, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20553, 13220, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20554, 13221, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20555, 13221, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20556, 13221, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20557, 13221, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20558, 13222, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20559, 13222, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20560, 13222, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20561, 13222, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20566, 13224, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20567, 13224, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20568, 13224, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31493, 18260, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (20440, 13180, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20586, 13034, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20587, 13034, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20588, 13034, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20589, 13042, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20537, 13210, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20538, 13210, 21, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20539, 13210, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20540, 13210, 24, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (20541, 13210, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20441, 13180, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20527, 4233, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20528, 4233, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (20590, 13042, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20591, 13042, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20592, 13042, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20593, 13042, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20594, 13042, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20595, 13043, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20391, 13164, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (20549, 13219, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20550, 13219, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20551, 13219, 176, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (20572, 13227, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20573, 13227, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20354, 13152, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20355, 13152, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20574, 13227, 189, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (20577, 13228, 126, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20578, 13228, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20579, 13228, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20533, 13209, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20534, 13209, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20372, 13158, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20373, 13158, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20374, 13158, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20575, 9941, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20576, 9941, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20596, 13043, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20597, 13043, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20598, 13043, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20599, 13043, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20600, 13044, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20601, 13044, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20602, 13044, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20603, 9976, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20604, 10584, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20605, 10584, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20606, 13045, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20607, 13045, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20608, 13045, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20609, 13045, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20610, 13045, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20611, 13035, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20612, 13035, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20613, 13035, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20614, 13035, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20615, 13036, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20616, 13036, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20617, 13036, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20618, 13037, 182, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20619, 13037, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20620, 13037, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20621, 13007, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20485, 13196, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20496, 13201, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20497, 13201, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20542, 13211, 262, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20543, 13211, 273, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20467, 13190, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20468, 13190, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20389, 13163, 188, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (20390, 13163, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (20581, 3110, 86, 9, 8);
INSERT INTO 'dancesformationsmap' VALUES (20488, 13198, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20501, 13203, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20502, 13203, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20505, 13205, 284, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20442, 13180, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20506, 13205, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20469, 13190, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20493, 13200, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20494, 13200, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20495, 13200, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20465, 13189, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20466, 13189, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20489, 13198, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20490, 13199, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20491, 13199, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20492, 13199, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20474, 13193, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20475, 13193, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20476, 13193, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20461, 13188, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20462, 13188, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20463, 13188, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20464, 13188, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20472, 13192, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20473, 13192, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20357, 13153, 27, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (20358, 13153, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (20454, 13186, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20455, 13186, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20456, 13186, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20478, 13194, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20479, 13194, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20480, 13194, 221, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20470, 13191, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20471, 13191, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20481, 13195, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20482, 13195, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20483, 13195, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20545, 13214, 216, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20546, 13214, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20498, 13201, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20503, 13204, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20504, 13204, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20499, 13202, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20500, 13202, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20434, 13178, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20435, 13178, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20436, 13178, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20452, 13185, 222, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20445, 13182, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20446, 13182, 386, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20407, 13170, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20408, 13170, 241, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20458, 13187, 241, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20459, 13187, 317, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20460, 13187, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20451, 13184, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20267, 13146, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (20268, 13146, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20264, 13145, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20265, 13145, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20266, 13145, 10, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20261, 13144, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20262, 13144, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (20263, 13144, 89, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20259, 13143, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20260, 13143, 110, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20275, 13148, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20276, 13148, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20247, 13140, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20248, 13140, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20255, 13142, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (20256, 13142, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20257, 13142, 225, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20270, 13147, 176, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20271, 13147, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20253, 13141, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20254, 13141, 75, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20453, 13185, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20622, 13007, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20623, 13007, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20624, 13007, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20625, 13007, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20626, 13038, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20627, 13038, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20628, 13038, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20629, 13038, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20630, 13038, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20631, 13039, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20632, 13039, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20633, 13039, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20634, 13039, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20635, 13039, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20636, 13039, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20637, 13040, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20638, 13040, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20639, 13040, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20640, 13041, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20641, 13041, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20642, 13041, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20643, 13041, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20654, 3230, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20655, 3230, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20656, 3230, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20657, 3230, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20658, 3230, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20667, 8701, 172, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20668, 8701, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20669, 13244, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20670, 13244, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20671, 13245, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20672, 13245, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20673, 13246, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20674, 13246, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20675, 13246, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20676, 13246, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20677, 13247, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20678, 13247, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20679, 13247, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20680, 13247, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20681, 13247, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20682, 13247, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20683, 13247, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20684, 13247, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20685, 13248, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20686, 13248, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20687, 13249, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20688, 13249, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20689, 13249, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20690, 7579, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20691, 7579, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20692, 7579, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20693, 7887, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20694, 7887, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20695, 7887, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20696, 7759, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20697, 7759, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20698, 7759, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20699, 7982, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20700, 7982, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20701, 7659, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20702, 7659, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20703, 7813, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20704, 7813, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20705, 7813, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20706, 7813, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20707, 7898, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20708, 7898, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20709, 7898, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20710, 7898, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20711, 7898, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20712, 7920, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20713, 7920, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20714, 7920, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20715, 7920, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20716, 7673, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20717, 7673, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20548, 5723, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20507, 13206, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20585, 13229, 112, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (20508, 13206, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (20486, 13197, 32, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (20487, 13197, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20659, 13080, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20718, 7673, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20719, 7673, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20720, 7991, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20721, 7991, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20722, 7991, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20723, 7991, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20724, 7991, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20725, 7806, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20726, 7806, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20727, 7806, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20728, 7806, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20729, 7832, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20730, 7832, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20731, 7832, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20732, 7832, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20733, 7996, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20734, 7996, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20735, 7996, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20736, 7706, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20737, 7706, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20738, 7706, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20739, 7799, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20740, 7799, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20741, 13027, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20742, 13027, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20743, 13023, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20744, 13023, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20745, 13023, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20746, 13023, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20747, 13026, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20748, 13026, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20749, 13024, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20750, 13024, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20751, 13024, 172, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20757, 13008, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20758, 13008, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20759, 13008, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20760, 13250, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20761, 13251, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20762, 13251, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20763, 13251, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20764, 13251, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20768, 13253, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20769, 13253, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20770, 13254, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20771, 13254, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20772, 13254, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20773, 13255, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20774, 13255, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20775, 13255, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20776, 13256, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20777, 13257, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20778, 13258, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20779, 13258, 141, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20780, 13258, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20781, 13258, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20782, 13258, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20783, 13258, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20784, 13258, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31475, 18256, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31476, 18256, 38, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31477, 18256, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (20799, 10611, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20800, 10611, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20801, 10611, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20802, 10612, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20803, 10613, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20804, 10613, 220, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20805, 10613, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20806, 10614, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20807, 10614, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20808, 10614, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20809, 10990, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20752, 13025, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20753, 13025, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20785, 7343, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20569, 13225, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20570, 13225, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20790, 3043, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20791, 3043, 265, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20793, 13269, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20794, 13269, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20795, 13269, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20796, 13269, 7, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31914, 18303, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31858, 13908, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31915, 18303, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20649, 13232, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20650, 13232, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20810, 10990, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20811, 10990, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20812, 10991, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20813, 10991, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20814, 10991, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20815, 10991, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20816, 10992, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20817, 10992, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20818, 10992, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20819, 10992, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20820, 10992, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20821, 10993, 175, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20822, 10993, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20823, 10993, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20865, 13279, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20866, 13279, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20867, 13279, 135, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20868, 13279, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20869, 13279, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20870, 13280, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20891, 1899, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20892, 1899, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20893, 1899, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20898, 2565, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20899, 2565, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20900, 2565, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20901, 2565, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20902, 8841, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20903, 8841, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20904, 8841, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20905, 8841, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20911, 4078, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20912, 4078, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20913, 4078, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20914, 4078, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20915, 4188, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20916, 4188, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20917, 4188, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20918, 4188, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20929, 5245, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20930, 5245, 229, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20931, 5245, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20932, 5245, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20933, 5273, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20848, 11807, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20877, 5720, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20835, 13274, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20836, 13274, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (20837, 13274, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20874, 13283, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20875, 13283, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20876, 13283, 225, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20660, 13233, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (20661, 13233, 220, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20662, 13233, 43, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (20663, 13233, 27, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (20644, 13230, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20645, 13230, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20646, 13230, 215, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20765, 13252, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20766, 13252, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20767, 13252, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20844, 10366, 224, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (20845, 10366, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20846, 10366, 265, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (20894, 2491, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20895, 2491, 185, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20896, 2491, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (20925, 5161, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20864, 2223, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20926, 5161, 202, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (20927, 5161, 183, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (20928, 5161, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (20919, 4278, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (20920, 4278, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20908, 3747, 173, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20909, 3747, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (20910, 3747, 71, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (20906, 3702, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20887, 1046, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20888, 1046, 224, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (20889, 1046, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20890, 1046, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20786, 13259, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20787, 13259, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20788, 13259, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20789, 13259, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20653, 9420, 28, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (20934, 5273, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20935, 5273, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20939, 5606, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20940, 5606, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20941, 5606, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20942, 5606, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20943, 5606, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20954, 7122, 72, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (20955, 7122, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20956, 7122, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31473, 18256, 23, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (31474, 18256, 224, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (20986, 13308, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20987, 13308, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20988, 13308, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20989, 13308, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6206, 7039, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31535, 2558, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (20872, 13282, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20873, 13282, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20921, 12320, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20922, 12320, 72, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (20923, 12320, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20924, 12320, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (20969, 13304, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20970, 13304, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20971, 13304, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20830, 13273, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (20831, 13273, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21000, 13311, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21001, 13311, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20832, 13273, 224, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (20859, 13277, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20860, 13277, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20861, 13277, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20853, 13218, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20854, 13218, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20857, 13218, 229, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20855, 13276, 82, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (20856, 13276, 145, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (20858, 13276, 229, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8065, 7825, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20972, 13305, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20841, 127, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (20842, 127, 183, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (20843, 127, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21005, 13312, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21006, 13312, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21007, 13312, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31536, 7825, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31537, 7825, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31854, 13908, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31856, 13908, 117, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21061, 2082, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21063, 6560, 221, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21070, 13333, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21071, 13333, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21072, 13333, 62, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21073, 13334, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21074, 13334, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21075, 13334, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21076, 13334, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21077, 13335, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21078, 13335, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21081, 9750, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21082, 9750, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21083, 9750, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21090, 9745, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21011, 13314, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21012, 13314, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (21013, 13314, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21039, 13323, 93, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (21040, 13323, 39, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21041, 13323, 32, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (21042, 13323, 58, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (21098, 13336, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21099, 13336, 62, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21100, 13336, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21101, 13336, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21102, 13336, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21103, 13337, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21104, 13337, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21105, 13337, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21106, 13337, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21108, 13339, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21109, 13340, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21110, 13340, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21111, 13340, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21112, 13340, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21113, 13340, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21114, 13341, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21115, 13341, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21116, 13341, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21117, 13342, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21118, 13342, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21119, 13342, 243, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21121, 13343, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21122, 13343, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21123, 13343, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21124, 13344, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20792, 4411, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21107, 13338, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21125, 13344, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21126, 13344, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21127, 13344, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21128, 13344, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21129, 13345, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21130, 13345, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21131, 13346, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21132, 13346, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21133, 13346, 156, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21140, 13349, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21027, 13320, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21022, 13318, 114, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21023, 13318, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20995, 13310, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21028, 13320, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20976, 13306, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20977, 13306, 249, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20978, 13306, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20996, 13310, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20997, 13310, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (20980, 13307, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20981, 13307, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20982, 13307, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20983, 13307, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (20967, 13303, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20968, 13303, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20960, 13301, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20961, 13301, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20962, 13301, 178, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20838, 13275, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20839, 13275, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20840, 13275, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20826, 13272, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (20827, 13272, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20828, 13272, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21089, 9584, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21086, 7385, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21087, 7385, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21088, 7385, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20948, 6586, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20949, 6586, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20950, 6586, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20944, 6025, 185, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20945, 6025, 45, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20946, 6025, 29, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (21066, 5836, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21067, 5836, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21068, 5836, 224, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21056, 4181, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21057, 4181, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21120, 4181, 243, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20936, 5549, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20937, 5549, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20938, 5549, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (20951, 3563, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (20952, 3563, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20953, 3563, 225, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (21060, 1096, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21058, 941, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21059, 941, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (20882, 807, 176, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20883, 807, 185, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (20884, 807, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21069, 765, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21141, 13349, 110, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21142, 13349, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21143, 13349, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21144, 13349, 72, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (21145, 13349, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21146, 13349, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21150, 3890, 243, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21169, 13373, 86, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (21170, 13373, 192, 4, 4);
INSERT INTO 'dancesformationsmap' VALUES (21024, 13319, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21084, 7438, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21177, 13578, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21025, 13319, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21026, 13319, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21032, 13321, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21178, 13578, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21179, 13578, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21180, 13578, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20862, 13278, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21015, 13316, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21016, 13316, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21002, 13311, 262, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21003, 13311, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21004, 13311, 62, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21017, 13316, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21018, 13316, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20863, 13278, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (21051, 13327, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21052, 13327, 296, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21033, 13321, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21043, 13324, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21044, 13324, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21045, 13324, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21046, 13325, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21047, 13325, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21048, 13325, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21049, 13326, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21050, 13326, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21092, 9572, 224, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21093, 9572, 183, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (21085, 7438, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21167, 13354, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21168, 13354, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21138, 13348, 200, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21139, 13348, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21204, 13605, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21205, 13605, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21206, 13605, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21210, 13612, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21211, 13612, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21212, 13612, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21213, 13612, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21214, 13612, 248, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21219, 13599, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21220, 13599, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21221, 13599, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21222, 13599, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21223, 13599, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21266, 619, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21267, 619, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21268, 619, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21269, 619, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21324, 13662, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21280, 13649, 13, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21281, 13649, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21282, 5891, 134, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21283, 5891, 192, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (21325, 13662, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21236, 13619, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21297, 13653, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21237, 13619, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21302, 13655, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21303, 13655, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21304, 13655, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21305, 13655, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21308, 13657, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21309, 13657, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21310, 13657, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21311, 13658, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21312, 13658, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21313, 13659, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21314, 13659, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21315, 13659, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21316, 13659, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21317, 13660, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21318, 13660, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21319, 13661, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21320, 13661, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21326, 13663, 184, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21327, 13663, 229, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21328, 13663, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21329, 13663, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21330, 13664, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21331, 13664, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21332, 13664, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21333, 13665, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21334, 13665, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21335, 13665, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21336, 13666, 203, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21337, 13666, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21338, 13667, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21339, 13667, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21340, 13668, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21147, 13350, 109, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21091, 9573, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (21292, 8991, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21293, 8991, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21294, 8991, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21134, 13347, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21135, 13347, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21153, 13351, 245, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21154, 13351, 244, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21171, 13547, 353, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21172, 13547, 121, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (21173, 13547, 234, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (21341, 13668, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21342, 13668, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21343, 13668, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21344, 13668, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21345, 13668, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21346, 13669, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21347, 13669, 101, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21348, 13670, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21349, 13670, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21350, 13670, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21351, 13670, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21352, 13672, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21353, 13672, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21354, 13672, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21161, 13353, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21162, 13353, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21008, 13313, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21009, 13313, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21163, 13353, 280, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21241, 13621, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21242, 13621, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (21243, 13621, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21244, 13621, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21152, 5500, 243, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21079, 9752, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21239, 13620, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21240, 13620, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (21232, 13617, 143, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21233, 13617, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21200, 13610, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (21201, 13610, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21202, 13610, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21203, 13610, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21229, 13604, 70, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21230, 13604, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21231, 13604, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21207, 13601, 81, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21208, 13601, 145, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21209, 13601, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (21181, 13602, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21182, 13602, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21183, 13602, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21186, 13598, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21187, 13598, 202, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21188, 13598, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21035, 13322, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21036, 13322, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (21037, 13322, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21151, 6965, 243, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9320, 7084, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21080, 9752, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21097, 9581, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21321, 8985, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21322, 8985, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21323, 8985, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21055, 6397, 365, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (21064, 1084, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21065, 1084, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21062, 942, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21355, 13673, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21356, 13673, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21357, 13673, 251, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21358, 13674, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21359, 13674, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21360, 13674, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21238, 13619, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21276, 13450, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21277, 13450, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (21295, 13652, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21296, 13652, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21289, 13650, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21290, 13650, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21291, 13650, 307, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21361, 13675, 85, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21250, 13628, 114, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21251, 13628, 166, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21246, 13626, 119, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21247, 13626, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21252, 13628, 31, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (21284, 13587, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21285, 13587, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21286, 13587, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21362, 13675, 183, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (21363, 13675, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21215, 13608, 249, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21298, 13654, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21299, 13654, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21300, 13654, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21216, 13608, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21217, 13608, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21218, 13608, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21224, 13606, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21225, 13606, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21226, 13606, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21261, 13645, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21262, 13645, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21263, 13645, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21264, 13645, 224, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (21227, 13609, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21228, 13609, 119, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (21414, 13680, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21415, 13680, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21416, 13680, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21272, 13647, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21273, 13647, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21402, 13522, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21403, 13522, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21404, 13522, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21455, 11833, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21456, 11833, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21457, 11834, 221, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21458, 11838, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21459, 11838, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21460, 11838, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21428, 13683, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21429, 13683, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21430, 13328, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21431, 13328, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21432, 13684, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21433, 13684, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21434, 13684, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21437, 13686, 25, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21438, 13686, 20, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21439, 13686, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21395, 13438, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21396, 13438, 71, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (21394, 13438, 272, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (21376, 13445, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21377, 13445, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21378, 13445, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31541, 7751, 119, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21467, 11849, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21468, 11849, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21469, 11849, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21471, 11855, 114, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (21472, 11855, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21473, 11855, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21474, 11857, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21475, 11857, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21476, 11860, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21477, 11859, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21478, 11865, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21479, 11865, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21483, 11160, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21484, 11160, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21488, 13707, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21489, 13707, 226, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21490, 13707, 62, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21491, 13708, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21492, 13708, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21493, 13708, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21494, 13708, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21499, 13710, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21500, 13710, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21501, 13710, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21423, 13681, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21234, 13618, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21364, 13676, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21365, 13676, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21189, 13600, 138, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21190, 13600, 186, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21191, 13600, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21418, 13589, 58, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21419, 13589, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21495, 13709, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (21496, 13709, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (21497, 13709, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21278, 13648, 317, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (21279, 13648, 250, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21255, 13640, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21256, 13640, 209, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21257, 13640, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21197, 13603, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21198, 13603, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21199, 13603, 114, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (21195, 13597, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (21196, 13597, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21480, 13596, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21481, 13596, 114, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (21512, 13424, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21517, 13378, 76, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (21159, 13352, 1, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (21371, 13447, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21372, 13447, 120, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21379, 13443, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21380, 13443, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21386, 13441, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21387, 13441, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21388, 13440, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21389, 13440, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21390, 13440, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21398, 13436, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21399, 13436, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21400, 13436, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21401, 13436, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (21531, 11874, 204, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21532, 11874, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (21533, 11874, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21539, 13703, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21540, 13703, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21541, 13703, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21528, 13702, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21521, 13380, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21522, 13380, 112, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21523, 13380, 58, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21524, 13380, 183, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (21525, 13380, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21529, 13702, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (21530, 13702, 32, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (21510, 13700, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21511, 13700, 119, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (21526, 13512, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21527, 13512, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21519, 13379, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21520, 13379, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21245, 6037, 30, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (21260, 13644, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21506, 13376, 225, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (21507, 13376, 66, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (21502, 13374, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21503, 13374, 39, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21504, 13374, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (21513, 13377, 143, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (21518, 9261, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (21514, 13377, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (21367, 13448, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21368, 13448, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21369, 13448, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31542, 7751, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21564, 13695, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21565, 13695, 18, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21566, 13695, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21567, 13695, 91, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21568, 1410, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21569, 1410, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21570, 1410, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21571, 3891, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21574, 13730, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21576, 13731, 185, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21577, 13731, 145, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21445, 13688, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21446, 13688, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21447, 13688, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21485, 13711, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21486, 13711, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21487, 13711, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21461, 13691, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21462, 13691, 192, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (21463, 11842, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21464, 11842, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (21465, 11842, 81, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21466, 11842, 183, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (21440, 13687, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21441, 13687, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31916, 18303, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23124, 14920, 134, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21442, 13687, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21443, 13687, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23125, 14920, 376, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (21508, 1204, 8, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21542, 13381, 265, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21543, 13381, 185, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (21544, 13381, 189, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (21509, 1204, 43, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (21288, 13587, 297, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (21451, 13690, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21452, 13690, 188, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (21453, 13690, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21470, 11850, 49, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21435, 13685, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21436, 13685, 109, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21551, 13706, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21552, 13706, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (21553, 13706, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21554, 13706, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (21575, 13730, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (31538, 7751, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31539, 7751, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31540, 7751, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21622, 13747, 119, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21695, 13832, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21662, 13816, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21705, 7862, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21706, 7862, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21707, 7862, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21708, 7862, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21716, 7103, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21717, 7103, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21718, 7103, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21728, 75, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21729, 75, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21634, 13805, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21696, 13832, 255, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21685, 13829, 111, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21686, 13829, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21687, 13829, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21763, 14288, 39, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21764, 14288, 176, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21765, 14288, 256, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21742, 14281, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21743, 14281, 117, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21692, 13831, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21746, 14282, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21747, 14282, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21750, 14283, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21751, 14283, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21748, 14282, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21752, 14284, 38, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21753, 14284, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21754, 14284, 90, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21680, 13827, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21681, 13827, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21758, 14286, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21759, 14286, 58, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21755, 14285, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21756, 14285, 273, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21757, 14285, 135, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21693, 13831, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21694, 13831, 4, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (21660, 13815, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21661, 13815, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21709, 4399, 221, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21710, 4399, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21620, 10624, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21621, 10624, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21697, 13832, 15, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21711, 4399, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21648, 13811, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21649, 13811, 255, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21650, 13811, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21658, 13814, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21659, 13814, 221, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21635, 13806, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21636, 13806, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21637, 13806, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21698, 13832, 373, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21639, 13808, 95, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (21640, 13808, 28, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (21641, 13808, 142, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (21642, 13809, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21643, 13809, 32, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (21644, 13809, 58, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (21645, 13810, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21646, 13810, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21647, 13810, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21730, 595, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (21731, 5682, 36, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21732, 5682, 82, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (21733, 5682, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21727, 5690, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21726, 2503, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (21721, 5469, 134, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (21722, 5469, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (21628, 868, 222, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21629, 868, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21667, 13818, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21668, 13818, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21669, 13818, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21448, 13689, 71, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21449, 13689, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21450, 13689, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21381, 13442, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21385, 13442, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21719, 5275, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (21720, 7080, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31861, 4741, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21578, 13732, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21715, 1273, 33, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (21579, 13732, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21632, 13807, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21633, 13807, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21616, 4223, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21410, 13679, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21411, 13679, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21405, 13677, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21581, 13733, 117, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21582, 13733, 1, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (21406, 13677, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21407, 13677, 224, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21688, 13830, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21689, 13830, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21690, 13830, 83, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21623, 12795, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21624, 12795, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (21625, 12795, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21613, 12364, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21614, 12364, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21615, 12364, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21482, 10469, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21546, 13704, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21547, 13704, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21557, 13705, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21558, 13705, 281, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (21555, 13513, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21556, 13513, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21735, 13376, 248, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (21734, 13374, 225, 51, 1);
INSERT INTO 'dancesformationsmap' VALUES (21741, 12971, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21738, 13377, 339, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21702, 13834, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (21703, 13834, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21704, 13834, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21626, 2364, 134, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21627, 2364, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21670, 13819, 235, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21651, 13812, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21652, 13812, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21653, 13812, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21671, 13819, 54, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21672, 13819, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21654, 13813, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21655, 13813, 22, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21656, 13813, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21760, 14287, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21761, 14287, 261, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21762, 14287, 193, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21737, 1204, 1, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (21590, 13735, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21886, 13355, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21723, 6295, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21725, 2853, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21610, 13740, 183, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (21611, 13740, 28, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21887, 13355, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21781, 7626, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21782, 7626, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21786, 3727, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21787, 3727, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21794, 14321, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21795, 14321, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21796, 14321, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21805, 13569, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21806, 13569, 35, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21807, 13569, 61, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (21815, 14323, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21816, 14323, 82, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21837, 14327, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21838, 14327, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21839, 14327, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21860, 13521, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21861, 13262, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21862, 13262, 4, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (21863, 13261, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21864, 13261, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21868, 13264, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21869, 13264, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21870, 13264, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21871, 13266, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21880, 13268, 193, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21881, 13268, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21803, 13730, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21804, 13730, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21929, 13975, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21930, 13975, 1, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (21931, 13975, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21932, 11285, 259, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21933, 14328, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21934, 14328, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21935, 14333, 262, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21936, 14333, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21937, 14333, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21939, 14055, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21940, 14055, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21941, 14055, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21942, 14055, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31543, 17432, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21827, 13364, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (21777, 14292, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21778, 14292, 78, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21779, 14292, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21767, 14289, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21768, 14289, 90, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21769, 14289, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21958, 14345, 18, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21959, 14345, 83, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21775, 14291, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21776, 14291, 81, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21872, 13267, 173, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21771, 14290, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21772, 14290, 87, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21773, 14290, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21848, 13362, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21849, 13362, 56, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (21972, 14351, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21963, 14348, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21964, 14348, 20, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21965, 14348, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21956, 14344, 77, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21957, 14344, 263, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21873, 13267, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21968, 14350, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21973, 14351, 30, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31544, 17432, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21824, 13359, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21825, 13359, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21826, 13359, 15, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21817, 14324, 257, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21818, 14324, 125, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21819, 14324, 103, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21811, 7296, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21822, 14325, 87, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21823, 14325, 192, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (21828, 14326, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21829, 14326, 192, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (21843, 13366, 83, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21833, 9676, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21834, 9676, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21835, 9676, 25, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21844, 13366, 23, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (21851, 13361, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21852, 13361, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21853, 13361, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21845, 13358, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21846, 13358, 16, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21847, 13358, 125, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21953, 14343, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (21900, 14332, 15, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21954, 14343, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21955, 14343, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21676, 13821, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21677, 13821, 94, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21951, 14342, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21678, 13821, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21947, 14341, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (21948, 14341, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21915, 14339, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21865, 13263, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21866, 13263, 64, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21867, 13263, 221, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21856, 13365, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21739, 13701, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21740, 13701, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21922, 13965, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21923, 13965, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21924, 13965, 30, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21903, 14337, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21938, 13984, 262, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21797, 14322, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21798, 14322, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21799, 14322, 43, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (21800, 14322, 85, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (21840, 13363, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21841, 13363, 188, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (21842, 13363, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21916, 14339, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21917, 14339, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21904, 14338, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21905, 14338, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21906, 14338, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21597, 13737, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21598, 13737, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21599, 13737, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21585, 13734, 199, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21586, 13734, 37, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21584, 13733, 220, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (21812, 7293, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21813, 7293, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21907, 11308, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21808, 3769, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21858, 13729, 42, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (21859, 13729, 84, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (21814, 7293, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21790, 6707, 3, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (21850, 13360, 70, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21809, 7289, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21810, 7289, 18, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21961, 14347, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21962, 14347, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31859, 4741, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31860, 4741, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21885, 14329, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21882, 13357, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21883, 13357, 114, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21966, 14349, 1, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (21967, 14349, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21918, 13964, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21919, 13964, 225, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21920, 13964, 224, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (21921, 13964, 106, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31545, 7775, 145, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31546, 7775, 49, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22050, 14390, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22051, 14390, 119, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22052, 14390, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22064, 14391, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22065, 14391, 7, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22409, 14418, 111, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (22073, 14395, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22074, 14395, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (1092, 2037, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4545, 2037, 202, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (3483, 6577, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6060, 6577, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7027, 6577, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1326, 2508, 117, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (4686, 2508, 28, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (22992, 2508, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22993, 2508, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (16890, 8197, 284, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22997, 14749, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22998, 14749, 9, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22999, 14749, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23000, 14749, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23001, 14749, 222, 47, 1);
INSERT INTO 'dancesformationsmap' VALUES (23002, 14749, 66, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (23003, 14749, 41, 113, 1);
INSERT INTO 'dancesformationsmap' VALUES (22027, 14366, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22028, 14366, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23012, 14742, 43, 17, 8);
INSERT INTO 'dancesformationsmap' VALUES (23013, 14742, 193, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (23014, 14742, 16, 37, 4);
INSERT INTO 'dancesformationsmap' VALUES (23015, 14742, 124, 41, 4);
INSERT INTO 'dancesformationsmap' VALUES (22060, 314, 157, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (22061, 9543, 157, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (22029, 14366, 30, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22100, 9675, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22101, 9675, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22102, 9675, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22042, 14388, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22043, 14388, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22037, 14375, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21997, 14355, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22095, 14399, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22096, 14399, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22097, 14399, 94, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22098, 14399, 22, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22099, 14399, 103, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22986, 14738, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22987, 14738, 283, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (22984, 14720, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22985, 14720, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22058, 9542, 157, 81, 4);
INSERT INTO 'dancesformationsmap' VALUES (22069, 14394, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22034, 14368, 168, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22017, 14363, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22066, 14392, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22067, 14392, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22018, 14363, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21990, 14357, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21991, 14357, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21992, 14357, 156, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21986, 14356, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22031, 14367, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22005, 14360, 156, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22006, 14360, 42, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (22007, 14360, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22062, 713, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22103, 14400, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22104, 14400, 158, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22035, 14368, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22070, 14394, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22071, 14394, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22032, 14367, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22033, 14367, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22012, 14362, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22013, 14362, 53, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22014, 14362, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21987, 14356, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21988, 14356, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21998, 14355, 126, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (21978, 14353, 33, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21979, 14353, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21980, 14353, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21981, 14353, 76, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21993, 14358, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21994, 14358, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21995, 14358, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (22008, 14360, 82, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (21969, 14350, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21970, 14350, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21971, 14350, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22036, 14368, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22075, 14396, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22076, 14396, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22077, 14396, 28, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (22078, 14396, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22020, 14364, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22021, 14364, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22022, 14364, 240, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22023, 14364, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22002, 14359, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22003, 14359, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22004, 14359, 42, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (22009, 14361, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22010, 14361, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22011, 14361, 48, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21999, 14355, 43, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (22000, 14355, 61, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (23016, 14742, 229, 69, 1);
INSERT INTO 'dancesformationsmap' VALUES (23017, 14742, 176, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (11972, 9013, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23021, 9013, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22285, 14439, 27, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (22286, 14439, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22287, 14439, 76, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (8342, 7745, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8343, 7745, 117, 45, 2);
INSERT INTO 'dancesformationsmap' VALUES (12242, 7745, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22857, 14243, 283, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22063, 694, 157, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21714, 313, 29, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (23006, 14744, 157, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23007, 14744, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (22068, 14393, 92, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22038, 3244, 259, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21783, 4904, 356, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21784, 4904, 28, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17957, 11284, 283, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22053, 5952, 157, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22054, 5952, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22994, 13847, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22995, 13847, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21857, 13365, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22045, 14389, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22046, 14389, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17077, 11985, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21897, 14331, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21898, 14331, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21899, 14331, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21983, 14354, 227, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21984, 14354, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21985, 14354, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22079, 14249, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22039, 14386, 78, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22040, 14386, 28, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22041, 14386, 8, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (22080, 14397, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22081, 14397, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22082, 14397, 189, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (22024, 14365, 142, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22025, 14365, 82, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (22088, 4366, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22059, 11195, 157, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22089, 4366, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (23004, 14750, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23005, 14750, 186, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22988, 14739, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22989, 14739, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22990, 14739, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22084, 14398, 82, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (22085, 14398, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22086, 14398, 42, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (9358, 8970, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (9359, 8970, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (9360, 8970, 286, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16115, 8970, 214, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5667, 5403, 75, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6914, 5403, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23022, 7745, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23023, 7745, 224, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23024, 7745, 127, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23025, 7745, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23027, 14799, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23028, 14799, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23029, 14799, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4042, 542, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23032, 13466, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23033, 13466, 42, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (23034, 13466, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22698, 14634, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22699, 14634, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22700, 14634, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23142, 14926, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23143, 14926, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23144, 14926, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23049, 14811, 268, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23050, 14811, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23051, 14811, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23052, 14811, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23053, 14812, 164, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23054, 14812, 287, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (23055, 14812, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23056, 14812, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23057, 14812, 48, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23059, 4847, 94, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23060, 4847, 183, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (23061, 4847, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (23062, 4847, 61, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31549, 7828, 8, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (416, 743, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2333, 4433, 96, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (5346, 4433, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23063, 4433, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2672, 5111, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23065, 5111, 32, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (21925, 13580, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21926, 13580, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21927, 13580, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21928, 13580, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (23066, 13138, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23067, 13138, 61, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (23068, 13138, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23069, 13138, 85, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (20562, 13223, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20563, 13223, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20564, 13223, 224, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (20565, 13223, 62, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23072, 14891, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23073, 14891, 66, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23074, 14891, 27, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (23075, 14891, 72, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (23076, 14891, 23, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (22279, 14437, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22280, 14437, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23080, 14437, 269, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23081, 14437, 7, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23082, 14439, 263, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7288, 7433, 26, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7289, 7433, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23090, 14910, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23091, 14910, 86, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23092, 14911, 30, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23093, 14911, 288, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23094, 14911, 289, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23098, 14913, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23099, 14913, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23100, 14913, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23101, 14913, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23102, 14914, 27, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23103, 14914, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (23104, 14914, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23105, 14915, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23106, 14915, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23107, 14915, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23108, 14916, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23109, 14916, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23110, 14916, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23111, 14916, 33, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23112, 14916, 134, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (23117, 14918, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23118, 14918, 293, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23119, 14919, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23120, 14919, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23121, 14919, 86, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (23131, 14922, 235, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23132, 14922, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23133, 14924, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23134, 14924, 132, 16, 1);
INSERT INTO 'dancesformationsmap' VALUES (23135, 14924, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23136, 14924, 286, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23145, 14927, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11968, 8158, 158, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23038, 8158, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20824, 13270, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20825, 13270, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (23070, 14890, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23071, 14890, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23077, 14892, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (23078, 14892, 43, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (23064, 4434, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23039, 14809, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23040, 14809, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23041, 14809, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23095, 14912, 290, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23096, 14912, 291, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3302, 6267, 172, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23083, 6267, 7, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (23043, 14810, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23044, 14810, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23045, 14810, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18237, 12520, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18238, 12520, 165, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18239, 12520, 29, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (18240, 12520, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23084, 6267, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23085, 6267, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31917, 18304, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1177, 2222, 285, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23020, 2222, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23113, 14917, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23114, 14917, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23115, 14917, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18802, 7311, 262, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23058, 7311, 183, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (23097, 14912, 292, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23137, 14925, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23138, 14925, 43, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (23139, 14925, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23140, 14925, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23126, 14921, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23127, 14921, 184, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23129, 14921, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (23146, 14927, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23147, 14927, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23148, 14928, 184, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23149, 14928, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23150, 14929, 93, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23151, 14929, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8569, 8704, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23156, 14931, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23157, 14931, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23158, 14931, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (1966, 3725, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5104, 3725, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23161, 3725, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23164, 13092, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23165, 13092, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23166, 13092, 30, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23167, 13093, 7, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (23168, 13093, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23169, 13093, 30, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (31547, 7828, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23174, 13095, 86, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (21248, 13627, 81, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (21249, 13627, 228, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23175, 13095, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23176, 13095, 30, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23177, 13096, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23178, 13096, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23179, 13097, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23180, 13098, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23086, 14909, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23087, 14909, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23088, 14909, 29, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (23089, 14909, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4639, 2353, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6551, 2353, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31862, 4741, 249, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31863, 4741, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22026, 14365, 42, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (7798, 8166, 1, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (7799, 8166, 165, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7800, 8166, 52, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23048, 8166, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (23181, 13098, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23182, 13098, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23183, 13098, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23184, 13098, 8, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (31548, 7828, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31550, 7828, 341, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23285, 522, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (23195, 14932, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23196, 14932, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23197, 14933, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23198, 14933, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23199, 14933, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (23200, 14933, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23201, 14933, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23202, 14934, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23203, 14934, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23204, 14934, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23205, 14935, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23206, 14935, 127, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23207, 14935, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (23208, 14935, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23209, 14936, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23210, 14936, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23211, 14936, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23212, 14937, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (23213, 14937, 27, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (23214, 14937, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23215, 14938, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23216, 14938, 286, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (23217, 14939, 184, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (23218, 14939, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23219, 14939, 160, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (222, 392, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3987, 392, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23222, 392, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9818, 5100, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9819, 5100, 119, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9820, 5100, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23223, 5100, 294, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (2748, 5262, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5620, 5262, 294, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16559, 5262, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23224, 8782, 38, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23225, 8782, 93, 5, 8);
INSERT INTO 'dancesformationsmap' VALUES (23226, 8782, 43, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (23227, 8782, 209, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23228, 8782, 1, 37, 4);
INSERT INTO 'dancesformationsmap' VALUES (23229, 8782, 220, 65, 3);
INSERT INTO 'dancesformationsmap' VALUES (23230, 8782, 32, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (23231, 14940, 54, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23232, 14940, 111, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23233, 14940, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23234, 14940, 58, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (23235, 14940, 192, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (23236, 14940, 62, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (19447, 12838, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19448, 12838, 263, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19449, 12838, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23241, 14611, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23242, 14611, 112, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (23243, 14611, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23244, 14611, 93, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (23245, 14610, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23246, 14610, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23247, 14610, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23248, 14610, 123, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21454, 13690, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (3189, 6057, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23250, 13757, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23251, 13757, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23252, 13757, 18, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23253, 13757, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23249, 6287, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23273, 14974, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23274, 14975, 105, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23275, 14975, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23277, 14975, 9, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23279, 14976, 92, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23281, 14976, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23282, 14977, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23283, 14977, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23284, 3165, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23286, 14978, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23287, 14978, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23278, 14976, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23190, 13101, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (92, 152, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23291, 14980, 94, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23292, 14980, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23293, 14980, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23294, 14980, 43, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (3812, 7182, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23240, 7182, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13677, 8998, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (13678, 8998, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23260, 14548, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23261, 14548, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23153, 14930, 127, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23154, 14930, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23155, 14930, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23159, 13090, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23160, 13090, 157, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23162, 13091, 269, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23237, 14941, 33, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (23163, 13091, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23152, 13099, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23185, 13099, 133, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23191, 13101, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13120, 10166, 235, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13121, 10166, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23238, 14941, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3082, 5885, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23192, 13102, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23193, 13102, 86, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5837, 5885, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23295, 14981, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23296, 14981, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23297, 14981, 43, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (22338, 14518, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22339, 14518, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23378, 15047, 246, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23379, 15047, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23380, 15047, 235, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31551, 7828, 119, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (23345, 15003, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23346, 15003, 82, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23347, 15003, 228, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23348, 15003, 168, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23351, 15020, 279, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23352, 15020, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (23353, 15020, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (23354, 15020, 42, 24, 4);
INSERT INTO 'dancesformationsmap' VALUES (23387, 15053, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23388, 15053, 142, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23389, 15053, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23390, 15054, 159, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23391, 15054, 280, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23392, 15054, 246, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9166, 8743, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9167, 8743, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10557, 8932, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1756, 3337, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13012, 10482, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23186, 13100, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23187, 13100, 375, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13013, 10482, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10558, 8932, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10559, 8932, 82, 26, 2);
INSERT INTO 'dancesformationsmap' VALUES (23410, 56, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (23302, 3337, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21424, 13681, 185, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (21425, 13681, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12601, 10428, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23220, 13103, 1, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (23221, 13103, 8, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (23329, 14994, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23330, 14994, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (1830, 3463, 77, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5006, 3463, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14468, 11170, 32, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12602, 10428, 71, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23239, 10428, 294, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22057, 6532, 157, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (23265, 6532, 133, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (23288, 14979, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23289, 14979, 119, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23256, 14942, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23257, 14942, 260, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23258, 14942, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3579, 6756, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (6121, 6756, 59, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21426, 13681, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12104, 5438, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7699, 2934, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23393, 13364, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23404, 15057, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23405, 15057, 58, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23406, 15057, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23407, 50, 112, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23408, 50, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23409, 50, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23414, 118, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23415, 118, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23416, 14546, 192, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23417, 14546, 29, 17, 6);
INSERT INTO 'dancesformationsmap' VALUES (8970, 7061, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8971, 7061, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9905, 7061, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23418, 14977, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23427, 15075, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23428, 15075, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23429, 15075, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23430, 15075, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23434, 15077, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23435, 15077, 43, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (23436, 15077, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23437, 15078, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23438, 15078, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23439, 15078, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23440, 15079, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23441, 15080, 160, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23442, 15080, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23443, 15080, 58, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23444, 15080, 58, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (23445, 15080, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23446, 15080, 49, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (23447, 15081, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23448, 15081, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23449, 15081, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23450, 15082, 9, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (23451, 15082, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23452, 15083, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23453, 15083, 59, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23454, 15083, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23455, 15084, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23456, 15084, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23457, 15084, 185, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23458, 15085, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23459, 15085, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23460, 15085, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23461, 15086, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23462, 15086, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23463, 15086, 58, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23464, 15086, 58, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (23361, 15022, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23356, 14382, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23382, 15051, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23349, 6150, 43, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (23340, 2602, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23341, 2602, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (23372, 14741, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23373, 14741, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23374, 14741, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23375, 14741, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23411, 13629, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23412, 13629, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19770, 12941, 228, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23298, 14982, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19771, 12941, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19772, 12941, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23381, 15048, 159, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23383, 15051, 235, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23307, 13586, 36, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (23355, 14955, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23308, 14986, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23299, 14983, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23300, 14983, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23301, 14983, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23384, 15051, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23376, 15044, 42, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (23357, 14382, 112, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (23413, 13629, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23316, 14988, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23465, 15087, 134, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23362, 15022, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23363, 15022, 188, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (23309, 14986, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23423, 15074, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23424, 15074, 29, 10, 2);
INSERT INTO 'dancesformationsmap' VALUES (23425, 15074, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23426, 15074, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23317, 14988, 30, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23318, 14988, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23325, 14993, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23326, 14993, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (23327, 14993, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23328, 14993, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23312, 14987, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23313, 14987, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23314, 14987, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23315, 14987, 134, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (23332, 14346, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23333, 14346, 296, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23334, 14346, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23335, 14346, 295, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23303, 14984, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23304, 14984, 21, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23305, 14984, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23306, 14984, 32, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (23310, 14986, 53, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13972, 10919, 297, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23358, 14382, 87, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23359, 14382, 183, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (23377, 15046, 159, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (714, 1323, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (4306, 1323, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6438, 1323, 297, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23339, 5060, 297, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23419, 5060, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23420, 5060, 276, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (23421, 5060, 32, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (23360, 15021, 188, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (23368, 15021, 72, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (23319, 14989, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23320, 14989, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31552, 7589, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23473, 15088, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23474, 15088, 84, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (23475, 15088, 84, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (23476, 15089, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23477, 15089, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23481, 15091, 112, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23482, 15091, 36, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23483, 15091, 36, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23484, 15092, 7, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23485, 15092, 92, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23486, 15092, 92, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (23487, 15092, 33, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23488, 15092, 7, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23489, 15092, 7, 29, 3);
INSERT INTO 'dancesformationsmap' VALUES (23494, 15094, 39, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23495, 15094, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23499, 15096, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23500, 15096, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23501, 15096, 28, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (23502, 15096, 72, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23503, 15096, 103, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (23504, 15096, 5, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (23505, 15096, 143, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (23506, 15096, 23, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (23507, 15096, 85, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (23508, 15096, 25, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (23509, 15096, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (23510, 2388, 43, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (23511, 2388, 23, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (23513, 10649, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (23514, 10649, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23515, 10649, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23516, 15057, 299, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31557, 17529, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31553, 7681, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11824, 4618, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23542, 15125, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23543, 15125, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23544, 15125, 283, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10680, 8515, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2267, 4309, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6797, 4309, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23431, 15076, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31864, 5438, 249, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9906, 4015, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23269, 4015, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (23254, 13771, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23255, 13771, 168, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (23385, 15052, 30, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23386, 15052, 246, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23394, 15055, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23532, 633, 87, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (23432, 15076, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23433, 15076, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23490, 15093, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23491, 15093, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23492, 15093, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23321, 14991, 260, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23322, 14991, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10682, 8515, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10683, 8515, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10681, 8515, 76, 18, 2);
INSERT INTO 'dancesformationsmap' VALUES (794, 1473, 83, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (10328, 1473, 154, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (7601, 1473, 32, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (23549, 1473, 183, 23, 4);
INSERT INTO 'dancesformationsmap' VALUES (23550, 1473, 225, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23551, 116, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23552, 116, 82, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (23554, 15131, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23555, 15131, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15272, 11543, 114, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (15273, 11543, 92, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15274, 11543, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23556, 11543, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (23557, 15133, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23558, 15133, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23559, 15133, 4, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (23560, 15134, 39, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23561, 15134, 183, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (23562, 15135, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23563, 15135, 58, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (23564, 15135, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23568, 15137, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23569, 15137, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31554, 7681, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31555, 7681, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31556, 7681, 85, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23582, 15142, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23583, 15142, 156, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23584, 15143, 112, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23585, 15143, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23586, 15144, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23587, 15144, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (23588, 15144, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23592, 15146, 15, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23593, 15146, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (23594, 15147, 112, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23595, 15147, 281, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (23596, 15147, 78, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14449, 11184, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14796, 11376, 117, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (14797, 11376, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (23601, 615, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23598, 410, 303, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15585, 11586, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15586, 11586, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23605, 14541, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23606, 14541, 43, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (23607, 12699, 154, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (23608, 12699, 23, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (23609, 12699, 93, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (23610, 12699, 305, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (23611, 12699, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23576, 15140, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23577, 15140, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23578, 15140, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23536, 7362, 152, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23546, 15128, 58, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (23547, 15128, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23548, 15128, 300, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23539, 14271, 302, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (23540, 14271, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (23599, 462, 32, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (23600, 462, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23541, 14271, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2433, 4644, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23520, 7415, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23525, 15098, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23526, 15098, 9, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23527, 15098, 152, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20957, 13300, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20958, 13300, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20959, 13300, 125, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23565, 15136, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23566, 15136, 112, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (23567, 15136, 202, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (12667, 10433, 69, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (23466, 15087, 134, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (22298, 14482, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22299, 14482, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23602, 14484, 7, 1, 12);
INSERT INTO 'dancesformationsmap' VALUES (23603, 14484, 260, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23604, 14484, 43, 24, 2);
INSERT INTO 'dancesformationsmap' VALUES (23524, 4925, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23570, 15138, 176, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23571, 15138, 259, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23572, 15138, 59, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10215, 9583, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23537, 9583, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23538, 9583, 7, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (21736, 1204, 41, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (23496, 15095, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23497, 15095, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23545, 195, 296, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23553, 15129, 183, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (31561, 7686, 23, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (23733, 6, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23734, 6, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23635, 15153, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23636, 15153, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23654, 15159, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23655, 15159, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23656, 15159, 162, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23657, 15159, 92, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23658, 15160, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23659, 15160, 91, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23660, 15160, 78, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23661, 15161, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23662, 15161, 112, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23663, 15161, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23664, 15161, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23665, 15161, 28, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23680, 15168, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23681, 15169, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23682, 15169, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23683, 15169, 9, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23684, 15170, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23685, 15170, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23686, 15170, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23687, 15170, 9, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23688, 15171, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23689, 15171, 19, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23690, 15171, 119, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23695, 15173, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23696, 15173, 91, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23697, 15173, 92, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23698, 15174, 119, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23699, 15174, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23700, 15174, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23701, 15175, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23702, 15175, 84, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23719, 5277, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23720, 3131, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23721, 3131, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7166, 4310, 53, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7167, 4310, 9, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23724, 4310, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14268, 1375, 125, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23725, 694, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23521, 498, 158, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23522, 498, 7, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (23523, 498, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23740, 5628, 7, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (23638, 15154, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23512, 15097, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23533, 14247, 69, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23534, 14247, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23744, 7705, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23745, 7705, 134, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (23746, 7705, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23747, 3646, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23782, 1192, 29, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (13381, 10563, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13382, 10563, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23612, 209, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23613, 209, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23614, 209, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23597, 292, 32, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23573, 15139, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23574, 15139, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23575, 15139, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23615, 14818, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23616, 14818, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (23617, 14818, 123, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (23589, 15145, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23590, 15145, 92, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (23591, 15145, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (31865, 3403, 224, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16743, 11970, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16744, 11970, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23619, 15148, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23620, 15148, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23621, 15148, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23751, 12023, 299, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17146, 12023, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23754, 4470, 43, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (23755, 4470, 38, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23756, 4814, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23757, 4814, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23758, 4814, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23759, 3654, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23760, 3654, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (161, 287, 185, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23763, 287, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23764, 287, 120, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23765, 4822, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23766, 4822, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23767, 4822, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23773, 8357, 121, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23774, 8357, 120, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (11575, 9631, 131, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15755, 9631, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8157, 105, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8158, 105, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23641, 15155, 74, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23642, 15155, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23643, 15156, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23644, 15156, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23645, 15156, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23666, 15162, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23667, 15162, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31918, 18304, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (31919, 18304, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23784, 10650, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23785, 10650, 42, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (23786, 10650, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23787, 10650, 7, 25, 8);
INSERT INTO 'dancesformationsmap' VALUES (23788, 10650, 23, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (23789, 9381, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23790, 9381, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23791, 14295, 134, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (23792, 14295, 18, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23793, 14295, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31920, 18304, 36, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (23717, 3188, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (23718, 3188, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23714, 15180, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23715, 15180, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23716, 15180, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23703, 15176, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (938, 1743, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (12395, 10390, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12396, 10390, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12397, 10390, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23669, 15163, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23670, 15163, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23775, 4065, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31921, 18304, 48, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (28212, 16702, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23761, 6448, 184, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23762, 6448, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (28213, 16702, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23727, 2056, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23728, 2056, 202, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23729, 2056, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23730, 2056, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (4110, 699, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23622, 699, 12, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23632, 15152, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23633, 15152, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23634, 15152, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23704, 15176, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23705, 15176, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23709, 15178, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23776, 4065, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23650, 15158, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23651, 15158, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23783, 7197, 189, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (23777, 1781, 1, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (23778, 1781, 67, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23779, 1781, 72, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (14492, 10703, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14493, 10703, 148, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23276, 14975, 43, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (23280, 14976, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11795, 10316, 109, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11796, 10316, 77, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11797, 10316, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11798, 10316, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31558, 7686, 84, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7572, 314, 120, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23801, 314, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23802, 314, 39, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (23806, 15182, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23807, 15182, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23808, 15182, 111, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23812, 15184, 8, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (23813, 15184, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23814, 15184, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (31559, 7686, 188, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (31560, 7686, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23826, 15188, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23827, 15188, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13627, 10787, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13628, 10787, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23833, 10787, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23841, 15190, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23842, 15190, 176, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23844, 15192, 1, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (23845, 15192, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23849, 15194, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23850, 15194, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (23851, 15194, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23852, 15194, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23862, 15197, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23863, 15197, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23864, 15197, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23865, 15197, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23870, 15200, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23871, 15200, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23872, 15200, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23873, 15200, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23883, 15203, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23884, 15203, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23885, 15203, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23886, 15203, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23732, 4975, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23738, 2315, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23794, 159, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23795, 159, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (540, 975, 27, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (4205, 975, 43, 19, 3);
INSERT INTO 'dancesformationsmap' VALUES (23772, 3065, 301, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1490, 2822, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23749, 3492, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23750, 2688, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23768, 2525, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23769, 2525, 224, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (31866, 3403, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31867, 3403, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13192, 3866, 365, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13193, 3866, 23, 34, 1);
INSERT INTO 'dancesformationsmap' VALUES (20280, 627, 265, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (20281, 627, 114, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (23741, 6798, 39, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23742, 6798, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23726, 6774, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14418, 6148, 72, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (23752, 6148, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23753, 6148, 64, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (22047, 14389, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22048, 14389, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23834, 14674, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23835, 14674, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23853, 15195, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23854, 15195, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23855, 15195, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23876, 15202, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23877, 15202, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23878, 15202, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23879, 15202, 66, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23857, 15196, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23858, 15196, 132, 3, 12);
INSERT INTO 'dancesformationsmap' VALUES (23859, 15196, 86, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (23860, 15196, 2, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23861, 15196, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23735, 13555, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23736, 13555, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23737, 13555, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23710, 15179, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23711, 15179, 105, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2106, 3988, 183, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (23780, 5730, 32, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (23781, 5730, 39, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (23887, 15203, 19, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23918, 15208, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23919, 15209, 23, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (23920, 15209, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23921, 15209, 168, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23922, 15209, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23937, 15213, 55, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23938, 15213, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23939, 15213, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23940, 15213, 176, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23941, 15213, 1, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (23942, 15213, 39, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (23943, 15213, 157, 61, 4);
INSERT INTO 'dancesformationsmap' VALUES (23944, 15214, 27, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (23945, 15214, 111, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23946, 15214, 61, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (23951, 15216, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23837, 14239, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23838, 14239, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23839, 14239, 64, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23955, 15218, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23956, 15218, 300, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7429, 7420, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7430, 7420, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23915, 15207, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23916, 15207, 183, 18, 1);
INSERT INTO 'dancesformationsmap' VALUES (23917, 15207, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23923, 15210, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23924, 15210, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12301, 8569, 114, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (23799, 8569, 359, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20230, 13118, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20231, 13118, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20232, 13118, 7, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (23818, 15186, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23803, 15181, 143, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23804, 15181, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23805, 15181, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23819, 15186, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23820, 15186, 303, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23843, 15191, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11434, 10232, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11435, 10232, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23797, 10232, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23874, 15201, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23875, 15201, 183, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (23798, 1100, 184, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23809, 15183, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23828, 15189, 269, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23829, 15189, 132, 2, 48);
INSERT INTO 'dancesformationsmap' VALUES (23830, 15189, 303, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23831, 15189, 7, 12, 1);
INSERT INTO 'dancesformationsmap' VALUES (23928, 15211, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23929, 15211, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23930, 15211, 251, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23840, 14239, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23810, 15183, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23811, 15183, 8, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (16351, 11830, 280, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23959, 11830, 286, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23960, 11830, 263, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23800, 8569, 184, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (10929, 7349, 83, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23966, 14465, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23967, 14465, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23972, 3176, 30, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (8116, 6978, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23974, 6978, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23975, 6978, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (23976, 6384, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23985, 14022, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23986, 14022, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23987, 14022, 30, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23988, 14022, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23999, 6250, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24000, 6250, 9, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (24005, 15220, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24006, 15220, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24007, 15221, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24008, 15221, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24019, 15225, 33, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24020, 15225, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24021, 15225, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24022, 15225, 224, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24026, 15227, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24027, 15227, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (24028, 15227, 145, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24029, 15227, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23989, 5898, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23990, 5898, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23991, 5898, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23992, 5898, 23, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (24042, 41, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24043, 41, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24044, 41, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13978, 10921, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13979, 10921, 56, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24065, 1060, 20, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (24069, 15263, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24070, 15263, 29, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (24071, 10926, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24072, 2168, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19653, 12893, 62, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (24077, 6451, 189, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (24078, 6451, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24079, 6451, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24086, 15265, 240, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24087, 15265, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24088, 15265, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23637, 15153, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23668, 15162, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24095, 15162, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17320, 12107, 29, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (17321, 12107, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23910, 1077, 175, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31868, 3566, 96, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (31869, 3566, 317, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (23909, 950, 78, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23898, 9929, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (23899, 9929, 43, 10, 2);
INSERT INTO 'dancesformationsmap' VALUES (23900, 9929, 112, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (23901, 9929, 183, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (23911, 1077, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (23957, 3320, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23984, 3472, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23907, 306, 33, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (23908, 306, 36, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (9691, 6188, 112, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9692, 6188, 58, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10158, 9560, 69, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10159, 9560, 61, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23888, 9940, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (23889, 9940, 15, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (23890, 9940, 17, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23891, 9940, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13588, 10774, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13589, 10774, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13590, 10774, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23639, 15154, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23640, 15154, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12198, 8513, 365, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23395, 15055, 298, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23396, 15055, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23397, 15055, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13089, 10367, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23983, 10367, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23961, 339, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23962, 339, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31870, 3566, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24112, 15270, 154, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (24098, 15267, 27, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (24099, 15267, 154, 13, 5);
INSERT INTO 'dancesformationsmap' VALUES (24100, 15267, 93, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (24108, 15269, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24109, 15269, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24110, 15269, 93, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (23973, 5688, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19106, 2518, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23934, 15212, 55, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23935, 15212, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23936, 15212, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23846, 15193, 308, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23847, 15193, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23866, 15198, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23867, 15198, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23912, 15206, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23913, 15206, 23, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (23947, 15215, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23948, 15215, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23949, 15215, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24009, 15222, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24010, 15222, 282, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23994, 15219, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23995, 15219, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23996, 15219, 313, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24059, 3782, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24060, 3782, 69, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23963, 4246, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23964, 4246, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24049, 15229, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (23998, 2711, 314, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (24011, 15223, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9520, 9109, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24066, 9109, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (24067, 9109, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24014, 15224, 43, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (24094, 7197, 82, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (24081, 13585, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24082, 13585, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24083, 13585, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24084, 13585, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24104, 15268, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24105, 15268, 61, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (24106, 15268, 285, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24107, 15268, 17, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (12478, 9160, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12479, 9160, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24050, 15229, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23977, 3509, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (23978, 3509, 43, 45, 2);
INSERT INTO 'dancesformationsmap' VALUES (24055, 15231, 235, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24051, 15230, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24056, 15231, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24057, 15231, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (24058, 15231, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24089, 15266, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24052, 15230, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24053, 15230, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24090, 15266, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24001, 5462, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24002, 5462, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24003, 5462, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24054, 15230, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24101, 2531, 183, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (24102, 2531, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24103, 2531, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (7137, 4356, 33, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (24030, 15228, 368, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (24031, 15228, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24032, 15228, 315, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24091, 15266, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24037, 13464, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19617, 12884, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19618, 12884, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24015, 15224, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24092, 15266, 189, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24012, 15223, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24013, 15223, 145, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19619, 12884, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24016, 15224, 310, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (23979, 3509, 23, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (23980, 3509, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (24116, 5786, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (11587, 9543, 38, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (24123, 4881, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24124, 7473, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (24125, 7473, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24126, 7473, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24127, 15273, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24128, 15273, 154, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24129, 15273, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24130, 15274, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24131, 15274, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24132, 15274, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24133, 15274, 82, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (24134, 15274, 134, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24135, 15274, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24142, 15278, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24143, 15278, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24144, 15278, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24145, 15279, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24146, 15280, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24147, 15280, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24148, 15280, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24155, 15282, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24156, 15283, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24157, 15283, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24158, 15283, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (24159, 15284, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24167, 3636, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24168, 3636, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24172, 6629, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24176, 3021, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24177, 3021, 265, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24178, 3021, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21724, 6295, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24200, 2853, 131, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21612, 13740, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24210, 14996, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24216, 14998, 78, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24217, 14999, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24218, 14999, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24226, 15001, 154, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24227, 15001, 306, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24228, 15001, 157, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24229, 15002, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24230, 15002, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24232, 15017, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24231, 15002, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24233, 15017, 17, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24234, 15017, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24244, 15006, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24245, 15006, 119, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (24246, 15007, 189, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24249, 15009, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24250, 15009, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24256, 15012, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24257, 15012, 71, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24258, 15013, 36, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24117, 13076, 222, 5, 8);
INSERT INTO 'dancesformationsmap' VALUES (24152, 15282, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24153, 15282, 184, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24276, 6255, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24277, 6255, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24278, 6255, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24279, 9390, 42, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (24190, 428, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24286, 1559, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24287, 1559, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (13955, 10913, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24292, 9948, 41, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (24191, 428, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (24004, 5232, 313, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24035, 4209, 32, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (24036, 4209, 43, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (24187, 13579, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24188, 13579, 303, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (107, 183, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24169, 183, 188, 10, 2);
INSERT INTO 'dancesformationsmap' VALUES (6574, 2593, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (24073, 2593, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24074, 2593, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19257, 7935, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19258, 7935, 27, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (24096, 7935, 303, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24097, 7935, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24041, 5830, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (23965, 7065, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24289, 13983, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24290, 13983, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24291, 13983, 8, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (10841, 7738, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (10842, 7738, 81, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (10843, 7738, 7, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24068, 10570, 374, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (24080, 3770, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24269, 7075, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24281, 15333, 168, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24300, 15337, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24301, 15337, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24302, 15337, 123, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (24288, 13278, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (24173, 3616, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24199, 161, 189, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (24121, 15272, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24122, 15272, 86, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (22867, 14244, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24208, 14244, 23, 19, 4);
INSERT INTO 'dancesformationsmap' VALUES (24045, 3561, 38, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (24038, 12368, 154, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (24039, 12368, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (24040, 12368, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24179, 9011, 299, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24075, 8203, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24023, 15226, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24211, 14995, 322, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24061, 15248, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24062, 15248, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24063, 15248, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24024, 15226, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24025, 15226, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24160, 15285, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24161, 15285, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24285, 1942, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24198, 15330, 306, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24139, 15277, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24140, 15277, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (24192, 14472, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (24193, 14472, 302, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (24239, 15005, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24180, 15313, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24181, 15313, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24235, 15004, 172, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24236, 15004, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24293, 14813, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24294, 14813, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24306, 7104, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24136, 15275, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24137, 15275, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24237, 15004, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24213, 14997, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24214, 14997, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24215, 14997, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14471, 11216, 27, 8, 2);
INSERT INTO 'dancesformationsmap' VALUES (24282, 15333, 188, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24254, 15011, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24255, 15011, 48, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24251, 15010, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24252, 15010, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24253, 15010, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24262, 15015, 142, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24296, 15336, 13, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24297, 15336, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24298, 15336, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24118, 15271, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24119, 15271, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24120, 15271, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24182, 15313, 72, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (24174, 3607, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (11365, 9816, 54, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (11366, 9816, 162, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24280, 9816, 36, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (24138, 15276, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24221, 15000, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24222, 15000, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24223, 15000, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24283, 15333, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24195, 15329, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24272, 11590, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24196, 15329, 7, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24204, 15332, 250, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24205, 15332, 19, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24206, 15332, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24209, 9166, 183, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (24247, 15008, 162, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24194, 11360, 234, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (24248, 15008, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24162, 15286, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24197, 15329, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24240, 15005, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24241, 15005, 157, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24242, 15005, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24303, 15338, 154, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24304, 15338, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24305, 15338, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24163, 15286, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24164, 15286, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24310, 9641, 29, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (24311, 9641, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12319, 8514, 273, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24324, 13133, 189, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (24325, 13133, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24326, 13133, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24330, 679, 29, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (24331, 679, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24085, 15265, 234, 7, 4);
INSERT INTO 'dancesformationsmap' VALUES (24352, 15380, 23, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24353, 15380, 43, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24354, 15380, 183, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24355, 15381, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24356, 15382, 164, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24357, 15383, 69, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24358, 15383, 43, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24359, 15383, 29, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24360, 15384, 43, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24361, 15384, 193, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24362, 15385, 87, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24363, 15385, 43, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24364, 15386, 23, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24365, 15386, 189, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24366, 15386, 69, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24367, 15387, 127, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24368, 15387, 85, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24374, 15390, 43, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24375, 15390, 69, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24376, 15390, 9, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24377, 15390, 189, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24378, 15391, 168, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24379, 15391, 183, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24380, 15391, 76, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24381, 15391, 42, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24382, 15392, 42, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24383, 15393, 183, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24384, 15393, 202, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24385, 15393, 69, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24386, 15394, 183, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24387, 15394, 43, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24388, 15395, 183, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24389, 15395, 162, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24390, 15395, 87, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24391, 15395, 193, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24392, 15395, 1, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24393, 15395, 176, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24394, 15396, 90, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24395, 15396, 43, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24396, 15396, 84, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24397, 15396, 38, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24401, 15398, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24402, 15398, 157, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24403, 15398, 7, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24407, 14014, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24408, 14014, 190, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11836, 9473, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11837, 9473, 65, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24409, 9473, 190, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19266, 1749, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24411, 1749, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24412, 15400, 29, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24413, 15400, 17, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24414, 15400, 76, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24415, 15400, 222, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24416, 15400, 42, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24424, 4715, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24264, 15016, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4474, 1817, 119, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24447, 1817, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (3722, 7019, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24446, 3257, 46, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (13145, 10504, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24202, 15331, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24426, 2315, 7, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24427, 2315, 7, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24201, 313, 301, 19, 8);
INSERT INTO 'dancesformationsmap' VALUES (24417, 2276, 82, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (24419, 4863, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24420, 4863, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24448, 15407, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24449, 15407, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24450, 15407, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24429, 5628, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24346, 15378, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24347, 15378, 90, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (24149, 15281, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24150, 15281, 319, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24151, 15281, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24313, 15358, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24314, 15358, 8, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (24315, 15358, 143, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24316, 15358, 23, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (31872, 3566, 69, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24343, 5807, 248, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (24458, 5894, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24464, 3137, 317, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24468, 15359, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24469, 15359, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24470, 15359, 203, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24433, 15402, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22578, 14597, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24431, 15401, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24432, 15401, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24461, 4920, 95, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24266, 15178, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24327, 13134, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24404, 15399, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24328, 13134, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24329, 13134, 85, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24175, 3608, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24465, 6393, 43, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (24259, 15014, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24260, 15014, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11242, 10088, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24410, 10069, 190, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11243, 10088, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24321, 13132, 69, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (24322, 13132, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24466, 6393, 157, 38, 4);
INSERT INTO 'dancesformationsmap' VALUES (24467, 6393, 38, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (24334, 15374, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24425, 2294, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24336, 15374, 222, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24456, 6555, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24457, 6555, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24430, 1277, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24459, 2746, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24350, 15379, 43, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (24351, 15379, 29, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (24460, 5558, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24263, 15015, 94, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24462, 4920, 78, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24405, 15399, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24398, 15397, 1, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24399, 15397, 23, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24370, 15389, 82, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24371, 15389, 262, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24372, 15389, 119, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (24451, 6859, 36, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24270, 1876, 36, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (24471, 1025, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24472, 1025, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24473, 1025, 27, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24337, 15375, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24338, 15375, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24307, 7104, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24308, 7104, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24271, 4553, 317, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2481, 4749, 84, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24452, 4464, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24453, 4464, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24454, 1227, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24455, 1227, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24312, 14363, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24463, 2927, 43, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24434, 15402, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24318, 13135, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24319, 13135, 32, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (24267, 4514, 36, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24268, 4514, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24483, 4514, 33, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24484, 4514, 36, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24491, 10479, 222, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13011, 10481, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24493, 10485, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24494, 10485, 225, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24495, 10485, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13025, 10486, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13026, 10486, 92, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24496, 10487, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24500, 10455, 42, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (24508, 14998, 78, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24219, 14999, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24220, 14999, 91, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24509, 15001, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31562, 12148, 185, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24515, 15002, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24516, 15017, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24523, 15007, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24265, 15016, 123, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24530, 15016, 20, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24531, 15016, 42, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24532, 15016, 123, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31563, 12148, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31564, 12148, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31565, 12148, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24525, 816, 42, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (9184, 8734, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9185, 8734, 76, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (24543, 12035, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24544, 12035, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24545, 12035, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24546, 12035, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24547, 12035, 111, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24611, 12051, 265, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24553, 12037, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24554, 12037, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24555, 12037, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24556, 12037, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24557, 12037, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24563, 12038, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24564, 12038, 203, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24565, 12038, 203, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24566, 12038, 262, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24567, 12038, 262, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24568, 12039, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24569, 12039, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24570, 12039, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24571, 12039, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24572, 12039, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24573, 12040, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24574, 12040, 225, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24575, 12040, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24576, 12040, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24580, 12041, 185, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (24581, 12041, 91, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24582, 12041, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24583, 12041, 7, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (24584, 12041, 32, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (24585, 12042, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24586, 12042, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24587, 12042, 164, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24588, 12042, 164, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24589, 12042, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24590, 12043, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24591, 12043, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24592, 12043, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24612, 12051, 7, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (24613, 12051, 5, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (24593, 12044, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24594, 12044, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24595, 12044, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24596, 12045, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24597, 12045, 133, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (24598, 12045, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24599, 12046, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24600, 12046, 183, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (24601, 12046, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24602, 12047, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24603, 12048, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24604, 12048, 286, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24605, 12049, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24606, 12049, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24607, 12049, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24608, 12049, 119, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (24609, 12050, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24610, 12050, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24615, 8978, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (10116, 9546, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24616, 9546, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24617, 9546, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24621, 15415, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24478, 13934, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24443, 15406, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13014, 10482, 53, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24339, 15376, 240, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24340, 15376, 123, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24341, 15376, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24559, 12020, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24560, 12020, 42, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (24561, 12020, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24562, 12020, 42, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24422, 4873, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24423, 7065, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (18209, 11105, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24344, 11105, 23, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (7621, 3299, 43, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (7622, 3299, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (24474, 3323, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24444, 15406, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24438, 15404, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24439, 15404, 265, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (31873, 3566, 234, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (24482, 3436, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31874, 3566, 1, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (24622, 15415, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24623, 15416, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24624, 15416, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24625, 15416, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24634, 15420, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24635, 15420, 221, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11116, 10048, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24558, 10048, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24541, 15180, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24542, 15180, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (24626, 15417, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13001, 10477, 225, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24489, 10477, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24093, 1551, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24475, 4821, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24517, 15004, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24506, 14997, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24548, 12036, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24549, 12036, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24550, 12036, 52, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24243, 15005, 224, 6, 2);
INSERT INTO 'dancesformationsmap' VALUES (24485, 4708, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24539, 13365, 325, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24497, 10488, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23713, 15179, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (24212, 14995, 42, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (24501, 14995, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (24528, 15010, 325, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24529, 15015, 325, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24435, 15403, 188, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24490, 10478, 154, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24627, 15417, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24510, 15412, 43, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (24511, 15412, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24224, 15000, 29, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (24225, 15000, 186, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24512, 15412, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24513, 15412, 69, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24618, 15414, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24488, 4553, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5434, 4707, 18, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24487, 4707, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24619, 15414, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24620, 15414, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24518, 15005, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24519, 15005, 1, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (24520, 15005, 157, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (24524, 15008, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24533, 15178, 144, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24534, 15178, 110, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24636, 15420, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24637, 15421, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24638, 15421, 214, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24639, 15421, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24640, 6894, 23, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (24647, 15424, 92, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24648, 15424, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24649, 15424, 70, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (24650, 15424, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24652, 15027, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24653, 15027, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24654, 12248, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24655, 12248, 326, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31566, 12148, 249, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31567, 12148, 193, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (17338, 2521, 43, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (24664, 15426, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24665, 15426, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23031, 542, 302, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (8559, 8699, 328, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24668, 8699, 183, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (24669, 10588, 252, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24666, 3650, 197, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24785, 15479, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (15421, 10594, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (15422, 10594, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18046, 12481, 327, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18047, 12481, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24697, 15448, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24698, 15448, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24699, 15447, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24700, 15447, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24670, 12481, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24746, 15456, 279, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24710, 15442, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24747, 15456, 82, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24748, 15456, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24744, 15450, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24745, 15450, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24749, 5752, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8016, 8410, 131, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24753, 8410, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15523, 11480, 5, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (24774, 15470, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24775, 15470, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24776, 15470, 251, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24780, 15472, 85, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (24781, 15472, 28, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (24782, 15472, 171, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (24783, 15478, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24784, 15478, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24795, 15494, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (16157, 11763, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (16158, 11763, 30, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (16159, 11763, 134, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (24661, 5667, 55, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (24662, 5667, 157, 31, 8);
INSERT INTO 'dancesformationsmap' VALUES (24755, 15457, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24756, 15457, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24757, 15457, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23262, 14548, 77, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24683, 7874, 90, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24684, 7874, 23, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (24685, 7874, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (23263, 14548, 53, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23264, 14548, 32, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (24791, 8987, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24792, 8987, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24793, 8987, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24643, 14604, 13, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24644, 14604, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19179, 8048, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24799, 15526, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24754, 11375, 363, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18366, 10595, 247, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (24730, 15437, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24732, 15435, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24733, 15435, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24734, 15435, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24629, 15419, 93, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24630, 15419, 220, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18873, 4716, 53, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2327, 4424, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24772, 4424, 42, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (24773, 4424, 111, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (24486, 4716, 202, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24694, 12397, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24695, 12397, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24696, 12397, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24717, 15431, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24711, 15441, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24712, 15441, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24737, 15436, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24738, 15436, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24739, 15436, 9, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (24498, 15411, 183, 19, 3);
INSERT INTO 'dancesformationsmap' VALUES (24499, 15411, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24750, 13638, 183, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (24577, 9336, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16039, 11720, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24631, 15419, 72, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (16040, 11720, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24578, 9336, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24579, 9336, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9036, 8088, 109, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9037, 8088, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24727, 15438, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24767, 15460, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24768, 15460, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24769, 15460, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9873, 9418, 84, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (24731, 15437, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24706, 15443, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24707, 15443, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24708, 15443, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24788, 15480, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24800, 15526, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24789, 15480, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24790, 15480, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24671, 15427, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24672, 15427, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24673, 15427, 143, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24656, 15425, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24657, 15425, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (24658, 15425, 83, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24794, 8987, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24714, 15440, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24715, 15440, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24716, 15440, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24722, 15439, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24667, 3715, 197, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24702, 15452, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24703, 15452, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24704, 15452, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24723, 15439, 170, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24724, 15439, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24796, 15483, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24705, 15452, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24763, 15459, 83, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24764, 15459, 2, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24765, 15459, 154, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24701, 15446, 225, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24797, 15483, 324, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24798, 15483, 331, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24803, 15527, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24812, 15540, 8, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (24728, 15434, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24729, 15434, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24691, 13755, 386, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24692, 13755, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24693, 13755, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (24641, 15422, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24642, 15422, 112, 40, 1);
INSERT INTO 'dancesformationsmap' VALUES (24476, 5730, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (24813, 15540, 76, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (24814, 15540, 170, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (24815, 15540, 1, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (24816, 15540, 72, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (12128, 488, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24651, 15027, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24817, 1158, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24819, 15541, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24820, 15541, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24821, 15541, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24824, 15543, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24825, 15543, 36, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24826, 15543, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24827, 15543, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24828, 15544, 119, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24829, 15545, 171, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24830, 15545, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24831, 15546, 217, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24832, 15546, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24833, 15546, 50, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24834, 15547, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24835, 15547, 217, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24836, 15548, 65, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24837, 15548, 186, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24842, 15550, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24843, 15550, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24844, 15550, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24845, 15550, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24846, 15550, 157, 161, 1);
INSERT INTO 'dancesformationsmap' VALUES (24847, 15550, 193, 193, 1);
INSERT INTO 'dancesformationsmap' VALUES (24955, 15577, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24861, 15554, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24862, 15554, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24863, 15554, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24864, 15555, 306, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24865, 15555, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24866, 15556, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24867, 15556, 162, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24868, 15557, 49, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24869, 15557, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24870, 15557, 10, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24874, 15559, 92, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24875, 15559, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24876, 15560, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24877, 15560, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24878, 15560, 263, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24879, 15561, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24880, 15561, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24881, 15562, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24882, 15562, 39, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24883, 15562, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24884, 15562, 328, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (24885, 15563, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24886, 15563, 157, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24887, 8930, 1, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (24888, 8930, 183, 19, 3);
INSERT INTO 'dancesformationsmap' VALUES (24889, 8930, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5946, 6214, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24890, 6214, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24899, 15565, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24900, 15565, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24901, 15565, 303, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24902, 15565, 217, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24903, 15565, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24904, 15565, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24956, 15577, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24957, 15577, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24931, 5711, 27, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (24932, 5711, 1, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (24933, 5711, 23, 11, 16);
INSERT INTO 'dancesformationsmap' VALUES (24934, 5711, 183, 12, 4);
INSERT INTO 'dancesformationsmap' VALUES (24935, 5711, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24936, 8576, 58, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24937, 8576, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24938, 8576, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24941, 4334, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21274, 13647, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (21275, 13647, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24964, 13595, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24965, 13595, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24966, 13595, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24967, 13595, 7, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (20085, 13083, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24946, 15575, 234, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (24947, 15575, 87, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24804, 14183, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24805, 14183, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (24808, 5696, 47, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24809, 5696, 317, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (24948, 15575, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24949, 15575, 29, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (24911, 15569, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24917, 15571, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24918, 15571, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24920, 15572, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24921, 15572, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24922, 15572, 111, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24908, 15567, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24678, 15430, 75, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (24679, 15430, 202, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24924, 15573, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24925, 15573, 203, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24915, 15570, 159, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24916, 15570, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24686, 15444, 55, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (24687, 15444, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24688, 15444, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24909, 15568, 72, 20, 2);
INSERT INTO 'dancesformationsmap' VALUES (24910, 15568, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24822, 15542, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24823, 15542, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24680, 15430, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (24713, 15441, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24751, 13638, 27, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24752, 13638, 43, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24726, 12437, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24770, 15460, 8, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (16469, 11894, 188, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (24852, 15552, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24853, 15552, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24807, 15539, 220, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16470, 11894, 189, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (24857, 15553, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24858, 15553, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24859, 15553, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24860, 15553, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24682, 11894, 234, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24950, 15576, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24951, 15576, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24952, 15576, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24953, 15576, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24871, 15558, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24872, 15558, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24873, 15558, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24838, 15549, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24839, 15549, 119, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24840, 15549, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24841, 15549, 123, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24848, 15551, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24849, 15551, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24850, 15551, 76, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (24977, 6633, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24978, 6633, 189, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24806, 15538, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24939, 5463, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24940, 5463, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24970, 10327, 8, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (24971, 10327, 333, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24974, 1187, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24801, 15526, 23, 10, 2);
INSERT INTO 'dancesformationsmap' VALUES (24802, 15526, 216, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24979, 15600, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24980, 15600, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24981, 15600, 92, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24891, 13624, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24892, 13624, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24973, 15481, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24982, 15619, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24983, 15619, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24984, 15619, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24985, 15619, 154, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (24989, 15623, 27, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24991, 15623, 183, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (24990, 15623, 9, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24992, 5386, 9, 7, 4);
INSERT INTO 'dancesformationsmap' VALUES (24993, 5386, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24994, 5386, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (12483, 8336, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12484, 8336, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24995, 12335, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24996, 12335, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (24986, 15621, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24987, 15621, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24926, 15341, 55, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24927, 15341, 332, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (24893, 15564, 27, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (24972, 15590, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24894, 15564, 42, 2, 0);
INSERT INTO 'dancesformationsmap' VALUES (24997, 12335, 81, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24998, 12335, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24999, 12335, 157, 31, 4);
INSERT INTO 'dancesformationsmap' VALUES (25001, 3536, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24943, 5596, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24944, 5596, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24945, 5596, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25022, 10419, 268, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25042, 11991, 183, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (25043, 2494, 189, 18, 4);
INSERT INTO 'dancesformationsmap' VALUES (25044, 2494, 131, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24154, 15282, 8, 10, 5);
INSERT INTO 'dancesformationsmap' VALUES (25045, 15413, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (25046, 15413, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25047, 15413, 8, 21, 4);
INSERT INTO 'dancesformationsmap' VALUES (25048, 15413, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25049, 13884, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25050, 13884, 29, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (25051, 12796, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (25052, 12796, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25053, 12796, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25054, 12796, 76, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (25055, 12796, 119, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (25056, 15678, 327, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25057, 15678, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25058, 15678, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25066, 9761, 154, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (25067, 6381, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25068, 6381, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (25069, 13567, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (25070, 13567, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25071, 13567, 76, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (31571, 12157, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (25095, 10693, 8, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (25096, 10693, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25097, 10693, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25098, 10693, 111, 18, 1);
INSERT INTO 'dancesformationsmap' VALUES (25099, 13462, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25100, 13462, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31572, 12157, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24988, 15622, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25114, 15703, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25115, 15703, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25116, 15703, 49, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25117, 15703, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25006, 12635, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (25010, 10288, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18808, 7313, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (18809, 7313, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (13728, 10824, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (25000, 6052, 7, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (25126, 15707, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25127, 15707, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25128, 15707, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24442, 15405, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15973, 8482, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8873, 5179, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24436, 15403, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15974, 8482, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25122, 15705, 156, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25123, 15705, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25124, 15705, 84, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25125, 15705, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25108, 15701, 94, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25109, 15701, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25059, 873, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25072, 15684, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25073, 15684, 154, 29, 3);
INSERT INTO 'dancesformationsmap' VALUES (25082, 15465, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25083, 15465, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17613, 12124, 225, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25110, 15701, 61, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25060, 873, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17614, 12124, 93, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (25041, 12124, 55, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (25101, 15163, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24437, 15403, 186, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24975, 1696, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (25091, 9288, 333, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (25092, 9288, 255, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25024, 15656, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24905, 15566, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24906, 15566, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24907, 15566, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25007, 15652, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25008, 15652, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25009, 15652, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (25034, 15654, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25035, 15654, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25036, 15654, 123, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25015, 7943, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (25016, 7943, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25017, 7943, 83, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (25018, 7943, 19, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25064, 6532, 234, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24968, 15589, 48, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (24969, 15589, 119, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (25061, 68, 183, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (25004, 13644, 313, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24960, 15579, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24961, 15579, 71, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1787, 3388, 24, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24976, 3388, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24962, 15579, 85, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24963, 15579, 43, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (25025, 15631, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9874, 9418, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25026, 15631, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25027, 15631, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25085, 15697, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25086, 15697, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25087, 15697, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (2890, 5529, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11735, 5529, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18810, 7313, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18817, 7316, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24675, 15428, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24676, 15428, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24677, 15428, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25062, 11282, 334, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7733, 29, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7734, 29, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25112, 15702, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25088, 9287, 16, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25089, 9287, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (25090, 9287, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7108, 3441, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7115, 7284, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7116, 7284, 56, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (7117, 7284, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25113, 15702, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31568, 12157, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31569, 12157, 123, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5451, 4759, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25102, 15698, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25103, 15698, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22929, 14712, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22930, 14712, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (22931, 14712, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (31570, 12157, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31573, 12346, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31574, 12346, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25200, 15727, 105, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25175, 15719, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25176, 15719, 20, 0, 4);
INSERT INTO 'dancesformationsmap' VALUES (25177, 15719, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23706, 15177, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25201, 15727, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25178, 15720, 82, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25179, 15721, 5, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25180, 15721, 183, 0, 3);
INSERT INTO 'dancesformationsmap' VALUES (25181, 15722, 84, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25182, 15722, 58, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25183, 15722, 133, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25132, 15709, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (25133, 15709, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25134, 15709, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22835, 14693, 77, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22836, 14693, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25135, 14693, 154, 29, 3);
INSERT INTO 'dancesformationsmap' VALUES (25184, 15723, 133, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25185, 15723, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25186, 15724, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5877, 5992, 55, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (25023, 5992, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25118, 15704, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25119, 15704, 386, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25039, 15659, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25040, 15659, 213, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25120, 15704, 93, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (25078, 15686, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25079, 15686, 132, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (25080, 15686, 175, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8825, 4075, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (25038, 4075, 299, 1, 12);
INSERT INTO 'dancesformationsmap' VALUES (25011, 14216, 93, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (25012, 14216, 43, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (25013, 14216, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25014, 14216, 145, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (25002, 15285, 355, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22852, 14688, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8792, 3300, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3059, 5842, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12271, 5842, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25141, 5842, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16154, 11763, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16155, 11763, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16156, 11763, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21914, 11763, 258, 43, 2);
INSERT INTO 'dancesformationsmap' VALUES (14481, 11219, 45, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14482, 11219, 240, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14483, 11219, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25187, 15724, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25188, 15724, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25189, 15724, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25190, 15724, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24183, 15314, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24184, 15314, 7, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (24185, 15314, 10, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (24186, 15314, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25191, 15725, 321, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25192, 15725, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25193, 15725, 248, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25194, 15725, 168, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25195, 15725, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25196, 15725, 249, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25129, 15708, 203, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (25130, 15708, 145, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25131, 15708, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25234, 15738, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25235, 15738, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25145, 10962, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25146, 10962, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24440, 15405, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24441, 15405, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (15972, 8482, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25150, 15713, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25151, 15713, 36, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25152, 15713, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (25153, 13429, 225, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25154, 13429, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25155, 13429, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25156, 13429, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25157, 13435, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25158, 13434, 1, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25159, 13434, 309, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25160, 13434, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25161, 15714, 83, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25162, 15715, 321, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25163, 15715, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25164, 15715, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25165, 15715, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25166, 15716, 139, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25167, 15716, 202, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25168, 15716, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25169, 15716, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25170, 15717, 309, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25171, 15717, 119, 0, 3);
INSERT INTO 'dancesformationsmap' VALUES (25172, 15717, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25173, 15718, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25174, 15718, 184, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15008, 11483, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15009, 11483, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15010, 11483, 93, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (15011, 11483, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25218, 15732, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25219, 15732, 84, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (25220, 15734, 314, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25221, 15734, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25222, 15734, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25223, 15735, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25224, 15735, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25225, 15735, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25226, 15735, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25227, 15736, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25228, 15736, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25229, 15736, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25230, 15736, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25238, 15739, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25239, 15739, 202, 0, 3);
INSERT INTO 'dancesformationsmap' VALUES (25244, 15741, 112, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (23707, 15177, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23708, 15177, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25207, 15729, 125, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25208, 15729, 65, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25147, 15684, 313, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25236, 15738, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25237, 15738, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25240, 15740, 145, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25241, 15740, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25242, 15740, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6851, 4759, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3551, 6709, 183, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (25003, 12426, 313, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (25074, 15685, 19, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25075, 15685, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (1549, 2947, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (4838, 2947, 165, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25076, 15685, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (12771, 2110, 189, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (12772, 2110, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21391, 13439, 93, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (21392, 13439, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25209, 15730, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25210, 15730, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25211, 15730, 162, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25213, 14680, 192, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25214, 14680, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25005, 13644, 168, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25063, 14017, 334, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25142, 6709, 189, 5, 6);
INSERT INTO 'dancesformationsmap' VALUES (25143, 6709, 93, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (25104, 15698, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22853, 14688, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22854, 14688, 281, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25136, 14688, 1, 29, 4);
INSERT INTO 'dancesformationsmap' VALUES (25105, 15698, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (8793, 3300, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23194, 4759, 75, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8794, 3300, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25245, 15741, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25246, 15741, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25247, 14740, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (25248, 14740, 64, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25249, 14740, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (25250, 14740, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25251, 15742, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25252, 15742, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25253, 15742, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25254, 15743, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25255, 15743, 162, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25256, 15743, 93, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25257, 15743, 214, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25258, 15744, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25259, 15744, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25260, 15744, 222, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25261, 15745, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25262, 15745, 249, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25263, 15745, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25264, 15745, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25265, 15746, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25266, 15746, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25267, 15746, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25271, 15748, 184, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25272, 15748, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25273, 15749, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25274, 15749, 249, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25275, 15749, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25276, 15749, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25277, 15749, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25278, 15749, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25279, 15750, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25280, 15750, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25281, 15751, 8, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25282, 15751, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25283, 15752, 224, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25284, 15752, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25285, 15752, 184, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25286, 15753, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25287, 15753, 8, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25288, 15754, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25289, 15754, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25290, 15755, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25291, 15755, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25292, 15755, 221, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25293, 15756, 93, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25294, 15756, 72, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25137, 15710, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11216, 10079, 56, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25202, 15728, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25203, 15728, 52, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25215, 15733, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25216, 15733, 74, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (25217, 15733, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8730, 2228, 27, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (8731, 2228, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25231, 15737, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (25232, 15737, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25233, 15737, 309, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25295, 15756, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25296, 15756, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25297, 15757, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25298, 15757, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25299, 15758, 184, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25300, 15758, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25301, 15759, 189, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25302, 15759, 188, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25303, 15759, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25304, 15760, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25305, 15760, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25306, 15760, 314, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25307, 15760, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25308, 15760, 96, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25309, 15760, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25310, 15761, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25311, 15761, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25312, 15761, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31575, 12346, 93, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (20878, 13299, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (20879, 13299, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20880, 13299, 186, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20881, 13299, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25339, 15770, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25340, 15770, 105, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (25341, 15770, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31576, 12346, 22, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10787, 9900, 317, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (1908, 3616, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5061, 3616, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6711, 3616, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3919, 161, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6261, 7182, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10925, 9967, 20, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10926, 9967, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10927, 9967, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (11115, 10048, 24, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (25327, 15767, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25328, 15767, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25329, 15767, 314, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (25330, 15767, 77, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7553, 7180, 117, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (22295, 7180, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (789, 1466, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4357, 1466, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25313, 15762, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25314, 15762, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25315, 15762, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25317, 15763, 30, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25318, 15763, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3474, 6566, 134, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (6053, 6566, 36, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (22454, 14557, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (22455, 14557, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18806, 7313, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18807, 7313, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3767, 7104, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25331, 15768, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31875, 9418, 5, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14758, 11366, 185, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7774, 6912, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7775, 6912, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7776, 6912, 55, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (42, 73, 317, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (6294, 73, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25354, 15774, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (25355, 15774, 225, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25356, 15774, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18874, 12729, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18875, 12729, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18876, 12729, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25319, 15764, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25320, 15764, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25321, 15764, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12485, 10392, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12486, 10392, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12487, 10392, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11017, 9998, 265, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (11018, 9998, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11019, 9998, 72, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (25324, 15766, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25325, 15766, 29, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (25326, 15766, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25357, 15775, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25358, 15775, 248, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (25359, 15775, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19269, 8085, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19270, 8085, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19271, 8085, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19272, 8085, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25342, 15771, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25323, 15765, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25343, 15771, 22, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25344, 15771, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (25362, 15776, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25363, 15776, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25364, 15776, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25365, 15776, 125, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (25335, 15769, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25336, 15769, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25337, 15769, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25345, 15771, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (25347, 15772, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25348, 15772, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25351, 15773, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25352, 15773, 78, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25353, 15773, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8964, 6834, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8965, 6834, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25148, 15323, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25149, 15323, 313, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25332, 15768, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24309, 7104, 123, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10788, 9900, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10789, 9900, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10790, 9900, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10791, 9900, 24, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (766, 1426, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25412, 5122, 330, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25413, 5122, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (25379, 15788, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25380, 15789, 144, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25381, 15789, 133, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25477, 15830, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25478, 15830, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25479, 15830, 26, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25372, 15785, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25403, 15797, 273, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25404, 15797, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25389, 15793, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25390, 15793, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25391, 15793, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25392, 15793, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25393, 15793, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25394, 15794, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25395, 15794, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25396, 15794, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25397, 15794, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25398, 15794, 201, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25399, 15795, 144, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25400, 15795, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25401, 15795, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25402, 15796, 144, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25405, 15798, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25406, 15798, 273, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25407, 15799, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25408, 15799, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25409, 15799, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25410, 15799, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25411, 15799, 1, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25366, 1466, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25470, 15828, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25471, 15828, 193, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25416, 15800, 324, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25417, 15800, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25418, 15800, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25419, 15800, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25420, 15801, 324, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25421, 15801, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25426, 15803, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25427, 15803, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25428, 15803, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25429, 15803, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25430, 15804, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25431, 15804, 324, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25434, 15806, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25435, 15806, 296, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25436, 15807, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25437, 15807, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25438, 15807, 296, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25439, 15808, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25440, 15808, 280, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25441, 15808, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25442, 15808, 42, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25443, 15809, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25444, 15809, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25445, 15809, 87, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25450, 15811, 1, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (31579, 12349, 216, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31580, 12349, 224, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (11217, 10079, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11218, 10079, 235, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31581, 12349, 220, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (31582, 12349, 8, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (25414, 1600, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25415, 1600, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17611, 12124, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25451, 15822, 314, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25452, 15822, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25453, 15822, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25460, 15825, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25461, 15825, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25454, 15823, 78, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25455, 15823, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25462, 15825, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10398, 9711, 176, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25467, 15827, 42, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25468, 15827, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25469, 15827, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25503, 15839, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25504, 15839, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25505, 15839, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25507, 15840, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25508, 15840, 267, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25509, 15840, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25510, 15841, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25511, 15841, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25512, 15841, 32, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25523, 15845, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25524, 15845, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25525, 15845, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25526, 15845, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22405, 14542, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17612, 12124, 42, 18, 1);
INSERT INTO 'dancesformationsmap' VALUES (25446, 15810, 86, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25447, 15810, 9, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25472, 15828, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25384, 15791, 29, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25385, 15791, 93, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25367, 15784, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25368, 15784, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25373, 15785, 224, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25374, 15785, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25375, 15785, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25448, 15810, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25449, 15810, 296, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25499, 15837, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25463, 15826, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25464, 15826, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (25465, 15826, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10399, 9711, 112, 21, 8);
INSERT INTO 'dancesformationsmap' VALUES (25480, 15831, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25481, 15831, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25482, 15831, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25490, 15834, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25491, 15834, 65, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25520, 15844, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25521, 15844, 36, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25522, 15844, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25527, 15846, 91, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25528, 15846, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25513, 15842, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25514, 15842, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25515, 15842, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25500, 15838, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25501, 15838, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31577, 18263, 186, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31578, 18263, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25502, 15838, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15424, 10593, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15425, 10593, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18202, 10593, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25377, 15787, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25378, 15787, 73, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25506, 13458, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22420, 12279, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22421, 12279, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25473, 15829, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25474, 15829, 142, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22422, 12279, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25495, 15836, 45, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25496, 15836, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25497, 15836, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25492, 15835, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25493, 15835, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25494, 15835, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25483, 15832, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25484, 15832, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25485, 15832, 333, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25487, 15833, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25488, 15833, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25376, 15786, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25432, 15805, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25433, 15805, 296, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25422, 15802, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25423, 15802, 56, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25424, 15802, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25532, 12228, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25533, 12228, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25534, 12228, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (25535, 12206, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25536, 12206, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25537, 12206, 134, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (21373, 13446, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21374, 13446, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21375, 13446, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17974, 12451, 117, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17975, 12451, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22406, 14542, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22407, 14542, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25538, 15849, 1, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25539, 15849, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25540, 15850, 184, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25541, 15850, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25542, 15850, 96, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25543, 15850, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25544, 15851, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25545, 15851, 156, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25546, 15851, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25552, 15853, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25553, 15853, 306, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25558, 15855, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25559, 15855, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25560, 15855, 32, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25561, 15856, 45, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25562, 15856, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25563, 15856, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25564, 15856, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25565, 15857, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25566, 15857, 27, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25567, 15857, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25568, 15858, 324, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25569, 15858, 59, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25570, 15858, 210, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25571, 15858, 220, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25572, 15858, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25573, 15859, 189, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25574, 15859, 249, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25575, 15859, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25576, 15859, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25577, 15860, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25578, 15860, 318, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25579, 15860, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25580, 15860, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25585, 15862, 321, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25586, 15862, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25587, 15862, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25588, 15862, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25589, 15863, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25590, 15863, 318, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25591, 15863, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25595, 15864, 184, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25596, 15864, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25597, 15864, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25598, 15864, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25599, 15864, 324, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25600, 15864, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25601, 15865, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25602, 15865, 119, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25603, 15865, 9, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25604, 15865, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25611, 15867, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25612, 15867, 102, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25613, 15868, 133, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25614, 15868, 16, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25615, 15868, 176, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25616, 15868, 324, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25617, 15868, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25618, 15869, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25619, 15869, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25620, 15869, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25621, 15869, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25622, 15869, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25623, 15870, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25624, 15870, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25625, 15870, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25698, 15422, 13, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (25547, 15852, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25548, 15852, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22980, 11985, 157, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (21156, 13351, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (21157, 13351, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (25626, 15870, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25627, 15870, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25631, 15872, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25632, 15872, 321, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25633, 15872, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25634, 15873, 324, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25635, 15874, 119, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25636, 15874, 92, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25637, 15875, 23, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25638, 15875, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25639, 15875, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25640, 15875, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25641, 15875, 224, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25642, 15875, 249, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25643, 15876, 95, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25644, 15876, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25645, 15876, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25646, 15876, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25647, 15878, 263, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25648, 15878, 119, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25649, 15878, 321, 0, 3);
INSERT INTO 'dancesformationsmap' VALUES (25650, 15879, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25651, 15879, 95, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25652, 15879, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25653, 15879, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25654, 15879, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25659, 15881, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25660, 15881, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25661, 15881, 248, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25662, 15881, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25663, 15882, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25664, 15882, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25665, 15882, 336, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25674, 15885, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25675, 15885, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25676, 15885, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25677, 15885, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25678, 15885, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25687, 15888, 119, 0, 4);
INSERT INTO 'dancesformationsmap' VALUES (25691, 15890, 112, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25692, 15890, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25693, 15890, 249, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25694, 15890, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25695, 15890, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25696, 15890, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25666, 15883, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25667, 15883, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25668, 15883, 119, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25669, 15883, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25700, 15365, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25701, 15365, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (25702, 15365, 294, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25703, 15365, 337, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25683, 15887, 26, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25684, 15887, 173, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25581, 15861, 94, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25582, 15861, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25583, 15861, 183, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (25685, 15887, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25554, 15854, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25555, 15854, 221, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (25556, 15854, 16, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25557, 15854, 82, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (23952, 15217, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23953, 15217, 70, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (23954, 15217, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11966, 9725, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20582, 3110, 24, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20583, 3110, 17, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (20584, 3110, 119, 81, 4);
INSERT INTO 'dancesformationsmap' VALUES (25704, 3110, 96, 113, 4);
INSERT INTO 'dancesformationsmap' VALUES (3779, 7124, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7623, 7124, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7624, 7124, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7625, 7124, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25705, 7124, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (25819, 15922, 321, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25820, 15922, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17976, 12451, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17977, 12451, 90, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (25670, 15884, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25671, 15884, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25688, 15889, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25689, 15889, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25690, 15889, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25628, 15871, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25629, 15871, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25655, 15880, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25530, 15847, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25592, 15586, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25593, 15586, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25594, 15586, 309, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (17223, 12074, 55, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25679, 15886, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25680, 15886, 314, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25681, 15886, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25682, 15886, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (25672, 15884, 75, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25673, 15884, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (25656, 15880, 20, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25657, 15880, 168, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25630, 15871, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (25821, 15922, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25822, 15922, 225, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25823, 15922, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (5762, 5667, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24663, 5667, 301, 43, 2);
INSERT INTO 'dancesformationsmap' VALUES (25709, 15893, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25710, 15893, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25711, 15895, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25712, 15895, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25713, 15895, 184, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25714, 15896, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25715, 15896, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25716, 15896, 72, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25717, 15896, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25722, 15898, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25723, 15898, 184, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25724, 15898, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25725, 15898, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25726, 15899, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25727, 15899, 93, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25728, 15899, 29, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25732, 15901, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25733, 15901, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25737, 15904, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25738, 15904, 93, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25739, 15904, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25740, 15904, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25743, 15906, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25744, 15906, 249, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25745, 15906, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25746, 15906, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25747, 15907, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25748, 15907, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25749, 15907, 333, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25750, 15907, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (394, 702, 27, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (13171, 9231, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13173, 9231, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25751, 9231, 338, 18, 6);
INSERT INTO 'dancesformationsmap' VALUES (25752, 9231, 154, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (24674, 15427, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25753, 15427, 132, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (25754, 15427, 338, 15, 4);
INSERT INTO 'dancesformationsmap' VALUES (31583, 11320, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31584, 11320, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (20797, 5821, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (20798, 5821, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25758, 5821, 132, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (25759, 5821, 338, 27, 3);
INSERT INTO 'dancesformationsmap' VALUES (25814, 15921, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25815, 15921, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14042, 10952, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25771, 15911, 249, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25772, 15911, 225, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (25773, 15911, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25794, 15916, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25795, 15916, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25796, 15916, 144, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25797, 15916, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25798, 15916, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25799, 15917, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25800, 15917, 45, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25801, 15917, 2, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25805, 15919, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25806, 15919, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25807, 15919, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25808, 15919, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25809, 15920, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25810, 15920, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25811, 15920, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25812, 15920, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25813, 15920, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25827, 15924, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25828, 15924, 185, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25829, 15924, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25830, 15925, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25831, 15925, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25832, 15925, 185, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (25833, 15925, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25834, 15926, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25835, 15926, 224, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25699, 15422, 23, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (25836, 15926, 225, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (25837, 15926, 1, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (25838, 15926, 192, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (25839, 15927, 184, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25840, 15927, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25841, 15927, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (25842, 15927, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25843, 15927, 131, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25844, 15927, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (25845, 15928, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25846, 15928, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (25847, 15928, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25848, 15928, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25849, 15930, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25850, 15930, 1, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (25851, 15930, 30, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25852, 15931, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25853, 15931, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (25854, 15931, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25855, 15931, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (25856, 15932, 314, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25857, 15932, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25858, 15932, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25859, 15932, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25741, 15905, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25742, 15905, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25735, 15903, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25736, 15903, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8506, 8684, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8507, 8684, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25729, 15900, 29, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (25730, 15900, 93, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (25731, 15900, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25718, 15897, 249, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (25719, 15897, 39, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (25720, 15897, 8, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (25721, 15897, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25706, 15892, 96, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25707, 15892, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25708, 15892, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25734, 15902, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25757, 8154, 338, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (25802, 15918, 29, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (25803, 15918, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25789, 15915, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25790, 15915, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (25791, 15915, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25792, 15915, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25793, 15915, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25804, 15918, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25816, 15921, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25860, 15933, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25861, 15933, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25862, 15933, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25863, 15933, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25864, 15933, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25865, 15933, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25866, 15934, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25867, 15934, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (25868, 15934, 314, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25869, 15934, 263, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25870, 15934, 42, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (25871, 15934, 249, 47, 1);
INSERT INTO 'dancesformationsmap' VALUES (25872, 15935, 90, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25873, 15935, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25874, 15935, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (25880, 15937, 130, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25881, 15937, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (25882, 15937, 183, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (25774, 15912, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25775, 15912, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25776, 15912, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25777, 15912, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25767, 15910, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25768, 15910, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25769, 15910, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25770, 15910, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25763, 15909, 12, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (25764, 15909, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25765, 15909, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25766, 15909, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25760, 15908, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25761, 15908, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25762, 15908, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17224, 12074, 185, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17225, 12074, 72, 37, 3);
INSERT INTO 'dancesformationsmap' VALUES (25778, 15913, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25779, 15913, 13, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (25780, 15913, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25875, 15936, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25876, 15936, 314, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (25877, 15936, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (25878, 15936, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25879, 15936, 70, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (25883, 15937, 193, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (25884, 15937, 183, 35, 2);
INSERT INTO 'dancesformationsmap' VALUES (25885, 15937, 183, 51, 2);
INSERT INTO 'dancesformationsmap' VALUES (25886, 15938, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25887, 15938, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25888, 15939, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25889, 15939, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25890, 15939, 16, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (25891, 15939, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25892, 15939, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25893, 15940, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25894, 15940, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25895, 15940, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25896, 15940, 249, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (25897, 15940, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22044, 14388, 193, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25898, 15941, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25899, 15941, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25900, 15941, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (25901, 15941, 214, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (25902, 15942, 152, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25903, 15943, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25904, 15943, 96, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (25905, 15943, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25906, 15943, 72, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (25907, 15943, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25908, 15943, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25909, 15944, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25910, 15944, 224, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (25911, 15944, 20, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (25912, 15944, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25913, 15944, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25914, 15945, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25915, 15945, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25916, 15945, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25917, 15945, 96, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25918, 15945, 96, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (25919, 15946, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25920, 15946, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25921, 15946, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25922, 15946, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (25923, 15946, 261, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25924, 15946, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25925, 15947, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25926, 15947, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25927, 15947, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25928, 15948, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25929, 15948, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25930, 15948, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25931, 15948, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25932, 15948, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25933, 15949, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25934, 15949, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25935, 15949, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25936, 15949, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25937, 15950, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (25938, 15950, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25939, 15950, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31585, 11320, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (25965, 15958, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25943, 15952, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25944, 15952, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26015, 15968, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25945, 15953, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25946, 15953, 203, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25947, 15954, 20, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25948, 15954, 12, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (25949, 15954, 19, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (25950, 15954, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25955, 15929, 134, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (25956, 15929, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25957, 15929, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26009, 15967, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26010, 15967, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26011, 15967, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26012, 15967, 96, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (25966, 15958, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25967, 15958, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18709, 6644, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26013, 6644, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25995, 15964, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (25951, 15955, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24342, 15374, 25, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (25952, 15955, 224, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (25953, 15955, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25954, 15955, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22108, 12071, 19, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13855, 9050, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (13856, 9050, 30, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13857, 9050, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (13858, 9050, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25975, 9050, 308, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25976, 15959, 204, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25977, 15959, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31878, 18286, 302, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (25986, 15962, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25987, 15962, 249, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (25988, 15962, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25989, 15962, 249, 47, 1);
INSERT INTO 'dancesformationsmap' VALUES (25990, 15962, 69, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (25991, 15962, 66, 59, 1);
INSERT INTO 'dancesformationsmap' VALUES (26004, 15966, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26005, 15966, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26006, 15966, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26007, 15966, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26008, 15966, 12, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28214, 16702, 376, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27732, 7161, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10701, 9864, 373, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25997, 15964, 96, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (26017, 15969, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (26021, 15971, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26022, 15971, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26023, 15971, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25962, 15957, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25963, 15957, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25998, 15964, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25964, 15957, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23467, 15087, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (23468, 15087, 176, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23469, 15087, 176, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23470, 15087, 143, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10702, 9864, 143, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25958, 15956, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26024, 15972, 157, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26018, 15970, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26019, 15970, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26020, 15970, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26027, 15973, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26028, 15973, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26029, 15973, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26030, 15973, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (26031, 15974, 126, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26032, 15974, 324, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26033, 15974, 118, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26034, 15974, 32, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (26154, 16016, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26155, 16016, 224, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26156, 16016, 225, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (26143, 16012, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26144, 16012, 318, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (26045, 15983, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26046, 15983, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26047, 15983, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26066, 15989, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26067, 15989, 16, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (26068, 15989, 96, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (26069, 15989, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26094, 15998, 255, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26095, 15998, 255, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26096, 15998, 96, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (26090, 15997, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26157, 16017, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26158, 16017, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26145, 16012, 21, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26119, 16004, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26120, 16004, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26121, 16004, 225, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26122, 16004, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25992, 15963, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25993, 15963, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25994, 15963, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12019, 10352, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12020, 10352, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25978, 15960, 249, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (25979, 15960, 189, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (25980, 15960, 183, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (10639, 9840, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10640, 9840, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16818, 4799, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25940, 15951, 251, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25941, 15951, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (25942, 15951, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26123, 16004, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26124, 16005, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26125, 16005, 190, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31589, 18266, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31590, 18266, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26084, 15995, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26085, 15995, 154, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26086, 15995, 318, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (26136, 16009, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26137, 16009, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26138, 16009, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26149, 16014, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26035, 15975, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26036, 15975, 265, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26037, 15975, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26081, 15994, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26082, 15994, 248, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26083, 15994, 37, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26166, 16019, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26167, 16019, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26168, 16019, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26169, 16019, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26170, 16019, 96, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (26171, 16020, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26172, 16020, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26150, 16014, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26173, 16021, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26174, 16021, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26175, 16021, 168, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26176, 16021, 168, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26177, 16021, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26178, 16022, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26179, 16022, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26180, 16022, 119, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26181, 16022, 119, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (26182, 16022, 154, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (26146, 16012, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26183, 16023, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26184, 16023, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26187, 16024, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26188, 16024, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26189, 16024, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26190, 16024, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26191, 16024, 249, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26192, 16024, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26151, 16015, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26195, 16026, 307, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26196, 16026, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26197, 16026, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26198, 16026, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26077, 15992, 186, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26078, 15992, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26087, 15996, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26088, 15996, 16, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26089, 15996, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26025, 15972, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26026, 15972, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26079, 15993, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26080, 15993, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26101, 16000, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26102, 16000, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26103, 16000, 96, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26104, 16000, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26105, 16001, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26106, 16001, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26107, 16001, 225, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26108, 16001, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26097, 15999, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26098, 15999, 114, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26099, 15999, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26100, 15999, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26091, 15997, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26092, 15997, 57, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26093, 15997, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26058, 15987, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26059, 15987, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26060, 15987, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26061, 15987, 96, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (26062, 15988, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26063, 15988, 268, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26064, 15988, 96, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (26065, 15988, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (26072, 15991, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26073, 15991, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26074, 15991, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26075, 15991, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26039, 15980, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26040, 15980, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26130, 16007, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26131, 16007, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26139, 16010, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25971, 8546, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25972, 8546, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25973, 8546, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25974, 8546, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26164, 16018, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26165, 16018, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26159, 16017, 1, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (26160, 16017, 149, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (26048, 15984, 92, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26049, 15984, 92, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26050, 15984, 249, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26051, 15984, 6, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26056, 15986, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26057, 15986, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26052, 15985, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26053, 15985, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26054, 15985, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26070, 15990, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26071, 15990, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26041, 15981, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26042, 15981, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26043, 15981, 77, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (26044, 15981, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26152, 16015, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26153, 16015, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26199, 16026, 92, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (26301, 16048, 209, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26302, 16048, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26303, 16048, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6049, 6552, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26290, 16046, 155, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26291, 16046, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26207, 16028, 308, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26208, 16028, 119, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26209, 16028, 119, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26210, 16028, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26328, 13487, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19467, 12848, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19468, 12848, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19469, 12848, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26206, 12848, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26218, 16031, 285, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26324, 16052, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26325, 16052, 143, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26239, 16036, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26329, 13487, 145, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26330, 13487, 185, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26304, 16048, 220, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26305, 16048, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26306, 16048, 210, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (26307, 16048, 117, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (26308, 16048, 72, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (26234, 16035, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26235, 16035, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26236, 16035, 96, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (26237, 16035, 77, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26238, 16035, 96, 47, 1);
INSERT INTO 'dancesformationsmap' VALUES (26244, 16037, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26245, 16037, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26246, 16038, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26247, 16039, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26248, 16039, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26249, 16039, 121, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26250, 16039, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26331, 13487, 286, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26126, 16006, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26127, 16006, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26128, 16006, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1005, 1864, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4493, 1864, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1609, 3066, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4877, 3066, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26038, 3066, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26109, 16002, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26110, 16002, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (26111, 16002, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13711, 10820, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13712, 10820, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26147, 16013, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26148, 16013, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26260, 16042, 303, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26261, 16042, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26262, 16042, 314, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26263, 16042, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26264, 16043, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26265, 16043, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26266, 16043, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26267, 16043, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26268, 16043, 224, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (26269, 16043, 248, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26270, 16043, 224, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (26271, 16043, 51, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (26272, 16043, 1, 61, 1);
INSERT INTO 'dancesformationsmap' VALUES (26273, 16043, 273, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (26274, 16043, 225, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (26275, 16043, 225, 77, 1);
INSERT INTO 'dancesformationsmap' VALUES (26276, 16043, 248, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (26277, 16043, 225, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (26309, 16048, 220, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (26310, 16048, 193, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (26314, 16050, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26315, 16050, 133, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26316, 16050, 313, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (9013, 7811, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (9014, 7811, 25, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9015, 7811, 55, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (9016, 7811, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26285, 7811, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (26281, 14582, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (26282, 14582, 339, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26283, 14582, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26284, 14582, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20754, 13025, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20755, 13025, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20756, 13025, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (26286, 16045, 280, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26287, 16045, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26288, 16045, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26289, 16045, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26339, 13485, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26292, 16047, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26293, 16047, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26294, 16047, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26295, 16047, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26296, 15360, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26297, 15360, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26298, 15360, 225, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (26299, 15360, 23, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (26300, 15360, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26317, 16050, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26340, 13485, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31876, 18286, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31877, 18286, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16693, 11949, 152, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16694, 11949, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (26341, 13480, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26342, 13480, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26343, 13480, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26344, 13483, 210, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26345, 13483, 176, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26346, 13483, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26347, 13483, 90, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26348, 13483, 38, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (26349, 13483, 8, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (26350, 13483, 328, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (26351, 13481, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26352, 13481, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26353, 13481, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26354, 13481, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26355, 13481, 42, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26356, 13481, 23, 36, 1);
INSERT INTO 'dancesformationsmap' VALUES (31593, 18262, 321, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31594, 18262, 62, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26326, 16052, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26278, 16044, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26279, 16044, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26280, 16044, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31879, 18286, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (26212, 16029, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26229, 16034, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26230, 16034, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26231, 16034, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (26216, 16030, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26217, 16030, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10510, 9758, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10511, 9758, 179, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10512, 9758, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26318, 16051, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26319, 16051, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26193, 16025, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26194, 16025, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26320, 16051, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26321, 16051, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26333, 13476, 245, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26334, 13476, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26311, 16049, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26312, 16049, 42, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (26335, 13476, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26336, 13476, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26337, 13476, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26338, 13476, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26256, 16041, 234, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (26257, 16041, 225, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (26258, 16041, 152, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (26213, 16029, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26214, 16029, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26215, 16029, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26240, 16036, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26241, 16036, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26220, 16032, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26221, 16032, 225, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (26222, 16032, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26242, 16036, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26243, 16036, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (26223, 16033, 33, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26224, 16033, 39, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26225, 16033, 224, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26226, 16033, 58, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26227, 16033, 185, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26357, 13489, 93, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (26358, 13489, 225, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26364, 13489, 193, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (26366, 13489, 19, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (26369, 13489, 117, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (26405, 16055, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26406, 16055, 263, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (26407, 16055, 24, 137, 2);
INSERT INTO 'dancesformationsmap' VALUES (26408, 16055, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26377, 13486, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26378, 13486, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26379, 13486, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26380, 13486, 66, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26409, 16055, 184, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (26439, 16058, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26440, 16058, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (26441, 16058, 123, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26386, 11228, 251, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26387, 11228, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26388, 11228, 132, 26, 3);
INSERT INTO 'dancesformationsmap' VALUES (26423, 13479, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26424, 13479, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26425, 13479, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26426, 13479, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (26389, 14962, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26390, 14962, 221, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26391, 14962, 23, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (26392, 14962, 154, 29, 3);
INSERT INTO 'dancesformationsmap' VALUES (26393, 15665, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26394, 15665, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26395, 15665, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (26396, 15665, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22529, 2956, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26327, 16052, 93, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26457, 16060, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26458, 16060, 3, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (26459, 16060, 42, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (1072, 1998, 77, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21617, 13756, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21618, 13756, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21619, 13756, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26442, 16058, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (26381, 13488, 103, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9125, 7611, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (26430, 13477, 341, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26431, 13477, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26432, 13477, 119, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (26433, 13477, 182, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26434, 13477, 183, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (26446, 16059, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26447, 16059, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26448, 16059, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26449, 16059, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26450, 16059, 134, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26413, 2475, 314, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (26501, 16072, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26502, 16072, 228, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16460, 11891, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16461, 11891, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22019, 14363, 277, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (5721, 5555, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26451, 5555, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26452, 5555, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8836, 4256, 43, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (8837, 4256, 27, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (26382, 13488, 285, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26383, 13488, 81, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26384, 13488, 69, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26414, 13478, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26415, 13478, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26416, 13475, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26417, 13475, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26418, 13475, 202, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26419, 13475, 185, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26420, 13475, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26421, 13475, 39, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26422, 13475, 249, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22824, 5296, 42, 18, 4);
INSERT INTO 'dancesformationsmap' VALUES (22825, 5296, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20077, 13083, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26435, 16057, 119, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (26436, 16057, 112, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26437, 16057, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26469, 16063, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26470, 16063, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26471, 16063, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26472, 16063, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26473, 16063, 308, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26474, 16064, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26475, 16064, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26476, 16064, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26477, 16064, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26478, 16064, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26479, 16064, 225, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (26480, 16065, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26481, 16065, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26482, 16065, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26483, 16066, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26484, 16066, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26485, 16066, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14235, 8334, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26492, 16068, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26185, 16023, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26186, 16023, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (14236, 8334, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14237, 8334, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14238, 8334, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26397, 16053, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26398, 16053, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26486, 16067, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26489, 16068, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26490, 16068, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26491, 16068, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20083, 13083, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20084, 13083, 188, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (26487, 16067, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26488, 16067, 183, 27, 3);
INSERT INTO 'dancesformationsmap' VALUES (26400, 16054, 200, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26443, 15308, 9, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (26444, 15308, 157, 12, 4);
INSERT INTO 'dancesformationsmap' VALUES (26445, 15308, 154, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (26498, 16071, 13, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26499, 16071, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26500, 16071, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26401, 16054, 82, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (26402, 16054, 92, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26399, 16053, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13974, 10920, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13975, 10920, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (20279, 10920, 273, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9126, 7611, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9127, 7611, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (26460, 16060, 43, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (26461, 16060, 192, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (26465, 16062, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26466, 16062, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26467, 16062, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26468, 16062, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24818, 13083, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26403, 16054, 93, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (31595, 12312, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31596, 12312, 114, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31597, 12312, 209, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31598, 12312, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (26506, 16073, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26507, 16073, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26508, 16073, 101, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26509, 16073, 249, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (26510, 16074, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26511, 16074, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26512, 16074, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26513, 16074, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26518, 16076, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26519, 16076, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26520, 16076, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26521, 16076, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26427, 16056, 227, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26514, 16075, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26200, 16025, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26515, 16075, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26493, 13614, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26428, 16056, 102, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26429, 16056, 317, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26522, 16076, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26523, 16077, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26524, 16077, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26525, 16077, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26526, 16078, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26527, 16078, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26528, 16079, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26529, 16079, 29, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (26530, 16079, 96, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (26531, 16079, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26532, 16079, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26533, 16080, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26534, 16080, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26535, 16080, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26536, 16081, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26537, 16081, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26538, 16081, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26539, 16082, 306, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26540, 16082, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26541, 16082, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26542, 16082, 328, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26543, 16083, 314, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26544, 16083, 96, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (26545, 16083, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26546, 16083, 314, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (26547, 16083, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26548, 16084, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26549, 16084, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26550, 16084, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26551, 16085, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26552, 16085, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26553, 16085, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26554, 16085, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26555, 16085, 225, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26556, 16085, 249, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (26557, 16086, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26558, 16086, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26559, 16086, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11577, 9224, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26629, 16107, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26630, 16107, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13767, 6964, 36, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (13768, 6964, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26560, 16087, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26561, 16087, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26562, 16087, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26563, 16087, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26564, 16088, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26565, 16088, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26566, 16088, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26570, 16091, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26571, 16091, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26572, 16091, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26573, 16092, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26574, 16092, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26575, 16093, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26576, 16093, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26577, 16093, 307, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26578, 16093, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31599, 12183, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26453, 14076, 76, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26454, 14076, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (16235, 11771, 119, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (11408, 6104, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11409, 6104, 114, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11410, 6104, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (16236, 11771, 214, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11745, 10306, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11747, 10306, 221, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22926, 14711, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22927, 14711, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22928, 14711, 37, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (15253, 9787, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15254, 9787, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15255, 9787, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26583, 16095, 144, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26584, 16095, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26585, 16095, 225, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26586, 16095, 224, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26587, 16095, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26588, 16096, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26589, 16096, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26590, 16096, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26591, 16096, 303, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26592, 16097, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26593, 16097, 82, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26594, 16097, 30, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26595, 16097, 234, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26596, 16097, 112, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26597, 16097, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (26599, 16098, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26600, 16098, 234, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26601, 16099, 168, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26602, 16099, 17, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (26603, 16099, 117, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (26604, 16099, 310, 77, 1);
INSERT INTO 'dancesformationsmap' VALUES (26605, 16099, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (26611, 16101, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26612, 16101, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26613, 16101, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26614, 16101, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26615, 16102, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26616, 16102, 129, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26617, 16102, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26622, 16104, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26623, 16104, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26624, 16104, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26625, 16105, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26626, 16105, 303, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26627, 16108, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26628, 16108, 241, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26631, 16107, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26632, 16107, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7597, 250, 28, 35, 2);
INSERT INTO 'dancesformationsmap' VALUES (26606, 16100, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26607, 16100, 10, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26579, 16094, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26653, 16112, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26654, 16112, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26655, 16112, 123, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26636, 13581, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26637, 13581, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26638, 13581, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (26639, 16109, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26640, 16109, 145, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26641, 16109, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (26642, 16109, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (26643, 16109, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26644, 16110, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26645, 16110, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26646, 16110, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26647, 16110, 27, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26648, 16110, 32, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (26656, 16112, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26657, 16112, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24113, 15270, 39, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24114, 15270, 69, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24115, 15270, 58, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (24111, 15269, 85, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26660, 16114, 249, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26661, 16114, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26662, 16114, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26663, 16115, 29, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (26664, 16115, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26608, 16100, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26665, 16116, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26666, 16116, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26667, 16116, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26668, 16116, 145, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13496, 8366, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (26652, 9815, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24810, 5696, 27, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (24811, 5696, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26580, 16094, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26581, 16094, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26649, 16111, 9, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26650, 16111, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26651, 16111, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26505, 250, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26567, 16089, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26568, 16089, 269, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26569, 16089, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26717, 16128, 58, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26718, 16128, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (26673, 16118, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26674, 16118, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26675, 16118, 96, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (26676, 16118, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26677, 16118, 224, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (26678, 16119, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26679, 16119, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26680, 16120, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26681, 16120, 249, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (26682, 16121, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26683, 16121, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26684, 16121, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (26685, 16121, 96, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26686, 16121, 1, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (26687, 16122, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26618, 16103, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8239, 454, 154, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (26688, 16122, 283, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26689, 16122, 109, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26690, 16122, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26691, 16122, 92, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10150, 5209, 262, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (341, 611, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26701, 16125, 114, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26702, 16125, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26703, 16125, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26704, 16125, 154, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26709, 6073, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26710, 6073, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26711, 6073, 72, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26712, 16127, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26713, 16127, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26714, 16127, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26715, 16127, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26716, 16127, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26723, 16129, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26724, 16129, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26725, 16130, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26726, 16130, 181, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26727, 16130, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26728, 16131, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26729, 16131, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26730, 16131, 249, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (26731, 16131, 23, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (26732, 16132, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26733, 16132, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26734, 16132, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26737, 16134, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26738, 16134, 249, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (26739, 16134, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26740, 16135, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26741, 16135, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26742, 16135, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26743, 4943, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26744, 9931, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26745, 9931, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26746, 9931, 123, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26777, 16142, 119, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26778, 16142, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26779, 16142, 70, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26780, 16142, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26784, 16144, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26785, 16144, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26786, 16144, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26806, 16151, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26807, 16151, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26804, 16150, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26805, 16150, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26658, 16113, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31602, 12183, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31603, 12183, 165, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26598, 14393, 313, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (11411, 6104, 23, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (4295, 1280, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26797, 16148, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26798, 16148, 62, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26799, 16148, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26669, 16117, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26670, 16117, 188, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (26671, 16117, 189, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (26792, 16146, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26793, 16146, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22228, 14425, 317, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23925, 15210, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23926, 15210, 132, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (23927, 15210, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (129, 224, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26789, 16145, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26800, 16149, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26801, 16149, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23342, 2602, 180, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23343, 2602, 145, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (23344, 2602, 297, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (18908, 12740, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (26802, 16149, 30, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26672, 16117, 17, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (26696, 16124, 39, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26697, 16124, 249, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26698, 16124, 297, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26699, 16124, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26692, 16123, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26693, 16123, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26694, 16123, 168, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26695, 16123, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26790, 16145, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26791, 16145, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10032, 894, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16853, 894, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26735, 16133, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21890, 13356, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21891, 13356, 317, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (26757, 16139, 103, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26758, 16139, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (26759, 16139, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (26760, 16139, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (26764, 16140, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26765, 16140, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (26751, 16137, 285, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26752, 16137, 341, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (26753, 16138, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26754, 16138, 1, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (26755, 16138, 8, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (26756, 16138, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (26747, 16136, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26748, 16136, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (26749, 16136, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26750, 16136, 313, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (26766, 16140, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (26781, 16143, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26782, 16143, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26783, 16143, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26767, 16140, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (26768, 16141, 38, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26705, 16126, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26706, 16126, 96, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26708, 16126, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26736, 16133, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26769, 16141, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (26770, 16141, 310, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26771, 16141, 133, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (26772, 16141, 16, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (26851, 5016, 9, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (26834, 1969, 43, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (26843, 16161, 10, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26844, 16161, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31606, 12226, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31607, 12226, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31608, 12230, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26820, 16155, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26821, 16155, 32, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (26813, 16154, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26814, 16154, 162, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26815, 16154, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26822, 13557, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26823, 13557, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31609, 12230, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31610, 12230, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31611, 12230, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (18990, 12767, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26828, 16157, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26829, 16157, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18430, 12538, 90, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18431, 12538, 183, 25, 8);
INSERT INTO 'dancesformationsmap' VALUES (18432, 12538, 52, 73, 2);
INSERT INTO 'dancesformationsmap' VALUES (18433, 12538, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (22165, 12538, 234, 57, 4);
INSERT INTO 'dancesformationsmap' VALUES (22166, 12538, 66, 69, 4);
INSERT INTO 'dancesformationsmap' VALUES (26838, 12538, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (26824, 16156, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26825, 16156, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26826, 16156, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26827, 16156, 314, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (26857, 16176, 1, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (26858, 16176, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22367, 14528, 83, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (22368, 14528, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (26907, 13205, 29, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (15062, 11500, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26846, 5936, 96, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (9527, 9114, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26901, 14514, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26879, 9114, 234, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (26841, 16160, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26842, 16160, 27, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (31612, 12254, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22191, 13594, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24064, 15248, 386, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13487, 8361, 9, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13488, 8361, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13489, 8361, 145, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9160, 7406, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23712, 15179, 263, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26794, 16147, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26795, 16147, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24535, 15179, 105, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24536, 15179, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16422, 11876, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16136, 11757, 343, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (25316, 15762, 123, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (31613, 12254, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (26869, 16181, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26870, 16181, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26859, 16177, 85, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (26860, 16177, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (26874, 16183, 28, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26918, 16189, 34, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26861, 16177, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26862, 16177, 93, 31, 4);
INSERT INTO 'dancesformationsmap' VALUES (26863, 16177, 28, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (26839, 16159, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26840, 16159, 184, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26848, 16159, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26849, 16159, 183, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26850, 16159, 7, 18, 2);
INSERT INTO 'dancesformationsmap' VALUES (11856, 4933, 69, 97, 2);
INSERT INTO 'dancesformationsmap' VALUES (26864, 4046, 12, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (26865, 16182, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26866, 16182, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26867, 16182, 16, 21, 4);
INSERT INTO 'dancesformationsmap' VALUES (26868, 16182, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26919, 16189, 222, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16137, 11757, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26830, 14964, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31614, 12254, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (31615, 12254, 8, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (22576, 14597, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22577, 14597, 225, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11864, 4933, 27, 65, 4);
INSERT INTO 'dancesformationsmap' VALUES (31616, 12254, 48, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31617, 12347, 15, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31618, 12347, 29, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31619, 12347, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31620, 12171, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31621, 12171, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31586, 18265, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31587, 18265, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26853, 12375, 10, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8658, 893, 214, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (23009, 14744, 70, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23010, 14744, 62, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (23011, 14744, 192, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (8473, 8674, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8474, 8674, 13, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16557, 6532, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23266, 6532, 16, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (23268, 6532, 183, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (14619, 1075, 43, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (12656, 9769, 36, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (25350, 15772, 92, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (7356, 7494, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14439, 11192, 66, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14440, 11192, 32, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (14437, 11191, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8859, 4965, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8860, 4965, 72, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (26809, 14347, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26808, 9817, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26787, 1943, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31588, 18265, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26462, 16061, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26902, 16185, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26889, 16184, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26890, 16184, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26891, 16184, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (26892, 16184, 7, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (26893, 16184, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26894, 12736, 334, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26884, 14672, 29, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (26885, 14672, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26886, 14672, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26887, 14672, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (26888, 14672, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26903, 16185, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26900, 10681, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26904, 16185, 23, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (26905, 16185, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26463, 16061, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26464, 16061, 8, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (26816, 16153, 96, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (15136, 8879, 267, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15137, 8879, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15138, 8879, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15139, 8879, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (26906, 16185, 36, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25111, 15701, 59, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26016, 15968, 119, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31625, 18267, 156, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26915, 16188, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26916, 16188, 281, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (26917, 16188, 157, 53, 2);
INSERT INTO 'dancesformationsmap' VALUES (31626, 18267, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31627, 18267, 171, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8573, 8705, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8574, 8705, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8575, 8705, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11578, 9224, 32, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (11579, 9224, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18685, 12669, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18686, 12669, 186, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26880, 15706, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26817, 16153, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5051, 3593, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26873, 3593, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26818, 16153, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26819, 16153, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26831, 14964, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26925, 16192, 142, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (26926, 16192, 183, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (26927, 16192, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26912, 16187, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26913, 16187, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26914, 16187, 58, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27047, 16236, 344, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26928, 16193, 306, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26932, 16195, 224, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26933, 16195, 281, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (26942, 16199, 306, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26943, 16199, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26944, 16199, 158, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26947, 16201, 73, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26948, 16201, 224, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26949, 16201, 225, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26950, 16201, 193, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26953, 16203, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26954, 16203, 1, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (8508, 8684, 23, 18, 3);
INSERT INTO 'dancesformationsmap' VALUES (8509, 8684, 90, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (8510, 8684, 157, 81, 4);
INSERT INTO 'dancesformationsmap' VALUES (8511, 8684, 38, 93, 1);
INSERT INTO 'dancesformationsmap' VALUES (25755, 8684, 338, 34, 3);
INSERT INTO 'dancesformationsmap' VALUES (25756, 8684, 301, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (26959, 16205, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26960, 16205, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26961, 16205, 21, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26962, 16205, 306, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26967, 16207, 158, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26968, 16207, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26969, 16207, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26970, 16208, 306, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26971, 16208, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26972, 16208, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26973, 16209, 1, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (26974, 16209, 314, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (26978, 16211, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26979, 16211, 269, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26980, 16211, 32, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27072, 16244, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27073, 16244, 268, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27074, 16244, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22676, 14631, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26958, 9224, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26981, 2439, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26982, 2439, 112, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (26983, 2439, 224, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (26984, 2439, 183, 53, 1);
INSERT INTO 'dancesformationsmap' VALUES (26985, 2439, 149, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (26986, 16214, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27048, 16236, 226, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27049, 16236, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31628, 18267, 321, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31629, 18267, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27050, 16236, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (26975, 16210, 29, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (26976, 16210, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26977, 16210, 8, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26988, 16221, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26995, 16223, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27051, 16237, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27052, 16237, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27053, 16237, 352, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22483, 14568, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26993, 16222, 72, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (22282, 14438, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22283, 14438, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26854, 3665, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11184, 10070, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26909, 16186, 133, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26987, 1949, 279, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (26810, 1791, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27080, 16246, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27081, 16246, 354, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27005, 1989, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27006, 1989, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27040, 16234, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27016, 16226, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27017, 16226, 10, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27022, 16229, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27023, 16229, 10, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27024, 16229, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27025, 16229, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27037, 16233, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27038, 16233, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27039, 16233, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27041, 16234, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27054, 16238, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27055, 16238, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27056, 16239, 350, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27057, 16239, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27058, 16239, 189, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27061, 16240, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (27062, 16240, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27066, 16242, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27067, 16242, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27068, 16242, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27020, 16228, 90, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26996, 16223, 250, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27044, 16235, 349, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27045, 16235, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27046, 16235, 346, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27063, 16241, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27064, 16241, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27026, 16230, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27035, 16232, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27036, 16232, 346, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27027, 16230, 327, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27028, 16230, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27065, 16241, 346, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26929, 16194, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26930, 16194, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26931, 16194, 306, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (31880, 3813, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7436, 2302, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26899, 2302, 132, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (26945, 16200, 227, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26946, 16200, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27059, 10441, 110, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27060, 10441, 249, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (15512, 11569, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11532, 8480, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27018, 16227, 119, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (26936, 16197, 318, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (26937, 16197, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27019, 16227, 118, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26951, 16202, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26952, 16202, 23, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (27077, 16245, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27078, 16245, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27079, 16245, 321, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27083, 16247, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27084, 16248, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27085, 16248, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27086, 16248, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27087, 16248, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27088, 16249, 168, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27089, 16249, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27090, 16249, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27091, 16249, 321, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27082, 16246, 138, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26955, 16204, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26956, 16204, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26957, 16204, 37, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27009, 16224, 349, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7692, 358, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26921, 16190, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26922, 16190, 248, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27010, 16224, 70, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27011, 16224, 351, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26997, 16223, 119, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26989, 16221, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26990, 16221, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26991, 16221, 84, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (26939, 16198, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26940, 16198, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26941, 16198, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26923, 16190, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26924, 16190, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27092, 16250, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27093, 16250, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27094, 16250, 260, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27095, 16251, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27096, 16251, 45, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27097, 16251, 185, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27098, 16251, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27099, 16252, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27100, 16252, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27101, 16252, 185, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27102, 16252, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27103, 16252, 168, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27104, 16252, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27105, 16253, 220, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27106, 16253, 324, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27107, 16254, 284, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27108, 16255, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27109, 16255, 36, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (25584, 15861, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27120, 16259, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27217, 16293, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27110, 16255, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27219, 16294, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27114, 16256, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (27115, 16256, 156, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27124, 16260, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27125, 16260, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27126, 16260, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27127, 16260, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27128, 5524, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27129, 5524, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27130, 16261, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27131, 16261, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27132, 16262, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27133, 16262, 112, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (27134, 16263, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27135, 16264, 164, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27136, 16264, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27137, 16264, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27138, 16265, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27139, 16266, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27140, 16266, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27141, 16267, 134, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (27142, 16267, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27143, 16267, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27144, 16268, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27145, 16268, 114, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27146, 16268, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27147, 16269, 36, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27148, 16270, 261, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27149, 16270, 114, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27150, 16271, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27151, 16271, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27152, 16272, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27153, 16272, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27154, 16272, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27155, 16272, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27156, 16273, 355, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27157, 16273, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27158, 16273, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27159, 16274, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27160, 16274, 39, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27161, 16274, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27162, 16274, 176, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27163, 15618, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27164, 15618, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27165, 16275, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27166, 16275, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27167, 16275, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27168, 16276, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27169, 16276, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27170, 16276, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27171, 16276, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27172, 16276, 317, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (27177, 16278, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27178, 16278, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27179, 16278, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27185, 16280, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27186, 16280, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27187, 16281, 71, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27188, 16282, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27189, 16282, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27030, 16231, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27031, 16231, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26994, 16222, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27004, 16222, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27173, 16277, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27174, 16277, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27175, 16277, 154, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27176, 16277, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27069, 16243, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27070, 16243, 353, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27071, 16243, 112, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (27190, 16282, 96, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (27194, 16284, 73, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27195, 16284, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27196, 16284, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27197, 16284, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (27218, 16293, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (27206, 16288, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27180, 16279, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27181, 16279, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27182, 16279, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27183, 16279, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27184, 16279, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27211, 16290, 43, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (27220, 16290, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27221, 16290, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27121, 16259, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27122, 16259, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27234, 16298, 18, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27235, 16298, 119, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (27236, 16298, 192, 40, 1);
INSERT INTO 'dancesformationsmap' VALUES (27237, 16299, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27238, 16299, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27239, 16299, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27240, 16299, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27247, 16302, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27248, 16302, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27249, 16303, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27008, 5013, 12, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (27241, 16300, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27209, 16289, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27210, 16289, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (27242, 16300, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27243, 16300, 333, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (27231, 16297, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27232, 16297, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27229, 16296, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27230, 16296, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27117, 16258, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27118, 16258, 24, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27119, 16258, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14617, 9407, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14896, 6152, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27007, 11189, 23, 69, 2);
INSERT INTO 'dancesformationsmap' VALUES (26934, 16196, 321, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26935, 16196, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27200, 16286, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27201, 16286, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27250, 16303, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27251, 16303, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27252, 16304, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27253, 16304, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27254, 16305, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27255, 16305, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27259, 16307, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27260, 16307, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27261, 16307, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27262, 16308, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27263, 16308, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27264, 16308, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27265, 16308, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27266, 16309, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27267, 16309, 96, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (27268, 16309, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27269, 16310, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27270, 16310, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27225, 16294, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27226, 16294, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27224, 16293, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (27244, 16301, 142, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27245, 16301, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27246, 16301, 354, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23270, 14973, 262, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27207, 16288, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (27208, 16288, 241, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (27271, 16310, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27272, 16310, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27282, 16314, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27283, 16314, 314, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27287, 16316, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27288, 16316, 203, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (27289, 16316, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27290, 16317, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27291, 16317, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27292, 16317, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27293, 16319, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27294, 16319, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27295, 16319, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27296, 16319, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27297, 16320, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27298, 16320, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27299, 16320, 134, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26404, 16054, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23271, 14973, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27304, 16322, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27305, 16322, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27306, 16322, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27307, 16322, 22, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (27308, 16323, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27309, 16323, 354, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27310, 16323, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27311, 16324, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27312, 16324, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27313, 16324, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27316, 16326, 30, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27317, 16326, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27318, 16326, 30, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27321, 16328, 96, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (27322, 16328, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27323, 16328, 162, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27324, 16329, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27325, 16329, 158, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27326, 16330, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27327, 16330, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27328, 16330, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27329, 16330, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27330, 16331, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27331, 16331, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27332, 16331, 90, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27333, 16331, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (27334, 16332, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27335, 16332, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27336, 16332, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27337, 16333, 134, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27338, 16333, 234, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (27339, 16333, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27340, 16334, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27341, 16334, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27342, 16334, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27343, 16335, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27344, 16335, 92, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (27345, 16335, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27346, 16336, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27347, 16336, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27348, 16336, 96, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (27356, 2263, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14271, 11113, 29, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (27353, 11113, 318, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27354, 5054, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27355, 5054, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27358, 16340, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27359, 16340, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27360, 16340, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27361, 16340, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27362, 16341, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27363, 16341, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27364, 16341, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27365, 16342, 280, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27366, 16342, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27367, 16343, 280, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27368, 16343, 9, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27379, 16348, 164, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27380, 16348, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27381, 16348, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27382, 16348, 148, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27383, 16348, 42, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27384, 16349, 164, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27385, 16349, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27386, 16349, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27387, 16350, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27388, 16350, 300, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27389, 16350, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27390, 16350, 138, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27391, 16351, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27392, 16351, 300, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27393, 16351, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27394, 16352, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27395, 16352, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27396, 16352, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27277, 16312, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27278, 16312, 386, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27279, 16312, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27203, 16287, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27204, 16287, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27205, 16287, 192, 24, 1);
INSERT INTO 'dancesformationsmap' VALUES (7832, 8203, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27198, 16285, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27199, 16285, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27191, 16283, 354, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27192, 16283, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27227, 16295, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27228, 16295, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27397, 16353, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27398, 16353, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27399, 16353, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27374, 16346, 260, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27375, 16346, 59, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27372, 16345, 260, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27373, 16345, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27369, 16344, 260, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27405, 2631, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27406, 16354, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27407, 16354, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27408, 16355, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27409, 16355, 284, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27410, 16355, 224, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27411, 16355, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27412, 16356, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27413, 16356, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27414, 16356, 280, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27415, 16356, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27420, 16358, 309, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27421, 16358, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27422, 16359, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27423, 16359, 260, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27424, 16360, 207, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27425, 16361, 207, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27426, 16361, 260, 24, 1);
INSERT INTO 'dancesformationsmap' VALUES (27427, 11751, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27428, 11751, 354, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (27429, 11751, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27430, 16362, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27431, 16362, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27432, 16362, 280, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27433, 16362, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27434, 16363, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27435, 16363, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27436, 16363, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27437, 16364, 324, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27438, 16364, 66, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (27439, 16365, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27440, 16365, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27441, 16365, 69, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27442, 16365, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27443, 16365, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27444, 16366, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27445, 16366, 144, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27116, 16257, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27284, 16315, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27285, 16315, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27286, 16315, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27446, 16366, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27447, 16366, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27452, 16368, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27453, 16368, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27454, 16368, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27314, 16325, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27315, 16325, 1, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (27400, 15691, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27401, 15691, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27402, 15691, 29, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (27403, 15691, 69, 18, 1);
INSERT INTO 'dancesformationsmap' VALUES (27370, 16344, 26, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27371, 16344, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27273, 16311, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (27274, 16311, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27275, 16311, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27276, 16311, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27319, 16327, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27320, 16327, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27357, 2263, 7, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (27352, 16339, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27455, 11659, 16, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27456, 11659, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27457, 11659, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27458, 11659, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27463, 16370, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27464, 16370, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27465, 16370, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27459, 16369, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27460, 16369, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27461, 16369, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27462, 16369, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27469, 16372, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27470, 16372, 46, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27471, 16372, 355, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27472, 16372, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27473, 16373, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27474, 16373, 355, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27475, 16373, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27476, 16373, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27477, 16374, 355, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27478, 16374, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27479, 16375, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27480, 16375, 355, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27481, 16375, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27482, 16375, 42, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27483, 16375, 251, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27484, 16376, 235, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27485, 16376, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27486, 16376, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27487, 16377, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27488, 16377, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27489, 16377, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27490, 16377, 314, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27491, 16378, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27492, 16378, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27493, 16378, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27494, 16379, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27495, 16379, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27496, 16379, 131, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27497, 16379, 354, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27498, 16380, 260, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27499, 16380, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27505, 16383, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27506, 16383, 36, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27507, 16383, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27515, 16386, 12, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (27516, 16386, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27517, 16387, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27518, 16387, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27519, 16387, 234, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (27520, 16388, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27521, 16388, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27522, 16389, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27523, 16389, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27524, 16389, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27525, 16389, 162, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27526, 16390, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27527, 16390, 8, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (27528, 16391, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27529, 16391, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27530, 16391, 126, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27531, 16391, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27534, 16393, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27535, 16393, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27536, 16393, 224, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27537, 16393, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27538, 16394, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27539, 16394, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27540, 16394, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27541, 16394, 8, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (27542, 16395, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27543, 16395, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (27544, 16395, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27545, 16395, 96, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (27546, 16396, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27547, 16396, 262, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27548, 16396, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27549, 16397, 162, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27550, 16397, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27551, 16397, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27552, 16397, 81, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (27553, 16397, 138, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27554, 16397, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (27555, 16398, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27596, 16413, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27597, 16413, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27598, 16413, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27599, 16413, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21780, 14292, 112, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (27600, 16413, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21770, 14289, 149, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21766, 14288, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21749, 14282, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21744, 14281, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21745, 14281, 90, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21774, 14290, 46, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (27558, 16400, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27559, 16400, 94, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27416, 16357, 173, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27417, 16357, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27418, 16357, 59, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27419, 16357, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27556, 4995, 302, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27557, 4995, 234, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (27466, 16371, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27467, 16371, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27468, 16371, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27592, 16412, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27593, 16412, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27594, 16412, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27560, 16401, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27561, 16401, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27562, 16401, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27563, 16401, 310, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (27564, 16402, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27565, 16402, 310, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27566, 16402, 354, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27567, 16402, 73, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31484, 18259, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27578, 16407, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27579, 16407, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27580, 16407, 225, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27584, 16410, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27585, 16410, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27586, 16410, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27587, 16410, 269, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (31485, 18259, 354, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27601, 16414, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27602, 16414, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27603, 16414, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31486, 18259, 168, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27611, 16417, 224, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27612, 16417, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27613, 16417, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17092, 11989, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17093, 11989, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27617, 16419, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27618, 16419, 220, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27619, 16419, 1, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (27620, 16419, 176, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (27621, 16420, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (27622, 16420, 249, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (27623, 16420, 39, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27624, 16421, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27625, 16421, 311, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27626, 16422, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27627, 16422, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15822, 11679, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27604, 16415, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27605, 16415, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27606, 16415, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27500, 16381, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27501, 16381, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27532, 16392, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27349, 16337, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27588, 16411, 3, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (27590, 16411, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27376, 16347, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27377, 16347, 260, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27378, 16347, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27533, 16392, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27574, 16405, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27575, 16405, 211, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27568, 16403, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27569, 16403, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27512, 16385, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27513, 16385, 9, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27514, 16385, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27502, 16382, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27503, 16382, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27504, 16382, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27571, 16404, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27572, 16404, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27573, 16404, 211, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27607, 16416, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27608, 16416, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (27609, 16416, 81, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27581, 16409, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27582, 16409, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27583, 16409, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27576, 16406, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27577, 16406, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27634, 16424, 249, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27635, 16424, 85, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (27636, 16424, 216, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (27637, 16425, 176, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27638, 16425, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27639, 16425, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27645, 16427, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27646, 16427, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27614, 16418, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27615, 16418, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27616, 16418, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27647, 16428, 285, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27648, 16429, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27649, 16429, 268, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27650, 16429, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27651, 16429, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27652, 16430, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27653, 16430, 224, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27654, 16430, 117, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27655, 16431, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27656, 16431, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27657, 16432, 106, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27658, 16432, 24, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27659, 16432, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27660, 16433, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27661, 16434, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27662, 16434, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27663, 16434, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27664, 16434, 214, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27665, 15679, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27666, 15679, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27667, 16435, 193, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (27668, 16435, 143, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27669, 16435, 83, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27670, 16435, 69, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (27671, 16435, 90, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (27672, 16435, 176, 113, 1);
INSERT INTO 'dancesformationsmap' VALUES (27673, 16435, 66, 120, 1);
INSERT INTO 'dancesformationsmap' VALUES (27674, 16436, 45, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27675, 16436, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27676, 16436, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27677, 16436, 333, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27678, 16437, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27679, 16437, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27680, 16437, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27681, 16437, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27682, 16437, 317, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (27683, 16438, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27684, 16438, 30, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27685, 16438, 175, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27686, 16438, 310, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (27694, 16441, 224, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27695, 16441, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27696, 16441, 143, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (27697, 16442, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27698, 16442, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27699, 16443, 214, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27700, 16443, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27701, 16443, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27702, 16444, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27703, 16444, 324, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27704, 16445, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27705, 16445, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27706, 16445, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27707, 16446, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27708, 16446, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27709, 16446, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27710, 16446, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27711, 16447, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27712, 16447, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27713, 16447, 249, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27714, 16447, 183, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (27715, 16448, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27716, 16448, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27717, 16448, 224, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27718, 16448, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27719, 16449, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27720, 16449, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27721, 16449, 144, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27722, 16450, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27723, 16450, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27724, 16451, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27725, 16451, 72, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (27726, 16451, 1, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (27727, 16451, 138, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (9553, 1453, 81, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (9554, 1453, 93, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (9555, 1453, 7, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (27747, 1453, 42, 5, 6);
INSERT INTO 'dancesformationsmap' VALUES (27740, 16452, 193, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (27741, 16452, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27742, 16452, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27743, 16453, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27744, 16453, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27745, 16453, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27746, 16453, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27748, 16454, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27749, 16454, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27750, 16455, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27751, 16455, 120, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27752, 16455, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27753, 16455, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27775, 16460, 158, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27733, 2445, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27734, 2445, 30, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31846, 1264, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27691, 16440, 72, 1, 5);
INSERT INTO 'dancesformationsmap' VALUES (27776, 16460, 7, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27777, 16460, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27763, 7972, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27256, 16306, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27257, 16306, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (27258, 16306, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27736, 5122, 23, 30, 1);
INSERT INTO 'dancesformationsmap' VALUES (27773, 16459, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27774, 16459, 324, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31487, 18259, 317, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27737, 1430, 317, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27738, 1430, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27739, 1430, 76, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27759, 16458, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27760, 16457, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27761, 16457, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27762, 16457, 175, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (27778, 16461, 112, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27779, 16461, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (27780, 16461, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27735, 2445, 131, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27783, 8128, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27784, 16462, 186, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27785, 16462, 131, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (27692, 16440, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27693, 16440, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (400, 713, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27756, 16456, 10, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18139, 5443, 45, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23189, 13100, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31882, 4432, 145, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18140, 5443, 93, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (27767, 3102, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27768, 3102, 27, 26, 2);
INSERT INTO 'dancesformationsmap' VALUES (27000, 5444, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27001, 5444, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27002, 5444, 69, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27003, 5444, 23, 12, 1);
INSERT INTO 'dancesformationsmap' VALUES (27782, 11769, 314, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (27640, 16426, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27641, 16426, 183, 7, 3);
INSERT INTO 'dancesformationsmap' VALUES (27642, 16426, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27643, 16426, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27644, 16426, 291, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27757, 16456, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27758, 16456, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27781, 16306, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27769, 5255, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27770, 5255, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31847, 1264, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31849, 1264, 8, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24526, 816, 1, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (27764, 7972, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27765, 7972, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27766, 7972, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27786, 16462, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27787, 16462, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27300, 16321, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (27301, 16321, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27302, 16321, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27303, 16321, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (11625, 10288, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27788, 190, 7, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (27789, 190, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27805, 16465, 316, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27792, 6597, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27887, 16485, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27888, 16486, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27806, 16465, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27824, 16472, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27825, 16472, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27826, 16472, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27909, 16491, 96, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (27796, 13869, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27797, 13869, 92, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (27817, 16470, 202, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27889, 16486, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27890, 16486, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27891, 16486, 119, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (27892, 16486, 287, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (27893, 16486, 4, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (27894, 11713, 138, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27895, 16487, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27896, 16487, 87, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27897, 16487, 33, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27818, 16470, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27819, 16470, 224, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27820, 16470, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10112, 9545, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10113, 9545, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31622, 4057, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31623, 4057, 119, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (31624, 4057, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (27821, 16471, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27822, 16471, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27823, 16471, 129, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26883, 15706, 213, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27947, 16501, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27948, 16501, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27949, 16501, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (15734, 11627, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15735, 11627, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27850, 14566, 203, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27851, 14566, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27852, 14566, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27905, 16490, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27906, 16490, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27907, 16490, 188, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (27858, 14793, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27859, 14793, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27860, 14793, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (20211, 13113, 85, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27865, 14790, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (27866, 14790, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27867, 14790, 145, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27868, 14790, 58, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27869, 16480, 251, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27870, 16480, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27871, 16480, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27872, 16480, 23, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (27873, 16480, 193, 56, 1);
INSERT INTO 'dancesformationsmap' VALUES (16023, 11714, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16024, 11714, 172, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27879, 11550, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16030, 11717, 91, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16031, 11717, 103, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (27880, 16483, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27881, 16483, 3, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27882, 16483, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27883, 16483, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27884, 16483, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27885, 16483, 61, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (27886, 16484, 118, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27902, 16489, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27903, 16489, 188, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (27904, 16489, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27908, 16490, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (31630, 18271, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14133, 11048, 151, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31631, 18271, 111, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27939, 16498, 189, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (27940, 16498, 94, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27941, 16498, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27953, 16503, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27843, 16478, 209, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27807, 16466, 119, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (23981, 3509, 222, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (23982, 3509, 1, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (27844, 16478, 220, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27831, 16474, 90, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27832, 16474, 328, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (27874, 16481, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27875, 16481, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27815, 16469, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27816, 16469, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27945, 16500, 27, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (27946, 16500, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27877, 16482, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27878, 16482, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27876, 16481, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27827, 16473, 93, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (27914, 16492, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27915, 16492, 43, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (27917, 16492, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27934, 16497, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27835, 16476, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27935, 16497, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27936, 16497, 10, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (27926, 16494, 185, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (27919, 16493, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27920, 16493, 52, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27921, 16493, 354, 18, 2);
INSERT INTO 'dancesformationsmap' VALUES (27922, 16493, 43, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (27927, 16494, 121, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27861, 14796, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (989, 1841, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27801, 16464, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27802, 16464, 34, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27853, 14797, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27854, 14797, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27855, 14797, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27928, 16494, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27931, 16496, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (27932, 16496, 354, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27828, 16473, 114, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27829, 16473, 354, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27933, 16496, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27937, 16497, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27845, 16478, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27836, 16476, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27837, 16476, 12, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27838, 16476, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27950, 16501, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27839, 16477, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27840, 16477, 224, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27841, 16477, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27942, 16499, 235, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27943, 16499, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27944, 16499, 42, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (27842, 16477, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27803, 6848, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27804, 6848, 317, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27833, 16475, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27834, 16475, 150, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27910, 16491, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (27911, 16491, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27912, 16491, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27913, 16491, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27954, 16503, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27955, 16503, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31883, 4432, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27929, 16495, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (27930, 16495, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27847, 14601, 234, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (13617, 10784, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19606, 10784, 143, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (7070, 7020, 112, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27793, 7020, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27987, 16515, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27988, 16515, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28066, 16593, 75, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28067, 16593, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28068, 16594, 42, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (22703, 14636, 193, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24766, 15459, 330, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (27978, 16511, 92, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27964, 16507, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27983, 16514, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (27997, 16538, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27998, 16538, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27999, 16538, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28000, 16538, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28069, 16594, 263, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28070, 16594, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27951, 16502, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27952, 16502, 297, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24295, 14813, 70, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28094, 16674, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28095, 16674, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28071, 9933, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28096, 16674, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28097, 16674, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28098, 16674, 165, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28099, 16675, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28100, 16675, 8, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (28101, 16675, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27984, 16514, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27972, 16508, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27973, 16508, 283, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27974, 16508, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28005, 16567, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28006, 16567, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28010, 16569, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28011, 16569, 262, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28012, 16569, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28013, 16569, 23, 29, 6);
INSERT INTO 'dancesformationsmap' VALUES (28075, 16618, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28076, 16618, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28127, 16681, 93, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (28128, 16681, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (27989, 16516, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28023, 16580, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28024, 16580, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28025, 16580, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28026, 16581, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28027, 16581, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28028, 16581, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28029, 16582, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28030, 16582, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28031, 16582, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28032, 16582, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28033, 16583, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28034, 16583, 353, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28035, 16583, 186, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28036, 16584, 183, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28037, 16584, 117, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28038, 16584, 321, 0, 4);
INSERT INTO 'dancesformationsmap' VALUES (28039, 16584, 193, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28040, 16585, 188, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28041, 16585, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28042, 16585, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28043, 16585, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28044, 16586, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28045, 16586, 119, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28046, 16586, 96, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28047, 16587, 2, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28048, 16587, 154, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28049, 16587, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28050, 16587, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28051, 16587, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28052, 16588, 154, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28053, 16588, 354, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28054, 16589, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28055, 16589, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28056, 16589, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28057, 16589, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28063, 16592, 358, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28064, 16592, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28065, 16592, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31635, 12095, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31636, 12095, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31637, 12095, 183, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28088, 16623, 189, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28089, 16623, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28085, 16621, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28086, 16621, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28087, 16621, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28091, 16673, 69, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28092, 16673, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28093, 16673, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28105, 16677, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28106, 16677, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28107, 16677, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28108, 16677, 24, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3942, 224, 43, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (27977, 224, 333, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27985, 16514, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28072, 9933, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28073, 9933, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28074, 9933, 36, 26, 2);
INSERT INTO 'dancesformationsmap' VALUES (28082, 16620, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28083, 16620, 189, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28084, 16620, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28090, 16623, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27975, 16509, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28102, 16676, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28103, 16676, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28104, 16676, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27995, 16521, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27996, 16521, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28113, 16678, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28114, 16678, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28115, 16678, 69, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28109, 16617, 1, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (28110, 16617, 265, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28111, 16617, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27956, 16504, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28058, 16590, 9, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28014, 16570, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28015, 16570, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28016, 16570, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28017, 16570, 29, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (27965, 16507, 127, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (27990, 16516, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28059, 16590, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27957, 16504, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27958, 16504, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28020, 16571, 52, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (28021, 16571, 82, 2, 0);
INSERT INTO 'dancesformationsmap' VALUES (28120, 16679, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28121, 16679, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28122, 16679, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28022, 16571, 93, 3, 0);
INSERT INTO 'dancesformationsmap' VALUES (28123, 16679, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27961, 16506, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27962, 16506, 20, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27963, 16506, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28007, 16568, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (13922, 10904, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28060, 16591, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28061, 16591, 93, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (13923, 10904, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22738, 14649, 227, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28008, 16568, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28009, 16568, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27986, 16514, 363, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28151, 16688, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28152, 16688, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28153, 16688, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28154, 16688, 317, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (28155, 16688, 96, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (28163, 16691, 92, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28164, 16691, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28165, 16691, 222, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28166, 16691, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28168, 16693, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28169, 16693, 224, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28170, 16693, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28171, 16693, 324, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28172, 16693, 176, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (28173, 16693, 66, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (28174, 16693, 224, 77, 2);
INSERT INTO 'dancesformationsmap' VALUES (28175, 16693, 152, 89, 2);
INSERT INTO 'dancesformationsmap' VALUES (28176, 16693, 149, 113, 1);
INSERT INTO 'dancesformationsmap' VALUES (28002, 3524, 143, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (31850, 2534, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28003, 3524, 84, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (31884, 4489, 133, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27982, 16513, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27959, 16505, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27993, 16518, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27994, 16518, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27979, 16512, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27980, 16512, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27960, 16505, 131, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28079, 16619, 220, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28080, 16619, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28181, 16695, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28182, 16695, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28183, 16695, 96, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28222, 16706, 43, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (28167, 16692, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31633, 13897, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28228, 16708, 93, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (28229, 16708, 203, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (28230, 16708, 354, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (28233, 16710, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28234, 16710, 88, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28235, 16711, 114, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28236, 16711, 188, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28237, 16712, 2, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28238, 16712, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28239, 16713, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28240, 16713, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28241, 16713, 360, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28242, 16713, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28243, 16714, 164, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28244, 16714, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28188, 16698, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28189, 16698, 58, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28190, 16698, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28191, 16698, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28192, 16698, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28193, 16698, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28245, 16714, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28196, 984, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28197, 984, 9, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (28206, 4933, 301, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (8155, 6449, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8156, 6449, 132, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (28199, 9465, 333, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28200, 9465, 67, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (28201, 1038, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28202, 1038, 123, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28255, 16717, 30, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28256, 16717, 360, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28257, 16717, 164, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28205, 7282, 23, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (28258, 16717, 216, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28209, 16701, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28210, 16701, 360, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28211, 16701, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28215, 16703, 42, 0, 4);
INSERT INTO 'dancesformationsmap' VALUES (28216, 16703, 203, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28217, 16703, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28218, 16704, 114, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28219, 16704, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28220, 16705, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28221, 16705, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28224, 16707, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28225, 16707, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28226, 16707, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28227, 16707, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28260, 16719, 324, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28261, 16719, 114, 0, 4);
INSERT INTO 'dancesformationsmap' VALUES (28262, 16719, 360, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28263, 16720, 23, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28264, 16720, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28265, 16721, 329, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28266, 16721, 261, 0, 3);
INSERT INTO 'dancesformationsmap' VALUES (28267, 16722, 222, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28268, 16722, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28269, 16722, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28270, 16722, 96, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28271, 16722, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28272, 16723, 96, 0, 4);
INSERT INTO 'dancesformationsmap' VALUES (31634, 13897, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (28292, 16725, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28293, 16725, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28147, 16686, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28148, 16686, 39, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28281, 16728, 235, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28282, 16728, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28283, 16728, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28286, 16730, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (28287, 16730, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28160, 16690, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28161, 16690, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28162, 16690, 55, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28223, 16706, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26014, 6644, 33, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (28231, 16709, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28232, 16709, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28136, 16684, 96, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (28137, 16684, 36, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28138, 16684, 8, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (28150, 16687, 81, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28177, 16694, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28116, 16678, 117, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28259, 16718, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28117, 16678, 176, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (28129, 16681, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28141, 16685, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28142, 16685, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28143, 16685, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28144, 16685, 96, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (28130, 16681, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28131, 16682, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28132, 16682, 138, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28133, 16682, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28134, 16682, 176, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28135, 16682, 216, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31929, 18307, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31930, 18307, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31931, 18307, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28294, 16725, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28279, 16727, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28280, 16727, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28149, 16686, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28124, 16680, 359, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28125, 16680, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28126, 16680, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28118, 16678, 90, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (28178, 16694, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28156, 16689, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28157, 16689, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28158, 16689, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28139, 16684, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22153, 14405, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22181, 14419, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (27404, 15691, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28288, 16730, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28295, 16725, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28380, 16522, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28311, 2585, 23, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (28312, 1957, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28313, 7436, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28314, 7436, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28315, 7436, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28318, 15140, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28289, 16536, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25140, 15710, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28379, 15710, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28184, 16696, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28185, 16696, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28208, 12450, 143, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28207, 5637, 16, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28001, 5803, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11197, 10072, 42, 17, 6);
INSERT INTO 'dancesformationsmap' VALUES (28299, 10072, 157, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (28276, 16726, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28277, 16726, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28278, 16726, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28319, 15140, 183, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28442, 16526, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24659, 15425, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10058, 9528, 27, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28081, 16619, 85, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28198, 11709, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22588, 14598, 39, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (28194, 14598, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28195, 14598, 41, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28302, 2084, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28303, 2084, 23, 8, 4);
INSERT INTO 'dancesformationsmap' VALUES (28304, 2084, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28305, 2084, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28187, 16697, 326, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (28316, 5575, 333, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28317, 5575, 132, 26, 2);
INSERT INTO 'dancesformationsmap' VALUES (28284, 16729, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28296, 6394, 265, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28297, 6394, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28298, 6394, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28203, 16699, 154, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (28246, 16715, 42, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (28248, 16715, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28249, 16715, 360, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28204, 16699, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28285, 16729, 51, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24660, 15425, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (31639, 18272, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28326, 16735, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28327, 16735, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14803, 11188, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28424, 16759, 56, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17528, 12123, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28330, 16736, 120, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28331, 16736, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28425, 16759, 313, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (28426, 16759, 354, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (28427, 16759, 182, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (28339, 3038, 127, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28340, 3038, 29, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (11756, 10309, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28341, 10309, 235, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28342, 9980, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28343, 9980, 56, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (28344, 9980, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28443, 16526, 241, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28306, 16466, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28335, 16738, 94, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28336, 16738, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28444, 16526, 307, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28390, 16751, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28391, 16751, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28392, 16751, 96, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28393, 16751, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28404, 16755, 15, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28405, 16755, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28406, 16755, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28407, 16755, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28408, 16755, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28409, 16755, 96, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (31640, 18272, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31642, 18273, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28414, 16757, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28415, 16757, 21, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28416, 16757, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28417, 16757, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28418, 16757, 154, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28419, 16757, 29, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (31643, 18273, 280, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31644, 18273, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31641, 18272, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28396, 16753, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28397, 16753, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28398, 16753, 120, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28399, 16753, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28307, 16731, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28309, 16731, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28310, 16731, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28428, 16760, 81, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28430, 16760, 356, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28431, 16760, 93, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (28345, 16739, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28348, 16740, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28349, 16740, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28350, 16740, 280, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28351, 16741, 30, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28352, 16741, 24, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28358, 16743, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28359, 16743, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28360, 16743, 134, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28361, 16743, 96, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (28388, 16750, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28440, 16525, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28371, 16747, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28372, 16747, 19, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28373, 16747, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28369, 16746, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28370, 16746, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28374, 16748, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28375, 16748, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28376, 16748, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28377, 16749, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28378, 16749, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28362, 16744, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28363, 16744, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28410, 16756, 354, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28411, 16756, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20242, 13127, 262, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20243, 13127, 92, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28420, 16758, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28421, 16758, 334, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28422, 16758, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28364, 16744, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28441, 16525, 362, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28381, 16522, 109, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28432, 16760, 361, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (28320, 16733, 145, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28321, 16733, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28322, 16733, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28346, 16739, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28347, 16739, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28353, 16741, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28354, 16741, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (21996, 14358, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28451, 16772, 84, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (28452, 16772, 165, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28453, 16772, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28454, 16772, 29, 29, 4);
INSERT INTO 'dancesformationsmap' VALUES (28455, 12845, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28456, 12845, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28457, 12845, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28458, 16773, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28459, 16773, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28482, 16785, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28483, 16785, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28484, 16785, 32, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27798, 13869, 36, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (27799, 13869, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (27800, 13869, 356, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28526, 3483, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28554, 16709, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28412, 16756, 354, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28413, 16756, 27, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28472, 11538, 132, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28473, 11538, 69, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28474, 5000, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28475, 5000, 216, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28476, 16633, 322, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28477, 16633, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28478, 16633, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28479, 16633, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28480, 16634, 119, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28481, 16634, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28531, 5503, 20, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (28489, 7878, 43, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (28490, 7878, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28485, 16786, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28486, 16786, 157, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28487, 16786, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28488, 16786, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28323, 16734, 110, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28273, 16724, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28324, 16734, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28290, 16536, 83, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (28355, 16742, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28356, 16742, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28357, 16742, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28437, 16524, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28438, 16524, 234, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28332, 16737, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28333, 16737, 23, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (28334, 16737, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31645, 13898, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31646, 13898, 188, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31647, 13898, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28400, 16754, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28401, 16754, 240, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28402, 16754, 154, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28403, 16754, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28366, 16745, 156, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25388, 15792, 328, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (28367, 16745, 263, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28368, 16745, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31885, 1751, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31886, 1751, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18206, 11105, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18207, 11105, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18208, 11105, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31881, 4432, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21559, 13705, 43, 24, 1);
INSERT INTO 'dancesformationsmap' VALUES (21560, 13705, 23, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (22531, 13449, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22532, 13449, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28394, 16752, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28395, 16752, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28328, 9528, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28491, 4830, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28508, 15326, 110, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28509, 15326, 228, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28499, 15032, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28495, 7501, 36, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (28496, 7501, 83, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (10090, 9540, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28466, 9540, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28119, 16678, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (28467, 16776, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28468, 16776, 12, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28527, 3483, 33, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (28528, 3483, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28510, 1708, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28511, 1708, 269, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28469, 16776, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3794, 7149, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6248, 7149, 367, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28512, 7149, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28529, 3466, 2, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (28530, 3466, 183, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (26803, 16149, 24, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23370, 14382, 9, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (28547, 16816, 154, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21253, 13628, 190, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (23079, 14892, 112, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28523, 16804, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28524, 16804, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28525, 16804, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22233, 14427, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22234, 14427, 63, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28555, 10028, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28556, 10028, 168, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28557, 10028, 157, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (28558, 4266, 138, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28540, 8335, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28541, 8335, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28542, 8335, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28567, 16823, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28500, 15032, 23, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (28501, 15032, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15372, 10213, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28543, 16815, 273, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28568, 16823, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28569, 16823, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (28570, 16823, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7583, 2437, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28571, 14025, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28572, 14025, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28573, 14025, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28574, 14025, 132, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (28575, 14025, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28576, 16824, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28577, 16824, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28578, 16824, 23, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (28579, 16824, 220, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28580, 16824, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28546, 7339, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (9965, 9482, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10326, 9674, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28471, 2563, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10327, 9674, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28560, 13931, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21254, 13628, 30, 12, 1);
INSERT INTO 'dancesformationsmap' VALUES (9966, 9482, 263, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28559, 15275, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28548, 16816, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28549, 16816, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28550, 16816, 321, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28539, 9674, 7, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (28561, 13931, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28562, 13931, 145, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28563, 13931, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28544, 16815, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28545, 16815, 72, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (28693, 1985, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28621, 16639, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28622, 16639, 354, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28623, 16639, 81, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28624, 16639, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (28629, 16641, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28630, 16641, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28631, 16641, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28632, 16642, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28633, 16642, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28634, 16642, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28635, 16642, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28636, 16642, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28637, 16643, 143, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28638, 16643, 143, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28639, 16643, 1, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (28640, 16643, 23, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (28641, 16644, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28642, 16644, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28651, 16647, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28652, 16647, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28653, 16647, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28660, 16649, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28661, 16649, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28662, 16649, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28663, 16649, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28664, 16649, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28665, 16649, 56, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28666, 16649, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28667, 16650, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28668, 16650, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28669, 16650, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28670, 16650, 81, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28671, 16650, 142, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28598, 9927, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31638, 13897, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28738, 8856, 15, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28739, 8856, 156, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28695, 6459, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28604, 9932, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28694, 1985, 85, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (9814, 9382, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9815, 9382, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28423, 16758, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22965, 780, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19598, 12877, 353, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28688, 16843, 42, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (28689, 16843, 7, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (28690, 16843, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28505, 16800, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (20392, 13164, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (17235, 12076, 87, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (17236, 12076, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (28691, 16842, 209, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28692, 16842, 321, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28616, 16672, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28617, 16672, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28618, 16672, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31887, 1751, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28722, 16852, 303, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28723, 16852, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28709, 16848, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28710, 16848, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28711, 16848, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28703, 16846, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28704, 16846, 114, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28705, 16846, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28606, 16635, 386, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28607, 16635, 154, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28608, 16635, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13031, 10488, 386, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10163, 9561, 32, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (14957, 11461, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28445, 16761, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28446, 16761, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28532, 9640, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28533, 9640, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28534, 9640, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12205, 9058, 23, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (12206, 9058, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15934, 4403, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28460, 16774, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28461, 16774, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28447, 16771, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28448, 16771, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28449, 16771, 235, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28734, 16856, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21682, 13828, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21683, 13828, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21684, 13828, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28564, 16822, 154, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28565, 16822, 186, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28566, 16822, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12210, 9632, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12211, 9632, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28609, 16636, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28610, 16636, 228, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28611, 16636, 261, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (1562, 2979, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28493, 16537, 283, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28494, 16537, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28594, 15437, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9376, 8980, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9377, 8980, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9378, 8980, 53, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11728, 1582, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (28672, 8775, 269, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28673, 8775, 62, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28678, 16840, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28605, 9932, 296, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28741, 2635, 247, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28585, 16827, 260, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28679, 16840, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28680, 16840, 120, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28681, 16840, 121, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28654, 16648, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28655, 16648, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28656, 16648, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28657, 16648, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28658, 16648, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28595, 16838, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28613, 16637, 36, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28614, 16637, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28647, 16646, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28648, 16646, 29, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (28649, 16646, 134, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28596, 16838, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28597, 16838, 305, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26878, 16183, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28599, 9927, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5285, 4239, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9213, 8809, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9214, 8809, 58, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9215, 8809, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19345, 12794, 168, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28742, 16535, 285, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10993, 2484, 90, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28586, 16827, 129, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28588, 16828, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28589, 16828, 224, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28590, 16828, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28674, 16839, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28675, 16839, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28676, 16839, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (28683, 8371, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (28684, 8371, 8, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (28685, 8371, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28600, 9928, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28601, 9928, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (28602, 9928, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28603, 9928, 119, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (28867, 16905, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28802, 10610, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28803, 10596, 154, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (28804, 10596, 23, 5, 6);
INSERT INTO 'dancesformationsmap' VALUES (28805, 10596, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (22735, 14648, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28751, 16858, 90, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (28752, 16858, 56, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (28753, 16858, 183, 6, 4);
INSERT INTO 'dancesformationsmap' VALUES (28754, 16858, 209, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28755, 16858, 210, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (28756, 16858, 83, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (28757, 16858, 85, 73, 2);
INSERT INTO 'dancesformationsmap' VALUES (28758, 16858, 29, 41, 4);
INSERT INTO 'dancesformationsmap' VALUES (28806, 10609, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28807, 10609, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28808, 10608, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28809, 10608, 273, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28760, 15613, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28761, 15613, 183, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (28762, 15613, 12, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28763, 15613, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28764, 15613, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28773, 15038, 164, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28774, 15038, 332, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28775, 15038, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28810, 10608, 29, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (28851, 16900, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28852, 16900, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28877, 16907, 29, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (22272, 14435, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28813, 14435, 251, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (28837, 16896, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28776, 16868, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28777, 16868, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28778, 16868, 189, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (28779, 8492, 23, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (1977, 3739, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28814, 3739, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28815, 3739, 183, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (11934, 6051, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28816, 3739, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28817, 7234, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28818, 7234, 83, 10, 11);
INSERT INTO 'dancesformationsmap' VALUES (7651, 4998, 39, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (5903, 6078, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28868, 16905, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26832, 14964, 155, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26833, 14964, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28791, 16871, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28792, 16871, 58, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28793, 16871, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28794, 16871, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28783, 7559, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28784, 7559, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28785, 7559, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28786, 7559, 96, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28854, 16901, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (28855, 16901, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22312, 3405, 36, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28798, 10610, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28799, 10610, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28800, 10610, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28801, 10610, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28795, 16872, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28796, 16872, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28797, 16872, 82, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (31891, 13824, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28846, 16899, 39, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28847, 16899, 220, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28859, 16895, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28826, 10698, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28759, 6612, 354, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28728, 16854, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28729, 16854, 224, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12798, 8511, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12799, 8511, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28725, 16853, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28726, 16853, 75, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28727, 16853, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28724, 16852, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28715, 16850, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (28716, 16850, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28717, 16850, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28712, 16849, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28713, 16849, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28714, 16849, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28700, 16845, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28701, 16845, 188, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (28702, 16845, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28696, 16844, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28697, 16844, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28698, 16844, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28591, 16829, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28592, 16829, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28593, 16829, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28747, 14457, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28748, 14457, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28749, 14457, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13032, 10488, 77, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (28765, 7504, 43, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (28766, 7504, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28767, 7504, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31654, 13899, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31655, 13899, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31656, 13899, 162, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31657, 13899, 42, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (3033, 5788, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19678, 12902, 355, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19679, 12902, 92, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28743, 10879, 143, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (1667, 3174, 72, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (28819, 16888, 340, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28820, 16888, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28821, 16888, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28625, 16640, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28627, 16640, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (2424, 4629, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4556, 2063, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28744, 16857, 214, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28864, 16904, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28865, 16904, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28838, 16896, 213, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24527, 816, 373, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28875, 2833, 29, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (28876, 2833, 36, 22, 1);
INSERT INTO 'dancesformationsmap' VALUES (28682, 16840, 328, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28891, 1128, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (28892, 1128, 72, 20, 1);
INSERT INTO 'dancesformationsmap' VALUES (10703, 9864, 91, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28881, 859, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16522, 11903, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13413, 10575, 109, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28839, 16896, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28787, 16870, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28788, 16870, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28862, 16903, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28863, 16903, 183, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (28789, 16870, 302, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28830, 16893, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28823, 6671, 43, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (28831, 16893, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28832, 16893, 154, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (28833, 16894, 121, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28834, 16894, 278, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28835, 16894, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28836, 16894, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28841, 16897, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28842, 16897, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11935, 6051, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (11936, 6051, 43, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (26871, 6051, 9, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26872, 6051, 18, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (28860, 14534, 235, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28878, 16907, 13, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28861, 14534, 15, 26, 2);
INSERT INTO 'dancesformationsmap' VALUES (28824, 6671, 36, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28889, 16527, 189, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (28897, 16908, 175, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28898, 16908, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28899, 16908, 203, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28900, 16908, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28901, 16908, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (9721, 9341, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2910, 5558, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28912, 16913, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28913, 16913, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28959, 16937, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28960, 16937, 75, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28961, 16937, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28958, 16936, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28909, 16911, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26582, 16094, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26232, 16034, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (26233, 16034, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28948, 16930, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28954, 16933, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25369, 15784, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25370, 15784, 126, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25371, 15784, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24238, 15004, 154, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (27570, 16403, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7767, 1485, 33, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (14881, 11436, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28962, 16938, 30, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28963, 16938, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28964, 16938, 112, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28965, 16938, 7, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28966, 16938, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31658, 13900, 84, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31659, 13900, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28972, 5957, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13414, 10575, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28973, 10956, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28974, 10956, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16803, 3945, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16804, 3945, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31660, 13900, 9, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28180, 16694, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7867, 8231, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15364, 10209, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15361, 10208, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24851, 15551, 143, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (8269, 8594, 153, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8270, 8594, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8271, 8594, 155, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27610, 16416, 354, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (7882, 8240, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8238, 8292, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28659, 16648, 33, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (7835, 8205, 7, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (28978, 8205, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28984, 10744, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28985, 10744, 111, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28986, 16945, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28987, 16945, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28988, 16945, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28989, 16946, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28990, 16946, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28991, 16946, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28992, 16946, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26700, 16124, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (14586, 3008, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14587, 3008, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14588, 3008, 120, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14589, 3008, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14590, 3008, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27123, 16259, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8307, 8612, 2, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8312, 8617, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27511, 16384, 4, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28907, 16910, 307, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16349, 11829, 112, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28895, 8042, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13584, 10772, 164, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28869, 16906, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20990, 13309, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (1047, 1946, 73, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20991, 13309, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28975, 16941, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28976, 16941, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28827, 10698, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28828, 10698, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28918, 16916, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28919, 16916, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28829, 10698, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28780, 16869, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28781, 16869, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8845, 4282, 76, 65, 3);
INSERT INTO 'dancesformationsmap' VALUES (22991, 14739, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17792, 9325, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28920, 16917, 225, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28921, 16917, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (16171, 11774, 112, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (16172, 11774, 372, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (13330, 10539, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16747, 11971, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28945, 16929, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28946, 16929, 13, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (28947, 16929, 114, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17793, 9325, 62, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28745, 16857, 61, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (17704, 11899, 124, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28825, 5802, 9, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (28879, 14453, 138, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28880, 14453, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28750, 14457, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19547, 12387, 54, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28915, 16915, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28916, 16915, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13018, 10483, 59, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (28707, 16847, 324, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28887, 9470, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28888, 9470, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28951, 16932, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28952, 16932, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28902, 16909, 180, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28981, 10745, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28982, 10745, 30, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28983, 10745, 9, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19548, 12387, 52, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (28893, 5170, 33, 5, 5);
INSERT INTO 'dancesformationsmap' VALUES (28894, 5170, 157, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28957, 16935, 193, 40, 2);
INSERT INTO 'dancesformationsmap' VALUES (28955, 16934, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28882, 16732, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28886, 14655, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28956, 16934, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9026, 7967, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9027, 7967, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28735, 16856, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28736, 16856, 280, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28737, 16856, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (17705, 11899, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17706, 11899, 231, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23529, 15098, 301, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (28943, 16928, 280, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28910, 16912, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28908, 16910, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28923, 16918, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24552, 12036, 58, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28926, 16920, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28927, 16920, 123, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (28930, 16922, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28931, 16923, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28932, 16923, 183, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (28933, 16923, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28934, 16924, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28935, 16924, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28936, 16924, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28937, 16924, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28949, 16931, 307, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28950, 16931, 114, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28944, 16928, 42, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (28911, 16912, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28914, 16913, 52, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (13671, 10798, 36, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (28979, 8204, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28993, 15740, 29, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28994, 15740, 96, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (23530, 15098, 176, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (16805, 3945, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16806, 3945, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28941, 16926, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28942, 16926, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28924, 16919, 226, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28925, 16919, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28995, 16954, 13, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28996, 16954, 235, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29107, 16984, 249, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29108, 16984, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29002, 6653, 8, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (29003, 6653, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29004, 6170, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29005, 6170, 46, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29006, 6170, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (29007, 6170, 8, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (29008, 6170, 23, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (29009, 6170, 2, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (29010, 14613, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29011, 14613, 324, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28866, 16904, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21417, 13680, 246, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (28999, 14789, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29000, 14789, 332, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29001, 14789, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29012, 16960, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29016, 2831, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29017, 2831, 38, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29018, 8740, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29019, 8740, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29020, 8740, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29021, 6220, 56, 9, 5);
INSERT INTO 'dancesformationsmap' VALUES (29022, 6220, 361, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29023, 6715, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29024, 6715, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29025, 6717, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29026, 6717, 353, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29027, 10932, 154, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (29028, 10932, 93, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (29029, 10932, 119, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (2814, 5389, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29030, 8332, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29031, 8332, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29032, 8332, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29033, 8332, 36, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (29034, 8332, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28840, 16896, 239, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24299, 15336, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29109, 16984, 318, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29110, 16984, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29111, 16984, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29035, 16964, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29036, 16964, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29037, 16964, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29117, 16986, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29118, 16986, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29119, 16987, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29043, 231, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29120, 16987, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29121, 16987, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29041, 16965, 162, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29042, 16965, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29047, 16966, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29048, 16966, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29049, 16966, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29050, 16967, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29051, 16967, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29052, 16967, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29053, 16967, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29054, 16968, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29055, 16968, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29056, 16969, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29057, 16969, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29058, 16969, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29059, 16969, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29060, 16970, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29061, 16970, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29062, 16970, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29063, 16971, 18, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29064, 16971, 332, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29065, 16971, 76, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29066, 16971, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29067, 16972, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29068, 16972, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29069, 16972, 221, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29070, 16973, 27, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29071, 16973, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29072, 16973, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29073, 16973, 334, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29074, 16974, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29075, 16974, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29076, 16974, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29077, 16974, 26, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29078, 16975, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29079, 16975, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29080, 16975, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29084, 16977, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29085, 16977, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29086, 16977, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29087, 16977, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29091, 16979, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29092, 16979, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29093, 16980, 101, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29094, 16980, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29095, 16981, 119, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29096, 16981, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29097, 16981, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29098, 16981, 186, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29099, 16982, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29100, 16982, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29101, 16982, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29102, 16982, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29104, 16983, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29105, 16983, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29106, 16983, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29122, 16987, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29123, 16987, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29124, 16987, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29125, 16988, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29126, 16988, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29127, 16988, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29128, 16988, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29129, 16989, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29130, 16989, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29131, 16989, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29132, 16989, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29133, 16989, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29134, 16990, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29135, 16990, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29136, 16990, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29137, 16990, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29138, 16990, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29139, 16991, 193, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29140, 16991, 234, 0, 6);
INSERT INTO 'dancesformationsmap' VALUES (29044, 16952, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10508, 9757, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24681, 15430, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (28997, 2572, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28998, 2572, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21259, 13640, 38, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (13331, 10539, 164, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28938, 16925, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (28939, 16925, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17707, 11899, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29141, 16991, 209, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29142, 16991, 183, 0, 4);
INSERT INTO 'dancesformationsmap' VALUES (29081, 16976, 386, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29082, 16976, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29083, 16976, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28928, 16921, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28929, 16921, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28903, 16909, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28904, 16909, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29143, 16991, 328, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29144, 16992, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29145, 16992, 148, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29146, 16992, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29147, 16992, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29148, 16992, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29112, 16985, 341, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29113, 16985, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29114, 16985, 84, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29115, 16985, 182, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29116, 16985, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29149, 16993, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29150, 16993, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29151, 16993, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29152, 16994, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29153, 16994, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29154, 16994, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29158, 16996, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29159, 16996, 59, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29160, 16996, 1, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29161, 16997, 318, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29162, 16997, 189, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29163, 16997, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29164, 16997, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29155, 16995, 112, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29013, 16960, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29014, 16960, 72, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29088, 16978, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29089, 16978, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29090, 16978, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23531, 15098, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (29156, 16995, 72, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29157, 16995, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29165, 16998, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29166, 16998, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29167, 16998, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29168, 16998, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29169, 16999, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29170, 16999, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29171, 17000, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29172, 17000, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29173, 17000, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29174, 17001, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29175, 17001, 123, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29176, 17001, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29177, 17001, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29178, 17002, 359, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29179, 17002, 221, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29180, 17003, 157, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29181, 17003, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29182, 17003, 317, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29183, 17003, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29184, 17004, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29185, 17004, 12, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29186, 17004, 119, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29187, 17004, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29188, 17004, 168, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29189, 17005, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29190, 17005, 109, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29191, 17005, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29192, 17005, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29206, 17009, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29207, 17009, 222, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29208, 17009, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29209, 17009, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29210, 17009, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29211, 17009, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29220, 891, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29221, 17012, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29222, 17012, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29223, 17012, 168, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29224, 17012, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29225, 17012, 119, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29226, 17012, 94, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29227, 17013, 321, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29228, 17013, 202, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29229, 17013, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29230, 17013, 102, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29237, 17015, 213, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29238, 17015, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29239, 17015, 339, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29240, 17015, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29241, 17015, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29242, 17016, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29243, 17016, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29244, 17016, 119, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (29212, 17010, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29213, 17010, 62, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29214, 17011, 159, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29215, 17011, 280, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29216, 17011, 145, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29217, 17011, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29218, 17011, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29219, 17011, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29198, 17007, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29285, 17041, 112, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29286, 17041, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (29287, 17041, 321, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (29288, 17041, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (29289, 3915, 251, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (29199, 17007, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29200, 17007, 241, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29245, 17017, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29294, 17042, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29315, 13639, 42, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29295, 17042, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28433, 16760, 234, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (28434, 16760, 52, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (28435, 16760, 1, 81, 2);
INSERT INTO 'dancesformationsmap' VALUES (28436, 16760, 182, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (29246, 17017, 308, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29296, 17042, 112, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (29282, 17028, 7, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (29283, 17037, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29284, 17037, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29312, 17047, 183, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (29297, 17042, 95, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (29298, 17043, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29316, 13639, 43, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29317, 13639, 32, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29318, 13639, 61, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29291, 5955, 7, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29292, 5955, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29319, 17067, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29325, 17069, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29322, 17068, 268, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29323, 17068, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29324, 17068, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29326, 17070, 321, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29327, 17070, 121, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (29328, 17070, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29329, 17070, 72, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (29202, 17008, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29203, 17008, 129, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29204, 17008, 278, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (29205, 17008, 321, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15641, 11601, 49, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15642, 11601, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29281, 11601, 132, 32, 1);
INSERT INTO 'dancesformationsmap' VALUES (29309, 17046, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29310, 17046, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29311, 17046, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (2163, 4103, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6495, 1786, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29038, 6294, 61, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (29039, 6294, 72, 53, 1);
INSERT INTO 'dancesformationsmap' VALUES (29040, 6294, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (27591, 16411, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17863, 12402, 119, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31664, 13901, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31665, 13901, 83, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17864, 12402, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29255, 17020, 111, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29256, 17020, 69, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29257, 17020, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29258, 17020, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (29103, 9388, 18, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29193, 17006, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29194, 17006, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29195, 17006, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29320, 17067, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29299, 17043, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29300, 17043, 175, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29306, 17045, 30, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31892, 18287, 313, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (31893, 18287, 215, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7715, 8113, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7716, 8113, 9, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29259, 17021, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29231, 17014, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29260, 17021, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29261, 17021, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29262, 17022, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29263, 17022, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29264, 17022, 43, 14, 2);
INSERT INTO 'dancesformationsmap' VALUES (29265, 17022, 340, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29267, 17023, 117, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (29268, 17023, 23, 18, 2);
INSERT INTO 'dancesformationsmap' VALUES (29269, 17023, 36, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29293, 5955, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29307, 17045, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29308, 17045, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29313, 17047, 249, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (29314, 17047, 176, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29302, 17044, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29303, 17044, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29304, 17044, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29305, 17044, 181, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (29247, 17018, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29248, 17018, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29249, 17018, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (29250, 17018, 73, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29330, 17070, 204, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29331, 17071, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29332, 17071, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29333, 17071, 112, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29334, 17071, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22462, 14560, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29015, 16960, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22400, 14533, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22391, 14535, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29430, 13120, 359, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29339, 17122, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29340, 17122, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29341, 17122, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29361, 3924, 324, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29362, 846, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29363, 846, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (29364, 846, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (868, 1605, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29365, 319, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (29366, 319, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29367, 319, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (29368, 286, 225, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (29369, 286, 119, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29370, 286, 119, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (29371, 2206, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29372, 2206, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29373, 1979, 176, 20, 1);
INSERT INTO 'dancesformationsmap' VALUES (29374, 1979, 185, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14203, 11070, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14204, 11070, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29375, 14201, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29376, 14201, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29377, 14201, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29378, 14201, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29379, 14201, 142, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29380, 14201, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23042, 14809, 157, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29384, 16657, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29385, 16657, 343, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29386, 16657, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22190, 13726, 162, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29358, 17135, 145, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29359, 17135, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29360, 17135, 213, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15105, 8869, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29401, 13516, 78, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29402, 13516, 28, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29398, 13545, 29, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29399, 13545, 143, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29400, 13545, 1, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29393, 11388, 5, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29394, 11388, 92, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29418, 17154, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29419, 17172, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29422, 17194, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29423, 17194, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29424, 17194, 359, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (29425, 17194, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29426, 13623, 134, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29427, 13623, 83, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29428, 13623, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29429, 13623, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (26076, 15991, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26055, 15985, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29408, 17144, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29431, 13120, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31650, 13896, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31651, 13896, 222, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31652, 13896, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31653, 13896, 70, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (11173, 10064, 374, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11174, 10064, 162, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (3458, 6541, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27111, 16255, 42, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (29457, 14879, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21019, 13316, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21020, 13316, 134, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29344, 17113, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29345, 17113, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21021, 13316, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27918, 16492, 249, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (27938, 16497, 96, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (27924, 16493, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27925, 16493, 154, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (29387, 16658, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29388, 16658, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29350, 17103, 48, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (28980, 8204, 132, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22463, 14560, 132, 21, 8);
INSERT INTO 'dancesformationsmap' VALUES (29351, 17102, 39, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29352, 17102, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29432, 13120, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29353, 17102, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29354, 17102, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14083, 11036, 312, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29443, 17304, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29444, 17304, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29445, 17304, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29346, 17113, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22394, 14536, 58, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7037, 6634, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29381, 16656, 235, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29382, 16656, 334, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22430, 14537, 17, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22208, 14421, 1, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (22209, 14421, 86, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12374, 10388, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12375, 10388, 7, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (29415, 17176, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29416, 17176, 213, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13129, 10501, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13130, 10501, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15914, 8465, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13255, 7547, 183, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (13256, 7547, 120, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (29434, 13121, 209, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29435, 13121, 56, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (5489, 4875, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5349, 4438, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29395, 17150, 16, 9, 11);
INSERT INTO 'dancesformationsmap' VALUES (29396, 17150, 131, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29397, 17150, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29355, 14723, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29356, 14723, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29357, 14723, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29448, 17316, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29449, 17316, 192, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29450, 17316, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29347, 17106, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29348, 17106, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29349, 17106, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29433, 13120, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (29405, 17152, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29406, 17152, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29392, 11800, 9, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (29403, 17151, 42, 9, 0);
INSERT INTO 'dancesformationsmap' VALUES (29404, 17151, 294, 13, 0);
INSERT INTO 'dancesformationsmap' VALUES (29458, 14879, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29459, 14879, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29460, 14879, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29461, 17331, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29462, 17331, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29463, 17331, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29464, 17331, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28969, 16939, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28970, 16939, 39, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (28971, 16939, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29335, 17121, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29336, 17121, 119, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (29337, 17121, 283, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (29338, 17121, 283, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (8605, 8714, 38, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (20250, 13140, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29407, 10563, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29412, 17166, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29413, 17166, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29414, 17166, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29389, 16659, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29390, 16659, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29273, 17024, 386, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29274, 17024, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (29275, 17024, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20251, 13140, 176, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20252, 13140, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20274, 13147, 193, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (9158, 8104, 158, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9159, 8104, 8, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15971, 8479, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28145, 16685, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28146, 16685, 9, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (29542, 1062, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29543, 1062, 29, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (29512, 16046, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29465, 17233, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29544, 1062, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24406, 15399, 183, 12, 2);
INSERT INTO 'dancesformationsmap' VALUES (29554, 17195, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (29555, 17195, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29545, 14262, 87, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (29546, 14262, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29547, 14262, 183, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29548, 14262, 23, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (29549, 14262, 25, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (29550, 1170, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29523, 10497, 317, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29529, 17143, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29522, 16473, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29530, 17143, 10, 29, 8);
INSERT INTO 'dancesformationsmap' VALUES (29486, 17385, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29487, 17385, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29488, 17385, 246, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29489, 17385, 213, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29551, 1170, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29552, 1170, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29553, 1170, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29524, 16614, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29491, 2179, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29492, 2179, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29493, 2179, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29494, 13872, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29495, 13872, 188, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (29496, 13872, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29497, 13872, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29525, 16614, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29490, 16894, 33, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (29498, 13870, 7, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29499, 13870, 249, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (29500, 13870, 69, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29501, 13870, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29502, 13870, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29503, 13871, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29504, 13871, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29505, 13871, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29526, 16614, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29527, 16614, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (29506, 13873, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29507, 13873, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29508, 13873, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29476, 17383, 42, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (28018, 16570, 234, 37, 6);
INSERT INTO 'dancesformationsmap' VALUES (28019, 16570, 112, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (23821, 15186, 7, 12, 1);
INSERT INTO 'dancesformationsmap' VALUES (23822, 15186, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29556, 17195, 321, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (29472, 17382, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29473, 17382, 294, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29474, 17382, 203, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29586, 17406, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29584, 17406, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29468, 17335, 42, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (29469, 17335, 123, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29558, 12321, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29513, 17388, 26, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29514, 17388, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29515, 17388, 217, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29516, 17388, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (29559, 12321, 96, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (29560, 12321, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29561, 12321, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29538, 17139, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29539, 17139, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29540, 17139, 303, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29481, 17384, 48, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29482, 17384, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (29483, 17384, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (29471, 6728, 33, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29466, 17233, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29467, 17233, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29580, 17347, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29581, 17347, 29, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (29582, 17347, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29600, 16855, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29528, 16613, 273, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29571, 9972, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29572, 17394, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29573, 17394, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29574, 17394, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29575, 17394, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29576, 17395, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29577, 17395, 358, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29578, 17395, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29579, 17395, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (29601, 16855, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29599, 16855, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27771, 5255, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27772, 5255, 374, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29475, 17383, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18181, 12512, 372, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18182, 12512, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18183, 12512, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29587, 17406, 93, 21, 8);
INSERT INTO 'dancesformationsmap' VALUES (29557, 17195, 56, 27, 4);
INSERT INTO 'dancesformationsmap' VALUES (29608, 17419, 143, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29609, 17419, 193, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (18184, 12512, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18185, 12512, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29566, 17393, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29615, 15606, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (29616, 15606, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29617, 15606, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (29618, 15606, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29627, 17422, 184, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29628, 17422, 124, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29629, 17422, 90, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29630, 17422, 9, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29631, 17421, 112, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29619, 17120, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29610, 17413, 87, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29611, 17413, 143, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29565, 17392, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29624, 17424, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29625, 17424, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29420, 17177, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29421, 17177, 10, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29562, 17391, 265, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (29563, 17391, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23968, 6130, 371, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23969, 6130, 133, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23970, 6130, 86, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (14527, 280, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29509, 17386, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31662, 13901, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31663, 13901, 324, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29510, 17386, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29511, 17386, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29590, 16801, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29591, 16801, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29592, 16801, 114, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14547, 11223, 372, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11049, 10007, 372, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19154, 8039, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17708, 11899, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29477, 17265, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29620, 17120, 214, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (19102, 1414, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29656, 17458, 87, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29567, 17393, 88, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1448, 2737, 221, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29668, 2737, 69, 265, 1);
INSERT INTO 'dancesformationsmap' VALUES (29669, 2737, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29634, 17425, 12, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29671, 8314, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31666, 13902, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29612, 17415, 89, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29613, 17415, 59, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29614, 17415, 61, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (11660, 10291, 29, 20, 2);
INSERT INTO 'dancesformationsmap' VALUES (29604, 17412, 29, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (14315, 5900, 82, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (29633, 17411, 29, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29621, 17417, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29622, 17417, 119, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (29623, 17417, 240, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29657, 17460, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29736, 17524, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29737, 17524, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29535, 2931, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26910, 16186, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29536, 2931, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29632, 17420, 112, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (7792, 4217, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31935, 4217, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29602, 17349, 386, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29603, 17349, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29606, 17418, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29597, 17410, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15907, 8462, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29607, 17418, 269, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29742, 17526, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29641, 17283, 20, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29642, 17283, 192, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29680, 17404, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29681, 17404, 15, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29682, 17404, 189, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29683, 17404, 5, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (29658, 17460, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29684, 17480, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29647, 546, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13587, 10773, 260, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29685, 12457, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (29686, 12457, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (22959, 4511, 176, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29701, 10291, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29648, 220, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29649, 220, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29650, 220, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29651, 220, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29702, 12365, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29675, 17479, 74, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29676, 17479, 69, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29677, 17138, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29706, 10592, 33, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (29703, 12365, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29704, 12365, 81, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29714, 17485, 154, 19, 4);
INSERT INTO 'dancesformationsmap' VALUES (29720, 17485, 332, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (15443, 11393, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29678, 17138, 154, 19, 3);
INSERT INTO 'dancesformationsmap' VALUES (8259, 8588, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15097, 8849, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29705, 11393, 154, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (15567, 11583, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (15568, 11583, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15569, 11583, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29689, 17481, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29690, 17481, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (29691, 17481, 154, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29692, 17481, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29695, 17482, 294, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29696, 17482, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29697, 17482, 192, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (29727, 2768, 332, 11, 3);
INSERT INTO 'dancesformationsmap' VALUES (22375, 6205, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29728, 2768, 1, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (29679, 17138, 166, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (29687, 12455, 43, 5, 6);
INSERT INTO 'dancesformationsmap' VALUES (29688, 12455, 29, 43, 2);
INSERT INTO 'dancesformationsmap' VALUES (29635, 17425, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29636, 17425, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29722, 12803, 23, 6, 8);
INSERT INTO 'dancesformationsmap' VALUES (26259, 16041, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (29710, 13577, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29723, 12803, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29724, 12803, 220, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29725, 12803, 168, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (23364, 15022, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19888, 13049, 262, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (29708, 17484, 324, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29709, 17484, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29711, 17485, 61, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29712, 17485, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19889, 13049, 224, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29713, 17485, 29, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (29721, 17484, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29707, 10592, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23371, 15022, 154, 29, 3);
INSERT INTO 'dancesformationsmap' VALUES (29729, 15605, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29730, 15605, 262, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29731, 15605, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29732, 15605, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29733, 16406, 317, 18, 1);
INSERT INTO 'dancesformationsmap' VALUES (29738, 17525, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29739, 17525, 209, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (29740, 17525, 168, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (29741, 17525, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (29698, 17483, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29699, 17483, 235, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21287, 13587, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29830, 15245, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29831, 15245, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (29836, 15245, 126, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29791, 17540, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29792, 17540, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29793, 17540, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29794, 17540, 213, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22072, 14394, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29797, 4365, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29798, 4365, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (29799, 12580, 29, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (29800, 11904, 117, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (21301, 13654, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29802, 17570, 269, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29803, 17570, 269, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29804, 17570, 162, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29805, 17570, 209, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29806, 17570, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (29807, 17570, 56, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (29808, 17570, 72, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (22218, 2984, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22219, 2984, 365, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29747, 17528, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29748, 17528, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27015, 16225, 346, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (20014, 12960, 225, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (8105, 485, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4535, 2010, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7634, 695, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15431, 5843, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29655, 6738, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14889, 8859, 134, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18078, 12493, 72, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (29694, 12449, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29672, 17463, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29673, 17463, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29670, 9802, 20, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (12126, 9047, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11303, 10115, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (11304, 10115, 273, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10537, 9775, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13681, 9740, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29734, 17523, 16, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13947, 8857, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (29693, 802, 36, 29, 0);
INSERT INTO 'dancesformationsmap' VALUES (19092, 6837, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29752, 17531, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8914, 5749, 317, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (8915, 5749, 46, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (8106, 485, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17709, 11899, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17710, 11899, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29810, 12664, 23, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (16474, 11895, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16475, 11895, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13720, 10822, 36, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (13721, 10822, 183, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (29478, 17265, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29479, 17265, 92, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29809, 2391, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29795, 9014, 229, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29796, 9014, 61, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29774, 17495, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29775, 17495, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11125, 10053, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26161, 16017, 23, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (26162, 16017, 183, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (29776, 17488, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29777, 17488, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29778, 17488, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29779, 16519, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29780, 16519, 224, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29781, 16519, 186, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26163, 16017, 328, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (29760, 17535, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29761, 17535, 143, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29820, 16789, 156, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29822, 16789, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29770, 6151, 7, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29771, 6151, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29772, 6151, 214, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29773, 6151, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29665, 17459, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29666, 17459, 7, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29667, 17459, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23046, 14810, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23047, 14810, 7, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29749, 17529, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28389, 16750, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29652, 6405, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13062, 9442, 317, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29643, 17282, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29644, 17282, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29645, 17282, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15088, 8861, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (15089, 8861, 260, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29758, 17534, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29759, 17534, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17104, 12005, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29801, 10370, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13944, 1914, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29819, 16750, 303, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29851, 4579, 365, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29852, 10089, 7, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29853, 10089, 23, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (29832, 17186, 265, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29833, 17186, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29834, 17186, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29835, 17186, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19660, 12895, 28, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (20833, 13273, 252, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29837, 12895, 29, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (13900, 10875, 262, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29854, 17582, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29855, 17582, 23, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (29856, 17582, 72, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (29848, 1796, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29857, 17582, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29849, 6271, 32, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (29762, 17535, 90, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29750, 17529, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14850, 8939, 66, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (29866, 8939, 328, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13901, 10875, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (29859, 10875, 27, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29824, 17578, 69, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29825, 17578, 330, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (29826, 17578, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29827, 17578, 185, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (29828, 17578, 32, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29829, 17578, 23, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (21545, 13381, 23, 15, 5);
INSERT INTO 'dancesformationsmap' VALUES (9570, 9124, 129, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15341, 10203, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15342, 10203, 56, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (15486, 11558, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29861, 11558, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19934, 13063, 189, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (19935, 13063, 185, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29862, 17583, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29863, 17583, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29864, 17583, 24, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29865, 17583, 82, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (31667, 13902, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31668, 13902, 123, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31669, 13902, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29744, 17527, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29745, 17527, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29746, 17527, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29756, 17533, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29757, 17533, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29751, 17530, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12679, 10460, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8748, 2401, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19837, 12999, 129, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29782, 16520, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29783, 16520, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29764, 17536, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29765, 17536, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29860, 9137, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8356, 3020, 8, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (29874, 17615, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29867, 17613, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29898, 11796, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29899, 11796, 318, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (29868, 17613, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31670, 13902, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29941, 16608, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29871, 17614, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29872, 17614, 156, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29873, 17614, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29968, 17663, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31671, 13902, 71, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (29929, 17629, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29984, 17667, 292, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29985, 17667, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29986, 17667, 157, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29875, 17616, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29876, 17616, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29877, 17616, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29878, 17617, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29879, 17617, 69, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29880, 17617, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29881, 17617, 4, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29882, 11782, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29883, 11782, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9338, 8956, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9339, 8956, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (29884, 8453, 111, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29885, 8453, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29886, 8453, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29887, 8453, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29763, 17535, 93, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (29920, 13385, 306, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29921, 13385, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28140, 16684, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (17229, 8927, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (29913, 17622, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29914, 17622, 235, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (29841, 5466, 326, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (29842, 5466, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29843, 5466, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (29840, 5465, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31894, 18288, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29989, 17669, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29766, 17537, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29767, 17537, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (29768, 17537, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29987, 17668, 224, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29988, 17668, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29982, 17666, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29983, 17666, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10685, 9858, 75, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10686, 9858, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13321, 10537, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (13322, 10537, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10723, 9871, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11376, 9819, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (12850, 9478, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29858, 4211, 365, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (12851, 9478, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24771, 15460, 157, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (11704, 3093, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29811, 17574, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29812, 17574, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9405, 9041, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (29905, 17621, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29906, 17621, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29907, 17621, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29969, 17663, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29918, 7389, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29919, 7389, 157, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (29910, 5256, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29911, 5256, 183, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (29912, 5256, 27, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (393, 699, 42, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (18791, 7301, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29942, 16608, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29943, 16608, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29923, 17626, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29924, 17626, 263, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (29925, 17626, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29926, 17627, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29927, 17627, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29928, 17627, 9, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (15948, 8472, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29965, 17661, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29966, 17661, 72, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (29967, 17661, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29888, 17618, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29889, 17618, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29446, 17304, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29897, 11796, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9071, 8165, 55, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29447, 17304, 132, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (15965, 8468, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29930, 17629, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29931, 17629, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29932, 17629, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29933, 17630, 94, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29934, 17630, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29935, 17630, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29936, 17630, 69, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (18792, 7301, 93, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (29838, 8289, 8, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (29844, 986, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29845, 986, 326, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11194, 10073, 56, 29, 4);
INSERT INTO 'dancesformationsmap' VALUES (29937, 17631, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11225, 10081, 192, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (29938, 17631, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29786, 10471, 363, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29787, 10471, 234, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (29788, 17539, 82, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (29789, 17539, 363, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29790, 17539, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (20225, 13116, 165, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29769, 17538, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13664, 10800, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (142, 245, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29890, 17619, 183, 1, 10);
INSERT INTO 'dancesformationsmap' VALUES (29891, 17619, 157, 7, 48);
INSERT INTO 'dancesformationsmap' VALUES (29922, 13385, 157, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (29944, 17637, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29945, 17637, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29946, 17637, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29947, 17637, 189, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (29957, 17659, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29958, 17659, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29959, 17659, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29948, 17657, 49, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29949, 17657, 58, 2, 0);
INSERT INTO 'dancesformationsmap' VALUES (29950, 17657, 96, 3, 0);
INSERT INTO 'dancesformationsmap' VALUES (29951, 17657, 5, 4, 0);
INSERT INTO 'dancesformationsmap' VALUES (29952, 17657, 69, 5, 0);
INSERT INTO 'dancesformationsmap' VALUES (16490, 7359, 39, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (29953, 17658, 224, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29954, 17658, 82, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (29955, 17658, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29956, 16706, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29960, 17659, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2488, 4763, 85, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (30003, 17671, 185, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30004, 17671, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30005, 17671, 249, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30006, 17671, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30007, 17671, 6, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30008, 17671, 183, 0, 3);
INSERT INTO 'dancesformationsmap' VALUES (30009, 17671, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30010, 17671, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30011, 17671, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30012, 17671, 356, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30013, 17671, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30019, 17674, 224, 0, 3);
INSERT INTO 'dancesformationsmap' VALUES (30020, 17674, 225, 0, 3);
INSERT INTO 'dancesformationsmap' VALUES (30021, 17674, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30022, 17674, 324, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30023, 17674, 42, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (30024, 17674, 168, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (30025, 17674, 162, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30125, 8351, 154, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13122, 10166, 189, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (29869, 17613, 235, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29870, 17613, 186, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30084, 16963, 68, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30085, 16963, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30094, 17705, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30095, 17705, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30068, 17683, 2, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30151, 17736, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5502, 4911, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30031, 17676, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30032, 17676, 8, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (30033, 17676, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30034, 17676, 183, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (30035, 17676, 154, 29, 4);
INSERT INTO 'dancesformationsmap' VALUES (30036, 17676, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (31672, 13903, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31673, 13903, 317, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30152, 17736, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30054, 17679, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30056, 17680, 354, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30057, 17680, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30058, 17680, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30059, 17680, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30060, 17680, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30096, 16456, 281, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30097, 16456, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31674, 13903, 83, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29470, 17335, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30081, 15677, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30082, 15677, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30083, 15677, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (31675, 13904, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31676, 13904, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14259, 11110, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30098, 11110, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30099, 11110, 329, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (30045, 17677, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30154, 17737, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30155, 17737, 42, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30156, 17737, 15, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (22126, 988, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1473, 2780, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29915, 17622, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30112, 17715, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29992, 17670, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29993, 17670, 27, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (30113, 17715, 26, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30114, 17715, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29972, 7572, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29973, 7572, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (29974, 7572, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29975, 7572, 36, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29976, 5272, 143, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (29990, 17669, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29991, 17669, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (29977, 17664, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17650, 12247, 103, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (15992, 8488, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15968, 8486, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30100, 17706, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29995, 6056, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (29978, 17664, 96, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (29979, 17664, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (29980, 17665, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29981, 17665, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30050, 17678, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30051, 17678, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30052, 17678, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (30053, 17678, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29894, 17620, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29895, 17620, 41, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29896, 17620, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30061, 17681, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30062, 17681, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (30063, 17681, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30064, 17681, 96, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (8737, 2321, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (30037, 17685, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30038, 17685, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (30039, 17685, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20664, 13233, 69, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (20665, 13233, 176, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (20666, 13233, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (30138, 17720, 46, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29996, 2413, 209, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29997, 2413, 356, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29998, 2413, 328, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (30014, 17673, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30015, 17673, 89, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (30016, 17673, 354, 43, 1);
INSERT INTO 'dancesformationsmap' VALUES (30017, 17673, 13, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (15429, 268, 43, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (15941, 8478, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22127, 988, 251, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22128, 988, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19175, 8047, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30026, 17675, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30077, 17688, 202, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30078, 17688, 318, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (30079, 17688, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30080, 17688, 23, 31, 2);
INSERT INTO 'dancesformationsmap' VALUES (29700, 17483, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30121, 17483, 154, 19, 3);
INSERT INTO 'dancesformationsmap' VALUES (30071, 17684, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30072, 17684, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30073, 17684, 249, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (15519, 11570, 109, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15520, 11570, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15521, 11570, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18816, 7316, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30165, 17649, 27, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (30055, 17679, 95, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (30166, 17649, 142, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (30117, 17704, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30118, 17704, 96, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (30119, 17704, 235, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30120, 17704, 283, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30146, 17729, 43, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30147, 17729, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30148, 17429, 33, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30149, 17429, 365, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30150, 17429, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30074, 17684, 185, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22925, 13590, 123, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (30122, 17716, 109, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30123, 17716, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30127, 17717, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30130, 17717, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30131, 17717, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30135, 17719, 109, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30136, 17719, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (30137, 17719, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30124, 17716, 373, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (30158, 17648, 9, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30159, 17648, 193, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30160, 17738, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30161, 17738, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30162, 17738, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30110, 1372, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24261, 15014, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30144, 8526, 5, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30145, 8526, 365, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (29892, 17619, 72, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (30163, 17738, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30164, 17738, 354, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30169, 17654, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30170, 17654, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30171, 17654, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30172, 17654, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30173, 17739, 20, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30174, 7802, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30175, 7802, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30176, 7802, 19, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30177, 7802, 221, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30027, 17675, 28, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30028, 17675, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30029, 17675, 30, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30069, 17683, 43, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30070, 17683, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30167, 17649, 93, 3, 8);
INSERT INTO 'dancesformationsmap' VALUES (30168, 17649, 120, 4, 4);
INSERT INTO 'dancesformationsmap' VALUES (30181, 17651, 30, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30182, 17651, 112, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30183, 17651, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30184, 17651, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30185, 17655, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30186, 17655, 30, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30187, 17655, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30188, 17655, 188, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30189, 17740, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30190, 17740, 9, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30191, 17740, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30192, 17740, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30193, 17652, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30194, 17652, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30195, 17652, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30196, 17652, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30197, 17652, 249, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30198, 17652, 183, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (30199, 17653, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30200, 17653, 133, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30201, 17653, 356, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30202, 17653, 330, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (30209, 17742, 273, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30210, 17742, 224, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30211, 17742, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30212, 17742, 249, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30213, 17647, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30214, 17647, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30215, 17647, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30216, 17647, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30217, 17743, 341, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30218, 17743, 87, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30219, 17743, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30220, 17743, 42, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30203, 17741, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30204, 17741, 145, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30282, 13558, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30308, 17778, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30309, 17778, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30225, 17749, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30226, 17749, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30227, 17749, 58, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22712, 14641, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22713, 14641, 102, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22714, 14641, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30283, 13558, 202, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30284, 13558, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30285, 13554, 262, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (30321, 17782, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30235, 17751, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30236, 17751, 281, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30237, 17751, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30238, 17751, 142, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30239, 14073, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30240, 14073, 65, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30241, 16490, 23, 19, 3);
INSERT INTO 'dancesformationsmap' VALUES (30242, 16494, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (30243, 16494, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30244, 10652, 224, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30245, 10652, 121, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30246, 10652, 185, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30247, 10652, 94, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30248, 10652, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30249, 10652, 29, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (30250, 10654, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30251, 10654, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30252, 10654, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30253, 10654, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30254, 10654, 172, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30228, 10402, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (30266, 10662, 142, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30267, 10662, 48, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30268, 10662, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30269, 10660, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30270, 10660, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30271, 10658, 164, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30272, 10658, 26, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30231, 17750, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30107, 2719, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30108, 2719, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30109, 2719, 78, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30065, 17682, 222, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30066, 17682, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30067, 17682, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30143, 985, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30088, 5576, 111, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30089, 5576, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6871, 4931, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30132, 17718, 33, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30041, 17687, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30042, 17687, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30043, 17687, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30040, 17686, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18920, 12743, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30139, 17720, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30140, 17720, 1, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30141, 17720, 30, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (16926, 8855, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9261, 5658, 7, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (10144, 2372, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30229, 14335, 12, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30230, 14335, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30258, 10659, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30259, 10659, 48, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30260, 10659, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30101, 17706, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30102, 17706, 102, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (31677, 13904, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31678, 13904, 92, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30280, 10094, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30261, 17752, 43, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (30262, 17752, 312, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (30263, 17752, 365, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (30264, 17752, 93, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (24400, 15397, 43, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (30305, 17773, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30306, 17773, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24373, 15389, 76, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (18186, 12512, 54, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30296, 17772, 312, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30278, 17767, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27728, 7161, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27729, 7161, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (30301, 17690, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30279, 17767, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30334, 14722, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30335, 14722, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30336, 14722, 58, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30330, 14726, 33, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30337, 17786, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30338, 17786, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30339, 17786, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30340, 1744, 65, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30341, 1744, 41, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30342, 1744, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30343, 1744, 184, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30344, 1744, 36, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30345, 1744, 49, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30322, 17782, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30331, 14726, 53, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30332, 14726, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30333, 14726, 65, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30291, 17770, 188, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (30292, 17770, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30205, 17741, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30206, 17741, 326, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30207, 17741, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (28516, 16802, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28517, 16802, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28325, 16734, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30327, 14728, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30328, 14728, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30255, 10661, 4, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30256, 10661, 94, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30257, 10661, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30299, 17689, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30300, 17689, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30293, 17771, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30294, 17771, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30295, 17771, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14887, 11438, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30281, 14040, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5208, 4015, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30302, 17690, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30303, 17690, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30178, 17142, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30179, 17142, 109, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30180, 17142, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30317, 5355, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30318, 5355, 29, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (30323, 17782, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30307, 17775, 213, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30297, 17772, 25, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (30310, 17778, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30346, 14724, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30347, 14724, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30438, 17796, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30439, 17796, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30465, 1308, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30433, 17795, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30487, 14385, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30488, 14385, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30489, 14385, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15719, 11625, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30386, 15297, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30387, 15297, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30388, 15297, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30389, 15297, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30390, 15297, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15720, 11625, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15721, 11625, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15722, 11625, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15723, 11625, 193, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (30490, 14385, 235, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31679, 13905, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31680, 13905, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31681, 13905, 129, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30420, 17879, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30421, 17879, 131, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18224, 12516, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30398, 12516, 29, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (30399, 12516, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30422, 17879, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30430, 17794, 214, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30431, 17794, 49, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30432, 17794, 92, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30491, 14385, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30456, 7274, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30415, 17802, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30416, 17802, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30417, 17802, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30353, 17787, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30354, 17787, 23, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (30355, 17787, 1, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (30356, 17787, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (3748, 7074, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30409, 17800, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30410, 17800, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30350, 14727, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30351, 14727, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30440, 17796, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7557, 3921, 87, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (30411, 7204, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30447, 17882, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30374, 2242, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30375, 2242, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (30376, 2242, 332, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30383, 17788, 297, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30384, 17788, 10, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (30385, 17788, 23, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (30460, 15299, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30492, 17890, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30493, 17890, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (30426, 17793, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30427, 17793, 1, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30428, 17793, 93, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30429, 17793, 143, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30453, 17883, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30454, 17883, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30455, 17883, 48, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30419, 6858, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30412, 17801, 173, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30413, 17801, 76, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30414, 17801, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30472, 11183, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30273, 17760, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30233, 17750, 162, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30234, 17750, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31895, 18288, 112, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (30394, 17792, 71, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30395, 17792, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30404, 17799, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30405, 17799, 114, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30406, 17799, 18, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (510, 924, 162, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2055, 3894, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30382, 11163, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30286, 8559, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30445, 9483, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30446, 9483, 249, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30391, 14156, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30392, 14156, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30393, 14156, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30311, 17781, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30312, 17781, 39, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (30313, 17781, 220, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30314, 17781, 149, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (30464, 5026, 42, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (30423, 5253, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30424, 5253, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30425, 5253, 61, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (30369, 3201, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30370, 3201, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30371, 3201, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30372, 3201, 225, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (30400, 17797, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30401, 17797, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30402, 17797, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30403, 17797, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30461, 15299, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30377, 15302, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30378, 15302, 231, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30324, 17782, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22187, 13593, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22292, 3588, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6867, 4925, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30463, 738, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30479, 14077, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30480, 14077, 72, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30481, 14077, 92, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30482, 16907, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30470, 5907, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30471, 5907, 48, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30483, 14074, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30484, 14074, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30418, 17802, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30485, 14074, 15, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30486, 14074, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30441, 17881, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30442, 17881, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30443, 17881, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30444, 17881, 119, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (30495, 3221, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30496, 3221, 365, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30379, 15302, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30325, 17782, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30380, 15302, 15, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30381, 15302, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23993, 5898, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (8807, 3695, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30319, 5355, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30320, 5355, 29, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (30362, 7074, 188, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (30363, 7074, 168, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (30365, 7074, 23, 14, 3);
INSERT INTO 'dancesformationsmap' VALUES (30348, 14725, 65, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30478, 16126, 336, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30558, 17919, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30559, 17919, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30635, 2643, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5885, 6023, 356, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30579, 17922, 13, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30580, 17922, 21, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30560, 17919, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30561, 17919, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29409, 17144, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29410, 17144, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30636, 2643, 95, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27898, 16488, 13, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27899, 16488, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27900, 16488, 123, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27901, 16488, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29411, 17144, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30608, 15107, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30609, 15107, 22, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24725, 15439, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (30530, 17832, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30531, 17832, 74, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30129, 6798, 23, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (30364, 13965, 36, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (30457, 17884, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30357, 7866, 65, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30358, 7866, 142, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30359, 7866, 43, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (28462, 16774, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30532, 17832, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30533, 12739, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30534, 12739, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30497, 17891, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30498, 17891, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30499, 17891, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30603, 15099, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30526, 17900, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30597, 15102, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30598, 15102, 168, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30503, 17893, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30504, 17893, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30536, 17893, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30537, 17893, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30599, 15102, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30600, 15102, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30601, 15102, 95, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30500, 17892, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30501, 17892, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30502, 17892, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30466, 17886, 111, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30509, 17895, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30510, 17895, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30511, 17895, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30538, 17895, 249, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (30522, 17899, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30523, 17899, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30524, 17899, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30512, 17896, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30513, 17896, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30528, 17901, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30529, 17901, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30585, 17780, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30539, 17902, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30540, 17902, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (30541, 17902, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30542, 17902, 7, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (30602, 15102, 72, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (30604, 15099, 58, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30566, 3855, 82, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (30546, 17904, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30547, 17904, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30548, 17904, 4, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30549, 17904, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30468, 17886, 4, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30469, 17886, 192, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30567, 3855, 28, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30568, 3855, 8, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (30569, 3855, 143, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30605, 15099, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30610, 17926, 213, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30611, 17926, 92, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (30587, 17780, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30588, 17780, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30550, 17905, 224, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30606, 15100, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30589, 17924, 314, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (30590, 17924, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30591, 17924, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30592, 17924, 365, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30607, 15100, 321, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30584, 2344, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13083, 8671, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30612, 17927, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30613, 17927, 188, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (30614, 17927, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30514, 17897, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30515, 17897, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30621, 15112, 356, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30622, 15112, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30516, 17897, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30551, 17905, 58, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30570, 17920, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (7604, 6823, 66, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (30473, 11183, 248, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30474, 11183, 49, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30477, 498, 162, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (14657, 11299, 56, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14658, 11299, 185, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14659, 11299, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (30554, 17918, 94, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30555, 17918, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30556, 17918, 189, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (30557, 17918, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (14660, 11299, 26, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (28519, 16803, 8, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (28520, 16803, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28521, 16803, 29, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (30543, 17903, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30544, 17903, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30545, 17903, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2625, 5026, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (1199, 2267, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30625, 15119, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30626, 15119, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30494, 8700, 193, 105, 1);
INSERT INTO 'dancesformationsmap' VALUES (12472, 8557, 53, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (12473, 8557, 1, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (30475, 7336, 165, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15243, 11536, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15244, 11536, 72, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (15245, 11536, 149, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (30476, 340, 165, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30352, 14723, 339, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30627, 15119, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30571, 17920, 17, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30572, 17920, 249, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (30573, 17920, 273, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30562, 17919, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (30552, 17905, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30553, 17905, 336, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30535, 14667, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30615, 15115, 15, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30616, 15115, 42, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (22030, 14366, 123, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31889, 13824, 9, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30628, 4558, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31890, 13824, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30623, 15112, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30624, 15112, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30525, 17900, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30527, 17900, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (30629, 17948, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30630, 17948, 93, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (30631, 17948, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30651, 5478, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24033, 15228, 225, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (24034, 15228, 66, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (30641, 3817, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30642, 3817, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30643, 3817, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30644, 4349, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30645, 4349, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30646, 4349, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30647, 4887, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30648, 4887, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30649, 4887, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30650, 4887, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30654, 6222, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30655, 6222, 224, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30656, 6222, 225, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30657, 6222, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30718, 17944, 321, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30719, 17944, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30659, 4355, 33, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (13067, 9445, 55, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11862, 10327, 142, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30660, 17978, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30661, 17978, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (26920, 16189, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30663, 16189, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (30664, 16189, 234, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30720, 17944, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30668, 17889, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30669, 17889, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30670, 17889, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30671, 17889, 324, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (16930, 2246, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30665, 17991, 112, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30666, 17991, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30667, 17991, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31077, 18049, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (30086, 16963, 318, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30087, 16963, 329, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30746, 18002, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30747, 18002, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30748, 18002, 248, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30749, 18002, 365, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (8576, 8705, 5, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30563, 6521, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30564, 6521, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30565, 6521, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30360, 7866, 96, 49, 3);
INSERT INTO 'dancesformationsmap' VALUES (30361, 7866, 76, 51, 3);
INSERT INTO 'dancesformationsmap' VALUES (30688, 17941, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30689, 17941, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30617, 15120, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30618, 15120, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30619, 15120, 56, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30620, 15120, 58, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30452, 17882, 62, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (30771, 18009, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28890, 16527, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30750, 16527, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30772, 18009, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30723, 17946, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30724, 17946, 59, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30725, 17946, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30672, 17980, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30673, 17980, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30674, 17980, 363, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30788, 2635, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30103, 17711, 23, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (30104, 17711, 154, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (30105, 17711, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30751, 18003, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30775, 18010, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30752, 18003, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30753, 18003, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30755, 18004, 365, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30707, 17997, 162, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30708, 17997, 315, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30709, 17997, 10, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30710, 17997, 90, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30711, 17997, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30732, 17999, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30759, 18005, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30713, 17943, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30714, 17943, 248, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30715, 17943, 356, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30716, 17943, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30717, 17943, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30726, 17947, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30727, 17947, 92, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30728, 17947, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30729, 17947, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30730, 17947, 215, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30652, 5478, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30653, 5478, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30632, 17948, 112, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (30633, 17948, 10, 51, 4);
INSERT INTO 'dancesformationsmap' VALUES (30634, 17948, 66, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (30743, 18001, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30769, 18008, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30770, 18008, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30760, 18005, 101, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30761, 18005, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30762, 18005, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (30756, 18004, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (30737, 18000, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30744, 18001, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30745, 18001, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30754, 18004, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30766, 18007, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28470, 16776, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (30738, 18000, 209, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30739, 18000, 90, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30740, 18000, 176, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30741, 18000, 156, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30733, 17999, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30767, 18007, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (9954, 9443, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30106, 17711, 70, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30734, 17999, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30735, 17999, 234, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30736, 17999, 82, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30757, 18004, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30758, 18004, 72, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (23336, 14346, 66, 69, 1);
INSERT INTO 'dancesformationsmap' VALUES (30840, 16958, 32, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (30785, 18014, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30786, 18014, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31451, 17878, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30841, 16958, 188, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (31682, 18274, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31683, 18274, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30763, 18006, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30764, 18006, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30658, 2887, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30637, 17949, 55, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (30638, 17949, 32, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30639, 17949, 132, 14, 4);
INSERT INTO 'dancesformationsmap' VALUES (30765, 18006, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28463, 16775, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28464, 16775, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28465, 16775, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30731, 16775, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13541, 9447, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5371, 4512, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10148, 6131, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (30712, 4438, 368, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9765, 3778, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30679, 17992, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30680, 17992, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30681, 17992, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28746, 16857, 334, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30872, 16958, 370, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (30777, 18011, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30783, 18013, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30784, 18013, 56, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30789, 18015, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29588, 17406, 72, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (29589, 17406, 120, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (14166, 7240, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30742, 18000, 193, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (30776, 18010, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22001, 14355, 61, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (30793, 18016, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30808, 18022, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30809, 18022, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30768, 18007, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30794, 18016, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30817, 18034, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30818, 18034, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (30819, 18034, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30820, 18034, 111, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30835, 16957, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30836, 16957, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26852, 15309, 249, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (17123, 12014, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30795, 18016, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23337, 14346, 33, 77, 2);
INSERT INTO 'dancesformationsmap' VALUES (23338, 14346, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (8753, 2499, 38, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (8754, 2499, 91, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (30898, 2499, 296, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (23369, 14988, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (30880, 18044, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30873, 3766, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30874, 3766, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30875, 3766, 33, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (30824, 16955, 87, 9, 0);
INSERT INTO 'dancesformationsmap' VALUES (30866, 17785, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30867, 17785, 202, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30868, 17785, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30869, 17785, 9, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16177, 11775, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30858, 18039, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30859, 18039, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30860, 18039, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30781, 18012, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30782, 18012, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30796, 18012, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30797, 18012, 56, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (30790, 18015, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30791, 18015, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21982, 14353, 224, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (30825, 16955, 61, 25, 0);
INSERT INTO 'dancesformationsmap' VALUES (30861, 9558, 29, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (30870, 11216, 370, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (30839, 16958, 303, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (19841, 13000, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18569, 12640, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20147, 13104, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30787, 18014, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24514, 15412, 183, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (30792, 18015, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30778, 18011, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14165, 7240, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (30826, 18036, 319, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30886, 18053, 119, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (30827, 18036, 87, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30847, 18037, 142, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (30848, 18037, 85, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (30828, 18036, 296, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (25081, 15686, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11219, 10079, 42, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (30662, 10079, 154, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30690, 17941, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30691, 17941, 5, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30692, 17941, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31695, 18277, 119, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (30849, 18038, 26, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (30887, 18053, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (31689, 18276, 71, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31690, 18276, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31685, 18275, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30842, 16887, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31686, 18275, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31687, 18275, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30891, 18054, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30892, 18054, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30893, 18054, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30894, 18055, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30895, 18055, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13080, 7671, 27, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (25106, 15698, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22015, 14362, 162, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22016, 14362, 66, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22236, 14428, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22237, 14428, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30896, 18073, 326, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30897, 18073, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21638, 13806, 27, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30779, 18011, 64, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30780, 18011, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30881, 18044, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30954, 1471, 8, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (31038, 15108, 151, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31039, 15108, 201, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30995, 15122, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30996, 15122, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31003, 15118, 285, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31004, 15118, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30899, 18074, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30900, 18074, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30902, 18074, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30908, 18081, 246, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30909, 18081, 29, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30910, 18081, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30911, 18081, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30916, 18077, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30917, 18077, 262, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30918, 18077, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30919, 18077, 92, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30955, 1471, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31040, 15108, 195, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30929, 18085, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30930, 18085, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30931, 18085, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30932, 18085, 150, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30933, 18086, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30934, 18086, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30935, 18086, 43, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (30936, 18086, 313, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30937, 18086, 300, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30942, 18088, 134, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (30943, 18088, 156, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30944, 18088, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30945, 18088, 59, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30946, 18089, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25077, 15685, 26, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24689, 15444, 8, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (24690, 15444, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30926, 18084, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30927, 18084, 240, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30928, 18084, 70, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (20979, 13306, 53, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30812, 10982, 356, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30813, 10982, 224, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (30883, 18046, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30884, 18046, 21, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30821, 3943, 12, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30822, 3943, 12, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30823, 3943, 82, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (21258, 13640, 202, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (20984, 13307, 154, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (20985, 13307, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30853, 17694, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30854, 17694, 119, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31899, 13825, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31900, 13825, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (17665, 12277, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14485, 11220, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18281, 12532, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30807, 12532, 294, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30863, 8628, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (30864, 8628, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30815, 18023, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30816, 18023, 27, 1, 9);
INSERT INTO 'dancesformationsmap' VALUES (30938, 18087, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30939, 18087, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30940, 18087, 317, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30920, 18082, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30921, 18082, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30922, 18082, 96, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (30885, 18046, 321, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16737, 11968, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30947, 18089, 309, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30948, 18089, 341, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (31000, 15121, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30951, 9126, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30952, 9126, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30953, 6382, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31001, 15121, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31002, 15121, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31017, 15109, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31018, 15109, 294, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30957, 18091, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30970, 18095, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30971, 18095, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30972, 18095, 154, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30973, 18095, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30982, 18098, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30983, 18098, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30984, 18098, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30985, 18099, 13, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30986, 18099, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30987, 18099, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30988, 18099, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30989, 18100, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (30990, 18100, 249, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (30991, 18101, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30992, 18101, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (30993, 18101, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30994, 18101, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31019, 15109, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31008, 15114, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31009, 15114, 279, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31011, 15110, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31012, 15110, 92, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31013, 15110, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30997, 15122, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14134, 11048, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31020, 15104, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31021, 15104, 123, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31014, 15113, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31015, 15113, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31016, 15113, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (14072, 11031, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31043, 11029, 95, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (31044, 11029, 210, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30967, 18094, 354, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (31048, 17465, 277, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31049, 17465, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30157, 17737, 93, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30968, 18094, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31005, 15116, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31006, 15116, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31007, 15116, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14085, 11037, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14086, 11037, 65, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14141, 11050, 42, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (31042, 17737, 43, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (14142, 11050, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31050, 11050, 112, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14090, 11038, 10, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31052, 18105, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31053, 18105, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (31054, 18105, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31058, 18108, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31059, 18108, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31060, 18108, 8, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (31055, 18107, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31056, 18107, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31057, 18107, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31051, 18104, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14135, 11048, 19, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31010, 15114, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30905, 18079, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30906, 18079, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31041, 15108, 143, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (27043, 16234, 351, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29784, 16520, 151, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30959, 18092, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30960, 18092, 49, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30961, 18092, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30962, 18092, 249, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (30907, 18079, 13, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30949, 18090, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30950, 18090, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31692, 18277, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13746, 10845, 90, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30912, 18078, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30913, 18078, 262, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30843, 16887, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30844, 16887, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30803, 18019, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30804, 18019, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30845, 16887, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (17620, 11365, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30963, 18093, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30964, 18093, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30965, 18093, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30966, 18093, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31031, 17745, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31032, 17745, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31033, 17745, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30903, 18075, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30904, 18075, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30956, 3690, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30958, 18091, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30980, 18097, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30981, 18097, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30969, 18094, 249, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31045, 18102, 234, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (31061, 18109, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31062, 18109, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31086, 13356, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31087, 13356, 30, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31156, 17405, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31157, 17405, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31094, 16910, 142, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (31095, 18122, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31096, 18122, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31097, 18122, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31099, 11036, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31100, 17789, 209, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31101, 17789, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31102, 17789, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31103, 17789, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31098, 11030, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14094, 11039, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31104, 11039, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31105, 18129, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31106, 18129, 92, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31107, 18129, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23832, 15189, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31108, 15457, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (31113, 18131, 4, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31114, 18131, 105, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30208, 17741, 29, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (31115, 18132, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31118, 18139, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31119, 18139, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31120, 18140, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31121, 18140, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31122, 18140, 19, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31161, 14894, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31162, 14894, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31123, 18141, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31124, 18141, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31125, 18141, 19, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31126, 18143, 4, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31127, 18143, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31128, 18143, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31163, 14894, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31035, 17748, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31036, 17748, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31088, 11047, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31089, 11047, 224, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (31090, 11047, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31159, 824, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31024, 17747, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31025, 17747, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31026, 17747, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (31027, 17747, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20535, 13209, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (20536, 13209, 373, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31022, 2506, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31023, 2506, 224, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14129, 11046, 54, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (14130, 11046, 66, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (30974, 15587, 260, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30975, 15587, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30976, 18096, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30977, 18096, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30978, 18096, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30979, 18096, 341, 39, 1);
INSERT INTO 'dancesformationsmap' VALUES (31129, 18142, 154, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (31130, 18142, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31131, 18142, 101, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31132, 18142, 145, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31133, 18142, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31134, 18144, 95, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (31135, 18144, 224, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31136, 18144, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31137, 18144, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31138, 18144, 333, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31148, 18183, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31149, 18183, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31150, 18183, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31167, 14895, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31168, 14895, 154, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31169, 14895, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31170, 14895, 119, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (31171, 14895, 49, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31172, 14897, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31173, 14897, 26, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31181, 14908, 70, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31182, 14908, 92, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31183, 14908, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31184, 14908, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31185, 14907, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31186, 14907, 279, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31187, 14907, 286, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31188, 14907, 76, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31189, 14906, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31190, 14906, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31191, 14906, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31192, 14900, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31193, 14900, 112, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30030, 17675, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31199, 18203, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31194, 17757, 93, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (31195, 17757, 23, 18, 2);
INSERT INTO 'dancesformationsmap' VALUES (31196, 17757, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31211, 15445, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31212, 15445, 321, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31200, 18203, 28, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31197, 17757, 85, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31143, 7145, 134, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (31206, 15453, 4, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31207, 15454, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31208, 15454, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31209, 15454, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31210, 15454, 333, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31213, 15445, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31214, 15445, 324, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31215, 15445, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31218, 17569, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31219, 17569, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31220, 15446, 202, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (31226, 1229, 76, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (31144, 7145, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31145, 7145, 33, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (31146, 7145, 32, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31082, 17885, 94, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31083, 17885, 28, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31084, 17885, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31085, 17885, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31147, 7145, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (31070, 18047, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31071, 18047, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31072, 18047, 366, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31081, 18121, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31174, 14898, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31073, 18049, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (31074, 18049, 185, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31075, 18049, 145, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31076, 18049, 33, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31175, 14898, 78, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31176, 14898, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31221, 18204, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31201, 12186, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31202, 12186, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31204, 12186, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31164, 2894, 25, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31165, 2894, 307, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31166, 2894, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31227, 17100, 93, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (31228, 17100, 85, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31177, 14901, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31178, 14901, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31179, 14901, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31109, 18130, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31110, 18130, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31111, 18130, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31112, 18130, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31151, 18184, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31152, 18184, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31153, 18184, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31063, 18110, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31064, 18110, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31065, 18110, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26811, 1791, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26812, 1791, 302, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31116, 18137, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31117, 18137, 222, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31224, 18207, 162, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31225, 18207, 105, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31066, 18118, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31067, 18118, 362, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31068, 18118, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31298, 18238, 9, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (13222, 8923, 23, 9, 6);
INSERT INTO 'dancesformationsmap' VALUES (31231, 12983, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31232, 18225, 134, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (31233, 18225, 92, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (31234, 18225, 222, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (31235, 18225, 23, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (31236, 18225, 228, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (31237, 18225, 8, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (31238, 18226, 112, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31239, 18226, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31240, 18226, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31241, 18226, 234, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31281, 18235, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31243, 7429, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31244, 7429, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31242, 18226, 202, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31279, 18235, 109, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31280, 18235, 283, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31245, 18227, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31246, 18227, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31247, 18227, 119, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (31248, 18229, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31249, 18229, 95, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (31250, 18229, 56, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (31251, 18229, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31252, 18229, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31253, 18229, 224, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (31254, 18229, 249, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (31255, 18229, 33, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (31299, 18238, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31300, 18238, 23, 6, 8);
INSERT INTO 'dancesformationsmap' VALUES (31306, 18240, 76, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (31307, 18240, 109, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (28843, 16898, 15, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28844, 16898, 24, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28845, 16898, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31290, 16898, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31268, 18231, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31269, 18231, 327, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31270, 18231, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31271, 18231, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31291, 18236, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31276, 18233, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31277, 18234, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31278, 18234, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31047, 18102, 62, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31296, 16680, 23, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (31297, 16680, 132, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (31315, 17467, 20, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31316, 17467, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31216, 13575, 36, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (31160, 824, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31380, 276, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (31378, 2305, 133, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31379, 2305, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31385, 2671, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31327, 17472, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31897, 13825, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31898, 13825, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31139, 18145, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31140, 18145, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12673, 10458, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29342, 17122, 23, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (31303, 18239, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31317, 17469, 321, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31318, 17469, 168, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31319, 17469, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31320, 17469, 213, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31314, 17467, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18152, 12504, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (18153, 12504, 43, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (18154, 12504, 85, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31308, 18241, 168, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31309, 18241, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31310, 18241, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31311, 18241, 123, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31312, 18241, 96, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31313, 18241, 234, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (31367, 17468, 188, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31368, 17468, 189, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31369, 17468, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31370, 17468, 225, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29343, 17122, 154, 29, 3);
INSERT INTO 'dancesformationsmap' VALUES (5477, 4834, 38, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31198, 17757, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31304, 18239, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31392, 17436, 154, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31393, 17436, 18, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29753, 17532, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29754, 17532, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29755, 17532, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (31696, 17532, 234, 10, 2);
INSERT INTO 'dancesformationsmap' VALUES (31697, 12717, 106, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31698, 12717, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31699, 12717, 296, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31700, 12717, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31701, 18278, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31702, 18278, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31787, 13925, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31788, 13925, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31789, 13925, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31703, 12715, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31704, 12715, 168, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31705, 12715, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31706, 12715, 26, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31707, 12715, 82, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30998, 15122, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30999, 15122, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31713, 2365, 26, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22357, 14525, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22358, 14525, 192, 6, 6);
INSERT INTO 'dancesformationsmap' VALUES (22354, 14524, 173, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22355, 14524, 119, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (31714, 13907, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31715, 13907, 65, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31716, 13907, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31790, 13925, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31726, 18279, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31727, 18279, 109, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31728, 18279, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31394, 18244, 201, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31395, 18244, 184, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (31396, 18244, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31397, 18244, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30773, 18009, 105, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30774, 18009, 249, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (31742, 13929, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31743, 13929, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31744, 13929, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30721, 17944, 42, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30722, 17944, 123, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31745, 13929, 43, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31746, 13929, 249, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31747, 13928, 164, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31748, 13927, 70, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31749, 13927, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31750, 12093, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31719, 13868, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31720, 13868, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31721, 13868, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31722, 13868, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31723, 13868, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (31751, 12093, 224, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31752, 12093, 225, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31632, 18271, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31724, 15105, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31725, 15105, 58, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31729, 18280, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31730, 18280, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31731, 18280, 7, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31732, 18281, 224, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31733, 18281, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31753, 12093, 93, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (27790, 6792, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27791, 6792, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31292, 14446, 138, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31293, 14446, 220, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31263, 18230, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31264, 18230, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31265, 18230, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26855, 3665, 112, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26856, 3665, 202, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (31376, 4257, 36, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11182, 10069, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31229, 17100, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31230, 17100, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31693, 18277, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31694, 18277, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31256, 3870, 355, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31258, 3870, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31078, 17768, 222, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31079, 17768, 43, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (31754, 12093, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29743, 17526, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28077, 16618, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28078, 16618, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31734, 17533, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31755, 12099, 224, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (31756, 12099, 226, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31757, 12099, 32, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (31758, 12099, 29, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (30075, 17684, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30076, 17684, 193, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (31735, 13919, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31736, 13919, 188, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31737, 13919, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31773, 15680, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31774, 15680, 318, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31775, 15680, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31776, 15680, 42, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (19241, 8072, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19242, 8072, 65, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19243, 8072, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19212, 8061, 225, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31777, 5234, 189, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (31778, 5234, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31779, 5234, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31780, 5234, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31781, 5234, 185, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (31782, 15683, 5, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31783, 15683, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31784, 15683, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31785, 13754, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31786, 13754, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15613, 5673, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31793, 13922, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31371, 18242, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31372, 18242, 142, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31373, 18242, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31738, 13544, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31739, 13544, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (31740, 13544, 189, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31741, 13544, 188, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (31336, 399, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31387, 924, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31381, 1447, 30, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31382, 1447, 354, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31383, 1447, 36, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (31333, 1840, 36, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (31384, 2232, 324, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (31388, 2300, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31389, 2300, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31334, 2849, 183, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (31335, 6030, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31331, 6947, 43, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (31332, 6947, 23, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (15222, 11529, 43, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (31766, 13926, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31661, 13901, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31771, 8083, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31772, 8083, 27, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31767, 13926, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21412, 13679, 120, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21413, 13679, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (31768, 13926, 17, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (31769, 13926, 119, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (31770, 13926, 105, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31717, 13932, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31718, 13932, 78, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31328, 17472, 49, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31390, 17439, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31391, 17439, 131, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24477, 1192, 7, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (9557, 9120, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31794, 13922, 190, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31795, 13922, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31796, 13922, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31797, 13921, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31798, 13921, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31799, 13921, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31800, 13921, 8, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31801, 13920, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31802, 13920, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31803, 13920, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31804, 13920, 111, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31708, 16794, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31807, 13918, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31808, 13918, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31709, 16794, 259, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (31710, 16794, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31809, 13917, 10, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31810, 13917, 324, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31811, 13917, 13, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31711, 16794, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10704, 9864, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31093, 9864, 23, 18, 1);
INSERT INTO 'dancesformationsmap' VALUES (18707, 12674, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18708, 12674, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30593, 17925, 272, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30594, 17925, 119, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30595, 17925, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30596, 17925, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26438, 16057, 373, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (31936, 13808, 61, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (31932, 18308, 156, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31933, 18308, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31934, 18308, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28179, 16694, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31975, 15844, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (25516, 15842, 66, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31993, 18333, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28159, 16689, 134, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (25517, 15843, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25518, 15843, 24, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25519, 15843, 379, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11623, 9191, 373, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (545, 987, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8854, 4704, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8855, 4704, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8856, 4704, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6407, 1040, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (900, 1666, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8081, 5144, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8082, 5144, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31942, 18310, 213, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31943, 18310, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31944, 18310, 145, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (8247, 8584, 77, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8248, 8584, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10503, 9756, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10504, 9756, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10471, 9738, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15601, 11589, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31997, 18316, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31985, 18330, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21712, 4399, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21713, 4399, 365, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14368, 5125, 365, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31994, 18333, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16505, 8006, 55, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (16508, 8006, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31949, 17124, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31950, 17124, 189, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31951, 17124, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31952, 17124, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31953, 17124, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31945, 17123, 225, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31946, 17123, 162, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31947, 17123, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31948, 17123, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31954, 17123, 69, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31955, 17132, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31956, 17132, 94, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31957, 17132, 10, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31958, 17132, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31959, 17132, 15, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31963, 17127, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31964, 17127, 228, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31965, 17127, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31966, 17128, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31967, 17128, 30, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31968, 17128, 317, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31976, 18311, 33, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (31977, 18311, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31978, 18311, 10, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31979, 18311, 209, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16815, 2705, 317, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (17641, 12245, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17642, 12245, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31969, 15825, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31970, 15825, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31922, 18305, 92, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11215, 10078, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11245, 10088, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (11246, 10088, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23848, 15193, 373, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (31321, 17470, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31322, 17470, 324, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31323, 17470, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19561, 12420, 36, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (31688, 18275, 123, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31791, 13923, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31792, 13923, 249, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31971, 15825, 96, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (25466, 15826, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31972, 15830, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31973, 15831, 175, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31974, 15834, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25529, 15846, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31998, 18222, 300, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31960, 17130, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31961, 17130, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31908, 18301, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31909, 18301, 32, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (31910, 18301, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31911, 18301, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31999, 18222, 7, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32000, 18222, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32014, 18335, 117, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31980, 6242, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31981, 6242, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31982, 6242, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31983, 6242, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27508, 16384, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27509, 16384, 87, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (27510, 16384, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30397, 16384, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32015, 18335, 17, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31991, 18332, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32005, 18210, 94, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32006, 18210, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15898, 11617, 21, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32011, 18334, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31995, 18316, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31996, 18316, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32001, 18212, 300, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32002, 18212, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32003, 18212, 193, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32004, 18210, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32007, 18215, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32008, 18215, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32009, 18215, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32010, 18215, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32012, 18334, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32013, 18334, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31992, 18332, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28584, 16827, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31962, 17130, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32020, 18224, 313, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32021, 18224, 92, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32022, 18224, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31813, 13916, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31814, 13916, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31815, 13916, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31937, 6725, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31938, 6725, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31819, 13914, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31820, 13914, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25531, 15847, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25486, 15832, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31805, 1763, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (31806, 1763, 23, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (14834, 9947, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14835, 9947, 55, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (17790, 9325, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21534, 11873, 204, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1100, 2049, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17791, 9325, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17795, 9325, 42, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (17796, 9325, 373, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (10613, 9828, 17, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (10614, 9828, 221, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (10615, 9828, 8, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (32023, 18221, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32024, 18221, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32025, 18221, 26, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32026, 18214, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31984, 15837, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31939, 18309, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31940, 18309, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (31941, 18309, 119, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (31986, 18330, 162, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31987, 18330, 93, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (31988, 18330, 56, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (32027, 18214, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32028, 18214, 313, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32029, 18214, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (272, 489, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4021, 489, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24614, 12051, 373, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (32137, 15342, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32138, 15342, 29, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32139, 15342, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32140, 15342, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32141, 15343, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32142, 15343, 123, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32143, 15343, 188, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32096, 18350, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32097, 18350, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32098, 18350, 29, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (26201, 16027, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32032, 2379, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32033, 2379, 269, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32034, 2379, 142, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32035, 2379, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32036, 13662, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32037, 13662, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32099, 18351, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32100, 18351, 326, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32101, 18351, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32179, 18382, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32150, 18365, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32102, 18352, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32042, 18336, 71, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32043, 18336, 224, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32044, 18336, 225, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32045, 18325, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32046, 18325, 10, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32047, 18325, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32048, 18325, 214, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32049, 18324, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32050, 18324, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32051, 2233, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (32052, 2233, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32053, 2233, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32054, 11825, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32055, 11825, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32056, 11825, 42, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (32030, 18218, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32031, 18218, 316, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (32103, 18352, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32104, 18352, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32105, 18352, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (16188, 11781, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32057, 11781, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32058, 11781, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32059, 18329, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32060, 18329, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32061, 18329, 214, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32130, 17728, 105, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32131, 17728, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32016, 18335, 93, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (30574, 17920, 61, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (32151, 18365, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32152, 18365, 77, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32073, 18341, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32074, 18341, 15, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32075, 18341, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32108, 17877, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32109, 17877, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32110, 17877, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32111, 17876, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32065, 18337, 43, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32066, 18337, 269, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32067, 18337, 142, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32068, 18337, 27, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (29823, 16789, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32089, 16961, 1, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32090, 16961, 8, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32091, 16961, 27, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32092, 16961, 69, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32112, 17876, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32113, 17876, 92, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32114, 17876, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32115, 17875, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32116, 17875, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32117, 17875, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15286, 11549, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15287, 11549, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32121, 17873, 112, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32122, 17873, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32123, 17873, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32124, 18354, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24445, 4749, 119, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (26202, 16027, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26203, 16027, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32038, 17348, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31989, 18331, 13, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (32039, 17348, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32080, 18348, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32081, 18348, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32082, 18348, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32083, 18348, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26204, 16027, 321, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27976, 16509, 324, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (32132, 16509, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32133, 16509, 183, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (26211, 16028, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32158, 5509, 95, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (32159, 5509, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32085, 16787, 192, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32148, 18372, 356, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (32149, 18372, 90, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (27966, 16507, 297, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27967, 16507, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (27968, 16507, 143, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (12411, 9061, 5, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (32144, 18372, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32145, 18372, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32146, 18372, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32147, 18372, 27, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32160, 18374, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32161, 18374, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32162, 18374, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32163, 18374, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32164, 18378, 165, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32165, 18378, 214, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32166, 18378, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32170, 18380, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32171, 18380, 7, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32172, 18380, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32173, 18380, 39, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (32174, 18380, 72, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (32167, 18379, 102, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32168, 18379, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32177, 18381, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32178, 18381, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32169, 18379, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32017, 18335, 220, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (27970, 16507, 52, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32062, 15363, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32153, 18365, 15, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32063, 15363, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32064, 15363, 213, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32086, 16788, 268, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32087, 16788, 162, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32088, 16788, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32018, 18335, 120, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (32019, 18335, 328, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (32154, 18365, 102, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27971, 16507, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (32175, 18380, 210, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (32176, 18380, 90, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (32106, 18353, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32107, 18353, 373, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32093, 16791, 65, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (25197, 15726, 16, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25198, 15726, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25199, 15726, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32076, 18346, 43, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32077, 18346, 85, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32134, 18356, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (32135, 18356, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (32136, 18356, 142, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32094, 18349, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32095, 18349, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32247, 13840, 125, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32248, 13840, 184, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32249, 13840, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32232, 18390, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32233, 18390, 380, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32234, 18390, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32191, 863, 265, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (32192, 863, 188, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32193, 863, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32250, 13843, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32251, 13843, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32252, 13843, 184, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30810, 18022, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (30811, 18022, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32253, 13843, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32197, 18386, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32198, 18386, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32199, 18386, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32200, 18386, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32208, 15662, 356, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32209, 15662, 71, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32210, 15662, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32254, 13845, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32255, 13845, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32256, 13845, 22, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32212, 123, 185, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32213, 123, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32300, 6893, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32301, 6893, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14666, 11298, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32257, 11298, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32258, 11298, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32259, 11298, 29, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (32260, 18366, 16, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (32261, 18366, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32262, 18366, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (32263, 18366, 112, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (32310, 18382, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32183, 10498, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32202, 4216, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26875, 16183, 143, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26876, 16183, 321, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26877, 16183, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32214, 10532, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32215, 10532, 184, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32216, 10532, 302, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32217, 10532, 42, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13803, 10531, 42, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32225, 10531, 302, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (26719, 16128, 317, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13135, 6259, 77, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13136, 6259, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13137, 6259, 13, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32284, 18395, 121, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32285, 18395, 93, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32239, 13838, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32240, 13838, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32241, 13838, 185, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32242, 13838, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32243, 13838, 249, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32244, 13838, 145, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (32245, 13838, 193, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (32246, 13840, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32302, 6893, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32303, 6893, 119, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (32203, 4216, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32195, 18385, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32196, 18385, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32286, 18395, 117, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (32304, 6893, 25, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32305, 6893, 96, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (32268, 13742, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32290, 1554, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32291, 1554, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32292, 1554, 69, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32293, 6677, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32294, 1953, 173, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32295, 1953, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32296, 733, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32297, 733, 82, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32298, 2062, 16, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32299, 2062, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32287, 18395, 8, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (29659, 17460, 123, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (29664, 17460, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32269, 13742, 84, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32270, 13742, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32316, 18408, 302, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32318, 18409, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32319, 18409, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32320, 18409, 8, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (32321, 18409, 380, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32332, 14903, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32333, 14903, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32204, 18387, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32205, 18387, 58, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32206, 18387, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32207, 18387, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32155, 18373, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32156, 18373, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32157, 18373, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32187, 17430, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32188, 17430, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32189, 17430, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32218, 18388, 235, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32219, 18388, 71, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32220, 18388, 82, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32221, 18388, 8, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (21155, 13351, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (32275, 18393, 10, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32276, 18393, 120, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32277, 18393, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (32278, 18393, 224, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (32279, 18393, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32334, 14903, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32335, 14903, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32317, 18408, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32180, 18384, 240, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32181, 18384, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32328, 18410, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32329, 18410, 119, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32330, 18410, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32331, 18410, 36, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (32182, 18384, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32288, 18395, 43, 53, 2);
INSERT INTO 'dancesformationsmap' VALUES (32281, 18394, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32282, 18394, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (32283, 18394, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32336, 9939, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32337, 9939, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32338, 9927, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32342, 14224, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32343, 14224, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32344, 14224, 123, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32455, 14372, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21989, 14356, 317, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (32194, 13052, 240, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32235, 18391, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32236, 18391, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32237, 18391, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32238, 18391, 183, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (31364, 2485, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1861, 3521, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32345, 17599, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32346, 17599, 150, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14759, 11366, 202, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (14760, 11366, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14761, 11366, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (32311, 12369, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32312, 12369, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32313, 12369, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32322, 16566, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (32323, 16566, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32324, 16566, 248, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32325, 16566, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32264, 12089, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32265, 12089, 165, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32266, 12089, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32267, 12089, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32211, 15676, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32201, 14750, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32306, 18376, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32307, 18376, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32308, 18376, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32309, 18376, 15, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32228, 18389, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32229, 18389, 165, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32230, 18389, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (32231, 18389, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32184, 18383, 384, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32185, 18383, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32186, 18383, 77, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32349, 18258, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32350, 18258, 58, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32351, 3375, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32352, 3375, 22, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32353, 3375, 36, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32356, 8760, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32357, 8760, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32358, 8760, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32359, 8760, 42, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (29583, 7201, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32360, 7201, 21, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22116, 14403, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32361, 4938, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32362, 595, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32363, 595, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32364, 14959, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32365, 14959, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32366, 14959, 354, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (32367, 18466, 209, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32368, 18466, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32369, 18467, 87, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32370, 18467, 28, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32381, 2503, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32382, 2503, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32383, 5469, 154, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (32384, 5469, 55, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32385, 5690, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32386, 5682, 134, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32387, 18472, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32388, 18472, 225, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32389, 18472, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32390, 18472, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (32397, 18475, 19, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32398, 18475, 184, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32399, 18475, 8, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32400, 18476, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32401, 18476, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32402, 18476, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32403, 18477, 373, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32404, 18477, 184, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32405, 18477, 16, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32406, 18477, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32407, 18477, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32408, 18478, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32409, 18479, 359, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32410, 18479, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32411, 18479, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32456, 14372, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32421, 18484, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32422, 18484, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32423, 18484, 1, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (32424, 5275, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32427, 7080, 134, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32428, 7080, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32429, 7080, 82, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (32430, 7080, 125, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (32395, 18474, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32396, 18474, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32412, 18480, 109, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32413, 18480, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13350, 10553, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13351, 10553, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13352, 10553, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15466, 11555, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15467, 11555, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15999, 11706, 127, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16000, 11706, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11568, 10284, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20647, 13231, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20648, 13231, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20651, 13232, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20652, 13232, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (32440, 18487, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32441, 18487, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32442, 18487, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32443, 18487, 76, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32444, 18487, 49, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14463, 9898, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32445, 3216, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29484, 17384, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29485, 17384, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28587, 8809, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32431, 14765, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32432, 14765, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32373, 18469, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32374, 18469, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32371, 18468, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32372, 18468, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32375, 18470, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32376, 18470, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32377, 18470, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32414, 18481, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32415, 18481, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22583, 9812, 234, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (13729, 10824, 58, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32416, 18482, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32417, 18482, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13730, 10824, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (13731, 10824, 112, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29532, 17137, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29533, 17137, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (29534, 17137, 8, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32418, 18483, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32419, 18483, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32420, 18483, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32457, 14372, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (875, 1621, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32438, 1621, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32439, 1621, 249, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (19749, 12929, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19750, 12929, 7, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32379, 18471, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32391, 18473, 46, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32392, 18473, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32354, 2410, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32355, 2410, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31080, 17768, 240, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31506, 17756, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31509, 17756, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31510, 17756, 112, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30846, 16887, 183, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32280, 18393, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32380, 18471, 154, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32339, 16661, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32340, 16661, 123, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30448, 17882, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30449, 17882, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30450, 17882, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30451, 17882, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32558, 17516, 324, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32559, 17516, 209, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24787, 15479, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32516, 15479, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32519, 15289, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32520, 15289, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32521, 15289, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32464, 18490, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32465, 18490, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32469, 18492, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32470, 18492, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32471, 18492, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32472, 18492, 234, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32473, 18493, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32474, 18493, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32475, 18493, 188, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (24551, 12036, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32479, 13359, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32480, 13359, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21836, 9676, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32459, 18486, 176, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32446, 18488, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32425, 1273, 183, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (32447, 18488, 165, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32448, 18488, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10845, 7738, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (14762, 11366, 156, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16954, 11366, 43, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (22526, 4858, 125, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (9539, 9115, 82, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (21943, 14340, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (21944, 14340, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21945, 14340, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21946, 14340, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32486, 15303, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32487, 15303, 48, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20027, 12962, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (20028, 12962, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (15996, 11704, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14056, 10967, 222, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14057, 10967, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14058, 10967, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9583, 9128, 45, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9584, 9128, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9662, 9167, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32435, 14118, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (32436, 14118, 92, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32460, 18486, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32461, 18486, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32462, 18486, 43, 69, 1);
INSERT INTO 'dancesformationsmap' VALUES (32463, 18486, 41, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (32560, 17516, 66, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32481, 18497, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32482, 18497, 269, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32497, 16919, 7, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32525, 15291, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32526, 15291, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32527, 15291, 55, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32514, 15288, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32515, 15288, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (24284, 15333, 29, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (32495, 16918, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32498, 16920, 36, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32491, 5983, 96, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (32492, 5983, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32493, 5983, 148, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32494, 5983, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21854, 13361, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29970, 17663, 359, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29971, 17663, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13763, 10852, 118, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32500, 10852, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18984, 12765, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32587, 18513, 71, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32588, 18513, 1, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32485, 567, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32507, 9938, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32508, 9938, 249, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32509, 9938, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32510, 9938, 332, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30223, 17744, 105, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32511, 15295, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32512, 15295, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32513, 15295, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30224, 17744, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32567, 146, 6, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32585, 18512, 241, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32586, 18512, 317, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32539, 18193, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32540, 18193, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32541, 18193, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32605, 18520, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32606, 18520, 269, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18969, 12761, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18970, 12761, 193, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (23931, 15211, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23932, 15211, 25, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (23933, 15211, 82, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (32546, 15211, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32534, 15298, 176, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32535, 15298, 120, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32536, 15298, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32537, 15298, 121, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (32538, 15298, 38, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32552, 878, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32553, 878, 48, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32554, 1637, 180, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32555, 1637, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32556, 1637, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32557, 1637, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32568, 12761, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32580, 18507, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32581, 18507, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32582, 18507, 241, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32569, 3481, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32570, 3481, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32571, 3481, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32572, 3481, 25, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32573, 3481, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32496, 16919, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32583, 18511, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32584, 18511, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32607, 13505, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32608, 13505, 184, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32609, 13505, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32574, 17339, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32575, 17339, 23, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (32589, 18514, 168, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (32590, 18514, 134, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32594, 18516, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32517, 15287, 164, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32595, 18516, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32596, 18516, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32610, 13505, 76, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32720, 18552, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (32615, 1503, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32616, 1503, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32620, 6659, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32621, 6659, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32622, 6659, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32623, 6659, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32624, 6659, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24958, 15577, 303, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24959, 15577, 7, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (32625, 17437, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32626, 17437, 134, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32627, 17437, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32701, 18549, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32702, 18549, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32658, 18536, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32659, 18536, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32660, 18536, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32640, 17438, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32641, 17438, 249, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (27042, 16234, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32697, 18548, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32433, 14765, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32434, 14765, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32703, 18549, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32704, 18549, 56, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32698, 18548, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32699, 18548, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32700, 18548, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32628, 18522, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32629, 18522, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32648, 1656, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (32649, 1656, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32547, 104, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32548, 104, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32499, 16921, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18947, 12753, 125, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32483, 1384, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32484, 1384, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (32666, 18538, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32667, 18538, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32668, 18538, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32669, 18538, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32750, 18554, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32751, 18554, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32724, 14115, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32725, 14115, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32726, 14115, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32646, 18534, 33, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32647, 18534, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32613, 15242, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32614, 15242, 92, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (32638, 432, 85, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (32639, 432, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32542, 18508, 23, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (32543, 18508, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32650, 18535, 58, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32651, 18535, 48, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32652, 18535, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32528, 3510, 120, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32529, 3510, 121, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (32530, 3510, 32, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32501, 15301, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32502, 15301, 93, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32561, 18510, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32562, 18510, 234, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32563, 18510, 173, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32653, 18535, 225, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32654, 18535, 56, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (32488, 15303, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20510, 13206, 185, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20511, 13206, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19456, 12841, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32531, 15292, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32532, 15292, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32635, 1015, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32636, 1015, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32637, 1015, 105, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32655, 17370, 306, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32656, 17370, 184, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32657, 17370, 1, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32661, 6956, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (32727, 14119, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32728, 14119, 65, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32729, 14119, 91, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13139, 1873, 234, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32664, 1873, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32665, 1873, 36, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32707, 18550, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32708, 18550, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32709, 18550, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27021, 16228, 117, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32643, 18533, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32644, 18533, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32645, 18533, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32676, 18541, 43, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32677, 18541, 120, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32678, 18541, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32711, 18551, 166, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (32713, 18551, 321, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (32714, 18551, 109, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32642, 18533, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32630, 18522, 239, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32631, 18523, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32717, 18552, 71, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32718, 18552, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32719, 18552, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32737, 17279, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32738, 17279, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32739, 17279, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32740, 17279, 312, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32741, 17279, 36, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32742, 17279, 96, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (32743, 14132, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32730, 14120, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32731, 14120, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32732, 14120, 176, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32733, 14120, 43, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32734, 14121, 70, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32735, 14121, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32736, 14121, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32744, 14131, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32745, 14131, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32746, 14131, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32632, 18523, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32633, 18523, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (32634, 18523, 239, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32705, 18549, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32706, 18549, 189, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (32757, 17457, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32758, 17457, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32759, 17457, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32760, 17456, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32761, 17456, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32762, 17456, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32763, 17455, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32764, 17455, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32577, 17339, 9, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (10772, 9888, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32578, 17339, 117, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32579, 17339, 328, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (32670, 18539, 55, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32671, 18539, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (32672, 18539, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32679, 18542, 7, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (32680, 18542, 96, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (32765, 17455, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32766, 17455, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32767, 18520, 132, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32768, 18520, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32769, 18516, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32770, 18516, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32601, 18518, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32602, 18518, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32773, 14123, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32774, 14123, 95, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32775, 14123, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32776, 14123, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32777, 14123, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32883, 3413, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32850, 18571, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32778, 14129, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32779, 14129, 175, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32780, 14129, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32851, 18571, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32852, 18571, 313, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32844, 12096, 162, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32845, 12096, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32782, 14252, 39, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32783, 14252, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32784, 14252, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32785, 14252, 23, 18, 2);
INSERT INTO 'dancesformationsmap' VALUES (32846, 12096, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29321, 17067, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32592, 18515, 70, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (32593, 18515, 154, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32791, 18515, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32792, 4396, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32781, 4023, 102, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32803, 18567, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32804, 18567, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32805, 18567, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32806, 18567, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32853, 14720, 380, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32832, 18580, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32833, 18580, 1, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32834, 18580, 120, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32828, 18578, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32793, 18561, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32807, 18568, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32808, 18568, 165, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32815, 4607, 119, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (32816, 4607, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32817, 4667, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32854, 17249, 20, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (32855, 17249, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32884, 5413, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32799, 18563, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32800, 18563, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32801, 18563, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32835, 18579, 241, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32836, 18579, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32837, 18579, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32838, 18579, 7, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32839, 18579, 76, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32856, 17254, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32857, 17254, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32858, 17254, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32859, 17254, 314, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32860, 17254, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32662, 18537, 313, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (32522, 17321, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32523, 17321, 189, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32617, 18521, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32618, 18521, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32619, 18521, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32752, 18555, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32753, 18555, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32865, 12169, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32866, 12169, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32867, 17252, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32868, 17252, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32869, 17252, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32870, 17252, 186, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32861, 17247, 55, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32862, 17247, 251, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32863, 17247, 280, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32864, 17247, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32874, 18033, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32875, 18033, 168, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32876, 18033, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32900, 2148, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32901, 2148, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32893, 18610, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32611, 15242, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32612, 15242, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32818, 1584, 41, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (32819, 1584, 42, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (32771, 16610, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32772, 16610, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32822, 18576, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32823, 18576, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (32871, 12817, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32872, 12817, 33, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32877, 16479, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32878, 16479, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32873, 12817, 83, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32747, 14130, 49, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32748, 14130, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32749, 14130, 103, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32788, 13592, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32789, 13592, 119, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (19408, 12819, 185, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19409, 12819, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19410, 12819, 83, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (32894, 18610, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32889, 18588, 51, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32890, 18588, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32891, 18588, 17, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32892, 18588, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32897, 6963, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32905, 18612, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32906, 18612, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32908, 18624, 189, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32895, 18610, 321, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (32896, 18610, 260, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32902, 4252, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32907, 18623, 189, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32903, 18612, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32904, 18612, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32809, 18568, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32810, 18568, 188, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32924, 18645, 355, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32915, 18625, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32916, 18625, 55, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32917, 18625, 95, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32918, 18625, 154, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32919, 18625, 142, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22105, 14400, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32925, 18645, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32926, 18645, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (32927, 18645, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32920, 18643, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32921, 18643, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32922, 18643, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32923, 18643, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32928, 18644, 16, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (32929, 18644, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32847, 15681, 278, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32909, 18626, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32848, 15681, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32885, 18587, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32886, 18587, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32887, 18587, 111, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32840, 18581, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32841, 18581, 321, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32842, 18581, 72, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32843, 18581, 73, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32983, 18640, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32984, 18640, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32942, 18649, 134, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (32943, 18649, 312, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (32944, 18649, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32945, 18649, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32946, 18650, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32947, 18650, 48, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32948, 18650, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32949, 18651, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32950, 18651, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32951, 18651, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32952, 18651, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32953, 18652, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32954, 18652, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (32955, 18652, 119, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (32956, 18653, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32957, 18653, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32958, 18653, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (32959, 18653, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28790, 16870, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32576, 17339, 209, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31158, 17405, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30304, 17690, 183, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (30265, 17752, 114, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32910, 18626, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32911, 18626, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32912, 18626, 43, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32960, 18627, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32961, 18627, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32962, 18630, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32963, 18630, 92, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32964, 18630, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32965, 18630, 103, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32966, 14080, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32967, 14080, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32968, 14080, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32969, 14078, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32970, 14078, 145, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32971, 14078, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32972, 14078, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32973, 18656, 17, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32974, 18656, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32975, 18656, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33014, 10448, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33015, 10448, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32888, 18587, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32681, 18542, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (32682, 18543, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32683, 18543, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32684, 18543, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32685, 18544, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32686, 18544, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32687, 18544, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32688, 18544, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32976, 396, 33, 10, 2);
INSERT INTO 'dancesformationsmap' VALUES (32977, 396, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32978, 396, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32694, 18547, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32695, 18547, 112, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (32696, 18547, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32930, 18646, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32931, 18646, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32932, 18646, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32933, 18646, 42, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (32934, 18647, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32935, 18647, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32936, 18647, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32937, 18647, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32938, 18647, 70, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32939, 18648, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32940, 18648, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32941, 18648, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33016, 17957, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33017, 17957, 313, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33018, 17957, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32689, 18545, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32690, 18545, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32979, 18545, 96, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (32980, 18641, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32981, 18641, 18, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32982, 18641, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33019, 17957, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32999, 18661, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33000, 18661, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33001, 18661, 23, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (32989, 18659, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33020, 17957, 241, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33021, 18634, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33022, 18634, 375, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32995, 18658, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32996, 18658, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32990, 18659, 168, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (32991, 18659, 114, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (32992, 18659, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32997, 18658, 185, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32715, 18551, 188, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (32716, 18551, 202, 26, 2);
INSERT INTO 'dancesformationsmap' VALUES (32691, 18546, 102, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32692, 18546, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32693, 18546, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32710, 18550, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (32880, 16612, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32378, 18470, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32985, 18657, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32986, 18657, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32987, 18657, 318, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32988, 18657, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33006, 18474, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33009, 18481, 214, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33035, 18674, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33036, 18674, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33037, 18674, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20114, 13088, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (20115, 13088, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20116, 13088, 36, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33023, 18666, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33024, 18666, 23, 18, 2);
INSERT INTO 'dancesformationsmap' VALUES (33025, 18666, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33026, 18666, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33027, 18665, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33028, 18665, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33038, 18674, 17, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33032, 9443, 49, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33033, 18633, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33034, 18633, 365, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33039, 18674, 71, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33040, 18675, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33007, 18664, 32, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33008, 18664, 185, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13680, 9740, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32993, 18660, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32994, 18660, 261, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (32913, 16869, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32914, 16869, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32476, 18494, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (32477, 18494, 82, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (32478, 18494, 372, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33041, 18675, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33042, 18675, 241, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33043, 18675, 92, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (33044, 18676, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33045, 18676, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33046, 18676, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33047, 18676, 92, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33048, 18677, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33049, 18677, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33050, 18678, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33051, 18678, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33052, 18678, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33053, 18678, 15, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33010, 10692, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33094, 18801, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33095, 18801, 92, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33066, 18690, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33067, 18690, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (27830, 16473, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14936, 11453, 25, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14937, 11453, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15081, 11508, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20388, 13162, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (33096, 18801, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20414, 13172, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (23311, 14986, 72, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (20399, 13166, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (33070, 18697, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33071, 18697, 17, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (33072, 18697, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18101, 12500, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (33138, 16534, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33139, 16534, 32, 29, 4);
INSERT INTO 'dancesformationsmap' VALUES (33140, 3832, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33141, 3832, 183, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (33073, 18721, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33074, 18721, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33075, 18721, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33076, 18721, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (33077, 18722, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33078, 18722, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11503, 10258, 20, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15073, 11504, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9972, 9486, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20484, 13195, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (33079, 18724, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33080, 18724, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33081, 18724, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33011, 10692, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33012, 10692, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33013, 10692, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33142, 3832, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (14971, 11466, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (33086, 9493, 71, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18075, 12490, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (33143, 18967, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33144, 18967, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33145, 18967, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20382, 13160, 61, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (20383, 13160, 29, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (33091, 18755, 241, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33092, 18755, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31888, 9482, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11499, 10257, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14986, 11473, 125, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11484, 10251, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (20477, 13193, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15084, 11509, 260, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15048, 11495, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (26998, 16223, 119, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (26999, 16223, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33093, 18791, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33102, 18815, 83, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33103, 18815, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33104, 18818, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33105, 18818, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33106, 18818, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33107, 18818, 283, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (18098, 12499, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9969, 9485, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14946, 11457, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14947, 11457, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (33082, 18726, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33083, 18726, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33084, 18726, 72, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (33085, 18726, 249, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (20457, 13186, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (33135, 11779, 168, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26881, 15706, 93, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26882, 15706, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28502, 15032, 8, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (33136, 16533, 42, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (33112, 7033, 46, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33113, 7033, 82, 9, 6);
INSERT INTO 'dancesformationsmap' VALUES (33114, 7033, 72, 25, 6);
INSERT INTO 'dancesformationsmap' VALUES (33115, 7033, 132, 98, 1);
INSERT INTO 'dancesformationsmap' VALUES (33116, 7033, 22, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (33117, 7033, 9, 113, 2);
INSERT INTO 'dancesformationsmap' VALUES (33121, 9542, 27, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (33122, 9542, 209, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33123, 9542, 87, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (33124, 9542, 210, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (15059, 11498, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (15044, 11493, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (32811, 18568, 71, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23116, 14917, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24207, 15332, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33137, 16533, 273, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29531, 17143, 23, 22, 1);
INSERT INTO 'dancesformationsmap' VALUES (28513, 16534, 213, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28514, 16534, 321, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28515, 16534, 4, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29541, 17139, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33130, 18495, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33131, 18495, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33132, 18495, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33147, 18968, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33148, 18968, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33149, 18968, 10, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33150, 18968, 101, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (33151, 18968, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15036, 11491, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (15037, 11491, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10185, 9569, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33133, 18495, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33125, 18926, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33126, 18926, 48, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33054, 15609, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33062, 18683, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33063, 18683, 386, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33055, 15609, 76, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (33056, 15609, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14926, 11450, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33061, 11450, 38, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31503, 16884, 183, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (32813, 18569, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20448, 13182, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (18064, 12486, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33090, 3133, 268, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14958, 11461, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14930, 11451, 86, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (18065, 12486, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31504, 16884, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29270, 17023, 222, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (29271, 17023, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (15508, 11567, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14992, 11475, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (20544, 5013, 162, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18050, 12482, 119, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (33097, 18806, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33098, 18806, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15710, 11623, 189, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (15711, 11623, 56, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (15712, 11623, 10, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27223, 16291, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11494, 10255, 315, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33057, 463, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33058, 463, 176, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (33059, 463, 52, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (33060, 463, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (31684, 18274, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20356, 13152, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33108, 18837, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33109, 18837, 241, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33110, 18837, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33111, 18837, 19, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (15052, 11496, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (18564, 12638, 45, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18565, 12638, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16148, 11760, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33156, 18972, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33068, 18696, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33069, 18696, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11461, 10241, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (19301, 12219, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33292, 9878, 72, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (33213, 19015, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33163, 18974, 50, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33164, 18974, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33165, 18974, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33166, 9569, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33167, 9569, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33168, 9569, 249, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (33177, 10239, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33178, 10239, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33179, 10239, 324, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33180, 10239, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33181, 10239, 249, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (33176, 10245, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33214, 19015, 148, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33259, 7940, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33232, 19025, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32591, 18514, 273, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33203, 18514, 341, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (33237, 19028, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33238, 19028, 142, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33239, 19028, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33240, 19028, 8, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33285, 15608, 188, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33182, 11852, 234, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (33183, 11852, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33184, 11852, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33185, 11852, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (33186, 11852, 7, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (33246, 19026, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33247, 19026, 26, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33248, 19026, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33249, 19026, 106, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33294, 19040, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33295, 19040, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33296, 19040, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33268, 2794, 70, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33269, 2794, 36, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33270, 2794, 72, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (33271, 2794, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33273, 6187, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13801, 10535, 76, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (33197, 18080, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33198, 18080, 273, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (33199, 18080, 8, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (33274, 6187, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33204, 18512, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8936, 6141, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8937, 6141, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8938, 6141, 117, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (33207, 19013, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33208, 19013, 249, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33209, 19013, 95, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (33210, 19014, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33211, 19014, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33212, 19014, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33260, 7940, 142, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33261, 7940, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33215, 19016, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33216, 19016, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33217, 19016, 148, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33218, 19019, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33219, 19019, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33220, 19019, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33221, 19017, 23, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (33222, 19017, 27, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (33223, 19017, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33224, 19017, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33225, 19030, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33226, 19030, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33227, 19030, 235, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33228, 19030, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33233, 19022, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33234, 19022, 193, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33235, 19022, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33236, 19022, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33229, 19025, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33230, 19025, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33231, 19025, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33250, 19024, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33251, 19024, 337, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33252, 19024, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33253, 19024, 123, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33241, 18969, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33242, 18969, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33243, 18969, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33244, 18969, 16, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33245, 18969, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32829, 18578, 317, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32830, 18578, 48, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32831, 18578, 92, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33264, 18578, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33265, 18578, 61, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (33275, 6187, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33134, 18495, 29, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (33288, 17045, 222, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33278, 19038, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33279, 19038, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33280, 17264, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33281, 17264, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33262, 7940, 321, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33282, 17047, 185, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33283, 17047, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33284, 17046, 95, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (29301, 17043, 317, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33289, 17042, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33290, 17042, 234, 6, 2);
INSERT INTO 'dancesformationsmap' VALUES (33291, 17044, 58, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33160, 18973, 27, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (33161, 18973, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (33162, 18973, 148, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33146, 18967, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33286, 15608, 280, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33287, 15608, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33301, 19011, 216, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (33302, 19011, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33303, 19011, 210, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33304, 19011, 220, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33305, 11274, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33306, 8389, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33309, 11273, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33310, 11273, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33311, 6520, 373, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33312, 6520, 1, 21, 5);
INSERT INTO 'dancesformationsmap' VALUES (33313, 6520, 8, 25, 5);
INSERT INTO 'dancesformationsmap' VALUES (33266, 19031, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33267, 19031, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33272, 19031, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33297, 19040, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33174, 18951, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33175, 18951, 120, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33127, 18926, 386, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33128, 18926, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33187, 18977, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33298, 19041, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33299, 19041, 12, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33300, 19041, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (33188, 18977, 184, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33189, 18977, 386, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33169, 18954, 186, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33118, 43, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33170, 18954, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33200, 9064, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33201, 9064, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33202, 9064, 278, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (33171, 18954, 154, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33307, 15206, 225, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33308, 15206, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33087, 18741, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33088, 18741, 241, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33314, 6520, 157, 33, 5);
INSERT INTO 'dancesformationsmap' VALUES (33315, 6520, 230, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (33319, 19043, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33320, 19043, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33254, 19018, 55, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (33255, 19018, 121, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (33256, 19018, 296, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (33129, 3896, 84, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (33152, 18971, 143, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33153, 18971, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33154, 18971, 1, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (33155, 18971, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33172, 18953, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33173, 18953, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25498, 15836, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (17120, 7125, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33157, 18972, 263, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33158, 18972, 189, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (33159, 18972, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33276, 19034, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33277, 19034, 313, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33195, 19010, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33196, 19010, 317, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33321, 19043, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33322, 2739, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33323, 2739, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33324, 2739, 36, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33453, 19066, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33454, 19066, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33360, 19032, 106, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33328, 16764, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33329, 16764, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33330, 17113, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33331, 17113, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33332, 18695, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33333, 18695, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33334, 18695, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33335, 18695, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14158, 4380, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (33399, 17530, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33339, 18911, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33340, 18911, 53, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33341, 18911, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33342, 18911, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33343, 18668, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33344, 18668, 114, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (33345, 917, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33346, 917, 39, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33400, 17530, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33443, 17448, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9070, 8165, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9809, 9380, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33355, 19052, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33356, 19052, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33357, 19052, 224, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33358, 19052, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33383, 7387, 183, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33384, 7387, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33385, 7387, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33363, 17106, 65, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33364, 17107, 359, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33365, 17107, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33366, 17107, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33367, 17107, 214, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33368, 17108, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33369, 17108, 101, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33370, 17108, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33371, 17108, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33350, 19050, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33351, 19050, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33352, 19050, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8619, 8718, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (8620, 8718, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24166, 15286, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33381, 4092, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33382, 4092, 111, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (19221, 8064, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33456, 19067, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33457, 19067, 353, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33353, 19051, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33354, 19051, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14749, 11360, 89, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14750, 11360, 72, 25, 5);
INSERT INTO 'dancesformationsmap' VALUES (33389, 19055, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33390, 19055, 186, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33391, 19055, 154, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (33392, 19057, 321, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (33393, 19057, 84, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (33394, 19057, 225, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (33396, 14471, 222, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (33397, 14471, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33398, 17536, 214, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33402, 14971, 326, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33403, 14971, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33404, 14971, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14743, 11358, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14744, 11358, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (33406, 5440, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33407, 5440, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33414, 17434, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33415, 17434, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33416, 17434, 193, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33417, 17441, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33418, 17441, 154, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30675, 17980, 90, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30676, 17980, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30677, 17980, 33, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (30678, 17980, 23, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (33419, 17441, 134, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (33420, 17441, 234, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33421, 17441, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33422, 17454, 30, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33423, 17454, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33424, 17452, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33408, 17314, 25, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33409, 17314, 82, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (33410, 17314, 76, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (33425, 17452, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33426, 17452, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33411, 19058, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33412, 19058, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33413, 19058, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33451, 19065, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33452, 19065, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33431, 17450, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33432, 17450, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33433, 17450, 148, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33434, 17450, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33444, 17448, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33439, 17449, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33440, 17449, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33441, 17449, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33442, 17449, 154, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31069, 18118, 15, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33435, 18118, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33445, 17448, 134, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (33450, 17446, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33446, 17447, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33447, 17447, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33448, 17447, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33449, 17447, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33458, 19068, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33459, 19068, 281, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33460, 19068, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (33461, 19068, 280, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33462, 19068, 38, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (33361, 19032, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33362, 19032, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33427, 7503, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33428, 7503, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23422, 5060, 29, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (33325, 17104, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33326, 17104, 7, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (33327, 17104, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32787, 18560, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33386, 18560, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33387, 18560, 8, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33401, 18398, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33472, 19072, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33473, 19072, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33474, 19072, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33475, 19072, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25243, 15740, 110, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33493, 19089, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33494, 19089, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33495, 19090, 114, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33496, 19090, 183, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (33497, 19091, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33498, 19091, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33499, 19092, 365, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (33500, 19092, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (33375, 17116, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33119, 43, 143, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (33376, 17116, 210, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33347, 19049, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33348, 19049, 186, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33349, 19049, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33336, 18357, 18, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33337, 18357, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33338, 18357, 145, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33487, 19087, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33488, 19087, 72, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (33489, 19087, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33481, 19074, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33482, 19074, 32, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33483, 19074, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33501, 19093, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33502, 19093, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33503, 19093, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (33405, 6368, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (33484, 19086, 42, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (31386, 2671, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (33436, 13296, 142, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33437, 13296, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17978, 12451, 38, 56, 1);
INSERT INTO 'dancesformationsmap' VALUES (14442, 11192, 29, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (33463, 19069, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33464, 19069, 314, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (33465, 19069, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33508, 19096, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33509, 19096, 192, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33510, 19096, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (33511, 19097, 305, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (33512, 19097, 324, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33513, 19097, 225, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33520, 19101, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33521, 19101, 72, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (33522, 19101, 114, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33523, 19101, 112, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (33524, 19101, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33525, 19102, 378, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33526, 19102, 192, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (33527, 19102, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33528, 19102, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (33529, 19102, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33530, 19102, 9, 37, 3);
INSERT INTO 'dancesformationsmap' VALUES (25959, 15956, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25960, 15956, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25961, 15956, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (33532, 19033, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33533, 19033, 12, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33534, 19033, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (33535, 19033, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14677, 11289, 364, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33542, 19105, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33543, 19105, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33544, 19105, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33545, 19105, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33550, 15046, 324, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33551, 15046, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (33552, 19116, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33553, 19116, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33554, 19116, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33557, 264, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33555, 19117, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33556, 19117, 119, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33558, 19117, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33559, 19117, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33560, 4897, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33561, 4897, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33562, 4897, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33563, 4897, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (33570, 19112, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33571, 19112, 110, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33572, 19112, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33573, 19112, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (33466, 19070, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33467, 19070, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33468, 19070, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33469, 19070, 239, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33517, 19099, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33518, 19099, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33574, 19111, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33575, 19111, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33536, 19103, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33537, 19103, 145, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33576, 19111, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33577, 19111, 186, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33578, 19111, 365, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33579, 19109, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33580, 19109, 92, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33581, 19109, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (33599, 19106, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33600, 19106, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33601, 19106, 225, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (33582, 19113, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33583, 19113, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33584, 19113, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33585, 19113, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (33586, 19113, 69, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (33587, 19113, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33588, 13812, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21657, 13813, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33593, 19123, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33594, 19123, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33598, 19106, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33490, 19088, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33491, 19088, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (413, 739, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33608, 15493, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33609, 15493, 93, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33610, 15495, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33611, 15495, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33612, 15495, 94, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33613, 15495, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33602, 19124, 277, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (33603, 19124, 16, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (33492, 19088, 296, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33504, 19094, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33505, 19094, 145, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33595, 16169, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33624, 19127, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33596, 16169, 249, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33597, 16169, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33506, 19094, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33604, 15492, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33605, 15492, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33606, 15492, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33607, 15492, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33507, 19094, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33565, 17979, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33470, 19071, 183, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (33471, 19071, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33519, 19100, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33566, 17979, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33567, 17979, 87, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33568, 17979, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33514, 19098, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (33515, 19098, 114, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33516, 19098, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33476, 19073, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33477, 19073, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33478, 19073, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33479, 19073, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33538, 19104, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33539, 19104, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33564, 19104, 84, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33455, 19066, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23623, 15149, 182, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23624, 15149, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33713, 19108, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33714, 19108, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33715, 19108, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33614, 19125, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33615, 19125, 202, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33616, 19125, 185, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (33617, 19125, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (33618, 19125, 23, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (33716, 13799, 15, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33717, 13799, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25686, 15887, 234, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33628, 15887, 5, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33625, 19127, 102, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33626, 19127, 96, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33627, 19127, 241, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33629, 19128, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33630, 19128, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33631, 19128, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33632, 19128, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33633, 16169, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33634, 16169, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33642, 18910, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33643, 18910, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15811, 11676, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (33734, 19110, 222, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (21034, 13321, 172, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (33645, 19107, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33646, 19107, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15293, 11553, 26, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15294, 11553, 102, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33667, 11024, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33668, 11024, 149, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33669, 11024, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33653, 11019, 105, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33540, 1173, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33541, 1173, 386, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33372, 19053, 94, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33373, 19053, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33546, 19115, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33547, 19115, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33548, 19115, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33654, 11019, 76, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (21679, 13821, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33619, 19126, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21038, 13322, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19965, 12949, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26633, 16106, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26634, 16106, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26635, 16106, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10166, 9562, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10167, 9562, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3450, 6526, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33589, 19119, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33590, 19119, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32790, 13592, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33591, 19120, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33592, 19120, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33655, 11021, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33656, 11021, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33657, 11021, 15, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (33658, 11021, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33659, 11022, 71, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33660, 11022, 55, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33661, 11022, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33662, 11022, 5, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33665, 11023, 224, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (33666, 11023, 49, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33748, 12343, 224, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33749, 12343, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33569, 17979, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33674, 11028, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33675, 11028, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33676, 11028, 65, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33737, 11553, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33722, 18211, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33723, 18211, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33677, 10040, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33678, 10040, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33679, 10040, 42, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (33680, 10040, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (23141, 14925, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (33684, 7421, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33685, 7421, 114, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33686, 7421, 251, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33724, 18213, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33725, 18213, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33726, 18217, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33727, 18217, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33728, 18217, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33692, 15482, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33693, 15482, 1, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (26228, 16033, 145, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (33694, 13789, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33695, 13789, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33696, 13789, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33697, 13790, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33698, 13790, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33699, 13791, 12, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33700, 13792, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33701, 13792, 8, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33702, 13792, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33703, 13793, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33704, 13793, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33705, 13793, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33706, 13794, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33707, 13794, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33708, 13794, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33709, 18734, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33710, 18734, 92, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33738, 19037, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33739, 19037, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33740, 19037, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33718, 19130, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33719, 19130, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33720, 19130, 329, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33741, 19133, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33742, 19133, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33743, 19133, 13, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33744, 19133, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (33729, 14020, 1, 1, 5);
INSERT INTO 'dancesformationsmap' VALUES (33730, 14020, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33731, 14020, 103, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33732, 14020, 27, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (33733, 1613, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33745, 12344, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33746, 12344, 249, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33747, 12344, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33663, 19129, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33664, 19129, 213, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33770, 13865, 92, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33771, 13865, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33768, 2484, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33769, 2484, 55, 21, 4);
INSERT INTO 'dancesformationsmap' VALUES (33772, 13865, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33644, 17979, 39, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (33750, 12343, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33735, 19110, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33736, 19110, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33480, 19073, 183, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (33670, 11024, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33671, 11026, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33672, 11026, 87, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33673, 11026, 117, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33647, 11015, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33649, 11015, 262, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (33711, 19066, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33712, 19066, 71, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33804, 19142, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13655, 10794, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33789, 2284, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33790, 2284, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33799, 18956, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33800, 18956, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33924, 3516, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33925, 3516, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33807, 3743, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (33815, 4586, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33821, 19143, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (33822, 19143, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33921, 16615, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33922, 16615, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33923, 16615, 297, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33830, 14187, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33831, 14187, 109, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33832, 14187, 84, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (33833, 4924, 235, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33834, 4924, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33835, 4924, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (33904, 19167, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33905, 19167, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33906, 19167, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33907, 19167, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33927, 16835, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33928, 16835, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33929, 16835, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33681, 17937, 225, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33721, 19131, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33682, 17937, 86, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33683, 17937, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33808, 7261, 43, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (33809, 7261, 69, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (33754, 14443, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (33786, 14445, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33787, 14445, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31294, 14446, 69, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31295, 14446, 328, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33816, 14448, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33817, 14448, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33755, 14449, 175, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33756, 14449, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33757, 14449, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (33758, 14449, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33759, 14450, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33760, 14450, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33761, 14450, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33762, 14450, 154, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (33763, 14450, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (33764, 14451, 45, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (33765, 14451, 354, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33766, 14451, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33767, 14451, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33773, 14452, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33774, 14452, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (33782, 14459, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (33783, 14459, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33784, 14459, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33785, 14459, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33811, 14970, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33911, 19169, 213, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33812, 14970, 363, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33813, 14970, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33687, 11020, 183, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (33688, 11020, 23, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (33689, 11020, 121, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (33777, 13637, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33778, 13637, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33779, 13637, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33690, 11020, 117, 4, 4);
INSERT INTO 'dancesformationsmap' VALUES (33638, 18841, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33650, 11018, 249, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (33651, 11018, 112, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33652, 11018, 72, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (33826, 14194, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33827, 14194, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33828, 14194, 92, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12069, 10361, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33639, 18841, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33640, 18841, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33836, 17324, 193, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (33837, 17324, 224, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (33838, 17324, 1, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (33839, 17324, 29, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (33851, 19150, 261, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33852, 19150, 72, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (33853, 19150, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33859, 19152, 72, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (33860, 19152, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33861, 19152, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33871, 19156, 135, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33872, 19156, 42, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (33873, 19156, 66, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33877, 19158, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33878, 19158, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33879, 19158, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33880, 19159, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33881, 19159, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33882, 19159, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (33883, 19160, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33884, 19160, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20973, 13305, 1, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32289, 18395, 193, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (30882, 18044, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (33915, 14620, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33916, 14620, 102, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33917, 14620, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33918, 14620, 8, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33919, 19094, 36, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33920, 19094, 71, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (33930, 9284, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33931, 9284, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33932, 9284, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (33933, 9284, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33934, 9282, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33935, 9282, 29, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33936, 9282, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33937, 9282, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33949, 15484, 2, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33950, 15484, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20974, 13305, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (20975, 13305, 92, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33939, 18164, 6, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33940, 18164, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33941, 18164, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33942, 5344, 197, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33943, 5344, 24, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (33908, 19168, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33909, 19168, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33910, 19168, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33951, 15484, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33874, 19157, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33875, 19157, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33876, 19157, 134, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (33797, 18941, 21, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33798, 18941, 280, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33791, 18946, 114, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33805, 19142, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33947, 15481, 324, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33801, 18655, 186, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33802, 18655, 154, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33926, 3516, 64, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (33823, 19144, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33825, 19144, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33948, 15481, 331, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33952, 15484, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33953, 15485, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33954, 15485, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33955, 15485, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33956, 15485, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33957, 15486, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33958, 15486, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33959, 15486, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33960, 15486, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33961, 15487, 86, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33962, 15488, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33963, 15488, 90, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33964, 15489, 176, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33965, 15489, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33966, 15491, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33967, 15491, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33968, 15491, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33969, 15491, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33970, 15496, 114, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (33971, 15497, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33972, 15497, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33973, 15497, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33976, 15500, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33977, 15500, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33984, 15506, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33985, 15506, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33986, 15506, 220, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33987, 15506, 29, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (33988, 15506, 87, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (33989, 15506, 69, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (33990, 15506, 176, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (33991, 15506, 1, 113, 1);
INSERT INTO 'dancesformationsmap' VALUES (33992, 15506, 66, 121, 1);
INSERT INTO 'dancesformationsmap' VALUES (33996, 15508, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33997, 15508, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33998, 15508, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33999, 15509, 87, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34000, 15509, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34001, 15510, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34002, 15510, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34003, 15510, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (34004, 15510, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33993, 15507, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33994, 15507, 226, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33995, 15507, 134, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34005, 15511, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34009, 15513, 86, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34010, 15513, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34018, 15516, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34019, 15516, 316, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34020, 15516, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34021, 15517, 83, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34022, 15518, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34023, 15518, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34024, 15518, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34025, 15518, 8, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34026, 15518, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34011, 15514, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34012, 15514, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34013, 15514, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34032, 15520, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33794, 19135, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33795, 19135, 162, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33792, 19134, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33793, 19134, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33854, 19151, 66, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33855, 19151, 183, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (33864, 19154, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33865, 19154, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33866, 19154, 105, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33848, 19148, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33844, 19147, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33845, 19147, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33840, 19145, 72, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (33841, 19145, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33842, 19145, 185, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33846, 19147, 58, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33847, 19147, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33892, 19163, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33893, 19163, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33849, 19149, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (33850, 19149, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33896, 19164, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33897, 19164, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33894, 19163, 176, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33889, 19162, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33890, 19162, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33891, 19162, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33885, 19161, 65, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33886, 19161, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33887, 19161, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33944, 424, 197, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33945, 424, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33946, 424, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20998, 13310, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20999, 13310, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33900, 19166, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33901, 19166, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33843, 19146, 30, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33980, 15503, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33938, 10170, 154, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33814, 6326, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33912, 19169, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33913, 19169, 114, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (33914, 19169, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33781, 13637, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33902, 19166, 102, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34033, 15520, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34034, 15521, 286, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34035, 15521, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34036, 15521, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34037, 15522, 72, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (34038, 15522, 87, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34039, 15522, 32, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (34040, 15523, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34041, 15523, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34042, 15523, 114, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34014, 15515, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34015, 15515, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34016, 15515, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34017, 15515, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33429, 7503, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33430, 7503, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18801, 7311, 18, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34052, 1406, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (34056, 18719, 93, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (34057, 18719, 32, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (34058, 18719, 52, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34059, 18719, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34053, 10953, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34054, 10953, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34055, 10953, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34082, 18591, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34083, 18591, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34068, 12316, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34069, 12316, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34070, 12316, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34064, 6582, 23, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34065, 6582, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34066, 6582, 67, 30, 1);
INSERT INTO 'dancesformationsmap' VALUES (13416, 10576, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13417, 10576, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34067, 10576, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34073, 10157, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34074, 14200, 119, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34075, 14200, 168, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34084, 14817, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34085, 14817, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34086, 14817, 321, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34087, 14817, 120, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34088, 14817, 328, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34079, 19170, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34080, 19170, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (34081, 19170, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34089, 17500, 7, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34090, 17500, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34076, 12190, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34096, 19175, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34097, 19175, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34098, 19175, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34099, 19176, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34100, 19176, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34101, 19176, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34077, 12190, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34078, 12190, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34006, 15512, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34007, 15512, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34008, 15512, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34071, 12316, 263, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33974, 15498, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33975, 15498, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34027, 15519, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34028, 15519, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33978, 15501, 112, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33979, 15501, 93, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (34029, 15519, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34030, 15519, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28337, 16738, 23, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (28338, 16738, 38, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34106, 18747, 119, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (34107, 18747, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34108, 18747, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30862, 9558, 23, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (34112, 14816, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (34113, 14816, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34114, 14816, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34115, 14815, 114, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (34188, 163, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34189, 163, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34117, 19179, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34118, 19179, 154, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34119, 19179, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34120, 18760, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34121, 18760, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34122, 18760, 354, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13295, 1546, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (13296, 1546, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13297, 1546, 123, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34185, 6966, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14964, 11464, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14965, 11464, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26847, 5936, 131, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34130, 1784, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34131, 1784, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34132, 19181, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34133, 19181, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34134, 19181, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34135, 3241, 103, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34136, 3241, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34137, 2797, 183, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (34138, 2797, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34139, 2797, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34140, 3851, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34141, 3851, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19055, 12777, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34172, 11178, 120, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34190, 163, 359, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34192, 2399, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34208, 7591, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34193, 10013, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13525, 10644, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33029, 18670, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33030, 18670, 131, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33031, 18670, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34145, 18670, 96, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (34146, 7296, 49, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32458, 14372, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (19842, 13001, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11644, 7575, 9, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (33867, 19155, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33868, 19155, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19843, 13001, 89, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19844, 13001, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33895, 19163, 66, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32503, 15301, 249, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (32504, 15301, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32505, 15301, 85, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9142, 8729, 142, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (9794, 9376, 78, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34180, 9376, 62, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8353, 8630, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34155, 15303, 193, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (17645, 12246, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34061, 18718, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34062, 18718, 313, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (34063, 18718, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19334, 12790, 77, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (17646, 12246, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (16778, 11640, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15203, 11523, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17325, 11205, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17326, 11205, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17327, 11205, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (13234, 10516, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34128, 19180, 305, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8349, 8629, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30865, 8628, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34129, 19180, 222, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13503, 8352, 33, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (12442, 7576, 296, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (12443, 7576, 32, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (22373, 845, 148, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34060, 18708, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8775, 2846, 132, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8776, 2846, 149, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34191, 1008, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (7474, 7558, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (7475, 7558, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10541, 9776, 48, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34147, 19182, 114, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34148, 19182, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34149, 19182, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34150, 19182, 307, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34091, 19174, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34092, 19174, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34109, 19177, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33898, 19165, 183, 33, 8);
INSERT INTO 'dancesformationsmap' VALUES (33899, 19165, 8, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (6592, 2823, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34047, 15525, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34048, 15525, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (34049, 15525, 95, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (34043, 15524, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34044, 15524, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34045, 15524, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32518, 15287, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34156, 15287, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34157, 2718, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34158, 2718, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34159, 2718, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34165, 14963, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34166, 14963, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34167, 14963, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34168, 14963, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34169, 12027, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34170, 12027, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34171, 12027, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18687, 12669, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34182, 10644, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (34194, 19183, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34195, 19183, 235, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (34196, 19183, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34209, 7591, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34210, 7591, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34211, 7591, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34102, 12771, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34103, 12771, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34104, 12771, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34105, 12771, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34197, 19183, 8, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34198, 6549, 64, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34199, 6549, 63, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34200, 6549, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34201, 9226, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34202, 9226, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34203, 9226, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34204, 8097, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34205, 8097, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34206, 8097, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34207, 8097, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34214, 9945, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (34215, 9945, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34216, 10764, 52, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34217, 10764, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34218, 10764, 183, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (34212, 6729, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (34213, 6729, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34219, 10159, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34220, 10160, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (34221, 10160, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34222, 10160, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34223, 10160, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34224, 7783, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34225, 7783, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34226, 7783, 36, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (34227, 5095, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34231, 15978, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34229, 9287, 119, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34230, 9287, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34232, 15978, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (12832, 7578, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34173, 11178, 121, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34174, 11178, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34186, 6966, 326, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34187, 6966, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34183, 18565, 273, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34184, 18565, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34235, 12345, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34236, 12345, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34237, 12345, 134, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (34238, 12345, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34239, 19012, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34240, 19012, 110, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34241, 19012, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34242, 19012, 32, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (34250, 14961, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34251, 14961, 217, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34252, 14961, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34253, 17098, 154, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34254, 17098, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34255, 17098, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34256, 18031, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34257, 18031, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34258, 18031, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34259, 18031, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34260, 18031, 56, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (34261, 18029, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34262, 18029, 39, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34263, 18029, 168, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34264, 15585, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34265, 15585, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34266, 15585, 154, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34267, 15585, 39, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34268, 15585, 56, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34269, 15585, 32, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (34270, 15585, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34271, 14766, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (34272, 14766, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34301, 19189, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26385, 13488, 245, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34302, 19189, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30349, 14725, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34303, 19189, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34304, 19189, 42, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14027, 10944, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34280, 4984, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34281, 14349, 197, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34282, 19186, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34283, 19186, 186, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34284, 19186, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34274, 19184, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34275, 19184, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34276, 19184, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34277, 19184, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22374, 6205, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17474, 12122, 216, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34321, 19194, 75, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34322, 19194, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34323, 19194, 92, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (6234, 7120, 30, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (15235, 11534, 294, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15236, 11534, 119, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (34181, 10417, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (10290, 9647, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19785, 12944, 224, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19786, 12944, 94, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (19787, 12944, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (19592, 12875, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16772, 11638, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (15190, 11519, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13402, 10569, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13386, 10564, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13575, 10549, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34273, 18553, 119, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (34314, 19192, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34315, 19192, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13284, 10525, 185, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13285, 10525, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (18425, 10435, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11299, 10114, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34176, 19059, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34177, 19059, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (7712, 8102, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34151, 6845, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34152, 6845, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34153, 6845, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34316, 19192, 294, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34154, 6845, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34160, 12302, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34161, 12302, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34162, 12302, 248, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12626, 10456, 43, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (12627, 10456, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34289, 19188, 92, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34290, 19188, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34291, 19188, 154, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (34300, 19188, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30832, 16955, 234, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (30837, 16957, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30838, 16957, 365, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (34340, 19199, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34341, 19199, 262, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (34334, 8552, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30829, 18036, 193, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (30830, 18036, 154, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (30831, 18036, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30857, 18036, 319, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (21974, 14352, 217, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21975, 14352, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21976, 14352, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22093, 5972, 72, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (22094, 5972, 36, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34110, 19177, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10753, 9882, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (32814, 18569, 241, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34123, 14155, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34124, 14155, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34125, 14155, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34126, 14155, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34292, 17811, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34293, 17811, 23, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (34294, 17811, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34295, 17811, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34335, 8552, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34336, 8552, 193, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34305, 13419, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34306, 13419, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34307, 10445, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34308, 10445, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34309, 10445, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34310, 10445, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34337, 8547, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34338, 8547, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34330, 8549, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34331, 8549, 249, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34332, 8549, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34333, 8549, 273, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34339, 8547, 6, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34344, 10593, 246, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34345, 3482, 114, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34346, 3899, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34347, 3899, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (34348, 3899, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11794, 4111, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34349, 11229, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34350, 11229, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34351, 11229, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34352, 11229, 183, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (34354, 9006, 166, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34355, 9006, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34357, 9818, 38, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34358, 9683, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34359, 9683, 30, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (34360, 9683, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34361, 10141, 185, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34362, 10141, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26761, 16139, 85, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26762, 16139, 112, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (34363, 10141, 183, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (34364, 10141, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34369, 10181, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34370, 10181, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34371, 10181, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34372, 10181, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34373, 10181, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34374, 10182, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34375, 10182, 6, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34376, 10182, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34278, 19185, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34279, 19185, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34296, 12348, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34297, 12348, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34298, 12348, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (17251, 12080, 229, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34299, 12348, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34233, 18566, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34234, 18566, 114, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34377, 10182, 185, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34378, 14951, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34379, 14951, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34380, 14951, 363, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34381, 14951, 10, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34382, 14953, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34383, 14953, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34384, 15042, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34385, 15042, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34386, 15042, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34467, 15664, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34318, 19195, 220, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34319, 19195, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (34320, 19195, 234, 17, 8);
INSERT INTO 'dancesformationsmap' VALUES (34387, 19195, 23, 14, 4);
INSERT INTO 'dancesformationsmap' VALUES (34388, 9577, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10191, 9572, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34389, 9405, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34390, 9405, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34391, 9389, 33, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (34392, 9296, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (34393, 2141, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34394, 2416, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34395, 2416, 9, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34396, 2416, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34397, 2416, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34398, 2208, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34399, 2301, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30462, 15299, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19119, 3803, 8, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (34448, 13572, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34449, 13572, 15, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (34450, 13572, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34451, 13572, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32998, 18658, 32, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (33803, 18655, 36, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34408, 18622, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34409, 18622, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34410, 18622, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34411, 18617, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34412, 18617, 12, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34413, 18617, 72, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (34414, 18617, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34415, 18528, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34416, 18528, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34417, 18528, 134, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34418, 18528, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34419, 16836, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34420, 16836, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34421, 16836, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34422, 16834, 365, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34423, 16834, 76, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (34424, 16834, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21875, 13267, 23, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (21876, 13267, 43, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (21877, 13267, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (21878, 13267, 32, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (21879, 13267, 38, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (34342, 19199, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34425, 19199, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34426, 19199, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34427, 11784, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34428, 6819, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34429, 5686, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26773, 16141, 90, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (26774, 16141, 117, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (26775, 16141, 210, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (26776, 16141, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (34468, 15664, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34469, 15664, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34439, 17323, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34440, 17323, 277, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (34441, 17323, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34444, 12297, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34445, 12297, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34446, 12297, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34447, 12297, 23, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (32533, 15292, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33641, 18841, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34311, 8544, 4, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34438, 2363, 157, 57, 4);
INSERT INTO 'dancesformationsmap' VALUES (34324, 8548, 55, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34325, 8548, 249, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (34326, 8548, 162, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34327, 8548, 224, 4, 5);
INSERT INTO 'dancesformationsmap' VALUES (34356, 9020, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (18696, 12671, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34343, 9983, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34433, 19201, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34434, 19201, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (34435, 19201, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34312, 8544, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34313, 8544, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16481, 11897, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34405, 726, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34406, 726, 114, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34407, 726, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (34452, 19203, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34453, 19203, 317, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (34454, 19203, 251, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34455, 19203, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34456, 8243, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34457, 8243, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34458, 8243, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (34459, 8243, 249, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (34460, 8243, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (34461, 8243, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (31712, 16794, 213, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (34462, 16576, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34463, 16576, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26410, 16055, 82, 105, 2);
INSERT INTO 'dancesformationsmap' VALUES (26411, 16055, 75, 233, 1);
INSERT INTO 'dancesformationsmap' VALUES (26412, 16055, 38, 249, 1);
INSERT INTO 'dancesformationsmap' VALUES (34475, 17162, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34353, 8650, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34285, 19187, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34286, 19187, 386, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34287, 19187, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34365, 10168, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34366, 10168, 7, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34367, 10168, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34368, 10168, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (158, 282, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34400, 282, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34401, 282, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34402, 282, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34476, 17162, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34477, 17162, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34464, 17155, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7842, 8211, 8, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (34430, 8211, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34431, 8211, 27, 49, 4);
INSERT INTO 'dancesformationsmap' VALUES (34494, 14236, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34495, 14236, 168, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34496, 14236, 30, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34489, 2551, 249, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34490, 2551, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34491, 15066, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34492, 15066, 39, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34493, 15066, 56, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34497, 14236, 36, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34498, 14819, 56, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34499, 14819, 222, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34500, 14819, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34501, 14819, 23, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (34502, 14819, 62, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34503, 14819, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34507, 15037, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34508, 15037, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34509, 15037, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34510, 15037, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34511, 15037, 186, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34512, 14233, 222, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34513, 14233, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34514, 14233, 265, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34515, 14233, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34432, 8211, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (34442, 13779, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34443, 13779, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34403, 457, 7, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (34404, 457, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32802, 18563, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34599, 19222, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34600, 19222, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34601, 19222, 7, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (24320, 13135, 58, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34602, 19222, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10792, 9900, 87, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (34603, 9879, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (34522, 3708, 193, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34523, 3708, 249, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (34524, 3708, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34525, 2920, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34526, 2920, 157, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (34465, 17155, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34466, 17155, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34527, 15062, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34528, 15062, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34529, 8523, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34530, 8523, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34531, 8523, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34532, 8523, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34533, 14943, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34534, 14943, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34535, 14943, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34536, 15072, 112, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34537, 15072, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34541, 13126, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34542, 13126, 314, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34543, 13126, 72, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (29726, 12803, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (18963, 12760, 149, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (18964, 12760, 90, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (18965, 12760, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (18276, 12531, 72, 29, 3);
INSERT INTO 'dancesformationsmap' VALUES (34544, 12466, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34606, 4550, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34607, 4550, 96, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (34608, 4550, 263, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (34538, 19205, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34539, 19205, 15, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (34540, 19205, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34650, 8575, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34651, 8575, 56, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (34652, 8575, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34653, 8575, 72, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34549, 10759, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34550, 10759, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34551, 10759, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34552, 11016, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34553, 11016, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34554, 11016, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34555, 11016, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15024, 11487, 64, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (15025, 11487, 193, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (15180, 11516, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15181, 11516, 176, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15182, 11516, 52, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (15183, 11516, 93, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (34556, 11633, 120, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (17081, 11986, 7, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (17082, 11986, 8, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (17083, 11986, 93, 61, 1);
INSERT INTO 'dancesformationsmap' VALUES (17084, 11986, 149, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (34557, 12301, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34558, 12301, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34559, 12301, 117, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34560, 12301, 183, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (34561, 12301, 149, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (34562, 12301, 66, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (34633, 9187, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34634, 9187, 101, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34568, 10702, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34569, 10702, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34570, 10702, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34571, 10702, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (9612, 9159, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28677, 16839, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34575, 10651, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34576, 10651, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34577, 10651, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34578, 10651, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34579, 12170, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34580, 12170, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34581, 12170, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34582, 18948, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34583, 18948, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34584, 18948, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34585, 18948, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34586, 18663, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34587, 18663, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34588, 18663, 134, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34485, 19135, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34572, 10701, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34516, 13129, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34517, 13129, 134, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34518, 13129, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34482, 18503, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34483, 18503, 111, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34563, 12381, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34564, 12381, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34565, 12381, 145, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (34504, 15035, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34505, 15035, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34506, 15035, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32489, 15303, 72, 4, 3);
INSERT INTO 'dancesformationsmap' VALUES (32490, 15303, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19625, 12886, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19626, 12886, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19627, 12886, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13957, 10914, 120, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13593, 10775, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (13594, 10775, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34486, 19200, 158, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34487, 19200, 355, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34488, 19200, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16485, 11898, 65, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34589, 18663, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34566, 12014, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34567, 12014, 71, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34590, 9669, 251, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34591, 10156, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34592, 10156, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34593, 10156, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34594, 10156, 216, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13269, 10147, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13270, 10147, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34595, 10017, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34596, 10017, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34598, 12399, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31034, 17745, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9613, 9159, 112, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (34635, 9097, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34636, 9097, 30, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (34609, 19223, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34610, 19223, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34611, 19223, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34612, 19223, 29, 18, 2);
INSERT INTO 'dancesformationsmap' VALUES (9491, 9095, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12410, 9061, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13670, 10798, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (34604, 9876, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (10733, 9874, 149, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34613, 4070, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34614, 4070, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34545, 18264, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34546, 18264, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34547, 18264, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28581, 16825, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28582, 16825, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28583, 16825, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34637, 9004, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34624, 9280, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34625, 9280, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34626, 9280, 94, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34627, 9280, 85, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (34628, 9280, 61, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (34629, 9207, 9, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34630, 9207, 183, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34631, 9207, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34632, 9207, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34638, 9004, 112, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (34639, 9004, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34640, 9004, 175, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34648, 8863, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34649, 8863, 157, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34655, 8528, 18, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34656, 8528, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34657, 8528, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34658, 8528, 9, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12752, 8509, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34666, 8250, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34667, 8250, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34674, 8164, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34675, 8106, 368, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34676, 8106, 7, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34677, 8106, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34678, 8098, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34679, 8098, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34680, 8098, 326, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34755, 6801, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34756, 6801, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34757, 6775, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34758, 6775, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34668, 19225, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34669, 19225, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34670, 19225, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34671, 19225, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34759, 6662, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34760, 6655, 176, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34761, 6655, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (34762, 6506, 176, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34763, 6506, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34764, 6506, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34765, 6506, 72, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (34766, 6506, 84, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (34767, 6506, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34694, 7975, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34695, 7975, 30, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34696, 14966, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34697, 14966, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34698, 14966, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33263, 7940, 4, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34701, 7518, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (34702, 7513, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34703, 7480, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34704, 7480, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34705, 7480, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34683, 19227, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34684, 19227, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34685, 19227, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34686, 19227, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34709, 7458, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34711, 7443, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34712, 7443, 69, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (34710, 7448, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34713, 7414, 143, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34714, 7414, 72, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (34715, 7414, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (34773, 6432, 189, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34774, 6432, 32, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (7427, 7404, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34736, 19235, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27075, 16244, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27076, 16244, 351, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34716, 7358, 43, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (34717, 7358, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34721, 7262, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34722, 19230, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34723, 19230, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3786, 7135, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34724, 7135, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (34726, 7060, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34728, 19232, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34729, 19232, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34730, 19232, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34687, 14478, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34688, 14478, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34777, 6375, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34796, 6143, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34797, 6143, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34743, 6887, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34672, 8170, 225, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34615, 9658, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34616, 9658, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34623, 9332, 225, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (34798, 6116, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34746, 6835, 7, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34691, 8023, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34692, 8023, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34693, 8023, 183, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (34747, 6835, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8467, 8672, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8468, 8672, 56, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (8469, 8672, 94, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34620, 9468, 7, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34621, 9468, 43, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (34622, 9468, 157, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (16768, 11637, 48, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10277, 9570, 43, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (34645, 8912, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34646, 8912, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15910, 8464, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7423, 7375, 43, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (9032, 7980, 234, 83, 1);
INSERT INTO 'dancesformationsmap' VALUES (9033, 7980, 157, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (15911, 8464, 7, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (3624, 6829, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34748, 6829, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (34749, 6829, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (34750, 6829, 32, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34751, 6829, 39, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (34752, 6829, 72, 45, 2);
INSERT INTO 'dancesformationsmap' VALUES (34753, 6829, 149, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (34754, 6829, 41, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (34778, 6375, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34779, 6375, 36, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (34780, 6341, 269, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34781, 6341, 7, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34783, 6234, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34784, 6234, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34799, 6094, 43, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (34800, 6094, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (34801, 6094, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34802, 6020, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34775, 6420, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34776, 6420, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34725, 7079, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (3476, 6568, 89, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (34734, 19234, 69, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (34785, 6229, 72, 45, 2);
INSERT INTO 'dancesformationsmap' VALUES (34786, 6209, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34787, 6209, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34788, 6185, 189, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34789, 6185, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (34790, 6153, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (34791, 6149, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34792, 6149, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34793, 6149, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34794, 6149, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34699, 7774, 119, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (34700, 7774, 72, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (34737, 19236, 326, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (34738, 19236, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (34739, 19236, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34659, 8493, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34660, 8493, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34661, 8493, 209, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34718, 7288, 9, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (34719, 7288, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34720, 7288, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34744, 6873, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34745, 6873, 38, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34681, 19226, 29, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (34682, 19226, 221, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (34619, 9772, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34768, 6436, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34769, 6436, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34770, 6436, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34771, 6436, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34772, 6436, 63, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34548, 18264, 10, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34706, 17253, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34707, 17253, 95, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34708, 17253, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34795, 6149, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34803, 6020, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34804, 5939, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34805, 5857, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34806, 5857, 72, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (34807, 5857, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34808, 5835, 56, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (34809, 5835, 29, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34810, 5775, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34811, 5775, 7, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (34812, 5764, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34813, 5764, 39, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (34814, 5764, 58, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (34815, 5764, 5, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (34816, 5719, 183, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (34817, 5677, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34818, 5619, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13124, 5593, 7, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (34821, 5518, 248, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34822, 5518, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (34740, 19237, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34741, 19237, 262, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (34742, 19237, 48, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34735, 19234, 143, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (34689, 14478, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34823, 5502, 310, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34824, 5502, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34825, 5502, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33293, 5451, 156, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (34826, 5414, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34827, 5404, 310, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34828, 5404, 7, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (34829, 5387, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34830, 5387, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34831, 5387, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34832, 5345, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34833, 5345, 43, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (34834, 5271, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34835, 5259, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34836, 5208, 7, 61, 1);
INSERT INTO 'dancesformationsmap' VALUES (34837, 5208, 308, 53, 1);
INSERT INTO 'dancesformationsmap' VALUES (34840, 5178, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34841, 5178, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34842, 5178, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34843, 5178, 9, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (34844, 5178, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34845, 5137, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34846, 5137, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34731, 19233, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34732, 19233, 365, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34733, 19233, 162, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34848, 4998, 32, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (11853, 4929, 120, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34853, 4929, 66, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (2576, 4927, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34854, 4884, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34857, 4789, 183, 14, 2);
INSERT INTO 'dancesformationsmap' VALUES (34858, 4789, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (34859, 4789, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34860, 19241, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34861, 19241, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34862, 19241, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34863, 19241, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34864, 4672, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34865, 4668, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34866, 4661, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34867, 4661, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34868, 4661, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34869, 4661, 189, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (34870, 4654, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34871, 4654, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34872, 4654, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34873, 4575, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34874, 4425, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34875, 18322, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34876, 18322, 251, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34877, 18322, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34878, 18322, 17, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34175, 11178, 85, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34943, 11178, 43, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (17570, 4226, 176, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (17571, 4226, 23, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (17572, 4226, 90, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (34882, 17498, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34883, 17498, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (34884, 4145, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34885, 4145, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34886, 3978, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34887, 3978, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34888, 3869, 7, 41, 3);
INSERT INTO 'dancesformationsmap' VALUES (34889, 3799, 7, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (34890, 3921, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34891, 3806, 192, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (34892, 3806, 189, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (34893, 3806, 117, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (34894, 3806, 162, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (34895, 19239, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34896, 19239, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34897, 19239, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34898, 19239, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34899, 4190, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34900, 4190, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34901, 4190, 185, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (34902, 4190, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (34903, 17494, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34904, 17494, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (34905, 17494, 30, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34906, 17494, 317, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34911, 3789, 332, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34913, 3745, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34914, 3504, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34915, 3461, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34916, 3461, 143, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34917, 3461, 23, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34918, 3461, 66, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (34922, 14432, 365, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34923, 14432, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34924, 3389, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34925, 3389, 202, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34926, 3389, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34927, 3389, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34944, 11178, 249, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34919, 3396, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34920, 3396, 43, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (17559, 4147, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17560, 4147, 296, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17561, 4147, 176, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (13117, 4494, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (34912, 3786, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13118, 4494, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34838, 5200, 30, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34849, 4930, 55, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34850, 4930, 87, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (34851, 4930, 1, 53, 1);
INSERT INTO 'dancesformationsmap' VALUES (34782, 6309, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34855, 4816, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34856, 4816, 175, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34907, 3798, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34908, 3798, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34909, 3798, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34839, 5200, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7592, 5612, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7593, 5612, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34963, 15244, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (34819, 5618, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (34820, 5618, 39, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34960, 2811, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34961, 2811, 185, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34962, 2811, 183, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (34964, 2760, 7, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (34930, 3378, 111, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34931, 3368, 114, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34932, 3368, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34933, 3352, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34934, 3219, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17366, 3009, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34936, 2944, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (34937, 2944, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34938, 2943, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34929, 10737, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34945, 5966, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34946, 5966, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34947, 15048, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34948, 15048, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34949, 15048, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28536, 10737, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28537, 10737, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28538, 10737, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34928, 10737, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34958, 2842, 315, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34959, 2842, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34965, 2743, 32, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (34966, 2743, 27, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (34967, 2743, 148, 51, 1);
INSERT INTO 'dancesformationsmap' VALUES (34968, 2732, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34969, 2732, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34970, 2708, 143, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (17343, 2611, 193, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (17344, 2611, 66, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (34979, 2462, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34921, 3396, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34879, 6805, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34880, 6805, 23, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (13114, 4283, 149, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (34881, 6805, 234, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (34980, 2433, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34981, 6807, 1, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (34982, 6807, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32786, 18560, 186, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26845, 16161, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35059, 751, 69, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (30298, 17772, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35105, 17778, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35106, 17778, 32, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35107, 17782, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34983, 19242, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34984, 19242, 183, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34985, 19242, 23, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (34986, 19242, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34987, 2329, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34988, 2329, 185, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (34989, 2329, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34990, 2329, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34991, 2329, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34992, 2089, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34993, 2089, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34994, 2052, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7684, 2050, 34, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34995, 2050, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34996, 2020, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34997, 2020, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34998, 2014, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34999, 2014, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35000, 2014, 72, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35001, 1996, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35002, 1951, 183, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (35003, 1913, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35005, 1731, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35006, 1720, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35007, 1720, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35008, 1679, 7, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (35009, 1638, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (6470, 1568, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8110, 1566, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8696, 1549, 38, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (35010, 1539, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35011, 1539, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (35015, 1477, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35017, 1393, 7, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35018, 1393, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35019, 1388, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35020, 1388, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35024, 1319, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35025, 1282, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35026, 1282, 176, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35029, 1202, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35030, 1202, 1, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (35031, 1202, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35032, 1202, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35033, 1202, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35034, 1147, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35035, 1058, 85, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35036, 1058, 9, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35037, 1050, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35038, 1045, 32, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (35040, 1007, 43, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35041, 1007, 183, 39, 1);
INSERT INTO 'dancesformationsmap' VALUES (35042, 898, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35043, 898, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35044, 898, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35045, 898, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (7132, 1854, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7133, 1854, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7134, 1854, 52, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35048, 810, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35049, 810, 30, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (35050, 810, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35054, 776, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35055, 776, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35056, 776, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35057, 768, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35058, 768, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35088, 8574, 263, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35061, 710, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35062, 691, 365, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35063, 691, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35064, 691, 7, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (35065, 691, 22, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35073, 590, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (35074, 590, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35075, 573, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35076, 573, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35077, 447, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35078, 447, 72, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15837, 385, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11594, 380, 1, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (35083, 560, 224, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (35084, 560, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34971, 1513, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35066, 684, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14322, 184, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (35067, 684, 176, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (35046, 18356, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35012, 17320, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35013, 17320, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35014, 17320, 157, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (35051, 805, 27, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (35052, 805, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35068, 665, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35069, 665, 183, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (34977, 2492, 83, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35039, 1013, 365, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (34978, 2492, 27, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (34952, 2896, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34953, 2896, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34935, 3147, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (14528, 280, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34950, 15052, 314, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34951, 15052, 42, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (34972, 2507, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34973, 2507, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34955, 2868, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34956, 2868, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34957, 2868, 82, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35004, 10890, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34939, 19060, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34940, 19060, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35071, 605, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35053, 805, 7, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (35072, 605, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35082, 188, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14521, 160, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24521, 15005, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24522, 15005, 193, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (35085, 6861, 308, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35095, 17775, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35089, 8574, 119, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35096, 17777, 1, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (35060, 751, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35087, 4127, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35097, 17777, 318, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35098, 17777, 192, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35099, 17779, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35100, 17779, 23, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (35101, 17779, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35108, 17776, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35109, 17776, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35110, 19248, 145, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35111, 19248, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35016, 1424, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35112, 19248, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35113, 19249, 225, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35114, 19249, 224, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35115, 19249, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35116, 19249, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35102, 17770, 33, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (35090, 8574, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35120, 14502, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35121, 14502, 46, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35086, 19246, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35103, 17770, 183, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (35104, 17770, 29, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35047, 829, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35070, 658, 32, 53, 1);
INSERT INTO 'dancesformationsmap' VALUES (35176, 13768, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35177, 13768, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35178, 13768, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35179, 13768, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23272, 14973, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28382, 16522, 119, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28383, 16522, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28384, 16522, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35181, 19255, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35182, 19255, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35183, 19255, 332, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35211, 19263, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35021, 1338, 185, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35022, 1338, 39, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35023, 1338, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35079, 307, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35080, 307, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35081, 307, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34847, 19240, 283, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14828, 1201, 111, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14829, 1201, 23, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (35212, 19263, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35213, 19263, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35214, 19263, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35184, 19256, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35185, 19256, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35186, 19257, 336, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35187, 19257, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35188, 19257, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35189, 19257, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35238, 19272, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33388, 18560, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35190, 732, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35215, 19264, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35216, 19264, 263, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35217, 19264, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35218, 19265, 12, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35154, 19251, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35155, 19251, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35122, 14502, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35123, 14502, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35124, 14502, 117, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (35125, 14502, 42, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (35126, 14502, 23, 42, 2);
INSERT INTO 'dancesformationsmap' VALUES (35133, 19051, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35134, 19051, 249, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35156, 19251, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35157, 19251, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35219, 19265, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35220, 19265, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35221, 19266, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35265, 2101, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35266, 2101, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35239, 19272, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35222, 19266, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35223, 19266, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22981, 14719, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22982, 14719, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22983, 14719, 119, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35224, 19266, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35225, 19266, 21, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35226, 19266, 154, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35227, 19267, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35228, 19267, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35229, 19267, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35230, 19267, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35200, 19260, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35150, 19250, 306, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35151, 19250, 133, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35152, 19250, 16, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35153, 19250, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23498, 15095, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35149, 15095, 96, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35201, 19260, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35202, 19260, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35203, 19260, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35231, 19269, 326, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35232, 19269, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35233, 19269, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35161, 14474, 308, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35162, 14474, 42, 9, 8);
INSERT INTO 'dancesformationsmap' VALUES (35163, 14474, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35169, 9163, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35170, 12324, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35171, 12324, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35172, 12324, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35173, 12324, 56, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (35174, 12324, 10, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (35175, 12324, 120, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35240, 19272, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35138, 19207, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35139, 19207, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (35140, 19207, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33359, 19052, 145, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35196, 19259, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35197, 19259, 251, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35198, 19259, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35199, 19259, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35204, 19261, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35205, 19261, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35206, 19261, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35207, 19262, 302, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35208, 19262, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35209, 19262, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35210, 19262, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35241, 18851, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35242, 18851, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35243, 18851, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35236, 11645, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35237, 11645, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35234, 13889, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35244, 19273, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35245, 19273, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35246, 19273, 1, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (28498, 14985, 42, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (35235, 14985, 96, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (14708, 11283, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14709, 11283, 112, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14710, 11283, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3938, 214, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35135, 13292, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35136, 13292, 189, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (14529, 280, 1, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (21192, 13600, 247, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31406, 3857, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6310, 214, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35141, 19063, 42, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (35142, 19063, 123, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35143, 19063, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35257, 19081, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35146, 19082, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35147, 19082, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35148, 19082, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35252, 19083, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35253, 19083, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35254, 19083, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35255, 19083, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15922, 8463, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17021, 4291, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (13733, 10842, 324, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (13734, 10842, 43, 37, 4);
INSERT INTO 'dancesformationsmap' VALUES (13735, 10842, 23, 38, 2);
INSERT INTO 'dancesformationsmap' VALUES (13736, 10842, 209, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (12075, 157, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12076, 157, 120, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35247, 19273, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35249, 19274, 262, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35250, 19274, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35251, 19142, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35264, 8149, 67, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23471, 15087, 69, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (23472, 15087, 8, 53, 2);
INSERT INTO 'dancesformationsmap' VALUES (35270, 2313, 185, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35271, 2313, 112, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (35269, 3188, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35164, 19252, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35165, 19252, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35166, 19252, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35167, 19252, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35168, 19252, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35180, 14401, 203, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35282, 5306, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (13782, 10797, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (35267, 2101, 193, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (35268, 2101, 72, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (35374, 19284, 82, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (35375, 19284, 365, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35294, 9431, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35295, 2023, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35296, 2023, 134, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (35297, 2023, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35367, 19283, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35368, 19283, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35369, 19283, 23, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (35370, 19283, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35371, 19283, 249, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35372, 19283, 10, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (35376, 19284, 46, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35337, 19281, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35332, 19278, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35333, 19278, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35334, 19278, 336, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35335, 19278, 365, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (35290, 19276, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35291, 19276, 184, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (35292, 19276, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35293, 19276, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3940, 222, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29850, 222, 365, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35338, 19281, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35336, 2616, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29817, 17576, 259, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29818, 17576, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35285, 19275, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35286, 19275, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33191, 18978, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33192, 18978, 249, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33193, 18978, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33194, 18978, 7, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35339, 19281, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35358, 19282, 10, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (35340, 18618, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35341, 18618, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35342, 18618, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35343, 18618, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35344, 18613, 154, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35345, 18613, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35346, 18613, 209, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (31759, 18282, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31760, 18282, 69, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31761, 18282, 43, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (31763, 18282, 52, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (31764, 18282, 53, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (31765, 18282, 162, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (35289, 18282, 157, 73, 4);
INSERT INTO 'dancesformationsmap' VALUES (35347, 18613, 66, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (35301, 9337, 7, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35348, 18398, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30434, 17795, 143, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30435, 17795, 1, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35302, 19234, 251, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35308, 18589, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35309, 18589, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35310, 18589, 23, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (35311, 18407, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35312, 18407, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35313, 18407, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35314, 18407, 186, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35315, 18407, 42, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35316, 18407, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (26609, 16100, 224, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (26610, 16100, 188, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35317, 14945, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35318, 14945, 273, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35319, 14945, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30436, 17795, 69, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (30437, 17795, 90, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35320, 5305, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35321, 5305, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35322, 10515, 216, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13230, 8193, 33, 43, 1);
INSERT INTO 'dancesformationsmap' VALUES (35323, 8193, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32797, 18562, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35359, 19282, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35360, 19282, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (18437, 12539, 183, 33, 6);
INSERT INTO 'dancesformationsmap' VALUES (35361, 8346, 96, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (35377, 19284, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35378, 19284, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35379, 19284, 67, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (9922, 6672, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9923, 6672, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35362, 6672, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (29594, 16817, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29595, 16817, 26, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29596, 16817, 58, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35373, 16817, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35354, 1834, 46, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35355, 1834, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35381, 19286, 251, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35382, 19286, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35389, 8770, 156, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35390, 8770, 324, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35380, 19286, 29, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35403, 17803, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35404, 17803, 13, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35405, 17803, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35303, 17311, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35304, 17311, 48, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31896, 18288, 353, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35356, 3320, 7, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (35357, 3320, 96, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35391, 19288, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35392, 19288, 43, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (35393, 19288, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35394, 19288, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30133, 17718, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30134, 17718, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35305, 17311, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35306, 17311, 154, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13425, 10580, 210, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35324, 10046, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35325, 10046, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35277, 2269, 87, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (35278, 2269, 162, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35280, 4317, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35281, 4317, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35298, 19078, 29, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (35299, 19078, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35300, 19078, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35363, 19079, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35364, 19079, 111, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (35258, 19081, 23, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (35259, 19081, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35287, 17206, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35288, 17206, 267, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35272, 11196, 220, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35273, 11196, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35274, 11196, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (35275, 11196, 216, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (35279, 2269, 209, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35260, 19271, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35261, 19271, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35262, 19271, 12, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35263, 19271, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35327, 19277, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35408, 19292, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35406, 19285, 9, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35407, 19285, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (35409, 19292, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35410, 19293, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35411, 19293, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35328, 19277, 114, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35329, 19277, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35330, 19277, 93, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35326, 3134, 42, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (32798, 18562, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35412, 19294, 321, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35413, 19294, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35414, 19294, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35415, 19294, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35419, 19296, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35420, 19296, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35421, 19296, 72, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35422, 19296, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35423, 19296, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35424, 19297, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35425, 19297, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35426, 19297, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35427, 19297, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35428, 19298, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35429, 19298, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35430, 19298, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35431, 19299, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35432, 19299, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35433, 19299, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35434, 19299, 5, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35435, 19300, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35436, 19300, 15, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35437, 19300, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35438, 19301, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35439, 19301, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35444, 19303, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35445, 19303, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35446, 19303, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35447, 19304, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35448, 19304, 183, 19, 3);
INSERT INTO 'dancesformationsmap' VALUES (35449, 19305, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35450, 19305, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35416, 19295, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35417, 19295, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35418, 19295, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35470, 19310, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35471, 19310, 197, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35472, 19310, 370, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35494, 19356, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35495, 19356, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35496, 19356, 321, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35497, 19356, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35498, 19356, 119, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35331, 19277, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (14421, 8043, 162, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14422, 8043, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14423, 8043, 158, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20285, 584, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35395, 19290, 1, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35396, 19290, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35397, 19290, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35191, 19258, 386, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35192, 19258, 4, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33380, 17116, 216, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (6855, 4803, 36, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (35386, 4803, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35387, 4803, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (35451, 19306, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35452, 19306, 58, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35453, 19306, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35454, 19306, 219, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35519, 566, 139, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35520, 566, 225, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35521, 566, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35522, 566, 176, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35499, 19357, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35500, 19357, 51, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35501, 19357, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35475, 4612, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35476, 4612, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35477, 4612, 249, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (35478, 2574, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35479, 4386, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35480, 4386, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35481, 4386, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35482, 5215, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35483, 5215, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35484, 1425, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35485, 1425, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35398, 19291, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35399, 19291, 10, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35400, 19291, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35401, 19291, 111, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (35402, 19291, 5, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35486, 18679, 70, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35487, 18679, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35488, 19354, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35489, 19354, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35490, 19354, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35523, 5931, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35524, 5931, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35502, 19358, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35503, 19358, 261, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (35504, 19358, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28686, 8371, 189, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (28687, 8371, 72, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (35505, 19359, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35506, 19359, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35507, 19359, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35528, 6909, 56, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (35529, 6909, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35530, 6909, 354, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (35531, 6909, 38, 35, 2);
INSERT INTO 'dancesformationsmap' VALUES (35508, 19360, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35509, 19360, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35510, 19360, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35511, 19360, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35532, 6909, 112, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (35533, 6909, 124, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35534, 10142, 125, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35535, 10142, 251, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35512, 19361, 119, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (35513, 19361, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35514, 19361, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35515, 19361, 365, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (35536, 10142, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35537, 10142, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35538, 10143, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35539, 10143, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35540, 10144, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35541, 10144, 203, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (35542, 10144, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35548, 3134, 381, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (35543, 10145, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35544, 10145, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14291, 10149, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14292, 10149, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35546, 10149, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35545, 10145, 92, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35551, 10145, 200, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21591, 13735, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21592, 13735, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21593, 13735, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21601, 13738, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21602, 13738, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21603, 13738, 209, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21604, 13738, 210, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21605, 13738, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21600, 13737, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (21606, 13739, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35460, 19308, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35461, 19308, 240, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35466, 18531, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35467, 18531, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35462, 19308, 10, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (20993, 13309, 296, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20994, 13309, 256, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35525, 13297, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35526, 13297, 307, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35527, 13297, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35547, 4827, 381, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21594, 13736, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (21595, 13736, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21589, 13734, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35440, 19302, 365, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35441, 19302, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35442, 19302, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35365, 19079, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35366, 19079, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21607, 13739, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21608, 13741, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21609, 13741, 143, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (35491, 19355, 25, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35492, 19355, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35493, 19355, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35660, 1489, 71, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35661, 1489, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13907, 10148, 92, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35552, 19364, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35553, 19364, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35554, 19364, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35555, 19364, 95, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35560, 19366, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35561, 19366, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35562, 19367, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35563, 19367, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35564, 19367, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35565, 19367, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35566, 19367, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35567, 19368, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35568, 19368, 176, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35569, 19368, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35570, 19369, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35571, 19369, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35572, 19369, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35573, 19370, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35574, 19370, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35583, 19373, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35584, 19373, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35585, 19373, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35586, 6443, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35587, 19374, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35588, 19374, 183, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (35589, 19374, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35590, 19374, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35591, 19375, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35592, 19375, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35593, 19375, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35594, 19375, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35575, 19371, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35576, 19371, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35577, 19371, 168, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35578, 19371, 4, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35597, 19377, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35598, 19377, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35599, 19377, 183, 17, 8);
INSERT INTO 'dancesformationsmap' VALUES (35604, 19383, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35605, 19383, 41, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35613, 19381, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35614, 19381, 317, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35615, 19381, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35620, 19386, 1, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (35621, 19386, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35622, 19386, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35681, 19396, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35635, 19389, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35636, 19389, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35637, 19389, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35638, 19389, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34690, 14478, 9, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35600, 19382, 315, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35601, 19382, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35602, 19382, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35603, 19382, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35632, 19388, 306, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35633, 19388, 158, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35634, 19388, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35456, 19306, 23, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (35516, 19362, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35517, 19362, 92, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29276, 17024, 142, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35549, 19363, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35579, 19372, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35580, 19372, 180, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35581, 19372, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35550, 19363, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30888, 18053, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (30889, 18053, 354, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (30890, 18053, 365, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (35463, 19309, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35464, 19309, 321, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35465, 19309, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35639, 19390, 306, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35640, 19390, 7, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (35641, 19390, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20547, 13214, 101, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35595, 19376, 13, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35596, 19376, 186, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35616, 19385, 222, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35617, 19385, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35618, 19385, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35619, 19385, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35642, 19391, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35643, 19391, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35644, 19391, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35645, 19391, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35646, 19391, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35625, 19387, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35626, 19387, 93, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35627, 19387, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35628, 19387, 134, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35629, 19387, 189, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (35630, 19387, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35631, 19387, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35675, 19395, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35676, 19395, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35677, 19395, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35678, 19395, 184, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35679, 19395, 82, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35680, 19395, 69, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (35682, 19396, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35692, 12807, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35693, 12807, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35705, 940, 381, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35694, 12807, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35695, 12807, 145, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35683, 19396, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35700, 15008, 381, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35704, 1465, 381, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35709, 7230, 381, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35684, 19396, 222, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (23528, 15098, 90, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35651, 19228, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35652, 19228, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35662, 10638, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35663, 10638, 262, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (35664, 10638, 27, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35653, 19228, 297, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35606, 19384, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35607, 19384, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35608, 19384, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35785, 16133, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35790, 10019, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35822, 19417, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35716, 19397, 154, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (35717, 19397, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35654, 19393, 156, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35623, 2236, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35624, 2236, 111, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35655, 17462, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35656, 17462, 354, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35670, 5882, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (35696, 2715, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35697, 2715, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35671, 5882, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35689, 1569, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35690, 1569, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13356, 10554, 296, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (13357, 10554, 117, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (35556, 17309, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35557, 17309, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (35691, 1569, 145, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35647, 19392, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35648, 19392, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35649, 19392, 8, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35668, 11804, 142, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35669, 11804, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35706, 9236, 381, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (35672, 5882, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35707, 9236, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35711, 2607, 381, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35665, 19394, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35666, 19394, 112, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35667, 19394, 93, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35708, 5830, 381, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13051, 10494, 168, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13052, 10494, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35722, 9855, 381, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35712, 9845, 381, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35658, 7419, 313, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35659, 7419, 262, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (35673, 3918, 145, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35674, 3918, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35703, 2275, 381, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35701, 9343, 381, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35713, 16832, 381, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35714, 16832, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20123, 10493, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35718, 19397, 70, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35719, 19397, 84, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (35720, 19397, 381, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (35721, 19397, 192, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (35723, 19398, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35724, 19398, 246, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (35725, 19398, 75, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35726, 19398, 103, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35727, 19399, 246, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35728, 19399, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (35729, 19399, 53, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35730, 19399, 103, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35731, 19400, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35732, 19400, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35733, 19400, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35734, 19400, 62, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35685, 19396, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12415, 8517, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (8362, 8633, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (35735, 19401, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35736, 19401, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (35737, 19401, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35833, 19421, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35834, 19421, 190, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35835, 19421, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35836, 19421, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35743, 19403, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35744, 19403, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35745, 19403, 62, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35746, 19403, 19, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35747, 15315, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35748, 15315, 58, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35749, 15315, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35750, 15315, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35751, 15315, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35752, 19404, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35753, 19404, 202, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (35754, 19404, 185, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35755, 19404, 92, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (35823, 19418, 26, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35809, 19415, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35763, 1654, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35764, 1654, 32, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (35765, 1654, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35766, 15312, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35767, 15312, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35768, 15312, 112, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35769, 15312, 21, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35770, 14237, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35771, 14237, 265, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35772, 14237, 114, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35773, 14237, 222, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35774, 14237, 183, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (35795, 529, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35796, 529, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35797, 529, 7, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (35778, 14944, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35779, 14944, 296, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35780, 14944, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35798, 529, 249, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35799, 529, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35781, 19410, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35782, 19410, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35783, 19410, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35784, 16133, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35791, 12913, 78, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35518, 19362, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35710, 782, 381, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35610, 19380, 317, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35686, 2068, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35611, 19380, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35612, 19380, 263, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35756, 10647, 20, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35757, 10647, 184, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35759, 19405, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35760, 19405, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35761, 19405, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34127, 14155, 324, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35786, 8865, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35787, 8865, 30, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35788, 8865, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35789, 8865, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35807, 19414, 227, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35808, 19414, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35837, 19422, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35838, 19422, 364, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35810, 19415, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35811, 19415, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35812, 19415, 166, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (35813, 19415, 145, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35839, 18602, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35840, 18602, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35841, 18602, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35842, 18602, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35843, 18602, 62, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35844, 18602, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35814, 19416, 103, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35848, 19428, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35849, 19427, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35824, 19418, 186, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35825, 19418, 183, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (35826, 19419, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35827, 19419, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35828, 19419, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35829, 19419, 363, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35830, 19420, 101, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35831, 19420, 45, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35832, 19420, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35845, 3955, 42, 25, 6);
INSERT INTO 'dancesformationsmap' VALUES (35473, 19310, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35474, 19310, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35850, 19427, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35851, 19427, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35852, 19427, 93, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35853, 19427, 362, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (32673, 18540, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32674, 18540, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32675, 18540, 365, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35854, 18540, 192, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (35800, 19412, 241, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35801, 19412, 283, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35802, 19412, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35803, 19413, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35804, 19413, 105, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35815, 19416, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35816, 19416, 165, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35817, 19416, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35846, 19416, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35818, 19417, 56, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35819, 19417, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35820, 19417, 168, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35821, 19417, 134, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35861, 17513, 260, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35862, 17513, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35863, 17513, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35864, 17513, 334, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35865, 17513, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35855, 17510, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35856, 17510, 43, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35857, 17510, 112, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35858, 17510, 193, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (35859, 17510, 41, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (35860, 17510, 93, 61, 2);
INSERT INTO 'dancesformationsmap' VALUES (35866, 17514, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35867, 17514, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35868, 17514, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35869, 17515, 10, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35870, 17515, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35871, 17515, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35872, 17515, 117, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (35873, 17515, 43, 75, 2);
INSERT INTO 'dancesformationsmap' VALUES (35874, 17515, 176, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (35875, 17517, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35876, 17517, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35877, 17517, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35878, 17517, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35879, 17518, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35880, 17518, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35881, 17518, 209, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35882, 17518, 59, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35883, 17519, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35884, 17519, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35885, 17519, 222, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35886, 17519, 43, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (35887, 17519, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35888, 17519, 36, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (35889, 17520, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35890, 17520, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35891, 17520, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35892, 17521, 29, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (35893, 17521, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35894, 17521, 145, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (35895, 17521, 296, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35896, 17521, 41, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (35897, 17521, 93, 53, 2);
INSERT INTO 'dancesformationsmap' VALUES (35898, 17522, 214, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35899, 17522, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35900, 17522, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35792, 19411, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35793, 19411, 302, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21409, 13677, 142, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (10532, 9774, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (10533, 9774, 72, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35775, 19409, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35776, 19409, 235, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35901, 17522, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35902, 17522, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35963, 19469, 188, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35964, 19469, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35965, 19469, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35966, 19469, 70, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35973, 19469, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35913, 19440, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35914, 19440, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35915, 19440, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35916, 19440, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35909, 19431, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35910, 19431, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35911, 19431, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35912, 19431, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35906, 19430, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35907, 19430, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (35908, 19430, 123, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35917, 19463, 359, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35918, 19463, 84, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (35919, 19463, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35920, 19463, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35738, 19402, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35739, 19402, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35740, 19402, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35741, 19402, 123, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35742, 19402, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35925, 9496, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35926, 9496, 32, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (35927, 9496, 29, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35928, 19461, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35929, 19461, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35955, 19466, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35956, 19466, 109, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35957, 19466, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35974, 12632, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35938, 18117, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35939, 18117, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35940, 18117, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35941, 18117, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35942, 18117, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35943, 18117, 56, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (35930, 19460, 19, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35931, 19460, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (35932, 19460, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35933, 19460, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35945, 15601, 28, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35946, 15601, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35947, 15601, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35948, 19464, 353, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35949, 19464, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35950, 19464, 228, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35958, 19467, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35959, 19467, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35960, 19467, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35961, 19468, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35962, 19468, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35967, 19470, 183, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (35968, 19470, 220, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35969, 19470, 117, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35970, 19470, 9, 51, 1);
INSERT INTO 'dancesformationsmap' VALUES (35971, 19470, 39, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (23652, 15158, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23653, 15158, 91, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35951, 19465, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35952, 19465, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35953, 19465, 102, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35954, 19465, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35972, 19465, 249, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35998, 19472, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35999, 19472, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36003, 19473, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36004, 19473, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35975, 6811, 95, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (35976, 6811, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36000, 14565, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36001, 14565, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36002, 14565, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35805, 19414, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35806, 19414, 36, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (36005, 19473, 23, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (25824, 15923, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25825, 15923, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25826, 15923, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25817, 15921, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25818, 15921, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35982, 18669, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35983, 18669, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35984, 18669, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36012, 8489, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36013, 8489, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36014, 8489, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36015, 8489, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36016, 12219, 12, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (36017, 2793, 278, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36023, 15309, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36024, 15309, 10, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36025, 15309, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36026, 15309, 39, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36027, 2832, 124, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36028, 2832, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36029, 18438, 92, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36030, 18438, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36031, 18438, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36032, 18438, 168, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36033, 18438, 95, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36034, 18438, 183, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (36035, 18438, 192, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (36036, 4243, 294, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36037, 19475, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36038, 19475, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36039, 19475, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36040, 19475, 23, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (36041, 19475, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35944, 2582, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35995, 6181, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35992, 1742, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35993, 1742, 55, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35994, 1742, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36201, 14173, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36202, 14173, 9, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36042, 16878, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36043, 16878, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36044, 16878, 22, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36045, 16878, 42, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36046, 16878, 123, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36056, 19062, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36057, 19062, 1, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36058, 19062, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36059, 19062, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36060, 19062, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35934, 13574, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35935, 13574, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35936, 13574, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35988, 19471, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35989, 19471, 28, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (35990, 19471, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35991, 19471, 26, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35937, 13574, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36051, 19061, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36009, 52, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36010, 52, 114, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36011, 52, 112, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (36006, 47, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36007, 47, 12, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (36008, 47, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36052, 19061, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (35903, 19429, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35904, 19429, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35905, 19429, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36053, 19061, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36054, 19061, 234, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (36147, 19496, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36159, 12274, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36160, 12274, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36153, 12252, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36154, 12252, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36155, 12252, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36150, 19497, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36151, 19497, 42, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (36152, 19497, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36070, 18606, 162, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36071, 18606, 87, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36072, 18606, 93, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (36073, 18606, 1, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (36074, 18606, 72, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36075, 18606, 296, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (36076, 18606, 193, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (36077, 19477, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36078, 19477, 33, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36079, 19477, 7, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36080, 19477, 23, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (36081, 19477, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36082, 19478, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36083, 19478, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36090, 19481, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36091, 19481, 318, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36092, 19481, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36093, 19481, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36094, 19482, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36095, 19482, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36096, 19482, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36120, 19488, 214, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (36128, 19491, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36129, 19491, 16, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36130, 19491, 332, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (36131, 19491, 39, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36132, 19491, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36103, 19484, 359, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36104, 19484, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36105, 19484, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36106, 19484, 221, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36107, 19485, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36108, 19485, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36109, 19485, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36110, 19485, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36111, 19485, 184, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (36116, 19487, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36117, 19487, 78, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36124, 19490, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36125, 19490, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36126, 19490, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36127, 19490, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36133, 19492, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36134, 19492, 365, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (36135, 19492, 33, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (36136, 19492, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36137, 19492, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36138, 19492, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36142, 19494, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36139, 19493, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36140, 19493, 92, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36141, 19493, 123, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36187, 19504, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36163, 19499, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36164, 19499, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36183, 19503, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36184, 19503, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36167, 19500, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18603, 12606, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36097, 19483, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36098, 19483, 265, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36099, 19483, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (36100, 19483, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (36101, 19483, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36102, 19483, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36084, 19479, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36085, 19479, 12, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36086, 19479, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36112, 19486, 43, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (36113, 19486, 261, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36114, 19486, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36115, 19486, 183, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (36118, 19488, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36119, 19488, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36188, 19504, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36161, 19498, 12, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36162, 19498, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16807, 3945, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16808, 3945, 86, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16809, 3945, 89, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16810, 3945, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (36178, 19502, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36179, 19502, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36180, 19502, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (36181, 19502, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36182, 4085, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36185, 19503, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36186, 19503, 36, 26, 2);
INSERT INTO 'dancesformationsmap' VALUES (36189, 19504, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36190, 19504, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36191, 19504, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36061, 19084, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36047, 19476, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35979, 14567, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35980, 14567, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35981, 14567, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35977, 647, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (35978, 647, 73, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35985, 4637, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35986, 4637, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36192, 19504, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (36196, 19508, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36197, 19508, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36198, 19508, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36199, 19508, 134, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (36200, 19508, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36193, 19507, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36194, 19507, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36195, 19507, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36208, 19506, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36204, 3677, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36205, 3677, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36206, 3677, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36207, 3677, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36209, 19506, 101, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36210, 19506, 341, 31, 2);
INSERT INTO 'dancesformationsmap' VALUES (36211, 19509, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36212, 19509, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36213, 19510, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (584, 1065, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36217, 5597, 251, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36218, 5597, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36303, 19537, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36304, 19537, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36305, 19537, 22, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28856, 16902, 265, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28857, 16902, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28858, 16902, 214, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36333, 2701, 96, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28853, 16900, 7, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36334, 2701, 189, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (36219, 3398, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30126, 8063, 23, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (36220, 19513, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36221, 19513, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (36222, 19513, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36274, 19527, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36275, 19527, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36228, 19515, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36229, 19515, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36230, 19515, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36231, 19515, 85, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (36232, 19515, 183, 43, 1);
INSERT INTO 'dancesformationsmap' VALUES (36233, 19515, 39, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (36234, 15600, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36235, 19516, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36236, 19516, 186, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36203, 14173, 94, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36361, 19553, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36237, 12703, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36238, 12703, 29, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36143, 19495, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36144, 19495, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36337, 3400, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (243, 432, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36148, 19496, 221, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36149, 19496, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36165, 12375, 42, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (36121, 19489, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36122, 19489, 114, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36123, 19489, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36066, 19076, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36067, 19076, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36145, 19495, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36224, 19514, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36225, 19514, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36226, 19514, 249, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36227, 19514, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36308, 19543, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36309, 19543, 110, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36068, 19076, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36087, 19480, 112, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36088, 19480, 171, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36089, 19480, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36166, 12375, 86, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36168, 12394, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36169, 12394, 24, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36170, 12394, 86, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36173, 19501, 12, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36174, 19501, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (36175, 19501, 278, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36176, 19501, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (36177, 19501, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36239, 12703, 32, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (34654, 8575, 183, 39, 1);
INSERT INTO 'dancesformationsmap' VALUES (36312, 19544, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36313, 19544, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36241, 14678, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (36242, 14677, 268, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36243, 14677, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36244, 14677, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36245, 14677, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36246, 19518, 38, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36247, 19518, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36248, 19518, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36249, 19519, 87, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36250, 19520, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36251, 19520, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36252, 19520, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36253, 19520, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36254, 19520, 33, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36255, 19521, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36256, 19521, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36257, 19521, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36258, 19521, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36259, 19522, 119, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (36260, 19522, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36261, 19522, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (36262, 19523, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36263, 19523, 119, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (36264, 11114, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (36265, 19524, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36266, 19524, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (36267, 19524, 134, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (36268, 19524, 328, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36269, 19525, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36270, 19525, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36271, 19526, 76, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36272, 19526, 111, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (36273, 19526, 72, 43, 1);
INSERT INTO 'dancesformationsmap' VALUES (36276, 19528, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36277, 19528, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36278, 19528, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36279, 19528, 4, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (36280, 19528, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (36281, 19529, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36282, 19529, 251, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36283, 19529, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (36284, 19529, 376, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (36285, 19530, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36286, 19530, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36287, 19530, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36288, 19532, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36289, 19532, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36290, 19533, 1, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (36291, 19533, 222, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36292, 19533, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (36293, 19533, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36294, 19533, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36295, 19534, 119, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36296, 19534, 24, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36297, 19534, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36298, 19535, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36299, 19536, 145, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36300, 19536, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36301, 19536, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36302, 19536, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36324, 2582, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36316, 19546, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36317, 19546, 36, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36318, 19546, 92, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36319, 19546, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36320, 19547, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36321, 19547, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36322, 19547, 36, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (36323, 19547, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36314, 19545, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36315, 19545, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36325, 19517, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36326, 19517, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36344, 14512, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36338, 4841, 30, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36339, 8068, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32849, 15681, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36345, 14512, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36346, 14512, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32820, 2701, 72, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (32821, 2701, 1, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (26895, 14506, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26896, 14506, 95, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36347, 14516, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36348, 14516, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36352, 19552, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26897, 14506, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26898, 14506, 28, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36351, 14506, 92, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36353, 19552, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36354, 19552, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36355, 19552, 183, 51, 4);
INSERT INTO 'dancesformationsmap' VALUES (36356, 19552, 28, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (36357, 1898, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36240, 4075, 372, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36358, 1898, 222, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36359, 1898, 138, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (36360, 1898, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36364, 14514, 249, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36214, 19510, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36215, 19510, 96, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (36366, 14513, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36331, 19549, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36332, 19549, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36362, 19553, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36363, 19553, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12803, 6087, 234, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (36365, 6087, 41, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36367, 14513, 154, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36368, 14513, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (36369, 14513, 91, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36404, 19560, 156, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (36429, 1742, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36430, 1742, 85, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36431, 17464, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36432, 17464, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31591, 18262, 186, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31592, 18262, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36372, 476, 202, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (36434, 13588, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36435, 13588, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36436, 1387, 183, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (36437, 1387, 112, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (36373, 606, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36374, 606, 317, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36375, 606, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36376, 606, 251, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36438, 6243, 202, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36439, 6243, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36377, 17250, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36378, 17250, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36379, 17250, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36440, 6243, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (36441, 6243, 82, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (36380, 482, 127, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36381, 482, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36382, 6123, 126, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36383, 6123, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36445, 4992, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36446, 940, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36447, 940, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (36448, 4818, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36449, 4818, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35996, 6181, 52, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35997, 6181, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36399, 6181, 193, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (36390, 257, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36391, 257, 142, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (36392, 257, 296, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36393, 257, 183, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (36394, 257, 209, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (36395, 257, 64, 89, 2);
INSERT INTO 'dancesformationsmap' VALUES (36396, 257, 16, 105, 1);
INSERT INTO 'dancesformationsmap' VALUES (36397, 257, 133, 109, 1);
INSERT INTO 'dancesformationsmap' VALUES (36398, 257, 149, 113, 1);
INSERT INTO 'dancesformationsmap' VALUES (36370, 19554, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (36371, 19554, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36418, 3965, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36419, 3965, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36384, 4421, 251, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36385, 4421, 28, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36335, 19550, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36340, 4098, 83, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36341, 4098, 82, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36342, 3896, 17, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36343, 3896, 87, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (36327, 19548, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (36336, 19550, 10, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (36450, 2709, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36451, 2709, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (36433, 3493, 114, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36223, 19514, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36311, 19543, 152, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36328, 19548, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36386, 4421, 22, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36452, 457, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36453, 457, 123, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (36454, 4954, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36459, 2762, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36460, 2762, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36461, 2762, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36410, 19562, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36411, 19562, 265, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36412, 19562, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36413, 19562, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36405, 19561, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36406, 19561, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36407, 19561, 337, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36408, 19561, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36409, 19561, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36388, 7218, 279, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36389, 7218, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36420, 4777, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36421, 4777, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36422, 3088, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36423, 3088, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36424, 489, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36401, 19560, 351, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36402, 19560, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36403, 19560, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36522, 19585, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36523, 19585, 149, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36524, 19585, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36465, 1590, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36466, 1590, 222, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36467, 1590, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36462, 3753, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36463, 3753, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36464, 3753, 183, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (36442, 261, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36443, 261, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (36444, 261, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36470, 19567, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36471, 19567, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36491, 19572, 185, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36492, 19572, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36493, 19572, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (36525, 19588, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36519, 19582, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36520, 19582, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36521, 19582, 39, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (36529, 19593, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36528, 19590, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36477, 19568, 39, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36478, 19568, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36479, 19568, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36481, 19569, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36482, 19569, 46, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36483, 19570, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36484, 19570, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36485, 19570, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36488, 19571, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36489, 19571, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36490, 19571, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32796, 18562, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36535, 18564, 308, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36536, 18564, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36537, 18564, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36538, 18564, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32794, 18561, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32795, 18561, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36532, 19595, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36533, 19595, 131, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36534, 19595, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36608, 17988, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36609, 17988, 229, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36544, 19596, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36545, 19596, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36546, 19596, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36547, 19596, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36552, 19610, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36553, 19610, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36554, 19610, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36610, 17988, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29813, 17575, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36555, 19615, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36556, 19615, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36557, 19615, 92, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36558, 19615, 36, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36559, 19615, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36560, 19615, 61, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (36562, 4286, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36480, 19568, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36486, 19570, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36487, 19570, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36498, 19575, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36499, 19575, 92, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36500, 19575, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36400, 647, 317, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35987, 4637, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36474, 6326, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36475, 6326, 120, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36476, 6326, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36506, 19577, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36507, 19577, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36508, 19577, 88, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36501, 19575, 134, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36509, 19578, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36510, 19578, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36472, 19567, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36473, 19567, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36569, 15247, 283, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36570, 15247, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36571, 15247, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36584, 19632, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36585, 19632, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29814, 17575, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29815, 17575, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (29816, 17575, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36577, 19629, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36578, 19629, 42, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (36425, 560, 55, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36426, 560, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36566, 15236, 353, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36567, 15236, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36511, 14584, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15094, 8847, 173, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36512, 14584, 32, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36526, 19592, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36527, 19592, 188, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (36513, 14584, 93, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (36514, 14584, 321, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (36515, 14584, 4, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36502, 19576, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36503, 19576, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36504, 19576, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36505, 19576, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36586, 15130, 8, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (36575, 4625, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36576, 4625, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36516, 19581, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36517, 19581, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36518, 19581, 123, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36563, 15233, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36564, 15233, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36565, 15233, 9, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36579, 19629, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36539, 16769, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36540, 16769, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (36541, 16769, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36530, 19594, 29, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (36531, 19594, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36494, 19573, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36580, 19631, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36581, 19631, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36582, 19631, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36583, 19631, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36587, 15235, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36588, 15235, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36589, 15235, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36495, 19574, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36496, 19574, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36497, 19574, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21053, 13327, 112, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21054, 13327, 273, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36611, 13961, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36612, 13961, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36613, 13961, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30046, 17677, 280, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30047, 17677, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30048, 17677, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30049, 17677, 69, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36640, 3590, 111, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36641, 883, 1, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36618, 19636, 111, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36619, 19636, 64, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36620, 19636, 65, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (36621, 19636, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36622, 19636, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36623, 19636, 43, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (36642, 3310, 20, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (23130, 14921, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36643, 14469, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36653, 19642, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36654, 19642, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (36548, 19597, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (36656, 19643, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36657, 19643, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36658, 38, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36659, 38, 123, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36660, 38, 154, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36644, 14469, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36645, 14469, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36646, 7598, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36647, 7598, 66, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36648, 7598, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36649, 7598, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36650, 7598, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36663, 1875, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36664, 1875, 1, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (36665, 1875, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36666, 328, 330, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36667, 328, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36671, 1571, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36672, 1571, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36673, 1571, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36674, 1571, 188, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36675, 19611, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36676, 19611, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36661, 19474, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36662, 19474, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36677, 19611, 61, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36668, 19023, 65, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36669, 19023, 105, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36670, 19023, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36682, 139, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36678, 14461, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36679, 14461, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36680, 14461, 131, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36681, 14461, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36593, 19597, 42, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (36683, 139, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36684, 139, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36655, 19642, 255, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36686, 8532, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36687, 8532, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36688, 8532, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36689, 8532, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36760, 19660, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36761, 19660, 222, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36762, 19660, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36763, 19660, 28, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36696, 19649, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36697, 19649, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36698, 19649, 65, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36699, 19649, 48, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36708, 19645, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36709, 19645, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36710, 19645, 19, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36718, 19656, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36719, 19656, 213, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36764, 19660, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36724, 19658, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36725, 19658, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36726, 19658, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36727, 19658, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13477, 8356, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13478, 8356, 192, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (36711, 19646, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36712, 19646, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36713, 19646, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36714, 19646, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36769, 2949, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36770, 2949, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36705, 19559, 312, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36706, 19559, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36715, 19647, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36716, 19647, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36690, 19555, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36691, 19555, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36692, 19555, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (28291, 16536, 157, 31, 4);
INSERT INTO 'dancesformationsmap' VALUES (36561, 5642, 69, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30366, 14600, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36414, 19563, 241, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36415, 19563, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30367, 14600, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (30368, 14600, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36624, 19637, 189, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (36625, 19637, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36626, 19637, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36627, 19637, 96, 30, 2);
INSERT INTO 'dancesformationsmap' VALUES (36550, 19604, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36637, 19640, 61, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36638, 19640, 93, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36639, 19640, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36633, 19639, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36628, 19638, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36629, 19638, 36, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (36630, 19638, 96, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36631, 19638, 75, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36634, 19639, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36635, 19639, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36551, 19604, 95, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36707, 19559, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36700, 19651, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36701, 19651, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36702, 19651, 10, 11, 3);
INSERT INTO 'dancesformationsmap' VALUES (36703, 19651, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36704, 19651, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36720, 19653, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36721, 19653, 261, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (36722, 19653, 157, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36723, 19653, 61, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36693, 19644, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36694, 19644, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36695, 19644, 285, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36728, 19657, 157, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (36729, 19657, 176, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36730, 19657, 139, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (36731, 19657, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34072, 12316, 87, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (36747, 19659, 201, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36748, 19659, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36749, 19659, 58, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16133, 11756, 85, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16134, 11756, 216, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (36755, 11756, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36816, 19672, 46, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36743, 19655, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36651, 19641, 119, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (36652, 19641, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36779, 14185, 143, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36780, 14185, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36781, 14185, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36597, 19633, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36598, 19633, 72, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (36599, 19633, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36594, 13985, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36595, 13985, 72, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (36596, 13985, 142, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (36794, 19665, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36795, 19665, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36717, 956, 9, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (9516, 9107, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36605, 19550, 30, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36606, 19550, 365, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36607, 19550, 364, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36765, 168, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36766, 168, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36767, 168, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (36768, 168, 365, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (14486, 11220, 288, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14487, 11220, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30871, 11220, 370, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9079, 8348, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36739, 19648, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36740, 19648, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36741, 19648, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36817, 19672, 30, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (36818, 19672, 56, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (36756, 16601, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36757, 16601, 1, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (36758, 16601, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36759, 16601, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36799, 19667, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36771, 19661, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (36772, 19661, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (36773, 19661, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (36774, 19661, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (36775, 19661, 365, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (36735, 19557, 96, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (36736, 19557, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36737, 19557, 188, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (36738, 19557, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36800, 19667, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36801, 19667, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36783, 19663, 314, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36784, 19663, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36785, 19663, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36776, 19662, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36777, 19662, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36778, 19662, 365, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36819, 19672, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36786, 19664, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36787, 19664, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36788, 19664, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36789, 19664, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36790, 19558, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36791, 19558, 95, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36792, 19558, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36824, 19674, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36825, 19674, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28329, 13127, 277, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36808, 19669, 183, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (36809, 19669, 296, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36810, 19670, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36811, 19670, 30, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36826, 19674, 110, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36831, 19676, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36832, 19676, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36833, 19676, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36837, 19678, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36838, 19678, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36839, 19679, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36840, 19679, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36841, 19679, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36842, 19680, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36843, 19680, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19185, 8050, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36844, 19681, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (36845, 19681, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36802, 18881, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36803, 18881, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36804, 18881, 49, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36805, 18881, 241, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36846, 18858, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36847, 18858, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36848, 18858, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36849, 18865, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36850, 18865, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36851, 18865, 48, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23625, 15149, 119, 20, 4);
INSERT INTO 'dancesformationsmap' VALUES (36852, 19682, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36853, 19682, 105, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36854, 19684, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36855, 19684, 221, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (36856, 19684, 262, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36857, 19684, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36911, 1454, 38, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (36912, 1454, 33, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36913, 1454, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (36951, 19696, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36952, 19696, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36953, 19696, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36861, 9499, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36862, 16288, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36869, 18471, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36870, 12051, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36929, 14426, 16, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36955, 19697, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36923, 813, 183, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (36924, 813, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36925, 813, 72, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (36926, 813, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33531, 15499, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36966, 15499, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36969, 15481, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36927, 813, 149, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (36928, 813, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35609, 19384, 7, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36979, 18124, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36882, 19446, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36883, 19446, 188, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36884, 19446, 168, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (36980, 18124, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36961, 19698, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36962, 19698, 43, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (36963, 19698, 69, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (31046, 18102, 324, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36885, 15234, 16, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36886, 15234, 92, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36879, 17848, 354, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36880, 17848, 186, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36881, 17848, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (36732, 19650, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36733, 19650, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36734, 19650, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36863, 19686, 188, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36864, 19686, 189, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36812, 19671, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36813, 19671, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36806, 19668, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36807, 19668, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36814, 19671, 56, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36815, 19671, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36796, 19666, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36797, 19666, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36798, 19666, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36750, 19652, 101, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36751, 19652, 370, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36753, 19652, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36887, 15234, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36888, 15234, 29, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (36889, 15234, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (36890, 1426, 1, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (36891, 19689, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36892, 19689, 33, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (36893, 19689, 18, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (36894, 19689, 56, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (36895, 19689, 354, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36896, 19689, 249, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (36897, 19689, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36902, 18343, 15, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36903, 18343, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36904, 18343, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36216, 19510, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36905, 13938, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36906, 13938, 143, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36907, 13938, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36964, 19698, 66, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (36965, 19698, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (36876, 19688, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36877, 19688, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36878, 19688, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36981, 210, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36982, 210, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36983, 210, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36935, 19692, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36936, 19692, 111, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36898, 17164, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36899, 17164, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36900, 17164, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36901, 17164, 7, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (36872, 19687, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36873, 19687, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36874, 19687, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36793, 19665, 321, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36867, 4024, 57, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36820, 19673, 66, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36827, 19675, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36828, 19675, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36829, 19675, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36830, 19675, 112, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (36821, 19673, 249, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36822, 19673, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (36908, 14053, 101, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36909, 14053, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36910, 14053, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36871, 7172, 332, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13719, 10822, 13, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36834, 19677, 197, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36835, 19677, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36836, 19677, 1, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (36937, 19692, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36938, 19692, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36967, 15501, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36940, 19693, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36941, 19693, 23, 5, 5);
INSERT INTO 'dancesformationsmap' VALUES (36942, 19693, 112, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36956, 19697, 24, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36944, 19694, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36945, 19694, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36946, 19694, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21673, 13820, 7, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21674, 13820, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21675, 13820, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36974, 658, 157, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (32341, 16661, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36970, 16661, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36947, 19695, 184, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (36948, 19695, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36949, 19695, 154, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (36950, 19695, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24165, 15286, 56, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (36971, 19700, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36968, 15483, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14900, 7999, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34031, 15519, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36972, 19700, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36973, 19700, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36957, 19697, 114, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36958, 19697, 119, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (36959, 19697, 92, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (36960, 19697, 23, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (36943, 15498, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36987, 7378, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36988, 7378, 112, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36989, 7378, 267, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (36990, 7378, 96, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (36991, 7378, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36996, 2459, 154, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (36997, 2459, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36998, 2459, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36999, 1235, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37000, 1235, 112, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37001, 1235, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37002, 18127, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37003, 18127, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37004, 18127, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37005, 18127, 221, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37006, 18133, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37007, 18133, 55, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37008, 18133, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37009, 18133, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37010, 18133, 125, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37017, 18135, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37018, 18135, 189, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (37019, 18135, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36858, 19685, 2, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (36859, 19685, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36860, 19685, 249, 31, 2);
INSERT INTO 'dancesformationsmap' VALUES (32118, 17874, 25, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32119, 17874, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32120, 17874, 83, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37020, 13727, 162, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37021, 13727, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37022, 13727, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37028, 16873, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37029, 16873, 318, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37030, 16873, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37031, 19702, 114, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37032, 19702, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37033, 19703, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37034, 19703, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37035, 19703, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37051, 19706, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37052, 19706, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37053, 19707, 203, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (37054, 19708, 110, 73, 2);
INSERT INTO 'dancesformationsmap' VALUES (37055, 19708, 87, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (37056, 19708, 59, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37057, 19708, 53, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (37058, 19708, 90, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (37059, 19710, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37061, 19713, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37062, 19713, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37063, 19714, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37064, 19714, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37065, 19714, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37066, 19715, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37067, 19716, 171, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37068, 19716, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37069, 19719, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37070, 19719, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37074, 19721, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37075, 19721, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37076, 19721, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37085, 18176, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37086, 18176, 185, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (37087, 18176, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37088, 18176, 95, 4, 3);
INSERT INTO 'dancesformationsmap' VALUES (37089, 18176, 183, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (37090, 18176, 249, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (36954, 19696, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37091, 19718, 81, 9, 6);
INSERT INTO 'dancesformationsmap' VALUES (37092, 18156, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37093, 18156, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37094, 18156, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37095, 18156, 91, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37096, 15243, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37097, 15243, 145, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37098, 15243, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37099, 15243, 9, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37100, 15243, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37101, 630, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37102, 926, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37103, 926, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37104, 995, 46, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37105, 995, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37106, 995, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36984, 15434, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21663, 13817, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21664, 13817, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37036, 19704, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37037, 19704, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37038, 19704, 33, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (37060, 19711, 73, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37107, 1603, 142, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36914, 19690, 359, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36915, 19690, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (36916, 19690, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36592, 19604, 36, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37136, 19736, 220, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37137, 19736, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37138, 19736, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37115, 6916, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37121, 18182, 23, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (37122, 18182, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37123, 18182, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37108, 19725, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37124, 18182, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37117, 11386, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37118, 11386, 145, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37112, 19727, 23, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (36930, 19691, 69, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (36931, 19691, 154, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37011, 15240, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37012, 15240, 43, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (36932, 19691, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36992, 534, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36993, 534, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36994, 534, 71, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37077, 19722, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37078, 19722, 8, 17, 8);
INSERT INTO 'dancesformationsmap' VALUES (37082, 19724, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37083, 19724, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37084, 19724, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37079, 19723, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37080, 19723, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37081, 19723, 359, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36939, 897, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36975, 205, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36976, 205, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36977, 205, 48, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37023, 18151, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37048, 19705, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37049, 19705, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37050, 19705, 75, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37024, 18151, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37025, 18151, 103, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37045, 17628, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (37046, 17628, 294, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37047, 17628, 183, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (37039, 19712, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37040, 19712, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37041, 19712, 241, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37042, 19712, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37113, 19727, 119, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37114, 19727, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37119, 11386, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37120, 11386, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37109, 19726, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37110, 19726, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37111, 19726, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37116, 19726, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37125, 19564, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37126, 19564, 42, 9, 6);
INSERT INTO 'dancesformationsmap' VALUES (37127, 19564, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28848, 16899, 117, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (28849, 16899, 120, 45, 2);
INSERT INTO 'dancesformationsmap' VALUES (28850, 16899, 121, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (15278, 11546, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15279, 11546, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32898, 11546, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32899, 11546, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37214, 18149, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33485, 19086, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37146, 19741, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37147, 19741, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37148, 19741, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37132, 19729, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37133, 19729, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33486, 19086, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37142, 18785, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37149, 18785, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37150, 18785, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15400, 10224, 267, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15401, 10224, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (37139, 19759, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37140, 19759, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37141, 19759, 1, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (35158, 303, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35159, 303, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12647, 9767, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12648, 9767, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12649, 9767, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (37153, 18364, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37154, 18364, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37155, 18364, 1, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (37156, 18364, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37157, 18364, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3762, 7096, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37151, 7096, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37152, 7096, 43, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (37161, 19761, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37162, 19761, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37163, 19761, 119, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37164, 19762, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37165, 19762, 138, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37166, 19762, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37167, 19763, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37168, 19763, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37169, 19763, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37170, 19763, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37171, 19764, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37172, 19764, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37173, 19764, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37177, 19766, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37178, 19766, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37179, 19766, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37180, 19766, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37181, 19766, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37182, 19767, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37183, 19767, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37184, 19768, 190, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37185, 19768, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37186, 19768, 9, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37187, 19768, 30, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (37188, 18358, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37189, 18358, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37190, 18358, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37158, 19760, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37159, 19760, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37160, 19760, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35160, 303, 365, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (37134, 7679, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37135, 7679, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1114, 2077, 296, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4559, 2077, 83, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37014, 19701, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (21193, 13611, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21194, 13611, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37192, 13611, 96, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (3592, 6780, 119, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (37193, 6780, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (37194, 6780, 202, 14, 1);
INSERT INTO 'dancesformationsmap' VALUES (37195, 6780, 71, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37196, 6780, 183, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (37197, 17816, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37198, 17816, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37199, 17816, 123, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37200, 17816, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37201, 17816, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20052, 13077, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (20054, 13077, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25144, 13077, 29, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (11252, 10093, 38, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11253, 10093, 1, 38, 2);
INSERT INTO 'dancesformationsmap' VALUES (11254, 10093, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34228, 10093, 154, 33, 10);
INSERT INTO 'dancesformationsmap' VALUES (37211, 10093, 157, 37, 4);
INSERT INTO 'dancesformationsmap' VALUES (37212, 10093, 183, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (37213, 10093, 329, 53, 1);
INSERT INTO 'dancesformationsmap' VALUES (37215, 18149, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37216, 18149, 362, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37217, 18149, 202, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (40, 66, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (3881, 66, 184, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (33395, 66, 42, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (36468, 66, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36469, 66, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (721, 1345, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4311, 1345, 156, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6442, 1345, 87, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36685, 1345, 9, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (37130, 19730, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37131, 19730, 105, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (2357, 4491, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5366, 4491, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6823, 4491, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29900, 8720, 356, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29901, 8720, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29902, 8720, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29903, 8720, 33, 35, 2);
INSERT INTO 'dancesformationsmap' VALUES (29904, 8720, 39, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (35027, 19243, 43, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (35028, 19243, 265, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (37202, 16940, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2954, 5642, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5754, 5642, 95, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (7141, 7302, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7142, 7302, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13845, 10882, 162, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8592, 8710, 25, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10837, 8710, 114, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21791, 14320, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (21792, 14320, 224, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10006, 9497, 112, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10007, 9497, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (10008, 9497, 30, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (11060, 9497, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (11061, 9497, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21793, 14320, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37218, 14320, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37219, 14320, 356, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37220, 18179, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37221, 18179, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37222, 18179, 341, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37203, 16940, 234, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37204, 16940, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37208, 17824, 56, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (37209, 17824, 26, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37210, 17824, 85, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37128, 19738, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37129, 19738, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37143, 19737, 105, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37144, 19737, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37145, 19737, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37015, 19701, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37016, 19701, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (18718, 12680, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18719, 12680, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37241, 19769, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20368, 13157, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (20369, 13157, 241, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20370, 13157, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (20371, 13157, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37242, 13157, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37223, 18178, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37224, 18178, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37225, 18178, 149, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37226, 18178, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37227, 18178, 185, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37228, 18178, 249, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (37229, 18178, 39, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (37230, 18178, 23, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (2320, 4407, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (20238, 4407, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28497, 14985, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37243, 19770, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37244, 19770, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37245, 19770, 7, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (37246, 19770, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37247, 19770, 365, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37248, 19770, 374, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37249, 19770, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37250, 19770, 86, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (37251, 19770, 309, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (37252, 19770, 42, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (37253, 19770, 296, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (37254, 19770, 87, 105, 1);
INSERT INTO 'dancesformationsmap' VALUES (37255, 19770, 149, 113, 1);
INSERT INTO 'dancesformationsmap' VALUES (33316, 18772, 278, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33317, 18772, 261, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33318, 18772, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37231, 17255, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37232, 17255, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37233, 17255, 334, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37234, 17255, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37235, 17255, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (9218, 7560, 52, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (10463, 7560, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (16032, 7560, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16033, 7560, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32466, 18491, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32468, 18491, 184, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31029, 17746, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31030, 17746, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37236, 17746, 154, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37237, 17746, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19725, 12918, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19726, 12918, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1592, 3031, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4861, 3031, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37256, 3031, 23, 30, 1);
INSERT INTO 'dancesformationsmap' VALUES (37257, 3031, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37271, 12855, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22147, 8743, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (2635, 5041, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20963, 13302, 43, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (20965, 13302, 23, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (10080, 9354, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10081, 9354, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10082, 9354, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10083, 9354, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37238, 1661, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37239, 1661, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (24273, 15041, 42, 21, 4);
INSERT INTO 'dancesformationsmap' VALUES (24274, 15041, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24275, 15041, 20, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37258, 12143, 84, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (23170, 13094, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23171, 13094, 307, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23172, 13094, 133, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23173, 13094, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33862, 19153, 33, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33863, 19153, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15625, 7019, 131, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (18531, 12594, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18532, 12594, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28385, 16523, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28386, 16523, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28387, 16523, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37259, 19771, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37260, 19771, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37261, 19771, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37240, 19769, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37262, 19771, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37264, 19772, 188, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37265, 19772, 24, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (37266, 19772, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37267, 19772, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37268, 19773, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37269, 19773, 154, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (432, 774, 82, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (4139, 774, 69, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37287, 19774, 58, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19481, 12855, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19482, 12855, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37270, 12855, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37272, 16962, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37273, 16962, 329, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37274, 16962, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32721, 18392, 88, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (37288, 19774, 30, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37289, 19774, 131, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34478, 17156, 321, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34479, 17156, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (5549, 5041, 30, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6879, 5041, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37277, 12179, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37278, 12179, 365, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37279, 12179, 82, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (37280, 12179, 76, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (37281, 12179, 25, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (37282, 9942, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37283, 9942, 265, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (37284, 9942, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23892, 8852, 42, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (23893, 8852, 112, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23894, 8852, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23895, 8852, 1, 18, 2);
INSERT INTO 'dancesformationsmap' VALUES (23896, 8852, 56, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23897, 8852, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (926, 1719, 265, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (37285, 1719, 183, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (37286, 1719, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34480, 17156, 241, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34481, 17156, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37013, 15240, 112, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36919, 15241, 222, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (36920, 15241, 225, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (36921, 15241, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36922, 15241, 62, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (4600, 2236, 69, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (7704, 7147, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21265, 7147, 9, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (1262, 2394, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (26205, 2394, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36744, 19655, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36745, 19655, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36746, 19655, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37290, 19626, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37291, 19626, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37292, 19626, 84, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37293, 19626, 29, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (37294, 19607, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37295, 19607, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37296, 19607, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37297, 19607, 281, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (37275, 12913, 42, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (36591, 19604, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9723, 9350, 42, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (9724, 9350, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37191, 9350, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37298, 19607, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (24645, 15423, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24646, 15423, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24912, 15569, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24913, 15569, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37263, 10694, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32722, 18392, 361, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32723, 18392, 72, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (20966, 13302, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (19476, 12850, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35558, 19365, 154, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (35559, 19365, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28506, 16800, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28507, 16800, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19727, 12918, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37276, 4407, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (32127, 15237, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32128, 15237, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32129, 15237, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37299, 19589, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37300, 19589, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37301, 19589, 209, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37302, 19589, 1, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (37303, 19589, 8, 35, 2);
INSERT INTO 'dancesformationsmap' VALUES (37304, 19589, 117, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (37305, 19589, 210, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (34727, 19231, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33257, 19018, 193, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (33258, 19018, 120, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (37357, 15060, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (20034, 12963, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20035, 12963, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (22855, 14243, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22856, 14243, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17958, 12426, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24741, 15455, 162, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24742, 15455, 220, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24743, 15455, 183, 35, 2);
INSERT INTO 'dancesformationsmap' VALUES (28112, 15455, 23, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (37328, 15455, 157, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (21901, 14332, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21902, 14332, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37372, 19781, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37373, 19781, 43, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (37374, 19781, 23, 45, 2);
INSERT INTO 'dancesformationsmap' VALUES (37375, 19781, 83, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (37376, 19781, 93, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (37377, 19781, 38, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (37337, 19778, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37338, 19778, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37339, 19778, 56, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37340, 19778, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20393, 13164, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20394, 13164, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28492, 13164, 123, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (5426, 4679, 77, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37341, 4679, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3096, 5906, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7580, 5906, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37342, 5906, 29, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (37343, 15063, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37344, 15063, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37345, 15063, 36, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37346, 15059, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37347, 15059, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37348, 15059, 82, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37349, 15059, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37350, 15067, 314, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37351, 15067, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37332, 19777, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37333, 19777, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37334, 19777, 134, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (37335, 19777, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37336, 19777, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37354, 19780, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37355, 19780, 112, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37356, 19780, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37352, 19779, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37353, 19779, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23398, 15056, 176, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23399, 15056, 157, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23400, 15056, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (23401, 15056, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23402, 15056, 90, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (23403, 15056, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (37358, 15070, 28, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37359, 15073, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37360, 15073, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37361, 15065, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37362, 15065, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37363, 15065, 105, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37364, 15061, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37365, 15061, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37366, 15061, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (37367, 15069, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37368, 15069, 13, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37369, 15071, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37370, 15071, 186, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37371, 15071, 189, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (29916, 17622, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29917, 17622, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37379, 8310, 10, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37380, 8310, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37387, 19784, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37388, 19784, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37389, 19784, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37384, 19783, 359, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37385, 19783, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37386, 19783, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37390, 19204, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37391, 19204, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37392, 19204, 234, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (37393, 19204, 23, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (37394, 19204, 95, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19077, 12786, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19078, 12786, 133, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19079, 12786, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19080, 12786, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19081, 12786, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19082, 12786, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19083, 12786, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31283, 18219, 33, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (31284, 18219, 23, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (31285, 18219, 132, 3, 0);
INSERT INTO 'dancesformationsmap' VALUES (25386, 15792, 42, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (37402, 19787, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37403, 19787, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37404, 19787, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37405, 19787, 75, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37406, 19787, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37407, 19788, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37408, 19788, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37409, 19788, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37410, 19788, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (25387, 15792, 93, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (15411, 10228, 153, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (37411, 15792, 23, 4, 4);
INSERT INTO 'dancesformationsmap' VALUES (19745, 12366, 27, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (19746, 12366, 193, 121, 1);
INSERT INTO 'dancesformationsmap' VALUES (37320, 12366, 296, 113, 1);
INSERT INTO 'dancesformationsmap' VALUES (31286, 18219, 55, 9, 0);
INSERT INTO 'dancesformationsmap' VALUES (37311, 19080, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37312, 19080, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37313, 19080, 23, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (20036, 12963, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20037, 12963, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37317, 19064, 359, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37318, 19064, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37319, 19064, 373, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37314, 19080, 61, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37315, 19080, 1, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (7928, 8309, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8196, 8309, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37329, 19776, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37330, 19776, 1, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (2231, 4232, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37326, 4232, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37327, 4232, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37381, 19782, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37382, 19782, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37383, 19782, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2861, 5464, 58, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (16877, 5464, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36018, 18437, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36019, 18437, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36020, 18437, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37412, 64, 265, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37413, 64, 114, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37414, 64, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37306, 19085, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37307, 19085, 183, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (37308, 19085, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37309, 19085, 69, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (10807, 9908, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10808, 9908, 72, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (9447, 9083, 164, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (3478, 6571, 65, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (37378, 6571, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37321, 16628, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37322, 16628, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37323, 16628, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37324, 16628, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37325, 16628, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37331, 19776, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4028, 501, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37417, 501, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37418, 501, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (312, 560, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36427, 560, 249, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (36428, 560, 269, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (613, 1127, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37419, 1127, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (37420, 1142, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37421, 1234, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (37422, 1234, 303, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37423, 1234, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37426, 2163, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37427, 2163, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37428, 2163, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37429, 2163, 81, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37430, 2163, 2, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (37431, 2163, 27, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (37432, 2163, 29, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (17458, 10766, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (17459, 10766, 38, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (17460, 10766, 69, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (17461, 10766, 52, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (37433, 12651, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18893, 12734, 1, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (19585, 12734, 8, 59, 2);
INSERT INTO 'dancesformationsmap' VALUES (19586, 12734, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (19359, 12810, 119, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (19360, 12810, 58, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19663, 12896, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19664, 12896, 185, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19665, 12896, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19666, 12896, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11479, 10250, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11480, 10250, 382, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (37434, 19789, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37435, 19789, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37471, 11235, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37472, 11235, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37398, 19786, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37399, 19786, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37400, 19786, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37401, 19786, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37436, 10747, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37437, 10747, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37438, 10747, 112, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (37443, 12828, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37444, 12828, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37473, 11236, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35657, 17462, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26835, 1176, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (26836, 1176, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26837, 1176, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15329, 10198, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15113, 8872, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37474, 4638, 111, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37446, 1315, 33, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (37502, 9239, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37503, 9239, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37483, 13643, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37484, 13643, 172, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37485, 13643, 214, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (254, 451, 43, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (12217, 451, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (37504, 19136, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37486, 13643, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29568, 17392, 41, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (10805, 9906, 41, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29569, 9906, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37482, 13306, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (5472, 4827, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16284, 11814, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (37453, 19794, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37454, 19794, 283, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37455, 19794, 49, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37456, 19794, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37475, 19797, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37476, 19797, 46, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37477, 19797, 186, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27628, 16423, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27629, 16423, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27630, 16423, 29, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27631, 16423, 32, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (27632, 16423, 93, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (27633, 16423, 214, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (16285, 11814, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37459, 19796, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37460, 19796, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37461, 19796, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26963, 16206, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26964, 16206, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26965, 16206, 224, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37481, 16745, 227, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1340, 2536, 38, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4694, 2536, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37424, 2536, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37425, 2536, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33796, 19135, 365, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (21010, 13313, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1257, 2383, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24418, 2383, 23, 10, 2);
INSERT INTO 'dancesformationsmap' VALUES (34050, 2383, 29, 17, 6);
INSERT INTO 'dancesformationsmap' VALUES (3278, 6221, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37509, 19800, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37510, 19800, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37511, 19800, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (37512, 19800, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37506, 19799, 64, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5948, 6221, 89, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37492, 11405, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37493, 11405, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37494, 11405, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37495, 11405, 114, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37496, 19798, 268, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37497, 19798, 168, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37498, 19798, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37499, 19798, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37500, 19798, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37501, 19798, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37507, 19799, 58, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (37508, 19799, 154, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26503, 16072, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26504, 16072, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37513, 11588, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (37514, 11588, 318, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (37515, 17624, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37516, 17624, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (37517, 17624, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37518, 17624, 154, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14726, 11351, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14727, 11351, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37519, 11364, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37520, 11364, 112, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (28650, 4832, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14746, 11359, 29, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (37521, 13559, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9688, 6221, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34051, 2383, 23, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (37491, 3472, 334, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37450, 19793, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37451, 19793, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37452, 19793, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (37457, 19795, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37458, 19795, 263, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16286, 11814, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (16287, 11814, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6632, 3129, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37505, 19136, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37447, 19792, 15, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37448, 19792, 154, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37449, 19792, 102, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37628, 19813, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14747, 11359, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37524, 11359, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37525, 17402, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37526, 17402, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37527, 17402, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37528, 17402, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37415, 64, 318, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37416, 64, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37469, 18611, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37470, 18611, 206, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (12260, 5480, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21572, 5480, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37465, 19602, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37466, 19602, 206, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37462, 19584, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37463, 19584, 206, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37464, 19584, 211, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33635, 18711, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (33636, 18711, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33637, 18711, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20283, 6627, 45, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37480, 6627, 227, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37529, 17401, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37530, 17401, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37629, 19813, 154, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37630, 19813, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (37631, 19813, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37583, 15239, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8622, 8719, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (8623, 8719, 126, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37534, 1108, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37535, 1108, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37536, 1108, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37537, 1108, 82, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (37584, 15239, 23, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (37585, 15239, 296, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37586, 15239, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (37589, 12832, 56, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37590, 12832, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37538, 18996, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37539, 18996, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37540, 18996, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37541, 18996, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37542, 18996, 82, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37546, 1151, 114, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37547, 1151, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37548, 1151, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37549, 198, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37550, 198, 354, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37551, 641, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37552, 641, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37553, 641, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31037, 17748, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37594, 19806, 114, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37595, 19806, 234, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (37596, 19806, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37599, 19809, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22975, 14717, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22976, 14717, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37597, 19805, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37591, 19804, 306, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37592, 19804, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37593, 19804, 162, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37565, 759, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37566, 759, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37567, 759, 202, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37600, 19809, 186, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37601, 19809, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37602, 19809, 364, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35698, 2715, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35699, 2715, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (37568, 2715, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37603, 14504, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37604, 14504, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37605, 14504, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37606, 14504, 15, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37607, 14504, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37522, 13559, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37523, 13559, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (37569, 13559, 93, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (37570, 6922, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37571, 6922, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37572, 833, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37573, 833, 23, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (37577, 890, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37578, 890, 112, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (37579, 890, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37608, 14517, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37609, 14517, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37610, 14517, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37580, 12799, 142, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37581, 12799, 69, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37582, 12799, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (16077, 8349, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (16109, 8349, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37632, 19814, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37633, 19814, 313, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37634, 19814, 10, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (37611, 14515, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37612, 14515, 8, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (37613, 14515, 42, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37614, 14515, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37615, 19808, 364, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37616, 19808, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37617, 19808, 241, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37618, 19810, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37619, 19810, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34941, 19060, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34942, 19060, 24, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (12167, 1191, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12168, 1191, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12169, 1191, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (12170, 1191, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (37635, 19814, 33, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (37636, 19814, 249, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37637, 19815, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37638, 19815, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37620, 19811, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37621, 19811, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37622, 19811, 92, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37623, 19811, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37624, 19812, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37625, 19812, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37626, 19812, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37627, 19812, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37639, 19815, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37640, 19815, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1091, 2035, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37644, 2035, 18, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37645, 1278, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37646, 1278, 81, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37647, 1449, 265, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37648, 1449, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37649, 1449, 72, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (37650, 6880, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37651, 6880, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37652, 19818, 65, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37653, 19818, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37654, 19818, 9, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (37655, 19730, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37656, 16876, 143, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37657, 16876, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37658, 16876, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37659, 16876, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37660, 19731, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37661, 19731, 234, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37662, 19731, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37663, 19731, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37664, 19731, 92, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9542, 9117, 52, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (37666, 19819, 114, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37667, 19819, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37668, 19819, 286, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (7987, 8388, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37669, 8388, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (9543, 9117, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9544, 9117, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9545, 9117, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9546, 9117, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11799, 10317, 13, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (36055, 19061, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37561, 2514, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37562, 2514, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37563, 2514, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37564, 2514, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11389, 991, 8, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (11390, 991, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27846, 991, 234, 9, 8);
INSERT INTO 'dancesformationsmap' VALUES (29455, 991, 72, 20, 1);
INSERT INTO 'dancesformationsmap' VALUES (37531, 17318, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37532, 17318, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37533, 17318, 33, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (11800, 10317, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11801, 10317, 22, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27012, 16225, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (27013, 16225, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27014, 16225, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27029, 16230, 346, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37670, 19738, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37751, 14140, 21, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37671, 7582, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37672, 7582, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37673, 7582, 189, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (37674, 7582, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19244, 5252, 1, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (37675, 5252, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16741, 11969, 112, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (37588, 11969, 41, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (37574, 401, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37575, 401, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37557, 19803, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37558, 19803, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (37576, 401, 36, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (37554, 681, 8, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (37555, 681, 119, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (37556, 681, 192, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (37543, 1186, 83, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37544, 1186, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37545, 1186, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (37641, 1196, 29, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (37642, 1196, 72, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (37643, 1196, 32, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (15582, 10678, 188, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37730, 10678, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37732, 19592, 318, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (37733, 5301, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37676, 19747, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37677, 19747, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (37678, 19747, 78, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37679, 19747, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37680, 19747, 92, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23008, 14744, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37681, 1403, 64, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37682, 1403, 111, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37683, 1403, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36349, 19551, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36350, 19551, 364, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37725, 17471, 240, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37726, 17471, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35468, 18531, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37727, 15536, 240, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37728, 15536, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37734, 5301, 33, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37735, 5301, 36, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (37710, 18597, 265, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (37711, 18597, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (37712, 18597, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37752, 14140, 87, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (36875, 19687, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37713, 17983, 143, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29383, 16656, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37665, 4301, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37717, 19831, 176, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37718, 19831, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37719, 19831, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37684, 19820, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37685, 19820, 9, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (37686, 19820, 83, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37720, 19831, 56, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (17317, 2477, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (17318, 2477, 8, 29, 4);
INSERT INTO 'dancesformationsmap' VALUES (9106, 8724, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9107, 8724, 42, 9, 6);
INSERT INTO 'dancesformationsmap' VALUES (37693, 6823, 55, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37694, 15040, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37695, 15040, 164, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37696, 15040, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (37697, 15040, 96, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37698, 15040, 7, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (13147, 10505, 19, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21029, 13320, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21030, 13320, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21031, 13320, 123, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37753, 14140, 225, 65, 4);
INSERT INTO 'dancesformationsmap' VALUES (37754, 14140, 72, 73, 2);
INSERT INTO 'dancesformationsmap' VALUES (37755, 14140, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (37756, 12827, 234, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (37702, 5580, 183, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37703, 5580, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37704, 5580, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37705, 15530, 129, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37706, 15530, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37707, 15530, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8153, 6830, 183, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (37708, 6473, 18, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37709, 6473, 82, 31, 2);
INSERT INTO 'dancesformationsmap' VALUES (37757, 12827, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37758, 12827, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13484, 8360, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (13485, 8360, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37736, 8360, 154, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (15501, 5615, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37731, 5615, 197, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36782, 14185, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37737, 19833, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37738, 19833, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37739, 19833, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18892, 12733, 193, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15185, 11517, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15186, 11517, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11743, 10305, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (11744, 10305, 114, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37740, 10305, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28870, 16906, 92, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37722, 19832, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28871, 16906, 154, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37746, 14231, 90, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37747, 14231, 72, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (37748, 14231, 43, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (37749, 14231, 81, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (37750, 14231, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (28872, 16906, 354, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37768, 19423, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37769, 19423, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37770, 19423, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28873, 16906, 154, 20, 2);
INSERT INTO 'dancesformationsmap' VALUES (37598, 19805, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37759, 19834, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37760, 19834, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37761, 19834, 303, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37771, 3360, 32, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (37772, 3360, 120, 21, 4);
INSERT INTO 'dancesformationsmap' VALUES (37773, 3360, 87, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37774, 3360, 157, 60, 4);
INSERT INTO 'dancesformationsmap' VALUES (9913, 4014, 173, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37689, 4014, 55, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (37690, 4014, 4, 113, 1);
INSERT INTO 'dancesformationsmap' VALUES (37775, 6206, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37776, 6206, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (16335, 11826, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9401, 9040, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (16336, 11826, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16337, 11826, 217, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16338, 11826, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (16339, 11826, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37723, 19832, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37724, 19832, 23, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (37729, 15536, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35469, 18531, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28619, 16672, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (28620, 16672, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37766, 365, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37767, 365, 297, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17980, 10663, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17981, 10663, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17982, 10663, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13630, 10653, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15527, 8375, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13985, 10928, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2475, 4737, 7, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37691, 4737, 134, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37692, 4737, 183, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8323, 5927, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8324, 5927, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8325, 5927, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8109, 708, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16340, 11826, 38, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (13354, 10554, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13355, 10554, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37779, 10554, 8, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (37780, 1392, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37781, 1392, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (37782, 1392, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37783, 17177, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37784, 17177, 70, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24919, 15571, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37785, 7397, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37786, 7397, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37788, 19837, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37789, 19837, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37790, 19837, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23188, 13100, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (24479, 13934, 103, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24480, 13934, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24481, 13934, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37791, 19838, 306, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23517, 13583, 300, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23518, 13583, 183, 19, 3);
INSERT INTO 'dancesformationsmap' VALUES (23519, 13583, 42, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (37863, 5889, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3352, 6363, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37792, 6363, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (37793, 6363, 72, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37794, 6363, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37795, 1114, 166, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37796, 1114, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37699, 19617, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37700, 19617, 7, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (37701, 19617, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37714, 18854, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37715, 18854, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37716, 18854, 213, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22519, 14571, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37745, 14713, 87, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (22520, 14571, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37559, 19803, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37560, 19803, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (22521, 14571, 184, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37762, 19835, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37763, 19835, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37764, 19835, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37721, 3397, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (26911, 16186, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37797, 14182, 318, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37798, 14182, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37799, 14182, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (37800, 14182, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37801, 14182, 175, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37802, 19839, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37803, 19839, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37804, 19839, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (37805, 19839, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37806, 19839, 10, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (37807, 19840, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37808, 19840, 306, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37809, 19840, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12359, 10384, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12360, 10384, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24203, 15331, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22916, 14709, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (32271, 13837, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32272, 13837, 93, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (32273, 13837, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32274, 13837, 162, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37810, 2247, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37811, 2247, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37812, 2247, 222, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (37813, 8312, 33, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (37887, 5732, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11305, 10116, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15924, 4435, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15925, 4435, 180, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37832, 15570, 32, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (15926, 4435, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24923, 15572, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10870, 9944, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (10871, 9944, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10689, 9860, 114, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (10690, 9860, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37836, 9860, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (12690, 7577, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12691, 7577, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37837, 7215, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37838, 6743, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37839, 6371, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37840, 6371, 29, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (37874, 8644, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37875, 8644, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37814, 19841, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37876, 8644, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37841, 5359, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37842, 1001, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37843, 886, 43, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (37844, 886, 29, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (22393, 14536, 119, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37845, 694, 4, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37846, 551, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1664, 3168, 85, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (4907, 3168, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37818, 3168, 72, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (37819, 3168, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37823, 19843, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37824, 19843, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37833, 212, 26, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35650, 19392, 154, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (15927, 4435, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (3927, 184, 81, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13911, 10855, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13912, 10855, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37864, 15649, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37865, 15649, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37866, 15649, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14051, 10960, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25028, 15631, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37847, 5063, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (37848, 5063, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12517, 8505, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (4089, 652, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37856, 18958, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37857, 18958, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37858, 18958, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37850, 11171, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37851, 11171, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37852, 11171, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37853, 11171, 210, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37854, 11171, 76, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37855, 11171, 32, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (12778, 9634, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12779, 9634, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12780, 9634, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37867, 652, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37868, 652, 23, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (37870, 5471, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25093, 9288, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (25094, 9288, 183, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (37869, 9288, 188, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (37871, 5471, 7, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (37872, 5471, 1, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (37815, 19841, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37816, 19841, 272, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37817, 19841, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37873, 19841, 249, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (13637, 10789, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (13638, 10789, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18720, 12680, 27, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (13639, 10789, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37877, 15632, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37878, 15632, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37879, 15632, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37883, 15633, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37884, 15633, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37885, 15633, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37886, 15633, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37880, 15632, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37881, 15632, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37882, 15632, 193, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (37787, 11821, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37834, 212, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37835, 212, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37828, 15568, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37829, 15568, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37859, 19822, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37860, 19822, 49, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11306, 10116, 172, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (9098, 6490, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (9099, 6490, 39, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37821, 19842, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37822, 19842, 124, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37825, 19843, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36329, 19548, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36330, 19548, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14996, 11477, 119, 18, 2);
INSERT INTO 'dancesformationsmap' VALUES (14997, 11477, 192, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (37849, 5063, 332, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37888, 11181, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25037, 15654, 189, 28, 2);
INSERT INTO 'dancesformationsmap' VALUES (37892, 13507, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37893, 13507, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37894, 13507, 1, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (37895, 13507, 23, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28250, 16716, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28251, 16716, 265, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (28252, 16716, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28253, 16716, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28254, 16716, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (37981, 2371, 96, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (37982, 2371, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37983, 2371, 188, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (37935, 16338, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37936, 16338, 158, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37937, 16338, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37929, 19847, 96, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (37930, 19847, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33869, 19155, 30, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (33870, 19155, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28874, 16906, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37931, 19847, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23731, 1946, 202, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37902, 19599, 263, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37903, 19599, 188, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (37904, 19599, 96, 31, 2);
INSERT INTO 'dancesformationsmap' VALUES (36995, 534, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (37946, 4975, 95, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37944, 2229, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (37945, 2229, 318, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (36310, 19543, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37908, 533, 173, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37915, 19845, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37916, 19845, 278, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37917, 19845, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37918, 19845, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15453, 11397, 43, 65, 4);
INSERT INTO 'dancesformationsmap' VALUES (26140, 16011, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37905, 2172, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37906, 2172, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37907, 2172, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37909, 5746, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37910, 5746, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37911, 5746, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37765, 19835, 33, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (37826, 1634, 123, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (37820, 3169, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37827, 1634, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15454, 11397, 27, 9, 8);
INSERT INTO 'dancesformationsmap' VALUES (15455, 11397, 69, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (23035, 11397, 23, 5, 8);
INSERT INTO 'dancesformationsmap' VALUES (23036, 11397, 17, 81, 4);
INSERT INTO 'dancesformationsmap' VALUES (23037, 11397, 66, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (11643, 7575, 85, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37955, 19851, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37956, 19851, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37957, 19851, 286, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (37958, 19851, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37920, 16892, 306, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37921, 16892, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37922, 16892, 162, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37923, 16892, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37924, 16892, 132, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (37925, 19846, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37926, 19846, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37927, 19846, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37928, 19846, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37971, 16715, 222, 26, 2);
INSERT INTO 'dancesformationsmap' VALUES (37959, 19851, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23739, 2315, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24428, 2315, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37998, 19857, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37999, 19857, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37984, 19856, 93, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (37976, 7731, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37977, 7731, 142, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37978, 7731, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37941, 19850, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37942, 19850, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37943, 19850, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37979, 7731, 249, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32449, 18488, 186, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37947, 14851, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (37948, 14851, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37949, 14851, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37950, 14851, 321, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32450, 18488, 142, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37960, 9291, 259, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37961, 9291, 9, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (37962, 9291, 119, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37963, 9291, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37914, 15233, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37985, 15246, 168, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (37986, 15246, 307, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37966, 10285, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37967, 19828, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25999, 15965, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26000, 15965, 202, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26001, 15965, 202, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (26002, 15965, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26003, 15965, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31518, 16889, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (1876, 3558, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5038, 3558, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37919, 3558, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37968, 19828, 55, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37969, 19828, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37970, 19828, 64, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36933, 19691, 27, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (36934, 19691, 176, 81, 2);
INSERT INTO 'dancesformationsmap' VALUES (31091, 11047, 39, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (31092, 11047, 176, 6, 2);
INSERT INTO 'dancesformationsmap' VALUES (14105, 11043, 189, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14106, 11043, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14107, 11043, 32, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14108, 11043, 58, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14109, 11043, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (38000, 19857, 168, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (5068, 3632, 52, 24, 1);
INSERT INTO 'dancesformationsmap' VALUES (14775, 11370, 66, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (14776, 11370, 183, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (14777, 11370, 121, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (14778, 11370, 120, 77, 1);
INSERT INTO 'dancesformationsmap' VALUES (14779, 11370, 1, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (19262, 1088, 224, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19263, 1088, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12818, 8525, 183, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (38001, 19857, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37980, 2371, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37987, 15246, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37988, 15246, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37989, 1894, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37990, 1894, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37991, 15307, 158, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37992, 15307, 112, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (37993, 15307, 119, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (37994, 19849, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37995, 19849, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37996, 19849, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37997, 19849, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38002, 17371, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38003, 17371, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38004, 17371, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38005, 17371, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38006, 17371, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31816, 13915, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (31817, 13915, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31818, 13915, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13951, 10912, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13952, 10912, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37896, 6464, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (9605, 802, 170, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36306, 19542, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37938, 14540, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36307, 19542, 152, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16654, 11939, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37951, 17805, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37952, 17805, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (37953, 17805, 92, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (37897, 6464, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37898, 6464, 8, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (37889, 11181, 6, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37890, 11181, 101, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16655, 11939, 20, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (18229, 12518, 72, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (18230, 12518, 149, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (18231, 12518, 225, 53, 2);
INSERT INTO 'dancesformationsmap' VALUES (18232, 12518, 224, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (18233, 12518, 134, 65, 4);
INSERT INTO 'dancesformationsmap' VALUES (18161, 12506, 193, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (38010, 12506, 265, 57, 4);
INSERT INTO 'dancesformationsmap' VALUES (38011, 5198, 329, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (12808, 9219, 32, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (12809, 9219, 66, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (38013, 8578, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38014, 8578, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38015, 8578, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20015, 12960, 27, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (38021, 4543, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38113, 19871, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38114, 19871, 142, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38026, 19859, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38027, 19859, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38028, 19859, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3667, 6910, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7059, 6910, 193, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38012, 6910, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38074, 17396, 39, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38022, 19858, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38023, 19858, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38031, 17471, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (810, 1504, 78, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (38070, 19892, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38071, 19892, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38072, 19892, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38075, 17396, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38039, 19722, 1, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (38076, 17396, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38077, 17396, 120, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38078, 17396, 121, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (38095, 2396, 33, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (38101, 5757, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38102, 5757, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38043, 19887, 23, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (38044, 19887, 143, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38045, 19887, 1, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (38051, 10726, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38052, 10726, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38053, 10726, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38054, 10726, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38103, 5757, 112, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (38104, 19861, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38105, 19861, 71, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (37939, 14540, 326, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38049, 10619, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38050, 10619, 36, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (38055, 6990, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26129, 16006, 313, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (37940, 14540, 294, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4469, 1806, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38061, 1806, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37964, 19852, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37965, 19852, 193, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38035, 7077, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38036, 7077, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38037, 7077, 8, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (37932, 19848, 69, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37933, 19848, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37934, 19848, 43, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (38056, 19890, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38059, 19890, 23, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (38057, 19891, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38058, 19891, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38062, 19891, 23, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (29626, 17424, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (38063, 17424, 199, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38079, 14540, 249, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29564, 17391, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38106, 19861, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38064, 17398, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38065, 17398, 23, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (38066, 17398, 42, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (38067, 17398, 123, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11652, 9222, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15654, 11605, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (15655, 11605, 213, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38060, 10456, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4378, 1521, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38107, 19861, 10, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38108, 19861, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38096, 19864, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38097, 19864, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38098, 19864, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38099, 19864, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38100, 19864, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38024, 19858, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38109, 19877, 92, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38110, 19877, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38111, 19877, 13, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38080, 19893, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38081, 19893, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38082, 19893, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38083, 19893, 17, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38112, 19877, 76, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38046, 19860, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38047, 19860, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38048, 19860, 1, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (38088, 19860, 102, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32824, 18576, 145, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (38089, 19894, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38090, 19894, 23, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (20074, 13082, 39, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (20075, 13082, 10, 51, 1);
INSERT INTO 'dancesformationsmap' VALUES (20076, 13082, 225, 61, 1);
INSERT INTO 'dancesformationsmap' VALUES (38093, 3037, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38094, 3037, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38127, 17050, 18, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38128, 17050, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38115, 19876, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38116, 19876, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38117, 19876, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38118, 19896, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38119, 19896, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38120, 19896, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38121, 19896, 92, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38122, 19896, 168, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38123, 6751, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38124, 19874, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38125, 19874, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38126, 19874, 157, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38129, 17050, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38130, 3522, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38131, 3522, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38132, 3522, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38133, 19883, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38134, 19883, 189, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38141, 585, 263, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38142, 585, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38143, 585, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14454, 11186, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14455, 11186, 87, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (14456, 11186, 149, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (9714, 8490, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21164, 13353, 93, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (21165, 13353, 224, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (21166, 13353, 225, 85, 1);
INSERT INTO 'dancesformationsmap' VALUES (38148, 13353, 296, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (38137, 19906, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38138, 19906, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38139, 19906, 152, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38029, 572, 183, 4, 3);
INSERT INTO 'dancesformationsmap' VALUES (38030, 572, 249, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2618, 5013, 88, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5538, 5013, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (38032, 19878, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38084, 14387, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38085, 14387, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38086, 14387, 303, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38073, 19892, 17, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38033, 19878, 78, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38034, 19878, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38087, 14387, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13085, 1521, 168, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38153, 19908, 224, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38154, 19908, 123, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38155, 19908, 225, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38156, 19908, 93, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (38157, 19908, 185, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38158, 19908, 32, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (38159, 19926, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38160, 19926, 90, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38161, 19926, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38174, 19933, 10, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38175, 19933, 94, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38176, 19933, 87, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (38177, 19933, 110, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (38178, 19933, 216, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (38205, 5543, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (9657, 9165, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38202, 19942, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38226, 19724, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38227, 19724, 28, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38228, 19723, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38149, 18939, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38150, 18939, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38151, 18939, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38242, 7087, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38183, 14860, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38184, 14860, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38185, 14860, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38186, 14860, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38187, 14860, 71, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38194, 19941, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38195, 19941, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38196, 19941, 75, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38197, 19941, 56, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (38198, 9143, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38199, 9143, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38200, 9143, 38, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38201, 9143, 249, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38206, 11422, 121, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38207, 11422, 188, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38208, 11422, 29, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38209, 11422, 72, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (38210, 11422, 120, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38211, 11422, 183, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (38212, 11422, 96, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (38213, 11422, 193, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (11133, 8814, 66, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38214, 2805, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34673, 8170, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38215, 8170, 120, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38282, 19953, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38216, 8169, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38217, 8169, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38218, 8168, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38219, 8168, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38220, 8168, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38223, 2102, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38234, 19936, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38235, 19936, 340, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38236, 19936, 52, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38237, 19936, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38283, 19953, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38284, 19953, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38243, 19944, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38135, 19904, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38136, 19904, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38068, 10578, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38069, 10578, 32, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (38173, 4026, 143, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38144, 19905, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15674, 11613, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38091, 19895, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38092, 19895, 386, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (38016, 4185, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38017, 4185, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38145, 19905, 386, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38179, 17251, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38180, 17251, 234, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (38181, 17251, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38188, 14832, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38189, 14832, 273, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38190, 14832, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38018, 4185, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38019, 4185, 1, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (13934, 10909, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38244, 19944, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (30274, 17760, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30275, 17760, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38238, 19940, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38239, 19940, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38240, 19940, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38241, 9107, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (38245, 9048, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38246, 19945, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38247, 19945, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38248, 19945, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38249, 19945, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38250, 19946, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38251, 19946, 109, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38252, 19946, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38253, 19946, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38254, 19947, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38255, 19947, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38256, 19947, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38257, 19948, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38258, 19948, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38259, 19948, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38260, 19949, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38261, 19949, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38262, 19949, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38263, 19950, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38264, 19950, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38265, 19950, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38266, 19950, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38267, 19950, 51, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (5520, 4959, 45, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38268, 19934, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38269, 19934, 234, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38270, 19934, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38285, 19953, 216, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38271, 19934, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38272, 19934, 76, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38273, 19951, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38274, 19951, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38275, 19951, 95, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38276, 19951, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38277, 19951, 142, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38278, 19924, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38279, 19924, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38280, 19924, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38281, 19924, 162, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38288, 479, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38289, 479, 42, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (38286, 19939, 53, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38287, 19939, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (24189, 13579, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38290, 479, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38291, 19954, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38292, 19954, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32544, 18508, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32545, 18508, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38221, 19943, 42, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (38222, 19943, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38293, 19955, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38294, 19955, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38295, 6813, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38296, 6813, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (34617, 9658, 103, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34618, 9658, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38140, 19906, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38297, 19925, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38298, 19925, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38169, 19932, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38170, 19932, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38171, 19932, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38172, 19932, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38164, 19930, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38165, 19930, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38162, 19927, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38163, 19927, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38166, 19930, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38203, 19942, 152, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19742, 12927, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38204, 9896, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38167, 19931, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38168, 19931, 334, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38229, 19935, 228, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38230, 19935, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38231, 19935, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38232, 19935, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38152, 18939, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38233, 7239, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38299, 19925, 119, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (7600, 1544, 90, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (38432, 4474, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38433, 4474, 365, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (38434, 4474, 372, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38366, 19448, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38367, 19448, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38308, 6061, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (29994, 17670, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38309, 19869, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38310, 19869, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38311, 19869, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38312, 19869, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38313, 19869, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38314, 19886, 316, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38315, 19886, 154, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25019, 7943, 42, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (25020, 7943, 43, 26, 2);
INSERT INTO 'dancesformationsmap' VALUES (25021, 7943, 112, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38318, 19885, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38319, 19885, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38320, 19885, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38321, 19957, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38322, 19957, 310, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38323, 19884, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38324, 19884, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38325, 19884, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7442, 3526, 33, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (8887, 5354, 176, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (8888, 5354, 1, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (8889, 5354, 16, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (8890, 5354, 72, 77, 1);
INSERT INTO 'dancesformationsmap' VALUES (8891, 5354, 83, 129, 1);
INSERT INTO 'dancesformationsmap' VALUES (38423, 19923, 246, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (37478, 19797, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (37479, 19797, 249, 31, 2);
INSERT INTO 'dancesformationsmap' VALUES (38326, 19866, 188, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38327, 19866, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38328, 19866, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38329, 19866, 107, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38368, 19438, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38330, 9125, 189, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38331, 19959, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24345, 11105, 34, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (38419, 19969, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38420, 19969, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12588, 10412, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38365, 10412, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (3430, 6489, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6031, 6489, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34436, 19201, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (34437, 19201, 252, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38350, 19962, 23, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (38369, 19438, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38370, 19438, 103, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38371, 19438, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38372, 19438, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38373, 19438, 154, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (38374, 175, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38360, 19966, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38361, 19966, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38362, 8918, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38363, 8918, 95, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38364, 8918, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38351, 19963, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38352, 19963, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38341, 19958, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38342, 19958, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38375, 7137, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38376, 7137, 359, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38377, 7137, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36146, 19495, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38379, 15, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17157, 12053, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17158, 12053, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (17159, 12053, 32, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (17160, 12053, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28977, 16941, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38383, 16941, 76, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38384, 18710, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38304, 19956, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38305, 19956, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38306, 19956, 386, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38307, 19956, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35193, 19258, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (35194, 19258, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35195, 19258, 69, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (38417, 19198, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38182, 17251, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (38418, 19198, 15, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (38347, 19961, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30287, 17769, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30288, 17769, 313, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38385, 18710, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38386, 18710, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38421, 19970, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38422, 19970, 365, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38332, 19960, 114, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (19753, 12930, 171, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (38394, 19968, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38395, 19968, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (38396, 19968, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38397, 19968, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38392, 19967, 307, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38393, 19967, 42, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (38398, 4471, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38399, 4471, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38387, 8917, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38388, 8917, 234, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (38389, 8917, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (38333, 19960, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38334, 19960, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38335, 19960, 134, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38406, 18930, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38407, 18930, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38408, 18930, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38409, 18930, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38414, 17581, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38427, 12052, 91, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (17176, 12058, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38431, 10270, 119, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (38378, 11760, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38300, 19938, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33856, 19151, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33857, 19151, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38301, 19938, 186, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38302, 19938, 154, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38343, 19958, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33858, 19151, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (38316, 14010, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38317, 14010, 101, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (38435, 12068, 123, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38380, 17623, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38381, 17623, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38382, 17623, 251, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38436, 18808, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38437, 18808, 123, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38438, 18808, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38428, 19971, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38429, 19971, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38430, 19971, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38344, 19958, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38336, 19901, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38337, 19901, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38338, 19901, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38339, 19901, 55, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38303, 19938, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38424, 19923, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38425, 19923, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38426, 19923, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38390, 18905, 260, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38391, 18905, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31456, 18251, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38480, 4442, 82, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (38498, 4442, 332, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38443, 17695, 235, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38444, 17695, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (36542, 16769, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (36543, 16769, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38499, 2257, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38500, 2257, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38439, 18808, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33099, 18806, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33100, 18806, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33101, 18806, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (38456, 17577, 114, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38457, 17577, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24735, 15435, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24736, 15435, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38465, 1943, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (8999, 7652, 145, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (38501, 2780, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (38462, 16289, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38463, 16289, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (97, 159, 56, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (23796, 159, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38464, 5347, 132, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38448, 19974, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7466, 183, 202, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24170, 183, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24171, 183, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (23971, 6130, 309, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38466, 6885, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22196, 4796, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22197, 4796, 66, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13335, 10541, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13336, 10541, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5501, 4907, 34, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38487, 4907, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27212, 16291, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27213, 16291, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27222, 16291, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38506, 19862, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38544, 19985, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38545, 19985, 72, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (38507, 19862, 27, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38509, 5878, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (30115, 17715, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (30116, 17715, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38475, 19979, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38476, 19979, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38552, 19995, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38553, 19995, 313, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38554, 19995, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38555, 19995, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (14219, 11078, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38473, 11078, 92, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38477, 19979, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38510, 6634, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38511, 6362, 308, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38512, 4725, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38474, 11260, 7, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (38488, 4806, 76, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38484, 19054, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38485, 19054, 33, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (38486, 794, 308, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9420, 9075, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38513, 7219, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38514, 899, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38491, 19437, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38492, 19437, 168, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38493, 19437, 92, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38494, 18714, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38495, 18714, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38496, 18714, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38497, 18714, 241, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38515, 1591, 72, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38516, 1591, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38517, 1591, 28, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38518, 1591, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38519, 3934, 30, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38520, 3934, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38508, 4359, 148, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15708, 11623, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15709, 11623, 30, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38523, 19983, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38524, 19983, 53, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38525, 19983, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38526, 18875, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38527, 18875, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38528, 18875, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38529, 18875, 105, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38530, 18940, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38531, 18940, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38532, 18940, 92, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38540, 19984, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38541, 19984, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38542, 19984, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38478, 19980, 358, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38481, 19981, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38445, 7302, 32, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (38446, 7302, 365, 121, 1);
INSERT INTO 'dancesformationsmap' VALUES (38415, 19197, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38416, 19197, 15, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (38521, 19982, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (38522, 19982, 220, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38440, 19972, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38441, 19972, 84, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38482, 19981, 8, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (38483, 19981, 33, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (38400, 19910, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38401, 19910, 356, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38402, 19910, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33374, 19053, 59, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38502, 1400, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38503, 1400, 332, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38410, 17693, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38411, 17693, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38412, 17693, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38403, 18729, 227, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38404, 18729, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38405, 18729, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17558, 4147, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30814, 10982, 23, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (10418, 9722, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22517, 14570, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38533, 14572, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38534, 1786, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38535, 14573, 142, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14196, 11066, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14197, 11066, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14209, 11073, 119, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (14210, 11073, 221, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38546, 19985, 29, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (38489, 4806, 19, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38549, 19994, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38550, 19994, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38551, 19994, 109, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38556, 19996, 5, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38557, 19996, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38558, 19996, 283, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38559, 19997, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38560, 19997, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38561, 19997, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38562, 19998, 314, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38563, 19998, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38564, 19998, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38565, 19998, 96, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (38566, 19998, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38567, 19999, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38568, 19999, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38569, 19999, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (20139, 5324, 225, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20140, 5324, 5, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38536, 17399, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5215, 4033, 91, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38460, 19903, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38461, 19903, 55, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (38537, 19900, 33, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38538, 19900, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (8992, 7534, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38490, 4806, 4, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (8633, 219, 65, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (8634, 219, 120, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38458, 19973, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38459, 19973, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38467, 19976, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13569, 10546, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10107, 7227, 8, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (38468, 19976, 134, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38471, 805, 303, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (38472, 805, 308, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (38469, 19976, 33, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38449, 19974, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38450, 19974, 33, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38451, 19974, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38570, 19999, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38579, 20000, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38580, 20000, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38581, 20000, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38582, 20000, 296, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38583, 20000, 220, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38584, 4424, 132, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38547, 19986, 42, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38548, 19986, 353, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38585, 19733, 326, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38586, 19733, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38587, 19733, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38588, 19987, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38589, 19987, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38590, 19987, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38591, 19988, 114, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38592, 19989, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38593, 19989, 86, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38594, 19990, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38595, 19990, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38596, 18446, 285, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38597, 18446, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38598, 18446, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38599, 18446, 17, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38600, 19991, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38601, 19991, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38602, 19991, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38603, 19992, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38604, 19992, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38605, 19992, 321, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38606, 18451, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38607, 18451, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38608, 18451, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38609, 18451, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38610, 18451, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38611, 19993, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15901, 8467, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15904, 8467, 158, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29999, 2413, 210, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (30000, 2413, 138, 73, 2);
INSERT INTO 'dancesformationsmap' VALUES (30001, 2413, 249, 81, 2);
INSERT INTO 'dancesformationsmap' VALUES (30002, 2413, 193, 89, 2);
INSERT INTO 'dancesformationsmap' VALUES (38613, 6461, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38614, 6461, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38615, 6461, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38616, 6461, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38617, 6461, 340, 69, 2);
INSERT INTO 'dancesformationsmap' VALUES (38618, 6461, 296, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (38619, 6461, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (38620, 17397, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38621, 17397, 56, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38622, 17397, 55, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38623, 17397, 28, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38624, 1438, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38625, 1438, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (38626, 1438, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38627, 1581, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38628, 1581, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38630, 1921, 188, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (38631, 1921, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38635, 20009, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38636, 20009, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38637, 20009, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13392, 10566, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (15702, 11621, 43, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (15703, 11621, 220, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (15704, 11621, 156, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (15705, 11621, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (38638, 10656, 101, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38639, 10656, 285, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38640, 10656, 43, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38641, 20011, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38642, 20011, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38643, 20011, 101, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38644, 13780, 46, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38645, 13780, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38646, 13780, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31217, 13575, 82, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38651, 20013, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38652, 20013, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38653, 20013, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38654, 20013, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38655, 20013, 93, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38656, 20013, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (38657, 20014, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38658, 20014, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38659, 20014, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38660, 20015, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38661, 20015, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38662, 20015, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38663, 20016, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38664, 20016, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38674, 20020, 202, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38675, 20020, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38676, 20020, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38667, 20018, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38668, 20018, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38669, 20018, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38680, 20022, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38681, 20022, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38677, 20021, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38678, 20021, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38679, 20021, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38682, 20022, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38670, 20019, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38697, 1958, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38665, 20017, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38666, 20017, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38698, 1958, 43, 33, 6);
INSERT INTO 'dancesformationsmap' VALUES (38699, 1958, 330, 17, 32);
INSERT INTO 'dancesformationsmap' VALUES (38575, 20001, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38576, 20001, 329, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38577, 20001, 42, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (38578, 20001, 72, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (38454, 19975, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38455, 19975, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38647, 20012, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38648, 20012, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38649, 20012, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38650, 20012, 380, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6550, 2345, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38684, 20023, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38685, 20023, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38686, 20023, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38687, 20023, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38688, 20023, 10, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (38689, 20024, 114, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38690, 20024, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38691, 20024, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38693, 20026, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38694, 20026, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38695, 20026, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38696, 20026, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38705, 20027, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38706, 20027, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31399, 18245, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31400, 18245, 123, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31401, 18245, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38709, 20029, 109, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38710, 20029, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38711, 20029, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38715, 20006, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38716, 20006, 168, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (38717, 20006, 225, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38718, 20006, 224, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (38719, 1695, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38721, 1848, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (38725, 4940, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38726, 4940, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38727, 11724, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17649, 12247, 72, 53, 1);
INSERT INTO 'dancesformationsmap' VALUES (38728, 17665, 42, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38729, 7613, 269, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38730, 15668, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38731, 15668, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38632, 2002, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38722, 20031, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38723, 20031, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38724, 20031, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38629, 3631, 9, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (38713, 9753, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38707, 3543, 85, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (11024, 10000, 38, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (38571, 20002, 36, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38572, 20002, 39, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38708, 3543, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38720, 6510, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38714, 1051, 145, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (38732, 15668, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38824, 20044, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38825, 20044, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38738, 20034, 42, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (38739, 20034, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38740, 20034, 376, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38826, 20044, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38827, 20044, 96, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (38828, 20044, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38735, 20033, 119, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (38736, 20033, 92, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38737, 20033, 318, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (21235, 13618, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38741, 13618, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38742, 13618, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20871, 13281, 221, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (38743, 13281, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38744, 13281, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38745, 12924, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38746, 12874, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38747, 12842, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38748, 12842, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (38749, 12792, 23, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (38753, 18976, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38754, 18976, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38755, 18208, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38756, 18208, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38757, 18208, 21, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38758, 17105, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38759, 17105, 23, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (38760, 17105, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38761, 12831, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38762, 12831, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38763, 12831, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38764, 19826, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38765, 17501, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38766, 17501, 76, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (38767, 17501, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38768, 17307, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38769, 17307, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38770, 17307, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38771, 17360, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38772, 17360, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38773, 17360, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38779, 17610, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38780, 17610, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38781, 17610, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26113, 16002, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38784, 17593, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38785, 17593, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38786, 17593, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38787, 17593, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38788, 17594, 114, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38789, 17594, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (38790, 17594, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38782, 17609, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38783, 17609, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36978, 205, 225, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38791, 205, 181, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38792, 20035, 326, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38793, 20035, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (33002, 18662, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33003, 18662, 26, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33004, 18662, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33005, 18662, 241, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38794, 15646, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38795, 15646, 157, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38796, 15646, 372, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38799, 20037, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38800, 20037, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38829, 6221, 372, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38797, 20036, 296, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38798, 20036, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38801, 20038, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38802, 20038, 220, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38803, 20038, 176, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15214, 11527, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (15215, 11527, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34573, 10701, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34574, 10701, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38830, 2156, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38831, 2156, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38832, 20045, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38804, 20040, 314, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38805, 20040, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38806, 20040, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38807, 20040, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38633, 2002, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38634, 2002, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38808, 3251, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38809, 3251, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38810, 14640, 8, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (38815, 20042, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38816, 20042, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38817, 20042, 222, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38818, 20042, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (38819, 20043, 72, 1, 5);
INSERT INTO 'dancesformationsmap' VALUES (38820, 20043, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38821, 20043, 283, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18247, 12522, 225, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (18248, 12522, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18249, 12522, 66, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (36823, 19673, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38822, 19673, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38823, 18242, 249, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (38833, 20045, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38834, 20045, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (38841, 15675, 154, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (38838, 20047, 114, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38839, 20047, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38840, 20047, 36, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (38842, 6523, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38843, 5794, 96, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (38844, 5794, 268, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38865, 14336, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15430, 5843, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15432, 5843, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2135, 4052, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38849, 12882, 314, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (15818, 11678, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (38850, 12253, 72, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38851, 12253, 114, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (38852, 7025, 48, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38866, 14336, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38867, 14336, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38858, 17700, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38733, 20032, 296, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38692, 20025, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38734, 20032, 43, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (38853, 20049, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38854, 20049, 224, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38855, 20049, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (14827, 1201, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38859, 17700, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38860, 17700, 39, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38861, 17700, 249, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38862, 17700, 1, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (38863, 17700, 87, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38864, 17700, 251, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (38871, 20051, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38811, 20041, 326, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38812, 20041, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38868, 20050, 240, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38872, 20051, 120, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38873, 20051, 7, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38874, 20051, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38875, 20051, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (29045, 16952, 235, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29046, 16952, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21366, 13676, 48, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (31287, 18219, 27, 17, 0);
INSERT INTO 'dancesformationsmap' VALUES (31288, 18219, 143, 25, 0);
INSERT INTO 'dancesformationsmap' VALUES (31289, 18219, 17, 33, 0);
INSERT INTO 'dancesformationsmap' VALUES (38876, 20052, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38877, 20052, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38878, 20052, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38845, 20048, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38846, 20048, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38847, 20048, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38848, 20048, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (38869, 20050, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38870, 20050, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38813, 20041, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38814, 20041, 26, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38774, 17596, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38775, 17596, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38776, 17596, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38879, 20052, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32879, 16479, 188, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (37861, 19822, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37862, 19822, 33, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (38880, 19145, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38881, 17340, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38882, 17340, 164, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38883, 17340, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38884, 17340, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30396, 17792, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38885, 19164, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38886, 19164, 33, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (38887, 20053, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38888, 20053, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38889, 20053, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10295, 9661, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38890, 9661, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24421, 4863, 72, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (3629, 6838, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (38943, 20060, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38944, 20060, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38945, 20060, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19388, 7608, 7, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19389, 7608, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (6373, 784, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (38946, 1086, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38947, 1086, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38899, 13122, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38900, 13122, 154, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38901, 13122, 94, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38902, 13122, 27, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38903, 13122, 26, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (2533, 4848, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38948, 20061, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (38904, 10922, 273, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38905, 10922, 234, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (31853, 2534, 134, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (38906, 9671, 91, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38894, 20054, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38895, 20054, 33, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38896, 20054, 92, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38897, 20054, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38898, 20054, 134, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38965, 2534, 119, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38966, 3025, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38967, 3025, 142, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30407, 17799, 36, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (30408, 17799, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38910, 12545, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38911, 12545, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38912, 20055, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38913, 20055, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38914, 20055, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34954, 2896, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38949, 20062, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16186, 11780, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (16187, 11780, 373, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38915, 11780, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38916, 11780, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (28782, 16869, 241, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (34910, 3798, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2940, 5609, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38917, 5279, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38918, 5279, 58, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38919, 5279, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38950, 20062, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (38920, 5174, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33888, 19161, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38924, 4632, 32, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38925, 4632, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38926, 4632, 6, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38927, 4149, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38928, 4149, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38952, 625, 56, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38907, 11661, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38933, 20058, 23, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (38934, 20058, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38935, 20058, 1, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38936, 20058, 154, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38937, 7360, 114, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (38938, 7360, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38939, 7360, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (38951, 20062, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38953, 2150, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38954, 2150, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38955, 2150, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (8721, 2119, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38921, 20056, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38922, 20056, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38923, 20056, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38940, 20059, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38941, 20059, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38942, 20059, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20849, 11807, 29, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20850, 11807, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20851, 11807, 71, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20852, 11807, 188, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (987, 1838, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7680, 1840, 67, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (38956, 2180, 143, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (19402, 12818, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (19403, 12818, 112, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (31410, 2232, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4615, 2276, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1245, 2363, 41, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38957, 6826, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (38958, 6826, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (38973, 12823, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38963, 7223, 183, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (38964, 7223, 185, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38892, 10924, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18762, 2421, 114, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31360, 2544, 134, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (31343, 3465, 7, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (28004, 3524, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (9458, 3979, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9459, 3979, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31340, 4033, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (5480, 4848, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38980, 4848, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31341, 4033, 112, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31342, 4033, 32, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (2227, 4225, 83, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (38968, 1033, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38969, 1033, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38970, 1033, 156, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38971, 1033, 143, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (38972, 1033, 27, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (34852, 4930, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (26659, 16113, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33810, 7261, 52, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (38981, 18573, 188, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38982, 18573, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38983, 18573, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38984, 18573, 154, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38985, 18573, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38986, 905, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38987, 467, 36, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36065, 19084, 386, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38959, 3293, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38960, 3293, 209, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38961, 3293, 210, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (38962, 3293, 84, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (31377, 4257, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1019, 1891, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28708, 16847, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38891, 9663, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38988, 6367, 269, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38989, 6367, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38929, 19898, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38930, 19898, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38931, 19898, 22, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38932, 19898, 251, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (12898, 8816, 134, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (38993, 20065, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (3710, 6995, 69, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (175, 312, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (38974, 12823, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38975, 12823, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19411, 12819, 143, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (1937, 3666, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38893, 10924, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12392, 2171, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (38990, 4835, 249, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (38991, 4835, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38992, 4835, 193, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (513, 932, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (305, 549, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38994, 20065, 28, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38995, 15635, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38996, 15635, 16, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (38997, 15635, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38998, 5310, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38539, 19900, 298, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38340, 19901, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38999, 19897, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31028, 17747, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39001, 114, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39002, 484, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39003, 484, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39004, 484, 9, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (39005, 484, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39006, 484, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39007, 2227, 4, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39008, 2227, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (39010, 17586, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39011, 17586, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39012, 17586, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39013, 17586, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39014, 17602, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39015, 17602, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39016, 17602, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39017, 17602, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39018, 19977, 183, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (39019, 19977, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39020, 19977, 176, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39021, 19977, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39022, 19977, 114, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39023, 18416, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39024, 18416, 42, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (39025, 18416, 17, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (37954, 17805, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39029, 17605, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39030, 17605, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39031, 17605, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39032, 17605, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39033, 17604, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39034, 17604, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39035, 17597, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39036, 17597, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39037, 17597, 150, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39038, 17592, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39039, 17592, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39040, 17591, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39041, 17591, 112, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39042, 17591, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39043, 17589, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39044, 17588, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39045, 17588, 39, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39046, 17588, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39047, 17585, 283, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39048, 17585, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39049, 17585, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39050, 17584, 176, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39051, 17584, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39052, 17584, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39053, 17584, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39054, 17584, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39055, 2463, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39056, 2463, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39060, 3794, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39061, 3794, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39062, 3794, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39067, 4241, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39068, 4241, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39069, 4241, 162, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (39070, 4241, 315, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (39071, 20069, 64, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39072, 20069, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39114, 19114, 43, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (39115, 19114, 23, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (39116, 19114, 39, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (39073, 2901, 69, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39074, 2901, 21, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39075, 2901, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39117, 19114, 328, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39118, 17230, 36, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39119, 17230, 134, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (39120, 17230, 112, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39121, 17230, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39122, 17230, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39088, 13822, 52, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39089, 13822, 87, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (39090, 13822, 43, 67, 2);
INSERT INTO 'dancesformationsmap' VALUES (39091, 13822, 90, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (39092, 13822, 149, 105, 1);
INSERT INTO 'dancesformationsmap' VALUES (39093, 17400, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39094, 17400, 93, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39095, 17400, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39096, 17310, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39097, 17310, 362, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39098, 17327, 221, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39099, 17327, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39100, 17327, 109, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39101, 17327, 365, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39082, 20071, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39083, 20071, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39084, 20071, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39085, 20071, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (39086, 20071, 162, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39087, 20071, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39127, 16837, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39128, 16837, 365, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39103, 9462, 217, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39104, 9462, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39105, 9462, 326, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (39106, 9462, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39107, 9462, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39108, 14820, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39109, 14820, 302, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39110, 14820, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39111, 14820, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39079, 20070, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39080, 20070, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39081, 20070, 307, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39129, 16837, 130, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39130, 15645, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39131, 15645, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39132, 15645, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39133, 15645, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39134, 15603, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39135, 15603, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39136, 14413, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39137, 14413, 314, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (39138, 13499, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39139, 13499, 112, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39140, 13499, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39141, 13499, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39142, 13499, 91, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39143, 13499, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (39144, 18963, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39145, 18963, 268, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39146, 18963, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39147, 8498, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39148, 8498, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39149, 8498, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39150, 8498, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39151, 8498, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39152, 46, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39153, 46, 157, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39154, 294, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39155, 294, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39161, 9489, 25, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (39162, 20072, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39026, 17608, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39027, 17608, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39028, 17608, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39076, 10768, 249, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (39077, 10768, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (39078, 10768, 386, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39063, 1080, 30, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39064, 1080, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39065, 1080, 9, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39057, 4696, 9, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (39058, 4696, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39059, 4696, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39009, 2345, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (39163, 20072, 18, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39164, 20073, 41, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39165, 20073, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39168, 20075, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39169, 20075, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5132, 3805, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (39000, 3805, 162, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (39102, 14510, 125, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39112, 4758, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39113, 4758, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39156, 441, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39157, 441, 84, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39158, 441, 312, 55, 1);
INSERT INTO 'dancesformationsmap' VALUES (39172, 18965, 7, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (39173, 18965, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39174, 19426, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39175, 19426, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39176, 19426, 134, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39177, 19426, 117, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39178, 19426, 210, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39179, 19426, 90, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (39180, 19426, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (39181, 19612, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39182, 19612, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39183, 19141, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39184, 19141, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39190, 14162, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39191, 14162, 165, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39192, 14162, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39193, 14162, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39170, 20075, 39, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39171, 20075, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39201, 20076, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39202, 20076, 7, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (39203, 20076, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39204, 20076, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39205, 20076, 183, 41, 3);
INSERT INTO 'dancesformationsmap' VALUES (39208, 20078, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39209, 20078, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39210, 20078, 307, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39211, 171, 251, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39212, 171, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39213, 171, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39214, 171, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39215, 177, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39216, 177, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39217, 177, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39218, 186, 114, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39219, 249, 234, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (39220, 249, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39221, 249, 114, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39222, 308, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39223, 308, 72, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (39224, 366, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39225, 366, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (39226, 452, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39227, 452, 318, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39228, 483, 157, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39229, 483, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39230, 483, 328, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (39231, 510, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39232, 510, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39233, 645, 193, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39234, 645, 176, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39235, 645, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39236, 645, 296, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39237, 645, 90, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (39238, 645, 7, 65, 4);
INSERT INTO 'dancesformationsmap' VALUES (39239, 645, 1, 85, 1);
INSERT INTO 'dancesformationsmap' VALUES (39240, 721, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39249, 857, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39250, 857, 36, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39255, 946, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39256, 946, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39257, 946, 117, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39258, 946, 43, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (39259, 946, 93, 69, 2);
INSERT INTO 'dancesformationsmap' VALUES (39260, 946, 39, 89, 2);
INSERT INTO 'dancesformationsmap' VALUES (39261, 999, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39262, 999, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39263, 999, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39266, 1032, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39267, 1032, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (39268, 1143, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39269, 1143, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39270, 1160, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (39271, 1160, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39272, 1160, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39273, 1183, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39274, 1193, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39275, 1193, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39276, 1193, 183, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (39277, 1193, 145, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39278, 9216, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39279, 9216, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39280, 9216, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39281, 1245, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39282, 1245, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39283, 1245, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39284, 1295, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39285, 1295, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39286, 1295, 154, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39287, 1295, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (39288, 1295, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39289, 1352, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39290, 1352, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39291, 1352, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39292, 1356, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39293, 1356, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39294, 1356, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39301, 1646, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39302, 1646, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39303, 1646, 55, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (39304, 1676, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39305, 1676, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39306, 1853, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39307, 1853, 37, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39308, 1853, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39309, 1963, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39310, 1963, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39311, 1963, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39312, 1963, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39313, 1963, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39314, 1972, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39315, 1972, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39316, 1972, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39317, 1977, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39318, 1977, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39319, 2100, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39320, 2100, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39321, 2100, 30, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (39322, 2151, 114, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (39323, 2151, 7, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (39327, 2192, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39328, 2192, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39329, 2192, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39330, 2271, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39331, 2271, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39332, 2271, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39334, 2450, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39335, 2450, 43, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (39336, 2450, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39342, 8577, 273, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39343, 8577, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39344, 8577, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39345, 8577, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39346, 10158, 154, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39347, 10158, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (39185, 19244, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39186, 19244, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39348, 20079, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39349, 20079, 43, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (39251, 875, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39252, 875, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39253, 875, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39254, 875, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39341, 2660, 86, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (39194, 13500, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39195, 13500, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39196, 13500, 9, 35, 2);
INSERT INTO 'dancesformationsmap' VALUES (39197, 13500, 105, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (39241, 742, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39242, 742, 32, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (39243, 742, 365, 69, 1);
INSERT INTO 'dancesformationsmap' VALUES (39244, 742, 38, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (39245, 742, 143, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (39187, 14122, 313, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39198, 13470, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39199, 13470, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39200, 13470, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39337, 2640, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39338, 2640, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39339, 2640, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39295, 1385, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39296, 1385, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39297, 1385, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39333, 2348, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14523, 170, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39188, 14122, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39189, 14122, 114, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39357, 2965, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39358, 2965, 7, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39359, 2965, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39360, 2965, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39361, 3006, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39362, 3006, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39363, 3006, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39364, 3006, 23, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39365, 3042, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39366, 3042, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39367, 3042, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39368, 3042, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39373, 3253, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39377, 13367, 86, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39378, 13367, 8, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (39379, 13367, 286, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (39380, 13758, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39381, 13758, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39382, 13758, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39383, 13758, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39384, 13383, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39385, 13383, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39386, 13383, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39387, 3564, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39388, 3564, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39389, 3574, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (39390, 3574, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39391, 3574, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39392, 3667, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39393, 3667, 314, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39394, 3667, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39395, 3669, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39396, 3669, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39397, 3669, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39398, 3669, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39399, 3785, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39400, 3785, 332, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39401, 3785, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39402, 3785, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39403, 3797, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39404, 3797, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39405, 3812, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39406, 3812, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39407, 3812, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39408, 3812, 33, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39409, 3812, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39410, 3812, 52, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (39411, 3812, 87, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (39412, 3812, 328, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (39413, 3812, 69, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (39414, 3812, 72, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (39415, 3889, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39416, 3889, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39417, 3889, 66, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39418, 3898, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (39419, 3898, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39420, 3898, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39421, 3898, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39422, 3925, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39423, 3925, 143, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39424, 3925, 72, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (39425, 3937, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39426, 3997, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39427, 3997, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39428, 3997, 112, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (39429, 13863, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39430, 13863, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39431, 13863, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39435, 15310, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39436, 15310, 23, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (39437, 15310, 296, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39438, 15310, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (39439, 15310, 39, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (39440, 15310, 17, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39441, 15311, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39442, 15311, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39443, 15311, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39444, 15311, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11602, 9699, 56, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (11603, 9699, 120, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (11604, 9699, 121, 61, 1);
INSERT INTO 'dancesformationsmap' VALUES (39445, 9699, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39446, 3510, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39495, 4840, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39496, 4840, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39497, 4840, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39374, 3366, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39375, 3366, 42, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (39376, 3366, 119, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (39450, 14578, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39451, 14578, 10, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (39452, 14578, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39453, 14578, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39454, 4017, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39455, 4017, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39456, 4017, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39457, 4042, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (39458, 4042, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39459, 4042, 41, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39460, 4042, 43, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (39461, 4042, 23, 113, 1);
INSERT INTO 'dancesformationsmap' VALUES (39462, 4082, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39463, 4082, 119, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (39464, 4082, 114, 14, 2);
INSERT INTO 'dancesformationsmap' VALUES (39465, 4082, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39466, 4082, 175, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39467, 4193, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39468, 4193, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39469, 4193, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39470, 4204, 96, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (39471, 4204, 355, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39472, 4204, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39479, 4417, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39480, 4417, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39481, 4417, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (39482, 4417, 17, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39483, 4417, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (39484, 4473, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39485, 4473, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39486, 4473, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39490, 4634, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39491, 4634, 23, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (39492, 4785, 81, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39493, 4785, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39494, 4785, 318, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39502, 4903, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39503, 4903, 1, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (39504, 4947, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39505, 4947, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39506, 4947, 114, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39507, 4947, 186, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39508, 4983, 365, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39509, 4983, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39510, 4983, 17, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (39511, 4983, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39512, 7637, 30, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39513, 7637, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39514, 7637, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39515, 7637, 7, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (39516, 7637, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39517, 7637, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39518, 19137, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39519, 19137, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39520, 19137, 305, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (39521, 19137, 38, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (39522, 18574, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39523, 18574, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39524, 18574, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39525, 18574, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39526, 17732, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39527, 17732, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39528, 17732, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39529, 17732, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39530, 17223, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39531, 17223, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39532, 17223, 145, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39369, 3115, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39370, 3115, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39371, 3115, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39353, 20079, 23, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (39354, 20079, 42, 53, 1);
INSERT INTO 'dancesformationsmap' VALUES (39355, 20079, 119, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (39356, 20079, 27, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (39498, 4878, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39499, 4878, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39500, 4878, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39533, 17223, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39534, 5035, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39535, 5035, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39536, 5035, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39537, 5070, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39487, 4559, 33, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39473, 4371, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39474, 4371, 119, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39475, 4371, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39488, 4571, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39489, 4571, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39538, 5070, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39539, 5070, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39540, 5082, 12, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39541, 5082, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39542, 5082, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39543, 5098, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39544, 5098, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39545, 5098, 7, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (39546, 5098, 114, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39547, 5129, 381, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39548, 5129, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39549, 5129, 145, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39550, 5129, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39551, 5129, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39552, 5139, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39553, 5139, 9, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (39554, 5139, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39555, 5139, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39556, 5139, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39557, 5139, 183, 43, 1);
INSERT INTO 'dancesformationsmap' VALUES (39558, 5181, 314, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (39559, 5181, 114, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39560, 5181, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39561, 5191, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39562, 5191, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39563, 5191, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39564, 5191, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39565, 5224, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39566, 5224, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39567, 5224, 120, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39568, 5224, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39569, 5238, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39570, 5238, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39571, 5238, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39572, 5264, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39573, 5264, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39574, 5264, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39575, 5264, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39580, 5302, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39581, 5302, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39582, 5302, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39583, 5302, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39584, 5327, 121, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39585, 5327, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39586, 5327, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39587, 5371, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39588, 5371, 43, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (39589, 5371, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39590, 5371, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39591, 5388, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39592, 5388, 120, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39593, 5388, 121, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39594, 5388, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39595, 5390, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (39596, 5390, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39597, 5390, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39598, 5409, 183, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (39206, 20077, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39207, 20077, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39599, 5448, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39600, 5448, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39601, 5448, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39602, 5448, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39603, 5516, 96, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (39604, 5516, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39605, 5516, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39606, 5516, 71, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39607, 5516, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (39611, 5630, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39612, 5630, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39613, 5630, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39614, 5650, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39615, 5650, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39616, 5650, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39620, 5902, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39621, 5902, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39627, 6085, 181, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39628, 6085, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39629, 6085, 54, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39630, 6085, 297, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (39631, 6085, 32, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (39632, 6085, 183, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (39633, 6085, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (39634, 6101, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39635, 6101, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39636, 6101, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39637, 6101, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39638, 6168, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39639, 6168, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39640, 6168, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39641, 6168, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39642, 6217, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39643, 6217, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39644, 6217, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39645, 6249, 13, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39646, 6252, 273, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39647, 6252, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39648, 6306, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39649, 6306, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39650, 6306, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39652, 6354, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (39653, 6354, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39654, 6354, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39655, 6354, 221, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39656, 6417, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39657, 6540, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39658, 6540, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39659, 6540, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39660, 6540, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39661, 6656, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39662, 6656, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39663, 6656, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39664, 6656, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (39665, 6713, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39666, 6713, 9, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (39667, 6713, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39668, 6713, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39669, 6713, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39670, 6785, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39671, 6785, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39672, 6933, 265, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39673, 6933, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39674, 6933, 38, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (39680, 6991, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39681, 6991, 7, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39682, 6991, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39683, 7034, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39684, 7034, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39685, 7036, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39686, 7036, 359, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39687, 7036, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39688, 7036, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39689, 7036, 314, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39690, 7112, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39691, 7112, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39692, 7112, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39693, 7112, 330, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39694, 7112, 176, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39695, 7112, 328, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (39696, 7112, 183, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (39697, 7113, 134, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (39698, 7113, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39699, 7113, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39700, 20081, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39701, 20081, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39702, 20081, 260, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39703, 20081, 154, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (39704, 7273, 168, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (39705, 7273, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39706, 7273, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39707, 7474, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39708, 7474, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39709, 7474, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39712, 7656, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39622, 6066, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39623, 6066, 165, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39675, 6939, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39676, 6939, 120, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39677, 6939, 175, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39678, 6939, 122, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39679, 6939, 121, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39576, 5265, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39577, 5265, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39578, 5265, 51, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39579, 5265, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39651, 6318, 314, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (39619, 5823, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39617, 5818, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39618, 5818, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39608, 5605, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39609, 5605, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39610, 5605, 214, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (39447, 20080, 315, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39448, 20080, 209, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39449, 20080, 216, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39713, 7656, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39714, 7656, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39715, 7656, 269, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39716, 7687, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39717, 7687, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39718, 7714, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39719, 7714, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39720, 7714, 24, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39721, 7714, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39723, 7790, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39724, 7790, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39725, 7790, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39726, 7790, 19, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39727, 7793, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39728, 7793, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39729, 7793, 312, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39730, 7793, 96, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (39731, 7873, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39732, 7873, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39733, 7873, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39734, 7892, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39735, 7892, 203, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39736, 7892, 7, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (39739, 7950, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39740, 7950, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39741, 7994, 61, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39742, 7994, 5, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (39743, 7994, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39744, 18072, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39745, 18072, 38, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39746, 18072, 10, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39747, 18072, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39748, 18072, 23, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (39749, 8037, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39750, 8037, 23, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (39751, 8037, 183, 19, 4);
INSERT INTO 'dancesformationsmap' VALUES (39752, 8118, 265, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39753, 8118, 114, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39754, 8118, 134, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39755, 8118, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39761, 8127, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39762, 8127, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39763, 8127, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39764, 8127, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39767, 8131, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39768, 8131, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39769, 8131, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39775, 8202, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39776, 8202, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39777, 8247, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39778, 8247, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39779, 8247, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39780, 8247, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39781, 8330, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39782, 8330, 36, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39783, 8330, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39784, 8330, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39785, 8339, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39786, 8339, 314, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39787, 8339, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39788, 8363, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39789, 8363, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39790, 8494, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39791, 8494, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39792, 8494, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39793, 8496, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39794, 8496, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39795, 8496, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39796, 8529, 145, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39797, 8529, 303, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39798, 8529, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39799, 8529, 265, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39800, 8539, 9, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39801, 8539, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39802, 8573, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39803, 8573, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39804, 8573, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39805, 8573, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39806, 8607, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39807, 8607, 162, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39808, 8688, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39809, 8688, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39810, 8688, 296, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (39811, 8688, 43, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (39812, 8688, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (39816, 8924, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (39817, 8924, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39818, 8924, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39819, 8924, 119, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (39820, 8924, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (39824, 8931, 202, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39825, 8931, 185, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39826, 8931, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39827, 8931, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (39828, 8936, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39829, 8936, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (39830, 8936, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39831, 8938, 18, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39832, 8938, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39833, 8938, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39834, 8940, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39835, 8940, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39836, 8955, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39837, 8955, 86, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (39838, 8955, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21580, 13732, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39839, 9, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39840, 9, 268, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39841, 9, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39842, 32, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39843, 32, 318, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39844, 83, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (39845, 83, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39847, 109, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39848, 9012, 265, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (39849, 9012, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39853, 9023, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39854, 9023, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39855, 9023, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39856, 9024, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39857, 9024, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39858, 9024, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39859, 9069, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39860, 9069, 110, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39861, 9069, 120, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39862, 9071, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39863, 9071, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39864, 9141, 269, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39865, 9141, 314, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (39866, 9141, 119, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (39867, 9190, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39868, 9190, 134, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39869, 9190, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39870, 9190, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39871, 9203, 43, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (39872, 9203, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39873, 9217, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39874, 9217, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39875, 9217, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39876, 9217, 53, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39877, 9221, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39878, 9221, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39879, 9221, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39880, 9229, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39881, 9229, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39882, 9240, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39883, 9240, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39884, 9240, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39885, 9290, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39886, 9290, 154, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39887, 9290, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39888, 9290, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39891, 9297, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39892, 9297, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39893, 9297, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39756, 8123, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39765, 8129, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39766, 8129, 15, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (39850, 9016, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39851, 9016, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39852, 9016, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39894, 9423, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39895, 9423, 181, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39896, 9423, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (39813, 8850, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39814, 8850, 202, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39889, 9294, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39890, 9294, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39815, 8850, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39846, 89, 330, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (39900, 9458, 53, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39901, 9458, 43, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (39902, 9460, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39903, 9460, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (39904, 9460, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39905, 9461, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39906, 9461, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39913, 9609, 81, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39914, 9609, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39915, 9609, 23, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (39916, 9609, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39917, 9637, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39918, 9637, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39919, 9637, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39920, 9639, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39821, 8926, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39822, 8926, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39770, 8162, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39771, 8162, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39823, 8926, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39921, 9639, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39922, 9639, 234, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39923, 9639, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39924, 9642, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39925, 9642, 318, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39926, 9642, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39927, 9643, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39928, 9643, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39929, 9643, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39930, 9649, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39931, 9649, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39932, 9649, 96, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39933, 9649, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39934, 9649, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39935, 9650, 39, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39936, 9650, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39937, 9650, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39938, 9651, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39939, 9651, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39940, 9651, 58, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39941, 9651, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39942, 9652, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39943, 9652, 7, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (39944, 9657, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39945, 9657, 330, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39946, 9657, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39947, 9659, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39948, 9659, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (10335, 9680, 72, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (39952, 9680, 43, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (39953, 9680, 149, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (39954, 9680, 38, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (39955, 9653, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (39956, 9653, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39957, 9654, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39958, 9654, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39959, 9654, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39960, 9655, 221, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39961, 9655, 112, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (39962, 9655, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39963, 9655, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39964, 9655, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39968, 9779, 314, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (39969, 9936, 359, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39970, 9936, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39971, 9936, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39972, 9943, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39987, 7486, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39988, 7486, 112, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39989, 7486, 120, 41, 4);
INSERT INTO 'dancesformationsmap' VALUES (39990, 7486, 87, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (39991, 7486, 121, 57, 4);
INSERT INTO 'dancesformationsmap' VALUES (39993, 10150, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39994, 10150, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39995, 10150, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39996, 10155, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (39997, 10155, 15, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (39998, 10155, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39999, 10155, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40000, 10162, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40001, 10162, 43, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (40002, 10162, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40003, 10162, 154, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (40004, 10162, 29, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (40005, 10162, 90, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (40006, 10162, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (40007, 10165, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40008, 10165, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40009, 10165, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40010, 10165, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40014, 10171, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40015, 10171, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40019, 10174, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40020, 10174, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40021, 10174, 157, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40022, 10174, 43, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40023, 10174, 90, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (40024, 10174, 149, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (40025, 10174, 117, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (40026, 10174, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (40027, 10175, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40028, 10175, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40029, 10175, 27, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (40030, 10175, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40034, 10179, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40035, 10179, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40036, 10179, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (40037, 10183, 87, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40038, 10183, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40039, 10183, 220, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40040, 10183, 183, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (40041, 10183, 9, 51, 2);
INSERT INTO 'dancesformationsmap' VALUES (40042, 10183, 157, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (40043, 10183, 193, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (40044, 10184, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40045, 10184, 183, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (40046, 10184, 23, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (40047, 10184, 117, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (40048, 10184, 90, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (40049, 10185, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40050, 10185, 114, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40051, 10185, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40052, 10185, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40053, 10194, 365, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40054, 10194, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40055, 10194, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40056, 10434, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40057, 10434, 114, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40058, 10434, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40059, 10434, 314, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40060, 10434, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40061, 10577, 314, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (40062, 10577, 86, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (40063, 10605, 23, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (40064, 10605, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40065, 10641, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40066, 10641, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40067, 10689, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40068, 10689, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40069, 10689, 132, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (40070, 10689, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40071, 10689, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40072, 10699, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40073, 10699, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40074, 10699, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40075, 10699, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40079, 1765, 112, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39965, 9656, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39966, 9656, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39912, 9535, 183, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (39907, 9472, 149, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39908, 9472, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (40076, 10802, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (40077, 10802, 23, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (40078, 10802, 318, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39897, 9423, 157, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39898, 9423, 124, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (39899, 9423, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (40081, 10707, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40082, 10707, 132, 4, 3);
INSERT INTO 'dancesformationsmap' VALUES (40083, 10707, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40084, 10708, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40085, 10708, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40086, 10708, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40087, 10708, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40088, 10713, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40089, 10713, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40090, 10713, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40091, 10713, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40092, 10713, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40093, 10740, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40094, 10740, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40095, 10740, 303, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40096, 10740, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40097, 10740, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40098, 10754, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40099, 10754, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40100, 10754, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40031, 10178, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39992, 7542, 87, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40032, 10178, 114, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40033, 10178, 308, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40016, 10172, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40017, 10172, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40018, 10172, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39949, 9660, 176, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39950, 9660, 157, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (39951, 9660, 17, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40011, 10169, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40012, 10169, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (40013, 10169, 145, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39973, 3649, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39974, 3649, 89, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39975, 3649, 365, 43, 1);
INSERT INTO 'dancesformationsmap' VALUES (39976, 3649, 27, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (40101, 10754, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40102, 10756, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40103, 10756, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40104, 10756, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40105, 10756, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40106, 10757, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40107, 10757, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40108, 10757, 7, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (40109, 10758, 234, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (40110, 10758, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40111, 10758, 96, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (40112, 10758, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40113, 10758, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40114, 10762, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40115, 10762, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40116, 10763, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40117, 10763, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40118, 10763, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40119, 10765, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40120, 10765, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40121, 10765, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40122, 10765, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40123, 10765, 372, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40124, 10767, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40125, 10767, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40126, 10767, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40127, 10767, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40130, 19978, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40131, 19978, 45, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40132, 19978, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40135, 10832, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40136, 10832, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40137, 10832, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40138, 10832, 114, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40139, 10834, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40140, 10834, 134, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40141, 10834, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40144, 10863, 217, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40145, 10865, 216, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40146, 10865, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40147, 10865, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40221, 12323, 103, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40222, 12323, 92, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (40223, 12323, 227, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8144, 4354, 43, 35, 4);
INSERT INTO 'dancesformationsmap' VALUES (8145, 4354, 38, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (40128, 4354, 32, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (40129, 4354, 157, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (40151, 10994, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40152, 10994, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40153, 10994, 7, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (40154, 11001, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40155, 11001, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40156, 11001, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40157, 11001, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39710, 7487, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39711, 7487, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40158, 11014, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40159, 11014, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40160, 11014, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40161, 11014, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40162, 11017, 29, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (40163, 11017, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40164, 11025, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40165, 11025, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40166, 11025, 87, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40167, 11025, 43, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (40168, 11025, 93, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (40169, 11091, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40170, 11091, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40171, 11197, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40172, 11197, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40173, 11198, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40174, 11198, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40175, 11198, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40176, 11198, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40177, 11200, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40178, 11200, 7, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (40179, 11200, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40180, 11201, 56, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (40181, 11201, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40182, 11201, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40183, 11201, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40184, 11202, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (40185, 11202, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40190, 11224, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40191, 11224, 114, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40192, 11224, 158, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40193, 11227, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40194, 11227, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40195, 11227, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40196, 11227, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40197, 11300, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40198, 11300, 183, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (40199, 11300, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40200, 11316, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40201, 11316, 117, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40202, 11316, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40203, 11316, 56, 35, 2);
INSERT INTO 'dancesformationsmap' VALUES (40204, 11316, 90, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (40205, 11419, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40206, 11419, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40207, 11419, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40208, 11773, 314, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40209, 11773, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40210, 12086, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40211, 12086, 365, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (40212, 12086, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40215, 12281, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40216, 12281, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40217, 12281, 114, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40218, 12296, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40219, 12296, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40220, 12296, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40228, 12619, 234, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (40229, 12619, 96, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (40230, 12718, 359, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40231, 12718, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40232, 12718, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40233, 12718, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40234, 12802, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40235, 12802, 114, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40236, 12802, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40237, 12802, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40242, 12829, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40243, 12829, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40244, 12829, 314, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40245, 12830, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40246, 12853, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40247, 12853, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17141, 12021, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40250, 13123, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40251, 13123, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40252, 13123, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40253, 13123, 72, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (40254, 13123, 111, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (40255, 13124, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40256, 13124, 9, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40248, 12901, 268, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40149, 10977, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40249, 12901, 73, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40186, 11204, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40187, 11204, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40188, 11204, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40150, 10977, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25333, 15768, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40257, 13124, 84, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40258, 13125, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40259, 13125, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40260, 13125, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40261, 13125, 23, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (40262, 13125, 154, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39722, 7748, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30640, 17949, 249, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (40263, 12196, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40264, 12196, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (34484, 18503, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40269, 13130, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40270, 13130, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40271, 13130, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40272, 13130, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40273, 13131, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40274, 13131, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40275, 13131, 29, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (40276, 13131, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40277, 13136, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40278, 13136, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40279, 13136, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40133, 10269, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (40134, 10269, 30, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (40224, 12396, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40225, 12396, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40226, 12396, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40227, 12396, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40265, 7890, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40266, 7890, 234, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (40267, 7890, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40148, 10880, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40142, 10860, 296, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40143, 10860, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40280, 13137, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40281, 13137, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40282, 13137, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40287, 13212, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40288, 13212, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40289, 13212, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40290, 13212, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40291, 13212, 114, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40292, 13215, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40293, 13215, 38, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (40294, 13216, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40295, 13260, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40296, 13260, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40297, 13152, 119, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (40298, 13317, 269, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40299, 13317, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40300, 13391, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40301, 13391, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40302, 13391, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40303, 13391, 70, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40304, 13393, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40305, 13393, 263, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40306, 13394, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40307, 13394, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40308, 13394, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40309, 13444, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40310, 13444, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40311, 13444, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40312, 13453, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40313, 13453, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40314, 13453, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40315, 13453, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40316, 13455, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40317, 13456, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40318, 13456, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40319, 13456, 120, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40320, 13456, 121, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40321, 13456, 234, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40322, 13456, 81, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (40323, 13456, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (40324, 13460, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40325, 13460, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40326, 13463, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40327, 13463, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40331, 11759, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40332, 13465, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40333, 13465, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40334, 13465, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40335, 13467, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40339, 13469, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40340, 13469, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40341, 13471, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40342, 13471, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40343, 13472, 143, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40344, 13472, 1, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (40345, 13472, 69, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (40346, 13472, 157, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (40347, 13472, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (40348, 13497, 114, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40349, 13497, 279, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40350, 13497, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (40351, 13497, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40352, 13502, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40353, 13502, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40354, 13502, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40355, 13502, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40356, 13508, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40357, 13508, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40358, 13508, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40359, 13511, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40360, 13511, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40362, 13523, 4, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40363, 13523, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40364, 13523, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40365, 13523, 251, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40366, 13528, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40367, 13528, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40368, 13528, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40369, 13538, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40370, 13538, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40371, 13538, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40372, 13538, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40373, 13538, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40374, 13553, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40375, 13553, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40376, 13556, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40377, 13556, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40378, 13556, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40379, 13556, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40396, 13560, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40397, 13560, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40398, 13560, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40399, 13560, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40400, 13584, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40401, 13584, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40283, 13139, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40284, 13139, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40285, 13139, 92, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40389, 10409, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40390, 10409, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (40391, 10409, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40392, 10409, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (40383, 10407, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35794, 19411, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2066, 3912, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40393, 3912, 308, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40394, 3912, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40395, 3912, 125, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (40402, 13584, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40403, 13625, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40404, 13625, 114, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40405, 13625, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40406, 13693, 7, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40407, 13693, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40408, 13693, 261, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40409, 13693, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40410, 13693, 188, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (40411, 13693, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40412, 13696, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40413, 13696, 183, 11, 3);
INSERT INTO 'dancesformationsmap' VALUES (40414, 13697, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40415, 13697, 1, 11, 3);
INSERT INTO 'dancesformationsmap' VALUES (40416, 13697, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40417, 13697, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40418, 13697, 93, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (40419, 13698, 183, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (40420, 13698, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40421, 13698, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40422, 13698, 143, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40423, 13719, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40424, 13719, 222, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (40425, 13719, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40426, 13720, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40427, 13720, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40428, 13720, 154, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40429, 13720, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40430, 13720, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40431, 13721, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40432, 13721, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40433, 13721, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40434, 13722, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40435, 13722, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40361, 13517, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (40380, 20082, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40381, 20082, 13, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40382, 20082, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40286, 13139, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40436, 13722, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40441, 13725, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40442, 13725, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40443, 13728, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40444, 13728, 157, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40445, 13728, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40446, 13743, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40447, 13743, 109, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40448, 13743, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40450, 13745, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40451, 13745, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40452, 13745, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40453, 13746, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40454, 13746, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40455, 13746, 114, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40456, 13748, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40457, 13748, 119, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (40458, 13749, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40459, 13749, 12, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40460, 13749, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40461, 13749, 260, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40462, 13750, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40463, 13750, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40464, 13750, 23, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (40469, 13753, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40470, 13753, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40471, 13753, 39, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40472, 13753, 260, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40473, 13753, 254, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40476, 13761, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40336, 13468, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40337, 13468, 131, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40328, 5220, 164, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40329, 5220, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (40330, 5220, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40477, 13761, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40478, 13761, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40479, 13761, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40480, 13763, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40481, 13763, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40482, 13763, 154, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40483, 13763, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40484, 13764, 51, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40485, 13764, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40486, 13765, 359, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40487, 13765, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40488, 13765, 168, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40493, 13767, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40494, 13767, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40498, 13773, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40499, 13773, 16, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40500, 13773, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (39372, 3115, 114, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40501, 13781, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40502, 13781, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (40503, 13781, 260, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40504, 13781, 82, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (40505, 13785, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40506, 13785, 58, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40507, 13785, 93, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40508, 13785, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40509, 13804, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40510, 13804, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40511, 13823, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40512, 13823, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40513, 13823, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40514, 13835, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40515, 13835, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40516, 13835, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40517, 13835, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40518, 13835, 96, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40519, 13841, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40520, 13841, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (40521, 13849, 176, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40522, 13849, 157, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40523, 13849, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40524, 13849, 38, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38025, 19858, 65, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40577, 13910, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40578, 13910, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40579, 13910, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40580, 13910, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40581, 13924, 12, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40582, 13924, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40583, 13930, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40584, 13930, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40585, 13930, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40537, 13860, 183, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (40538, 13860, 83, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40539, 13860, 273, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40540, 13860, 340, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (40541, 3010, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40542, 3010, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40532, 20083, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40533, 20083, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40534, 20083, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40535, 20083, 214, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (40550, 13861, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40551, 13861, 229, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40552, 13861, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (40553, 13861, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40554, 13864, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40555, 13864, 222, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40556, 13864, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (40557, 13864, 23, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (40558, 13864, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40559, 13864, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40560, 13864, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40561, 13866, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40562, 13866, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40563, 13866, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40564, 13866, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40568, 13886, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40569, 13886, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40570, 13886, 49, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40571, 13886, 69, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (40572, 13887, 42, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (40573, 13887, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40590, 13942, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40591, 13942, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40592, 13942, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40593, 13942, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40594, 13942, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40595, 13942, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40596, 14001, 13, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40597, 14001, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40598, 14001, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40599, 14001, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40600, 14009, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40601, 14009, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (40602, 14009, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40603, 14009, 249, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (40608, 14023, 119, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40609, 14023, 58, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (40610, 14023, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40611, 14024, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40612, 14024, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40613, 14024, 355, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40614, 14024, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40617, 14043, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40618, 14043, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40437, 13723, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40438, 13723, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (40439, 13723, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40440, 13723, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40465, 13751, 13, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40466, 13751, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40604, 14021, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40605, 14021, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40606, 14021, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40607, 14021, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40615, 14038, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40616, 14038, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40565, 13867, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40566, 13867, 56, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40567, 13867, 256, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40449, 13744, 260, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40474, 13760, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40475, 13760, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40574, 13892, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40575, 13892, 234, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (40576, 13892, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40619, 14043, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40620, 14043, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40777, 20089, 121, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40621, 14075, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40622, 14075, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40623, 14086, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (40624, 14086, 23, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (40625, 14086, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40626, 14102, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40627, 14103, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40628, 14103, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40629, 14103, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40630, 14117, 314, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (40631, 14117, 119, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40632, 14117, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40633, 14136, 152, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40634, 14136, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40635, 14137, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40636, 14137, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40637, 14137, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40638, 14137, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40639, 14137, 340, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40640, 14138, 119, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40641, 14138, 56, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (40642, 14138, 93, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40643, 14138, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40644, 14138, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40645, 14139, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40646, 14139, 101, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40647, 14139, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40648, 14141, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40649, 14141, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40653, 14232, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40654, 14232, 119, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (40655, 14234, 120, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40656, 14234, 121, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40657, 14234, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40650, 14161, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40586, 13933, 9, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (40587, 13933, 164, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40588, 13933, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40529, 13859, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40530, 13859, 75, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40531, 13859, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40495, 13772, 365, 6, 2);
INSERT INTO 'dancesformationsmap' VALUES (40496, 13772, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40497, 13772, 238, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (40525, 13852, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40526, 13852, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40527, 13852, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40528, 13852, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40651, 14161, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40652, 14161, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40658, 14234, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40659, 14234, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40660, 14235, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40661, 14235, 222, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40662, 14235, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40663, 14235, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40664, 14238, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40665, 14238, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40666, 14238, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40667, 14072, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40668, 14072, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40669, 14072, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40670, 14072, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40671, 14242, 165, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40672, 14242, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40673, 14270, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40674, 14270, 278, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40675, 14270, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40676, 14270, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40677, 14270, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40678, 14274, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (40679, 14274, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40680, 14274, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40681, 14274, 154, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40682, 14274, 278, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40683, 14276, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40684, 14276, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40685, 14276, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40686, 14276, 185, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40687, 14276, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40688, 14276, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (40689, 386, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40690, 386, 145, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40691, 386, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40692, 386, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14884, 11437, 127, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14885, 11437, 1, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (40693, 1256, 183, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (40694, 1256, 43, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (40695, 1256, 39, 21, 4);
INSERT INTO 'dancesformationsmap' VALUES (40696, 1256, 149, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (40697, 1256, 90, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (40698, 14293, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40699, 14293, 202, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40700, 14293, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40701, 14294, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40702, 14294, 294, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40703, 14294, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40704, 14294, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40705, 14318, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40706, 14318, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40707, 14318, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40708, 14371, 69, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40709, 14371, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40710, 14371, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40711, 1354, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40712, 1354, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40713, 1354, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40714, 1354, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40715, 1354, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40716, 1354, 120, 40, 1);
INSERT INTO 'dancesformationsmap' VALUES (40717, 1354, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (40718, 14374, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40719, 14374, 43, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (40720, 14374, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40721, 14376, 92, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40722, 14376, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40723, 14376, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40724, 14376, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40725, 14414, 62, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40726, 14414, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40727, 14414, 85, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40728, 3013, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40729, 3013, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40730, 3013, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40731, 3013, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40732, 19867, 112, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40733, 19867, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (40734, 19867, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40735, 19867, 42, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (40736, 19867, 123, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40740, 2579, 81, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40741, 2579, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40742, 2579, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40743, 14422, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40744, 14422, 176, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40745, 14422, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40746, 14422, 157, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (40749, 14460, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (40750, 14460, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40751, 14466, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40752, 14466, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40753, 14466, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40754, 14466, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40755, 14476, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40756, 14476, 93, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (40757, 14476, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40758, 14476, 183, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40759, 20086, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40760, 20086, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40761, 20086, 77, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40762, 14479, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40763, 14479, 261, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (40764, 14479, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40765, 14480, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40766, 14480, 157, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40767, 14480, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40768, 14480, 39, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40769, 14480, 330, 39, 1);
INSERT INTO 'dancesformationsmap' VALUES (40770, 13289, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40771, 13289, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (40772, 13289, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40773, 13289, 125, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (35137, 13292, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33438, 13296, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40747, 14442, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40748, 14442, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40785, 20091, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40786, 20091, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40787, 20091, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40784, 1283, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40789, 20092, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40790, 20092, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40791, 20092, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40793, 20093, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40794, 20093, 145, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40795, 20093, 56, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (40796, 20093, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40797, 20094, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40798, 20094, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40799, 20094, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12586, 10408, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40778, 20089, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40779, 20089, 117, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40780, 20090, 321, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40781, 20090, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (40782, 20090, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40823, 14496, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40824, 14496, 75, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40825, 14496, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40826, 14496, 92, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40827, 14496, 61, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (40828, 14497, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40829, 14497, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (40830, 14497, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40831, 14497, 5, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40838, 14547, 315, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40839, 14547, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40840, 14547, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40841, 14556, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40842, 14556, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40843, 14556, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40844, 14563, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40845, 14563, 96, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (40846, 14563, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40847, 14563, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40848, 14589, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40849, 14589, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40850, 14589, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (40851, 14589, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40852, 14590, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40853, 14590, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40854, 14590, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40855, 14590, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40856, 14785, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40857, 14785, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40858, 280, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40859, 280, 263, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (40862, 14666, 83, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40863, 14666, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40864, 14668, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40865, 14668, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40866, 14668, 332, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40867, 14669, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40868, 14669, 96, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (40869, 14669, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40870, 14670, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40871, 14670, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40872, 14670, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40873, 14671, 102, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40874, 14676, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40875, 14676, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40876, 14676, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40877, 14676, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40878, 14748, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40879, 14748, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40880, 14748, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40881, 14748, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40882, 14798, 183, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (40883, 14798, 39, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40884, 14798, 38, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (40885, 14798, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40886, 14798, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40887, 14814, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40888, 14814, 359, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40889, 14814, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40890, 14814, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40891, 14828, 127, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40892, 14828, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40893, 14828, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40894, 14904, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40895, 14904, 134, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40896, 14904, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40897, 14904, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40898, 14904, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40899, 14904, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40900, 14946, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40901, 14946, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40902, 14946, 143, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40903, 14946, 7, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (40904, 14946, 149, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (40905, 14946, 328, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (40906, 14947, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40907, 14947, 165, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40908, 14947, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40909, 14947, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40928, 14954, 72, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (40929, 14954, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40930, 14954, 157, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (40931, 14954, 32, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40932, 14954, 23, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (40933, 14965, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40934, 14965, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (334, 597, 234, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (40910, 597, 96, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (40911, 597, 365, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (40917, 14948, 23, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (40918, 14948, 183, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (40919, 14948, 43, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (219, 389, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40922, 389, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40923, 778, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40924, 14952, 157, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40925, 14952, 183, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (40926, 14952, 117, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40927, 14952, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (40935, 14965, 70, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40936, 14965, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40941, 14968, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40942, 14968, 82, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (40943, 14968, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40944, 14968, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40945, 14969, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40946, 14969, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (40947, 14969, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40948, 14969, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40949, 14969, 273, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40950, 14972, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40951, 14972, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40952, 14972, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40953, 18807, 72, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (40954, 18807, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (40955, 18807, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40956, 18807, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (40959, 20101, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (40960, 20102, 268, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40961, 20102, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40962, 20102, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40963, 20102, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40964, 20103, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40965, 20103, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40774, 20088, 96, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40775, 20088, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40776, 20088, 168, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40800, 20094, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40801, 20094, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40807, 20096, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40808, 20096, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40920, 14949, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40921, 14949, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40802, 20095, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40812, 20097, 1, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (40813, 20097, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40814, 20097, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40803, 20095, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40804, 20095, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40805, 20095, 92, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40815, 20098, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40816, 20098, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40817, 20098, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40818, 20098, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13645, 10791, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13646, 10791, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40832, 14545, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40833, 14545, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40834, 14545, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40835, 14545, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (40836, 14545, 28, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40543, 20084, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40544, 20084, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40545, 20084, 185, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40546, 20084, 202, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40547, 20084, 249, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (40548, 20084, 154, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40966, 20103, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40967, 20103, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40968, 20103, 27, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40971, 20105, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40972, 20105, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40973, 20105, 123, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40974, 20106, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40975, 20106, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40976, 20106, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40977, 20107, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40978, 20107, 42, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (40979, 20107, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (40980, 2992, 1, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (40981, 2992, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40982, 2073, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40986, 20108, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40987, 20108, 114, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (40988, 20109, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40989, 20109, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40990, 20109, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40991, 20109, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39350, 20079, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (39351, 20079, 263, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (39352, 20079, 154, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (40992, 20112, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40993, 20112, 328, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40994, 20112, 39, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40995, 20112, 1, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (40996, 20112, 67, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (40997, 20112, 43, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (41101, 15340, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41102, 15340, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41103, 15340, 185, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40998, 20114, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40999, 20114, 296, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41000, 20114, 43, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (41001, 20114, 1, 51, 1);
INSERT INTO 'dancesformationsmap' VALUES (33620, 19126, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33621, 19126, 354, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (33622, 19126, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33623, 19126, 110, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40969, 20104, 263, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40970, 20104, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41002, 20117, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41003, 20117, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41004, 20117, 314, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41005, 20117, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41006, 20118, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41007, 20118, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41008, 20118, 183, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41009, 20118, 145, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41010, 20118, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41011, 14950, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41012, 14950, 221, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41013, 20119, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41014, 20119, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41015, 20119, 302, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40788, 20091, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40792, 20092, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41020, 15030, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40912, 2550, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40913, 2550, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40957, 20100, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (40958, 20100, 185, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40914, 2550, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40937, 14967, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (40938, 14967, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40939, 14967, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40940, 14967, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41021, 15030, 2, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41022, 15030, 175, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41023, 15030, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41024, 15030, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41025, 15033, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41026, 15033, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41027, 15034, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41028, 15034, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41029, 15036, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41030, 15036, 183, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (41031, 15043, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41032, 15043, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41033, 15043, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41034, 15058, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41035, 15058, 24, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41036, 15058, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41037, 15058, 92, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (41038, 15064, 121, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41039, 15064, 81, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41040, 15068, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41041, 15068, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41042, 15068, 251, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40809, 20096, 56, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (40810, 20096, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40811, 20096, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41043, 15101, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41044, 15101, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41045, 15101, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41046, 15101, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41047, 2296, 188, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (41048, 2296, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41049, 2296, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41050, 15103, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (41051, 15103, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41052, 15103, 354, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41053, 15103, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41054, 15111, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (41055, 15111, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41056, 15111, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41057, 15111, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41058, 15111, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41063, 15290, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41064, 15290, 373, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (41065, 15290, 26, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41066, 15290, 143, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41067, 15290, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41068, 15290, 103, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (41069, 15290, 61, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (41070, 2522, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41071, 2522, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41072, 15304, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41073, 15304, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41074, 15304, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41075, 15304, 7, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (41076, 15306, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41077, 15306, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41078, 15306, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41079, 15316, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41080, 15316, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41081, 15316, 186, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41082, 15317, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41083, 15317, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41084, 15317, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41085, 15320, 2, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41086, 15320, 111, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41087, 15320, 156, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41088, 15320, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41089, 15320, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41090, 15327, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41091, 15327, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41092, 15327, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41093, 15327, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41094, 15334, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41095, 15334, 193, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41096, 15334, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41097, 15334, 53, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (41098, 15339, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41099, 15339, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41100, 15339, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41104, 15340, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41105, 15361, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41106, 15361, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41107, 15361, 252, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41108, 15362, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41109, 15362, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41110, 15362, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41111, 15362, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41117, 15366, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41118, 15366, 154, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (41119, 15366, 134, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41120, 15366, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41121, 15366, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41122, 2606, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41123, 2606, 119, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (41124, 2606, 29, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (41125, 2606, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (41126, 15367, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41127, 15367, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41128, 15367, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41129, 15367, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41130, 15368, 176, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41131, 15368, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41132, 15368, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41133, 15368, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41134, 15368, 90, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41135, 15368, 39, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (41059, 15124, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41060, 15124, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41139, 15370, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41140, 15370, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41141, 15370, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41142, 15370, 334, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41143, 15370, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41144, 15371, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41145, 15371, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41146, 15371, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41147, 15372, 81, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41148, 15372, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41149, 15372, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41150, 15373, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41151, 15373, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41152, 15373, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41153, 15373, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41154, 15408, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41155, 15408, 12, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41156, 15408, 183, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (41157, 15408, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41158, 15408, 7, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41159, 15409, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41160, 15409, 53, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41161, 15409, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41162, 15410, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41163, 15410, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41164, 15410, 216, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41169, 15578, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41170, 15578, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41171, 15578, 85, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (41172, 15578, 142, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (41173, 2907, 162, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41174, 2907, 224, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41175, 2907, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41176, 2907, 197, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (41177, 15582, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41178, 15582, 120, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41179, 15582, 121, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41180, 15582, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41181, 15582, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41182, 15588, 111, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41183, 15588, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41184, 15588, 20, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41185, 15588, 61, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41186, 15588, 221, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (41187, 2932, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41188, 5136, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41189, 5437, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (41283, 15648, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41284, 15648, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41285, 15648, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41286, 15648, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41192, 15429, 176, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (41193, 15429, 214, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (41194, 15429, 143, 41, 4);
INSERT INTO 'dancesformationsmap' VALUES (41195, 15591, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41196, 15591, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41197, 15591, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41198, 15591, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41199, 15591, 365, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41200, 15592, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41201, 15592, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41202, 15592, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41203, 15593, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41204, 15593, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41205, 15593, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41136, 15369, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41137, 15369, 114, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (41138, 15369, 294, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41016, 15025, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41017, 15025, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41018, 15025, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (41019, 15025, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41206, 15593, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41207, 3041, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41208, 3041, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41209, 3041, 288, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41213, 15595, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41214, 15595, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41215, 15595, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41216, 15596, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41217, 15596, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41218, 15596, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41226, 3146, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41227, 3146, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41230, 15607, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41231, 15610, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41232, 15610, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41233, 15610, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41234, 3183, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41235, 3183, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41236, 3183, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41237, 15611, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41238, 15611, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41239, 15611, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41240, 15611, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41241, 15612, 143, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41242, 15612, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41243, 15612, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41244, 15612, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41287, 4384, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41288, 15650, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41247, 15615, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41248, 15615, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41249, 15615, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41253, 15617, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41254, 15617, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41255, 15617, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41256, 15617, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41257, 15627, 183, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (41258, 15627, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41259, 15627, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41260, 3173, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (41261, 3173, 36, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (41289, 15650, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40819, 20098, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41312, 5243, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41313, 5243, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41265, 15639, 286, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41266, 15640, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41290, 15661, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41291, 15661, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41292, 15661, 123, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41262, 15636, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41263, 15636, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41264, 15636, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25475, 15829, 148, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25476, 15829, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (41267, 15641, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41268, 15641, 134, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41269, 15641, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41270, 15641, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41271, 15642, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41272, 15642, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (41273, 15642, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41274, 15642, 365, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (41275, 15643, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41276, 15643, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41277, 15643, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41278, 15644, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41279, 15644, 23, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (41280, 15644, 38, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (41281, 15647, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41282, 15647, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41293, 15661, 119, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41294, 15661, 168, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41295, 15661, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41296, 15663, 42, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (41297, 15663, 20, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41298, 15666, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41299, 15666, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41300, 15666, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41301, 15666, 217, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41302, 15666, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41303, 15667, 36, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41304, 15667, 23, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (41305, 15667, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41306, 15667, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41307, 2510, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41308, 2510, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4059, 583, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41309, 583, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41310, 424, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41311, 424, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5586, 5159, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39624, 6066, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39625, 6066, 17, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39626, 6066, 120, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41224, 20131, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41225, 20131, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41228, 15604, 7, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (41229, 15604, 157, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (41250, 15616, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41251, 15616, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41314, 11746, 183, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (31600, 12183, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (31601, 12183, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31604, 12183, 29, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (31605, 12183, 72, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (32314, 12369, 9, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (32315, 12369, 354, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41315, 12449, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (32506, 15301, 224, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (32326, 16566, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (32327, 16566, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32564, 18510, 324, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32565, 18510, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32566, 18510, 95, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (38345, 19958, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38346, 19958, 26, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (41316, 15690, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41317, 15690, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41318, 15690, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41319, 15695, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41320, 15695, 90, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41321, 15695, 23, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (41322, 15695, 56, 43, 1);
INSERT INTO 'dancesformationsmap' VALUES (41323, 15699, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41324, 15699, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41325, 15699, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41326, 15700, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41327, 15700, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41328, 15700, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41329, 15700, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41330, 15700, 30, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41331, 15700, 134, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (41332, 15891, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41333, 15891, 183, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (41334, 15891, 90, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41335, 15891, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (41336, 16069, 42, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (41337, 16069, 12, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (41338, 16069, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41339, 16069, 234, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (41340, 16070, 176, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41341, 16070, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41342, 16070, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (41343, 16070, 296, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41344, 16070, 157, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (41345, 16070, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (41346, 16158, 1, 4, 4);
INSERT INTO 'dancesformationsmap' VALUES (41347, 16158, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41348, 16158, 72, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (41349, 16158, 10, 35, 4);
INSERT INTO 'dancesformationsmap' VALUES (41350, 16158, 90, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (41351, 16158, 157, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (41190, 20121, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41191, 20121, 307, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (41352, 16215, 58, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41353, 16215, 39, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (41354, 16215, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41355, 16218, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41356, 16218, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41357, 16218, 157, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41358, 16218, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41359, 16219, 56, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41360, 16219, 83, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41361, 16219, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (29674, 17463, 43, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (41362, 16220, 149, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (41363, 16220, 276, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (41364, 16220, 143, 97, 4);
INSERT INTO 'dancesformationsmap' VALUES (41365, 16510, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (31324, 17470, 10, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31325, 17470, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31326, 17470, 93, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (41219, 15599, 296, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41220, 15599, 356, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41221, 15599, 56, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41165, 15574, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41166, 15574, 315, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41245, 15614, 278, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41246, 15614, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41366, 16510, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41367, 16558, 43, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (41368, 16558, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41369, 16558, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41370, 16625, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41371, 16625, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41372, 16625, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41373, 16625, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41379, 16663, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41380, 16663, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41381, 16663, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41382, 16700, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41383, 16700, 7, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41384, 16700, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41385, 16700, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41386, 16700, 12, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (41387, 16700, 183, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41388, 16700, 157, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (41389, 16700, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (41446, 16881, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41447, 16881, 96, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41448, 16881, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41449, 16883, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41390, 20120, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41391, 20120, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (41392, 20120, 154, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (41393, 20120, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (41394, 16762, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41395, 16762, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41396, 16762, 1, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (41397, 16763, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41398, 16763, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41399, 16763, 7, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (41400, 16763, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41401, 16767, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41402, 16767, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41403, 16767, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41404, 16768, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41405, 16768, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41406, 16768, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41407, 16768, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41408, 16770, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41409, 16770, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41410, 16770, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41411, 16770, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41412, 16777, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (41413, 16777, 265, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (41414, 16779, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41415, 16779, 119, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (41416, 16779, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41417, 16782, 56, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41418, 16782, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41419, 16784, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41420, 16784, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41421, 16784, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41422, 16784, 33, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (41423, 16784, 119, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (41424, 16784, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41425, 16784, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41426, 16830, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41427, 16830, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41428, 16830, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41429, 16831, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41430, 16831, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41431, 16831, 222, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41432, 16833, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41433, 16833, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41434, 16833, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41435, 16833, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41441, 16867, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41442, 16867, 183, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (41443, 16867, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41444, 16877, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41445, 16877, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41450, 16883, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41451, 16883, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41452, 16891, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41453, 16891, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41454, 16891, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41455, 16953, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41456, 16953, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41457, 16953, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41458, 16953, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41459, 16953, 101, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10643, 9170, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10644, 9170, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41461, 17026, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41462, 17026, 112, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41463, 17026, 176, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41464, 17027, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41465, 17027, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41466, 17048, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41467, 17048, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41468, 17048, 23, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (41469, 17048, 262, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41470, 17048, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41471, 17049, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41472, 17049, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (27848, 14601, 324, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41460, 5772, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41473, 17049, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41474, 17051, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41475, 17051, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41476, 17051, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41477, 17052, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41478, 17052, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41479, 17052, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41626, 20136, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (41627, 17218, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (41628, 17218, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41480, 17053, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41481, 17053, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41482, 17053, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41483, 17054, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41484, 17054, 318, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41485, 17054, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41486, 17072, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (41487, 17072, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41488, 17072, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41489, 17072, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41490, 17073, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41491, 17073, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41492, 17073, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41493, 17073, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41494, 17074, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41495, 17074, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41496, 17074, 262, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41497, 17074, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41498, 17076, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41499, 17076, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41500, 17076, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41501, 17076, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41502, 17076, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41503, 17091, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41504, 17091, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41505, 17091, 121, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41506, 17091, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (41507, 17125, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41508, 17125, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41509, 17125, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41510, 17125, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41511, 17126, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41512, 17126, 332, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41513, 17126, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41514, 17126, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41515, 17131, 30, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41516, 17131, 123, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41517, 17131, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41518, 17131, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22658, 14625, 277, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22659, 14625, 92, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (9141, 8729, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41521, 3602, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41522, 3602, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41523, 3596, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41524, 3596, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (41525, 3596, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41526, 3507, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41527, 3507, 120, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41528, 3371, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41529, 3371, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41530, 3324, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41531, 3324, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (41535, 1688, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41536, 1688, 72, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (41537, 1688, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41538, 1688, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41539, 2108, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41540, 2108, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41541, 2075, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41542, 2075, 71, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (41543, 2480, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41544, 2480, 81, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (41545, 2480, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41546, 2945, 221, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41374, 16626, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41375, 16626, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41376, 16626, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41377, 16626, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41378, 16626, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41547, 2945, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41548, 2945, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41549, 9293, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41550, 9293, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (41551, 9293, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (41552, 9293, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41553, 3012, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41554, 3012, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41555, 3012, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41556, 3012, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41557, 3012, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41558, 17084, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41559, 17084, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41560, 17084, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41561, 17084, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41562, 3096, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41563, 20133, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41564, 17134, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41565, 17134, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41566, 17134, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41567, 17136, 340, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41568, 17136, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (41569, 17140, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (41570, 17140, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41571, 17140, 30, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41572, 17140, 314, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41573, 17140, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (41577, 17146, 318, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41591, 5391, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41592, 5391, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41593, 5391, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41597, 17175, 78, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41598, 17175, 96, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41599, 17175, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41600, 17175, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41601, 17180, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41602, 17180, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41603, 17180, 93, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41604, 17180, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (41605, 17181, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41606, 17181, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41607, 17181, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41608, 17181, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41609, 17185, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41610, 17185, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41611, 17185, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41612, 17187, 41, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41613, 17187, 7, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (41614, 17187, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41617, 17208, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41618, 17208, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41619, 17211, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41620, 17211, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41621, 17211, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41622, 20135, 52, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41623, 20135, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41624, 20136, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41625, 20136, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (41629, 17218, 9, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (41630, 17218, 43, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (41631, 17221, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41632, 17221, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41633, 17221, 70, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41634, 17221, 23, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (41635, 17221, 43, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (41636, 17228, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41637, 17228, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41638, 17228, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41639, 17229, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41640, 17229, 222, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41641, 17229, 23, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (41642, 17229, 96, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (41643, 17229, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41644, 17231, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41645, 17231, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41646, 17231, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41647, 17231, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41651, 17234, 332, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41652, 17234, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41653, 17234, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41586, 17149, 33, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41587, 17149, 58, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (41519, 3628, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41520, 3628, 84, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41588, 17149, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (41589, 17149, 175, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (41583, 17148, 109, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41584, 17148, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41585, 17148, 286, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41532, 3263, 255, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (41533, 3263, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41534, 3263, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41574, 17145, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41575, 17145, 154, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (41576, 17145, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41654, 17234, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41655, 17235, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41656, 17235, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41657, 17235, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41658, 17235, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41659, 17236, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41660, 17236, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41661, 17236, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (41662, 17237, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41663, 17237, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41664, 17237, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41665, 17238, 119, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41666, 17238, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41670, 17260, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41671, 17260, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41672, 17260, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41673, 17260, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41686, 17268, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41687, 17268, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41692, 17270, 27, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41693, 17270, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40806, 20095, 26, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (41694, 17271, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41695, 17271, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41696, 17271, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (41697, 17271, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41698, 17272, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41699, 17272, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41700, 17272, 308, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41701, 17273, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41702, 17273, 70, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41703, 17274, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41704, 17274, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41705, 17274, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41706, 17274, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41707, 17275, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41708, 17275, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41709, 17275, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41710, 17275, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41711, 17276, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41712, 17305, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41713, 17305, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41714, 17305, 72, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (41715, 17306, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41716, 17306, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41717, 17306, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41718, 17308, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41719, 17308, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41720, 17308, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41721, 17308, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41722, 17308, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41723, 17308, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41724, 17312, 260, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41725, 17312, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41726, 17312, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41727, 17312, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41728, 17313, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41729, 17313, 28, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (41730, 17313, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41731, 17313, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41736, 17326, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41737, 17326, 58, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41738, 17326, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41594, 9369, 45, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41595, 9369, 183, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41615, 20134, 120, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41616, 20134, 156, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41596, 9369, 96, 35, 2);
INSERT INTO 'dancesformationsmap' VALUES (41648, 17232, 268, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41649, 17232, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41683, 17267, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41684, 17267, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41685, 17267, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41680, 17266, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41681, 17266, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41682, 17266, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41688, 17269, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41689, 17269, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41690, 17269, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41674, 17261, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41675, 17261, 96, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41676, 17261, 36, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41739, 17326, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (41740, 17372, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41741, 17372, 119, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (41742, 17372, 72, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41743, 3332, 29, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (41744, 3332, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41745, 3332, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41746, 3332, 72, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (41748, 17403, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41749, 17403, 13, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41750, 17403, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41751, 17403, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41752, 17407, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41753, 17407, 154, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41754, 17407, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41755, 17407, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41756, 17408, 23, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (41757, 17408, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41764, 17435, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41765, 17435, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41766, 17435, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41767, 17442, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41768, 17442, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41769, 17442, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41770, 17443, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41771, 17443, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41772, 17443, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41773, 17443, 134, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (41774, 17444, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41775, 17444, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41776, 17444, 18, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (41777, 17444, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41778, 17445, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41779, 17445, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41780, 17445, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41781, 17445, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41782, 17453, 1, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (41783, 17453, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41784, 17466, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41785, 17466, 340, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41787, 6186, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (41788, 14218, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41789, 14218, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41790, 14218, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41791, 2147, 225, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (41792, 2147, 224, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (41793, 2147, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41794, 17474, 217, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41795, 17474, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41796, 17474, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41797, 17474, 28, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (41798, 17474, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41799, 17475, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41800, 17475, 265, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41801, 17475, 340, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (41802, 17476, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41803, 17476, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41804, 17476, 145, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (41805, 17477, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41806, 17477, 202, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41807, 17477, 112, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41812, 17487, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41813, 17487, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41814, 17487, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41815, 17487, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41816, 17499, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41817, 17499, 278, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41818, 17499, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41819, 3380, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41820, 3380, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (41821, 4083, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41822, 4083, 176, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41823, 4083, 183, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (41824, 17502, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41825, 17502, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41826, 17502, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41827, 17505, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41828, 17505, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41829, 17505, 183, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (41830, 17505, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41831, 17506, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41832, 17506, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41833, 17506, 33, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (41834, 17506, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41762, 17428, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41763, 17428, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41808, 17478, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41809, 17478, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41810, 17478, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41835, 17563, 249, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41836, 17563, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41843, 7067, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41844, 7067, 8, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (41845, 1190, 145, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (41846, 4172, 1, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (41847, 4172, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41848, 17580, 359, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (41849, 17580, 43, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (41850, 17580, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41851, 17580, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41855, 17595, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41856, 17595, 96, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41857, 17595, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41858, 17595, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41859, 17595, 365, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41860, 17598, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41861, 17598, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41862, 17598, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41863, 3321, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41864, 6784, 224, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41865, 6784, 112, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (41866, 4240, 32, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41867, 4240, 189, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41868, 1420, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41869, 1420, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41870, 17600, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41871, 17600, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41872, 17600, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41873, 17601, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41874, 17601, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41875, 17601, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41876, 17603, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41877, 17603, 154, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41878, 17603, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41879, 17603, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41880, 17603, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41881, 17606, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41882, 17606, 109, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41883, 17606, 214, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41884, 17607, 96, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (41885, 17607, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (41886, 17607, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41887, 17607, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41888, 17612, 93, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41889, 17612, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41890, 17612, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41891, 17625, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41892, 17625, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41893, 17625, 183, 18, 2);
INSERT INTO 'dancesformationsmap' VALUES (41894, 17625, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41895, 3619, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41896, 3619, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41897, 3619, 220, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41898, 3619, 374, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (41899, 3619, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41900, 17650, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41901, 17650, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41902, 17650, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41903, 17650, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41904, 17656, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41905, 17656, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (41906, 17656, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41907, 3793, 32, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (41908, 3793, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41909, 3793, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41910, 17662, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41911, 17662, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41912, 17730, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41913, 17730, 10, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (41914, 17730, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41915, 17731, 173, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41916, 17731, 119, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (41917, 17731, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41918, 17733, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41919, 17733, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41920, 17733, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41921, 17733, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41922, 17734, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41923, 17734, 10, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (41924, 17734, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41925, 17734, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41926, 17734, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41927, 17735, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41928, 17735, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41929, 17735, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41930, 17774, 23, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (41931, 17774, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41758, 17409, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38020, 4185, 41, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (17914, 12432, 87, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41786, 12432, 43, 43, 1);
INSERT INTO 'dancesformationsmap' VALUES (41932, 17774, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41933, 17790, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41934, 17790, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41935, 17790, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41936, 10325, 202, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41937, 10325, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41938, 10325, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41939, 10325, 41, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41940, 10325, 260, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41941, 10325, 39, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (41942, 3721, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41943, 3956, 82, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41944, 3956, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41945, 3966, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41946, 3966, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41947, 3966, 46, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41948, 17870, 56, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41949, 17870, 23, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (41950, 17880, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41951, 17880, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41952, 17880, 119, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (41953, 17887, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41954, 17887, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41955, 17888, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41956, 17888, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41957, 17888, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41958, 17888, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41959, 17888, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41964, 17953, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41965, 17953, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41966, 17953, 56, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (41968, 4129, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41969, 4129, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (41970, 4129, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28522, 16803, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41971, 4122, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41972, 4122, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41973, 4122, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41974, 4153, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41975, 4153, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (41976, 4153, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41977, 4323, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41988, 17962, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41989, 17962, 111, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41990, 17962, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41991, 17962, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41992, 17962, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41997, 17965, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41998, 17965, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41999, 17965, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42000, 17968, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42001, 17968, 49, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42002, 17968, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42009, 17981, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42010, 17981, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42011, 17981, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13765, 9059, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13766, 9059, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42012, 17986, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42013, 17986, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42014, 17986, 183, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41837, 20138, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41960, 17950, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41961, 17950, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41840, 14377, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41841, 14377, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (41962, 17950, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41985, 17960, 93, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41981, 17959, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41982, 17959, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41983, 17959, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41984, 17959, 36, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (41986, 17960, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41987, 17960, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42019, 4448, 287, 20, 1);
INSERT INTO 'dancesformationsmap' VALUES (42020, 4448, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42021, 18020, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42022, 18024, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42023, 18024, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42024, 18024, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42025, 18063, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42026, 18063, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42027, 18063, 154, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42028, 18063, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42029, 18063, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42030, 18067, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42031, 18067, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42032, 18067, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42033, 18067, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42034, 18103, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42035, 18103, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42036, 18103, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42037, 18106, 306, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42038, 18123, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42039, 18123, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42040, 18123, 383, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42041, 18136, 234, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (42042, 18136, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42043, 18138, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42044, 18138, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42045, 18138, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42046, 18181, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42047, 18181, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42048, 18206, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (38908, 11661, 93, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38909, 11661, 53, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42049, 18209, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42050, 18209, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42051, 18209, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42052, 18216, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42053, 18216, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42054, 18216, 82, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (42055, 18237, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42062, 18289, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42063, 18289, 7, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42064, 18289, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42065, 18289, 23, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (42066, 18289, 30, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (42067, 18289, 81, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (42068, 18289, 43, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (42080, 20144, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42081, 20144, 64, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42082, 20144, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42083, 20144, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42084, 20145, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42085, 20145, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42090, 18317, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42091, 18317, 173, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42092, 18317, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42093, 18317, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42094, 18318, 10, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42095, 18318, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42096, 18318, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42097, 18318, 365, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42098, 18318, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42099, 18342, 41, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42100, 18342, 142, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42101, 18342, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42102, 18342, 27, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (42103, 18342, 138, 73, 2);
INSERT INTO 'dancesformationsmap' VALUES (42104, 18342, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (42105, 18369, 42, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (42106, 18369, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42107, 18369, 353, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42108, 18369, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42109, 18369, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42110, 18445, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42111, 18445, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42112, 18445, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42113, 18445, 110, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42086, 20146, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42087, 20146, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42088, 20146, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42003, 17971, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42004, 17971, 8, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (42005, 17971, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42089, 20146, 213, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42056, 18243, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42057, 18243, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42058, 18243, 23, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (42015, 17998, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42016, 17998, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42017, 17998, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42018, 17998, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (42060, 18285, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42061, 18285, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41978, 4390, 162, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41979, 4390, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41980, 4390, 36, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42073, 20142, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42074, 20142, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42075, 20142, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42006, 17973, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42069, 20141, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42070, 20141, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42071, 20141, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42007, 17973, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42008, 17973, 9, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42114, 18445, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42115, 18498, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42116, 18498, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42117, 18499, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42118, 18499, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42119, 18499, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13683, 9742, 63, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42120, 18402, 33, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42121, 18402, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42122, 18402, 156, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42123, 18402, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (8713, 1934, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (42127, 18500, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42128, 18500, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42129, 18500, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42130, 18500, 214, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (42131, 18501, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42132, 18501, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42133, 18501, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (42134, 18502, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42135, 18502, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42136, 18504, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42137, 18504, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42138, 18504, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42139, 18505, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42140, 18505, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42141, 18505, 154, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42142, 18506, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42143, 18506, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42144, 18506, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42145, 18509, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42146, 18509, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42147, 18572, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42148, 18572, 73, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42149, 18572, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42150, 18575, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42151, 18575, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42152, 18575, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42153, 18575, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42154, 18575, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42158, 18590, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42159, 18590, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42160, 18592, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42161, 18592, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42162, 18592, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42163, 18592, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42164, 18593, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (42165, 18593, 220, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42166, 18593, 210, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42167, 18593, 72, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (42168, 18593, 176, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (42169, 18603, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42170, 18603, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42171, 18603, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42172, 18614, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42173, 18614, 101, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42174, 18614, 33, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42175, 18616, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42176, 18616, 8, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (42177, 18615, 157, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42178, 18615, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42179, 18615, 306, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42180, 18619, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42181, 18619, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42182, 18619, 252, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42124, 20148, 154, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42125, 20148, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42126, 20148, 365, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (42183, 18621, 145, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42184, 18621, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42185, 18621, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42186, 18621, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42187, 18636, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42188, 18636, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42189, 18636, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42190, 18654, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42191, 18654, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42192, 18654, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42193, 18654, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42194, 18654, 119, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (13087, 10367, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42077, 20143, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42078, 20143, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42195, 18667, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42196, 18667, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42197, 18667, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42198, 18667, 296, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42199, 18667, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (42200, 18943, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42201, 18943, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42202, 18944, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42203, 18944, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42204, 18944, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42205, 18945, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42206, 18945, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42207, 18945, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42208, 18947, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42209, 18947, 324, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42210, 18947, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42211, 18949, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42212, 18949, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42213, 18949, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42214, 18950, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42215, 18950, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42216, 18950, 52, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42217, 18955, 183, 11, 3);
INSERT INTO 'dancesformationsmap' VALUES (42218, 18955, 278, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42219, 18955, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42220, 18957, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42221, 18957, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42222, 18957, 56, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (42223, 18957, 85, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42224, 18957, 176, 43, 1);
INSERT INTO 'dancesformationsmap' VALUES (42225, 18959, 210, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42229, 18962, 184, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42230, 18962, 70, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42231, 18962, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42232, 18962, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42233, 18962, 71, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42234, 18964, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42235, 18964, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42236, 18964, 1, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (42237, 18964, 183, 41, 3);
INSERT INTO 'dancesformationsmap' VALUES (42238, 18966, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42239, 18966, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42240, 18966, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42241, 18975, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42242, 18975, 261, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (42243, 4457, 1, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42244, 4457, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42245, 4457, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42246, 4457, 27, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42247, 4457, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (42251, 19139, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42252, 19140, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42253, 19140, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42254, 19140, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42255, 19140, 28, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (42256, 19202, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42257, 19202, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42258, 19202, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42259, 19202, 373, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42260, 19212, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42265, 4459, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42266, 4459, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42267, 4459, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42268, 4459, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42269, 4459, 48, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42270, 4530, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42271, 4530, 221, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42272, 4160, 162, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42273, 4545, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42274, 4557, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42275, 4557, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42276, 4557, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42277, 4557, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42278, 19238, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42279, 19238, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42280, 19238, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42281, 19328, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42282, 19328, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42283, 19328, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42284, 19328, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42285, 19424, 186, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42286, 19424, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42287, 19424, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42288, 19424, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42289, 19424, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42290, 19425, 30, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42291, 19425, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42292, 19425, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42293, 19425, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42294, 19425, 314, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42295, 19425, 134, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42296, 19425, 7, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (42297, 19511, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42298, 19511, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42299, 19511, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42300, 19512, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42301, 19512, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42302, 19512, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42303, 19579, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42304, 19579, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42305, 19579, 307, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42306, 19580, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42307, 19580, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42308, 19580, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42309, 19580, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42310, 19580, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42311, 19583, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42312, 19583, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42313, 19583, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42314, 19583, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42315, 19586, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42316, 19591, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42317, 19591, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42320, 19605, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42321, 19605, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42322, 19605, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42323, 19608, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42324, 19608, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42325, 19608, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42326, 19616, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42327, 19616, 1, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (42328, 19616, 183, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (42329, 19616, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42330, 19616, 83, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42331, 19616, 251, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (42332, 19616, 72, 53, 1);
INSERT INTO 'dancesformationsmap' VALUES (42333, 19616, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (42339, 19625, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42340, 19625, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42341, 19625, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42342, 19625, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42346, 19699, 82, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42347, 19699, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (42348, 17872, 249, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (42349, 17872, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42350, 17872, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42351, 17872, 119, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (42352, 19816, 373, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42353, 19816, 333, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23290, 14979, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42359, 19879, 52, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42360, 19879, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42361, 19879, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42362, 19899, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42363, 19899, 354, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42364, 19899, 24, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42365, 19899, 118, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42366, 19899, 216, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (42367, 20010, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (42368, 20010, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42369, 17205, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42370, 17205, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42371, 17205, 73, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42372, 16217, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42373, 16217, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42374, 16217, 220, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (42375, 15123, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42376, 15123, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42377, 15123, 23, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (42261, 19220, 333, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42262, 19220, 278, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42263, 19220, 286, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42264, 19220, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5030, 3528, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42318, 20149, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42319, 20149, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42248, 19138, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42249, 19138, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42250, 19138, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42226, 18961, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42227, 18961, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42228, 18961, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42378, 11721, 314, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (42379, 11721, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42380, 2524, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42381, 2524, 120, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42382, 2524, 121, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42383, 2524, 185, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42384, 2524, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42385, 1071, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42386, 1071, 185, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42387, 1071, 225, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (42388, 1869, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (42389, 1869, 188, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (42390, 1869, 96, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (42391, 7331, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42392, 1767, 36, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42393, 1767, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42394, 1767, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42395, 1767, 164, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42396, 1767, 356, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42397, 4635, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42398, 1764, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42399, 1764, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41839, 20139, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42400, 20137, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42401, 20137, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42402, 20137, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42403, 752, 32, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42404, 752, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42492, 6197, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42405, 6173, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42406, 20150, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42407, 20150, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42408, 3572, 64, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42409, 3572, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42413, 10690, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42414, 10690, 74, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42415, 10690, 148, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25981, 15960, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38543, 19984, 215, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14722, 1937, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (14723, 1937, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (14724, 1937, 168, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (17990, 2039, 30, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (17991, 2039, 36, 44, 1);
INSERT INTO 'dancesformationsmap' VALUES (42416, 2259, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34974, 2507, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34975, 2507, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34976, 2507, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42417, 2589, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42418, 2589, 123, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (42419, 2900, 32, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40384, 10410, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40385, 10410, 251, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (40386, 10410, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (40387, 10410, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (40388, 10410, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9792, 9376, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (9793, 9376, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42493, 6224, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42494, 6450, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42423, 20151, 112, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42424, 20151, 142, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (1630, 3108, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42425, 3111, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42434, 20180, 188, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42334, 19619, 180, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42335, 19619, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42336, 19619, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42337, 19619, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (42338, 19619, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42430, 20182, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42431, 20182, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11828, 3244, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42435, 3570, 111, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42436, 3570, 125, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (42437, 3625, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31405, 3857, 307, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42438, 3885, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42439, 3885, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42440, 3885, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42441, 3885, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42442, 20153, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42443, 20153, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42444, 20153, 92, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (42445, 20153, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42446, 20196, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42447, 20196, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42448, 20196, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42449, 20196, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (3001, 5726, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42452, 1407, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42453, 1407, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42454, 1407, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42455, 4312, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (6817, 4447, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42456, 4447, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42457, 4476, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42458, 19220, 261, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42451, 1271, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42354, 19872, 56, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (42355, 19872, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42343, 19628, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42344, 19628, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42345, 19628, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42410, 2854, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42411, 2854, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42412, 2854, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18548, 4483, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5335, 4404, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42462, 4500, 332, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (7668, 2312, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42463, 4610, 32, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42464, 4610, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42465, 4620, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42466, 4692, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38505, 4806, 192, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (42467, 2919, 9, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (42468, 2919, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (42469, 4982, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2716, 5200, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42471, 3664, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42472, 3664, 265, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42473, 3664, 43, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (42495, 6450, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42474, 5320, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42475, 4527, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42476, 4527, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42477, 4527, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42478, 12479, 25, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42479, 12479, 42, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42480, 5609, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42481, 5578, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42482, 5578, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42483, 5578, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42484, 5578, 185, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42485, 6379, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42486, 6379, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42487, 6379, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (42488, 6379, 123, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42489, 6628, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42490, 6628, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42491, 6628, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5742, 5616, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42496, 10691, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42497, 10691, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42498, 10691, 16, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42499, 10691, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42500, 6835, 303, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7122, 7285, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42501, 7310, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12617, 7570, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10844, 7738, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12467, 7782, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42502, 7782, 222, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42503, 7782, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (42504, 8094, 222, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (42505, 8116, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39757, 8123, 286, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39758, 8123, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (39759, 8123, 314, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39760, 8123, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42506, 8238, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16052, 8654, 110, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42470, 5237, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42420, 17509, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5381, 4552, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14602, 5853, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14603, 5853, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42426, 20181, 132, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42427, 20181, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (14604, 5853, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42459, 2850, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42432, 20182, 95, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (42433, 20182, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42460, 2850, 172, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42461, 2850, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14605, 5853, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (16053, 8654, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (12800, 8511, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42507, 9008, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42508, 20197, 13, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42509, 20197, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42510, 20197, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42511, 9115, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42512, 9115, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42513, 9115, 7, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (9656, 9165, 114, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42514, 9189, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42515, 9513, 303, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10289, 9647, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42517, 9647, 333, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42518, 9648, 183, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (10319, 9672, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (10320, 9672, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42519, 9804, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42520, 9820, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42521, 9820, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (10621, 9829, 38, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42522, 9833, 314, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (10998, 9989, 50, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42526, 9989, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (22694, 7265, 36, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (9830, 9387, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42527, 9387, 314, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11700, 10295, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11701, 10295, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (42529, 10376, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42530, 10381, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (15503, 11565, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15504, 11565, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42588, 10714, 8, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (42589, 10714, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21420, 13589, 30, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21421, 13589, 93, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (21422, 13589, 192, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (22150, 13982, 48, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42531, 10696, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42532, 10696, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42533, 10696, 148, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42534, 10696, 8, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42535, 10697, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42536, 10697, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42537, 10697, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42538, 2775, 30, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42539, 2775, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42540, 2775, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42541, 4258, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42542, 4258, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42543, 4258, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42544, 4258, 62, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42545, 4454, 162, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42546, 4454, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (42547, 4454, 21, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14503, 10534, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14504, 10534, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14505, 10534, 102, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42548, 10534, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13389, 10565, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42549, 10565, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13508, 10601, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13509, 10601, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42550, 10601, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42551, 10632, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42552, 10675, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42553, 10675, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15577, 10695, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42554, 10695, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13649, 10792, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42555, 10792, 154, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42556, 10792, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42557, 10817, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42558, 10854, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13919, 10859, 126, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40783, 20090, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42559, 5484, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (42560, 5484, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42561, 5484, 72, 21, 4);
INSERT INTO 'dancesformationsmap' VALUES (42562, 5484, 117, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (22729, 14646, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42590, 17685, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42591, 4690, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42592, 4690, 225, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (42593, 6090, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42594, 4329, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42595, 4329, 71, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42596, 4329, 24, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42563, 10704, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42564, 10704, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42565, 10704, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42566, 10704, 134, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42567, 10704, 184, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42568, 10711, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42569, 10711, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42570, 10711, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42571, 10711, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42597, 4329, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42598, 697, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42599, 697, 9, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42572, 10715, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42573, 10715, 184, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42574, 10715, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42575, 10715, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42523, 9862, 156, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21977, 14352, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42600, 1339, 5, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42528, 10075, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (2507, 4803, 77, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35388, 4803, 30, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42524, 9869, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14475, 11217, 29, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (42576, 11564, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16442, 11884, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16443, 11884, 71, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (40213, 12090, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40214, 12090, 72, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (42577, 12692, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (19709, 12910, 82, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (42578, 12953, 321, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42579, 13227, 308, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42580, 1599, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42581, 1599, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42582, 1599, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42583, 1599, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20580, 13228, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42584, 3696, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42585, 3696, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42586, 6439, 176, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42587, 6439, 87, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42622, 98, 134, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42623, 98, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (42516, 9563, 314, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (22083, 14397, 61, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (42607, 17798, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42608, 17798, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42609, 17798, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42610, 17798, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42611, 19929, 251, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42612, 19929, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42613, 2848, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42614, 2848, 72, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (42615, 2848, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42616, 55, 69, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42617, 55, 303, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (42618, 73, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42619, 88, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42620, 88, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42621, 93, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14514, 100, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14515, 100, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42624, 128, 176, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42625, 3155, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42626, 155, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (99, 162, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42627, 174, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42628, 202, 365, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42629, 202, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42630, 3224, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42631, 3224, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41838, 20138, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42632, 20138, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42633, 20138, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42634, 18953, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (30044, 17687, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28730, 16854, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42638, 16853, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (42639, 16852, 154, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (28718, 16850, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42637, 17664, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14570, 2668, 5, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42601, 9227, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42640, 16849, 303, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28706, 16846, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28699, 16844, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42641, 16800, 164, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42642, 20198, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42643, 20198, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42644, 20198, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42645, 20198, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42646, 20198, 273, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42647, 20199, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42648, 20199, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29417, 17176, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42649, 17176, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42650, 17176, 216, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42651, 11819, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34328, 8548, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34329, 8548, 6, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (39910, 9515, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (39911, 9515, 251, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15221, 11529, 218, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (42652, 12719, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42653, 17686, 1, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (29593, 16801, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42654, 16801, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27233, 16297, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42655, 16297, 134, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42656, 16296, 134, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (42657, 16258, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27350, 16337, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (27351, 16337, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24740, 15436, 183, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (42658, 15431, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25781, 15914, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25782, 15914, 157, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25783, 15914, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25784, 15914, 306, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25785, 15914, 143, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (25786, 15914, 27, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (25787, 15914, 133, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (25788, 15914, 32, 61, 1);
INSERT INTO 'dancesformationsmap' VALUES (42660, 15909, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42661, 15908, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42662, 15889, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42664, 11824, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42665, 11824, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (42666, 11824, 273, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42667, 11824, 224, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42668, 11824, 225, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (42669, 11824, 93, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (42670, 11824, 66, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (42671, 5602, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42672, 1363, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42673, 1464, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42674, 1464, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42675, 2596, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42676, 2596, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42677, 2596, 145, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42678, 14260, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42679, 14260, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42680, 14260, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42681, 4382, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42682, 4382, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42683, 1818, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42684, 1818, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42685, 15836, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42686, 15411, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42687, 15411, 249, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24348, 15378, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24349, 15378, 154, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (42688, 15378, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42689, 15378, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42690, 15378, 8, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42691, 609, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42692, 609, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (25489, 15833, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23259, 14942, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21949, 14341, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42693, 14339, 333, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42694, 14338, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (21596, 13736, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21587, 13734, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (21588, 13734, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21583, 13733, 56, 43, 2);
INSERT INTO 'dancesformationsmap' VALUES (42696, 13733, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (15862, 11689, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42697, 10666, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42698, 10666, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42699, 10666, 273, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42703, 7009, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42704, 7009, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42727, 13441, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (42728, 13441, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42706, 12574, 263, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42729, 2013, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (42730, 2013, 148, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42731, 2013, 8, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (42732, 2013, 46, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (21393, 13439, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (42733, 13439, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (42734, 13439, 32, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (42735, 13436, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42736, 20200, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42707, 7062, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42708, 7062, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42709, 7062, 17, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42710, 7062, 125, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42737, 20200, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42738, 20200, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27849, 14601, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42711, 5530, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42712, 5530, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42713, 5530, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21408, 13677, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42714, 13603, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42715, 13603, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (21184, 13602, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21185, 13602, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42726, 13442, 96, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42635, 3946, 36, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (30289, 17769, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30290, 17769, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42716, 13596, 18, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34519, 13129, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34520, 13129, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34521, 13129, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26455, 14076, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26456, 14076, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42717, 17439, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42718, 4684, 134, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (42719, 4684, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42720, 4684, 183, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (42721, 4684, 185, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42722, 4684, 189, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (42723, 13447, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42724, 13447, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42725, 13447, 38, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42739, 16822, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42740, 20201, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42741, 20201, 314, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (42742, 20201, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42743, 20201, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42744, 13318, 148, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42745, 13303, 29, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (42746, 13303, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42747, 13301, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42748, 14787, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42749, 14787, 94, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42750, 14787, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42751, 14787, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42752, 14787, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42753, 14788, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42754, 14788, 142, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42755, 14788, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42756, 14788, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42757, 14788, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20829, 13272, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42705, 13229, 321, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42758, 16518, 334, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42759, 14791, 269, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42760, 14791, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (42761, 14791, 92, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (27981, 16512, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35307, 17311, 95, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (33829, 14194, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37205, 16940, 225, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37206, 16940, 10, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (37207, 16940, 224, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (30855, 17694, 154, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (30856, 17694, 123, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42765, 17694, 13, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12141, 8500, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42663, 15884, 111, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41578, 17147, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (37026, 18151, 15, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37027, 18151, 125, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42766, 3058, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42767, 3058, 1, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (42768, 3058, 7, 59, 1);
INSERT INTO 'dancesformationsmap' VALUES (15050, 11496, 36, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (15051, 11496, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42769, 11496, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42770, 18599, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42771, 18599, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42772, 18599, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42773, 18599, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42779, 15786, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42780, 8892, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15132, 8878, 32, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (15133, 8878, 207, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (15134, 8878, 193, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (20509, 13206, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42782, 13068, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35443, 19302, 114, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42851, 8295, 303, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42852, 12726, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42853, 12726, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42783, 11642, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42784, 11642, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42785, 11642, 64, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42786, 12962, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19969, 12955, 8, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19970, 12955, 28, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (19699, 12908, 234, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19964, 12949, 225, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42789, 12949, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42855, 12693, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24632, 15419, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24633, 15419, 38, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (42790, 15419, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (30315, 17781, 112, 57, 4);
INSERT INTO 'dancesformationsmap' VALUES (30316, 17781, 38, 153, 1);
INSERT INTO 'dancesformationsmap' VALUES (42794, 4531, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42795, 4531, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42796, 9326, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42797, 9326, 96, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (42798, 12927, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42799, 12907, 157, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42800, 12906, 56, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42801, 12906, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (19684, 12903, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16153, 11762, 23, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (42803, 12681, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30018, 17673, 86, 73, 2);
INSERT INTO 'dancesformationsmap' VALUES (42804, 5040, 303, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42805, 1664, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4844, 2978, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42807, 976, 314, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42808, 976, 96, 6, 2);
INSERT INTO 'dancesformationsmap' VALUES (25425, 15802, 335, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42813, 12890, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42814, 12888, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19631, 12887, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42815, 12886, 7, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (42816, 12883, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19610, 12881, 176, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (42817, 12881, 132, 51, 1);
INSERT INTO 'dancesformationsmap' VALUES (42818, 12880, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42819, 11656, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42820, 11656, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42821, 11656, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42822, 11656, 30, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42823, 11656, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42824, 11656, 192, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (19581, 12872, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19577, 12871, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42825, 12871, 33, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (8536, 8693, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8537, 8693, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8538, 8693, 321, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8539, 8693, 5, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42826, 5141, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42827, 5141, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42812, 9406, 16, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (42831, 12856, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42832, 12856, 29, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (42828, 12869, 314, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42829, 12869, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42833, 12846, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19444, 12836, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19445, 12836, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42834, 12825, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11149, 10062, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42835, 10062, 15, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42836, 3336, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42837, 3336, 55, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (42838, 3336, 328, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (42840, 12811, 36, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (19333, 12790, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42841, 7527, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42842, 12744, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (18919, 12743, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18915, 12742, 203, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (18916, 12742, 71, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42843, 12731, 33, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (42844, 12731, 23, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (42791, 7084, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42792, 7084, 36, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (42793, 7084, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42845, 4320, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42846, 2430, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (633, 1155, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42847, 1155, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42848, 1155, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42849, 1155, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13424, 10580, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42850, 10580, 256, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14852, 11427, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14853, 11427, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8208, 8295, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (18743, 12688, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42859, 12688, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42860, 12675, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (18700, 12672, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18701, 12672, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42863, 17699, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42864, 17699, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42865, 17699, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42866, 17699, 189, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19317, 12636, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (20224, 13116, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42854, 12695, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42802, 12902, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42762, 20203, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42867, 17701, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42868, 17701, 204, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42869, 17701, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42870, 17701, 112, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (37891, 11181, 234, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42871, 4871, 314, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42872, 4871, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42874, 12627, 314, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (18591, 12624, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18642, 12617, 225, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (42875, 12617, 356, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42659, 6965, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42879, 12615, 234, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (18631, 12614, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18632, 12614, 19, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42880, 12611, 234, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (42881, 12609, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42882, 12609, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (18613, 12608, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (18608, 12607, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18609, 12607, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42883, 12587, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42884, 12584, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42885, 12577, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42877, 9017, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42787, 12952, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42788, 12952, 9, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (42861, 12671, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42856, 9021, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42857, 9021, 225, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (42806, 11643, 65, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42809, 11644, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42810, 11644, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42811, 11644, 224, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (42830, 12868, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42774, 17958, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42775, 17958, 152, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (18660, 12662, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42873, 12637, 314, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42839, 1747, 356, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42862, 12662, 154, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (15571, 11585, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (15572, 11585, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42878, 9017, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42886, 12529, 340, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (42887, 12613, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42889, 12524, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42890, 12523, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (17744, 12427, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42892, 12427, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42893, 12427, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (18444, 12416, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42894, 2777, 333, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42895, 1162, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42896, 12404, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17865, 12402, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (17866, 12402, 103, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (17858, 12401, 154, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (17859, 12401, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (17860, 12401, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42897, 12401, 314, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (17062, 11979, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42898, 12364, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17663, 12277, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17664, 12277, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (17624, 12242, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42899, 12228, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18455, 12216, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17635, 12201, 9, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42900, 12149, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (17457, 12121, 91, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (42901, 12121, 157, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (42902, 2968, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15624, 11597, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42966, 17702, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42967, 17702, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42968, 17702, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42969, 17702, 302, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42970, 17703, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42971, 17703, 9, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (15172, 11513, 183, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (15173, 11513, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42903, 12094, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42904, 12094, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42972, 17703, 96, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (42973, 17703, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42974, 17703, 111, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42975, 17703, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16245, 11799, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42909, 12092, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42910, 12092, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42911, 12092, 83, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42912, 12092, 29, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (42913, 12092, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42905, 20205, 309, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (42906, 20205, 87, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42907, 20205, 234, 41, 3);
INSERT INTO 'dancesformationsmap' VALUES (42858, 9021, 296, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42914, 12083, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42915, 12083, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42916, 12076, 7, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42917, 12063, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42918, 12063, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17179, 12059, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42976, 10243, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42977, 18570, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (42978, 18570, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42979, 18799, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42980, 18799, 184, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42981, 18799, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42982, 11774, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42983, 11774, 7, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42984, 11772, 154, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42985, 11771, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42986, 11765, 43, 43, 1);
INSERT INTO 'dancesformationsmap' VALUES (40837, 14545, 265, 41, 4);
INSERT INTO 'dancesformationsmap' VALUES (42987, 14545, 233, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42919, 12091, 180, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42920, 12091, 307, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42921, 12091, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42922, 12091, 16, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42926, 12018, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42927, 12018, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42928, 12017, 381, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42929, 12017, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42931, 11990, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17076, 11984, 69, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (42932, 2607, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (17069, 11982, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42933, 11981, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42934, 11976, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (16107, 11749, 214, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28922, 16917, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42935, 16917, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42936, 16917, 87, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16638, 11928, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (16639, 11928, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16640, 11928, 15, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16601, 11915, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42937, 11915, 7, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (16593, 11913, 56, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (16594, 11913, 61, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (42938, 11890, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42939, 11879, 33, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42940, 11837, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (17046, 11832, 224, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (17047, 11832, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42941, 11815, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42942, 11815, 134, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (42943, 11815, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (9902, 9425, 81, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12607, 10438, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26938, 16197, 21, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42421, 17509, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42422, 17509, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42946, 17509, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42947, 17509, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42948, 9487, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16278, 11811, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16271, 11809, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (42949, 17691, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42950, 17691, 23, 11, 3);
INSERT INTO 'dancesformationsmap' VALUES (42951, 17691, 241, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42952, 17696, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42953, 17696, 154, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (42954, 17696, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42957, 17698, 134, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42958, 17698, 330, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (42959, 17698, 10, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (42960, 17698, 159, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42961, 17698, 87, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (42962, 17698, 90, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (42891, 12429, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19296, 12631, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19297, 12631, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42781, 13143, 259, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (42888, 12527, 314, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42923, 1398, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42924, 1398, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42955, 17697, 186, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42956, 17697, 201, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42930, 12007, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42963, 17698, 149, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (42964, 17698, 43, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (42965, 17698, 23, 93, 1);
INSERT INTO 'dancesformationsmap' VALUES (42988, 11748, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42989, 11747, 36, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42990, 11708, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42991, 12491, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42992, 12491, 184, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42993, 18938, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42994, 18938, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42995, 18938, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42997, 18937, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (42998, 18937, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (42999, 18937, 84, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43000, 20206, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43001, 20206, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43002, 20206, 22, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (16759, 11634, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (16760, 11634, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43003, 11632, 96, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (43007, 12357, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43008, 12357, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43009, 12357, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15683, 11615, 84, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (15649, 11603, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43010, 11598, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43011, 12293, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43012, 12293, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43013, 12293, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15825, 11680, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42996, 11680, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (17247, 12079, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43004, 20207, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43005, 20207, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43006, 20207, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43014, 12265, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43015, 12265, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43016, 12265, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43017, 12265, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43018, 12159, 189, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43019, 12159, 1, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (15507, 11567, 203, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (43020, 11567, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43021, 11561, 314, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15296, 11554, 56, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (15249, 11537, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15229, 11532, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15219, 11528, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15212, 11526, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (43022, 11526, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (43023, 11521, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (15193, 11520, 56, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (15194, 11520, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43024, 11519, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42908, 20205, 135, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (43092, 14370, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43093, 14370, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43094, 14370, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43095, 14370, 48, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43025, 12131, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43026, 12131, 58, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (15020, 11486, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15017, 11485, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (15018, 11485, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15015, 11484, 103, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43027, 11484, 43, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (43028, 11479, 96, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (43029, 11478, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43030, 11475, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14905, 11440, 114, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (15460, 11399, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43031, 11399, 18, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43032, 12153, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43033, 12153, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43034, 12153, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43035, 12358, 74, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43036, 12358, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43037, 12187, 95, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (43038, 12187, 234, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43039, 12187, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43040, 12187, 43, 4, 3);
INSERT INTO 'dancesformationsmap' VALUES (43041, 12187, 83, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43042, 12205, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43043, 12205, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43044, 12205, 16, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43045, 12205, 341, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (17360, 11225, 145, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43046, 11225, 227, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15437, 11391, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15438, 11391, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43047, 11373, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14784, 11371, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43048, 11367, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43082, 20212, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43049, 9552, 365, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15844, 11683, 19, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43050, 11682, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43051, 11682, 9, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43052, 11682, 76, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43083, 20212, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43084, 20212, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43053, 2529, 249, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43054, 2529, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43085, 20212, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (25322, 15764, 28, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43055, 15764, 69, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43096, 2801, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43097, 10949, 269, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43098, 10946, 268, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14307, 10943, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25334, 15768, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40080, 15768, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43060, 4655, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43061, 4655, 249, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43062, 4655, 185, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15854, 11686, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43063, 11264, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43064, 11261, 341, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (43065, 11258, 96, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (43066, 11226, 222, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (43067, 11221, 23, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (43068, 11220, 186, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43069, 11691, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43070, 11695, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43071, 11695, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43072, 11696, 77, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43073, 11697, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15881, 11698, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (15515, 11193, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14466, 11164, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14296, 11156, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14297, 11156, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43074, 11156, 43, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (43075, 20210, 72, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43076, 20210, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43077, 20210, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43078, 20211, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43079, 20211, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43080, 20211, 251, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43081, 20211, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14247, 11108, 32, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (14248, 11108, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14191, 11063, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (14074, 11032, 158, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43087, 11013, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41842, 14377, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43088, 14377, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14053, 10961, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14054, 10961, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43091, 10959, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14010, 10937, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14011, 10937, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14006, 10936, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14007, 10936, 117, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43100, 10936, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43101, 10931, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (13970, 10918, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43102, 10918, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43109, 20214, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43110, 20214, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43111, 20214, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43112, 20214, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13834, 10896, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13830, 10894, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43113, 10889, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13812, 10887, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13809, 10886, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43114, 10886, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43089, 10963, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14305, 11107, 318, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (43086, 11107, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14045, 10958, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14046, 10958, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13805, 10885, 365, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (15857, 11687, 148, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43103, 20213, 109, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43099, 10938, 333, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (36917, 19690, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36918, 19690, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13931, 10908, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13932, 10908, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13785, 10878, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13904, 10877, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (43115, 14184, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43116, 14184, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43117, 14184, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43118, 14184, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43119, 14184, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43120, 14184, 52, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (43121, 14184, 28, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (43127, 5560, 36, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43128, 5560, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13634, 10788, 39, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (13635, 10788, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13599, 10778, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13600, 10778, 72, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (13601, 10778, 328, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (43129, 10778, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (43130, 10778, 41, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (43131, 10775, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43132, 20216, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43056, 6416, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43133, 20217, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43134, 20217, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (43135, 20217, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (43136, 20217, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43137, 10669, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (13520, 10642, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43138, 10602, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15788, 10599, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15414, 10587, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (15415, 10587, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15416, 10587, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43140, 10587, 171, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13408, 10572, 39, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (13409, 10572, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13410, 10572, 176, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43143, 10569, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (43144, 10564, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43145, 10560, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43146, 219, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43147, 6689, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43149, 10546, 340, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43150, 10546, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13347, 10545, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13344, 10543, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (13339, 10542, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13340, 10542, 92, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (13341, 10542, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43153, 10542, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43154, 10540, 9, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (13323, 10537, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13324, 10537, 365, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (14499, 10533, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (14500, 10533, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13280, 10524, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13281, 10524, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13282, 10524, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43155, 10523, 312, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43156, 17974, 164, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43157, 17974, 77, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43158, 10521, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (13263, 10520, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13264, 10520, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43221, 10111, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43159, 17972, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43160, 17972, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43161, 17972, 325, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43162, 17970, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43163, 17970, 240, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43164, 17970, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13242, 10518, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13243, 10518, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (13233, 10516, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43165, 17969, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43166, 17969, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43167, 17969, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43168, 17969, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13154, 10506, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43169, 17967, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43170, 17967, 84, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43171, 10501, 314, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43172, 10501, 96, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (13046, 10491, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43174, 10491, 1, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (12995, 10475, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43175, 10473, 234, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (43176, 10462, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43177, 10462, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43178, 17966, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43179, 17966, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43180, 17966, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43181, 17963, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43182, 17963, 9, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43183, 17963, 77, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43184, 17963, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43186, 10404, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43222, 10108, 7, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43223, 10108, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11272, 10103, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41963, 17950, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43185, 10406, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12488, 10392, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20847, 10366, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43187, 10364, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12043, 10357, 76, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43188, 17951, 24, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43189, 17951, 280, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43190, 17951, 281, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (43191, 17951, 42, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (43192, 10345, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11978, 10344, 84, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43193, 10341, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11888, 10333, 185, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11889, 10333, 189, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (43194, 10424, 234, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43195, 10329, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43196, 10324, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43197, 10308, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43198, 10304, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11731, 10301, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43199, 10300, 42, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (43200, 10262, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43201, 10242, 20, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (43202, 10236, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11417, 10195, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43203, 10180, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39967, 9656, 7, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43204, 10177, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17356, 10176, 43, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (43205, 17952, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43206, 17952, 240, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43207, 17952, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43208, 17952, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43209, 17952, 221, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (17536, 10173, 193, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43210, 10173, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43211, 10163, 301, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11426, 10154, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43212, 10153, 33, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (43213, 10153, 184, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (43214, 10152, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43215, 10152, 192, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (43216, 10136, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (43217, 10136, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (43218, 10115, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (43219, 10114, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (43220, 10112, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11273, 10103, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43224, 10096, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43225, 10095, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41252, 15616, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11165, 10068, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11166, 10068, 17, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11176, 10068, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43229, 10067, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43230, 10067, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14638, 10066, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43231, 10065, 132, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (11154, 10063, 81, 97, 2);
INSERT INTO 'dancesformationsmap' VALUES (11155, 10063, 27, 105, 2);
INSERT INTO 'dancesformationsmap' VALUES (43232, 10063, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43233, 10063, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (43234, 10063, 93, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (43235, 10060, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43236, 10060, 96, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (43237, 10060, 234, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (41967, 17953, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43238, 17955, 210, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43139, 10589, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43122, 20215, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43227, 10071, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43226, 10083, 365, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (11233, 10084, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43148, 10555, 36, 6, 2);
INSERT INTO 'dancesformationsmap' VALUES (43106, 20213, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43107, 20213, 29, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43108, 20213, 42, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (43141, 10579, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43142, 10579, 1, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (43173, 10500, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43239, 17955, 225, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43240, 17955, 56, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43241, 17955, 220, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13200, 10514, 112, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (13201, 10514, 71, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43252, 9999, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (43242, 15886, 142, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43243, 10059, 314, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (43245, 10023, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (43248, 10012, 69, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (43251, 10007, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (43253, 9974, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14833, 9947, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (43254, 9941, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43255, 9941, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42776, 17958, 117, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42777, 17958, 220, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (16014, 11709, 7, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (43256, 9937, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43257, 9937, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43259, 9902, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10781, 9893, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10778, 9891, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43262, 9890, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43263, 9887, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43264, 9887, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (10766, 9886, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43265, 9885, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10758, 9884, 86, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (10759, 9884, 142, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (10760, 9884, 27, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (43266, 9884, 132, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (43269, 3382, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12477, 9868, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43271, 6355, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (43272, 6355, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (43273, 6355, 296, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (43274, 6355, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (43275, 6355, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (43276, 9853, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10666, 9850, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10659, 9847, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10660, 9847, 46, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43277, 9845, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43278, 9844, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (43279, 9843, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43280, 9840, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (10632, 9834, 1, 37, 3);
INSERT INTO 'dancesformationsmap' VALUES (43281, 9834, 269, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24854, 15552, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24855, 15552, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24856, 15552, 157, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10577, 9813, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43356, 9536, 7, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40189, 11204, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43284, 10668, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43285, 10668, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43286, 10668, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43287, 10668, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43290, 20219, 306, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43291, 20219, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43292, 20219, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (43293, 20219, 162, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43294, 1990, 185, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43295, 1990, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43296, 1990, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43342, 8911, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43343, 8911, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30142, 17720, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43301, 17726, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43302, 17726, 143, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43304, 17724, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43305, 17724, 7, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43306, 17724, 65, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43307, 17724, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43308, 17724, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43309, 9783, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43310, 9769, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11179, 9760, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43311, 9760, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43312, 9759, 249, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10501, 9755, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43313, 20221, 269, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43314, 20221, 303, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43315, 20221, 7, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (22783, 11195, 17, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22784, 11195, 52, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (43322, 9724, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43323, 9724, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43324, 9710, 20, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (43325, 9687, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43326, 9685, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43327, 9684, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43316, 17723, 162, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43317, 17723, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43318, 17723, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43319, 17723, 96, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (43320, 17723, 19, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43321, 17723, 76, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (43328, 11203, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (43329, 11203, 42, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (43330, 11203, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43331, 3568, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43332, 20223, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43333, 20223, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43334, 20224, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43335, 20224, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43336, 20224, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12653, 9768, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43340, 9635, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (43357, 9532, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43337, 20225, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43344, 8911, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43345, 8913, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43346, 8913, 110, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43347, 19138, 8, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (10188, 9571, 72, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (43353, 9562, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43374, 8916, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43366, 18076, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43367, 18076, 72, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (43368, 18076, 1, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (43369, 18076, 41, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (43370, 9475, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43372, 9469, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43348, 20226, 93, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (43349, 20226, 134, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (43350, 20226, 142, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (43351, 20226, 1, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (43354, 9549, 234, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10594, 9547, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (13399, 9539, 4, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (10030, 9505, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43358, 9505, 314, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43359, 8919, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43360, 8919, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43361, 8919, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43365, 10273, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43375, 8916, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11695, 9466, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43376, 9459, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12151, 9456, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43377, 9454, 235, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (43373, 9469, 216, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (12449, 9467, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13070, 9451, 76, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (43382, 9451, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (43383, 9451, 251, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43378, 8915, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43379, 8915, 112, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43380, 8915, 83, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43381, 8915, 27, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43389, 9407, 234, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (43362, 20229, 16, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43363, 20229, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43364, 20229, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (41590, 17149, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43390, 17149, 183, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (43391, 9385, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43392, 9384, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (43393, 9367, 17, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43394, 9365, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43371, 9474, 148, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43355, 9541, 43, 39, 1);
INSERT INTO 'dancesformationsmap' VALUES (43260, 9897, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43244, 10057, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43249, 10011, 265, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43250, 10011, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (43352, 9573, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43384, 8914, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43267, 9880, 249, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (43268, 9880, 39, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (43258, 9908, 9, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43341, 9578, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12835, 9895, 38, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (43261, 9895, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43288, 9830, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43289, 9830, 39, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (43303, 9809, 314, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (35276, 11196, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (43282, 20218, 54, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (38573, 20002, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38574, 20002, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43297, 20220, 283, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43298, 20220, 313, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (39159, 441, 32, 61, 1);
INSERT INTO 'dancesformationsmap' VALUES (39160, 441, 73, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (10536, 9775, 285, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (43338, 20225, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43339, 20225, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43396, 9351, 333, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (43397, 9351, 303, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43398, 8910, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43399, 8910, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43400, 8910, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43401, 8910, 225, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (43402, 8910, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (43403, 8910, 90, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (43404, 8910, 176, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (43405, 8910, 157, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (43406, 9388, 125, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43407, 9388, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43484, 18909, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34647, 8912, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43408, 2617, 189, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (43409, 2617, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43410, 2997, 65, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43411, 9289, 269, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43412, 9234, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (13854, 9196, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43485, 18909, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43486, 18909, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43487, 18909, 119, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (43488, 18909, 15, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9485, 9093, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43489, 9093, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43490, 9093, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43491, 9091, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43414, 4738, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43415, 4738, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43416, 4738, 81, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43417, 16627, 32, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (43418, 16627, 58, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43419, 16627, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43420, 16632, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43421, 16632, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43422, 16632, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43423, 16632, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43492, 9089, 45, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43425, 9181, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43426, 9181, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43427, 16629, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43428, 16629, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43429, 16629, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43430, 16629, 159, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43522, 17322, 172, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43523, 17322, 313, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43524, 17322, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13532, 9192, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43462, 9123, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (13096, 9200, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (13097, 9200, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43498, 4337, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43499, 4337, 95, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (43438, 16630, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43439, 16630, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43440, 16630, 355, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43441, 16630, 92, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43424, 9184, 234, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (43442, 4152, 33, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43443, 4152, 39, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43444, 4152, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43445, 10279, 95, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (43446, 10279, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43447, 10279, 189, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (43448, 10279, 154, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (43449, 9162, 132, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43450, 2877, 84, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43451, 2877, 76, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (42428, 20181, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42429, 20181, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43533, 19119, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43453, 20232, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43454, 20232, 380, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43455, 20232, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43456, 20233, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43457, 20233, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (6101, 6712, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43452, 20182, 4, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43534, 19119, 364, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43463, 9113, 54, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11544, 10275, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (43464, 9102, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43465, 9102, 303, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43466, 9098, 45, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43469, 10281, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43470, 10281, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43471, 10282, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (43472, 10282, 148, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43473, 10282, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43474, 20236, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43475, 20236, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43476, 20236, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43477, 20236, 92, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (21505, 13374, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (43467, 20235, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43468, 20235, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43478, 20235, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11562, 10274, 114, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11563, 10274, 4, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (43479, 20237, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43480, 20237, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43481, 20237, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43482, 20237, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43483, 20237, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43515, 13374, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43516, 20241, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43517, 20241, 49, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43518, 20241, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43519, 20241, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43520, 19600, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43506, 9085, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9444, 9082, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9445, 9082, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9446, 9082, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43507, 9080, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43508, 9079, 314, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43509, 9078, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21548, 13704, 33, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21549, 13704, 253, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43510, 13703, 332, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42450, 20196, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43511, 13702, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43512, 13700, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43513, 13512, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43514, 13512, 96, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (43521, 19600, 214, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43493, 20238, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43494, 20238, 42, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43495, 20238, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43496, 20238, 234, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43497, 20238, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43501, 20239, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43502, 20239, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43503, 20239, 53, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43504, 20239, 262, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (43505, 20239, 71, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43525, 20242, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43526, 20242, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43527, 20242, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (43528, 20242, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (9423, 9076, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43535, 9076, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43536, 9054, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (17443, 9026, 114, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17444, 9026, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43537, 20243, 105, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43538, 20243, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43539, 20243, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43545, 9010, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (43547, 9003, 7, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (43548, 9003, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43549, 9002, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (9471, 9001, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43550, 9000, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43540, 20244, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43431, 20230, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43432, 20230, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43433, 20230, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (43434, 20230, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43500, 4337, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43529, 19122, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43530, 19122, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43531, 19122, 84, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (12323, 9204, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43458, 20234, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (43459, 20234, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10467, 9352, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43395, 9352, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43546, 9009, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43532, 19122, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43541, 20244, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43542, 20244, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43543, 20244, 92, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43544, 20244, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43642, 20261, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43643, 20261, 32, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43644, 20261, 52, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43600, 20255, 262, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43551, 20250, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43552, 20250, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43553, 20250, 359, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43554, 20250, 109, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (40549, 20084, 39, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (43555, 20252, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43556, 20252, 359, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43557, 20252, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (43558, 20252, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14609, 8992, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43559, 8975, 314, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43560, 8975, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43561, 8968, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43562, 19480, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43563, 4141, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12506, 8951, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43565, 8951, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9681, 8954, 154, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9682, 8954, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (9683, 8954, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13218, 8941, 119, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13219, 8941, 72, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (43601, 20255, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43602, 20255, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43566, 5573, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43567, 5573, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (12317, 8858, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43568, 11972, 234, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (43569, 20253, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43570, 20253, 269, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43571, 20253, 7, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43578, 587, 314, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (9302, 6666, 163, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (9303, 6666, 7, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43579, 2134, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43580, 2134, 64, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43581, 2134, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43572, 2681, 183, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (43573, 2681, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43574, 2681, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43575, 2681, 119, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43576, 2681, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43577, 2681, 96, 6, 2);
INSERT INTO 'dancesformationsmap' VALUES (43610, 20266, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43611, 20266, 148, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43612, 20266, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43613, 20266, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43614, 20266, 102, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43653, 20258, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43654, 20258, 249, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43655, 20258, 7, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43656, 20258, 48, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43645, 20261, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43582, 20254, 154, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (43583, 20254, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43584, 20254, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43585, 20254, 111, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43586, 20254, 6, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43587, 20254, 39, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (43646, 20261, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43594, 15589, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43657, 20258, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (25212, 15730, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43647, 8833, 20, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (43648, 8739, 183, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (43595, 16654, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43596, 16654, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43597, 16654, 185, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43598, 16654, 154, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43599, 16654, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10101, 2135, 90, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10102, 2135, 149, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10103, 2135, 66, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11915, 8737, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8609, 8715, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8913, 5749, 23, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (17555, 4044, 66, 113, 1);
INSERT INTO 'dancesformationsmap' VALUES (43588, 14499, 56, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43589, 14499, 95, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (43590, 14499, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43591, 14499, 112, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43592, 14499, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43593, 14499, 30, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (43564, 19712, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (16683, 8838, 193, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (16684, 8838, 149, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (43649, 8715, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (8591, 8700, 117, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (13878, 9199, 17, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43619, 2367, 77, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43620, 3542, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (43621, 3542, 29, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (43622, 3542, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (34178, 19059, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34179, 19059, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35144, 19063, 10, 27, 4);
INSERT INTO 'dancesformationsmap' VALUES (35145, 19063, 43, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (36069, 19076, 119, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (40983, 19077, 362, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40984, 19077, 56, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (40985, 19077, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37316, 19080, 220, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (35256, 19083, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43625, 20274, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43626, 20274, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43627, 20274, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43628, 20274, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (43631, 20276, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43632, 20276, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43633, 20277, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43634, 20277, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43635, 20277, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43636, 20278, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43637, 20278, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43638, 20279, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43639, 20279, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43640, 20280, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43641, 20280, 214, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (13881, 9052, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43650, 8700, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (43658, 8629, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43659, 8627, 296, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (43660, 8620, 134, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8291, 8603, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8278, 8597, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12197, 8568, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43663, 8568, 21, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43603, 20259, 158, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43604, 20259, 163, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (43605, 20259, 86, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (43606, 20259, 1, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (43651, 20259, 96, 17, 6);
INSERT INTO 'dancesformationsmap' VALUES (11940, 8566, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43664, 8566, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43665, 8564, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9082, 8562, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (9083, 8562, 92, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (9084, 8562, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12471, 8557, 87, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (43666, 8557, 55, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (12453, 8556, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12138, 8555, 76, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43667, 8554, 36, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (43670, 10858, 175, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43671, 8533, 78, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12855, 8527, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43673, 8519, 148, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43674, 8512, 162, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43675, 8506, 332, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43676, 8503, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8462, 8670, 42, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (43652, 8670, 372, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12732, 8522, 112, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43615, 9019, 56, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (43616, 9019, 95, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (12156, 8501, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (43677, 8500, 314, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (43678, 8500, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43679, 8499, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11991, 7564, 9, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7321, 7455, 77, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43680, 7455, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43668, 6766, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43669, 6766, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11992, 7564, 172, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43745, 7564, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25360, 15775, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43623, 20273, 134, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (43624, 20273, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43629, 20275, 23, 1, 5);
INSERT INTO 'dancesformationsmap' VALUES (43630, 20275, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43661, 8608, 162, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43662, 8608, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25361, 15775, 186, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43681, 8487, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15988, 8485, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43683, 8476, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43684, 8473, 95, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (43685, 8473, 96, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (43743, 7468, 157, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43747, 15765, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (18796, 7304, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25338, 15769, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43748, 15769, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18797, 7304, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25346, 15771, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43686, 20281, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43687, 20281, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43688, 20281, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43689, 20281, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43690, 20281, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43691, 20281, 1, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (43692, 7484, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (15921, 8463, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15930, 8461, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15931, 8461, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43693, 8461, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43694, 8375, 45, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13460, 8367, 154, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (43695, 8364, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43696, 8355, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13463, 8345, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43697, 8345, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43698, 8345, 38, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15754, 8331, 36, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (43699, 8313, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43700, 8246, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43701, 8246, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (43703, 7461, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43704, 7461, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43705, 7461, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43706, 7461, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43707, 7461, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43749, 7533, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43750, 7528, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43708, 7496, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43709, 7496, 149, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43710, 8178, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43751, 7524, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (43711, 8173, 9, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (43713, 8155, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17372, 12110, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17373, 12110, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43712, 12110, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43714, 8140, 251, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9050, 8120, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43717, 8105, 314, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (17399, 12117, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (7698, 8086, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43718, 9922, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43719, 9922, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19198, 8056, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19157, 8040, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43720, 8040, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43721, 8024, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43753, 7506, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43722, 20282, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43723, 20282, 149, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43724, 20282, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43725, 20282, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43726, 20282, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43727, 20256, 188, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43728, 20256, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43729, 20256, 228, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43730, 7412, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43731, 7416, 103, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17217, 7992, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43732, 7842, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (43733, 7842, 18, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43734, 7826, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (12521, 7814, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (14310, 7723, 90, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (43735, 7723, 32, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (43736, 7723, 7, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15162, 7647, 210, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (43755, 7499, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43756, 7494, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43757, 7494, 58, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (43758, 7490, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43759, 7490, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23493, 15093, 29, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (12444, 7576, 7, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (43742, 7567, 314, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (14575, 7566, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43744, 7565, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (43760, 7469, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9313, 7450, 120, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43761, 7450, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (7422, 7375, 1, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (43762, 7375, 23, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (43763, 7375, 157, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (43781, 7300, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (43764, 7356, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (13088, 10367, 42, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (23535, 14247, 85, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28628, 16640, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43765, 7348, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43770, 7340, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43771, 7338, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (7414, 7337, 111, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43772, 7336, 183, 7, 3);
INSERT INTO 'dancesformationsmap' VALUES (29196, 17006, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29197, 17006, 90, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43754, 17006, 72, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (43682, 8478, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43777, 7333, 314, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43778, 7333, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43779, 7333, 9, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18824, 7318, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43780, 7318, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (10798, 9903, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43782, 7355, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43789, 7289, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43783, 2786, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (43784, 2786, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43785, 20285, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43786, 20285, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43787, 20285, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43788, 20285, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6283, 7260, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43790, 7260, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (43791, 7257, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17566, 7256, 30, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43792, 7220, 332, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43738, 20283, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43773, 20257, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43797, 7195, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43798, 7195, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43799, 7188, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43800, 7188, 7, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (43801, 7164, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43774, 20257, 273, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43775, 20257, 48, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43776, 20257, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43739, 20283, 49, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43740, 20283, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43741, 20283, 92, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (43746, 7557, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43794, 20286, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43795, 20286, 29, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43766, 13776, 224, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (43767, 13776, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43768, 13776, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43769, 13776, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43796, 20286, 148, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35119, 10842, 20, 85, 4);
INSERT INTO 'dancesformationsmap' VALUES (43802, 20287, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (43803, 20287, 154, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (43804, 20287, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (43805, 20287, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43806, 20287, 43, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (43807, 20287, 41, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (43808, 20287, 328, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (43809, 20288, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43810, 20288, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43811, 20288, 355, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43812, 20289, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43813, 20289, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43814, 20289, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43815, 20289, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43816, 7143, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43817, 7142, 183, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (6238, 7129, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43818, 7125, 132, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (12888, 7121, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (43819, 7110, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43820, 7110, 39, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43821, 7105, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (43702, 8201, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43737, 7654, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (22746, 14651, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23836, 14674, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43793, 7206, 269, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43715, 8138, 33, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43716, 8138, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43825, 7093, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43826, 7093, 96, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (43827, 7081, 96, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (43828, 7075, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (43829, 7073, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43830, 7073, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43831, 7071, 318, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (43832, 11769, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (43887, 6997, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43888, 6996, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (43833, 20240, 224, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43834, 20240, 91, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43835, 20240, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43836, 20240, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43837, 20240, 328, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43892, 6952, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43893, 6941, 36, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (18900, 12737, 209, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43838, 12737, 157, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43839, 7049, 314, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (43842, 7028, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43843, 7028, 32, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (43844, 7028, 38, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (12885, 7027, 7, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (43845, 7027, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43846, 7027, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43847, 7016, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43848, 7016, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6196, 7013, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43849, 7013, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43850, 7013, 162, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41732, 17315, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41733, 17315, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41734, 17315, 102, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41735, 17315, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43851, 19146, 131, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28612, 16636, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43852, 20292, 164, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24317, 15358, 43, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (38976, 12823, 41, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38977, 12823, 69, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38978, 12823, 32, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (38979, 12823, 95, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (43855, 12354, 265, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43856, 12354, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43857, 12354, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43858, 4685, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43862, 5142, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12731, 8522, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43672, 8522, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43867, 5984, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43868, 5984, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43869, 20294, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43870, 20294, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43871, 20294, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43872, 20294, 72, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (43873, 20294, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43874, 20294, 154, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (43875, 20294, 192, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (17715, 6932, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43894, 6932, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (43895, 6931, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (43876, 6606, 224, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43877, 6606, 23, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (43878, 6606, 225, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43879, 11323, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43880, 11323, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43881, 11323, 112, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43882, 11323, 202, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43883, 11323, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29436, 13121, 43, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (29437, 13121, 87, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (29438, 13121, 38, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (15246, 11536, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (43884, 10928, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43885, 10928, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43886, 10928, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13737, 10842, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (35117, 10842, 157, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (35118, 10842, 259, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43896, 6931, 23, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (43897, 6931, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43898, 6919, 183, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (43899, 6913, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43863, 20293, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43864, 20293, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43865, 20293, 72, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (43866, 20293, 154, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43900, 6981, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43901, 6981, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43902, 6890, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43903, 6879, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43904, 6876, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43905, 6876, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43906, 6876, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43910, 6847, 143, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43911, 6846, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (43912, 6846, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43916, 20295, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43917, 20295, 7, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43913, 2639, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43914, 2639, 119, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43915, 2639, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (19431, 12411, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43918, 20295, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43919, 20295, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43920, 20295, 5, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21535, 11873, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (21536, 11873, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (21537, 11873, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43931, 6783, 318, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3619, 6818, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43925, 6817, 148, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43926, 6816, 314, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (43927, 20300, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43928, 20300, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43929, 20300, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43930, 20300, 221, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21538, 11873, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43907, 2049, 127, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43908, 2049, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43909, 2049, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6125, 6767, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43932, 6767, 365, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (43933, 20296, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43934, 20296, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43935, 20296, 92, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (43936, 6758, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43937, 6758, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43938, 6720, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43940, 6675, 318, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43941, 6661, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43945, 9883, 162, 59, 1);
INSERT INTO 'dancesformationsmap' VALUES (43946, 20299, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43853, 15238, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43854, 15238, 7, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43822, 20290, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43823, 20290, 262, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (43947, 20299, 82, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (43948, 20299, 16, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (42602, 9227, 38, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (42603, 9227, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42604, 9227, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42605, 9227, 259, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42606, 9227, 185, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (8461, 8670, 45, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (12405, 8516, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43949, 6899, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43950, 6899, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43951, 6899, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43952, 6899, 318, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (44061, 15669, 193, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43979, 5332, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44062, 6522, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43958, 20305, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43959, 20305, 318, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43960, 20305, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43961, 20305, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43962, 20305, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43963, 20305, 95, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (43968, 20304, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43969, 20304, 119, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (43921, 20301, 229, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43953, 20302, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43954, 20302, 220, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43955, 20302, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (43964, 20306, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43965, 20306, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43966, 20306, 8, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (43840, 7042, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43841, 7042, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (15332, 10199, 212, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43942, 6646, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (43943, 6646, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43944, 6646, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (43889, 6959, 7, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (43890, 6959, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43891, 6959, 303, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43956, 20302, 183, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (43970, 20304, 42, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (43971, 20303, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43972, 20303, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43973, 20303, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43974, 20303, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43975, 20303, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (43617, 9019, 83, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (43618, 9019, 262, 4, 4);
INSERT INTO 'dancesformationsmap' VALUES (43976, 5534, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43977, 5534, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43978, 5534, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44079, 2706, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (43980, 5257, 269, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (43981, 5001, 265, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (43982, 5001, 7, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (43859, 4896, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (43860, 4896, 69, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (43861, 4896, 33, 41, 4);
INSERT INTO 'dancesformationsmap' VALUES (44100, 20310, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44101, 20310, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43985, 6618, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43989, 6601, 234, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (43990, 6600, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43991, 3238, 365, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43992, 3053, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (43993, 3051, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43994, 3051, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43995, 3051, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43996, 2914, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (43997, 2914, 176, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (43998, 2914, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (43999, 2840, 365, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13789, 2597, 65, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (44000, 2597, 81, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (44001, 1896, 7, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (44005, 20297, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44006, 20297, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44007, 20297, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44008, 20297, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44009, 20297, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44010, 1862, 117, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44011, 1862, 314, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (44012, 1698, 318, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44013, 1698, 29, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (44014, 2813, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44015, 2813, 43, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (44016, 2813, 112, 53, 2);
INSERT INTO 'dancesformationsmap' VALUES (44019, 3067, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44020, 3067, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44021, 3067, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44022, 3067, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44002, 20307, 152, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44003, 20307, 9, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44004, 20307, 29, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44023, 5458, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44024, 5458, 193, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (44025, 5458, 43, 69, 2);
INSERT INTO 'dancesformationsmap' VALUES (43151, 10544, 9, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (43152, 10544, 157, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (36590, 15235, 43, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (44031, 6093, 7, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44032, 5109, 315, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44033, 5109, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44034, 5109, 32, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (44035, 6456, 120, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44036, 6456, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44037, 6456, 220, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44038, 6456, 72, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (44039, 7270, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44040, 7270, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44041, 7270, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (44042, 7270, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44043, 7270, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44044, 7270, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44045, 7270, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (44046, 6575, 303, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44047, 15673, 117, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44048, 15673, 225, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (44049, 15673, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (44050, 15673, 220, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (44051, 15673, 210, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44052, 15673, 27, 6, 2);
INSERT INTO 'dancesformationsmap' VALUES (44053, 15672, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44054, 15672, 87, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44055, 15672, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44056, 15672, 225, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44057, 6550, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44058, 6550, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44059, 15669, 56, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44060, 15669, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44063, 6518, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44064, 6492, 314, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44065, 6492, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44066, 6484, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44067, 6484, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3427, 6485, 183, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (44081, 6387, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44068, 20308, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44069, 20308, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44070, 6481, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12843, 6472, 25, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44071, 6463, 318, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44072, 6444, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44073, 6444, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (44074, 14510, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44077, 6399, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44078, 6397, 318, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (32078, 18346, 110, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32079, 18346, 93, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (44082, 6386, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44083, 6380, 43, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (44084, 6380, 23, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (44085, 6380, 7, 65, 4);
INSERT INTO 'dancesformationsmap' VALUES (44086, 6358, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44087, 6358, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44088, 6348, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44089, 6323, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12827, 6319, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12828, 6319, 66, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44090, 4508, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44091, 4508, 188, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44092, 15913, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44093, 15913, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44094, 16929, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44095, 16929, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (30941, 18087, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44096, 6167, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44097, 6167, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44098, 6163, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44099, 6161, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43986, 6616, 16, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (43987, 6616, 183, 49, 3);
INSERT INTO 'dancesformationsmap' VALUES (43988, 6616, 7, 63, 1);
INSERT INTO 'dancesformationsmap' VALUES (44026, 5707, 38, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (44027, 5707, 7, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (44028, 5707, 32, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (43983, 4048, 9, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43984, 4048, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11041, 6135, 72, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (11042, 6135, 87, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (11043, 6135, 142, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (10147, 6131, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44103, 6077, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44104, 6058, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3183, 6048, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44105, 6048, 314, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44106, 6048, 251, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (20947, 6025, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44107, 6025, 183, 15, 3);
INSERT INTO 'dancesformationsmap' VALUES (44108, 4791, 76, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44109, 4791, 46, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44110, 4261, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44111, 4261, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44112, 4261, 36, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (44203, 5661, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44204, 5236, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44205, 5236, 7, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44206, 5236, 185, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (44207, 5236, 143, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44208, 5236, 12, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (44212, 5303, 365, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44176, 3551, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44177, 3551, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44178, 3551, 183, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (44179, 3551, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44180, 4373, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44181, 3662, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44182, 3662, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44183, 3662, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27794, 7020, 45, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (27795, 7020, 23, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (44120, 20324, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44121, 20324, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44122, 20324, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44123, 20324, 157, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44200, 5773, 145, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44075, 19566, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44184, 2535, 30, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (44185, 2535, 36, 22, 1);
INSERT INTO 'dancesformationsmap' VALUES (44029, 6843, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44030, 6843, 7, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (44017, 20284, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44018, 20284, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43283, 20218, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44235, 5839, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44236, 5839, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44213, 491, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44214, 491, 59, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44215, 491, 49, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44127, 5981, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44128, 5905, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44129, 5905, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44130, 5904, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44131, 5904, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44217, 6691, 145, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (44218, 4999, 4, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44219, 4999, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44220, 20328, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44221, 20328, 21, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44222, 20328, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44113, 20323, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44114, 20323, 17, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44115, 20323, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44223, 20328, 142, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44140, 4895, 287, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44141, 4895, 36, 3, 13);
INSERT INTO 'dancesformationsmap' VALUES (44142, 4895, 89, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44143, 4895, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44144, 5897, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44148, 5865, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44149, 5865, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44150, 5763, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44151, 5763, 20, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44152, 1119, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44153, 1119, 333, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (44154, 414, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44155, 3264, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44156, 3264, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44157, 3264, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44158, 3264, 112, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44159, 3264, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (14441, 11192, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (13827, 10893, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44160, 795, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44161, 795, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (44162, 795, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44163, 550, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44224, 20331, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44225, 20331, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44226, 20331, 92, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44227, 20331, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44244, 20330, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34317, 19192, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44164, 19192, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44165, 19192, 92, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (44166, 19192, 234, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (44167, 19192, 23, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (44251, 5741, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44252, 5717, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44243, 5795, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44191, 2588, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44192, 2588, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (39501, 4878, 49, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44193, 4211, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44194, 1300, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44195, 1300, 314, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44196, 4047, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44197, 4047, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44198, 4047, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44199, 3106, 312, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (9031, 7980, 1, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (39909, 9472, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44248, 5759, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44240, 5817, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44242, 5798, 215, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44239, 5824, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44201, 5773, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44202, 5773, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (44102, 20310, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44249, 5759, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44250, 5759, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (8909, 5744, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38612, 20002, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43299, 20220, 184, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (43300, 20220, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44234, 5848, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (11919, 5840, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44253, 5717, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11901, 5687, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44259, 5687, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (44245, 20330, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44246, 20330, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44247, 20330, 75, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44228, 20331, 27, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44237, 5825, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44216, 6207, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44260, 20335, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44238, 5825, 318, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44229, 20333, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44186, 20327, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44187, 20327, 148, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44188, 20327, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44189, 20327, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44190, 20327, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44254, 20334, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44230, 20333, 156, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44255, 20334, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44256, 20334, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44257, 20334, 72, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (44231, 20333, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44232, 20333, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (17603, 1533, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (17604, 1533, 85, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44124, 20319, 313, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44125, 20319, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44126, 20319, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44342, 1881, 62, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (44343, 1881, 356, 133, 1);
INSERT INTO 'dancesformationsmap' VALUES (44344, 4043, 83, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44345, 4043, 82, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (44346, 4043, 143, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (44347, 4043, 192, 121, 1);
INSERT INTO 'dancesformationsmap' VALUES (44348, 3680, 87, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44349, 3680, 43, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (44350, 3680, 41, 121, 1);
INSERT INTO 'dancesformationsmap' VALUES (44265, 5669, 9, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44266, 5669, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44267, 5643, 268, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (2944, 5617, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44351, 3680, 149, 185, 1);
INSERT INTO 'dancesformationsmap' VALUES (44352, 3680, 112, 69, 2);
INSERT INTO 'dancesformationsmap' VALUES (44353, 3680, 156, 201, 1);
INSERT INTO 'dancesformationsmap' VALUES (44354, 5699, 234, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (44355, 5699, 183, 39, 2);
INSERT INTO 'dancesformationsmap' VALUES (44356, 5699, 7, 81, 4);
INSERT INTO 'dancesformationsmap' VALUES (44357, 5699, 156, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (44358, 5699, 157, 225, 1);
INSERT INTO 'dancesformationsmap' VALUES (44268, 20332, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44269, 20332, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (44270, 20332, 94, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44272, 20332, 249, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (44273, 20332, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44274, 20332, 61, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (44359, 3777, 87, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44258, 20334, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44279, 5571, 185, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44280, 5568, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44281, 5564, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44360, 3777, 149, 105, 2);
INSERT INTO 'dancesformationsmap' VALUES (44285, 5539, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44364, 4988, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44365, 4988, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44366, 4988, 120, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44286, 5494, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15238, 5487, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15239, 5487, 45, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15240, 5487, 154, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (15241, 5487, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44289, 5421, 126, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44290, 5410, 308, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44291, 5402, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44275, 20336, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44276, 20336, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44277, 20336, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44209, 4974, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44210, 4974, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44211, 4974, 29, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (8896, 5422, 52, 81, 2);
INSERT INTO 'dancesformationsmap' VALUES (8897, 5422, 149, 169, 1);
INSERT INTO 'dancesformationsmap' VALUES (44287, 5422, 43, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (44288, 5422, 157, 161, 1);
INSERT INTO 'dancesformationsmap' VALUES (44168, 20326, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44169, 20326, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44170, 20326, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44145, 5868, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44146, 5868, 287, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44147, 5868, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44241, 5800, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44172, 16959, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44173, 16959, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44174, 16959, 86, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44278, 5581, 157, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12737, 5378, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44292, 5364, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (6909, 5358, 19, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44293, 5358, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44294, 5350, 332, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (7587, 5326, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (7588, 5326, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44295, 5282, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2755, 5276, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44296, 5276, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44297, 5276, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44298, 5276, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44299, 5261, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44300, 5217, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44301, 5217, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44302, 5204, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44303, 5171, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44304, 5161, 222, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44305, 5160, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44306, 5151, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44367, 4988, 185, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44368, 4948, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14348, 6724, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44261, 20335, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44262, 20335, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44263, 20335, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44307, 9630, 66, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44308, 5102, 318, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44309, 5039, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44310, 5037, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44311, 5037, 72, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (44312, 5037, 43, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (44313, 5037, 23, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (44314, 5034, 269, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44315, 5028, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44363, 6724, 145, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (5512, 4932, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44282, 5549, 222, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44283, 5549, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (44284, 5549, 355, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44316, 5027, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44317, 5027, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44318, 5027, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44319, 5027, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44371, 4882, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44372, 4875, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44322, 20325, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44323, 20325, 303, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44324, 20325, 7, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (44325, 9617, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44326, 9617, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44327, 9617, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44328, 9617, 303, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44329, 3428, 52, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44330, 3428, 134, 33, 4);
INSERT INTO 'dancesformationsmap' VALUES (44331, 3428, 149, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (44332, 3428, 84, 89, 3);
INSERT INTO 'dancesformationsmap' VALUES (44333, 5128, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44334, 5128, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39246, 742, 52, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (39247, 742, 1, 105, 1);
INSERT INTO 'dancesformationsmap' VALUES (39248, 742, 149, 113, 1);
INSERT INTO 'dancesformationsmap' VALUES (44338, 5799, 32, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (44339, 5799, 87, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (44340, 4680, 87, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44341, 4680, 52, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44373, 4875, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44374, 4819, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44375, 20338, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44376, 20338, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44361, 20337, 183, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (44362, 20337, 72, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (44386, 20342, 283, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44387, 20342, 95, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (44388, 20342, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44392, 4804, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44369, 4908, 111, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44389, 1770, 143, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10574, 4813, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44390, 4809, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44391, 4809, 36, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (44264, 5671, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44393, 4755, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44394, 4752, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44395, 5278, 188, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (44396, 5278, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44401, 5491, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44402, 5491, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44403, 5809, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44404, 5809, 225, 2, 9);
INSERT INTO 'dancesformationsmap' VALUES (44405, 5809, 183, 2, 17);
INSERT INTO 'dancesformationsmap' VALUES (44406, 5809, 296, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44407, 5809, 66, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (44408, 4746, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (44409, 4720, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (44410, 4642, 365, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44411, 4642, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44412, 4642, 132, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44413, 20343, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44414, 20343, 332, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (44415, 20343, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44416, 4597, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44417, 4595, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44418, 4581, 42, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (44419, 4565, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44420, 4561, 86, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44421, 4561, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42778, 17958, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44377, 20339, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44378, 20339, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44379, 20339, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44380, 20340, 158, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44381, 20340, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13727, 4774, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19193, 2686, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44423, 4436, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44424, 4436, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44425, 4436, 58, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44426, 3552, 36, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (44427, 4455, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44428, 4439, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44429, 4439, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44559, 3544, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44430, 4398, 312, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (44432, 4346, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44433, 4346, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (44434, 4374, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44435, 4318, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38470, 19976, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44560, 3538, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (5372, 4517, 54, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44437, 4291, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15156, 4279, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (15157, 4279, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (15158, 4279, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44438, 4278, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44439, 4270, 148, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44440, 4268, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44441, 4268, 7, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (44442, 4262, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44443, 4262, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5284, 4238, 72, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (44444, 4238, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44445, 4222, 96, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (44446, 4196, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44447, 4196, 318, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44448, 4183, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44449, 4176, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44450, 4169, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44451, 4155, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44452, 4155, 131, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44453, 4142, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44454, 4142, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44455, 4136, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44456, 4136, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44457, 5979, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44458, 5979, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44459, 5979, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44460, 5979, 221, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44461, 5979, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44462, 6024, 30, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (44463, 6024, 56, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5244, 4126, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44464, 4115, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44465, 4115, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44466, 4106, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44467, 6039, 43, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (44468, 6039, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44469, 4058, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44470, 6067, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44471, 6067, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44472, 6067, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6769, 4064, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44397, 5475, 365, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16884, 8112, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44398, 5475, 19, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44335, 4271, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44336, 4271, 184, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (44337, 4271, 1, 145, 3);
INSERT INTO 'dancesformationsmap' VALUES (44422, 4484, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44370, 4888, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44473, 6067, 365, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44474, 4051, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44475, 4022, 7, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44476, 4022, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44477, 4019, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44478, 4019, 30, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44479, 4019, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44484, 2456, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44561, 3538, 249, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44562, 6649, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44486, 5399, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44485, 59, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44487, 4688, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44488, 5106, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44489, 5106, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44490, 6301, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44491, 6301, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44492, 5300, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44493, 5300, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44494, 3931, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44495, 3923, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44496, 3918, 268, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44497, 3887, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44498, 3887, 148, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44503, 6357, 193, 56, 3);
INSERT INTO 'dancesformationsmap' VALUES (44504, 6357, 176, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (44505, 6357, 43, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (44506, 6357, 72, 97, 4);
INSERT INTO 'dancesformationsmap' VALUES (44507, 6357, 8, 67, 2);
INSERT INTO 'dancesformationsmap' VALUES (44508, 3847, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44509, 3847, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43057, 6416, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43058, 6416, 84, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43059, 6416, 125, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44511, 6426, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44512, 6426, 225, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44513, 6426, 189, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44514, 3830, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44515, 3830, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (8333, 3829, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44516, 3828, 20, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44517, 3792, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44518, 3792, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44519, 3787, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44520, 6392, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44521, 3783, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44522, 3783, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44523, 3783, 249, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (44524, 3781, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44525, 3767, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44526, 3767, 234, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (44527, 3728, 33, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (44528, 3728, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36387, 4421, 192, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (44529, 3723, 18, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44530, 6447, 38, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (44531, 6447, 224, 45, 4);
INSERT INTO 'dancesformationsmap' VALUES (44532, 6447, 87, 56, 4);
INSERT INTO 'dancesformationsmap' VALUES (44533, 6429, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44534, 6429, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44535, 6508, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44536, 3711, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (5093, 3698, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44537, 3698, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44538, 3698, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44539, 3678, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (44540, 3660, 131, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44541, 1099, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44542, 6579, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44543, 6579, 156, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44544, 6595, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44545, 6595, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44546, 6595, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44549, 3645, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44550, 3645, 96, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (1921, 3638, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5072, 3638, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44551, 3638, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44552, 3638, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44553, 3638, 132, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (44554, 3595, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44555, 3589, 96, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (44556, 3569, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44557, 3569, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (13108, 3559, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44558, 3559, 96, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (44563, 6649, 183, 20, 1);
INSERT INTO 'dancesformationsmap' VALUES (44564, 3499, 30, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44565, 3492, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44566, 3475, 333, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44567, 3454, 157, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44568, 3454, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (5000, 3446, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (44569, 3409, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44570, 3287, 112, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44571, 3287, 83, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29456, 991, 96, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (44574, 3387, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44575, 4591, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44576, 3345, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35715, 16832, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44577, 8430, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44578, 8430, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44579, 3340, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1750, 3326, 79, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44580, 3317, 365, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44581, 3317, 111, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (44431, 4352, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44582, 3309, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44583, 3309, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4936, 3268, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19025, 3268, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (19026, 3268, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44584, 5186, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44585, 5186, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44586, 3261, 268, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44587, 3261, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44588, 3256, 18, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44589, 3250, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44590, 3250, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44591, 3207, 77, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44592, 3207, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6640, 3177, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44593, 13776, 123, 12, 1);
INSERT INTO 'dancesformationsmap' VALUES (44594, 3145, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44595, 3145, 134, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (44596, 3105, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44597, 3084, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44598, 3080, 145, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14804, 11189, 43, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (44689, 2469, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44690, 2469, 287, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44691, 2469, 23, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (44692, 2465, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44693, 2465, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44694, 2464, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44695, 2464, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44613, 20344, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44614, 20344, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (44615, 20344, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44616, 20344, 8, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44617, 20344, 69, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44618, 20344, 192, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (44619, 1997, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44620, 17285, 87, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44621, 17285, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44622, 17285, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44623, 17285, 373, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44624, 2979, 132, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44625, 2970, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44626, 2957, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19113, 2955, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44627, 2926, 96, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (44628, 2910, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44629, 2906, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44630, 2903, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44607, 20345, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44608, 20345, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44609, 20345, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44610, 20345, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44611, 20345, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44612, 20345, 8, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (44604, 20346, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44605, 20346, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (44606, 20346, 92, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (44600, 20347, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44601, 20347, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44602, 20347, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44603, 20347, 92, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (44436, 4313, 12, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (44631, 2882, 185, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44480, 6290, 69, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (44481, 6290, 28, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44547, 6645, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (44548, 6645, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44499, 6322, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44500, 6322, 82, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (44501, 6322, 333, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (5144, 3833, 39, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44510, 3833, 52, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44634, 2871, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44635, 2871, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44636, 8447, 183, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (44637, 8447, 95, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (44638, 8447, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44639, 2859, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44633, 5772, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14333, 2835, 188, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (44640, 2826, 132, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (44641, 2826, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44643, 2821, 308, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44644, 2821, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44645, 2789, 55, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44646, 2781, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44647, 2753, 287, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (44648, 2753, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44632, 3016, 234, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44649, 8448, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44650, 8448, 184, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44651, 8448, 127, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44652, 8448, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44655, 2742, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44656, 2736, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44657, 2734, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44696, 2458, 154, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (44697, 2458, 235, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44698, 2431, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8630, 10, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (44658, 10, 158, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (44659, 10, 183, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (44660, 10, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (44661, 10, 33, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (44662, 10, 95, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (44663, 2725, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44664, 2725, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (1432, 2713, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44665, 8450, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44666, 8450, 4, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (44667, 8450, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44668, 2642, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44671, 2587, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44672, 2571, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44673, 8460, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44674, 8460, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (44675, 8460, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44676, 8460, 221, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44677, 8451, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44678, 8451, 1, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (44679, 8451, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44680, 2568, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44681, 2568, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44682, 2568, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44683, 2538, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44684, 2538, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (23770, 2525, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23771, 2525, 185, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44685, 2525, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44686, 2495, 318, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6494, 1782, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44699, 2423, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44700, 2423, 222, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44701, 2423, 43, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (44702, 2402, 23, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (44703, 2389, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44704, 2372, 9, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (44705, 1505, 33, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (44706, 2364, 112, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44707, 2356, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27202, 16286, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44708, 2352, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44709, 2352, 111, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44710, 2350, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44711, 2333, 333, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (7667, 2312, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (17794, 9325, 86, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44712, 9325, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9190, 8794, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9191, 8794, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8583, 8707, 42, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (44713, 6394, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31141, 18145, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31142, 18145, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44714, 2288, 145, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44715, 2288, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44716, 2278, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44717, 2267, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (44718, 2254, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13798, 2253, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44719, 2237, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44720, 2196, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44721, 20349, 230, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44722, 20349, 376, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44723, 20349, 314, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (44724, 20349, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44725, 20349, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44726, 2189, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44728, 2171, 16, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (44727, 2173, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29735, 17523, 168, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44729, 17523, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44730, 17523, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44731, 17523, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44732, 9828, 65, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44733, 2169, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44734, 2169, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (44735, 2162, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44736, 2162, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9940, 9435, 124, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44737, 2130, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44599, 3063, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44740, 2079, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44741, 2077, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44742, 2077, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44743, 2063, 96, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44744, 2063, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44745, 2060, 125, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44746, 2060, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4542, 2033, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44747, 2033, 134, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (44748, 2033, 29, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (44749, 2033, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14252, 2016, 23, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (14253, 2016, 58, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44754, 2016, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (44755, 2004, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44756, 2000, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16838, 1982, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44757, 1965, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44758, 1965, 183, 41, 3);
INSERT INTO 'dancesformationsmap' VALUES (12988, 1959, 203, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (12989, 1959, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44759, 1928, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44760, 1928, 123, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (44761, 1928, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44762, 855, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44763, 5768, 43, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (44764, 5768, 149, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44765, 1908, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44766, 1908, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44767, 1884, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44768, 1884, 20, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44769, 1884, 42, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (44770, 1857, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44771, 1857, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44772, 1857, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44773, 1847, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44774, 1830, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44775, 1826, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44776, 1819, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44777, 1804, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44778, 8996, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (8410, 8656, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (44850, 1547, 327, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (7999, 8394, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44779, 7138, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44780, 7116, 20, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (44851, 1547, 9, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (44852, 2513, 287, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44853, 1543, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44781, 7057, 29, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (44782, 7057, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44783, 7057, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44854, 1543, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44855, 1526, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (4375, 1513, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44784, 135, 189, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (44785, 135, 43, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44786, 135, 72, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (44789, 2064, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44790, 2064, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (44794, 4792, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44795, 4792, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44796, 861, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4740, 2687, 386, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (16783, 2687, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44669, 2608, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44739, 2129, 306, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44670, 2608, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6509, 1903, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44642, 2823, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44653, 8449, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44654, 8449, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44797, 861, 183, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44798, 861, 23, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (44799, 861, 72, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (44808, 2457, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44809, 2457, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36742, 19648, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44810, 19648, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44811, 1774, 308, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44812, 1762, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44813, 1762, 77, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (44814, 6722, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44815, 6722, 46, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44816, 6682, 30, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44817, 6682, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44818, 6261, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44819, 6261, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (8932, 6038, 23, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (44820, 5554, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44821, 5554, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44822, 5513, 184, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44823, 4919, 318, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44824, 1757, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (44825, 1756, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44826, 6292, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (44827, 6292, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44828, 1722, 188, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44829, 1707, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44830, 1707, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44831, 1677, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44832, 1653, 303, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (8097, 1609, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44833, 4253, 96, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (44834, 1596, 183, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (18117, 1587, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44838, 1579, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44839, 14017, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44840, 14017, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44841, 14017, 355, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44842, 14017, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44843, 3135, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44844, 3364, 183, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (44856, 1481, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44845, 15871, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44857, 1475, 183, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (44858, 1474, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44859, 1474, 33, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44860, 1467, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8092, 1429, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44861, 1376, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (730, 1364, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44862, 1364, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44382, 20341, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44383, 20341, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44384, 20341, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (44385, 20341, 12, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44846, 1564, 7, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (44863, 1359, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25658, 15880, 23, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (44847, 15880, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (6468, 1558, 69, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44848, 1558, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44849, 1558, 23, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (44864, 1359, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44865, 6383, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44866, 281, 183, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (44867, 1561, 240, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44868, 1561, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44869, 2032, 185, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44870, 2032, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44871, 1180, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44872, 1180, 202, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44873, 1180, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44874, 6283, 55, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44875, 2467, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44876, 2467, 183, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (44877, 2467, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44880, 1350, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (8689, 1293, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44878, 6107, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44879, 6107, 42, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (44881, 1280, 132, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (13963, 1247, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (13964, 1247, 138, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44886, 1246, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44887, 1246, 318, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44687, 6971, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (44688, 6971, 240, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44882, 20312, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44883, 20312, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44884, 20312, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (44885, 20312, 5, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44750, 2045, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44751, 2045, 45, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44800, 6013, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44801, 6013, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44791, 3944, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44792, 3944, 332, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44793, 3944, 96, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (44787, 935, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44788, 935, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44803, 3860, 189, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44804, 3860, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44805, 3860, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44806, 3860, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44807, 3860, 249, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (44896, 1882, 189, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44897, 1882, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44898, 1882, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44899, 1882, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (4585, 2177, 87, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44902, 3069, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44903, 3069, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44904, 3069, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (44908, 3877, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44909, 3877, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44910, 1311, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44911, 1223, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44912, 1215, 96, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (44913, 1192, 184, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6520, 2006, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (44914, 1954, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44915, 1954, 12, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (44916, 1954, 1, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44917, 1861, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44923, 1179, 309, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (16267, 11808, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44931, 20354, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44932, 20354, 7, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44933, 20354, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44934, 20354, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44935, 20355, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44936, 20355, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44937, 20355, 43, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44938, 20355, 96, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (44939, 20356, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44940, 20356, 365, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44941, 20356, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44950, 1171, 134, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (44951, 1171, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44918, 1511, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44919, 1511, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (44920, 1511, 87, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (44921, 1511, 72, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44922, 1511, 9, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (44952, 1368, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (4313, 1349, 16, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (44953, 1153, 332, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44954, 1152, 145, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44955, 1152, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44956, 1131, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44957, 1131, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44958, 1131, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14257, 1113, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44959, 1113, 296, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44960, 1103, 7, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44961, 690, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44962, 690, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44963, 690, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44964, 690, 7, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44965, 690, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44966, 690, 43, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (44967, 690, 125, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (44968, 273, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44969, 103, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44970, 103, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44971, 103, 96, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (44972, 82, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44973, 81, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44974, 1074, 314, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44975, 1073, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44976, 1034, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44892, 20351, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7534, 4928, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44946, 20358, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44947, 20358, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44948, 20358, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (44888, 20314, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44889, 20314, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44890, 20314, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4464, 1793, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44893, 20351, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44894, 20351, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44895, 20351, 55, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44977, 20351, 92, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45001, 871, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45002, 871, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45003, 867, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45005, 853, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45006, 852, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44924, 20352, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44925, 20352, 131, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44926, 20352, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (45007, 852, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (45008, 852, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (45009, 848, 41, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (45010, 848, 135, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (44927, 20353, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44928, 20353, 75, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44929, 20353, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44930, 20353, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44978, 992, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (44979, 974, 268, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44980, 974, 332, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (538, 972, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44981, 972, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45011, 842, 33, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (45012, 842, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45013, 842, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45014, 819, 308, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20885, 807, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20886, 807, 224, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45015, 807, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45016, 802, 23, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (45017, 765, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44987, 915, 234, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (44982, 20321, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44983, 20321, 58, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44984, 20321, 213, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44985, 20321, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44986, 20321, 69, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44996, 20361, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44997, 20361, 95, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44998, 20361, 355, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44999, 20361, 76, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45000, 20361, 317, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (12189, 722, 42, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (45022, 717, 180, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45023, 715, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45024, 687, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45025, 685, 96, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (44988, 20359, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45020, 18696, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45021, 18696, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44905, 931, 188, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (44906, 931, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44907, 931, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45038, 20246, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44989, 20359, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44990, 20359, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44991, 20359, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4102, 680, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45031, 680, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45032, 672, 20, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45039, 20246, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45040, 20246, 94, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45041, 20246, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45042, 671, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45043, 655, 132, 7, 3);
INSERT INTO 'dancesformationsmap' VALUES (45033, 20245, 56, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45034, 20245, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45035, 20245, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45036, 20245, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45037, 20245, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45026, 20248, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45027, 20248, 249, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (45028, 20248, 297, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45029, 20248, 7, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45044, 9213, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45049, 20247, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45050, 20247, 172, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45045, 9213, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45046, 9213, 185, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45051, 20247, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45047, 9213, 259, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45030, 20248, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44900, 828, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (44901, 828, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44942, 20357, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44943, 20357, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (44944, 20357, 1, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (44945, 20357, 249, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (6351, 654, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (45151, 20391, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45053, 650, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45054, 644, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7613, 629, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45152, 20391, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45153, 20391, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45055, 600, 234, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (45056, 600, 302, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45154, 20391, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45155, 20391, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45156, 20391, 90, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (8123, 598, 71, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45057, 596, 314, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45058, 596, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45059, 578, 234, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (7626, 549, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7627, 549, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45060, 547, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45061, 547, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45064, 530, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (278, 497, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45066, 485, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (2994, 5712, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45067, 475, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45068, 475, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45069, 475, 7, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45070, 471, 332, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45071, 443, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45072, 20362, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45073, 20362, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45074, 20362, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (45075, 20362, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45052, 20247, 214, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45076, 10117, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45048, 9213, 225, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45078, 10120, 185, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45079, 10120, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45077, 10119, 193, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45080, 440, 197, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (4002, 439, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45081, 439, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45082, 439, 7, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45083, 439, 365, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45084, 420, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45085, 407, 33, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45086, 407, 365, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (45087, 400, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3990, 397, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45088, 397, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45089, 397, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7630, 387, 209, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (7631, 387, 38, 137, 1);
INSERT INTO 'dancesformationsmap' VALUES (45090, 382, 29, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (45091, 382, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13126, 359, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13127, 359, 7, 21, 3);
INSERT INTO 'dancesformationsmap' VALUES (45092, 340, 234, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (41061, 15124, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41062, 15124, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (45093, 15323, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45094, 15323, 197, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (32437, 14118, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45095, 300, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14525, 274, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45096, 271, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15428, 268, 183, 39, 1);
INSERT INTO 'dancesformationsmap' VALUES (45097, 268, 234, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (45098, 268, 26, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45099, 229, 96, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (12082, 228, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45100, 228, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45101, 140, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45102, 137, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45103, 137, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45104, 11331, 261, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45105, 11331, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45106, 3232, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45107, 4007, 173, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45108, 4007, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45109, 1004, 12, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45110, 1004, 249, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (19041, 896, 215, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44992, 20360, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45065, 521, 318, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (45062, 1711, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45063, 1711, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45018, 761, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22092, 5972, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45004, 860, 222, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (45113, 4231, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45114, 4231, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (45111, 20368, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45112, 20368, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45115, 20367, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45116, 20367, 36, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45117, 20366, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45118, 20366, 225, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45119, 20366, 262, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (45120, 20366, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45121, 2269, 197, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (45122, 2269, 157, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (45123, 2269, 16, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (11035, 10003, 157, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45124, 10003, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45167, 2630, 43, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (45168, 2630, 249, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (45169, 2630, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45125, 20370, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45126, 20370, 125, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45127, 20370, 283, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45128, 20370, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45129, 1747, 368, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45131, 2636, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (45132, 2636, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45133, 2629, 314, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45134, 2629, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45135, 20364, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45136, 20364, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45137, 20364, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45138, 7199, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45139, 20313, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45140, 20313, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44233, 20333, 4, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45141, 1823, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45142, 1823, 330, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (45143, 1823, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45144, 1823, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45145, 1823, 234, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37687, 19820, 142, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37688, 19820, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45148, 13797, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45149, 13797, 102, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45150, 13797, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45170, 5978, 45, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (5003, 3452, 184, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45161, 12629, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45162, 12629, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45163, 12629, 249, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (45164, 12629, 287, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45165, 12629, 185, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30682, 17992, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45166, 17992, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45171, 5978, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45172, 5978, 332, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45173, 20363, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45174, 20363, 119, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (45175, 20363, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45176, 20365, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45177, 20365, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45158, 20392, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45159, 20392, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45160, 20392, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13156, 10507, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13157, 10507, 225, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45178, 20365, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45179, 20365, 8, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13675, 157, 33, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45180, 20393, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45181, 20393, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45182, 20393, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45183, 20393, 184, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45184, 20393, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45185, 18096, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45186, 20394, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45187, 20394, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45188, 20394, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45189, 5041, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (7528, 3246, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45190, 8452, 157, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45191, 8452, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45192, 8452, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (45193, 8452, 317, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (45194, 13739, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14821, 11402, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14822, 11402, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45195, 6536, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45196, 6536, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45197, 5776, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45198, 5776, 185, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45199, 5776, 145, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45200, 5776, 39, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36156, 12252, 24, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (36157, 12252, 43, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (36158, 12252, 183, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (36171, 12394, 221, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (36172, 12394, 268, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (45203, 4800, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (4729, 2649, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45201, 2649, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45202, 2649, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38452, 19974, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38453, 19974, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (45244, 4658, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45245, 4658, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45246, 4658, 7, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (45204, 10022, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45205, 10022, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45206, 17571, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45207, 17571, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45208, 17571, 249, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (28940, 16925, 105, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13723, 10823, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16466, 11893, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (22087, 14398, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (31871, 3566, 202, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (34163, 12302, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34164, 12302, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (30373, 3201, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (16473, 11895, 210, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (16476, 11895, 45, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24954, 15576, 143, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (13716, 10821, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (45209, 20421, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45210, 20421, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45211, 20421, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13190, 10512, 101, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13191, 3866, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (13198, 9343, 58, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (34116, 7558, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13205, 9046, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7471, 7557, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13687, 10803, 41, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13688, 10803, 64, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (24709, 15443, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (38357, 19965, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45212, 17572, 2, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45213, 17572, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45214, 17572, 120, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45215, 17572, 121, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45216, 17572, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (45217, 9527, 314, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (12229, 1814, 83, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (12230, 1814, 112, 61, 2);
INSERT INTO 'dancesformationsmap' VALUES (38358, 19965, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38359, 19965, 93, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (10061, 9529, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (10062, 9529, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45218, 9529, 103, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45219, 9529, 172, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9562, 9122, 58, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (15598, 1541, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15599, 1541, 276, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45221, 1541, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45224, 20416, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45225, 20416, 265, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45226, 20416, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45227, 20369, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45228, 20369, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45229, 8567, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45230, 8567, 134, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38353, 19964, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38354, 19964, 234, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (38355, 19964, 87, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38356, 19964, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45249, 19964, 69, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (14061, 10978, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45231, 10978, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22334, 14013, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22335, 14013, 313, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14304, 11107, 114, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45222, 20415, 13, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45223, 20415, 71, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20278, 13148, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20249, 13140, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20258, 13142, 224, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45220, 13142, 332, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20273, 13147, 120, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (15496, 11563, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30806, 18019, 287, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (41167, 15574, 92, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41168, 15574, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19656, 12894, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29480, 17265, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45232, 20425, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45233, 20425, 283, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45234, 20425, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45235, 20425, 376, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45236, 20427, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45237, 20427, 123, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (45238, 20427, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45240, 5063, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45241, 8062, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (19249, 8074, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (14228, 11081, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45242, 11081, 87, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45243, 11081, 103, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (45251, 14383, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45252, 14383, 188, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45253, 14383, 92, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45254, 14383, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (41579, 17147, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41580, 17147, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41581, 17147, 96, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (41582, 17147, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45255, 12140, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45256, 12140, 221, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45257, 12140, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45258, 20428, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45259, 20428, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45260, 20428, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45261, 20428, 142, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45262, 20429, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45263, 20429, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45264, 20429, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45265, 20430, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45266, 20430, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45267, 20430, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45268, 20430, 95, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45269, 20430, 127, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45270, 20430, 61, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (45277, 20433, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45278, 20433, 22, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45279, 20433, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45280, 20433, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45290, 20437, 241, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45291, 20437, 8, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (45292, 20437, 134, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45247, 3036, 269, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45248, 3036, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45281, 20434, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45282, 20434, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45283, 20434, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45284, 20434, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (15560, 11582, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15561, 11582, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15562, 11582, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45293, 11582, 312, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45294, 11582, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45271, 20431, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45272, 20431, 56, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45287, 20436, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45288, 20436, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45273, 20432, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45274, 20432, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45275, 20432, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45276, 20432, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45285, 20435, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45286, 20435, 105, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45289, 20436, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45317, 20444, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45318, 20444, 189, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45319, 20444, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (45320, 20444, 8, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45321, 20444, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45322, 20444, 283, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (45299, 20440, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45300, 20440, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45301, 20440, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45302, 20440, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45323, 20447, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45324, 20447, 283, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45325, 20447, 49, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45329, 20448, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45330, 20448, 283, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45331, 20448, 92, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13048, 10492, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45401, 20458, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45402, 20458, 234, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45326, 20449, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45327, 20449, 30, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45328, 20449, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45336, 20396, 224, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45337, 20396, 112, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45357, 20400, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45358, 20400, 224, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45359, 20400, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45360, 20403, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45361, 20403, 93, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45362, 20403, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45366, 20286, 64, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45370, 11095, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45371, 11095, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45372, 11095, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (45373, 11095, 5, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45403, 20458, 240, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45404, 20458, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45405, 20458, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45453, 20486, 142, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45454, 20486, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45455, 20486, 154, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38777, 17596, 170, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (38778, 17596, 114, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (45378, 15237, 15, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45406, 20458, 225, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (45407, 20459, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45379, 20451, 25, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45380, 20451, 82, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45385, 20453, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45386, 20453, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45387, 20453, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (4550, 2045, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45392, 20455, 213, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45464, 20489, 154, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45465, 20489, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21370, 13448, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13049, 10492, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45446, 10492, 76, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45408, 20459, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (41811, 17478, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45409, 20472, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45410, 20472, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45411, 20472, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45315, 20446, 75, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45316, 20446, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45351, 20401, 286, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45312, 20445, 201, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45313, 20445, 186, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45314, 20445, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45381, 20452, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45382, 20452, 21, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45383, 20452, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6708, 3609, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45352, 20401, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45353, 20401, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38348, 19961, 86, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (38349, 19961, 234, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (45250, 19961, 307, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45332, 20398, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45388, 20454, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45389, 20454, 70, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45390, 20454, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45333, 20398, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45334, 20398, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45335, 20398, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45374, 20404, 224, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45375, 20404, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45376, 20404, 340, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19256, 8078, 83, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45239, 8078, 249, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45341, 20397, 95, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (45342, 20397, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45343, 20397, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45344, 20397, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45345, 20397, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45338, 20399, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45339, 20399, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45340, 20399, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45377, 20404, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45295, 20439, 138, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45296, 20439, 93, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45297, 20439, 220, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45298, 20439, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45309, 20443, 235, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45310, 20443, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45311, 20443, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45303, 20441, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45304, 20441, 277, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45305, 20441, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45412, 20473, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45413, 20473, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45414, 20473, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45415, 20474, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45416, 20474, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45417, 20474, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45418, 20474, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45419, 20475, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45420, 20475, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45421, 20475, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45422, 20476, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45423, 20476, 102, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45424, 20476, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45425, 20476, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45426, 20477, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45427, 20477, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45428, 20477, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45429, 20478, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45430, 20478, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45431, 20478, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45432, 20478, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45433, 20479, 313, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45434, 20479, 260, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45435, 20479, 278, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (45436, 20479, 43, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (45437, 20480, 56, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45438, 20480, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45439, 20480, 123, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45440, 20480, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45441, 20481, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45442, 20481, 260, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45443, 20483, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45444, 20483, 327, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45445, 20483, 84, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45450, 20485, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45451, 20485, 251, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45452, 20485, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45460, 20490, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45461, 20490, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45462, 20490, 94, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45393, 20456, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45394, 20456, 12, 15, 4);
INSERT INTO 'dancesformationsmap' VALUES (45466, 20489, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45470, 20488, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45471, 20488, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45447, 20484, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45448, 20484, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45449, 20484, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45456, 20491, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45457, 20491, 29, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45458, 20491, 235, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45459, 20491, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45367, 20450, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45368, 20450, 134, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (45369, 20450, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45363, 20316, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45364, 20316, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45365, 20316, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45395, 20457, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45396, 20457, 8, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45397, 20457, 234, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (45398, 20457, 112, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45399, 20457, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45467, 20487, 5, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45468, 20487, 92, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45469, 20487, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45472, 20488, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45473, 20488, 142, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45463, 20490, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45563, 20522, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45477, 20493, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45478, 20493, 25, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45479, 20493, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (45480, 20493, 92, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (45485, 6786, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45486, 6786, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45487, 6786, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45523, 20497, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45524, 20497, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45525, 20497, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45490, 8535, 326, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45491, 8535, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45492, 14481, 296, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45493, 14481, 220, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45494, 14481, 1, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (45495, 14481, 330, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (21884, 13357, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45500, 17763, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45501, 17763, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45502, 17765, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45503, 17765, 9, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (45504, 17765, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45505, 17765, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (45506, 17762, 56, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45507, 17762, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45508, 19132, 356, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45509, 19132, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45510, 20494, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45511, 20494, 240, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45512, 20494, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45496, 20495, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45497, 20495, 110, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45498, 20495, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45499, 20495, 29, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (45513, 16202, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45514, 16202, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45515, 20496, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45516, 20496, 234, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (45517, 20496, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45518, 20496, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45519, 10261, 15, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45520, 4837, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45521, 4837, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45522, 4837, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45526, 2093, 162, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45527, 2093, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45528, 2093, 72, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (45529, 2093, 176, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (45530, 20498, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45531, 20498, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45532, 13769, 254, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45533, 13769, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45597, 20523, 92, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45598, 20523, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18180, 12511, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45599, 20523, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45600, 20524, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45534, 20499, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45535, 20499, 334, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45536, 20500, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45537, 20500, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45538, 20500, 120, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (45539, 20500, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45540, 20500, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45601, 20524, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45602, 20524, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45603, 20524, 154, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45545, 20502, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45546, 20502, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45547, 20502, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45541, 20501, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45542, 20501, 366, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45543, 20501, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45544, 20501, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45553, 830, 224, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (45554, 830, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43824, 20290, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45556, 20516, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45561, 20512, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45569, 20508, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45570, 20508, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45571, 20508, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45572, 20508, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45573, 20509, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45574, 20509, 189, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45575, 20509, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45576, 20509, 42, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (44802, 6013, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45555, 20514, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45577, 20514, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11762, 10310, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45559, 20518, 296, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45581, 20518, 56, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45582, 20518, 162, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45583, 20518, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45549, 20513, 213, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45550, 20513, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (9777, 9368, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45548, 9368, 72, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (45564, 20506, 95, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (45565, 20506, 183, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (45566, 20506, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45551, 6071, 111, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45552, 6071, 148, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45346, 20402, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45347, 20402, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45348, 20402, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45349, 20402, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45596, 20535, 119, 3, 4);
INSERT INTO 'dancesformationsmap' VALUES (45560, 20519, 10, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45584, 20519, 64, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45562, 20520, 193, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (45588, 20520, 176, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45589, 20520, 72, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (45590, 20520, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45591, 18048, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45592, 18048, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45593, 18048, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45606, 20526, 365, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (45607, 20526, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45608, 20526, 138, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45609, 20527, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45610, 20528, 152, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45611, 20529, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45612, 20529, 241, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45613, 20529, 145, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (45614, 20530, 24, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45615, 20530, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45622, 20536, 93, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45623, 20536, 184, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45624, 20536, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (42079, 20143, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45621, 20534, 82, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (45585, 13796, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45586, 13796, 197, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45587, 13796, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45604, 20525, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45605, 20525, 114, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45626, 20537, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45627, 20537, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45628, 20537, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (54, 89, 43, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (45488, 3629, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45489, 3629, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45481, 20317, 228, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45632, 20539, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45633, 20539, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45634, 20540, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45635, 20540, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45636, 20540, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45482, 20317, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45578, 20515, 56, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45579, 20515, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45557, 20517, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45558, 20517, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45483, 20317, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45629, 20538, 76, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45630, 20538, 91, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45631, 20538, 158, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45646, 20545, 313, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45647, 20545, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (45648, 20546, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45649, 20546, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45650, 20546, 86, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (45654, 20548, 134, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (45655, 20548, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45656, 20549, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45657, 20549, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (45658, 20550, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45659, 20550, 67, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (45660, 20551, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45661, 20551, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45662, 20551, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45663, 20551, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45664, 20551, 251, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (45665, 20551, 273, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (45666, 20551, 23, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (45672, 18383, 17, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33903, 19166, 384, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45673, 19166, 76, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (35777, 19409, 384, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45674, 19409, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45675, 18671, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45676, 18671, 260, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45677, 18671, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45678, 107, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45683, 6718, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45684, 6718, 22, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45685, 6718, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45690, 20555, 123, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (45691, 20555, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45692, 20556, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45693, 20556, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45694, 20556, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (45695, 20557, 24, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45696, 20557, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45697, 20557, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45698, 20557, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45699, 20558, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45700, 20558, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45701, 20558, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45702, 20558, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45400, 20457, 193, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (45708, 16729, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45709, 16729, 103, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45710, 3094, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45711, 3094, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45712, 3094, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45713, 20560, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45714, 20560, 129, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45715, 20560, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45716, 20560, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45717, 20560, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45724, 17191, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45725, 17191, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45726, 17191, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45727, 16671, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45728, 16671, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45729, 16671, 307, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45730, 20517, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45731, 20517, 36, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29908, 17621, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (29909, 17621, 154, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45580, 20515, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45722, 20515, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45723, 20515, 249, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45703, 20559, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45704, 20559, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45705, 20559, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45706, 20559, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45707, 20559, 123, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45484, 20317, 154, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22260, 14430, 142, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22261, 14430, 260, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22263, 14430, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45718, 20561, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45719, 20561, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45753, 20567, 96, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (45740, 20564, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45741, 20564, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45742, 20564, 16, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45743, 20564, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45754, 20568, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45734, 20315, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45735, 20315, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45640, 20542, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45641, 20542, 92, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45642, 20542, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45667, 20552, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45668, 20552, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45686, 2331, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45687, 2331, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45688, 2331, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45744, 20565, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45745, 20565, 1, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (45746, 20565, 70, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45737, 20320, 359, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45738, 20320, 92, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45739, 20320, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45670, 20553, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45671, 20553, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45616, 20531, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45617, 20531, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45763, 20571, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45651, 20547, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45652, 20547, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45653, 20547, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45764, 20571, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45618, 20532, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45619, 20532, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45679, 20554, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45762, 20570, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45680, 20554, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45681, 20554, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45750, 20566, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45751, 20566, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45752, 20566, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45720, 20562, 112, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45721, 20562, 23, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (32882, 16612, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45620, 20533, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45625, 20533, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45594, 20535, 235, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45595, 20535, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45637, 20541, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45638, 20541, 240, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45639, 20541, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45768, 20572, 156, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45769, 20572, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45755, 20568, 30, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45756, 20568, 156, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45757, 20568, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45758, 20569, 33, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45759, 20569, 156, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45760, 20569, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45766, 20573, 156, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45767, 20573, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1940, 3672, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (5086, 3672, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30798, 18017, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30799, 18017, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45306, 20442, 326, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45307, 20442, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45308, 20442, 26, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (45474, 20492, 5, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45475, 20492, 283, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45476, 20492, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20375, 13159, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (20376, 13159, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31434, 453, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15869, 11693, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15870, 11693, 119, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (15871, 11693, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45736, 20315, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45771, 20315, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (41667, 17239, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41668, 17239, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (41669, 17239, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (193, 338, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45772, 338, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45773, 338, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45774, 338, 119, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45790, 11465, 92, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (23018, 14743, 376, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (23019, 14743, 102, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (10204, 9579, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10205, 9579, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (10206, 9579, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21094, 9579, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21095, 9579, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45775, 9579, 112, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (45844, 20609, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5238, 4102, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8111, 4102, 119, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (2775, 5308, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (5637, 5308, 119, 17, 6);
INSERT INTO 'dancesformationsmap' VALUES (23906, 5308, 23, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (45384, 20452, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36614, 19635, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (36615, 19635, 355, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (36616, 19635, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (36617, 19635, 222, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (39324, 2170, 23, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (39325, 2170, 226, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (39326, 2170, 365, 93, 1);
INSERT INTO 'dancesformationsmap' VALUES (45798, 13539, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45799, 13539, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45800, 20593, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45801, 20593, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45802, 20593, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45803, 20593, 303, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45804, 20594, 318, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (45805, 20594, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45806, 20595, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45807, 20596, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45808, 20596, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45809, 20597, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45810, 20597, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45811, 20597, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45812, 20597, 185, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26251, 16040, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (26252, 16040, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26253, 16040, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (26254, 16040, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26255, 16040, 373, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (408, 729, 56, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (4119, 729, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45019, 729, 36, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (93, 153, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22691, 153, 248, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45776, 20575, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45777, 20575, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45778, 20575, 132, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (45779, 20575, 7, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (20443, 13181, 260, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (20444, 13181, 183, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (3963, 301, 58, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (6315, 301, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45783, 20577, 273, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45784, 20577, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45785, 20577, 45, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (45643, 20543, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45644, 20543, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45645, 20543, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37395, 19785, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (14966, 11465, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (14967, 11465, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45791, 16040, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45780, 20576, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45781, 20576, 213, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45782, 20576, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30683, 17993, 2, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (30684, 17993, 29, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (30685, 17993, 86, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (30686, 17993, 112, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (30687, 17993, 373, 0, 0);
INSERT INTO 'dancesformationsmap' VALUES (45813, 20597, 66, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11333, 10129, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45797, 10129, 23, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (21892, 14330, 111, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21893, 14330, 17, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21894, 14330, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21895, 14330, 30, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21896, 14330, 365, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (45814, 20598, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45815, 20598, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45816, 20598, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (45817, 20599, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45818, 20599, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45819, 20599, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45820, 20599, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45821, 20600, 66, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45822, 20600, 185, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45823, 20600, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45824, 20600, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45825, 20601, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45826, 20601, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45827, 20601, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45828, 20602, 45, 19, 3);
INSERT INTO 'dancesformationsmap' VALUES (45829, 20603, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45830, 20603, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45831, 20603, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45832, 20603, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45833, 20604, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45834, 20604, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45835, 20604, 39, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45669, 20552, 23, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (25029, 15634, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45836, 20605, 321, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (25030, 15634, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (25031, 15634, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25032, 15634, 82, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (25033, 15634, 192, 40, 1);
INSERT INTO 'dancesformationsmap' VALUES (45837, 20606, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45838, 20606, 42, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (45839, 20606, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45840, 20607, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45841, 20607, 67, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45842, 20608, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45843, 20608, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45770, 20574, 105, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45747, 20565, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45748, 20565, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (45749, 20565, 46, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (45786, 20578, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45787, 20578, 67, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45788, 20578, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (45789, 20578, 72, 4, 3);
INSERT INTO 'dancesformationsmap' VALUES (45761, 20570, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45733, 20563, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20377, 13159, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (20378, 13159, 112, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (20419, 13173, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20420, 13173, 224, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (37396, 19785, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37397, 19785, 23, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (11732, 4102, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (30221, 9800, 188, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (30222, 9800, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7390, 7523, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (7391, 7523, 365, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (45848, 20610, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45849, 20610, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45850, 20611, 27, 1, 6);
INSERT INTO 'dancesformationsmap' VALUES (45851, 20611, 62, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (45852, 20612, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45853, 20612, 314, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45854, 20612, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (45855, 20613, 365, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45856, 20613, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45857, 20613, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45858, 20613, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45859, 20614, 1, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (45860, 20614, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45861, 20614, 186, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45862, 20615, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45863, 20615, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45864, 20615, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45865, 20616, 33, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (45866, 20616, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45867, 20616, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (45868, 20617, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45869, 20617, 365, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45870, 20617, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45871, 20617, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13822, 10892, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13823, 10892, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13824, 10892, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20327, 11303, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (24628, 15418, 86, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45933, 20639, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45934, 20639, 1, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (45876, 20619, 65, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45877, 20619, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45878, 20619, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45908, 20636, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45909, 20636, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45792, 20579, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45793, 20579, 183, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45794, 20579, 296, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45795, 20579, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45796, 20579, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41210, 15594, 30, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (41211, 15594, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (41212, 15594, 8, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (34470, 15597, 49, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34471, 15597, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34472, 15597, 114, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34473, 15597, 181, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34474, 15597, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40467, 13752, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40468, 13752, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41436, 16865, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41437, 16865, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (41438, 16865, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41439, 16865, 365, 53, 1);
INSERT INTO 'dancesformationsmap' VALUES (41440, 16865, 328, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (45879, 20623, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45880, 20623, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8386, 8648, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8387, 8648, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8388, 8648, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45881, 20624, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45882, 20624, 353, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45883, 20624, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21785, 4904, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36572, 4904, 55, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (36573, 4904, 85, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (36574, 4904, 183, 49, 6);
INSERT INTO 'dancesformationsmap' VALUES (45872, 20618, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45873, 20618, 8, 2, 3);
INSERT INTO 'dancesformationsmap' VALUES (45935, 20639, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (1543, 2935, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12029, 2935, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30517, 17898, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30518, 17898, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30519, 17898, 354, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30520, 17898, 224, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30521, 17898, 225, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (6148, 6836, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (2696, 5155, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45889, 3624, 8, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (45890, 3624, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45891, 4101, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45892, 4101, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45893, 4101, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45894, 4101, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45910, 20636, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (45905, 20637, 314, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45906, 20637, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45845, 20609, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45846, 20609, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45847, 20609, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11080, 10016, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11081, 10016, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11190, 10016, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11191, 10016, 188, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (43246, 10016, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43247, 10016, 234, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (45895, 20632, 154, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (45896, 20632, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45897, 20632, 165, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32663, 18537, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (491, 896, 24, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (19039, 896, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19040, 896, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45907, 20637, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3550, 6705, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (7040, 6705, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43939, 6705, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1943, 3681, 96, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45911, 3681, 119, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45912, 3681, 263, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (1452, 2744, 263, 0, 2);
INSERT INTO 'dancesformationsmap' VALUES (6582, 2744, 82, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11725, 10303, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28518, 16802, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45898, 20633, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45899, 20633, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45900, 20633, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (45901, 20633, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45902, 20633, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3383, 6406, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6007, 6406, 86, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15480, 6406, 30, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (15481, 6406, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (44080, 6406, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (3054, 5832, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45913, 5832, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45915, 15712, 87, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (45916, 15712, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (45917, 15712, 193, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (45918, 15712, 27, 81, 2);
INSERT INTO 'dancesformationsmap' VALUES (45919, 15712, 90, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (45920, 15712, 9, 122, 2);
INSERT INTO 'dancesformationsmap' VALUES (10940, 7648, 112, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45921, 7648, 30, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (45903, 20634, 142, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45904, 20634, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (12306, 1404, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (12307, 1404, 75, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12309, 1404, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45926, 20635, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45927, 20635, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45928, 20635, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45929, 20635, 149, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45930, 17356, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45931, 17356, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45932, 17356, 45, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (22796, 14679, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22797, 14679, 132, 12, 2);
INSERT INTO 'dancesformationsmap' VALUES (22798, 14679, 158, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1754, 3333, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41747, 3333, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1576, 3001, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (4854, 3001, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45936, 3001, 102, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22273, 14436, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22274, 14436, 17, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45922, 6264, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45923, 6264, 39, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (45924, 6264, 71, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45925, 6264, 112, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (45886, 20625, 317, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45887, 20625, 42, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45888, 20625, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45884, 20620, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45885, 20620, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45874, 20618, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45875, 20618, 27, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (39982, 5812, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39983, 5812, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39984, 5812, 1, 53, 2);
INSERT INTO 'dancesformationsmap' VALUES (40820, 20099, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40821, 20099, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40822, 20099, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3701, 6972, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (10292, 6972, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (32597, 18517, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8163, 1479, 143, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (8164, 1479, 38, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (8165, 1479, 66, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (24942, 1479, 301, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (29439, 17133, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29440, 17133, 17, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (29441, 17133, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (29442, 17133, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32598, 18517, 340, 2, 6);
INSERT INTO 'dancesformationsmap' VALUES (32599, 18517, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (32600, 18517, 225, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (33205, 18517, 210, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45941, 17826, 70, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45942, 17826, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45943, 17826, 49, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33206, 18517, 209, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (2919, 5574, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36985, 16792, 43, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (36986, 16792, 82, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (45937, 20640, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45938, 20640, 165, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45939, 20640, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45940, 20640, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (13418, 10578, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13419, 10578, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45944, 20641, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45945, 20641, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23743, 6798, 183, 29, 3);
INSERT INTO 'dancesformationsmap' VALUES (30128, 6798, 42, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (28967, 16939, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (28968, 16939, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39123, 17141, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39124, 17141, 52, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (39125, 17141, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39126, 17141, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29570, 5915, 41, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (17242, 10963, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (17243, 10963, 119, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43090, 10963, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14353, 5316, 185, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (14354, 5316, 202, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14355, 5316, 121, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38750, 19254, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38751, 19254, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34243, 14583, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34244, 14583, 129, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (34245, 14583, 240, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34246, 14583, 273, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (34247, 14583, 93, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (34248, 14583, 112, 53, 1);
INSERT INTO 'dancesformationsmap' VALUES (34249, 14583, 216, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (36455, 213, 51, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36456, 213, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (36457, 213, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36458, 213, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15848, 11685, 8, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (15849, 11685, 1, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (15850, 11685, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45946, 20642, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45947, 20642, 12, 2, 4);
INSERT INTO 'dancesformationsmap' VALUES (45948, 20642, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7452, 5222, 16, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (7748, 5222, 134, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9265, 5222, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (9266, 5222, 16, 6, 2);
INSERT INTO 'dancesformationsmap' VALUES (24076, 5260, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (28811, 5552, 157, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (28812, 5552, 1, 10, 4);
INSERT INTO 'dancesformationsmap' VALUES (25605, 15866, 27, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (25606, 15866, 102, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (25607, 15866, 202, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (25608, 15866, 112, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (25609, 15866, 43, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38224, 15866, 23, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (38225, 15866, 249, 39, 2);
INSERT INTO 'dancesformationsmap' VALUES (26720, 14673, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (26721, 14673, 172, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26722, 14673, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (31259, 18228, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31260, 18228, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (31261, 18228, 96, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (31262, 18228, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5771, 5688, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (24046, 3561, 41, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (24047, 3561, 19, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24048, 3561, 157, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (11737, 5802, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (9565, 5804, 106, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15457, 11398, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (24332, 11398, 42, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (24333, 11398, 321, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19134, 5579, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19135, 5579, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (7378, 7511, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7379, 7511, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43752, 7511, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7905, 8289, 69, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (22055, 5952, 41, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22056, 5952, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23722, 5992, 183, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (23723, 5992, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (19143, 5995, 7, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (37741, 6012, 29, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (37742, 6012, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (37743, 6012, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37744, 6012, 1, 29, 4);
INSERT INTO 'dancesformationsmap' VALUES (10018, 9501, 21, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10019, 9501, 112, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (9522, 9111, 1, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (9523, 9111, 132, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (12120, 9111, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45952, 5455, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (40238, 12805, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (40239, 12805, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40240, 12805, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40241, 12805, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8586, 8709, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8587, 8709, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (8588, 8709, 45, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28769, 13582, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28770, 13582, 18, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28771, 13582, 96, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (28772, 13582, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (41993, 17964, 213, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (41994, 17964, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41995, 17964, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41996, 17964, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10694, 9862, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10695, 9862, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13650, 10793, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13651, 10793, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (13652, 10793, 221, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (24928, 15341, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24929, 15341, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (24930, 15341, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45949, 5455, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45950, 5455, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45951, 5455, 43, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (45953, 2386, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (10509, 9758, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45954, 20659, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45955, 20659, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45956, 20659, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (10154, 7654, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10155, 7654, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (10156, 7654, 221, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38752, 19254, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (14356, 5316, 39, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14357, 5316, 33, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (15206, 11525, 75, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (17836, 9250, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17837, 9250, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (17838, 9250, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (15207, 11525, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45957, 20661, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45958, 20661, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45959, 20661, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17839, 9250, 71, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (17840, 9250, 119, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (22744, 14651, 82, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (22745, 14651, 23, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (22747, 14651, 386, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (30329, 14728, 59, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (26494, 13614, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26495, 13614, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26496, 13614, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26497, 13614, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9521, 9110, 42, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (3224, 6136, 145, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (33806, 5915, 176, 1, 8);
INSERT INTO 'dancesformationsmap' VALUES (45960, 20663, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45961, 20663, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45962, 20663, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (45963, 20664, 33, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45964, 20664, 58, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (45965, 20664, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45966, 20664, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35349, 15602, 56, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35350, 15602, 52, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (35351, 15602, 16, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35352, 15602, 133, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35353, 15602, 90, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46066, 19854, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8364, 8635, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45967, 8635, 148, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45968, 8635, 96, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (45969, 8635, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10462, 5307, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33775, 14441, 307, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33776, 14441, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (33751, 14443, 226, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33752, 14443, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (33753, 14443, 123, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33788, 14445, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25968, 14447, 78, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (25969, 14447, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (25970, 14447, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33818, 14448, 262, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (33819, 14448, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (33820, 14448, 9, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (22598, 14458, 173, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (27991, 16517, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27992, 16517, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (45978, 20318, 16, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45979, 20318, 125, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45980, 20318, 30, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45981, 20318, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45982, 20666, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45983, 20666, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45984, 20666, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45970, 20665, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46067, 19854, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (46068, 19854, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46069, 19854, 96, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (45689, 2331, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46014, 2858, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46015, 2858, 142, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46016, 20671, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46017, 20671, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46018, 20671, 91, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46019, 20671, 225, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46020, 20671, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46008, 5678, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46009, 5678, 265, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46010, 5678, 249, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46011, 5678, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6507, 1883, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29290, 1883, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45985, 20667, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45986, 20667, 26, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (45987, 20667, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44835, 20350, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44836, 20350, 84, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44837, 20350, 65, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45988, 20668, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45989, 20668, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45990, 20668, 125, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45991, 20668, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15494, 11562, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (38479, 19980, 383, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45992, 19980, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45993, 19980, 29, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (1055, 1960, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45994, 1960, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (45999, 17971, 65, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (9110, 3876, 105, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19820, 3876, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22996, 13847, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45995, 20669, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (45996, 20669, 186, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (45997, 20669, 56, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (45998, 20669, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46012, 5678, 183, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46013, 5678, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (46021, 17559, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46000, 20670, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46001, 20670, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46002, 20670, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46003, 20670, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (18478, 12166, 90, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (35127, 12166, 54, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35128, 12166, 209, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35129, 12166, 27, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (35130, 12166, 19, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (35131, 12166, 210, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (35132, 12166, 85, 113, 2);
INSERT INTO 'dancesformationsmap' VALUES (812, 1508, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (4373, 1508, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46004, 1508, 38, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46005, 1508, 183, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46006, 1508, 72, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (28274, 16724, 16, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (28275, 16724, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46007, 16724, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (27112, 2723, 43, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (27113, 2723, 33, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (46022, 17559, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (16228, 11797, 56, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (46033, 20676, 9, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (46030, 20675, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46031, 20675, 120, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46032, 20675, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46053, 20706, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46054, 20706, 156, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46049, 20704, 105, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20449, 13183, 206, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (34641, 19224, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (34642, 19224, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (34643, 19224, 76, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (8982, 7475, 65, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (8983, 7475, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29537, 2931, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46038, 3128, 96, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (46039, 3128, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46040, 3128, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46041, 3128, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46042, 20702, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46043, 20702, 318, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46044, 20702, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46028, 20645, 183, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (20450, 13183, 33, 19, 4);
INSERT INTO 'dancesformationsmap' VALUES (37043, 19717, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46045, 13286, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46046, 13286, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46047, 13286, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46048, 13286, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37044, 19717, 112, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46050, 20705, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46051, 20705, 26, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46052, 20705, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46055, 20706, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46056, 20706, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46057, 20707, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46058, 20707, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46059, 20707, 283, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46060, 20707, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46061, 20707, 373, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46062, 20708, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46063, 20708, 91, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46064, 20708, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46065, 20708, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32347, 14456, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (32348, 14456, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35702, 14456, 381, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (34644, 19224, 386, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46034, 20676, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (46029, 20645, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28905, 16909, 123, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (28906, 16909, 186, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46070, 20649, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46071, 20649, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46072, 20649, 183, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46073, 20649, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22482, 14568, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31923, 18305, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (31924, 18305, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46035, 20676, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46036, 20676, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (29598, 17410, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45971, 20665, 53, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (45972, 20665, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (45973, 20665, 4, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31925, 18305, 162, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (12562, 10401, 45, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46158, 20734, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12563, 10401, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23691, 15172, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23692, 15172, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23693, 15172, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23694, 15172, 91, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46074, 20718, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46075, 20718, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46076, 20718, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46077, 20718, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46078, 20719, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46079, 20719, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46080, 20719, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46081, 6545, 265, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46082, 6545, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46083, 6545, 95, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (46084, 6545, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (9509, 9104, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46181, 20742, 119, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (29232, 17014, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (29233, 17014, 280, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (29234, 17014, 83, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29235, 17014, 94, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (29236, 17014, 216, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (15007, 11482, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46162, 20736, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46163, 20736, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46164, 20736, 33, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46165, 20737, 313, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46085, 13894, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46086, 13894, 296, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46087, 13894, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46088, 13894, 72, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (46089, 20720, 10, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (46090, 20720, 48, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (46091, 20721, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46092, 20721, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46093, 20721, 96, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46094, 20721, 385, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46166, 20737, 119, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46167, 20737, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46168, 20737, 109, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46169, 20738, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46170, 20738, 26, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46102, 20723, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46103, 20723, 385, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46104, 20723, 96, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (46105, 20723, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (46106, 20724, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46107, 20724, 385, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46108, 20724, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46109, 20724, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46110, 20724, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46111, 20725, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46112, 20725, 385, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46113, 20725, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46114, 20725, 96, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (46095, 16025, 385, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46096, 19041, 385, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46097, 20722, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46098, 20722, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (46099, 20722, 385, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46100, 20722, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46101, 20722, 283, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46115, 20726, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46116, 20726, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46117, 20726, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46118, 19601, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46119, 19601, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46120, 19601, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46121, 19601, 156, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46122, 20727, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46123, 20727, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46124, 20727, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46125, 20727, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46171, 20738, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25382, 15790, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (25383, 15790, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46126, 15790, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46127, 20728, 42, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46128, 20728, 23, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (46129, 20728, 81, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (46130, 20728, 192, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (46131, 13778, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46132, 13778, 41, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46133, 13778, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46138, 20729, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46139, 20729, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46140, 20729, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46134, 17244, 112, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46135, 17244, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (46136, 17244, 93, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (46137, 17244, 249, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (46172, 20739, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46173, 20739, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46174, 20739, 297, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46175, 20740, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36048, 19476, 309, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (36049, 19476, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (36050, 19476, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46176, 20740, 84, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46177, 20740, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46187, 20744, 90, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46188, 20744, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46141, 20730, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46142, 20730, 69, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46143, 20730, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46144, 20730, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46145, 20730, 83, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46146, 20730, 193, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (46147, 20730, 1, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (46148, 20730, 66, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (46149, 20731, 5, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46150, 20731, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46151, 20731, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46152, 20732, 302, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46153, 20732, 49, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46154, 20732, 152, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46182, 20742, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (12564, 10401, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (4322, 1372, 77, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (30111, 1372, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (21014, 13315, 203, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (42944, 13315, 314, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42945, 13315, 183, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (46194, 20747, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46195, 20747, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46196, 20747, 134, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46178, 20741, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46179, 20741, 111, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46180, 20741, 69, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46023, 20674, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30850, 18038, 94, 17, 0);
INSERT INTO 'dancesformationsmap' VALUES (30851, 18038, 93, 25, 0);
INSERT INTO 'dancesformationsmap' VALUES (46184, 20743, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46185, 20743, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46186, 20743, 193, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46191, 20746, 25, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46192, 20746, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46193, 20746, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46197, 20747, 5, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31222, 18204, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (31223, 18204, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46198, 20748, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46199, 20748, 83, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46155, 20733, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46156, 20733, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46157, 20733, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46183, 20742, 283, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (30852, 18038, 28, 33, 0);
INSERT INTO 'dancesformationsmap' VALUES (12565, 10401, 22, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (26619, 16103, 18, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (26620, 16103, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26621, 16103, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25138, 15710, 134, 19, 8);
INSERT INTO 'dancesformationsmap' VALUES (46247, 20778, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46248, 20778, 91, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46249, 20778, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46189, 20745, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46190, 20745, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46205, 1064, 251, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46206, 1064, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26322, 16051, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (26323, 16051, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46250, 20778, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (25139, 15710, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35091, 19247, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (35092, 19247, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (35093, 19247, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46211, 20672, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46212, 20672, 164, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (46213, 20672, 2, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35094, 19247, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34288, 19187, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (36021, 18437, 10, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (36022, 18437, 386, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46200, 20673, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46201, 20673, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (46202, 20673, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46203, 20673, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46204, 20673, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46214, 11302, 188, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46215, 11302, 19, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46216, 11302, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (2436, 4652, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (5415, 4652, 78, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46217, 4652, 21, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46218, 4652, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (6232, 7111, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35457, 19307, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (35458, 19307, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (35459, 19307, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46219, 20753, 23, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (46220, 20753, 65, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (14145, 9474, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14146, 9474, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30914, 18078, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (46244, 20773, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28643, 16645, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (28644, 16645, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28645, 16645, 158, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28646, 16645, 354, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19305, 12633, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (19306, 12633, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19307, 12633, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (19292, 12630, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45354, 20401, 283, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45355, 20401, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45356, 20401, 96, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (33190, 18977, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (40489, 13766, 154, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (40490, 13766, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (40491, 13766, 386, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (40492, 13766, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46251, 20779, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46252, 20779, 72, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46253, 20779, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (46254, 20779, 84, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46255, 20779, 142, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22194, 13594, 143, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46227, 20770, 334, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46228, 20770, 283, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46229, 20770, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46230, 20770, 213, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46231, 17975, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46232, 17975, 325, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46233, 17975, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46234, 17975, 251, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46235, 17975, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (46240, 20772, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46241, 20772, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46242, 20772, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46243, 20772, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46236, 20771, 283, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46237, 20771, 312, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46238, 20771, 36, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46239, 20771, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31266, 18230, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31267, 18230, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46024, 20674, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46025, 20674, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2577, 4928, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (6869, 4928, 18, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (24540, 13365, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (29846, 986, 23, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (29847, 986, 36, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (22445, 14553, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46026, 20674, 121, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30458, 17884, 386, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (30459, 17884, 70, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (11524, 10269, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (16878, 5464, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27214, 16292, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27215, 16292, 386, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (27216, 16292, 83, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (641, 1173, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19715, 12913, 234, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (33064, 18683, 89, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (33065, 18683, 234, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (18457, 12542, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18458, 12542, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (44993, 20360, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (44994, 20360, 228, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44995, 20360, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38007, 20, 185, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38008, 20, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46258, 20, 386, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (42356, 19872, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42357, 19872, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (42358, 19872, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22446, 14553, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (22281, 14438, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22590, 14599, 262, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (28917, 16915, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9698, 9334, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1084, 2021, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44752, 2021, 332, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (44753, 2021, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30575, 17921, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (30576, 17921, 366, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (30577, 17921, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (30578, 17921, 367, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7462, 4857, 32, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (7463, 4857, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (44320, 4991, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (44321, 4991, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32524, 17321, 375, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25121, 15704, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8401, 3383, 386, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13565, 10768, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (17749, 12429, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41112, 15364, 386, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (41113, 15364, 58, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41114, 15364, 93, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (41115, 15364, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (41116, 15364, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32125, 18355, 386, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (32126, 18355, 340, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32226, 18355, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (32227, 18355, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36062, 19084, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (36063, 19084, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36064, 19084, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (16782, 2687, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23365, 15023, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46224, 20767, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43228, 10070, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (24323, 13132, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24718, 15432, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (24719, 15432, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (24720, 15432, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38442, 19972, 58, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38146, 19905, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38147, 19905, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46245, 20773, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46246, 20773, 71, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (46207, 20749, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46208, 20749, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46209, 20749, 70, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46221, 20766, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46222, 20766, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46223, 20766, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46256, 20780, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46257, 20780, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23366, 15023, 81, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (23367, 15023, 386, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (44076, 19566, 193, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35921, 19442, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35922, 19442, 386, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35923, 19442, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35924, 19442, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (29605, 17349, 110, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (5767, 5679, 386, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (31421, 5679, 249, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31422, 5679, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31423, 5679, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (42695, 13755, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31458, 18252, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (31459, 18252, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31460, 18252, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (22275, 14436, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (22277, 14436, 58, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (22278, 14436, 62, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (21665, 13817, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21666, 13817, 59, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18060, 12485, 92, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (20447, 13182, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (27448, 16367, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (27449, 16367, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (27450, 16367, 156, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27451, 16367, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27032, 16231, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27033, 16231, 185, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27034, 16231, 66, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (33981, 15503, 386, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (33982, 15503, 114, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (33983, 15503, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46260, 7171, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46261, 7171, 32, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (46262, 13911, 57, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46263, 13911, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46264, 13911, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46265, 13911, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46266, 13911, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46331, 20801, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (15699, 11620, 91, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (18061, 12486, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18062, 12486, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46309, 20795, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46310, 20795, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (46311, 20795, 188, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46312, 20795, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (8135, 1639, 114, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (36416, 19563, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (36417, 19563, 386, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19798, 12947, 386, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (19799, 12947, 4, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (19800, 12947, 93, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (19802, 12947, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14114, 11045, 69, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14115, 11045, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14116, 11045, 8, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14117, 11045, 93, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14118, 11045, 386, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14119, 11045, 91, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14120, 11045, 142, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14121, 11045, 9, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14122, 11045, 27, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14123, 11045, 87, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (14124, 11045, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (46273, 20784, 359, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46274, 20784, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46282, 20787, 162, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46283, 20787, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46284, 20787, 154, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46285, 20787, 36, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46286, 20787, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46296, 20791, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46290, 20789, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46291, 20789, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46349, 20806, 72, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (46350, 20806, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46269, 20782, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46292, 20790, 168, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46293, 20790, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46294, 20790, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46295, 20790, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46302, 20793, 162, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46303, 20793, 117, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46304, 20793, 210, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46305, 20793, 56, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (46332, 20801, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (28062, 16591, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (25268, 15747, 386, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25269, 15747, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25270, 15747, 21, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11312, 10118, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (28186, 16696, 26, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26516, 16075, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26517, 16075, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21148, 13350, 76, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (21149, 13350, 386, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (46308, 6268, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (9650, 9156, 56, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46297, 20791, 302, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46298, 20791, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46338, 17114, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46268, 20781, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46271, 20781, 131, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20418, 13173, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (14928, 11451, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (14929, 11451, 386, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38856, 20049, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (38857, 20049, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46316, 20049, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (28439, 16524, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46317, 20797, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46318, 20797, 23, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (46319, 20797, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46324, 20799, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46325, 20799, 224, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (46326, 20799, 225, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46327, 20799, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46328, 20800, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46329, 20800, 9, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (46330, 20800, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46306, 20794, 90, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46307, 20794, 296, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46279, 20786, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (38671, 20019, 154, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46339, 17114, 29, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (46340, 17114, 176, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46341, 17114, 183, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (15644, 11602, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46287, 20788, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46288, 20788, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46289, 20788, 21, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46335, 20788, 249, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (15645, 11602, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46342, 17114, 209, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (46343, 2026, 30, 23, 2);
INSERT INTO 'dancesformationsmap' VALUES (26132, 16007, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (26133, 16007, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9270, 1562, 133, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (26141, 16011, 111, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (26142, 16011, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46336, 20805, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (46337, 20805, 10, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46347, 1915, 143, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46272, 20783, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46344, 20783, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (46345, 20783, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46346, 20783, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46348, 1915, 8, 29, 4);
INSERT INTO 'dancesformationsmap' VALUES (46275, 20785, 302, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46276, 20785, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46351, 20807, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46352, 20807, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (21515, 13701, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (38672, 20019, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (38673, 20019, 224, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46313, 20796, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46314, 20796, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46315, 20796, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46267, 11451, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46299, 20792, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46300, 20792, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46301, 20792, 155, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18063, 12486, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46333, 20804, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46334, 20804, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46320, 20798, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46321, 20798, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46322, 20798, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46323, 20798, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23350, 11170, 297, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (21516, 13701, 39, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46353, 20808, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46354, 20808, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46355, 20808, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46356, 20808, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (26134, 16008, 269, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (26135, 16008, 142, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46474, 20838, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46361, 20348, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46357, 20809, 132, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46362, 20809, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46363, 20809, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46364, 20811, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46365, 20811, 77, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46366, 20811, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46367, 20812, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46368, 20812, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46369, 20812, 1, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (46370, 20813, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46371, 20813, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46372, 20813, 58, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (46373, 20814, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46374, 20814, 7, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (46375, 20814, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46376, 20815, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46377, 20815, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46378, 20815, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46379, 20815, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46380, 20815, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (46381, 20816, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (46382, 20816, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46475, 20838, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46383, 20817, 56, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46384, 20817, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (46385, 20817, 120, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46386, 20817, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46387, 20817, 381, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46388, 20817, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46389, 20817, 213, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46390, 20818, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46391, 20818, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46392, 20818, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46408, 20821, 1, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46409, 20821, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46410, 20821, 69, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46411, 20821, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46482, 20840, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46483, 20840, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46484, 20840, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46485, 20841, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46476, 20839, 55, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46477, 20839, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46478, 20839, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46479, 20839, 251, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46397, 20769, 189, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46398, 20769, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46399, 20769, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46400, 20769, 203, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (46401, 20769, 188, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46358, 20810, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (46359, 20810, 58, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46360, 20810, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (46405, 20820, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46406, 20820, 75, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46407, 20820, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46412, 20822, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46413, 20822, 332, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46414, 20822, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46415, 20822, 7, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (46416, 20822, 72, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (46426, 20826, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46427, 20826, 32, 20, 2);
INSERT INTO 'dancesformationsmap' VALUES (46428, 20826, 43, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (46429, 20827, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46430, 20827, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46431, 20827, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46432, 20828, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46433, 20828, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46434, 20828, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46435, 20828, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46436, 20828, 162, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46437, 20829, 24, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46438, 20829, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46439, 20829, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46440, 20829, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46441, 20830, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46442, 20830, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46443, 20830, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46444, 20830, 249, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46445, 20830, 1, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (46446, 20830, 7, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (46447, 20831, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46448, 20831, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46449, 20831, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46450, 20832, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46451, 20832, 7, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46452, 20832, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46453, 20832, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46454, 20832, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46455, 20832, 202, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (46456, 20833, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46457, 20833, 7, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (46458, 20834, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46459, 20834, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46460, 20834, 84, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46461, 20834, 221, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46462, 20835, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46463, 20835, 103, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46464, 20835, 26, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46465, 20835, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46466, 20836, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46467, 20836, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (46468, 20836, 61, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46469, 20836, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46470, 20837, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46471, 20837, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46472, 20837, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46473, 20837, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46486, 20841, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46487, 20841, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46488, 20842, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46489, 20842, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46490, 20842, 7, 10, 1);
INSERT INTO 'dancesformationsmap' VALUES (46491, 20842, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46492, 20842, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46493, 20843, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46494, 20843, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46495, 20843, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46496, 20843, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46497, 20844, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46498, 20844, 112, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (46499, 20844, 51, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46500, 20844, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46506, 20846, 43, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (46507, 20846, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46508, 20847, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46509, 20847, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46510, 20847, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46511, 20848, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (46512, 20848, 8, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (46513, 20848, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46514, 20848, 341, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46515, 20849, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46516, 20849, 7, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (46517, 20849, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46518, 20850, 64, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46519, 20850, 9, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46520, 20850, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46417, 20823, 112, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (46422, 20825, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46423, 20825, 112, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (46424, 20825, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46425, 20825, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46418, 20823, 19, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46419, 20823, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46521, 20850, 43, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (46522, 20851, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46523, 20851, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46524, 20851, 273, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46525, 20851, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46526, 20851, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46527, 20852, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46528, 20852, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46529, 20852, 134, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46530, 20852, 76, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46531, 20852, 96, 39, 1);
INSERT INTO 'dancesformationsmap' VALUES (46393, 20768, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46394, 20768, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46395, 20768, 114, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46396, 20768, 235, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (46420, 20824, 24, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46421, 20824, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46403, 20819, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46404, 20819, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46532, 20853, 148, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46533, 20853, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46534, 20853, 168, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46535, 20853, 25, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46536, 20853, 119, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (46537, 20854, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46538, 20854, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46539, 20854, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46540, 20854, 221, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46541, 20855, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46542, 20855, 27, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46543, 20855, 125, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46544, 20856, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46545, 20856, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46546, 20856, 112, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (46547, 20856, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46548, 20857, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46549, 20857, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46550, 20857, 72, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (46551, 20858, 189, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46552, 20858, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46553, 20859, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46554, 20859, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46555, 20859, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (17973, 12450, 7, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46556, 12450, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46557, 20861, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46558, 20861, 10, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (46559, 20861, 121, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46560, 20861, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46561, 20862, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46562, 20862, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (46563, 20862, 154, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (46564, 20862, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46565, 20864, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (46566, 20864, 258, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (46567, 20864, 134, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46568, 20864, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46594, 20871, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46595, 20871, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (45146, 20390, 86, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (45147, 20390, 314, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (14914, 11443, 78, 250, 2);
INSERT INTO 'dancesformationsmap' VALUES (21573, 5480, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46571, 60, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (37310, 19085, 93, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (46501, 20845, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46502, 20845, 249, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46503, 20845, 32, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46504, 20845, 94, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46505, 20845, 149, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46277, 20785, 12, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (46575, 20866, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46576, 20866, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46572, 20865, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46573, 20865, 10, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46574, 20865, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (41650, 17232, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46577, 20867, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46578, 20867, 134, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (46579, 20867, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46580, 20868, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46581, 20868, 180, 1, 9);
INSERT INTO 'dancesformationsmap' VALUES (46582, 20868, 69, 1, 17);
INSERT INTO 'dancesformationsmap' VALUES (46583, 20868, 365, 1, 25);
INSERT INTO 'dancesformationsmap' VALUES (46584, 19711, 125, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46609, 20874, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46610, 20874, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46611, 20874, 9, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46585, 20869, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46586, 20869, 192, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46587, 20869, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46588, 20869, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46592, 14116, 64, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46593, 14116, 178, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13741, 10843, 193, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (13743, 10844, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13744, 10844, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46632, 20881, 213, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46633, 20881, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46634, 20881, 36, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (46636, 20882, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46637, 20882, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46638, 20882, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46600, 20873, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46601, 20873, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (46602, 20873, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46603, 20873, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46604, 20873, 123, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46605, 20873, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46606, 9363, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46607, 9363, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46608, 9363, 183, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (44116, 20311, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44117, 20311, 36, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (44118, 20311, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (44119, 20311, 5, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46643, 20884, 333, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46644, 20884, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46645, 20884, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46646, 20884, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (46647, 20884, 214, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46614, 20875, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46615, 20875, 102, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46617, 20876, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46618, 20876, 224, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46619, 20876, 145, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46630, 20880, 119, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (46631, 20880, 129, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46641, 20883, 165, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46642, 20883, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (46612, 20874, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46624, 20878, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46620, 20877, 132, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46621, 20877, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46622, 20877, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46623, 20877, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46627, 20879, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46628, 20879, 321, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46629, 20879, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46596, 20871, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46635, 20881, 23, 30, 1);
INSERT INTO 'dancesformationsmap' VALUES (13757, 10848, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46648, 20885, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46649, 20885, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46616, 20875, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46657, 20888, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46658, 20888, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46659, 20888, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46660, 1906, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (46661, 1906, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46662, 1906, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46663, 1906, 168, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46664, 20891, 322, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46665, 20891, 55, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46666, 20891, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46667, 20891, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43123, 20215, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (43124, 20215, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (43125, 20215, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43126, 20215, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (24502, 14995, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (24503, 14995, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46625, 20878, 92, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (46626, 20878, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46677, 811, 365, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (46678, 811, 23, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (46679, 811, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46672, 20893, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46673, 20893, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46674, 20893, 384, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46680, 20893, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46675, 7630, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46681, 20679, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46676, 7630, 183, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (13755, 10847, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (46653, 20887, 17, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46654, 20887, 119, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (46655, 20887, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46650, 20886, 154, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (46651, 20886, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46652, 20886, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46589, 20863, 1, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (46590, 20863, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46591, 20863, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46597, 20872, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46598, 20872, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46599, 20872, 189, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (46639, 20882, 154, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46640, 20882, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9326, 5956, 183, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (9327, 5956, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46685, 5956, 36, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46686, 5956, 5, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46687, 20682, 278, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46688, 20682, 61, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46689, 20682, 134, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46690, 20682, 33, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (46691, 20682, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46682, 20679, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46683, 20679, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46684, 20679, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (34605, 9876, 183, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (44949, 20358, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39432, 14675, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (39433, 14675, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (39434, 14675, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46750, 20910, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46751, 20910, 39, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46712, 20899, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46713, 20899, 58, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46714, 20899, 93, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46715, 20899, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46716, 20899, 213, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18343, 10589, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (18344, 10589, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (34662, 8493, 117, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (34663, 8493, 315, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (34664, 8493, 27, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (34665, 8493, 157, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (18345, 10589, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40589, 13933, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46769, 20915, 119, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46770, 20915, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46696, 20896, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46697, 20896, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46698, 20896, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46699, 20896, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46762, 20914, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46803, 20925, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46804, 20925, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46763, 20914, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46764, 20914, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46796, 20923, 158, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (14699, 11294, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14700, 11294, 103, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (39340, 2640, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46656, 20887, 23, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46797, 20923, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46739, 20906, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (39298, 1385, 157, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39299, 1385, 29, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (46702, 20898, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46703, 20898, 38, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46704, 20897, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46705, 20897, 42, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (46706, 20897, 262, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (46707, 20897, 5, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46708, 18756, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46709, 18756, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46710, 18756, 125, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46711, 18756, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31205, 12186, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46613, 20874, 302, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46781, 20920, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46777, 20919, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46778, 20919, 185, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46724, 20902, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46725, 20902, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46726, 20902, 217, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46727, 20902, 213, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46720, 20901, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46721, 20901, 213, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46722, 20901, 249, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46723, 20901, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46732, 20904, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46733, 20904, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46734, 20904, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46735, 20904, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46736, 20904, 189, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46737, 20904, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (46728, 20903, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46729, 20903, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46730, 20903, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46731, 20903, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46765, 20914, 109, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46766, 20914, 273, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46767, 20914, 7, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (46805, 20925, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46800, 20924, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46801, 20924, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46773, 20917, 119, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46771, 20916, 71, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46756, 20912, 168, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46779, 20919, 202, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46772, 20917, 263, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46717, 20900, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46789, 20786, 42, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (46775, 20918, 217, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46776, 20918, 379, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46752, 20910, 250, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46798, 20786, 294, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46746, 20909, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46692, 20895, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46693, 20895, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46694, 20895, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46695, 20895, 285, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (46700, 20895, 92, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (46701, 20895, 192, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (46757, 20912, 188, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46744, 20908, 20, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46745, 20908, 189, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46759, 20913, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46718, 20900, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46719, 20900, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46780, 20920, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46799, 20786, 302, 4, 3);
INSERT INTO 'dancesformationsmap' VALUES (46802, 20924, 221, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (39300, 1385, 43, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (46747, 20909, 75, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46748, 20909, 315, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46786, 20922, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46787, 20922, 86, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46788, 20922, 32, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (46738, 20906, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46753, 20911, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46754, 20911, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46755, 20911, 17, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46743, 20908, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46740, 20907, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46741, 20907, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46742, 20907, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46760, 20913, 10, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46761, 20913, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46768, 20915, 17, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46795, 20445, 145, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46774, 20918, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46758, 20912, 354, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46749, 20910, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (23331, 14994, 102, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46806, 20925, 73, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46807, 20925, 71, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46808, 20927, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46809, 20927, 154, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46810, 20927, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46811, 20927, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46812, 11839, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27862, 14796, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (27863, 14796, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27864, 14796, 189, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (19107, 2518, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19108, 2518, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46813, 5604, 119, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46814, 5604, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46815, 5604, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46818, 6679, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (14044, 10958, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40268, 7890, 216, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46790, 16595, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46791, 16595, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46792, 16595, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46793, 16595, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46794, 16595, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (11192, 10073, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11193, 10073, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46895, 20953, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46896, 20953, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46897, 20953, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46822, 6903, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46823, 6903, 184, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46824, 6903, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46825, 6903, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46826, 6903, 95, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46898, 20953, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46903, 20953, 62, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (18594, 12625, 183, 27, 3);
INSERT INTO 'dancesformationsmap' VALUES (46827, 20931, 269, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46828, 20931, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46829, 20931, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46830, 20931, 287, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46831, 20931, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46832, 20931, 192, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (46819, 20930, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46820, 20930, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46821, 20930, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46037, 20676, 330, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42155, 18586, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (42156, 18586, 19, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (42157, 18586, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46836, 20933, 184, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (46837, 20933, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46838, 20934, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46839, 20934, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46840, 20934, 69, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (46841, 20935, 134, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (46842, 20935, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46843, 20935, 111, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46844, 20935, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46855, 20939, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46856, 20939, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46857, 20939, 114, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46858, 20939, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46859, 20939, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46860, 20939, 372, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46867, 20942, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46868, 20942, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46869, 20942, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46870, 20942, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46871, 20943, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46872, 20943, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (46873, 20943, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46874, 20943, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46875, 20943, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46876, 20944, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46877, 20944, 158, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46878, 20945, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46879, 20945, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46880, 20945, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (46881, 20946, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46882, 20946, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (46851, 20938, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46852, 20938, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46853, 20938, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46854, 20938, 39, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46863, 20941, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46864, 20941, 112, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (46865, 20941, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46866, 20941, 123, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46883, 20021, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38683, 20022, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (29653, 6405, 36, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (29654, 6405, 183, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (46884, 20019, 93, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (46885, 20019, 85, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (46886, 20025, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (11970, 9220, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (11971, 9220, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43413, 9220, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (18758, 12695, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (18759, 12695, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46887, 12695, 18, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46888, 5924, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (46889, 5924, 85, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10732, 9874, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28300, 10072, 148, 37, 3);
INSERT INTO 'dancesformationsmap' VALUES (46890, 20947, 221, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46891, 20947, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46892, 20947, 9, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (46893, 20948, 354, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46894, 20948, 373, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (28301, 10072, 183, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (46904, 20957, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46905, 20957, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46906, 20957, 111, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46907, 20957, 317, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46908, 20957, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46909, 20957, 29, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (25697, 10077, 29, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (11056, 10010, 93, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (42925, 1398, 4, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46899, 20951, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46900, 20951, 112, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46901, 20951, 4, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46902, 20951, 103, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46910, 20958, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46911, 20958, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46912, 20958, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10974, 9985, 30, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46913, 20959, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46914, 20959, 313, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11211, 10011, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (11237, 10086, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11241, 10087, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11244, 10088, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13433, 6678, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13434, 6678, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13435, 6678, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46918, 20960, 183, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (46919, 20960, 112, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46920, 20960, 39, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46915, 20959, 235, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (46916, 20959, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46917, 20959, 214, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46569, 20864, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46570, 20864, 123, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46921, 20961, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46922, 20961, 43, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (46923, 20961, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46924, 20961, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46925, 20961, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46926, 20962, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46927, 20962, 8, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46928, 20962, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46929, 20963, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46930, 20963, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (46931, 20963, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46932, 20963, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (22552, 5637, 32, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (46933, 3998, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46934, 3998, 134, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46935, 3998, 36, 22, 1);
INSERT INTO 'dancesformationsmap' VALUES (46936, 3998, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46937, 185, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46938, 599, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46861, 20940, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46845, 20936, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46846, 20936, 58, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46225, 20767, 20, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46226, 20767, 186, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46782, 20921, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46783, 20921, 76, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46833, 20932, 92, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46834, 20932, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (46784, 20921, 356, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46847, 20937, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46848, 20937, 132, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46816, 20929, 262, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46817, 20929, 71, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46849, 20937, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (4087, 649, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46939, 649, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46940, 838, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46941, 838, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46942, 20964, 260, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46943, 20964, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46944, 20964, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46945, 20964, 302, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46949, 1089, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46950, 1259, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46951, 1259, 134, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (15596, 1518, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46952, 1556, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (4406, 1618, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46953, 1618, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46954, 1618, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46955, 1618, 376, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (46956, 1766, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46957, 1766, 134, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (46958, 1766, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (46959, 2328, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46960, 3234, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46961, 3402, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46962, 3402, 181, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46963, 14027, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (46964, 14027, 289, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46965, 14027, 192, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (46966, 3775, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44891, 20314, 235, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46996, 20968, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46997, 20968, 384, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46998, 20968, 283, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46999, 20968, 119, 6, 4);
INSERT INTO 'dancesformationsmap' VALUES (13061, 9442, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (46967, 4486, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46991, 20967, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46992, 20967, 384, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28953, 16932, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (46993, 20967, 283, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (43385, 8914, 119, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43386, 8914, 188, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13055, 9440, 43, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (13056, 9440, 148, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (13057, 9440, 27, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (46969, 5165, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46970, 5165, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9949, 9438, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (46971, 9438, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46972, 5582, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (46973, 5582, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46974, 5582, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (43387, 8914, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43388, 8914, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46978, 6159, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (11136, 10057, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (11167, 10057, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43607, 9018, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (43608, 9018, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43609, 9018, 214, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47001, 14595, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27687, 16439, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (27688, 16439, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (27689, 16439, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27690, 16439, 183, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (46946, 20965, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46947, 20965, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46948, 20965, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7227, 7376, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46979, 7376, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46980, 7435, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7366, 7500, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46981, 7500, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (46982, 7500, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (7898, 8283, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13486, 8361, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13224, 8925, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13225, 8925, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13226, 8925, 59, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (46983, 12670, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (34093, 19174, 134, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (45765, 20571, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46968, 4779, 365, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46984, 9177, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46985, 9177, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46986, 9177, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (11529, 10272, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (46987, 20796, 154, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (34094, 19174, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (34095, 19174, 175, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47033, 20979, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47034, 20979, 183, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (47022, 20975, 76, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (47038, 20981, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47039, 20981, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47041, 20982, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46988, 20966, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46989, 20966, 384, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46990, 20966, 283, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (47042, 20982, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46994, 20968, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (46995, 20968, 94, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47064, 20992, 5, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (33120, 43, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32549, 104, 368, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47065, 20992, 235, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47028, 20978, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47029, 20978, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47030, 20978, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47023, 20976, 76, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (47002, 20969, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47003, 20969, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47004, 20969, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47068, 1196, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (6475, 1603, 251, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47047, 20985, 72, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (47048, 20985, 52, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (47049, 20985, 193, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (47024, 20977, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47050, 20986, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47051, 20986, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47052, 20986, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21630, 868, 119, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (21631, 868, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47012, 20972, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47013, 20972, 93, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (47056, 20989, 8, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47057, 20989, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47058, 20989, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47053, 20987, 317, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (46975, 5831, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47000, 11461, 315, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47005, 20970, 225, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47006, 20970, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47007, 20970, 260, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47066, 20992, 156, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47062, 20991, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47063, 20991, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (32550, 104, 73, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47008, 20971, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47009, 20971, 162, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47010, 20971, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47011, 20971, 192, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (32551, 104, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (44572, 230, 81, 48, 1);
INSERT INTO 'dancesformationsmap' VALUES (44573, 230, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (47067, 230, 132, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47014, 20973, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47015, 20973, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47016, 20973, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47017, 20973, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39066, 1080, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22792, 1841, 157, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (38700, 1958, 117, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (38701, 1958, 296, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (47031, 20978, 93, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (47032, 20978, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47025, 20977, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46976, 5831, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (46977, 5831, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47026, 20977, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47040, 20981, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47036, 20980, 32, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47027, 20977, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47037, 20980, 321, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47035, 20979, 61, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (47046, 20984, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47054, 20988, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47055, 20988, 41, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47044, 20983, 185, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47045, 20983, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (38702, 1958, 209, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (38703, 1958, 210, 105, 1);
INSERT INTO 'dancesformationsmap' VALUES (38704, 1958, 220, 225, 1);
INSERT INTO 'dancesformationsmap' VALUES (35687, 2068, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (35688, 2068, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8824, 4075, 132, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47069, 20994, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47070, 20994, 48, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47071, 20994, 225, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47072, 20994, 32, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47073, 20994, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47018, 20974, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47019, 20974, 224, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47020, 20974, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47021, 20974, 101, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47074, 20918, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47075, 4696, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47076, 4696, 333, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (44399, 5475, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (44400, 5475, 310, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35283, 5642, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (35284, 5642, 120, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37912, 5746, 145, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (37913, 5746, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22090, 5972, 83, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (22091, 5972, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (44482, 6290, 224, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (44483, 6290, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (47077, 6290, 315, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (47078, 6645, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (40915, 2550, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (40916, 2550, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (39476, 4371, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39477, 4371, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39478, 4371, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (38038, 7077, 193, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (38447, 7302, 1, 113, 2);
INSERT INTO 'dancesformationsmap' VALUES (28768, 7504, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39737, 7928, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (39738, 7928, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47079, 9245, 66, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (28535, 9640, 29, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (10746, 9880, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (10747, 9880, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (10748, 9880, 185, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (13361, 10555, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (35758, 10647, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (16261, 11805, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22954, 12085, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20187, 13106, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (20188, 13106, 39, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20189, 13106, 66, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (8893, 5422, 33, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8894, 5422, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (8895, 5422, 16, 33, 3);
INSERT INTO 'dancesformationsmap' VALUES (24721, 15432, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (29391, 16659, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33377, 17116, 69, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (33378, 17116, 154, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (33379, 17116, 220, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47083, 18850, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47084, 18850, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47085, 18850, 48, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47086, 18850, 319, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42059, 18243, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47087, 18604, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47088, 18604, 117, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47089, 18604, 193, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47090, 18604, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47091, 18604, 220, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47092, 18604, 72, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (47093, 18604, 157, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (47094, 18954, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47095, 19982, 157, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (17939, 12440, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (40338, 13468, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31648, 13898, 154, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31649, 13898, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (22049, 14389, 7, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (22849, 14689, 52, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (31180, 14901, 65, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (47096, 14901, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47097, 14901, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (23856, 15195, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (23880, 15202, 1, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (23881, 15202, 176, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23882, 15202, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (23914, 15206, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (23950, 15215, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (25549, 15852, 224, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25550, 15852, 225, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (25551, 15852, 328, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (26796, 16147, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47098, 16726, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47099, 1091, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47100, 1091, 155, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (31990, 18331, 119, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (38191, 14832, 278, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (38192, 14832, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (38193, 14832, 7, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (47082, 20995, 192, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (29646, 17282, 32, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (32040, 17348, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32041, 17348, 214, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (41759, 17409, 355, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (41760, 17409, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (41761, 17409, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (32190, 17430, 8, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47101, 17689, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47102, 17771, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (31154, 18184, 123, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (31155, 18184, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (32084, 18348, 373, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (47103, 18348, 260, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (32222, 18388, 112, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32223, 18388, 29, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32224, 18388, 373, 1, 0);
INSERT INTO 'dancesformationsmap' VALUES (32393, 18473, 8, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (32394, 18473, 373, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (35582, 19372, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (37467, 19602, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (37468, 19602, 211, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36865, 19686, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (36866, 19686, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (43104, 20213, 36, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43105, 20213, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (43922, 20301, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (43923, 20301, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (43924, 20301, 32, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (44171, 20326, 61, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45567, 20506, 189, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (45568, 20506, 185, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46480, 20839, 7, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (46481, 20839, 61, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (27595, 16412, 251, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47080, 20995, 42, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (47081, 20995, 61, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (23618, 14818, 214, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47059, 20989, 221, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (47060, 20989, 188, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (47061, 20989, 1, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (47104, 4348, 45, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47105, 4348, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47106, 4348, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (2289, 4351, 386, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47107, 4351, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (8012, 8407, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47108, 8407, 308, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47109, 8407, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47110, 9427, 378, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47111, 13150, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47112, 13187, 154, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (33089, 18741, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47113, 18741, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47114, 18745, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47115, 18745, 76, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47116, 18745, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (32812, 18569, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (35762, 19405, 123, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (39772, 8162, 269, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39773, 8162, 303, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (39774, 8162, 7, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (27193, 16283, 333, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (43967, 20306, 333, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (10446, 9733, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (10447, 9733, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (10448, 9733, 119, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (47117, 9733, 183, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (47118, 9733, 332, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (47119, 473, 185, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47120, 473, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47121, 473, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47122, 508, 142, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47123, 508, 318, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47124, 2139, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47125, 2139, 278, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47126, 2139, 265, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47127, 2139, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47128, 3910, 145, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47129, 3910, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47130, 3910, 185, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47131, 3910, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (488, 892, 80, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47132, 1460, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (6501, 1831, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47133, 1831, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47134, 1831, 114, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47135, 1831, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47136, 2211, 154, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47137, 2211, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47138, 2211, 163, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (23030, 3463, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47139, 4290, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47140, 4290, 58, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (47141, 5244, 8, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (47142, 5976, 183, 13, 3);
INSERT INTO 'dancesformationsmap' VALUES (47143, 5976, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47144, 6389, 16, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (47145, 6389, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47146, 7476, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13668, 7530, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (7409, 7540, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47147, 7540, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (19065, 12781, 8, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (19066, 12781, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21136, 13347, 234, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (21137, 13347, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47148, 13347, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47149, 14970, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47150, 1850, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47151, 1850, 126, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47152, 1850, 85, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (47153, 1850, 134, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (47154, 1850, 7, 43, 2);
INSERT INTO 'dancesformationsmap' VALUES (47155, 6535, 41, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47156, 6535, 158, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47157, 6535, 162, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47158, 6535, 133, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47159, 8227, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47160, 8227, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47161, 1657, 193, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47162, 2337, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47163, 3022, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47164, 3692, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47166, 5890, 33, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (47167, 5890, 185, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47168, 5986, 184, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47169, 5986, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47170, 6006, 7, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (47171, 6401, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47172, 6401, 7, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (47173, 6619, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47174, 6619, 9, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (47175, 7432, 112, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (15607, 11592, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47165, 4389, 39, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47176, 4389, 183, 25, 3);
INSERT INTO 'dancesformationsmap' VALUES (47195, 21001, 314, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (47196, 21001, 119, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47197, 21001, 93, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47241, 21015, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47242, 21015, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47243, 21015, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47244, 21016, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47245, 21016, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47246, 21016, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47247, 21017, 222, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47177, 20997, 7, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47178, 20997, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47179, 20997, 222, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (47180, 20997, 241, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47181, 20997, 119, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (47248, 21017, 72, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (47249, 21017, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47250, 21017, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47251, 21018, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47252, 21018, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47253, 21018, 4, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47185, 20999, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47186, 20999, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47187, 20999, 220, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47188, 21000, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47189, 21000, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47190, 21000, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47191, 21000, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47192, 21000, 9, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (47193, 21000, 112, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47194, 21000, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (190, 334, 56, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (17659, 12250, 59, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (47200, 21002, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47201, 21002, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47202, 21002, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (47205, 21004, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47206, 21004, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47207, 21004, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47204, 21003, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47208, 21005, 313, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (47209, 21005, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47210, 21005, 119, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47211, 21006, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47212, 21006, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47213, 21006, 165, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47214, 21006, 283, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47215, 21007, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47216, 21007, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47217, 21007, 53, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47218, 21007, 358, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47219, 21008, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47220, 21008, 43, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (47221, 21008, 156, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47222, 21009, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47223, 21009, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (47224, 21009, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47229, 21011, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47230, 21011, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47231, 21011, 96, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (47232, 21012, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (47233, 21012, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47234, 21013, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47235, 21013, 188, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47236, 21013, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47237, 21014, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47238, 21014, 318, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47239, 21014, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47240, 21014, 234, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (47254, 21018, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47255, 21019, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47256, 21019, 314, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (47257, 21019, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47258, 21019, 222, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47259, 21019, 119, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47260, 21020, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47261, 21020, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47262, 21020, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47263, 21020, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47264, 21021, 29, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47265, 21021, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47268, 10169, 22, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47269, 21023, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47270, 21023, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (47271, 21023, 61, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (46862, 20940, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47272, 20767, 96, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (47273, 21024, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47274, 21024, 321, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47275, 21024, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47276, 21025, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47277, 21025, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47278, 21025, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47283, 21027, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47284, 21027, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47287, 21029, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47288, 21029, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47289, 21029, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47225, 21010, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47226, 21010, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47227, 21010, 241, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47228, 21010, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47295, 895, 7, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (47290, 21030, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47279, 21026, 76, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47280, 21026, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47281, 21026, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (47282, 21026, 62, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47266, 21022, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47267, 21022, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47182, 20998, 121, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47183, 20998, 8, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47184, 20998, 176, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47203, 21002, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47285, 21028, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47286, 21028, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47291, 21030, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47292, 21030, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47293, 21030, 38, 26, 1);
INSERT INTO 'dancesformationsmap' VALUES (47294, 21030, 134, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (47296, 21030, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47297, 21027, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47303, 21032, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47304, 21032, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47305, 21032, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47306, 21032, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47298, 21031, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47299, 21031, 318, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47300, 21031, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47301, 21031, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47302, 21031, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47307, 21033, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47308, 21033, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47309, 21033, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47310, 21034, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47311, 21034, 92, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47312, 21034, 5, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47313, 21034, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47314, 21035, 283, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47315, 21035, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47316, 21035, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47317, 21036, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47318, 21036, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47319, 21037, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47320, 21037, 92, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (47321, 21037, 168, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47322, 21038, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47323, 21038, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47324, 21038, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47325, 21038, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47326, 21039, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47327, 21039, 8, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47328, 21040, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47329, 21040, 4, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47330, 21040, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47331, 21041, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47332, 21041, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (47333, 21041, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47334, 21042, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47335, 21042, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47336, 21042, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47340, 21044, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47341, 21044, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47342, 21044, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47343, 21044, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47344, 21045, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47345, 21045, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47346, 21045, 283, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47347, 21046, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47348, 21046, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47349, 21046, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47350, 21047, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47351, 21047, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47352, 21047, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47353, 21047, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47354, 21048, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47355, 21048, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47356, 21048, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47357, 21049, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47358, 21049, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47359, 21049, 154, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47360, 21049, 283, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47361, 21050, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47362, 21050, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47363, 21050, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47364, 21050, 165, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47365, 21051, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47366, 21051, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47367, 21051, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47368, 21051, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47369, 21052, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47370, 21052, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47371, 21052, 241, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47379, 21055, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47380, 21055, 152, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47376, 21054, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47377, 21054, 318, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47378, 21054, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47372, 21053, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47373, 21053, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47374, 21053, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47375, 21053, 241, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47381, 21056, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47382, 21056, 318, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47383, 21056, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47449, 21078, 105, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47450, 21079, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47451, 21079, 48, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47387, 21058, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47388, 21058, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47389, 21058, 152, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47394, 21060, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47395, 21060, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47396, 21060, 168, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47406, 21063, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47407, 21063, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47408, 21064, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47409, 21064, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47410, 21064, 268, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47390, 21059, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47391, 21059, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47392, 21059, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47393, 21059, 183, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (47397, 21061, 92, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47398, 21061, 234, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (47399, 21061, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47400, 21062, 52, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47401, 21062, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47402, 21062, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47403, 21062, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47404, 21062, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47405, 21062, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47384, 21057, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47385, 21057, 152, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47386, 21057, 234, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (47337, 21043, 92, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47338, 21043, 168, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47339, 21043, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47411, 21065, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47412, 21065, 12, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47413, 21065, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47414, 21066, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47415, 21066, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (47416, 21066, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47417, 21067, 315, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47418, 21067, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47419, 21067, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47420, 21067, 39, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47421, 21068, 105, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47428, 21070, 28, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47429, 21070, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47430, 21070, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47431, 21071, 283, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47432, 21071, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47433, 21071, 165, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47434, 21073, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47435, 21073, 112, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47436, 21073, 171, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47437, 21074, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47438, 21074, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47439, 21074, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47440, 21075, 145, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47441, 21075, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47442, 21075, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47443, 21075, 283, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47444, 21076, 48, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47445, 21076, 321, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47446, 21076, 241, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47447, 21077, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47448, 21077, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47452, 21079, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47453, 21080, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47454, 21080, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47455, 21080, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47459, 21082, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47460, 21082, 251, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47461, 21082, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47462, 21082, 119, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (47463, 21083, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (47464, 21083, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47465, 21083, 241, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47466, 21084, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47467, 21084, 189, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (47468, 21084, 241, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47469, 21085, 189, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47470, 21085, 84, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47471, 21085, 241, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47472, 21086, 283, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47456, 21081, 183, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (47457, 21081, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47458, 21081, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47473, 21086, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47474, 21086, 241, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47475, 21087, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47476, 21087, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47477, 21087, 123, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47478, 21087, 283, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47479, 21088, 21, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47480, 21088, 165, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47481, 21088, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47482, 21088, 283, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47487, 21090, 186, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47488, 21090, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47489, 21090, 283, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47490, 21091, 18, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47491, 21091, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47492, 21091, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47422, 21069, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47423, 21069, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47424, 21069, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47425, 21069, 22, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47426, 21069, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (47427, 21069, 168, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (47483, 21089, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47484, 21089, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47485, 21089, 283, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47486, 21089, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47504, 21095, 84, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47505, 21095, 30, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47506, 21095, 49, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (47507, 20693, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47508, 20693, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47509, 20693, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47510, 20693, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47511, 20692, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47512, 20692, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47513, 20692, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47514, 20692, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47515, 20692, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46835, 20932, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47516, 21097, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47517, 21097, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47518, 21097, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46785, 20921, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47519, 19075, 69, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (47520, 19075, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47521, 21098, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47522, 21098, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47523, 21098, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47524, 14794, 43, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (47525, 14794, 23, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (47526, 14794, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47527, 14794, 72, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47528, 14794, 121, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (47529, 14794, 157, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (47532, 20643, 132, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47533, 20643, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47534, 20643, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47535, 20643, 8, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47536, 20643, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (47608, 19668, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47609, 2799, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47543, 20647, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47544, 20647, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47545, 20647, 8, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (47546, 20648, 202, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47547, 20650, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47548, 20650, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47549, 20650, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47550, 20651, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47551, 20651, 314, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (47552, 20651, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47553, 20652, 8, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47554, 20652, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47555, 20652, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47556, 20653, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47557, 20653, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47558, 20653, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47559, 20653, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47560, 20654, 7, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47561, 20654, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47562, 20654, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47537, 20644, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47538, 20644, 83, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47563, 20655, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47564, 20655, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47565, 20655, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47566, 20656, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47567, 20656, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47568, 20656, 26, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47569, 20656, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47570, 20657, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47571, 20657, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47572, 20657, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47573, 20657, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47574, 20658, 220, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47575, 20658, 121, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47576, 20658, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47577, 20658, 216, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47578, 19823, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47579, 19823, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47580, 19823, 26, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47581, 19824, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47582, 19824, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47583, 19824, 119, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (47584, 19824, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47585, 19824, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47586, 19825, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47587, 19825, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (47588, 19825, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47589, 19827, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47590, 19829, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47591, 19829, 172, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47592, 19829, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47593, 19829, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47594, 21100, 120, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47595, 21100, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (47596, 21100, 157, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (47597, 19618, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47598, 19618, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47599, 19618, 87, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (19526, 12292, 119, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47600, 12318, 12, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (3713, 7000, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1040, 1932, 221, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47601, 1932, 36, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47602, 17538, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47603, 17538, 112, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (47610, 2799, 176, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47611, 2799, 145, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47612, 2799, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47501, 21094, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (47502, 21094, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47503, 21094, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47604, 21094, 96, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47613, 2799, 287, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (47614, 4781, 216, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47615, 4781, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47616, 4781, 117, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47617, 4781, 1, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (47618, 4781, 32, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (47619, 6404, 148, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47620, 6949, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47621, 6949, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47493, 21092, 332, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47494, 21092, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47495, 21092, 129, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47496, 21092, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (27856, 14797, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (27857, 14797, 23, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47539, 20646, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47540, 20646, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47541, 20646, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47542, 20646, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47605, 4347, 209, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47606, 10682, 36, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (47607, 10682, 114, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47622, 6949, 27, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47623, 6949, 63, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47628, 8121, 1, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47629, 8121, 305, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47630, 8418, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47631, 8418, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9737, 9358, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47632, 10749, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (47633, 10749, 55, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (47634, 10749, 23, 83, 1);
INSERT INTO 'dancesformationsmap' VALUES (15662, 11608, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (15663, 11608, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19535, 12367, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47635, 13777, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47636, 13777, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47637, 13777, 112, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47638, 13777, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47639, 13777, 202, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47497, 21093, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47498, 21093, 96, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (47499, 21093, 76, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47640, 13777, 69, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (47624, 7460, 22, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47625, 7460, 55, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47626, 7460, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47627, 7460, 192, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (47641, 14490, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47642, 14490, 156, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47643, 14490, 353, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47644, 14792, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47645, 14792, 93, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47646, 14792, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47748, 20147, 119, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47749, 20147, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47750, 20147, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47647, 15531, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47648, 15531, 7, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47649, 15531, 234, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (47650, 15531, 143, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (47651, 15531, 260, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (47652, 15531, 10, 51, 1);
INSERT INTO 'dancesformationsmap' VALUES (47653, 15531, 87, 105, 1);
INSERT INTO 'dancesformationsmap' VALUES (41222, 15599, 43, 37, 4);
INSERT INTO 'dancesformationsmap' VALUES (41223, 15599, 23, 37, 4);
INSERT INTO 'dancesformationsmap' VALUES (25204, 15728, 53, 105, 2);
INSERT INTO 'dancesformationsmap' VALUES (25205, 15728, 69, 57, 2);
INSERT INTO 'dancesformationsmap' VALUES (25206, 15728, 143, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47654, 15728, 9, 33, 8);
INSERT INTO 'dancesformationsmap' VALUES (47655, 21101, 302, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47656, 21101, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47657, 21101, 105, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47658, 21102, 134, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47659, 21102, 102, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47660, 21102, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47661, 5441, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47751, 20147, 134, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (47662, 21103, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47663, 21103, 15, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47719, 11420, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47764, 13184, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47765, 13184, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47766, 12785, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47666, 15418, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (21397, 13437, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (47667, 13437, 41, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47668, 13378, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47669, 13378, 96, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47670, 21106, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47671, 21106, 306, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (47672, 21106, 8, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (47673, 21106, 157, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (21160, 13352, 188, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (47674, 12863, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47675, 12863, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47676, 12852, 318, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47679, 12639, 263, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47680, 12533, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47681, 12453, 184, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47682, 12446, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (47683, 12421, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47684, 12326, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47685, 12326, 227, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19514, 12194, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (19515, 12194, 353, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (19516, 12194, 72, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (19224, 8065, 225, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47686, 8065, 192, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47664, 21103, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47665, 21103, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (24141, 15277, 386, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47752, 17257, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47687, 21109, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47688, 21109, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47689, 21109, 224, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47690, 21109, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47691, 21110, 15, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47692, 21110, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47693, 7838, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47694, 7838, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47695, 7838, 12, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (47696, 4306, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47697, 4306, 96, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47698, 4306, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47699, 4306, 36, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47700, 21108, 321, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (47701, 21108, 23, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (47702, 21108, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47703, 12682, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47704, 11973, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47705, 11822, 37, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47706, 11816, 318, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47707, 11816, 314, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47708, 11790, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47709, 11790, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47710, 11785, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47711, 11574, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47712, 11574, 7, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (47713, 11574, 183, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (47714, 11574, 41, 35, 1);
INSERT INTO 'dancesformationsmap' VALUES (47715, 11606, 16, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47716, 11455, 23, 11, 4);
INSERT INTO 'dancesformationsmap' VALUES (14915, 11444, 119, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (47717, 11444, 314, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (47718, 11444, 23, 15, 2);
INSERT INTO 'dancesformationsmap' VALUES (47720, 11403, 302, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47721, 11403, 23, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (47722, 20996, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47723, 20996, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47724, 20996, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47725, 20996, 154, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (47726, 20996, 213, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47727, 20955, 70, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47728, 20955, 188, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47729, 20955, 168, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47730, 20954, 209, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47731, 20954, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47732, 20860, 87, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47733, 20703, 261, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (47734, 20703, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47739, 20521, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47740, 20521, 7, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47741, 20521, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47742, 20405, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47743, 20405, 13, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47744, 20405, 27, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (47745, 20298, 26, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47746, 20298, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47747, 20298, 55, 255, 1);
INSERT INTO 'dancesformationsmap' VALUES (47753, 17257, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47754, 17257, 10, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (47755, 17257, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47756, 17257, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (47767, 10940, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47768, 10940, 72, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47769, 10916, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47770, 10897, 142, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47757, 21111, 15, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47758, 21111, 228, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (47783, 10085, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47784, 10085, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47785, 10009, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47786, 10009, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (47787, 9926, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (47735, 20662, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47736, 20662, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47737, 20662, 308, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47738, 20662, 7, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47771, 10897, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (47774, 10857, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47775, 10769, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47776, 10591, 183, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47777, 10591, 109, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47778, 10290, 33, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (47779, 10271, 359, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (47780, 10092, 333, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47781, 10092, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47782, 10092, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47788, 9901, 183, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47789, 9901, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47790, 9892, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47791, 9892, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47792, 9892, 132, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47793, 9785, 234, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (47794, 9770, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47795, 9726, 13, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47796, 9726, 23, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (47797, 9708, 332, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (47798, 9708, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47759, 21112, 283, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47760, 21112, 29, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47799, 21115, 185, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47800, 21115, 24, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47761, 21112, 42, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47772, 10883, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47773, 10883, 318, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47677, 12756, 249, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47678, 12756, 332, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47907, 21118, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47923, 21118, 184, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47924, 21118, 168, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47807, 21116, 61, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47808, 21116, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47809, 21116, 91, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47810, 21116, 7, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (32754, 18555, 32, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (32755, 18555, 93, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (32756, 18555, 363, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (31691, 18276, 49, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47802, 21124, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47803, 21124, 93, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47804, 21124, 154, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47805, 21124, 119, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47806, 21124, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47811, 21131, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47812, 21131, 30, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47813, 21131, 92, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47814, 21131, 234, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47815, 21131, 48, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (35455, 19306, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (45682, 20554, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (36632, 19638, 33, 30, 1);
INSERT INTO 'dancesformationsmap' VALUES (47816, 10502, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47925, 21118, 119, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (47908, 21122, 69, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47842, 21142, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47843, 21142, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47844, 21142, 52, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47817, 21113, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47818, 21113, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47819, 21113, 93, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (47820, 21113, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47821, 21113, 95, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47845, 21142, 249, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (47909, 21122, 193, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (47823, 9686, 314, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47824, 9686, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47825, 9682, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47826, 9679, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47827, 9679, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47828, 9537, 183, 5, 3);
INSERT INTO 'dancesformationsmap' VALUES (47829, 9242, 43, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47830, 9242, 72, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47831, 9242, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47833, 9101, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47834, 9100, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (47841, 9099, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47910, 21122, 53, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (47846, 21142, 362, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (46027, 20674, 33, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (36636, 19639, 185, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (47911, 21122, 90, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (47912, 21122, 23, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (47913, 21122, 32, 6, 2);
INSERT INTO 'dancesformationsmap' VALUES (47921, 21122, 87, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (47922, 21122, 72, 8, 2);
INSERT INTO 'dancesformationsmap' VALUES (47884, 21138, 85, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (12324, 9204, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47885, 21138, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47886, 21138, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47835, 21141, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47836, 21141, 95, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47837, 21141, 105, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47838, 21141, 15, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47839, 21141, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47840, 21141, 23, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (47847, 21140, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47848, 21140, 123, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47849, 21140, 96, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47850, 21140, 8, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47851, 21140, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47852, 9090, 332, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47853, 9084, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47854, 9056, 314, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47855, 9042, 33, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (47856, 9007, 52, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47857, 9007, 65, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47858, 8965, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (47862, 8732, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47863, 8732, 18, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (8602, 8714, 43, 49, 3);
INSERT INTO 'dancesformationsmap' VALUES (8604, 8714, 296, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (47864, 8714, 183, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47865, 8647, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47866, 8647, 183, 11, 3);
INSERT INTO 'dancesformationsmap' VALUES (15944, 8475, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47867, 8470, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47868, 8241, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47869, 8241, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47870, 8206, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47895, 21123, 95, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47896, 21123, 32, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47871, 21139, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47872, 21139, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47876, 21145, 27, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47877, 21145, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47878, 21136, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47879, 21136, 159, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (47880, 21136, 143, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (47881, 21136, 224, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (47882, 21137, 15, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47883, 21137, 84, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47926, 10848, 96, 1, 5);
INSERT INTO 'dancesformationsmap' VALUES (47927, 8199, 29, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (47928, 8176, 9, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47887, 21148, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47888, 21148, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47889, 21148, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47890, 21148, 26, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (47891, 21147, 75, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47892, 21147, 93, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47893, 21147, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (47894, 21147, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47897, 21123, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47898, 21123, 93, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (47899, 2830, 76, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47900, 2830, 83, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47901, 2830, 9, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (47822, 21114, 119, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47929, 8176, 234, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47801, 21115, 119, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (47930, 8133, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47931, 8107, 29, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47932, 8107, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47902, 21120, 209, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47903, 21120, 176, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47904, 21120, 66, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47933, 8103, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (47934, 8076, 333, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47935, 8071, 302, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (47936, 8055, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47937, 8053, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47938, 8052, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47939, 17697, 29, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (47905, 21118, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47906, 21118, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47940, 17697, 228, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47945, 21150, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47946, 21150, 33, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47947, 21150, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47948, 21150, 134, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47198, 21001, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47941, 21149, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47942, 21149, 93, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (47943, 21149, 353, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47832, 9136, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47199, 21001, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47917, 21121, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47918, 21121, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (38504, 1400, 234, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47953, 21152, 78, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47954, 21152, 23, 19, 3);
INSERT INTO 'dancesformationsmap' VALUES (47955, 21152, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47873, 21144, 29, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47874, 21144, 16, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (47875, 21144, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47859, 8840, 23, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (47919, 21121, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47950, 21151, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47916, 21119, 152, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47951, 21151, 240, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47914, 21117, 5, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47915, 21117, 119, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47952, 21151, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47944, 21149, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47860, 8840, 18, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (47861, 8840, 234, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (13926, 10907, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (13927, 10907, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (13928, 10907, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47956, 21133, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47957, 21133, 321, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (47958, 21133, 95, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (47959, 21133, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47960, 21133, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47961, 21133, 134, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (47962, 21133, 70, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (13890, 10872, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (19, 30, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47963, 1793, 234, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (47964, 7653, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47965, 7605, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47966, 7464, 188, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47967, 7464, 265, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47968, 7464, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47969, 7406, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47970, 7388, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47971, 7388, 70, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47972, 7388, 18, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47973, 7373, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47974, 7353, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47975, 7353, 234, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47976, 7295, 183, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (47977, 7295, 314, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (47978, 7193, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47979, 7193, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47980, 7190, 189, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47981, 7190, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47982, 7190, 154, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (3806, 7175, 17, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47983, 7174, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47984, 7174, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (47985, 7174, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (47986, 7159, 333, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (47987, 7043, 183, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (47988, 6982, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (42076, 20142, 64, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48067, 1000, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28450, 16771, 119, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (47989, 21126, 314, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (47990, 21126, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (47991, 21126, 109, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47920, 21121, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (47762, 21112, 82, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (47763, 21112, 214, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47992, 20920, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (47999, 1606, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48000, 1606, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48001, 1606, 143, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48002, 1606, 148, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48003, 11806, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48068, 1000, 120, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48069, 1000, 149, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48070, 1000, 234, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (48071, 1000, 296, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48004, 21128, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48005, 21128, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48006, 21128, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48007, 21128, 273, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48008, 21125, 93, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48009, 21125, 184, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48010, 21125, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48011, 21125, 186, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48012, 21134, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48013, 21134, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48014, 21134, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48015, 21134, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48016, 21119, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48017, 21119, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48018, 21119, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48072, 1000, 43, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (48073, 1000, 90, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (48074, 1000, 193, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (48075, 1000, 189, 69, 1);
INSERT INTO 'dancesformationsmap' VALUES (48076, 1000, 85, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (48019, 21130, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48020, 21130, 222, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48021, 21130, 168, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48022, 21130, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48023, 21130, 123, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48024, 21129, 168, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48061, 730, 296, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48062, 730, 387, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48063, 730, 41, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (48028, 21127, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48029, 21127, 134, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48030, 21127, 168, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48031, 21127, 189, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48032, 21157, 70, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48033, 21157, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48034, 21157, 78, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48035, 21158, 42, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48036, 21158, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (48037, 21158, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48038, 21158, 312, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (47993, 21153, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (47994, 21153, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47995, 21153, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (47996, 21153, 183, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47997, 21153, 154, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (47998, 21153, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48039, 6962, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (48040, 6962, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48041, 6946, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48043, 6904, 131, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48044, 6904, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48045, 6904, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48046, 6902, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48047, 6721, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48048, 6704, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48049, 6704, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48050, 6704, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48051, 6686, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48052, 6686, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48053, 6685, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48054, 6632, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48055, 6632, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48056, 6556, 183, 15, 3);
INSERT INTO 'dancesformationsmap' VALUES (48057, 6556, 12, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (48058, 6479, 42, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (3412, 6455, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48059, 6455, 20, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48060, 6455, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (12515, 3933, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (5919, 6122, 103, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9175, 3119, 72, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (9176, 3119, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (9177, 3119, 38, 28, 1);
INSERT INTO 'dancesformationsmap' VALUES (16291, 2410, 61, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (23997, 15219, 183, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48077, 6419, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48078, 6407, 148, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48079, 6310, 251, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48080, 6219, 321, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48081, 6219, 42, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (48082, 6204, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48083, 6162, 143, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48084, 6162, 33, 19, 4);
INSERT INTO 'dancesformationsmap' VALUES (48085, 6136, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48086, 6112, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48087, 6112, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (6972, 6053, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48088, 6047, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48089, 6044, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48090, 6044, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48091, 6044, 28, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48092, 5980, 318, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48093, 5917, 43, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (48094, 5915, 32, 85, 2);
INSERT INTO 'dancesformationsmap' VALUES (48095, 5911, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48096, 5858, 148, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48097, 5808, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48098, 5808, 41, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48099, 5788, 183, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (48100, 5787, 318, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (2998, 5721, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48101, 5721, 234, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48102, 5721, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (48103, 5685, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48104, 5685, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48105, 5654, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48106, 5654, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48107, 5654, 32, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (48108, 5584, 26, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48109, 5559, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48110, 5559, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48111, 5559, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48112, 5559, 18, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48113, 5542, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48114, 5542, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48115, 5542, 359, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48116, 5511, 12, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48117, 5445, 332, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48118, 5445, 93, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48119, 5445, 33, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (20269, 13146, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (20277, 13148, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (20272, 13147, 93, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48120, 7158, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48121, 7158, 72, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48122, 7158, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48124, 14472, 318, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (7575, 4617, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (7576, 4617, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48204, 4602, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48205, 4602, 36, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (48206, 4602, 23, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (48128, 21162, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48129, 21162, 52, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48130, 21162, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48131, 21162, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48207, 4601, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48208, 4594, 222, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (48209, 4564, 43, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (48210, 4537, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48211, 4537, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (48212, 4537, 175, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48132, 21163, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48133, 21163, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48134, 21163, 92, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48135, 21163, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48136, 21163, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48137, 21163, 71, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (48125, 21161, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48126, 21161, 92, 12, 2);
INSERT INTO 'dancesformationsmap' VALUES (48127, 21161, 29, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (46210, 20749, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48153, 5219, 7, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (2804, 5366, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (2709, 5187, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48154, 5187, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (5583, 5154, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48157, 5154, 332, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48158, 5154, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48159, 5120, 15, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48160, 5120, 43, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48161, 5093, 43, 9, 6);
INSERT INTO 'dancesformationsmap' VALUES (48162, 5093, 69, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48163, 5064, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48164, 5053, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48165, 5053, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48166, 4916, 23, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (48167, 4916, 39, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48168, 4877, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48169, 4877, 332, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48170, 4877, 43, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (48171, 4845, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48172, 4815, 265, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (48173, 4815, 332, 47, 1);
INSERT INTO 'dancesformationsmap' VALUES (48174, 4815, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (8300, 8608, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (2371, 4528, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48213, 4528, 43, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48175, 21168, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48176, 21168, 23, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48214, 4528, 9, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (48215, 4528, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48216, 4498, 126, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48217, 4498, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48218, 3684, 20, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (48219, 3684, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48220, 14585, 56, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48221, 14585, 284, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48222, 14585, 43, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48223, 14585, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (48181, 21170, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48182, 21170, 316, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48183, 21170, 92, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48231, 20956, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48184, 21167, 23, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (48185, 21167, 225, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48194, 4697, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48195, 4697, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48186, 21171, 8, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48187, 21171, 157, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (33549, 19115, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42636, 3946, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48188, 3946, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48189, 3946, 234, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (48190, 7132, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48191, 7132, 53, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (48192, 7132, 8, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (48193, 4734, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48196, 4674, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48197, 4674, 96, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (48198, 4674, 1, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (48199, 4673, 234, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48200, 4669, 183, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (48201, 4663, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48202, 4630, 134, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48203, 4628, 314, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48232, 20956, 157, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48233, 20956, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48234, 20956, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48235, 20956, 9, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (48236, 20956, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48237, 21185, 33, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48238, 21185, 1, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (48239, 21185, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48240, 21185, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (42525, 9869, 183, 65, 4);
INSERT INTO 'dancesformationsmap' VALUES (48247, 13396, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48241, 21186, 189, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48242, 21186, 286, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (48243, 21186, 188, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48224, 13389, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48225, 13389, 224, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48226, 13389, 296, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48227, 13389, 117, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48228, 13389, 9, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48229, 13389, 120, 6, 2);
INSERT INTO 'dancesformationsmap' VALUES (48230, 13389, 1, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (48248, 13396, 1, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48249, 13396, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (8523, 8689, 77, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48250, 6270, 265, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48244, 21186, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48155, 5172, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48156, 5172, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48123, 2814, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48245, 6543, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48246, 6543, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (11610, 683, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (11611, 683, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (18928, 12746, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (18929, 12746, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48251, 6270, 185, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48252, 6270, 149, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48253, 6270, 90, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48254, 6270, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48255, 6270, 72, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (48256, 6270, 143, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (48257, 6270, 29, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (48258, 16463, 193, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48259, 16463, 43, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (48260, 16463, 72, 25, 4);
INSERT INTO 'dancesformationsmap' VALUES (48261, 16463, 157, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48262, 16463, 176, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (48263, 10751, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48264, 10751, 25, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48265, 10751, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48266, 10751, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48267, 10753, 1, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (48268, 10753, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48269, 16572, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48270, 16572, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48271, 16572, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48272, 16572, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48273, 16573, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48274, 16573, 87, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48275, 16573, 314, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (48138, 21164, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48139, 21164, 262, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (48140, 21164, 189, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48141, 21164, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48142, 21165, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48143, 21165, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48144, 21165, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48145, 21165, 176, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (39977, 3649, 4, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (39978, 3649, 143, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (39979, 3649, 96, 107, 1);
INSERT INTO 'dancesformationsmap' VALUES (39980, 3649, 87, 137, 1);
INSERT INTO 'dancesformationsmap' VALUES (39981, 3649, 192, 153, 1);
INSERT INTO 'dancesformationsmap' VALUES (48146, 21166, 86, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48147, 21166, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48148, 21166, 273, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48149, 21166, 52, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48276, 16574, 332, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48277, 16574, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48278, 16574, 188, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48279, 16574, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48280, 16574, 183, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (48281, 16575, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48282, 16575, 234, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (48283, 16575, 188, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (48284, 16577, 185, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48285, 16577, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48286, 16577, 15, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (48287, 16577, 120, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (48288, 16577, 1, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (48289, 16577, 157, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (48290, 16578, 9, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48291, 16578, 189, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48292, 16579, 27, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48293, 16579, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48294, 16579, 120, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (48295, 16579, 183, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (48296, 16579, 157, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (17712, 2704, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (17713, 2704, 1, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48380, 21195, 22, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48381, 21195, 263, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48382, 21195, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (30805, 18019, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48403, 3726, 188, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48404, 3726, 131, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48405, 3726, 96, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (48406, 3699, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48407, 3699, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48299, 4651, 53, 16, 1);
INSERT INTO 'dancesformationsmap' VALUES (48300, 4499, 132, 15, 8);
INSERT INTO 'dancesformationsmap' VALUES (48301, 4499, 33, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48302, 4393, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48303, 4383, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48304, 4358, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48305, 4358, 334, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48306, 4336, 308, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48307, 4302, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48308, 4302, 249, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48309, 4299, 131, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48310, 4224, 183, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (48311, 4215, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48312, 4215, 12, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (48313, 4215, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48316, 16597, 43, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48317, 16597, 157, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (48318, 16597, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48314, 16596, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48315, 16596, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48319, 16598, 119, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (48320, 16598, 112, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48321, 16600, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48322, 16600, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48323, 16600, 101, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48324, 16603, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48325, 16603, 49, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48326, 16603, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48327, 16611, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48328, 16611, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48329, 16611, 353, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48330, 16611, 365, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (32881, 16612, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (2207, 4191, 45, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48331, 4191, 318, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48332, 4170, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48333, 4170, 269, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48334, 4120, 23, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48335, 4110, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48336, 4105, 183, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (48337, 4105, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48338, 4063, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48339, 4063, 134, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48340, 4063, 36, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (48341, 4063, 16, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48342, 4005, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (48343, 4002, 8, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (48344, 16664, 102, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48345, 16664, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48346, 16664, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48347, 16664, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48352, 19848, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48353, 17112, 193, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48354, 17119, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48355, 17119, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48356, 17119, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48357, 20064, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48358, 20064, 96, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (45350, 20402, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (46402, 20769, 15, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (48359, 21146, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48360, 21146, 65, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48361, 21146, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (46850, 20937, 72, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48408, 3689, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48383, 21196, 8, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48384, 21196, 142, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48385, 21196, 52, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48386, 21196, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48297, 21189, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48298, 21189, 23, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (48366, 21192, 96, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48367, 21192, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48368, 21192, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48369, 21192, 49, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48370, 19870, 117, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48371, 19870, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48409, 3689, 192, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48410, 3642, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (48411, 3642, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48025, 21155, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48026, 21155, 15, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48027, 21155, 215, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48387, 18711, 30, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48388, 3994, 318, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48389, 3892, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48390, 3892, 30, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48391, 3892, 83, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48392, 3882, 33, 23, 3);
INSERT INTO 'dancesformationsmap' VALUES (48393, 3837, 27, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48394, 3837, 1, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (48395, 3800, 180, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48396, 3800, 72, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48397, 3800, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48400, 3737, 184, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48401, 3730, 127, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48402, 3730, 27, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48177, 21169, 123, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (48178, 21169, 93, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48179, 21169, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48180, 21169, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48372, 21193, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48373, 21193, 63, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48374, 21193, 154, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (48375, 21194, 341, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48376, 21194, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48377, 21194, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48378, 21194, 29, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48379, 21194, 1, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42072, 20141, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48412, 3592, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48413, 3592, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48414, 3586, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48415, 3567, 183, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (48419, 4956, 69, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48362, 21191, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48363, 21191, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48364, 21191, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (41691, 17269, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (33780, 13637, 91, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48420, 4956, 308, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48423, 19177, 388, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48425, 19363, 388, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (48424, 19240, 388, 8, 1);
INSERT INTO 'dancesformationsmap' VALUES (38413, 17693, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (15497, 11563, 5, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48429, 727, 119, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48426, 21199, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48427, 21199, 119, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (48428, 21199, 36, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48430, 727, 33, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48431, 727, 183, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48432, 16934, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48433, 16934, 1, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (9292, 4497, 86, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (9293, 4497, 158, 49, 2);
INSERT INTO 'dancesformationsmap' VALUES (48434, 4497, 87, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (16995, 3449, 221, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48435, 21200, 186, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48436, 21200, 165, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48421, 12004, 251, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48422, 12004, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48416, 21197, 92, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48437, 21201, 96, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48438, 21201, 234, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (48439, 21201, 267, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48440, 21201, 92, 4, 2);
INSERT INTO 'dancesformationsmap' VALUES (48441, 21202, 95, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48442, 21202, 64, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48443, 21202, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48444, 21202, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48529, 1003, 193, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48530, 1003, 210, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48445, 15525, 183, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48446, 15525, 192, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (34046, 15524, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48447, 15524, 143, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48531, 1003, 176, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48532, 1172, 209, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48533, 1172, 210, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48534, 1172, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48535, 2094, 1, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48536, 2094, 8, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (9535, 8138, 71, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (19008, 12769, 120, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (19009, 12769, 183, 69, 2);
INSERT INTO 'dancesformationsmap' VALUES (9023, 7967, 38, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9024, 7967, 72, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (9025, 7967, 1, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (5069, 3634, 84, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (48457, 21206, 165, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48458, 21206, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48459, 21206, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48460, 3578, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48537, 2094, 83, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48495, 21216, 42, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (40860, 14665, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48559, 21279, 332, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48560, 21279, 93, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48561, 21279, 32, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48461, 21207, 234, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48462, 21207, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (48463, 21207, 20, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48464, 21207, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48465, 304, 149, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48466, 304, 111, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48467, 304, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48468, 270, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (48469, 270, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48470, 21208, 75, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48471, 21208, 82, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (6282, 7259, 43, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (48472, 6134, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48473, 6134, 176, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48474, 6134, 120, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48475, 6134, 112, 17, 3);
INSERT INTO 'dancesformationsmap' VALUES (48476, 6134, 85, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (48477, 6134, 130, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (48478, 6134, 72, 69, 1);
INSERT INTO 'dancesformationsmap' VALUES (48479, 6134, 193, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (48480, 6134, 234, 13, 4);
INSERT INTO 'dancesformationsmap' VALUES (48398, 3765, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48399, 3765, 165, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (40861, 14665, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (47500, 21093, 71, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48481, 21093, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48450, 21204, 280, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48451, 21204, 15, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48452, 21204, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48448, 21203, 280, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48449, 21203, 184, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48482, 9909, 85, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48453, 21205, 56, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48454, 21205, 189, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48455, 21205, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (48456, 21205, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48496, 21216, 263, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48497, 21216, 307, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48507, 21220, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (28883, 16732, 4, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (28884, 16732, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (28885, 16732, 76, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (10626, 9832, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (10627, 9832, 173, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (15166, 11511, 265, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (15171, 11511, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48508, 21220, 82, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (10524, 9772, 70, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (33691, 11020, 120, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48483, 3553, 92, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48484, 3537, 148, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48485, 3529, 148, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48509, 21220, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48510, 21220, 15, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (13112, 4283, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (13113, 4283, 64, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (48538, 21165, 249, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (24895, 15564, 273, 3, 0);
INSERT INTO 'dancesformationsmap' VALUES (24896, 15564, 23, 4, 0);
INSERT INTO 'dancesformationsmap' VALUES (24897, 15564, 71, 5, 0);
INSERT INTO 'dancesformationsmap' VALUES (48489, 21215, 92, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (48490, 21215, 112, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48491, 21215, 93, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48492, 21215, 43, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (48493, 21215, 154, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (48494, 21215, 10, 59, 1);
INSERT INTO 'dancesformationsmap' VALUES (13936, 10910, 19, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (13937, 10910, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (42763, 20203, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (42764, 20203, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43460, 20234, 94, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (43461, 20234, 1, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (13844, 10882, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (13848, 10884, 1, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (15903, 11703, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (20437, 13179, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (20438, 13179, 15, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48498, 21217, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48499, 21217, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (24898, 15564, 8, 6, 0);
INSERT INTO 'dancesformationsmap' VALUES (48539, 21228, 4, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48540, 21228, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (3951, 245, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48500, 21217, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48501, 21218, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48502, 21218, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48503, 21218, 5, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48504, 21219, 313, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48505, 21219, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48506, 21219, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48513, 17913, 224, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48514, 17913, 225, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48515, 17913, 65, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48511, 21221, 82, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48512, 21221, 386, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48516, 885, 90, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48517, 885, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48518, 885, 117, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (48519, 885, 149, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (48520, 920, 42, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48521, 920, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48522, 920, 189, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48523, 920, 188, 36, 1);
INSERT INTO 'dancesformationsmap' VALUES (48524, 955, 119, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48525, 955, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48526, 955, 197, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48527, 955, 29, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (48528, 955, 72, 37, 2);
INSERT INTO 'dancesformationsmap' VALUES (48541, 21228, 82, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48542, 21229, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48543, 21229, 272, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (48544, 21229, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (21801, 14322, 76, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (21802, 14322, 193, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48486, 21213, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48487, 21213, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48488, 21213, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48545, 21230, 83, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48546, 21230, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48547, 21230, 193, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48548, 21230, 225, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (48549, 21230, 117, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (48553, 5203, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48554, 5203, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48555, 21278, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48556, 21278, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48557, 21278, 32, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (47949, 21150, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48558, 21278, 120, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48550, 21277, 1, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (48551, 21277, 8, 20, 3);
INSERT INTO 'dancesformationsmap' VALUES (48552, 21277, 38, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (41677, 17261, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (41678, 17261, 132, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (41679, 17261, 32, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48563, 3511, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48564, 3437, 183, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48565, 3433, 42, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48566, 3433, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (48567, 3422, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48568, 3415, 314, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48569, 3415, 249, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (48570, 3407, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48571, 3393, 30, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1782, 3381, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48572, 3381, 28, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48573, 3351, 96, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48417, 21197, 28, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48418, 21197, 71, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48574, 21179, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48575, 21179, 112, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48576, 21179, 202, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (48150, 21166, 1, 35, 2);
INSERT INTO 'dancesformationsmap' VALUES (48151, 21166, 72, 41, 2);
INSERT INTO 'dancesformationsmap' VALUES (48152, 21166, 23, 47, 1);
INSERT INTO 'dancesformationsmap' VALUES (48583, 20775, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48584, 20775, 318, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48585, 20775, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48586, 20774, 241, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48587, 20774, 26, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48588, 3349, 314, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (48589, 3349, 8, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48590, 3339, 269, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48591, 3331, 202, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48592, 3331, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48593, 3331, 81, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48594, 3331, 5, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48595, 3245, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48596, 3245, 23, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (48597, 3235, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48598, 3233, 168, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48599, 3233, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48600, 3218, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48601, 3218, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48602, 3218, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48562, 21279, 216, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48603, 2195, 69, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48604, 2195, 83, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48605, 2195, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48606, 2195, 224, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48607, 2195, 52, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48608, 2195, 72, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (48609, 2195, 120, 45, 1);
INSERT INTO 'dancesformationsmap' VALUES (48610, 21286, 176, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48611, 21286, 84, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48612, 21287, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48613, 21287, 87, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48614, 21288, 87, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (48615, 21288, 54, 97, 1);
INSERT INTO 'dancesformationsmap' VALUES (48616, 21288, 112, 117, 2);
INSERT INTO 'dancesformationsmap' VALUES (48617, 21288, 9, 121, 1);
INSERT INTO 'dancesformationsmap' VALUES (48618, 21289, 27, 49, 3);
INSERT INTO 'dancesformationsmap' VALUES (48619, 21289, 22, 81, 1);
INSERT INTO 'dancesformationsmap' VALUES (48620, 21289, 143, 125, 1);
INSERT INTO 'dancesformationsmap' VALUES (48621, 21291, 149, 241, 1);
INSERT INTO 'dancesformationsmap' VALUES (48622, 21292, 251, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48623, 21292, 176, 900, 1);
INSERT INTO 'dancesformationsmap' VALUES (48624, 21293, 27, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (48625, 5997, 234, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (48626, 5997, 1, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (36754, 19652, 215, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (31505, 16884, 93, 29, 2);
INSERT INTO 'dancesformationsmap' VALUES (28822, 16888, 157, 29, 4);
INSERT INTO 'dancesformationsmap' VALUES (44175, 16959, 353, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (31511, 17756, 142, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48627, 3169, 96, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48628, 3169, 183, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48632, 1163, 333, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (22800, 14681, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48365, 21191, 281, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (48580, 20777, 69, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48682, 2702, 53, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48683, 2702, 332, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48629, 18125, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48630, 18125, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48631, 18125, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48633, 18125, 95, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (12333, 10370, 129, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (4008, 461, 85, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (48645, 21305, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48646, 21305, 28, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48647, 21305, 72, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48648, 21305, 230, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48649, 21305, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48650, 21306, 183, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (48651, 21306, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48652, 21307, 32, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48653, 21308, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48654, 21308, 69, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48655, 21308, 96, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (48656, 21309, 202, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48657, 21309, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48658, 21309, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48659, 21309, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48660, 21310, 278, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48661, 21310, 119, 21, 2);
INSERT INTO 'dancesformationsmap' VALUES (48662, 21311, 114, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48634, 21301, 183, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (48635, 21301, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48636, 21301, 185, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48637, 21302, 184, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48638, 21303, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48639, 21303, 85, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48640, 21304, 32, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48641, 21304, 23, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48642, 21304, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48643, 21304, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48644, 21304, 72, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48684, 2698, 1, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (21174, 13547, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (14563, 11267, 61, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (14564, 11267, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48663, 3140, 175, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48664, 3113, 145, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48665, 3113, 29, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48666, 3113, 202, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48667, 3113, 32, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48668, 3114, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (4847, 2981, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48669, 2981, 43, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48670, 2941, 9, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48671, 2897, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (48672, 2897, 318, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (1499, 2834, 5, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48673, 2828, 9, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48674, 2828, 23, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (48675, 2752, 82, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48676, 2749, 183, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48677, 2749, 43, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (48678, 2749, 93, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48679, 2716, 318, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48680, 2714, 314, 7, 2);
INSERT INTO 'dancesformationsmap' VALUES (48681, 2714, 29, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48577, 20777, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48578, 20777, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48579, 20777, 29, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48685, 2695, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (1410, 2673, 84, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48686, 2673, 9, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (48687, 2673, 142, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48688, 21312, 72, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48689, 21312, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48690, 21312, 29, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (48698, 21315, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48699, 21315, 303, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48695, 21314, 32, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (8919, 5852, 19, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48700, 21316, 332, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48701, 21316, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48702, 21316, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48703, 21316, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48704, 21316, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48696, 21314, 234, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48697, 21314, 87, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48691, 21313, 33, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48692, 21313, 313, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (48693, 21313, 92, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48694, 21313, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48709, 12861, 82, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48705, 21317, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48706, 21317, 189, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (48707, 21317, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48708, 21317, 1, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48710, 21318, 29, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48711, 21318, 42, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (48712, 21318, 286, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (48713, 21318, 69, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48064, 730, 130, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (48065, 730, 189, 53, 1);
INSERT INTO 'dancesformationsmap' VALUES (48066, 730, 193, 57, 1);
INSERT INTO 'dancesformationsmap' VALUES (48581, 20776, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48582, 20776, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48714, 21319, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48715, 21319, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48716, 21319, 120, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (48717, 21319, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48718, 18367, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48719, 18367, 96, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48720, 18367, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (48721, 18367, 321, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48722, 18367, 92, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48723, 18367, 224, 6, 1);
INSERT INTO 'dancesformationsmap' VALUES (48748, 21329, 213, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48749, 21329, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48750, 21329, 186, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48754, 21331, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48755, 21331, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48756, 21331, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48757, 21332, 145, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48758, 21332, 76, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48759, 21332, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48724, 21320, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48725, 21321, 183, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (48726, 21321, 17, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48727, 21321, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48728, 21322, 307, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48729, 21322, 94, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48730, 21322, 85, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48731, 21323, 152, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48732, 21323, 71, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48733, 21323, 192, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (48734, 21324, 48, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48735, 21324, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48736, 21326, 204, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48737, 21326, 188, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48738, 21326, 189, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48739, 21326, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48740, 21326, 71, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48741, 21327, 235, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48742, 21327, 92, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48743, 21327, 221, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (22255, 14429, 85, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (22256, 14429, 142, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (22257, 14429, 72, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (22258, 14429, 132, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (3375, 6393, 10, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48744, 21328, 145, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48745, 21328, 302, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48746, 21328, 23, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48747, 21328, 93, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48764, 21334, 26, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48765, 21334, 5, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48766, 21335, 302, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48767, 21335, 85, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48768, 21335, 183, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (48769, 21335, 103, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (1584, 3019, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48770, 3019, 183, 15, 1);
INSERT INTO 'dancesformationsmap' VALUES (48771, 3019, 234, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (48772, 3019, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48773, 2613, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48774, 2610, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48775, 2610, 8, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48776, 2575, 314, 9, 4);
INSERT INTO 'dancesformationsmap' VALUES (48777, 2573, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48778, 2573, 249, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (48779, 2530, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48780, 2530, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48781, 2526, 263, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48782, 2504, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48783, 2488, 143, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48784, 2472, 192, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48785, 2427, 9, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (48786, 2398, 318, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48787, 2398, 221, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48788, 2398, 15, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48789, 2380, 33, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48790, 2342, 134, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48791, 2342, 23, 27, 2);
INSERT INTO 'dancesformationsmap' VALUES (48792, 2298, 78, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48793, 2294, 23, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48794, 2289, 42, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48795, 2289, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48796, 2289, 168, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48797, 2289, 189, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48798, 2260, 269, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48799, 2199, 30, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (48800, 2199, 38, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (48801, 2199, 234, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48802, 2199, 303, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48760, 21333, 94, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48761, 21333, 81, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48762, 21333, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48763, 21333, 142, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48818, 9660, 41, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (43957, 20302, 328, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48819, 21339, 78, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48820, 21339, 192, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (17550, 7812, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (17551, 7812, 119, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (48806, 7812, 96, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48803, 21336, 27, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48804, 21336, 261, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48805, 21336, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48807, 18886, 16, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48808, 18886, 119, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48809, 18886, 168, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48810, 21337, 93, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48811, 21337, 23, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48812, 21337, 76, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48813, 21337, 4, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48814, 21338, 32, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48815, 21338, 29, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48816, 21338, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48817, 21338, 193, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48821, 4572, 42, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48822, 4572, 145, 2, 2);
INSERT INTO 'dancesformationsmap' VALUES (48823, 4572, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48824, 21135, 156, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48825, 21135, 39, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48826, 21135, 93, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48827, 21135, 90, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48828, 21135, 15, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (48829, 21135, 85, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (48830, 19326, 1, 1, 4);
INSERT INTO 'dancesformationsmap' VALUES (48831, 19326, 7, 5, 4);
INSERT INTO 'dancesformationsmap' VALUES (48832, 19326, 87, 33, 2);
INSERT INTO 'dancesformationsmap' VALUES (48833, 19326, 259, 43, 1);
INSERT INTO 'dancesformationsmap' VALUES (48834, 19326, 193, 65, 1);
INSERT INTO 'dancesformationsmap' VALUES (48835, 19326, 41, 73, 1);
INSERT INTO 'dancesformationsmap' VALUES (48836, 9780, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48837, 1877, 120, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48838, 1877, 121, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48839, 1877, 134, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48840, 1877, 23, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48841, 2158, 314, 11, 3);
INSERT INTO 'dancesformationsmap' VALUES (48842, 2124, 183, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48843, 2124, 43, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48844, 2124, 55, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48845, 2103, 43, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48846, 2095, 222, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (48847, 2072, 27, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48848, 2072, 17, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48849, 2072, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48850, 2030, 318, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48851, 2030, 96, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (48852, 1992, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (48853, 1992, 15, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48854, 1992, 302, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (48855, 1992, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48856, 1992, 9, 31, 1);
INSERT INTO 'dancesformationsmap' VALUES (48857, 1992, 23, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48858, 1992, 378, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (48859, 1955, 43, 37, 1);
INSERT INTO 'dancesformationsmap' VALUES (48860, 1955, 16, 17, 4);
INSERT INTO 'dancesformationsmap' VALUES (48861, 1924, 84, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48862, 1924, 42, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48863, 1905, 234, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48864, 1905, 96, 1, 3);
INSERT INTO 'dancesformationsmap' VALUES (48865, 1891, 318, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48866, 1852, 7, 9, 3);
INSERT INTO 'dancesformationsmap' VALUES (48867, 1852, 30, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48868, 1851, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48869, 1851, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48870, 13891, 1, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48871, 13891, 356, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48872, 13891, 157, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48877, 1843, 332, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48878, 1842, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (48879, 1842, 43, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48880, 1842, 145, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (48881, 1807, 125, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48882, 1801, 30, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48883, 1801, 134, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48884, 1697, 23, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48885, 1697, 183, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48886, 1678, 105, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48887, 1668, 269, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48888, 1643, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48889, 1643, 314, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48890, 1643, 69, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48891, 1635, 188, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48892, 1635, 42, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (877, 1624, 29, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48895, 1608, 120, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48896, 1608, 96, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48897, 1595, 58, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48898, 1595, 188, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48899, 1578, 96, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (48900, 1552, 55, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48901, 1535, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48902, 1535, 234, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48903, 1499, 314, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48904, 1499, 16, 11, 2);
INSERT INTO 'dancesformationsmap' VALUES (48905, 1499, 23, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48893, 6286, 303, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48894, 6286, 269, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48963, 21344, 111, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48964, 21344, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48965, 21344, 82, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48966, 21344, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (39985, 5812, 27, 65, 2);
INSERT INTO 'dancesformationsmap' VALUES (39986, 5812, 193, 89, 1);
INSERT INTO 'dancesformationsmap' VALUES (48906, 17830, 154, 3, 3);
INSERT INTO 'dancesformationsmap' VALUES (48907, 17830, 23, 3, 2);
INSERT INTO 'dancesformationsmap' VALUES (48908, 17830, 43, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48909, 17830, 260, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48910, 17830, 193, 41, 1);
INSERT INTO 'dancesformationsmap' VALUES (48911, 21341, 42, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48912, 21341, 25, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48913, 21341, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48914, 17807, 28, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48915, 17807, 82, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48920, 17809, 28, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48921, 17809, 75, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48922, 17809, 29, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48923, 17809, 192, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48924, 1488, 23, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48925, 1488, 365, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48926, 1452, 42, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48927, 1452, 318, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48928, 1437, 318, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48929, 1390, 183, 19, 2);
INSERT INTO 'dancesformationsmap' VALUES (48930, 1382, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (48931, 1382, 23, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48932, 1382, 214, 27, 1);
INSERT INTO 'dancesformationsmap' VALUES (711, 1314, 81, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48933, 1314, 72, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48934, 1314, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48935, 1314, 183, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (48936, 1314, 265, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48937, 1307, 43, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48938, 1285, 1, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48939, 1285, 27, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48940, 1285, 143, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48941, 1261, 29, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48942, 1242, 145, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48943, 1242, 33, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (4285, 1238, 76, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48944, 1238, 13, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48945, 1238, 183, 23, 1);
INSERT INTO 'dancesformationsmap' VALUES (11383, 10188, 28, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11384, 10188, 35, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (11385, 10188, 61, 0, 1);
INSERT INTO 'dancesformationsmap' VALUES (48946, 1200, 318, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48947, 1195, 55, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48948, 1182, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48949, 1145, 27, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (48950, 1145, 96, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48951, 1085, 142, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48952, 1085, 111, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48953, 1059, 42, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (48954, 1037, 168, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (11823, 9009, 43, 17, 2);
INSERT INTO 'dancesformationsmap' VALUES (48916, 21342, 23, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48917, 21342, 302, 11, 1);
INSERT INTO 'dancesformationsmap' VALUES (48918, 21342, 1, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48919, 21342, 157, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48955, 9426, 23, 13, 2);
INSERT INTO 'dancesformationsmap' VALUES (48956, 9426, 158, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48957, 9426, 9, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48958, 21343, 55, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48959, 21343, 42, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48960, 21343, 23, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48961, 21343, 29, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48962, 21343, 58, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (49000, 17769, 119, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48996, 21348, 143, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48997, 21348, 27, 2, 1);
INSERT INTO 'dancesformationsmap' VALUES (48998, 21348, 72, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48999, 21348, 193, 4, 1);
INSERT INTO 'dancesformationsmap' VALUES (48967, 998, 183, 7, 1);
INSERT INTO 'dancesformationsmap' VALUES (48968, 998, 43, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48969, 977, 269, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48970, 954, 184, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48971, 954, 143, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48972, 925, 29, 19, 1);
INSERT INTO 'dancesformationsmap' VALUES (48973, 925, 42, 25, 2);
INSERT INTO 'dancesformationsmap' VALUES (48974, 850, 197, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48975, 834, 82, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48976, 834, 72, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48977, 827, 249, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48978, 815, 43, 5, 2);
INSERT INTO 'dancesformationsmap' VALUES (48979, 815, 32, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48980, 767, 42, 29, 1);
INSERT INTO 'dancesformationsmap' VALUES (48981, 762, 55, 1, 2);
INSERT INTO 'dancesformationsmap' VALUES (48982, 760, 29, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48983, 21345, 42, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48984, 21345, 353, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48985, 21345, 156, 49, 1);
INSERT INTO 'dancesformationsmap' VALUES (48986, 21345, 93, 61, 1);
INSERT INTO 'dancesformationsmap' VALUES (48987, 21346, 213, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (48988, 21346, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48989, 21346, 154, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48990, 21346, 29, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (48991, 21346, 8, 21, 1);
INSERT INTO 'dancesformationsmap' VALUES (48992, 21347, 43, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (48993, 21347, 82, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48994, 21347, 22, 17, 1);
INSERT INTO 'dancesformationsmap' VALUES (48995, 21347, 192, 33, 1);
INSERT INTO 'dancesformationsmap' VALUES (48873, 21340, 332, 3, 1);
INSERT INTO 'dancesformationsmap' VALUES (48874, 21340, 32, 9, 1);
INSERT INTO 'dancesformationsmap' VALUES (48875, 21340, 70, 13, 1);
INSERT INTO 'dancesformationsmap' VALUES (48876, 21340, 358, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (49004, 21350, 58, 5, 1);
INSERT INTO 'dancesformationsmap' VALUES (49005, 21350, 278, 9, 2);
INSERT INTO 'dancesformationsmap' VALUES (49001, 21349, 22, 1, 1);
INSERT INTO 'dancesformationsmap' VALUES (49002, 21349, 53, 25, 1);
INSERT INTO 'dancesformationsmap' VALUES (49003, 21349, 353, 17, 1);


--
INSERT INTO 'dancespublicationsmap' VALUES (16266, 14569, 1116, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16267, 14596, 1116, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16268, 15564, 1116, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17599, 15331, 1193, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17600, 15567, 1193, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17601, 15568, 1193, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17602, 15569, 1193, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17603, 15570, 1193, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17604, 15571, 1193, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17605, 15572, 1193, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17606, 15573, 1193, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5084, 5880, 104, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15933, 10535, 1092, 22, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15934, 12538, 1092, 23, 102);
INSERT INTO 'dancespublicationsmap' VALUES (17628, 15639, 1199, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17629, 15640, 1199, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17630, 15641, 1199, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17631, 15642, 1199, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17632, 15643, 1199, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17633, 15644, 1199, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17634, 15645, 1199, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17635, 15646, 1199, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17636, 15647, 1199, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17637, 15648, 1199, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17638, 15649, 1199, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17639, 15650, 1199, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17640, 3057, 1199, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (751, 876, 442, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3017, 3469, 442, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14558, 7316, 996, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8, 11, 258, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (42, 50, 64, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (93, 106, 93, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13, 16, 548, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (65, 76, 19, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5082, 5878, 19, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (116, 132, 21, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (103, 116, 22, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (96, 109, 23, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (33, 40, 24, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3055, 3515, 467, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3150, 3622, 467, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (111, 125, 510, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (117, 133, 511, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3, 5, 577, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9, 12, 503, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5081, 5877, 504, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (29, 36, 505, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (109, 123, 506, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (110, 124, 509, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (52, 62, 247, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (58, 69, 259, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (51, 61, 164, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18, 22, 92, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6798, 7458, 787, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6819, 7485, 787, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (70, 82, 540, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (85, 98, 540, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10, 13, 208, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5073, 5866, 629, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (126, 142, 273, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16084, 14406, 1091, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (122, 138, 57, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (113, 128, 701, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5077, 5873, 184, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5080, 5876, 184, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (25, 31, 677, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (82, 94, 172, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (89, 102, 138, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (125, 141, 708, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (131, 147, 517, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6, 9, 101, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (127, 143, 563, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16083, 5667, 1103, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (120, 136, 276, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (97, 110, 248, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24, 30, 266, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (101, 114, 267, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15935, 11788, 1092, 24, 102);
INSERT INTO 'dancespublicationsmap' VALUES (149, 169, 475, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (73, 85, 710, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (208, 242, 441, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (176, 202, 209, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (144, 163, 64, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (166, 188, 123, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6807, 7471, 786, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (43, 51, 56, 1, 21);
INSERT INTO 'dancespublicationsmap' VALUES (63, 74, 211, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (99, 112, 716, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6919, 497, 803, 2, 34);
INSERT INTO 'dancespublicationsmap' VALUES (6918, 4102, 803, 5, 34);
INSERT INTO 'dancespublicationsmap' VALUES (6920, 651, 803, 8, 34);
INSERT INTO 'dancespublicationsmap' VALUES (6921, 5616, 803, 12, 34);
INSERT INTO 'dancespublicationsmap' VALUES (6922, 3567, 803, 14, 34);
INSERT INTO 'dancespublicationsmap' VALUES (6923, 7189, 803, 16, 34);
INSERT INTO 'dancespublicationsmap' VALUES (40, 48, 257, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (46, 55, 26, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20, 25, 533, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (68, 80, 195, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17612, 15624, 1197, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (45, 54, 129, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (32, 39, 710, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (83, 95, 600, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (84, 97, 698, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17609, 15599, 1195, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21, 26, 231, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (128, 144, 648, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (87, 100, 706, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6794, 7452, 798, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6795, 7454, 798, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23, 29, 586, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5075, 5868, 207, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6789, 7444, 720, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4, 7, 720, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4195, 4842, 469, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (72, 84, 678, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17064, 14365, 1159, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6821, 7487, 790, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (92, 105, 682, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (30, 37, 682, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (213, 249, 97, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (232, 272, 668, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (164, 185, 93, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (214, 251, 237, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (146, 165, 440, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (266, 311, 606, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (247, 289, 23, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (192, 221, 35, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17619, 15631, 1198, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (77, 89, 128, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7, 10, 580, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (105, 118, 201, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17647, 15660, 1200, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (80, 92, 268, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17648, 15661, 1200, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17649, 15662, 1200, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17650, 15664, 1200, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17651, 15665, 1200, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17652, 15666, 1200, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (119, 135, 755, 2, 35);
INSERT INTO 'dancespublicationsmap' VALUES (5104, 5902, 146, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6787, 7442, 789, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12, 15, 50, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5078, 5874, 674, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1, 3, 143, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (132, 148, 143, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (54, 64, 246, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (162, 183, 36, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (190, 219, 36, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (194, 223, 54, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (169, 192, 108, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (186, 215, 108, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (163, 184, 501, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (221, 260, 511, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (229, 269, 575, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (215, 253, 506, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (156, 176, 507, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (152, 172, 508, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (145, 164, 151, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (191, 220, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (219, 257, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5076, 5872, 641, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5090, 5888, 265, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (90, 103, 486, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (121, 137, 484, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6814, 7479, 788, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6790, 7445, 788, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10599, 9292, 529, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10600, 9293, 529, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (47, 56, 155, 2, 40);
INSERT INTO 'dancespublicationsmap' VALUES (79, 91, 155, 25, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6786, 7441, 778, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6804, 7465, 778, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (94, 107, 122, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5052, 5842, 122, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (38, 46, 639, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5079, 5875, 515, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (143, 162, 261, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (62, 73, 436, 38, 40);
INSERT INTO 'dancespublicationsmap' VALUES (36, 44, 515, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (56, 67, 483, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (205, 238, 618, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5070, 5863, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (171, 195, 652, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16085, 14407, 1091, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16086, 14408, 1091, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (137, 155, 679, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (181, 209, 448, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (135, 151, 621, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5059, 5850, 117, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5055, 5845, 139, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (183, 211, 485, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (161, 182, 539, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (196, 227, 190, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5097, 5895, 546, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (217, 255, 557, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (241, 282, 550, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5064, 5856, 620, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5103, 5901, 245, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5094, 5892, 101, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5106, 5904, 53, 12, 18);
INSERT INTO 'dancespublicationsmap' VALUES (285, 331, 258, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (344, 401, 64, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5131, 5931, 66, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (279, 325, 603, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (303, 352, 189, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (304, 353, 189, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5119, 5918, 119, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (296, 344, 443, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (316, 368, 443, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (348, 407, 115, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5136, 5937, 10, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (281, 327, 18, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (320, 373, 22, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5121, 5921, 24, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (324, 377, 24, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6037, 6998, 675, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3542, 4075, 675, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3045, 3505, 675, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (222, 261, 76, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (318, 370, 501, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (321, 374, 510, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (363, 423, 510, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (294, 341, 575, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (350, 409, 576, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (311, 363, 577, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (300, 348, 504, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (347, 406, 506, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5163, 5971, 507, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (358, 417, 508, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5161, 5969, 508, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5169, 5977, 518, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (185, 213, 76, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (309, 360, 209, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (371, 433, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (288, 335, 169, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16087, 14409, 1091, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16088, 14410, 1091, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5126, 5926, 43, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (335, 390, 701, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (315, 367, 149, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16128, 12905, 1108, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16098, 14425, 1106, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16099, 14426, 1106, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (343, 400, 56, 9, 21);
INSERT INTO 'dancespublicationsmap' VALUES (224, 263, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (368, 430, 30, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5066, 5858, 27, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5173, 5982, 27, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5108, 5906, 25, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (174, 200, 533, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (231, 271, 670, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (193, 222, 15, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (250, 293, 521, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (160, 180, 521, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5118, 5917, 570, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (165, 186, 231, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (245, 286, 698, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (240, 281, 695, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (360, 420, 112, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (154, 174, 514, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5137, 5939, 220, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (234, 275, 514, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5168, 5976, 84, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (293, 340, 38, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5053, 5843, 207, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (158, 178, 199, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (168, 190, 199, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (325, 378, 213, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (239, 280, 212, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5146, 5952, 212, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5157, 5964, 3, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5057, 5847, 3, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5156, 5963, 5, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5145, 5951, 634, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (369, 431, 634, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5154, 5961, 634, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (220, 258, 758, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (195, 225, 758, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (141, 160, 196, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (151, 171, 196, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (339, 394, 526, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (267, 312, 526, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5067, 5859, 513, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (203, 236, 682, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5111, 5909, 678, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (328, 381, 678, 31, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5150, 5957, 746, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5086, 5882, 746, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (249, 291, 682, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (140, 159, 211, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (243, 284, 211, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5109, 5907, 117, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5158, 5966, 591, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (341, 397, 605, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (356, 415, 605, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5120, 5920, 620, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5147, 5953, 138, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (441, 514, 558, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5197, 6012, 68, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (454, 533, 668, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (415, 483, 93, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (416, 484, 237, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (417, 486, 440, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (155, 175, 162, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5062, 5854, 578, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5105, 5903, 166, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (365, 426, 578, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5138, 5941, 579, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (227, 267, 579, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5140, 5944, 579, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5123, 5923, 216, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (351, 410, 13, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17654, 15668, 1200, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17655, 15669, 1200, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (261, 305, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (253, 296, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (255, 298, 252, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5148, 5954, 252, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (187, 216, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (207, 241, 228, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (286, 332, 146, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (429, 499, 146, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (124, 140, 50, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5091, 5889, 51, 34, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5135, 5935, 612, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5176, 5985, 548, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (440, 513, 548, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5218, 6036, 10, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (13215, 1786, 954, 52, 102);
INSERT INTO 'dancespublicationsmap' VALUES (380, 442, 33, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (446, 521, 9, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (413, 480, 54, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (374, 436, 560, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (460, 539, 575, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (452, 528, 576, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5230, 6049, 576, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5231, 6050, 576, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (394, 459, 504, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5190, 6004, 507, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (433, 506, 641, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (322, 375, 486, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5060, 5851, 444, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16111, 14441, 1107, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (138, 156, 552, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (136, 152, 495, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (235, 276, 155, 12, 40);
INSERT INTO 'dancespublicationsmap' VALUES (319, 371, 155, 41, 40);
INSERT INTO 'dancespublicationsmap' VALUES (200, 232, 495, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (275, 321, 495, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (366, 428, 495, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5072, 5865, 141, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (283, 329, 122, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (272, 318, 261, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5167, 5978, 639, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (134, 150, 515, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (327, 380, 484, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (233, 273, 484, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5201, 6016, 507, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (459, 538, 508, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5232, 6051, 116, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5183, 5994, 235, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (401, 466, 235, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (467, 546, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (377, 439, 208, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (397, 462, 209, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (450, 526, 651, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (468, 547, 618, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (385, 447, 652, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16090, 14412, 1091, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16091, 14413, 1091, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16092, 14414, 1091, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5226, 6044, 679, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (461, 540, 149, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (402, 467, 621, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (449, 525, 485, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5191, 6005, 539, 29, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5189, 6003, 677, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (372, 434, 605, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (430, 500, 710, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (615, 719, 710, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5214, 6032, 254, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (423, 493, 135, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5192, 6006, 269, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5187, 5999, 549, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (403, 468, 233, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (524, 608, 2, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (506, 588, 3, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (547, 638, 668, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (501, 582, 558, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (518, 601, 601, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (548, 639, 258, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5264, 6090, 70, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (598, 697, 71, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (585, 679, 123, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (393, 457, 76, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (476, 557, 527, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (591, 686, 527, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (560, 652, 37, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (490, 571, 8, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (578, 672, 560, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5237, 6057, 108, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (480, 561, 575, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (481, 562, 503, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (532, 620, 503, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (582, 676, 508, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (493, 574, 509, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5250, 6070, 509, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (605, 707, 107, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5248, 6068, 247, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (570, 663, 613, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16131, 9542, 1108, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16101, 14432, 1106, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16102, 14433, 1106, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5125, 5925, 622, 6, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5238, 6058, 30, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (389, 451, 77, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (564, 656, 28, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5174, 5983, 672, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (375, 437, 672, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (312, 364, 670, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5153, 5960, 670, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (364, 424, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5128, 5928, 129, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5209, 6027, 695, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5220, 6038, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (386, 448, 175, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5195, 6010, 640, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (387, 449, 145, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5114, 5912, 595, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (517, 600, 593, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (383, 445, 207, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (425, 495, 207, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (521, 604, 207, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (483, 564, 213, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (428, 498, 634, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (396, 461, 533, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (410, 477, 721, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (489, 570, 142, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (463, 542, 176, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (610, 713, 176, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (308, 358, 727, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (510, 592, 678, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (435, 508, 678, 33, 20);
INSERT INTO 'dancespublicationsmap' VALUES (496, 577, 746, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (525, 610, 6, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (618, 723, 5, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5211, 6029, 14, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (588, 682, 14, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (562, 654, 17, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (526, 611, 17, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (381, 443, 195, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (623, 729, 212, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (486, 567, 212, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (540, 631, 734, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (508, 590, 92, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5244, 6064, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (498, 579, 536, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (544, 635, 209, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5258, 6080, 210, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (594, 691, 704, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (473, 553, 652, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (602, 704, 169, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5259, 6081, 100, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5235, 6054, 523, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5263, 6088, 523, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (511, 593, 117, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5249, 6069, 139, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (604, 706, 99, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (545, 636, 485, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (520, 603, 571, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (512, 594, 190, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (475, 555, 620, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (554, 646, 138, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (514, 596, 269, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (478, 559, 128, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (465, 544, 130, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (485, 566, 130, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5233, 6052, 144, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (505, 587, 578, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (546, 637, 167, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5178, 5987, 579, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (447, 522, 16, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (537, 627, 201, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (566, 658, 201, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5186, 5998, 719, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (542, 633, 61, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (17660, 15663, 1200, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17657, 3067, 1200, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5198, 6013, 755, 9, 35);
INSERT INTO 'dancespublicationsmap' VALUES (603, 705, 228, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (442, 516, 146, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (334, 389, 50, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (337, 392, 50, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5172, 5981, 51, 35, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5241, 6061, 51, 36, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5228, 6046, 674, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (567, 660, 497, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (474, 554, 612, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (717, 837, 442, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5308, 6136, 210, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (693, 810, 66, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (750, 875, 68, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (633, 740, 440, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (684, 800, 527, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (636, 743, 21, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (728, 848, 21, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (645, 754, 7, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (631, 738, 8, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (638, 745, 9, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5271, 6097, 560, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (713, 833, 64, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (625, 731, 439, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (676, 792, 560, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (747, 871, 271, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (712, 832, 510, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5274, 6100, 511, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (672, 785, 502, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5305, 6132, 505, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5294, 6120, 508, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5182, 5993, 522, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (16121, 14452, 1107, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (384, 446, 545, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (487, 568, 234, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (437, 510, 264, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16122, 14453, 1107, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (568, 661, 552, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (434, 507, 552, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (556, 648, 552, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5202, 6017, 155, 4, 40);
INSERT INTO 'dancespublicationsmap' VALUES (390, 453, 155, 24, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5212, 6030, 155, 27, 40);
INSERT INTO 'dancespublicationsmap' VALUES (557, 649, 547, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (379, 441, 60, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (444, 518, 122, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5219, 6037, 60, 13, 18);
INSERT INTO 'dancespublicationsmap' VALUES (398, 463, 639, 54, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5196, 6011, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (758, 883, 508, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (700, 817, 509, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (681, 797, 238, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (736, 857, 235, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (762, 888, 115, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (643, 752, 208, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (685, 801, 209, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (663, 775, 169, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5286, 6112, 679, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (642, 751, 236, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (669, 781, 543, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5279, 6105, 539, 31, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5270, 6096, 557, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5301, 6127, 135, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5266, 6092, 269, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (720, 840, 269, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5314, 6143, 233, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5277, 6103, 227, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (730, 851, 101, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5298, 6124, 627, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (735, 856, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (632, 739, 55, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (764, 890, 64, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5311, 6139, 709, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5360, 6197, 123, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5378, 6216, 668, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (637, 744, 443, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (740, 862, 2, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (801, 932, 527, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (843, 975, 527, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5318, 6152, 11, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5304, 6130, 6, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16139, 1114, 1108, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16107, 13627, 1106, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16108, 14437, 1106, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (659, 770, 622, 10, 40);
INSERT INTO 'dancespublicationsmap' VALUES (842, 974, 56, 2, 21);
INSERT INTO 'dancespublicationsmap' VALUES (655, 766, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5254, 6075, 257, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (661, 773, 29, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (752, 877, 27, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (650, 760, 25, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (644, 753, 25, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5280, 6106, 672, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (552, 644, 670, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (651, 761, 670, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (620, 726, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5302, 6128, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (686, 803, 129, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5261, 6085, 129, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (778, 906, 716, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5372, 6209, 699, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (726, 846, 700, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5239, 6059, 695, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5240, 6060, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5275, 6101, 283, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (737, 859, 727, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (731, 852, 514, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (619, 725, 145, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (722, 842, 706, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (682, 798, 595, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (708, 827, 207, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (662, 774, 199, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (815, 946, 213, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (611, 714, 95, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5309, 6137, 533, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5245, 6065, 521, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5347, 6183, 173, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (727, 847, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (725, 845, 256, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (606, 709, 111, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5386, 6229, 147, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (607, 710, 147, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (652, 762, 212, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (495, 576, 526, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (580, 674, 526, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (695, 812, 513, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5377, 6215, 678, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5359, 6196, 748, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (699, 816, 746, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (656, 767, 211, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (851, 984, 24, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (769, 895, 34, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (827, 958, 8, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (781, 909, 9, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (706, 825, 675, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (707, 826, 675, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5341, 6177, 108, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (812, 943, 673, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (813, 944, 510, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5357, 6194, 510, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5320, 6154, 511, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (829, 961, 577, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5348, 6184, 504, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (759, 884, 506, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (780, 908, 107, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5354, 6190, 613, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5363, 6200, 94, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (835, 967, 518, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (761, 886, 92, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (802, 933, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (768, 894, 209, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (814, 945, 558, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (818, 949, 210, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (789, 918, 629, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (788, 916, 149, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5367, 6204, 448, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (828, 960, 403, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (943, 1091, 710, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5433, 6286, 709, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5343, 6179, 628, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5365, 6202, 588, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (634, 741, 125, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5273, 6099, 128, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (675, 789, 579, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5361, 6198, 216, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (678, 794, 13, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5349, 6185, 201, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (715, 835, 252, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (688, 805, 61, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (17663, 15676, 1200, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (630, 737, 480, 41, 40);
INSERT INTO 'dancespublicationsmap' VALUES (590, 685, 127, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5315, 6144, 127, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (647, 756, 230, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (734, 855, 714, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (739, 861, 755, 8, 35);
INSERT INTO 'dancespublicationsmap' VALUES (5281, 6107, 757, 9, 35);
INSERT INTO 'dancespublicationsmap' VALUES (667, 779, 50, 6, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5321, 6155, 146, 33, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5319, 6153, 72, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (702, 819, 50, 7, 18);
INSERT INTO 'dancespublicationsmap' VALUES (666, 778, 51, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (807, 938, 143, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (729, 850, 246, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (665, 777, 612, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (608, 711, 114, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (837, 969, 245, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5431, 6284, 442, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (954, 1103, 208, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5417, 6268, 235, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (981, 1136, 705, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5428, 6280, 601, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (928, 1074, 66, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (925, 1071, 68, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (895, 1038, 70, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5403, 6251, 668, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (907, 1052, 93, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (876, 1015, 606, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5412, 6263, 527, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (881, 1020, 20, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5434, 6287, 23, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (879, 1018, 7, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (951, 1100, 9, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5362, 6199, 712, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5415, 6266, 501, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5410, 6261, 575, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (965, 1117, 502, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (899, 1042, 507, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (863, 1001, 107, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (910, 1055, 240, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (911, 1056, 240, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (904, 1049, 241, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (657, 768, 611, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (488, 569, 137, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (959, 1109, 243, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (671, 784, 522, 7, 31);
INSERT INTO 'dancespublicationsmap' VALUES (763, 889, 265, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (565, 657, 545, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (499, 580, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5300, 6126, 547, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5329, 6163, 82, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (776, 904, 122, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (597, 696, 707, 36, 20);
INSERT INTO 'dancespublicationsmap' VALUES (635, 742, 60, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (756, 881, 515, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (705, 823, 59, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (654, 765, 486, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (810, 941, 483, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (703, 820, 482, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (952, 1101, 734, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (869, 1008, 238, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (992, 1147, 238, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5429, 6281, 518, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (977, 1132, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (960, 1110, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (809, 940, 76, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5396, 6242, 75, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (891, 1032, 489, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (990, 1145, 704, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (900, 1043, 618, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (972, 1126, 57, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (886, 1025, 149, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (924, 1070, 403, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5327, 6161, 113, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (962, 1112, 543, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (968, 1121, 184, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5400, 6247, 628, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (935, 1082, 539, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (969, 1122, 637, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (982, 1137, 620, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (942, 1090, 135, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5420, 6272, 517, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5398, 6245, 227, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16146, 1804, 1108, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (855, 992, 56, 4, 21);
INSERT INTO 'dancespublicationsmap' VALUES (848, 981, 56, 8, 21);
INSERT INTO 'dancespublicationsmap' VALUES (826, 957, 449, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5316, 6148, 449, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (938, 1085, 670, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (782, 910, 30, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5432, 6285, 28, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5382, 6224, 44, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (913, 1058, 129, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (847, 980, 15, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (971, 1125, 154, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (929, 1075, 88, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (838, 970, 700, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5381, 6223, 700, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (983, 1138, 695, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (774, 901, 695, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5358, 6195, 112, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (914, 1059, 112, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (970, 1124, 727, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (773, 900, 648, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (783, 911, 145, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (817, 948, 84, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5416, 6267, 595, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (823, 954, 595, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (787, 915, 593, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (949, 1098, 593, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (767, 893, 207, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5368, 6205, 207, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (840, 972, 15, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (939, 1086, 634, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5337, 6172, 533, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (858, 996, 521, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (793, 923, 260, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5317, 6150, 176, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (973, 1128, 142, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (786, 914, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (916, 1061, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (889, 1029, 256, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5373, 6210, 256, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (854, 988, 111, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5384, 6226, 111, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (853, 986, 526, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (991, 1146, 513, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (864, 1002, 746, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5389, 6233, 2, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5346, 6182, 2, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (976, 1131, 211, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (878, 1017, 17, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5402, 6250, 212, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5409, 6260, 758, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5475, 6335, 439, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5447, 6303, 442, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1023, 1182, 123, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5449, 6305, 557, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1064, 1233, 64, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1094, 1271, 69, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1100, 1277, 152, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1012, 1167, 97, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5459, 6318, 668, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1119, 1297, 440, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1103, 1280, 20, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1055, 1223, 32, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1118, 1296, 7, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1148, 1329, 560, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1027, 1187, 271, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1151, 1336, 710, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (994, 1149, 501, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1150, 1334, 501, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5451, 6307, 511, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5439, 6293, 576, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1011, 1166, 503, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1071, 1241, 503, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1016, 1174, 506, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1059, 1227, 151, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1054, 1222, 94, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1063, 1231, 238, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1083, 1257, 193, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1070, 1240, 496, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1090, 1265, 496, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1116, 1294, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5460, 6320, 235, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1018, 1177, 208, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1072, 1242, 210, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1115, 1293, 210, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5450, 6306, 489, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1128, 1308, 489, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1048, 1215, 651, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1101, 1278, 273, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1061, 1229, 100, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1057, 1225, 701, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1153, 1338, 130, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5426, 6278, 578, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1102, 1279, 165, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (901, 1044, 719, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5340, 6176, 579, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (805, 936, 16, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (974, 1129, 216, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1047, 1214, 216, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (933, 1080, 163, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5411, 6262, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (830, 962, 719, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (890, 1030, 127, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (956, 1106, 252, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1002, 1157, 252, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (804, 935, 755, 3, 35);
INSERT INTO 'dancespublicationsmap' VALUES (1041, 1201, 146, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (885, 1024, 50, 9, 18);
INSERT INTO 'dancespublicationsmap' VALUES (892, 1034, 51, 5, 18);
INSERT INTO 'dancespublicationsmap' VALUES (856, 993, 674, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (957, 1107, 143, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1065, 1234, 246, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (894, 1037, 497, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (816, 947, 114, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1135, 1316, 543, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1000, 1155, 571, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1037, 1197, 539, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1025, 1185, 637, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1051, 1218, 153, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1053, 1221, 245, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1110, 1288, 549, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1038, 1198, 708, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5440, 6294, 227, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1125, 1304, 55, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1056, 1224, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1188, 1375, 152, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1154, 1339, 71, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1203, 1392, 65, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1232, 1425, 66, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5512, 6379, 69, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1241, 1436, 123, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1219, 1408, 119, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1200, 1389, 527, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1225, 1415, 10, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5463, 6323, 21, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5551, 6420, 23, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5499, 6364, 710, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6041, 7002, 471, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5501, 6368, 33, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1189, 1376, 34, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5513, 6380, 35, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1202, 1391, 560, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1192, 1380, 678, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1187, 1374, 673, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (903, 1047, 610, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (993, 1148, 137, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5546, 6413, 641, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1130, 1310, 243, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (966, 1119, 141, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (765, 891, 545, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1050, 1217, 444, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (940, 1087, 643, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5393, 6239, 155, 7, 40);
INSERT INTO 'dancespublicationsmap' VALUES (806, 937, 155, 7, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5414, 6265, 82, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (874, 1013, 639, 38, 20);
INSERT INTO 'dancespublicationsmap' VALUES (866, 1004, 639, 48, 20);
INSERT INTO 'dancespublicationsmap' VALUES (937, 1084, 483, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1193, 1381, 505, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5544, 6411, 505, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5489, 6353, 507, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5533, 6400, 509, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1213, 1402, 241, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1239, 1433, 241, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5520, 6387, 115, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5483, 6344, 551, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5467, 6327, 116, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1209, 1398, 92, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1228, 1418, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1174, 1360, 235, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1183, 1370, 178, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1217, 1406, 208, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1198, 1387, 75, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1167, 1352, 489, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1156, 1341, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1205, 1394, 541, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5542, 6409, 57, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16149, 9646, 1108, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5515, 6382, 56, 3, 21);
INSERT INTO 'dancespublicationsmap' VALUES (1124, 1303, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5492, 6356, 449, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1105, 1283, 30, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1008, 1163, 29, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5506, 6373, 26, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (999, 1154, 25, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5457, 6316, 160, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1199, 1388, 126, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5531, 6398, 716, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1044, 1207, 134, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1246, 1445, 699, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1123, 1301, 698, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1040, 1200, 698, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5553, 6422, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (967, 1120, 283, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1033, 1193, 283, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (997, 1152, 145, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1106, 1284, 570, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5519, 6386, 38, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (998, 1153, 593, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1068, 1238, 207, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1087, 1261, 207, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1185, 1372, 207, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (896, 1039, 199, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5526, 6393, 213, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1196, 1384, 212, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1042, 1205, 758, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1141, 1322, 634, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1020, 1179, 255, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1221, 1410, 142, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1222, 1412, 173, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1147, 1328, 721, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1028, 1188, 721, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1006, 1161, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1140, 1321, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1005, 1160, 196, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1142, 1323, 256, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1242, 1437, 14, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1017, 1176, 211, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1045, 1210, 1, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5495, 6359, 1, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1163, 1348, 4, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1179, 1366, 17, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5524, 6391, 52, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5547, 6414, 118, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5550, 6417, 118, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5503, 6370, 485, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1182, 1369, 571, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5507, 6374, 677, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1178, 1365, 677, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1184, 1371, 557, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1168, 1353, 254, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5514, 6381, 110, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5532, 6399, 708, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1336, 1546, 705, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1317, 1525, 97, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1331, 1541, 603, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1354, 1567, 237, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1292, 1496, 11, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1372, 1588, 23, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1297, 1501, 9, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5594, 6471, 54, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1377, 1594, 560, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5538, 6405, 675, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1333, 1543, 108, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1365, 1579, 54, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1277, 1481, 673, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5556, 6425, 501, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1379, 1597, 501, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1369, 1583, 511, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1326, 1536, 576, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1309, 1514, 577, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5568, 6441, 577, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5597, 6474, 577, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1260, 1462, 505, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1318, 1526, 505, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1283, 1487, 506, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1321, 1529, 506, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1324, 1534, 507, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1330, 1540, 507, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1256, 1457, 104, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5589, 6466, 240, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5590, 6467, 240, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1322, 1530, 734, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1375, 1592, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1273, 1477, 235, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1343, 1553, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1504, 1741, 710, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5580, 6456, 728, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1334, 1544, 210, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5584, 6461, 210, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1263, 1467, 75, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1374, 1590, 489, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1258, 1460, 618, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1323, 1532, 629, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1086, 1260, 125, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1197, 1385, 130, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1030, 1190, 167, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1161, 1346, 578, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5554, 6423, 480, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5497, 6362, 16, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5486, 6349, 13, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5454, 6310, 487, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1152, 1337, 163, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1122, 1300, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5488, 6352, 252, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1021, 1180, 757, 6, 35);
INSERT INTO 'dancespublicationsmap' VALUES (1216, 1405, 72, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1003, 1158, 50, 10, 18);
INSERT INTO 'dancespublicationsmap' VALUES (1098, 1275, 609, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1138, 1319, 674, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5490, 6354, 143, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1010, 1165, 121, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1255, 1456, 612, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1380, 1598, 273, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1378, 1595, 679, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1312, 1518, 701, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1313, 1520, 701, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1281, 1485, 149, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1356, 1569, 621, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5598, 6475, 557, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1291, 1495, 712, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1355, 1568, 708, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5563, 6434, 227, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1498, 1735, 442, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1388, 1607, 42, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (1522, 1764, 68, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1381, 1599, 70, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1506, 1743, 152, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1405, 1628, 123, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1486, 1723, 97, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5640, 6524, 668, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1410, 1634, 237, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5639, 6523, 10, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1401, 1624, 19, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1520, 1762, 20, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5600, 6477, 7, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5608, 6486, 560, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1462, 1696, 271, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1425, 1650, 87, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5602, 6480, 510, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5621, 6504, 576, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1519, 1761, 577, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1132, 1312, 547, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1039, 1199, 545, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1261, 1465, 264, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1340, 1550, 444, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5472, 6332, 444, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5596, 6473, 552, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1301, 1505, 495, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1035, 1195, 155, 27, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5555, 6424, 155, 32, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5464, 6324, 219, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5579, 6455, 639, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1077, 1250, 122, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5607, 6485, 581, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5529, 6396, 219, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1079, 1252, 436, 9, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5595, 6472, 484, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5530, 6397, 483, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1034, 1194, 482, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5605, 6483, 502, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5641, 6525, 504, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1500, 1737, 505, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1495, 1732, 508, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1266, 1470, 56, 10, 21);
INSERT INTO 'dancespublicationsmap' VALUES (5479, 6339, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1249, 1448, 449, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5473, 6333, 672, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1236, 1430, 197, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1276, 1480, 28, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1477, 1712, 77, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5611, 6489, 27, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1371, 1586, 25, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1265, 1469, 47, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1224, 1414, 670, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1279, 1483, 670, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5485, 6348, 129, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1286, 1490, 709, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1345, 1555, 196, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1342, 1552, 256, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1339, 1549, 134, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1441, 1671, 231, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1327, 1537, 699, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1227, 1417, 698, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5516, 6383, 695, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1349, 1560, 695, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5558, 6427, 112, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1359, 1573, 147, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5541, 6408, 145, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1329, 1539, 570, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1373, 1589, 595, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1516, 1757, 207, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1303, 1507, 199, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1521, 1763, 212, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1431, 1656, 709, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1450, 1681, 634, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1282, 1486, 533, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5494, 6358, 533, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5586, 6463, 521, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5606, 6484, 142, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1364, 1578, 526, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1250, 1450, 513, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5502, 6369, 512, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1158, 1343, 512, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1310, 1515, 443, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1360, 1574, 211, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5634, 6518, 15, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1274, 1478, 1, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1392, 1615, 2, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1351, 1562, 3, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5622, 6505, 5, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1368, 1582, 14, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1447, 1677, 17, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1275, 1479, 682, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1302, 1506, 682, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1408, 1631, 518, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5613, 6492, 92, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5618, 6500, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1466, 1700, 728, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1411, 1635, 208, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1387, 1606, 441, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5610, 6488, 558, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1398, 1621, 75, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1428, 1653, 704, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1399, 1622, 273, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1451, 1682, 273, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5620, 6502, 541, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1488, 1725, 105, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1508, 1746, 99, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1482, 1718, 184, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1459, 1693, 539, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1499, 1736, 443, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5648, 6539, 15, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1455, 1686, 254, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1468, 1702, 627, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1396, 1619, 263, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1426, 1651, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1416, 1641, 55, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5658, 6551, 214, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1603, 1863, 734, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1573, 1827, 705, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5651, 6543, 64, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1524, 1767, 68, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1664, 1930, 115, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1601, 1861, 93, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1409, 1632, 104, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1612, 1873, 606, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1559, 1811, 527, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1483, 1719, 90, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1537, 1783, 24, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5699, 6599, 8, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1529, 1773, 9, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1535, 1780, 54, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5696, 6596, 560, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5678, 6572, 673, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1647, 1912, 510, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5647, 6538, 511, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1628, 1890, 505, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5654, 6547, 506, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1610, 1870, 507, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5671, 6564, 509, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5662, 6555, 151, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1563, 1817, 151, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5660, 6553, 518, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5675, 6569, 92, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1585, 1844, 178, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1608, 1868, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5664, 6557, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1637, 1900, 536, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5687, 6584, 441, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1589, 1848, 210, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1582, 1841, 704, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1579, 1837, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5690, 6588, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1646, 1910, 629, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5623, 6506, 130, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1259, 1461, 130, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5566, 6439, 162, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5624, 6507, 578, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1335, 1545, 166, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1513, 1753, 578, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1304, 1508, 201, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1501, 1738, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1332, 1542, 674, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1180, 1367, 51, 7, 18);
INSERT INTO 'dancespublicationsmap' VALUES (1363, 1577, 228, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5587, 6464, 228, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5601, 6478, 146, 32, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5656, 6549, 146, 35, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1252, 1452, 85, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1613, 1874, 273, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1558, 1810, 100, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5833, 6760, 472, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1609, 1869, 117, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1642, 1906, 571, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5694, 6594, 677, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5661, 6554, 557, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1551, 1802, 254, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1553, 1805, 254, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1673, 1940, 558, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1677, 1946, 152, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16219, 14503, 1111, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1605, 1865, 678, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1751, 2026, 93, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5727, 6631, 237, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1393, 1616, 551, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1750, 2024, 20, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16156, 15335, 1108, 66, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1479, 1714, 622, 7, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1420, 1645, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5636, 6520, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1574, 1828, 79, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1755, 2030, 29, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1634, 1896, 77, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1738, 2010, 28, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1532, 1776, 27, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1763, 2042, 26, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5672, 6566, 25, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5638, 6522, 670, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5685, 6582, 670, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5653, 6545, 129, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1555, 1807, 611, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1404, 1627, 262, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5504, 6371, 137, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1571, 1825, 243, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1602, 1862, 522, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (5487, 6350, 547, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1315, 1523, 545, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1421, 1646, 444, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1471, 1705, 573, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1569, 1823, 639, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1325, 1535, 122, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1385, 1604, 284, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5665, 6558, 639, 58, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1296, 1500, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1382, 1600, 486, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5670, 6563, 486, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1565, 1819, 484, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5667, 6560, 483, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1480, 1716, 482, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5474, 6334, 482, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1663, 1929, 716, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1711, 1981, 600, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1643, 1907, 88, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1626, 1888, 231, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1406, 1629, 700, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5689, 6587, 695, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1389, 1610, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1429, 1654, 147, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1384, 1603, 514, 32, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1478, 1713, 175, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1472, 1706, 640, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5669, 6562, 640, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1616, 1877, 595, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1539, 1788, 595, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1592, 1852, 207, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1597, 1857, 207, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1442, 1672, 199, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1591, 1851, 213, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1721, 1992, 213, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1523, 1766, 533, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5604, 6482, 160, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1413, 1638, 255, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5700, 6600, 255, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1436, 1665, 721, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1432, 1659, 256, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1526, 1769, 111, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1557, 1809, 256, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1576, 1831, 551, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1675, 1942, 746, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5681, 6576, 746, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5677, 6571, 746, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1546, 1796, 211, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1543, 1792, 1, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1665, 1931, 2, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1661, 1927, 3, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5688, 6585, 6, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1549, 1799, 5, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1541, 1790, 5, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5729, 6633, 271, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5725, 6628, 69, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1722, 1993, 510, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1756, 2031, 510, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1651, 1917, 511, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1668, 1935, 575, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5720, 6623, 577, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1717, 1987, 502, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5705, 6608, 504, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1654, 1920, 504, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1714, 1984, 507, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1724, 1995, 507, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1752, 2027, 508, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1754, 2029, 508, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1666, 1932, 107, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5703, 6603, 241, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1660, 1926, 247, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1737, 2009, 247, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1723, 1994, 259, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1739, 2011, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1687, 1956, 178, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1671, 1938, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5724, 6627, 209, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1744, 2017, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1695, 1965, 169, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1696, 1966, 169, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1681, 1950, 273, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1694, 1964, 476, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1710, 1980, 476, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1764, 2043, 100, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1748, 2021, 679, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1718, 1988, 539, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1719, 1989, 539, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1716, 1986, 677, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1713, 1983, 588, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1685, 1954, 620, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5744, 6652, 245, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5709, 6612, 227, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1622, 1884, 53, 15, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5756, 6665, 637, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1870, 2160, 601, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1881, 2172, 65, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1861, 2147, 67, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16226, 14512, 1111, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1792, 2072, 104, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1876, 2166, 1, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1898, 2190, 606, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1882, 2173, 115, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1803, 2084, 32, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5753, 6661, 113, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16225, 14509, 1111, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5776, 6688, 575, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1875, 2165, 575, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5780, 6693, 577, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1785, 2065, 503, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5783, 6696, 508, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1809, 2090, 107, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1765, 2044, 3, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1837, 2121, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1858, 2143, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1884, 2176, 235, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1841, 2125, 208, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1872, 2162, 558, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1883, 2174, 558, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1826, 2110, 210, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1833, 2117, 618, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5758, 6667, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1492, 1729, 125, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1572, 1826, 128, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1700, 1970, 162, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5650, 6542, 578, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1631, 1893, 579, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5666, 6559, 579, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1538, 1786, 16, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1604, 1864, 13, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5663, 6556, 719, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5644, 6531, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5674, 6568, 719, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1617, 1878, 755, 4, 35);
INSERT INTO 'dancespublicationsmap' VALUES (5715, 6618, 230, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1662, 1928, 714, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1645, 1909, 51, 9, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5686, 6583, 228, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1638, 1901, 228, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1825, 2109, 146, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1720, 1990, 72, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5659, 6552, 51, 37, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5777, 6690, 609, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1704, 1974, 246, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5631, 6514, 497, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1706, 1976, 612, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1463, 1697, 114, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1855, 2139, 100, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1798, 2079, 679, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5768, 6679, 679, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5785, 6699, 621, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1843, 2127, 523, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1851, 2135, 105, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1814, 2097, 118, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1769, 2048, 591, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1818, 2102, 485, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1877, 2167, 571, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1779, 2059, 491, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1849, 2133, 138, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5784, 6697, 135, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1802, 2083, 269, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5771, 6683, 708, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1901, 2193, 597, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1879, 2170, 227, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1864, 2152, 563, 38, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1892, 2184, 627, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16158, 14465, 1108, 70, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1736, 2007, 622, 4, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1804, 2085, 58, 4, 21);
INSERT INTO 'dancespublicationsmap' VALUES (1702, 1972, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1703, 1973, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1857, 2141, 533, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1890, 2182, 257, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1707, 1977, 257, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1852, 2136, 25, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1840, 2124, 77, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1869, 2158, 47, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1845, 2129, 670, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5746, 6654, 670, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1780, 2060, 126, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4236, 4892, 473, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5773, 6685, 129, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5711, 6614, 129, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5712, 6615, 129, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1758, 2033, 129, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1670, 1937, 88, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5774, 6686, 610, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1418, 1643, 137, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1730, 2001, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1838, 2122, 545, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1745, 2018, 547, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1629, 1891, 155, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1682, 1951, 82, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1639, 1902, 261, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1619, 1881, 60, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5742, 6650, 515, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1853, 2137, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5775, 6687, 484, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5710, 6613, 482, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1650, 1916, 6, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1887, 2179, 231, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1698, 1968, 231, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1829, 2113, 700, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5766, 6676, 700, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1709, 1979, 698, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1757, 2032, 695, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1799, 2080, 695, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1679, 1948, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1821, 2105, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1762, 2041, 283, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5721, 6624, 648, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5761, 6670, 514, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1697, 1967, 175, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1846, 2130, 640, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1725, 1996, 640, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1657, 1923, 145, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1767, 2046, 595, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1797, 2077, 207, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1878, 2169, 207, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1766, 2045, 199, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1888, 2180, 634, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1672, 1939, 260, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1899, 2191, 721, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1743, 2016, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5750, 6658, 4, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1839, 2123, 512, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1823, 2107, 111, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1774, 2054, 111, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5735, 6640, 281, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5754, 6662, 748, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1773, 2053, 4, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1690, 1959, 195, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1676, 1945, 195, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16188, 14474, 1109, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1820, 2104, 263, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5788, 6702, 705, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1924, 2222, 123, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1931, 2233, 70, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1964, 2270, 65, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1944, 2247, 66, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1986, 2294, 152, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16227, 14506, 1111, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1904, 2196, 548, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5800, 6721, 19, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5813, 6736, 32, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5830, 6756, 35, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1977, 2285, 576, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5827, 6753, 502, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5803, 6724, 503, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1928, 2230, 503, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1995, 2304, 506, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1908, 2202, 247, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1925, 2224, 710, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5807, 6729, 94, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1992, 2301, 238, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1953, 2258, 518, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1915, 2212, 131, 2, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5804, 6725, 536, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1981, 2289, 210, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1976, 2284, 75, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5825, 6751, 704, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1984, 2292, 541, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1985, 2293, 541, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1936, 2239, 43, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (1932, 2234, 485, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5796, 6716, 543, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2010, 2319, 543, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1956, 2262, 539, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1969, 2277, 588, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1974, 2282, 588, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1946, 2249, 605, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1937, 2240, 615, 4, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1917, 2215, 491, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1960, 2266, 491, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1922, 2220, 172, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5809, 6731, 172, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5826, 6752, 557, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1920, 2218, 138, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5810, 6733, 138, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16254, 14570, 1115, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16255, 14571, 1115, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1965, 2271, 245, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5802, 6723, 233, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2020, 2330, 274, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2051, 2365, 539, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2028, 2338, 172, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2096, 2416, 70, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5847, 6775, 66, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2071, 2390, 67, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2109, 2429, 123, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5848, 6776, 548, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2108, 2428, 10, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5867, 6797, 19, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5882, 6817, 19, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2016, 2325, 709, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2112, 2432, 32, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2116, 2437, 35, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2075, 2394, 36, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2144, 2469, 36, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5836, 6763, 8, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2070, 2389, 54, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5849, 6777, 673, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5870, 6801, 108, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2132, 2455, 510, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2074, 2393, 511, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5873, 6806, 576, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2058, 2373, 577, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5886, 6821, 577, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2097, 2417, 504, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2004, 2313, 128, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1873, 2163, 130, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1701, 1971, 578, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1805, 2086, 166, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1831, 2115, 579, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1830, 2114, 579, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1865, 2153, 16, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5808, 6730, 216, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5749, 6657, 719, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5779, 6692, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1784, 2064, 755, 5, 35);
INSERT INTO 'dancespublicationsmap' VALUES (2038, 2348, 146, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16253, 1358, 1114, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1786, 2066, 674, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1910, 2205, 246, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2094, 2414, 506, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2084, 2403, 507, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2137, 2461, 508, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2129, 2452, 709, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5841, 6768, 107, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2033, 2343, 214, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5850, 6778, 518, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2145, 2470, 193, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2067, 2385, 259, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2034, 2344, 92, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5853, 6782, 235, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2095, 2415, 15, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2098, 2418, 536, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5879, 6813, 209, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2076, 2395, 558, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5872, 6805, 75, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2103, 2423, 704, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5878, 6812, 618, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2063, 2380, 169, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2136, 2460, 476, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2081, 2400, 403, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5851, 6780, 117, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16164, 3678, 1108, 82, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16167, 4426, 1108, 88, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2118, 2439, 622, 3, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2131, 2454, 622, 12, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5884, 6819, 56, 7, 21);
INSERT INTO 'dancespublicationsmap' VALUES (5819, 6744, 58, 3, 21);
INSERT INTO 'dancespublicationsmap' VALUES (2041, 2352, 58, 5, 21);
INSERT INTO 'dancespublicationsmap' VALUES (1902, 2194, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2120, 2441, 79, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1948, 2251, 670, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5793, 6710, 28, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2113, 2433, 77, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2039, 2349, 26, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2053, 2367, 44, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1955, 2260, 670, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1987, 2295, 129, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5822, 6748, 1, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5790, 6704, 600, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2044, 2355, 600, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5818, 6743, 196, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5881, 6815, 134, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5792, 6709, 700, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5801, 6722, 570, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5860, 6790, 243, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1921, 2219, 495, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1983, 2291, 545, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1994, 2303, 234, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1967, 2275, 264, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1930, 2232, 155, 14, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5778, 6691, 141, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1842, 2126, 122, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1916, 2214, 82, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1962, 2268, 219, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5814, 6738, 639, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1926, 2225, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2011, 2320, 595, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1942, 2245, 593, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1973, 2281, 586, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5811, 6734, 38, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1939, 2242, 207, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1957, 2263, 207, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2077, 2396, 213, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1947, 2250, 1, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2050, 2363, 634, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1945, 2248, 533, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5812, 6735, 533, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2015, 2324, 521, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1972, 2280, 173, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5855, 6785, 173, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1912, 2207, 721, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1959, 2265, 212, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2107, 2427, 526, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1919, 2217, 111, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5821, 6747, 678, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5794, 6711, 17, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2018, 2327, 746, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2008, 2317, 3, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1906, 2199, 211, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1993, 2302, 4, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2115, 2436, 17, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5869, 6800, 17, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2072, 2391, 682, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5890, 6825, 139, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2032, 2342, 485, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2110, 2430, 571, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5846, 6774, 277, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5892, 6827, 539, 32, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2078, 2397, 637, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2062, 2379, 677, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5863, 6793, 588, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2088, 2408, 153, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2087, 2407, 546, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2080, 2399, 550, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5875, 6808, 138, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2083, 2402, 708, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5891, 6826, 227, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5934, 6875, 250, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2157, 2483, 613, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2224, 2560, 441, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2227, 2564, 601, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2182, 2514, 64, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2192, 2524, 68, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2165, 2493, 152, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2232, 2569, 440, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2167, 2495, 11, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5911, 6848, 20, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2166, 2494, 23, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2255, 2600, 33, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2171, 2501, 34, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2269, 2616, 37, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5915, 6852, 87, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5929, 6869, 510, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5917, 6855, 575, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2256, 2601, 576, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5906, 6842, 577, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5896, 6831, 503, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2151, 2477, 506, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2263, 2609, 507, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2183, 2515, 241, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5920, 6859, 151, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2189, 2521, 496, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2264, 2610, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2250, 2591, 728, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2150, 2476, 209, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2261, 2607, 210, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2163, 2490, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2141, 2465, 448, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17, 20, 448, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2200, 2533, 236, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2204, 2537, 523, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2205, 2538, 523, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2206, 2539, 523, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2251, 2592, 105, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5898, 6834, 118, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2270, 2617, 539, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5907, 6844, 491, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2249, 2589, 90, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2197, 2530, 138, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16256, 14572, 1115, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16257, 14573, 1115, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16258, 14369, 1115, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5921, 6860, 549, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5926, 6865, 274, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5924, 6863, 563, 34, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16246, 14534, 1113, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16247, 14535, 1113, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2244, 2583, 710, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5972, 6922, 64, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2272, 2619, 67, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5970, 6918, 69, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2331, 2685, 123, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5973, 6923, 668, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5945, 6886, 440, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2307, 2659, 548, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5914, 6851, 710, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2122, 2443, 712, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5944, 6885, 20, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2384, 2747, 22, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2382, 2745, 7, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2305, 2657, 675, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2236, 2573, 130, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5854, 6784, 167, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2139, 2463, 163, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5815, 6739, 201, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1952, 2257, 13, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16213, 14499, 1110, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1941, 2244, 719, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2203, 2536, 228, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2099, 2419, 50, 16, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2173, 2504, 50, 17, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2035, 2345, 674, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1929, 2231, 674, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2349, 2706, 246, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2247, 2586, 612, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2266, 2612, 675, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2036, 2346, 712, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2292, 2642, 501, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2284, 2633, 511, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2319, 2672, 511, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2285, 2634, 577, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2334, 2689, 502, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2368, 2729, 503, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2327, 2680, 504, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5974, 6925, 505, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2337, 2693, 505, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2345, 2702, 238, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16170, 4983, 1108, 94, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16173, 14469, 1108, 100, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2221, 2556, 56, 12, 21);
INSERT INTO 'dancespublicationsmap' VALUES (2178, 2510, 58, 1, 21);
INSERT INTO 'dancespublicationsmap' VALUES (2343, 2700, 30, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2226, 2563, 77, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2027, 2337, 533, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2186, 2518, 670, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5844, 6771, 670, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2199, 2532, 126, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2057, 2371, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5916, 6854, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5959, 6904, 212, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2275, 2623, 716, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2294, 2645, 14, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5905, 6841, 700, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2233, 2570, 698, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2258, 2603, 695, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2164, 2492, 526, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2140, 2464, 648, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2184, 2516, 514, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2092, 2412, 640, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2220, 2555, 175, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2037, 2347, 145, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2339, 2695, 570, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5922, 6861, 586, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2234, 2571, 586, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2174, 2506, 207, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2385, 2749, 207, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2231, 2568, 213, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5894, 6829, 113, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5902, 6838, 634, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2240, 2577, 173, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2212, 2546, 256, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5964, 6912, 748, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5923, 6862, 281, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2243, 2581, 746, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2155, 2481, 712, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2085, 2405, 611, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2340, 2696, 522, 8, 31);
INSERT INTO 'dancespublicationsmap' VALUES (1893, 2185, 547, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2300, 2652, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5874, 6807, 234, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2267, 2613, 264, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2068, 2386, 86, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2160, 2487, 275, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5883, 6818, 639, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5903, 6839, 515, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2045, 2356, 486, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2248, 2587, 484, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2060, 2376, 482, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2246, 2585, 211, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5950, 6894, 716, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5939, 6880, 710, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2161, 2488, 709, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2170, 2498, 2, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2328, 2682, 2, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5967, 6915, 4, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16194, 7313, 1109, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16195, 14476, 1109, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2358, 2715, 496, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2370, 2731, 728, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2371, 2732, 728, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5954, 6898, 441, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5943, 6884, 558, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5937, 6878, 618, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5946, 6888, 618, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5969, 6917, 541, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2338, 2694, 57, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2322, 2675, 149, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2383, 2746, 149, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6006, 6964, 448, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5941, 6882, 403, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2286, 2635, 118, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2311, 2663, 117, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2324, 2677, 139, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5948, 6891, 139, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2379, 2740, 99, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5968, 6916, 591, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16263, 14594, 1116, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16264, 14595, 1116, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16265, 14568, 1116, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13225, 1884, 954, 55, 102);
INSERT INTO 'dancespublicationsmap' VALUES (2304, 2656, 557, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16260, 14575, 1115, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16261, 14576, 1115, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2308, 2660, 110, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2392, 2757, 227, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16262, 12845, 995, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2481, 2862, 601, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2426, 2798, 258, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2471, 2850, 69, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5998, 6955, 119, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2472, 2851, 527, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5995, 6952, 54, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6024, 6983, 673, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2401, 2770, 108, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2482, 2863, 258, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5979, 6932, 511, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2442, 2816, 502, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2458, 2835, 502, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5981, 6934, 504, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2512, 2898, 506, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5982, 6935, 507, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2435, 2808, 439, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2455, 2830, 107, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2488, 2869, 734, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5991, 6946, 238, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2518, 2905, 238, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5978, 6931, 518, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2511, 2897, 92, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2430, 2803, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6061, 7027, 709, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6016, 6975, 728, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6017, 6976, 728, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2403, 2772, 536, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2417, 2788, 536, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2476, 2856, 441, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2429, 2802, 558, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2462, 2840, 75, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2396, 2762, 489, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2504, 2890, 679, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2514, 2900, 115, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2477, 2857, 701, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2352, 2709, 76, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2519, 2906, 236, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6015, 6974, 523, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2440, 2814, 105, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5983, 6936, 99, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2413, 2782, 591, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6014, 6973, 485, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2483, 2864, 485, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2394, 2759, 628, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2454, 2829, 628, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2497, 2883, 677, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2404, 2773, 172, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2419, 2790, 172, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2399, 2768, 138, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2409, 2778, 245, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6008, 6967, 227, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2500, 2886, 227, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6002, 6960, 627, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5997, 6954, 635, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5985, 6940, 667, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2453, 2828, 130, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2373, 2734, 130, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2406, 2775, 162, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5976, 6927, 578, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2252, 2593, 16, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2278, 2627, 580, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2402, 2771, 216, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2276, 2624, 163, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2467, 2845, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2362, 2723, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5938, 6879, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2056, 2370, 127, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2312, 2664, 228, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6030, 6991, 146, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2356, 2713, 50, 19, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2280, 2629, 674, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5942, 6883, 143, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2194, 2526, 497, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2463, 2841, 612, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6083, 7054, 442, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6038, 6999, 536, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2553, 2944, 67, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2532, 2919, 69, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6033, 6994, 668, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6057, 7022, 93, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6007, 6965, 200, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2568, 2962, 22, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2563, 2956, 24, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16175, 14471, 1108, 104, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2408, 2777, 29, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5990, 6945, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2446, 2821, 44, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5963, 6911, 260, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2289, 2638, 257, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2433, 2806, 526, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2434, 2807, 25, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2487, 2868, 47, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2299, 2651, 670, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2283, 2632, 126, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5993, 6949, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2427, 2799, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2643, 3045, 15, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2389, 2753, 706, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2302, 2654, 700, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2496, 2882, 695, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6012, 6971, 695, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2422, 2794, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5994, 6950, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2288, 2637, 112, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2437, 6897, 249, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2418, 2789, 648, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2348, 2705, 648, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2315, 2667, 514, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2271, 2618, 640, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2473, 2852, 514, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2410, 2779, 175, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2460, 2837, 145, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2374, 2735, 84, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2333, 2687, 586, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2505, 2891, 594, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2411, 2780, 207, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2448, 2823, 199, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2432, 2805, 213, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2621, 3021, 213, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5999, 6956, 590, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6000, 6957, 15, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2277, 2626, 195, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2303, 2655, 111, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2350, 2707, 526, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2445, 2820, 2, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5936, 6877, 512, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2364, 2725, 52, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2428, 2801, 610, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2495, 2879, 262, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2341, 2698, 639, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2415, 2784, 545, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6029, 6990, 495, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2281, 2630, 275, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2318, 2671, 155, 15, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2210, 2544, 155, 46, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5965, 6913, 122, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2363, 2724, 219, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2329, 2683, 261, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2468, 2846, 60, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2414, 2783, 436, 45, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6028, 6989, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2478, 2859, 483, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2287, 2636, 483, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2516, 2902, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2438, 2812, 4, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6013, 6972, 81, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2591, 2986, 212, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2636, 3038, 24, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2578, 2972, 54, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2618, 3017, 560, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2558, 2951, 675, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2550, 2941, 108, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2635, 3037, 673, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2525, 2912, 575, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2617, 3015, 575, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2608, 3005, 503, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2561, 2954, 504, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2606, 3003, 507, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2530, 2917, 508, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6059, 7025, 214, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2541, 2930, 496, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6068, 7036, 164, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2527, 2914, 92, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6074, 7043, 208, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6073, 7041, 210, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2544, 2933, 489, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2601, 2998, 618, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6051, 7015, 618, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2605, 3002, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6065, 7033, 652, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2535, 2923, 541, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2539, 2927, 149, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2548, 2939, 270, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6075, 7044, 117, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6064, 7032, 543, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2600, 2997, 539, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6087, 7058, 539, 33, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6060, 7026, 491, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6045, 7008, 557, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6036, 6997, 550, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2640, 3042, 110, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2631, 3033, 269, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6056, 7021, 274, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6062, 7030, 227, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6078, 7047, 563, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16283, 12124, 1118, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2740, 3155, 71, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2756, 3172, 152, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2604, 3001, 104, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2681, 3091, 10, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2737, 3152, 10, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2674, 3084, 11, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2693, 3105, 11, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2749, 3165, 33, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2696, 3108, 35, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6129, 7105, 36, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2739, 3154, 54, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2668, 3078, 510, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2666, 3076, 710, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2751, 3167, 510, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2680, 3090, 511, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2676, 3086, 575, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6094, 7066, 575, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2747, 3163, 575, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6118, 7092, 576, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2669, 3079, 577, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2743, 3159, 577, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2707, 3120, 504, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2677, 3087, 506, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6100, 7072, 509, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6125, 7101, 712, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6115, 7089, 734, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6097, 7069, 164, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6128, 7104, 116, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6103, 7076, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6132, 7108, 235, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2730, 3145, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2716, 3130, 712, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2689, 3100, 728, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2708, 3121, 536, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6114, 7088, 208, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2656, 3061, 558, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2723, 3138, 558, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2678, 3088, 489, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2713, 3127, 618, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6112, 7086, 476, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2722, 3137, 149, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6126, 7102, 117, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2657, 3062, 602, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2682, 3092, 571, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2726, 3141, 184, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2717, 3131, 277, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2648, 3050, 254, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2710, 3124, 135, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2711, 3125, 135, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2759, 3175, 269, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2736, 3151, 233, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2732, 3147, 227, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2575, 2969, 443, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16178, 7980, 1108, 110, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16179, 6815, 1108, 114, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6106, 7079, 130, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2712, 3126, 162, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6095, 7067, 167, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2623, 3024, 201, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2748, 3164, 166, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2537, 2925, 13, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2577, 2971, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2703, 3116, 252, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6104, 7077, 146, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2576, 2970, 50, 22, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6089, 7061, 85, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6040, 7001, 143, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2584, 2979, 51, 12, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6101, 7073, 51, 13, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2735, 3150, 622, 5, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2562, 2955, 670, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2531, 2918, 30, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6069, 7037, 29, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6084, 7055, 44, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6054, 7018, 670, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2744, 3160, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6035, 6996, 129, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2545, 2936, 126, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2663, 3070, 126, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2587, 2982, 720, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2529, 2916, 4, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2644, 3046, 6, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2701, 3114, 147, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16200, 14481, 1109, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6042, 7003, 521, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2704, 3117, 173, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16298, 9974, 1121, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6133, 7109, 5, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6086, 7057, 700, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2720, 3135, 698, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6046, 7010, 695, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2574, 2968, 283, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2526, 2913, 514, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2610, 3007, 640, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6079, 7050, 145, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2733, 3148, 570, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6052, 7016, 570, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6111, 7085, 706, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2609, 3006, 706, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2629, 3031, 207, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2588, 2983, 593, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6055, 7020, 199, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2684, 3094, 213, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2661, 3066, 634, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2603, 3000, 513, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2664, 3071, 748, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6096, 7068, 14, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2700, 3113, 211, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6047, 7011, 682, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6048, 7012, 682, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2791, 3209, 588, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2803, 3224, 71, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6165, 7146, 728, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2880, 3315, 208, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2796, 3217, 601, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2787, 3205, 258, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6156, 7137, 65, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2774, 3190, 66, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2770, 3186, 67, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2837, 3265, 152, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2819, 3245, 237, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2826, 3253, 237, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2862, 3291, 527, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2607, 3004, 610, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2612, 3010, 137, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16123, 12368, 1107, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2709, 3122, 641, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2652, 3054, 265, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2750, 3166, 545, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2565, 2958, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2683, 3093, 264, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2580, 2974, 86, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6039, 7000, 573, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2570, 2964, 552, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2690, 3101, 155, 4, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6049, 7013, 639, 56, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6088, 7060, 122, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2593, 2988, 515, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2628, 3030, 59, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6162, 7143, 19, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6166, 7147, 24, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2890, 3326, 33, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2820, 3246, 8, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2855, 3284, 9, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6157, 7138, 560, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2776, 3192, 511, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2771, 3187, 509, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2830, 3257, 151, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2786, 3204, 94, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6170, 7153, 238, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2823, 3249, 496, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6149, 7128, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6137, 7113, 441, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2815, 3240, 210, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2878, 3313, 652, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2794, 3215, 273, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6161, 7142, 523, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6139, 7116, 591, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2772, 3188, 277, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16292, 14627, 1118, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16293, 14628, 1118, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2789, 3207, 254, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2764, 3180, 713, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2831, 3258, 135, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2851, 3280, 517, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2809, 3234, 101, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2865, 3294, 276, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2853, 3282, 635, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2931, 3372, 442, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2974, 3418, 93, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2782, 3198, 710, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2939, 3380, 67, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6177, 7162, 152, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2932, 3373, 115, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6193, 7181, 440, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2921, 3361, 548, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2902, 3342, 11, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2899, 3339, 18, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6217, 7210, 21, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2898, 3338, 32, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6211, 7204, 37, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2990, 3435, 54, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2946, 3388, 271, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2792, 3211, 551, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6210, 7203, 673, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2952, 3394, 502, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2971, 3415, 505, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2995, 3440, 507, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2994, 3439, 509, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2901, 3341, 734, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6212, 7205, 518, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3013, 3463, 116, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2933, 3374, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2914, 3354, 540, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3000, 3447, 441, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6192, 7180, 75, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2964, 3408, 704, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6189, 7176, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6194, 7182, 169, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2975, 3419, 273, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3018, 3472, 679, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2824, 3250, 710, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2961, 3405, 701, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2887, 3323, 149, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2986, 3431, 149, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2935, 3376, 403, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2924, 3364, 709, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2967, 3411, 621, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2978, 3423, 117, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3010, 3458, 139, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2904, 3344, 602, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2970, 3414, 543, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16180, 6816, 1108, 116, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2810, 3235, 12, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2805, 3226, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2948, 3390, 79, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2821, 3247, 257, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2854, 3283, 521, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2784, 3200, 670, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6203, 7195, 77, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6174, 7159, 77, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2825, 3251, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6184, 7171, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6145, 7123, 709, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6099, 7071, 125, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2760, 3176, 128, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6134, 7110, 130, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2912, 3352, 130, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2885, 3321, 167, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2671, 3081, 578, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2581, 2975, 719, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2667, 3077, 578, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2596, 2993, 579, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2546, 2937, 579, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2738, 3153, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2864, 3293, 163, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2804, 3225, 61, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6110, 7084, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2691, 3103, 127, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2866, 3295, 252, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2861, 3290, 146, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2675, 3085, 604, 3, 35);
INSERT INTO 'dancespublicationsmap' VALUES (2658, 3063, 674, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2790, 3208, 114, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6204, 7196, 443, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6144, 7121, 196, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2811, 3236, 5, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6168, 7150, 231, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2841, 3269, 695, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2817, 3242, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6181, 7168, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6202, 7194, 112, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2799, 3220, 514, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6164, 7145, 249, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6167, 7149, 640, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2834, 3262, 145, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2829, 3256, 570, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6131, 7107, 272, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2988, 3433, 207, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3002, 3449, 593, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6172, 7157, 199, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6153, 7133, 678, 41, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2897, 3337, 634, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6150, 7129, 255, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2798, 3219, 255, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2867, 3299, 176, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2954, 3397, 176, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2813, 3238, 260, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2960, 3404, 173, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3023, 3477, 721, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16204, 7297, 1109, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2874, 3309, 147, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2879, 3314, 526, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2800, 3221, 513, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6155, 7135, 281, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2812, 3237, 3, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2783, 3199, 716, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2992, 3437, 4, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6185, 7172, 14, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2852, 3281, 14, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2997, 3444, 17, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2875, 3310, 52, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6215, 7208, 682, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3006, 3453, 571, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2910, 3350, 677, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2953, 3396, 677, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6191, 7179, 588, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2963, 3407, 605, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2991, 3436, 153, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2942, 3384, 546, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (16295, 14630, 1118, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2909, 3349, 550, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6197, 7188, 254, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6190, 7178, 708, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2987, 3432, 597, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3052, 3512, 442, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3097, 3567, 179, 5, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6276, 48, 109, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3109, 3579, 123, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3140, 3611, 10, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3077, 3541, 11, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3022, 3476, 262, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6151, 7131, 243, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6187, 7174, 639, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6158, 7139, 522, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (3009, 3456, 86, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2869, 3302, 234, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2807, 3228, 444, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2840, 3268, 264, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2828, 3255, 573, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6160, 7141, 552, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2780, 3196, 155, 31, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2920, 3360, 552, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6163, 7144, 141, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6121, 7096, 436, 73, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2838, 3266, 639, 33, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2908, 3348, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2773, 3189, 59, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2833, 3261, 486, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2936, 3377, 484, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16314, 328, 710, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3117, 3588, 18, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3118, 3589, 18, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3046, 3506, 21, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6201, 7193, 113, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6247, 7242, 7, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6249, 7245, 7, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3073, 3537, 54, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3123, 3594, 54, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3070, 3534, 502, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6223, 7216, 503, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3128, 3599, 503, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3071, 3535, 505, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6252, 7248, 506, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3076, 3540, 508, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3096, 3565, 734, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3040, 3497, 518, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3088, 3554, 193, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3121, 3592, 92, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3116, 3586, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3119, 3590, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3037, 3494, 540, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3111, 3581, 558, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6235, 7230, 210, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16335, 14701, 1124, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6262, 7260, 100, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3033, 3487, 43, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6232, 7227, 105, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3080, 3545, 139, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3043, 3503, 591, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6236, 7231, 677, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3028, 3482, 190, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3079, 3544, 190, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6240, 7235, 172, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3032, 3486, 269, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6234, 7229, 708, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6224, 7217, 597, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3062, 3524, 227, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6261, 7258, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3167, 3643, 539, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3215, 3700, 65, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3199, 3682, 67, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3185, 3664, 69, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3211, 3696, 70, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3196, 3677, 71, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3209, 3693, 606, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6297, 644, 548, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3166, 3642, 10, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6271, 7269, 710, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3243, 3735, 18, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3275, 3774, 18, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3264, 3759, 21, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3181, 3659, 22, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3250, 3743, 22, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3210, 3695, 32, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3151, 3623, 7, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3232, 3722, 8, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3238, 3730, 8, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3267, 3763, 54, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3247, 3740, 87, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3192, 3673, 576, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3193, 3674, 509, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16185, 13934, 1108, 128, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16186, 14473, 1108, 130, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3126, 3597, 622, 11, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3099, 3569, 56, 6, 21);
INSERT INTO 'dancespublicationsmap' VALUES (3202, 3685, 29, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3091, 3558, 27, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3148, 3620, 26, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3153, 3625, 26, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3159, 3631, 25, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2982, 3427, 521, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2903, 3343, 670, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3039, 3496, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3072, 3536, 129, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3234, 3724, 600, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3053, 3513, 709, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3035, 3489, 600, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2781, 3197, 719, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16324, 14689, 1088, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16323, 14688, 1088, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6216, 7209, 578, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2906, 3346, 580, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6273, 15, 41, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6288, 410, 41, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6258, 7254, 578, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6259, 7255, 578, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2950, 3392, 579, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6230, 7223, 163, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2947, 3389, 201, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2891, 3329, 201, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6290, 480, 39, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2104, 2424, 474, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6298, 650, 39, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3257, 3752, 252, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3197, 3679, 604, 6, 35);
INSERT INTO 'dancespublicationsmap' VALUES (6218, 7211, 604, 7, 35);
INSERT INTO 'dancespublicationsmap' VALUES (3058, 3519, 146, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2979, 3424, 51, 14, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3105, 3575, 51, 16, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3115, 3585, 51, 17, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6209, 7202, 674, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3027, 3481, 445, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3194, 3675, 231, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3074, 3538, 231, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3134, 3605, 648, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3021, 3475, 514, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2945, 3387, 514, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2972, 3416, 640, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3141, 3613, 570, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6257, 7253, 570, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3065, 3527, 595, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6220, 7213, 586, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6222, 7215, 207, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3049, 3509, 199, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3087, 3553, 213, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3036, 3493, 212, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3090, 3557, 709, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2905, 3345, 255, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6244, 7239, 176, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3068, 3531, 721, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6256, 7252, 196, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6264, 7262, 147, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2962, 3406, 513, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6200, 7192, 512, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3191, 3672, 14, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3132, 3603, 678, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6245, 7240, 716, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3094, 3562, 2, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3145, 3617, 3, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3276, 3775, 6, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3164, 3637, 5, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3100, 3570, 103, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3206, 3690, 107, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13224, 1883, 954, 55, 102);
INSERT INTO 'dancespublicationsmap' VALUES (3169, 3645, 116, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3268, 3765, 92, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3213, 3698, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16318, 3991, 1123, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16319, 1738, 1123, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16320, 5187, 1123, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3214, 3699, 75, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3258, 3753, 489, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3260, 3755, 704, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3177, 3655, 652, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3254, 3748, 169, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3228, 3718, 476, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16336, 14702, 1124, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16337, 14703, 1124, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3176, 3654, 448, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3354, 3865, 710, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3432, 3953, 15, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3182, 3660, 236, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3220, 3706, 523, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3297, 3800, 113, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3394, 3910, 104, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3248, 3741, 139, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6302, 694, 277, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6309, 792, 539, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3263, 3758, 677, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3350, 3861, 179, 7, 31);
INSERT INTO 'dancespublicationsmap' VALUES (16321, 6692, 1123, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3307, 3811, 258, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3387, 3899, 65, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3389, 3901, 71, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3269, 3767, 641, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3154, 3626, 522, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (3195, 3676, 82, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6274, 34, 444, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3031, 3485, 155, 30, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3201, 3684, 264, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3190, 3671, 264, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3082, 3547, 643, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3011, 3461, 122, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3162, 3634, 275, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3108, 3578, 275, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3101, 3571, 219, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2983, 3428, 60, 5, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3187, 3666, 639, 52, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3089, 3555, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3042, 3502, 484, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3168, 3644, 460, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6352, 1662, 97, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3289, 3792, 237, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3396, 3912, 11, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3405, 3921, 18, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3377, 3888, 19, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3351, 3862, 21, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3287, 3788, 23, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3403, 3919, 673, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3314, 3820, 501, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3412, 3930, 510, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3303, 3807, 575, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3316, 3822, 575, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3363, 3874, 577, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3391, 3904, 506, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3298, 3801, 509, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3368, 3879, 247, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3325, 3831, 441, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3374, 3885, 210, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16338, 14704, 1124, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16339, 14705, 1124, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16340, 14706, 1124, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16341, 14707, 1124, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16342, 14708, 1124, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3402, 3918, 113, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3359, 3870, 591, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3313, 3819, 571, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3395, 3911, 677, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3331, 3839, 557, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3301, 3804, 620, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6327, 985, 221, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6323, 919, 224, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (3343, 3854, 227, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3536, 4069, 179, 21, 31);
INSERT INTO 'dancespublicationsmap' VALUES (3487, 4017, 67, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3550, 4083, 67, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3425, 3946, 71, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3472, 3997, 237, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3461, 3984, 440, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3535, 4068, 10, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3514, 4046, 33, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3496, 4026, 58, 6, 21);
INSERT INTO 'dancespublicationsmap' VALUES (3384, 3895, 449, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6278, 86, 79, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3386, 3897, 79, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3381, 3892, 751, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3418, 3938, 29, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3414, 3932, 26, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3239, 3731, 670, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3300, 3803, 670, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3367, 3878, 670, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3170, 3647, 126, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3172, 3650, 126, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3304, 3808, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3326, 3833, 129, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3277, 3776, 600, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3308, 3812, 600, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3310, 3814, 255, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3380, 3891, 142, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3327, 3834, 5, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3407, 3924, 700, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3252, 3746, 700, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3349, 3860, 695, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3229, 3719, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3342, 3853, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3288, 3790, 112, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3286, 3787, 648, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3339, 3849, 514, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3306, 3810, 145, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3404, 3920, 128, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3358, 3869, 128, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3324, 3830, 130, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3137, 3608, 16, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3038, 3495, 201, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6324, 934, 41, 9, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6325, 972, 41, 11, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3064, 3526, 13, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6226, 7219, 16, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3208, 3692, 216, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3203, 3686, 216, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3291, 3794, 163, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3173, 3651, 61, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3278, 3777, 61, 5, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6306, 778, 39, 6, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3149, 3621, 127, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6320, 899, 39, 9, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6322, 909, 39, 10, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6301, 662, 40, 78, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6307, 779, 40, 93, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3356, 3867, 230, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3218, 3703, 228, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3508, 4038, 146, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3318, 3824, 146, 37, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3136, 3607, 50, 27, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3138, 3609, 50, 28, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3225, 3711, 50, 29, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3165, 3638, 51, 20, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3946, 4543, 51, 28, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6337, 1259, 497, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3186, 3665, 570, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3355, 3866, 570, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6332, 1072, 272, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6344, 1465, 272, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6291, 510, 706, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3219, 3705, 207, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3283, 3783, 207, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3302, 3805, 634, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3400, 3916, 634, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3382, 3893, 255, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3174, 3652, 260, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3280, 3780, 727, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3281, 3781, 526, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3322, 3828, 526, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3401, 3917, 513, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3352, 3863, 746, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3376, 3887, 15, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3299, 3802, 4, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3463, 3986, 17, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3449, 3972, 8, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3531, 4064, 9, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3518, 4050, 501, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3479, 4004, 510, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3499, 4029, 575, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3478, 4003, 576, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3544, 4077, 576, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3446, 3969, 577, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3543, 4076, 503, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3521, 4054, 504, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3523, 4056, 505, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3438, 3960, 509, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3551, 4084, 247, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3480, 4006, 734, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3549, 4082, 259, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3495, 4025, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3428, 3949, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16344, 14649, 1124, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16345, 14710, 1124, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16346, 13590, 1124, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3538, 4071, 403, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3466, 3989, 236, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3525, 4058, 591, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3509, 4039, 539, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3506, 4036, 190, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3430, 3951, 620, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3484, 4013, 620, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3547, 4080, 620, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3436, 3958, 254, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15959, 13730, 1092, 36, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15961, 7227, 1092, 37, 102);
INSERT INTO 'dancespublicationsmap' VALUES (3644, 4189, 668, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3552, 4086, 21, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3603, 4144, 21, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3568, 4103, 24, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3571, 4106, 35, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3621, 4165, 673, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3585, 4123, 501, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3555, 4089, 505, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3624, 4168, 506, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3439, 3961, 104, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3556, 4090, 104, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3649, 4195, 4, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3639, 4183, 238, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3569, 4104, 518, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3570, 4105, 116, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3572, 4107, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3557, 4091, 367, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3607, 4149, 536, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3605, 4147, 489, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3582, 4119, 704, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3657, 4203, 641, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6369, 1952, 275, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3454, 3977, 243, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3279, 3778, 265, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6433, 3316, 444, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3241, 3733, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3360, 3871, 86, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3346, 3857, 155, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3044, 3504, 122, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3198, 3680, 60, 6, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3295, 3798, 639, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3284, 3784, 639, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3337, 3846, 515, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3455, 3978, 486, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3675, 4225, 679, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3658, 4204, 534, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3659, 4205, 534, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3420, 3940, 6, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3646, 4191, 236, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6436, 3365, 45, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3601, 4142, 591, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3668, 4218, 637, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3590, 4128, 677, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6418, 3078, 546, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3559, 4093, 138, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3669, 4219, 254, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3594, 4133, 157, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3636, 4180, 110, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3680, 4230, 110, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3608, 4150, 135, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3666, 4214, 288, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3620, 4164, 517, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3459, 3982, 622, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3469, 3992, 622, 9, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3588, 4126, 30, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6443, 3538, 77, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3565, 4100, 28, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3530, 4063, 672, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6440, 3500, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3581, 4118, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3678, 4228, 678, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3507, 4037, 700, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3504, 4034, 695, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3539, 4072, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3617, 4161, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3630, 4174, 648, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3482, 4011, 175, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3616, 4160, 145, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3625, 4169, 570, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3672, 4222, 570, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6383, 2312, 706, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6462, 3684, 706, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3417, 3937, 595, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3435, 3957, 586, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3424, 3945, 586, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3663, 4209, 207, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3553, 4087, 207, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3492, 4022, 207, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3442, 3964, 720, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3443, 3965, 76, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3510, 4040, 578, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6364, 1864, 41, 26, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3628, 4172, 167, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3460, 3983, 579, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3416, 3934, 16, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3473, 3998, 216, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3674, 4224, 580, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3336, 3845, 201, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3468, 3991, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3371, 3882, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3372, 3883, 61, 6, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3512, 4043, 61, 7, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6328, 1019, 39, 11, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3450, 3973, 127, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3566, 4101, 146, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6329, 1020, 39, 12, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6388, 2419, 40, 77, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6420, 3104, 40, 82, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6455, 3609, 40, 84, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6453, 3601, 40, 85, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6454, 3607, 40, 92, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3483, 4012, 252, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3475, 4000, 252, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3423, 3944, 755, 6, 35);
INSERT INTO 'dancespublicationsmap' VALUES (6411, 2934, 50, 20, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3537, 4070, 674, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6446, 3561, 50, 30, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3399, 3915, 50, 31, 18);
INSERT INTO 'dancespublicationsmap' VALUES (558, 650, 51, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (563, 655, 51, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2040, 2350, 51, 10, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3413, 3931, 51, 22, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16347, 15, 1125, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16348, 140, 1125, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16349, 389, 1125, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16350, 392, 1125, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3600, 4141, 533, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3579, 4115, 255, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3673, 4223, 260, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3520, 4053, 260, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3451, 3974, 260, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3470, 3994, 727, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3583, 4120, 727, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3494, 4024, 526, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3654, 4200, 716, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3560, 4094, 712, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21814, 18328, 1450, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21815, 18329, 1450, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3452, 3975, 682, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3655, 4201, 517, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6414, 3007, 597, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3634, 4178, 597, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3661, 4207, 274, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3671, 4221, 274, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6422, 3147, 222, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6441, 3524, 222, 5, 31);
INSERT INTO 'dancespublicationsmap' VALUES (3726, 4284, 539, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3748, 4311, 66, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3811, 4386, 66, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3764, 4329, 70, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3807, 4381, 93, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3805, 4379, 440, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3689, 4239, 18, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3788, 4358, 22, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3827, 4404, 33, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3746, 4309, 7, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3786, 4356, 7, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3768, 4336, 54, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3826, 4402, 575, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3738, 4297, 576, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3812, 4387, 503, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3687, 4237, 506, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3803, 4377, 506, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3701, 4254, 509, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3831, 4408, 710, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6483, 3933, 193, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3783, 4353, 164, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3782, 4352, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3828, 4405, 728, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3695, 4246, 536, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3752, 4315, 536, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6494, 4185, 441, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3814, 4389, 558, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3749, 4312, 489, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3813, 4388, 704, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3795, 4367, 618, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3743, 4303, 476, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3794, 4366, 709, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3697, 4248, 523, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6515, 4555, 45, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6530, 4803, 45, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3727, 4285, 105, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3809, 4384, 117, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3769, 4338, 591, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3776, 4345, 485, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3779, 4348, 571, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3781, 4351, 571, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3747, 4310, 277, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3787, 4357, 491, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3792, 4363, 491, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6487, 4004, 546, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3772, 4341, 135, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3932, 4527, 69, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3829, 4406, 548, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3850, 4429, 548, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3848, 4427, 527, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3852, 4431, 20, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3859, 4440, 20, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3874, 4455, 20, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3924, 4518, 20, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3830, 4407, 22, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3922, 4511, 22, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3906, 4491, 23, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3869, 4450, 9, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3854, 4433, 54, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3892, 4476, 54, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3938, 4533, 560, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3821, 4396, 675, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3737, 4296, 610, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3609, 4152, 611, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3766, 4332, 611, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3720, 4275, 641, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3629, 4173, 495, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3732, 4290, 243, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3593, 4132, 86, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3619, 4163, 234, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3422, 3943, 155, 20, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3613, 4156, 275, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6525, 4695, 275, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3485, 4014, 60, 7, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3513, 4044, 60, 9, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3681, 4231, 639, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3637, 4181, 483, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3427, 3948, 59, 999, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3652, 4198, 482, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6569, 5648, 675, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3865, 4446, 247, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3842, 4419, 214, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3887, 4469, 178, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3902, 4487, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3912, 4498, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3930, 4525, 728, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3839, 4416, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3931, 4526, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6561, 5511, 629, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3927, 4521, 679, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3847, 4425, 236, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3886, 4467, 621, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3923, 4515, 543, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3696, 4247, 449, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3714, 4269, 449, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6576, 5822, 257, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3801, 4374, 26, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3858, 4438, 25, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3918, 4506, 25, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3880, 4461, 25, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3898, 4483, 255, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3763, 4328, 126, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3778, 4347, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3808, 4383, 129, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6517, 4572, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6595, 6183, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3840, 4417, 196, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3785, 4355, 147, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3694, 4244, 443, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3789, 4359, 15, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3740, 4300, 88, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3742, 4302, 700, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3693, 4243, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3731, 4289, 175, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6586, 6018, 706, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3799, 4371, 706, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3893, 4477, 38, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3713, 4268, 207, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3818, 4393, 207, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3793, 4365, 212, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3734, 4293, 1, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6488, 4015, 176, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3686, 4236, 142, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6497, 4217, 678, 29, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3797, 4369, 580, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6467, 3730, 41, 59, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3704, 4258, 162, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3690, 4240, 167, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3871, 4452, 579, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3691, 4241, 163, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3706, 4260, 167, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3861, 4442, 13, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3911, 4497, 719, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3724, 4282, 61, 8, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6526, 4744, 39, 61, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3765, 4330, 127, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6518, 4595, 39, 67, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6519, 4638, 39, 68, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6464, 3711, 40, 90, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6531, 4830, 40, 91, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3750, 4313, 604, 2, 35);
INSERT INTO 'dancespublicationsmap' VALUES (3910, 4495, 230, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3692, 4242, 146, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3770, 4339, 146, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3889, 4473, 146, 36, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3632, 4176, 674, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3920, 4508, 246, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3684, 4234, 194, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3919, 4507, 194, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3913, 4499, 17, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3790, 4360, 748, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3806, 4380, 716, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3761, 4325, 1, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3760, 4324, 4, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3775, 4344, 682, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3736, 4295, 682, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3933, 4528, 233, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6537, 4930, 222, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6573, 5732, 222, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6567, 5609, 223, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6596, 6245, 223, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6597, 6294, 223, 5, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6591, 6103, 224, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6598, 6309, 224, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6549, 5330, 225, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6588, 6048, 226, 0, 31);
INSERT INTO 'dancespublicationsmap' VALUES (3899, 4484, 53, 10, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3863, 4444, 53, 16, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3846, 4424, 53, 14, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3888, 4471, 55, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4015, 4622, 442, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4006, 4610, 108, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4007, 4612, 65, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4025, 4635, 68, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4069, 4690, 70, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3951, 4550, 119, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3950, 4548, 10, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4031, 4641, 10, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3960, 4559, 11, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4036, 4646, 11, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3966, 4565, 20, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3962, 4561, 32, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4021, 4629, 37, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3996, 4595, 54, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4048, 4663, 54, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3977, 4576, 673, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4076, 4697, 673, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4066, 4687, 504, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4095, 4719, 509, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4009, 4615, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3955, 4554, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4046, 4661, 75, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4057, 4677, 704, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4037, 4647, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4032, 4642, 679, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4004, 4607, 534, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4013, 4619, 701, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4102, 4726, 149, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3990, 4589, 539, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3944, 4541, 615, 14, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4084, 4708, 157, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4052, 4670, 245, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3961, 4560, 233, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6605, 6434, 224, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6611, 6612, 225, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (4061, 4681, 627, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4106, 4731, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3999, 4599, 109, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3942, 4538, 705, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3968, 4567, 705, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3956, 4555, 53, 20, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4000, 4601, 55, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4053, 4671, 542, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4038, 4648, 587, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6615, 6675, 745, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4135, 4764, 247, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4194, 4840, 68, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6548, 5316, 90, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4184, 4827, 21, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4213, 4865, 21, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4234, 4890, 22, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4132, 4759, 23, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4196, 4844, 33, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4167, 4805, 35, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4068, 4689, 710, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4143, 4776, 115, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4029, 4639, 712, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4043, 4654, 113, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4128, 4755, 9, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4210, 4862, 9, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4117, 4744, 54, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4166, 4804, 54, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4183, 4826, 560, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4225, 4879, 504, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4163, 4801, 505, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4233, 4889, 508, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4146, 4780, 509, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3832, 4409, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4016, 4623, 449, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6577, 5888, 272, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6663, 7282, 761, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6664, 7283, 761, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4137, 4767, 28, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3976, 4575, 77, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3980, 4579, 28, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3959, 4558, 27, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3964, 4563, 27, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4010, 4616, 670, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3711, 4265, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3917, 4505, 234, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4011, 4617, 264, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3939, 4534, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6543, 5176, 275, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3822, 4398, 707, 34, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3703, 4257, 155, 8, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3716, 4271, 60, 8, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3725, 4283, 60, 10, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4026, 4636, 515, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3997, 4596, 515, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3780, 4350, 482, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4055, 4675, 482, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4008, 4614, 700, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3965, 4564, 129, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4041, 4651, 129, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4108, 4733, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3957, 4556, 514, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4097, 4721, 514, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4050, 4667, 640, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3838, 4415, 640, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4005, 4608, 175, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6603, 6410, 272, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4056, 4676, 595, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4002, 4604, 594, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4206, 4857, 38, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4096, 4720, 38, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4001, 4602, 207, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3971, 4570, 678, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3989, 4588, 533, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3879, 4460, 521, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3904, 4489, 160, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3864, 4445, 160, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3953, 4552, 255, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3973, 4572, 173, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6627, 6949, 173, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4153, 4788, 173, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4030, 4640, 721, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3963, 4562, 14, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6645, 3441, 764, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4073, 4694, 716, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6646, 3847, 764, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4235, 4891, 716, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4047, 4662, 200, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4212, 4864, 15, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4147, 4782, 6, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4208, 4860, 509, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4018, 4625, 735, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4034, 4644, 144, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6616, 6711, 39, 91, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6601, 6359, 41, 96, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6614, 6658, 41, 97, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3873, 4454, 162, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4103, 4728, 16, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4089, 4713, 166, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4168, 4806, 13, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3885, 4466, 201, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6590, 6091, 201, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4149, 4784, 201, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4075, 4696, 163, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6617, 6721, 39, 92, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6547, 5310, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6602, 6383, 757, 2, 35);
INSERT INTO 'dancespublicationsmap' VALUES (4202, 4853, 604, 1, 35);
INSERT INTO 'dancespublicationsmap' VALUES (4120, 4747, 604, 9, 35);
INSERT INTO 'dancespublicationsmap' VALUES (4072, 4693, 146, 31, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3855, 4434, 51, 25, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3866, 4447, 51, 26, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3870, 4451, 51, 27, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16352, 650, 1125, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16353, 655, 1125, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16354, 662, 1125, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4217, 4870, 674, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4022, 4630, 674, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3982, 4581, 246, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6637, 7139, 524, 2, 32);
INSERT INTO 'dancespublicationsmap' VALUES (3998, 4598, 194, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4017, 4624, 194, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4263, 4924, 710, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4122, 4749, 151, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4219, 4872, 247, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4161, 4798, 164, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4223, 4876, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4393, 5077, 710, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6705, 7348, 793, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6642, 7231, 541, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4226, 4881, 236, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4116, 4743, 621, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4121, 4748, 270, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4138, 4769, 628, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4188, 4831, 605, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4152, 4787, 615, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4189, 4832, 190, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6618, 6776, 557, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4205, 4856, 135, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6621, 6826, 223, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6630, 6967, 224, 5, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6633, 7030, 225, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6624, 6902, 226, 0, 31);
INSERT INTO 'dancespublicationsmap' VALUES (4192, 4836, 263, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4277, 4942, 440, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4264, 4925, 19, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4238, 4894, 34, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4267, 4929, 34, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4329, 5006, 37, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4266, 4928, 9, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4283, 4950, 501, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4246, 4905, 575, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4294, 4963, 575, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4300, 4971, 576, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4325, 5002, 577, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4273, 4938, 107, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4326, 5003, 613, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4243, 4901, 518, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4332, 5009, 518, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6701, 7344, 787, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6706, 7349, 787, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6729, 7373, 787, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4343, 5020, 178, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4305, 4977, 367, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4286, 4953, 113, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4274, 4939, 210, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4255, 4916, 704, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4251, 4910, 618, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4327, 5004, 618, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4317, 4991, 679, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4259, 4920, 149, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4328, 5005, 118, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4250, 4909, 117, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4307, 4979, 543, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4302, 4973, 605, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4256, 4917, 708, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4322, 4998, 233, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4291, 4960, 597, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4268, 4930, 227, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4347, 5024, 101, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4218, 4871, 53, 17, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4165, 4803, 53, 18, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4477, 5172, 258, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4441, 5130, 668, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4356, 5033, 18, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4363, 5040, 24, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4423, 5111, 32, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4413, 5099, 34, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4355, 5032, 8, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4371, 5048, 560, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4424, 5112, 510, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4372, 5050, 511, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6700, 7343, 786, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6726, 7370, 786, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4405, 5090, 58, 2, 21);
INSERT INTO 'dancespublicationsmap' VALUES (4241, 4897, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6668, 1782, 761, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6669, 5637, 761, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4265, 4927, 28, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4290, 4959, 27, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4385, 5065, 26, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4271, 4935, 26, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4125, 4752, 44, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4224, 4877, 672, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4176, 4815, 672, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4276, 4941, 160, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4346, 5023, 670, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6619, 6785, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4293, 4962, 698, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4339, 5016, 129, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4170, 4808, 129, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4214, 4867, 698, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4216, 4869, 231, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6648, 4375, 764, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6649, 4544, 764, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6739, 7384, 791, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6738, 7383, 791, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6723, 7367, 791, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4173, 4811, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6650, 4668, 764, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4309, 4981, 283, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4154, 4790, 610, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4178, 4820, 262, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4024, 4634, 137, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6604, 6424, 522, 5, 31);
INSERT INTO 'dancespublicationsmap' VALUES (3901, 4486, 547, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6702, 7345, 788, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4344, 5021, 234, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4035, 4645, 436, 18, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3837, 4414, 436, 23, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6711, 7354, 788, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4227, 4882, 155, 3, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4198, 4848, 155, 5, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3986, 4585, 155, 6, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6694, 7337, 778, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4115, 4742, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4200, 4850, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6699, 7342, 798, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6704, 7347, 798, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4193, 4838, 727, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6671, 696, 220, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4222, 4875, 514, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6632, 7017, 514, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4348, 5025, 145, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4280, 4947, 706, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4240, 4896, 255, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4310, 4982, 260, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4207, 4858, 176, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4275, 4940, 176, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4282, 4949, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4345, 5022, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4185, 4828, 256, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4306, 4978, 111, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4171, 4809, 147, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4438, 5127, 748, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4331, 5008, 512, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4257, 4918, 195, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6639, 7195, 443, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4330, 5007, 1, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4315, 4989, 716, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6703, 7346, 790, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6698, 7341, 790, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4451, 5141, 6, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4318, 4992, 76, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4177, 4818, 76, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4287, 4954, 76, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4394, 5078, 575, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4388, 5068, 576, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4391, 5075, 577, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4418, 5105, 502, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4374, 5052, 504, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4485, 5182, 240, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4373, 5051, 734, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4471, 5164, 734, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4486, 5183, 94, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4475, 5168, 92, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6761, 7409, 787, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4060, 4680, 61, 9, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6629, 6957, 41, 100, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4229, 4884, 166, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4248, 4907, 13, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4490, 5187, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6620, 6817, 39, 93, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6635, 7057, 755, 1, 35);
INSERT INTO 'dancespublicationsmap' VALUES (6631, 6971, 757, 1, 35);
INSERT INTO 'dancespublicationsmap' VALUES (4284, 4951, 72, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6709, 7352, 789, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6740, 7385, 789, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4187, 4830, 50, 33, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4281, 4948, 50, 34, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4258, 4919, 51, 30, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4269, 4932, 51, 31, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16358, 934, 1125, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16359, 1019, 1125, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4427, 5115, 674, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6771, 7423, 787, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4431, 5120, 208, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4466, 5158, 208, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4633, 5352, 443, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4376, 5054, 210, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4440, 5129, 210, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4449, 5139, 210, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4408, 5093, 704, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4479, 5175, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4417, 5104, 652, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4358, 5035, 541, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4549, 5256, 76, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4350, 5027, 113, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4483, 5179, 118, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4445, 5135, 571, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4472, 5165, 571, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4432, 5121, 628, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4353, 5030, 677, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4389, 5072, 677, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4443, 5132, 588, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4429, 5118, 605, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4397, 5081, 491, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4414, 5101, 546, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4428, 5117, 549, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4403, 5088, 708, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4484, 5180, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4411, 5096, 109, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4383, 5062, 55, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4468, 5160, 55, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4528, 5231, 668, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4518, 5218, 276, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4544, 5250, 601, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4659, 5386, 65, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4586, 5301, 66, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4524, 5224, 68, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4515, 5215, 70, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4650, 5373, 152, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4493, 5190, 606, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4642, 5364, 18, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4509, 5208, 22, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4609, 5326, 36, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4632, 5351, 7, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4508, 5207, 8, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4598, 5313, 675, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4564, 5271, 108, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4592, 5307, 87, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4571, 5280, 501, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4580, 5294, 510, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4634, 5353, 510, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4656, 5381, 511, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4545, 5251, 576, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4541, 5247, 577, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4537, 5242, 508, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4561, 5268, 509, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4552, 5259, 238, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4653, 5377, 238, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4547, 5254, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4519, 5219, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4572, 5281, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4570, 5279, 536, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4647, 5369, 540, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4579, 5293, 558, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4543, 5249, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4655, 5380, 652, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4648, 5370, 541, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4531, 5235, 701, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4627, 5345, 236, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4636, 5357, 105, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4534, 5238, 118, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4550, 5257, 591, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4619, 5336, 184, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4530, 5234, 605, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4576, 5285, 615, 7, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4620, 5337, 557, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4577, 5288, 620, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4503, 5202, 135, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4535, 5239, 1, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4514, 5213, 708, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4613, 5330, 227, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4522, 5222, 2, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6783, 7437, 786, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4433, 5122, 197, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4629, 5347, 28, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4384, 5063, 672, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4354, 5031, 533, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4382, 5061, 670, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4426, 5114, 126, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4591, 5306, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4652, 5376, 2, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4375, 5053, 700, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6779, 7432, 791, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6752, 7399, 791, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4447, 5137, 699, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4420, 5107, 699, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4510, 5209, 699, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4640, 5362, 6, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4523, 5223, 17, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6748, 7395, 791, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6775, 7427, 791, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4560, 5267, 168, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4396, 5080, 648, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4467, 5159, 648, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4574, 5283, 145, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6746, 7393, 798, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6754, 7402, 798, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6772, 7424, 798, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4464, 5156, 570, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4505, 5204, 38, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4644, 5366, 207, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4463, 5155, 690, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4630, 5348, 552, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4402, 5087, 86, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4623, 5340, 545, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4593, 5308, 155, 18, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4301, 4972, 547, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6751, 7398, 788, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6696, 7339, 778, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6707, 7350, 778, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4395, 5079, 643, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4421, 5108, 643, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4448, 5138, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4461, 5151, 486, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4554, 5261, 484, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4578, 5290, 212, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4455, 5145, 533, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4502, 5201, 521, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4511, 5210, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4512, 5211, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4359, 5036, 196, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4654, 5378, 196, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4401, 5086, 195, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4398, 5083, 526, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4668, 5396, 748, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4667, 5395, 195, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4614, 5331, 512, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4546, 5253, 512, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4507, 5206, 746, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4494, 5191, 746, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6764, 7413, 790, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6760, 7408, 790, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4589, 5304, 563, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4768, 5517, 442, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4806, 5562, 178, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4715, 5456, 601, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4669, 5397, 65, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4756, 5503, 68, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4819, 5578, 69, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4841, 5602, 71, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4716, 5457, 440, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4765, 5514, 440, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4762, 5511, 606, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4719, 5462, 11, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4720, 5463, 19, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4701, 5441, 20, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4773, 5522, 22, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4679, 5407, 36, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4684, 5412, 37, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4800, 5555, 37, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4750, 5497, 7, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4583, 5298, 162, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4492, 5189, 167, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4378, 5056, 579, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4504, 5203, 166, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4621, 5338, 579, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4499, 5198, 201, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4439, 5128, 61, 10, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4626, 5344, 127, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4587, 5302, 146, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4740, 5485, 146, 34, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6784, 7438, 789, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4637, 5358, 50, 35, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4351, 5028, 51, 32, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16365, 1368, 1125, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4559, 5266, 612, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4781, 5533, 612, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4831, 5591, 8, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4785, 5539, 54, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4688, 5417, 673, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4828, 5587, 511, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4758, 5505, 576, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4706, 5447, 577, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4796, 5551, 577, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4840, 5601, 507, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4821, 5580, 107, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4843, 5604, 107, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4824, 5583, 241, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4788, 5542, 116, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4803, 5559, 92, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4673, 5401, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4818, 5577, 131, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4776, 5526, 558, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4699, 5437, 489, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4696, 5431, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4792, 5546, 273, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4802, 5558, 149, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4830, 5590, 149, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4676, 5404, 621, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4801, 5556, 523, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4538, 5243, 90, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4772, 5521, 118, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4677, 5405, 99, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4702, 5442, 571, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4767, 5516, 184, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4783, 5537, 539, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4747, 5494, 588, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4728, 5471, 605, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4672, 5400, 710, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4822, 5581, 550, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4814, 5572, 254, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4847, 5609, 227, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4937, 5715, 442, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4902, 5673, 603, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4914, 5687, 64, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4866, 5628, 152, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4842, 5603, 551, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4807, 5563, 678, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4982, 5765, 23, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5008, 5794, 24, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5014, 5800, 24, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4955, 5734, 34, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5018, 5804, 35, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4850, 5612, 36, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5022, 5808, 37, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4885, 5652, 501, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4933, 5711, 64, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4870, 5633, 510, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5029, 5815, 511, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4928, 5706, 575, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4971, 5753, 576, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4874, 5639, 504, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4969, 5751, 613, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4905, 5677, 238, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5032, 5818, 496, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4883, 5650, 164, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4996, 5782, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4849, 5611, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4896, 5666, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4944, 5722, 100, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4863, 5625, 701, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5011, 5797, 701, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4926, 5704, 236, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4932, 5710, 523, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4988, 5771, 543, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4901, 5672, 539, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4913, 5686, 56, 5, 21);
INSERT INTO 'dancespublicationsmap' VALUES (4925, 5703, 56, 11, 21);
INSERT INTO 'dancespublicationsmap' VALUES (4837, 5598, 449, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4704, 5444, 197, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4703, 5443, 197, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4918, 5691, 29, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4935, 5713, 27, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4912, 5685, 77, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4833, 5593, 77, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4770, 5519, 27, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4862, 5624, 26, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4820, 5579, 670, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4793, 5547, 126, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4797, 5552, 126, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4689, 5418, 132, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4855, 5617, 129, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4722, 5465, 600, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4731, 5474, 709, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4769, 5518, 196, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4924, 5702, 6, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5009, 5795, 699, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4590, 5305, 698, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4746, 5493, 112, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5026, 5812, 112, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4542, 5248, 283, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4581, 5296, 514, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5036, 5824, 220, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4808, 5564, 570, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4678, 5406, 595, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4812, 5569, 586, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4825, 5584, 207, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5012, 5798, 207, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4949, 5727, 443, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4889, 5658, 1, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4805, 5561, 521, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4795, 5550, 260, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4736, 5480, 142, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4705, 5445, 212, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4743, 5489, 111, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4817, 5576, 526, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4670, 5398, 14, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4517, 5217, 281, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4876, 5641, 3, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4709, 5450, 3, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4698, 5436, 4, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4930, 5708, 5, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5016, 5802, 52, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4594, 5309, 137, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4798, 5553, 552, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4859, 5621, 155, 6, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4908, 5681, 444, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4724, 5467, 444, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4695, 5425, 552, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6758, 7406, 778, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4721, 5464, 643, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4500, 5199, 122, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4532, 5236, 141, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4939, 5717, 82, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4942, 5720, 639, 44, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4754, 5501, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4811, 5568, 483, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4973, 5755, 52, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4816, 5575, 682, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4927, 5705, 605, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4974, 5756, 491, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4999, 5785, 172, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4871, 5634, 557, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4893, 5662, 549, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4975, 5757, 233, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4953, 5732, 227, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4964, 5746, 263, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4860, 5622, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4881, 5647, 635, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5020, 5806, 109, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5035, 5822, 109, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6871, 43, 19, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5045, 5834, 734, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5043, 5831, 116, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6912, 7563, 802, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6913, 7564, 802, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6914, 7565, 802, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6915, 7566, 802, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6916, 7567, 802, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6917, 7569, 802, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6926, 7575, 802, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6822, 7488, 787, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4853, 5615, 128, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4813, 5571, 130, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5002, 5788, 130, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4739, 5484, 162, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5030, 5816, 165, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4919, 5696, 580, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4993, 5778, 167, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4775, 5525, 13, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4694, 5423, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4898, 5669, 201, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4873, 5638, 674, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5027, 5813, 252, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4984, 5767, 146, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4856, 5618, 714, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4985, 5768, 714, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4994, 5779, 146, 29, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4674, 5402, 50, 36, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4692, 5421, 50, 37, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16374, 2631, 1125, 28, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16375, 2713, 1125, 29, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16380, 2979, 1125, 34, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4992, 5776, 143, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4755, 5502, 497, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6824, 7490, 787, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6852, 7524, 787, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6856, 7528, 787, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4887, 5654, 113, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4864, 5626, 195, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4894, 5663, 195, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4940, 5718, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5034, 5821, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4936, 5714, 533, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5041, 5829, 533, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6968, 7245, 805, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6969, 5497, 805, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6970, 5351, 805, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6971, 7242, 805, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6972, 3623, 805, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6973, 4309, 805, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7076, 2153, 808, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7077, 522, 808, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7078, 1786, 808, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7079, 3608, 808, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (4968, 5750, 698, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4921, 5698, 695, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4965, 5747, 695, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4946, 5724, 445, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6841, 7510, 791, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6847, 7516, 791, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6840, 7509, 791, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4981, 5764, 283, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4987, 5770, 175, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6867, 4398, 220, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6831, 7498, 798, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6837, 7506, 798, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6839, 7508, 798, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6846, 7515, 798, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5000, 5786, 255, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4880, 5646, 727, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4934, 5712, 513, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6853, 7525, 790, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6836, 7505, 790, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6845, 7514, 790, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7445, 7549, 293, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7457, 351, 569, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7487, 1313, 569, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7466, 7619, 572, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4857, 5619, 137, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6825, 7491, 788, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6848, 7517, 778, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6850, 7521, 778, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7004, 4641, 806, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7005, 3091, 806, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7006, 2428, 806, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6872, 5239, 799, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6873, 6748, 799, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6874, 1210, 799, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6875, 5007, 799, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6876, 4293, 799, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7040, 1864, 807, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7041, 4442, 807, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7042, 4806, 807, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7043, 410, 807, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7044, 2925, 807, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7160, 3763, 810, 101, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7161, 6952, 810, 102, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7170, 4663, 810, 111, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7171, 4804, 810, 112, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6924, 6658, 804, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6925, 4324, 804, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6934, 5436, 804, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6935, 3437, 804, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6936, 3802, 804, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6937, 4195, 804, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6938, 2302, 804, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6939, 6915, 804, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6940, 2916, 804, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6941, 2812, 804, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6942, 2053, 804, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6943, 1348, 804, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6944, 6505, 804, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6945, 1799, 804, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6946, 3236, 804, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6947, 5708, 804, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6948, 723, 804, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6949, 3834, 804, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6950, 5963, 804, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6951, 1790, 804, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6952, 3637, 804, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6953, 1476, 804, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6954, 7109, 804, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6955, 1274, 804, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6956, 5731, 804, 25, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6957, 1916, 804, 26, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6958, 5702, 804, 27, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6959, 3775, 804, 28, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6960, 5141, 804, 29, 14);
INSERT INTO 'dancespublicationsmap' VALUES (4980, 5763, 141, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6909, 3418, 801, 1, 11);
INSERT INTO 'dancespublicationsmap' VALUES (4749, 5496, 284, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5046, 5836, 486, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4872, 5636, 482, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (21070, 292, 1407, 10, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21072, 312, 1407, 10, 101);
INSERT INTO 'dancespublicationsmap' VALUES (4922, 5699, 61, 11, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6869, 3860, 755, 10, 35);
INSERT INTO 'dancespublicationsmap' VALUES (6868, 2882, 604, 8, 35);
INSERT INTO 'dancespublicationsmap' VALUES (6842, 7511, 789, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6832, 7499, 789, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4983, 5766, 50, 39, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4972, 5754, 51, 33, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16383, 3424, 1125, 37, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16384, 3529, 1125, 38, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16385, 3561, 1125, 39, 10);
INSERT INTO 'dancespublicationsmap' VALUES (7501, 7684, 97, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7486, 7651, 193, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7468, 1519, 170, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7112, 4968, 809, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7113, 3888, 809, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7114, 1624, 809, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7115, 76, 809, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7116, 6797, 809, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7117, 5463, 809, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7118, 7143, 809, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7123, 43, 809, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7119, 6721, 809, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7120, 6817, 809, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7121, 4925, 809, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7122, 5878, 809, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7124, 1020, 809, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7125, 6848, 809, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7126, 4431, 809, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7127, 6885, 809, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7128, 4440, 809, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7129, 4455, 809, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7130, 1762, 809, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7131, 4565, 809, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7132, 4518, 809, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7133, 5441, 809, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7134, 2024, 809, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7135, 1280, 809, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7136, 4144, 809, 25, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7137, 4865, 809, 26, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7138, 3862, 809, 27, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7249, 6710, 813, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7250, 5347, 813, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7251, 656, 813, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7252, 6285, 813, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7253, 4927, 813, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7254, 4100, 813, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7255, 4767, 813, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7256, 1480, 813, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7257, 2010, 813, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7258, 4579, 813, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7259, 6824, 813, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7260, 4995, 813, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7261, 2158, 813, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7262, 1469, 813, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7263, 6271, 813, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7264, 2868, 813, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7265, 3685, 813, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7266, 3938, 813, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7267, 7037, 813, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7268, 2030, 813, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7269, 6406, 813, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7270, 1163, 813, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7271, 1446, 813, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7272, 773, 813, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7273, 2777, 813, 25, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7274, 5691, 813, 26, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7275, 1283, 685, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7276, 2742, 685, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7277, 2918, 685, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7278, 430, 685, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7279, 4126, 685, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7280, 2700, 685, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7281, 910, 685, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7282, 6058, 685, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7283, 1641, 685, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7284, 5160, 685, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7285, 3267, 685, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7286, 4601, 685, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7287, 4471, 685, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7288, 5062, 685, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7289, 4092, 685, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7290, 1908, 685, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7291, 739, 685, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7292, 1304, 685, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7293, 2725, 685, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7294, 5802, 685, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7295, 3310, 685, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7296, 5755, 685, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7297, 6391, 685, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7298, 1647, 685, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7299, 1244, 685, 25, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7300, 4155, 685, 26, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7305, 5310, 685, 27, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7388, 549, 763, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7389, 796, 763, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7390, 1350, 763, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21071, 301, 1407, 10, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21073, 314, 1407, 11, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21077, 353, 1407, 12, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21078, 373, 1407, 12, 101);
INSERT INTO 'dancespublicationsmap' VALUES (7467, 7620, 572, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7495, 7661, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7475, 7635, 306, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7482, 7645, 306, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7429, 1524, 441, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7518, 5965, 319, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7444, 7467, 291, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7453, 7593, 291, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7474, 7634, 291, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7430, 4397, 215, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7431, 4472, 215, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7432, 4847, 215, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7433, 4859, 215, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7434, 4936, 215, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7435, 4958, 215, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7436, 5391, 215, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7437, 5481, 215, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7438, 6149, 215, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7439, 6537, 215, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7449, 7585, 597, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7387, 6902, 227, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7400, 153, 202, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7172, 4595, 810, 113, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7173, 480, 810, 114, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7174, 3154, 810, 115, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7175, 1780, 810, 116, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7213, 2136, 812, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7214, 1154, 812, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7215, 760, 812, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7216, 1586, 812, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7306, 3338, 688, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7307, 5111, 688, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7308, 3695, 688, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7309, 2084, 688, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7310, 4561, 688, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7311, 6736, 688, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7312, 2432, 688, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7313, 1223, 688, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7314, 6091, 688, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7315, 2353, 688, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7316, 2332, 688, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7317, 3762, 688, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7318, 1768, 688, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7319, 5422, 688, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7320, 5529, 688, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7321, 2323, 688, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7322, 5860, 688, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7323, 4484, 688, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7324, 6701, 688, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7328, 1884, 688, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7329, 4444, 688, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7336, 4844, 711, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (5021, 5807, 60, 12, 18);
INSERT INTO 'dancespublicationsmap' VALUES (7498, 7678, 311, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7384, 578, 39, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (7385, 7073, 39, 96, 18);
INSERT INTO 'dancespublicationsmap' VALUES (7508, 7691, 314, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16401, 4334, 1125, 55, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16402, 4434, 1125, 56, 10);
INSERT INTO 'dancespublicationsmap' VALUES (7600, 7786, 301, 2, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7619, 7807, 331, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7539, 7732, 320, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7544, 7735, 320, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7522, 7712, 306, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7525, 7714, 306, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7572, 7750, 306, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7687, 7877, 306, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7523, 2099, 319, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7519, 7708, 291, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7527, 2359, 291, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7531, 7717, 291, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7532, 7718, 291, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7545, 7737, 291, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7659, 7844, 291, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7665, 7853, 291, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7667, 7856, 291, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7668, 7857, 291, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7672, 7861, 291, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7554, 2542, 325, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7556, 2754, 325, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7639, 7256, 534, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7634, 4116, 270, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7538, 7731, 443, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7578, 7756, 233, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7528, 2255, 597, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7609, 7796, 597, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7671, 4775, 597, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7644, 7825, 299, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7594, 7775, 299, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7566, 2959, 326, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7568, 2992, 307, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7561, 2935, 307, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7535, 7724, 290, 2, 35);
INSERT INTO 'dancespublicationsmap' VALUES (7494, 7660, 310, 1, 35);
INSERT INTO 'dancespublicationsmap' VALUES (7521, 2080, 310, 2, 35);
INSERT INTO 'dancespublicationsmap' VALUES (7526, 2036, 310, 3, 35);
INSERT INTO 'dancespublicationsmap' VALUES (7562, 5286, 321, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7542, 7734, 321, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7555, 2614, 321, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7541, 7335, 321, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7587, 3532, 321, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7573, 7751, 299, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7647, 7828, 299, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7450, 7589, 299, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7571, 3075, 569, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7617, 3850, 687, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7673, 7862, 703, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7685, 7874, 699, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7597, 7781, 699, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7524, 2113, 791, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7458, 7604, 514, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7401, 153, 84, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7402, 1133, 84, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (7403, 4506, 84, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7404, 4782, 84, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7405, 4657, 84, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7520, 7710, 293, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7662, 7847, 293, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7546, 2647, 323, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7613, 3806, 323, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7649, 7830, 572, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7651, 7833, 572, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7692, 5214, 323, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7693, 6000, 323, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7543, 2582, 322, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7552, 2766, 322, 2, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7553, 2793, 322, 3, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7608, 7795, 308, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7652, 7835, 308, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7559, 3587, 303, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7560, 3712, 303, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7581, 7760, 303, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7592, 7771, 303, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7570, 7747, 304, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7583, 7766, 304, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7585, 7769, 304, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7590, 7431, 304, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7591, 7770, 304, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7736, 5781, 511, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7839, 244, 576, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7733, 7919, 320, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7757, 5938, 320, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7788, 6663, 320, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7786, 7979, 193, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7801, 7998, 170, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7829, 8026, 306, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7834, 8034, 306, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7793, 7989, 291, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7732, 7918, 325, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7767, 7963, 325, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7804, 8003, 325, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7747, 5955, 549, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7764, 7958, 597, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7776, 6498, 597, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7826, 8022, 597, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13254, 2294, 954, 64, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13726, 2267, 954, 64, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13255, 2302, 954, 65, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13257, 2323, 954, 65, 102);
INSERT INTO 'dancespublicationsmap' VALUES (7775, 7969, 627, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7781, 7976, 627, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7785, 7978, 627, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7748, 5950, 263, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7739, 7928, 308, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7743, 7931, 303, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7797, 7993, 303, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7809, 8007, 303, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7823, 8018, 303, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7796, 7992, 304, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7807, 8005, 304, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7810, 8008, 304, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7730, 7914, 300, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7791, 7983, 300, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7792, 7986, 300, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7794, 7990, 300, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13256, 2321, 954, 65, 102);
INSERT INTO 'dancespublicationsmap' VALUES (7558, 2989, 294, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7576, 7754, 294, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7579, 7758, 294, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7588, 5942, 294, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7549, 7742, 317, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7678, 6493, 317, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7550, 7743, 317, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7567, 2984, 328, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7646, 4361, 328, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7638, 4146, 328, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7325, 5904, 688, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7326, 4256, 688, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7327, 4424, 688, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7348, 5136, 711, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7349, 4929, 711, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7350, 1376, 711, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7351, 5099, 711, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7352, 4805, 711, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7353, 3108, 711, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7354, 221, 711, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7355, 4106, 711, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7356, 2437, 711, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7357, 6756, 711, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7358, 5804, 711, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7359, 6380, 711, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7360, 5326, 718, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7361, 5612, 718, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7362, 5407, 718, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7363, 2394, 718, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7364, 7105, 718, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7365, 219, 718, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7366, 183, 718, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7367, 2469, 718, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7369, 5555, 718, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7370, 4629, 718, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7371, 2616, 718, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7372, 7204, 718, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7822, 7191, 219, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7440, 21, 284, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13259, 2349, 954, 66, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13258, 2332, 954, 66, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13261, 2353, 954, 66, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13260, 2350, 954, 66, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13263, 2367, 954, 67, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13262, 2360, 954, 67, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13264, 2389, 954, 68, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13267, 2409, 954, 68, 102);
INSERT INTO 'dancespublicationsmap' VALUES (6389, 2428, 39, 23, 18);
INSERT INTO 'dancespublicationsmap' VALUES (7577, 7755, 311, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7670, 4768, 337, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7664, 7852, 604, 5, 35);
INSERT INTO 'dancespublicationsmap' VALUES (16404, 4451, 1125, 58, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16405, 4543, 1125, 59, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16406, 4638, 1125, 60, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16407, 4830, 1125, 61, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16408, 4919, 1125, 62, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16409, 4932, 1125, 63, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16410, 4948, 1125, 64, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16411, 5028, 1125, 65, 10);
INSERT INTO 'dancespublicationsmap' VALUES (13266, 2408, 954, 68, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13268, 2415, 954, 68, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13265, 2394, 954, 68, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13271, 2428, 954, 69, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13270, 2421, 954, 69, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13269, 2419, 954, 69, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13741, 2453, 954, 70, 102);
INSERT INTO 'dancespublicationsmap' VALUES (7725, 1591, 340, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7789, 7981, 293, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21085, 480, 1407, 15, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21087, 15405, 1407, 15, 101);
INSERT INTO 'dancespublicationsmap' VALUES (16486, 7940, 1128, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7820, 8014, 293, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7727, 4659, 340, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7799, 6757, 340, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16484, 7662, 1128, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7595, 7777, 290, 3, 35);
INSERT INTO 'dancespublicationsmap' VALUES (7735, 5772, 290, 4, 35);
INSERT INTO 'dancespublicationsmap' VALUES (7744, 7933, 290, 5, 35);
INSERT INTO 'dancespublicationsmap' VALUES (7750, 7942, 290, 6, 35);
INSERT INTO 'dancespublicationsmap' VALUES (7755, 6055, 307, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7841, 8039, 297, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7842, 8040, 297, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7843, 8041, 297, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7844, 8042, 297, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7751, 2142, 290, 7, 35);
INSERT INTO 'dancespublicationsmap' VALUES (7778, 3085, 290, 8, 35);
INSERT INTO 'dancespublicationsmap' VALUES (7821, 8015, 290, 9, 35);
INSERT INTO 'dancespublicationsmap' VALUES (7765, 7959, 310, 6, 35);
INSERT INTO 'dancespublicationsmap' VALUES (7699, 7892, 321, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7742, 7930, 321, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7761, 7953, 321, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7705, 5292, 321, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7828, 8025, 315, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7830, 8027, 315, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7833, 8032, 315, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7831, 8028, 315, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7836, 8036, 315, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7835, 8035, 315, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7832, 8031, 315, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7827, 8023, 315, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7706, 5399, 698, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7702, 5291, 727, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16485, 6141, 1128, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7723, 5665, 340, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7724, 1444, 340, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7811, 6921, 340, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7711, 532, 322, 15, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7983, 887, 322, 24, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7865, 3443, 687, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7777, 6503, 687, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7783, 6591, 687, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7710, 427, 322, 14, 40);
INSERT INTO 'dancespublicationsmap' VALUES (22827, 14584, 1135, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8635, 8114, 292, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8636, 8115, 292, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8637, 8116, 292, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8638, 8117, 292, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8639, 8118, 292, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8640, 8119, 292, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8641, 8120, 292, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8642, 8121, 292, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8643, 8122, 292, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8644, 8123, 292, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22829, 19103, 1514, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22830, 19104, 1514, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22831, 12812, 1514, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22832, 13319, 1514, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22833, 13320, 1514, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22834, 19105, 1514, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22835, 19106, 1514, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8718, 445, 775, 188, 31);
INSERT INTO 'dancespublicationsmap' VALUES (8719, 462, 775, 191, 31);
INSERT INTO 'dancespublicationsmap' VALUES (8720, 584, 775, 193, 31);
INSERT INTO 'dancespublicationsmap' VALUES (8721, 1128, 775, 195, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8645, 8124, 302, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8646, 8125, 302, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8647, 8126, 302, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8608, 556, 333, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8609, 3772, 333, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8611, 659, 78, 54, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8612, 1306, 78, 55, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8613, 3556, 78, 56, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8603, 2037, 322, 33, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8615, 1560, 290, 10, 35);
INSERT INTO 'dancespublicationsmap' VALUES (8614, 8089, 310, 7, 35);
INSERT INTO 'dancespublicationsmap' VALUES (8604, 2208, 322, 34, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8605, 2596, 322, 35, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8606, 4944, 322, 36, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8150, 2822, 191, 62, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8151, 2868, 191, 62, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8149, 2821, 191, 62, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8656, 5170, 678, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (8904, 1446, 74, 35, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8905, 1466, 74, 35, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8906, 1469, 74, 36, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8907, 1478, 74, 36, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8908, 1480, 74, 36, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8657, 8102, 327, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8909, 1501, 74, 37, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8910, 1521, 74, 37, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8911, 1544, 74, 37, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8912, 1562, 74, 38, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8595, 758, 322, 25, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8596, 898, 322, 26, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8597, 925, 322, 27, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8598, 1235, 322, 28, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8914, 1586, 74, 38, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8915, 1588, 74, 38, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8913, 1578, 74, 38, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8917, 1615, 74, 39, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8916, 1582, 74, 39, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8918, 1624, 74, 39, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8919, 1647, 74, 39, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8599, 1363, 322, 29, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8600, 1454, 322, 30, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8601, 1459, 322, 31, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8602, 1464, 322, 32, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8152, 2878, 191, 62, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8153, 2903, 191, 62, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8156, 2918, 191, 63, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8154, 2910, 191, 63, 104);
INSERT INTO 'dancespublicationsmap' VALUES (16424, 441, 1126, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16427, 742, 1126, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16430, 1881, 1126, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6512, 4518, 39, 65, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6513, 4543, 39, 66, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6606, 6471, 39, 87, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16431, 2846, 1126, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16433, 3428, 1126, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16435, 3680, 1126, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16426, 633, 1126, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16428, 805, 1126, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16432, 3225, 1126, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16434, 3651, 1126, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16429, 1789, 1126, 28, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2836, 3264, 73, 106, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3086, 3551, 73, 107, 40);
INSERT INTO 'dancespublicationsmap' VALUES (22828, 19604, 73, 310, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6607, 6477, 39, 88, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6610, 6552, 39, 89, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6612, 6634, 39, 90, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8610, 3016, 604, 10, 35);
INSERT INTO 'dancespublicationsmap' VALUES (8013, 8086, 50, 11, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8580, 3594, 342, 16, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8581, 3672, 342, 17, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8582, 3834, 342, 18, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8583, 4032, 342, 19, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8584, 5802, 342, 20, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8585, 5964, 342, 21, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8586, 7147, 342, 22, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8587, 522, 342, 23, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8588, 743, 342, 24, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8589, 1501, 342, 25, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8590, 3588, 342, 26, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8591, 4646, 342, 27, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8592, 5462, 342, 28, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16487, 12793, 1130, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (7737, 5824, 707, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7779, 7973, 284, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7721, 5656, 284, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8593, 5982, 342, 29, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16418, 5889, 1125, 72, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16419, 5981, 1125, 73, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16420, 6061, 1125, 74, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16421, 6552, 1125, 75, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16422, 7073, 1125, 76, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16423, 7173, 1125, 77, 10);
INSERT INTO 'dancespublicationsmap' VALUES (8159, 2925, 191, 63, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8158, 2924, 191, 63, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8157, 6477, 191, 63, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8155, 2916, 191, 63, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8160, 2934, 191, 64, 104);
INSERT INTO 'dancespublicationsmap' VALUES (21084, 462, 1407, 15, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21086, 12426, 1407, 15, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21089, 7351, 1407, 16, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21088, 13577, 1407, 16, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21090, 522, 1407, 16, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21091, 535, 1407, 17, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21093, 559, 1407, 17, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21092, 549, 1407, 17, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21094, 9562, 1407, 18, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21096, 584, 1407, 18, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21095, 570, 1407, 18, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21099, 596, 1407, 19, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21098, 594, 1407, 19, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21097, 588, 1407, 19, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21100, 633, 1407, 20, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21101, 652, 1407, 20, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21102, 658, 1407, 21, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21103, 674, 1407, 21, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21104, 13586, 1407, 21, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21107, 754, 1407, 22, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21106, 753, 1407, 22, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21105, 743, 1407, 22, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21109, 769, 1407, 22, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21108, 760, 1407, 22, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21112, 779, 1407, 23, 101);
INSERT INTO 'dancespublicationsmap' VALUES (13277, 2495, 954, 71, 102);
INSERT INTO 'dancespublicationsmap' VALUES (22836, 16180, 1514, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22837, 19107, 1514, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22838, 13323, 1514, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22839, 15585, 1514, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22840, 13324, 1514, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22841, 19108, 1514, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22842, 12814, 1514, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13276, 2494, 954, 71, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13279, 2501, 954, 72, 102);
INSERT INTO 'dancespublicationsmap' VALUES (22843, 16179, 1514, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13280, 2504, 954, 72, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13281, 2506, 954, 72, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13282, 2556, 954, 73, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13782, 250, 954, 73, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13284, 2593, 954, 74, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13285, 2600, 954, 74, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13718, 2616, 954, 74, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13286, 2631, 954, 74, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13287, 2644, 954, 75, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13289, 2661, 954, 75, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13290, 2682, 954, 75, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13288, 2645, 954, 75, 102);
INSERT INTO 'dancespublicationsmap' VALUES (22844, 13325, 1514, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21120, 893, 1407, 26, 101);
INSERT INTO 'dancespublicationsmap' VALUES (22845, 19109, 1514, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22846, 19110, 1514, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22847, 12824, 1514, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22848, 19111, 1514, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22849, 13326, 1514, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22850, 19112, 1514, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8724, 1841, 775, 201, 31);
INSERT INTO 'dancespublicationsmap' VALUES (8725, 5693, 775, 203, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8726, 2604, 775, 212, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8727, 2935, 775, 213, 16);
INSERT INTO 'dancespublicationsmap' VALUES (22851, 13321, 1514, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22852, 12813, 1514, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22853, 13322, 1514, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22854, 12815, 1514, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22855, 15456, 1514, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22856, 12825, 1514, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22857, 19113, 1514, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22858, 13327, 1514, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8655, 4299, 336, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9470, 4789, 725, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9471, 4333, 725, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9472, 4628, 725, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9473, 2151, 725, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9474, 1127, 725, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9475, 5098, 725, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9476, 5181, 725, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9477, 2329, 725, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9478, 3470, 725, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9479, 1720, 725, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9480, 4984, 725, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9481, 6705, 725, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9487, 6173, 730, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9488, 6002, 730, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9489, 903, 730, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9490, 7184, 730, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9491, 226, 730, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9492, 1517, 730, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9493, 6546, 730, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9494, 7164, 730, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9495, 4364, 730, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9496, 7200, 730, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9497, 6858, 730, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9498, 782, 730, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9499, 1335, 730, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9500, 3421, 730, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9501, 5174, 730, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9468, 7531, 48, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9570, 452, 731, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9571, 1183, 731, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9572, 1245, 731, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9573, 2643, 731, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9574, 3669, 731, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9575, 3817, 731, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9576, 4349, 731, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9577, 4887, 731, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9578, 5070, 731, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9579, 5082, 731, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9580, 5478, 731, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9581, 6222, 731, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9609, 8241, 351, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9610, 8242, 351, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9611, 8243, 351, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9612, 8244, 351, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9613, 8245, 351, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9614, 8246, 351, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9615, 8247, 351, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9616, 8248, 351, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9617, 8249, 351, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9618, 8250, 351, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9619, 8251, 351, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9620, 8252, 351, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9621, 8253, 351, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9622, 8254, 351, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9623, 8255, 351, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9624, 8256, 351, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9625, 8257, 351, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9533, 8178, 343, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9534, 8179, 343, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9535, 8180, 343, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9536, 8181, 343, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9537, 8182, 343, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9538, 8183, 343, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9539, 8184, 343, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9540, 8185, 343, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8659, 8139, 310, 8, 35);
INSERT INTO 'dancespublicationsmap' VALUES (16453, 6720, 1127, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16454, 822, 1127, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16455, 8732, 1127, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (9700, 8328, 359, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9701, 8329, 359, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9702, 8330, 359, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16438, 4014, 1126, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16439, 4271, 1126, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (9626, 8258, 352, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9703, 8331, 359, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9704, 8332, 359, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9705, 8333, 359, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9706, 8334, 359, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9707, 8335, 359, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9708, 8336, 359, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9709, 8337, 359, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9710, 8338, 359, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9711, 8339, 359, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9347, 5982, 74, 146, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8658, 8138, 707, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9549, 8111, 344, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9550, 8112, 344, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9551, 8194, 344, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9552, 8113, 344, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9553, 8195, 344, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9554, 8196, 344, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9555, 8197, 344, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9647, 8279, 353, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9648, 8280, 353, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9661, 8293, 355, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9345, 5964, 74, 146, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9344, 5963, 74, 146, 103);
INSERT INTO 'dancespublicationsmap' VALUES (21123, 909, 1407, 27, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21122, 905, 1407, 27, 101);
INSERT INTO 'dancespublicationsmap' VALUES (9781, 8413, 363, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9662, 8294, 355, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9532, 5540, 287, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9663, 8295, 355, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9665, 8297, 355, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9664, 8296, 355, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9666, 8298, 355, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9346, 5981, 74, 146, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9348, 6010, 74, 146, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9349, 6029, 74, 147, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9350, 6048, 74, 147, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9395, 6736, 74, 159, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9667, 8299, 355, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9668, 8300, 355, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9669, 8301, 355, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9670, 8302, 355, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9712, 8340, 296, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9714, 8342, 296, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21124, 13449, 1407, 27, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21125, 964, 1407, 28, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21126, 980, 1407, 28, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21127, 985, 1407, 29, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21128, 7629, 1407, 29, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21130, 13581, 1407, 30, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21132, 15177, 1407, 30, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21131, 1019, 1407, 30, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21129, 7284, 1407, 30, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21135, 14533, 1407, 31, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21133, 1060, 1407, 31, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21136, 1087, 1407, 31, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21134, 11375, 1407, 31, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21137, 1100, 1407, 32, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21139, 11368, 1407, 32, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21138, 895, 1407, 32, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21142, 1176, 1407, 33, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21141, 10787, 1407, 33, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21140, 14738, 1407, 33, 101);
INSERT INTO 'dancespublicationsmap' VALUES (9671, 8303, 355, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9672, 8304, 355, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9649, 8281, 354, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9650, 8282, 354, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9652, 8284, 354, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9651, 8283, 354, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9654, 8286, 354, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9653, 8285, 354, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9655, 8287, 354, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9656, 8288, 354, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9657, 8289, 354, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9658, 8290, 354, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9659, 8291, 354, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9660, 8292, 354, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9560, 8202, 345, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9561, 8203, 345, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9562, 8204, 345, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9563, 8205, 345, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9564, 8206, 345, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9565, 8207, 345, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9566, 8208, 345, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9567, 8209, 345, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9742, 8370, 360, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9743, 8371, 360, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9744, 8372, 360, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9745, 8373, 360, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9924, 8554, 372, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9925, 8555, 372, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9694, 3471, 358, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9695, 3123, 358, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9696, 8326, 358, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9697, 3530, 358, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9698, 1785, 358, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9699, 8327, 358, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9869, 8499, 368, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9870, 8500, 368, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9685, 8317, 357, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9686, 8318, 357, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9687, 8319, 357, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9688, 8320, 357, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9689, 8321, 357, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9690, 8322, 357, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9691, 8323, 357, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9692, 8324, 357, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9693, 8325, 357, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9871, 8501, 368, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9872, 8502, 368, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9873, 8503, 368, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9874, 8504, 368, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9875, 8505, 368, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9876, 8506, 368, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9877, 8507, 368, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9878, 8508, 368, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9883, 8513, 369, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9884, 8514, 369, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9885, 8515, 369, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9886, 8516, 369, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9887, 8517, 369, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9888, 8518, 369, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9889, 8519, 369, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9890, 8520, 369, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9891, 8521, 369, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9892, 8522, 369, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9898, 8528, 370, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9899, 8529, 370, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9900, 8530, 370, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4877, 5642, 452, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5466, 6326, 452, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9746, 8376, 361, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9747, 8377, 361, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9748, 8378, 361, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9749, 8380, 361, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9755, 8381, 361, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9750, 8382, 361, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9751, 8383, 361, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9752, 8384, 361, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9753, 8385, 361, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9754, 8386, 361, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9976, 8595, 377, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9977, 8596, 377, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9981, 8600, 377, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9926, 8024, 372, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9927, 8029, 372, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9928, 8556, 372, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9929, 7782, 372, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9930, 8557, 372, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9931, 7814, 372, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9932, 7903, 372, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9933, 7911, 372, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9934, 8558, 372, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9935, 8560, 373, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9980, 8599, 377, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9936, 8561, 373, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9937, 8562, 373, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9938, 8563, 373, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9939, 8564, 373, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9940, 8565, 373, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9941, 8566, 373, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9955, 7099, 373, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9956, 8352, 373, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9860, 8489, 366, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9979, 8598, 377, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9756, 8388, 348, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10025, 5427, 383, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10024, 8137, 383, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9759, 8391, 347, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9760, 8392, 347, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9761, 8393, 347, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9762, 8394, 347, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9763, 8395, 347, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3653, 4199, 451, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2441, 2815, 451, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3564, 4098, 451, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2957, 3400, 451, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4336, 5013, 451, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4904, 5676, 451, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2625, 3026, 451, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4367, 5044, 451, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3385, 3896, 451, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (370, 432, 451, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9524, 8172, 707, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9525, 8173, 707, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9526, 6336, 707, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9527, 8174, 707, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9528, 8175, 707, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9529, 976, 707, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9530, 8176, 707, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9531, 8177, 707, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9757, 8389, 348, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9838, 8467, 298, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9833, 8462, 298, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9835, 8464, 298, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9758, 8390, 348, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9963, 1, 722, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9978, 8597, 377, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9861, 8490, 366, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9862, 8492, 366, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9863, 8493, 366, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9845, 8474, 362, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9849, 8478, 362, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9846, 8475, 362, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9843, 8472, 362, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9841, 8470, 362, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9844, 8473, 362, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9847, 8476, 362, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9848, 8477, 362, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9840, 8469, 362, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9864, 8494, 366, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9857, 8486, 365, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9850, 8479, 365, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9853, 8482, 365, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9851, 8480, 365, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9858, 8487, 365, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9855, 8484, 365, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9852, 8481, 365, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9854, 8483, 365, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9856, 8485, 365, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9865, 8495, 366, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9866, 8496, 366, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9867, 8497, 366, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9868, 8498, 366, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16465, 8730, 1127, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (9982, 8601, 377, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9988, 8607, 378, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9962, 4633, 682, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9795, 8427, 349, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9813, 8428, 349, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9796, 8429, 349, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9797, 8430, 349, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9798, 8431, 349, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9814, 8432, 349, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9799, 8433, 349, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9800, 8434, 349, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9801, 8435, 349, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9802, 8436, 349, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9803, 8437, 349, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9804, 8438, 349, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9805, 8439, 349, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9806, 8440, 349, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9807, 8441, 349, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9808, 8442, 349, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9809, 8443, 349, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9810, 8444, 349, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9811, 8445, 349, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9812, 8446, 349, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21147, 1223, 1407, 34, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21145, 1210, 1407, 34, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21146, 13847, 1407, 34, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21148, 12962, 1407, 35, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21150, 11771, 1407, 35, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21149, 1244, 1407, 35, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21152, 14552, 1407, 36, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21153, 1330, 1407, 36, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21151, 1280, 1407, 36, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21156, 16537, 1407, 37, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21154, 11374, 1407, 37, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21155, 1348, 1407, 37, 101);
INSERT INTO 'dancespublicationsmap' VALUES (10007, 4335, 379, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10008, 7704, 379, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10009, 8631, 379, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10010, 8632, 379, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10011, 8633, 379, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10015, 8634, 379, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10014, 8635, 379, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10013, 8636, 379, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10012, 8637, 379, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9958, 8379, 375, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9959, 8567, 375, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9960, 8572, 375, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9961, 8582, 375, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10031, 5459, 43, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (10019, 5460, 105, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10030, 3577, 74, 81, 103);
INSERT INTO 'dancespublicationsmap' VALUES (10033, 7561, 713, 3, 40);
INSERT INTO 'dancespublicationsmap' VALUES (10034, 7738, 713, 4, 40);
INSERT INTO 'dancespublicationsmap' VALUES (10035, 8722, 713, 5, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13331, 3129, 954, 86, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13334, 3165, 954, 86, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13332, 3154, 954, 86, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13333, 3152, 954, 86, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13336, 3176, 954, 87, 102);
INSERT INTO 'dancespublicationsmap' VALUES (9964, 8583, 376, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9965, 8584, 376, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10114, 4479, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10115, 7842, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10154, 807, 815, 11, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10155, 1046, 815, 13, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10156, 1587, 815, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10157, 1847, 815, 7, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10158, 1899, 815, 19, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10159, 2565, 815, 10, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10160, 3563, 815, 9, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10161, 3702, 815, 18, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10162, 3747, 815, 6, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10163, 4078, 815, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10102, 8795, 397, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10103, 8797, 397, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10104, 8796, 397, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10105, 8798, 397, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10106, 8799, 397, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10107, 8800, 397, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10108, 8801, 397, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10109, 8802, 397, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10110, 8803, 397, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10111, 8804, 397, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10112, 8805, 397, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9901, 8531, 370, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9902, 8532, 370, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9903, 8533, 370, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9904, 8534, 370, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9815, 8447, 364, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9816, 8448, 364, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9817, 8449, 364, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9818, 8450, 364, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9819, 8451, 364, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9820, 8452, 364, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9821, 8453, 364, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9828, 8460, 364, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9822, 8454, 364, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9823, 8455, 364, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10020, 8711, 382, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9957, 7744, 361, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10067, 8769, 393, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10068, 8770, 393, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10069, 8771, 393, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10070, 2209, 393, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10071, 8772, 393, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10072, 7886, 393, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10073, 252, 393, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10074, 2697, 393, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10120, 7243, 404, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10121, 8832, 404, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10122, 8833, 404, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10123, 8834, 404, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10124, 8835, 404, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10125, 8836, 404, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10126, 8837, 404, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10127, 8838, 404, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10128, 8839, 404, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10129, 8840, 404, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21172, 1501, 1407, 43, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21171, 10016, 1407, 43, 101);
INSERT INTO 'dancespublicationsmap' VALUES (9967, 8586, 376, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9966, 8585, 376, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9969, 8588, 376, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9968, 8587, 376, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9971, 8590, 376, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9970, 8589, 376, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9973, 8592, 376, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10099, 8734, 396, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10100, 8794, 396, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10101, 8793, 396, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10075, 4422, 336, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10130, 173, 814, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10131, 497, 814, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10132, 598, 814, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10002, 5433, 438, 8, 40);
INSERT INTO 'dancespublicationsmap' VALUES (10119, 5434, 402, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10118, 157, 284, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10036, 7613, 386, 1, 11);
INSERT INTO 'dancespublicationsmap' VALUES (10037, 8729, 386, 2, 11);
INSERT INTO 'dancespublicationsmap' VALUES (10042, 5079, 344, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10043, 3547, 344, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10044, 5464, 344, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10045, 5108, 344, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10038, 8730, 386, 3, 11);
INSERT INTO 'dancespublicationsmap' VALUES (10040, 5219, 386, 4, 11);
INSERT INTO 'dancespublicationsmap' VALUES (10133, 651, 814, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10134, 670, 814, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10135, 1593, 814, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10136, 2409, 814, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10137, 2842, 814, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10138, 3129, 814, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10139, 3474, 814, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10140, 3567, 814, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10141, 3861, 814, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10142, 4069, 814, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10143, 4102, 814, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10144, 4175, 814, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10145, 5616, 814, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10146, 5741, 814, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10147, 5848, 814, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10148, 5945, 814, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10149, 6897, 814, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10150, 6978, 814, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10151, 7111, 814, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10152, 7189, 814, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10153, 7122, 814, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10208, 497, 405, 1, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10209, 651, 405, 2, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10210, 5616, 405, 3, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10211, 4102, 405, 4, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10212, 3567, 405, 5, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10213, 7189, 405, 6, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10214, 3861, 405, 7, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10215, 5945, 405, 8, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10216, 7111, 405, 9, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10217, 2409, 405, 10, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10218, 3474, 405, 11, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10219, 5741, 405, 12, 33);
INSERT INTO 'dancespublicationsmap' VALUES (9974, 8593, 376, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9972, 8591, 376, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10220, 497, 818, 1, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10221, 651, 818, 2, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10222, 5616, 818, 3, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10223, 4102, 818, 4, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10224, 3567, 818, 5, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10225, 7189, 818, 6, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10026, 1596, 307, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10028, 5885, 307, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9983, 8603, 377, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9986, 8606, 377, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9985, 8605, 377, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9984, 8604, 377, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10095, 3449, 399, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (10096, 2154, 399, 2, 40);
INSERT INTO 'dancespublicationsmap' VALUES (10097, 7259, 399, 3, 40);
INSERT INTO 'dancespublicationsmap' VALUES (10098, 2527, 399, 4, 40);
INSERT INTO 'dancespublicationsmap' VALUES (10191, 807, 817, 12, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10192, 1046, 817, 1, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10193, 1587, 817, 14, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10194, 1847, 817, 8, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10195, 1899, 817, 5, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10196, 2565, 817, 11, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10197, 3563, 817, 10, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10198, 3702, 817, 4, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10199, 3747, 817, 7, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10200, 4078, 817, 16, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10201, 4188, 817, 17, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10202, 5161, 817, 15, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10203, 5245, 817, 3, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10204, 5549, 817, 13, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10175, 807, 816, 14, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10176, 1046, 816, 1, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10177, 1587, 816, 5, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10178, 1847, 816, 8, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10179, 1899, 816, 12, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10180, 2565, 816, 13, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10181, 3563, 816, 16, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10182, 3702, 816, 11, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10183, 3747, 816, 3, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10184, 4078, 816, 7, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10185, 4188, 816, 15, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10186, 5161, 816, 6, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10187, 5549, 816, 4, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10188, 5606, 816, 9, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10189, 6025, 816, 2, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10166, 5245, 815, 21, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10167, 5549, 815, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10168, 5606, 815, 8, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10169, 6025, 815, 5, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10170, 6586, 815, 20, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10171, 7122, 815, 15, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10172, 4278, 815, 12, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10173, 8841, 815, 14, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10174, 2491, 815, 17, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10237, 8851, 407, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10238, 359, 407, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10239, 8842, 407, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10236, 8844, 408, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10325, 1046, 424, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10326, 6025, 424, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10327, 3747, 424, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10328, 5549, 424, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10329, 1587, 424, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10330, 4078, 424, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10331, 1847, 424, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10332, 5606, 424, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10333, 7122, 424, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10334, 3702, 424, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10335, 1899, 424, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10336, 2565, 424, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10337, 807, 424, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10338, 4188, 424, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10339, 8993, 425, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10340, 8994, 425, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10077, 8773, 394, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10078, 8774, 394, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10079, 8775, 394, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10080, 8776, 394, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10081, 8778, 394, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5741, 6649, 457, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5759, 6668, 457, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5866, 6796, 457, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4127, 4754, 456, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4140, 4771, 456, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4142, 4773, 456, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10342, 2744, 314, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10343, 4513, 314, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10344, 1924, 314, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10345, 2595, 314, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10346, 2747, 314, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9942, 3791, 374, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9943, 8568, 374, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9944, 8569, 374, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9945, 8570, 374, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9946, 8571, 374, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9948, 7793, 374, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9947, 8573, 374, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10341, 8995, 425, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10311, 8942, 423, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10312, 8943, 423, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10313, 8944, 423, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10314, 8945, 423, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10315, 8946, 423, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10316, 8947, 423, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10317, 8948, 423, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10318, 8949, 423, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10319, 8950, 423, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10320, 8951, 423, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10291, 7455, 795, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10292, 7440, 795, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10293, 7484, 795, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10294, 7461, 795, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10295, 7496, 795, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10296, 7468, 795, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10297, 7523, 795, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10298, 7382, 795, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10299, 7416, 795, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10300, 7412, 795, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10373, 9022, 429, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10419, 9102, 437, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10420, 9103, 437, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10421, 9104, 437, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10422, 9105, 437, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10423, 9106, 437, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10424, 9107, 437, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10425, 9108, 437, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10228, 7111, 818, 9, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10229, 2409, 818, 10, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10279, 8898, 413, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10280, 8899, 413, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10281, 8900, 413, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10241, 8854, 477, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10240, 8845, 477, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10242, 8843, 477, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10282, 8901, 413, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10283, 8902, 413, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10396, 9082, 434, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10397, 9083, 434, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10398, 1413, 434, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10399, 9084, 434, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10400, 9085, 434, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10284, 8903, 413, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10116, 1930, 707, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10117, 1854, 707, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1828, 2112, 460, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3221, 3707, 460, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21173, 9559, 1407, 43, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21175, 1544, 1407, 44, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21176, 17142, 1407, 44, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21180, 1582, 1407, 45, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21181, 1624, 1407, 45, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21177, 1562, 1407, 45, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21179, 1588, 1407, 45, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21182, 1647, 1407, 46, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21183, 1677, 1407, 46, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21184, 17137, 1407, 46, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21186, 17140, 1407, 47, 101);
INSERT INTO 'dancespublicationsmap' VALUES (10266, 8885, 410, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10267, 8886, 412, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10268, 8887, 412, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10269, 8888, 412, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10270, 8889, 412, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10271, 8890, 412, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10272, 8891, 412, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10273, 8892, 412, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10274, 8893, 412, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10275, 8894, 412, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10276, 8895, 412, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10277, 8896, 412, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10278, 8897, 412, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10439, 9138, 447, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10374, 9023, 429, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10375, 9024, 429, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10376, 9025, 429, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10377, 9026, 429, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10378, 9027, 429, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10379, 9028, 429, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10381, 9049, 430, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10382, 9050, 430, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10383, 9051, 430, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10384, 9052, 430, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10501, 4121, 430, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10502, 9196, 430, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10503, 9197, 430, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10504, 9198, 430, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10505, 9199, 430, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10506, 7694, 430, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10367, 9016, 428, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10368, 9017, 428, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10369, 9018, 428, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10370, 9019, 428, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10371, 9020, 428, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10372, 9021, 428, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10482, 7651, 499, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10483, 1257, 499, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10484, 1258, 499, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10485, 2470, 499, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10486, 3554, 499, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10487, 3933, 499, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10488, 7979, 499, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10489, 6852, 499, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10490, 3740, 499, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10507, 9201, 500, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10508, 9202, 500, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10500, 9191, 500, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10509, 9203, 500, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10704, 9380, 562, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10705, 9381, 562, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10706, 9382, 562, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10707, 2387, 562, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10708, 5100, 562, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10709, 9384, 562, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10710, 9385, 562, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10711, 9169, 562, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10712, 9386, 562, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10713, 9387, 562, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10714, 9388, 562, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10715, 9389, 562, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10716, 9390, 562, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10717, 7849, 562, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (822, 953, 465, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (834, 966, 465, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (836, 968, 465, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10638, 9333, 537, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10510, 9204, 500, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10585, 9278, 528, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10586, 9279, 528, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10587, 9280, 528, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10588, 9281, 528, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10589, 9282, 528, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10590, 9283, 528, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10591, 9284, 528, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10592, 9285, 528, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10626, 9319, 531, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10627, 9320, 531, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10628, 9321, 531, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10629, 9322, 531, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10630, 9323, 531, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10631, 9324, 531, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10632, 9325, 531, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2412, 2781, 51, 11, 18);
INSERT INTO 'dancespublicationsmap' VALUES (10235, 2360, 406, 12, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3067, 3529, 51, 15, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3144, 3616, 51, 19, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3650, 4196, 51, 23, 18);
INSERT INTO 'dancespublicationsmap' VALUES (10633, 9326, 531, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10634, 9327, 531, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10635, 9328, 531, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10636, 9329, 531, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10637, 9330, 531, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10551, 9243, 520, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10552, 9244, 520, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10553, 9245, 520, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10554, 9246, 520, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10468, 9171, 493, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10469, 9172, 493, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10470, 9173, 493, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10471, 9174, 493, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10528, 9222, 519, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10530, 9224, 519, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10529, 9223, 519, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10531, 9225, 519, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10532, 9226, 519, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10533, 9227, 519, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10534, 9228, 519, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10459, 9158, 490, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10512, 9206, 500, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10460, 9159, 490, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10461, 6490, 490, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10402, 9087, 434, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10403, 3485, 434, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10404, 3979, 434, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10462, 9160, 490, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10458, 9157, 490, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10463, 9161, 490, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10466, 9162, 490, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10464, 9163, 490, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10465, 9164, 490, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10511, 9205, 500, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10535, 9229, 519, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10536, 9230, 519, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10537, 9231, 519, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10380, 14713, 775, 209, 16);
INSERT INTO 'dancespublicationsmap' VALUES (16504, 14528, 1131, 72, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10247, 8866, 411, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10248, 8867, 411, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10249, 8868, 411, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10250, 8869, 411, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10251, 8870, 411, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10252, 8871, 411, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10253, 8872, 411, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10254, 18611, 411, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10605, 9298, 530, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10606, 9299, 530, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10607, 9300, 530, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10608, 9301, 530, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10609, 9302, 530, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10610, 9303, 530, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10611, 9304, 530, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10612, 9305, 530, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10613, 9306, 530, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10563, 9256, 525, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10564, 9257, 525, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10565, 9258, 525, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10566, 9259, 525, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10567, 9260, 525, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10568, 9261, 525, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10569, 9262, 525, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10570, 9263, 525, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10571, 9264, 525, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (859, 997, 465, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (870, 1009, 465, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (871, 1010, 465, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (930, 1076, 465, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10429, 8699, 431, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10430, 8672, 431, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10431, 8981, 431, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10432, 8670, 431, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10433, 6479, 431, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10434, 8708, 431, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10435, 3898, 431, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10436, 9112, 431, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10437, 8660, 431, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10438, 8715, 431, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1073, 1243, 465, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1076, 1248, 465, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10555, 9247, 520, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10556, 9248, 520, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10557, 9249, 520, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10558, 9250, 520, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10559, 9251, 520, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10560, 9252, 520, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10561, 9253, 520, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10562, 9254, 520, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10689, 9366, 559, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10690, 9367, 559, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10691, 9368, 559, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10692, 9369, 559, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10693, 9370, 559, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10866, 9586, 638, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10867, 9588, 638, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13346, 3326, 954, 91, 102);
INSERT INTO 'dancespublicationsmap' VALUES (10814, 9542, 617, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10879, 9599, 642, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10880, 9600, 642, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10881, 9601, 642, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10882, 9602, 642, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10883, 9603, 642, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10884, 9604, 642, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10885, 9605, 642, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10886, 9606, 642, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10887, 9607, 642, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10888, 9608, 642, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10868, 9587, 638, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10869, 9589, 638, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10870, 9590, 638, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10871, 9591, 638, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10872, 9592, 638, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10804, 9517, 614, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10805, 9518, 614, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10806, 9519, 614, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10807, 9520, 614, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10808, 9521, 614, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10809, 9522, 614, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10810, 9523, 614, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10811, 9524, 614, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10812, 9525, 614, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10813, 9526, 614, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10729, 9403, 566, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10730, 9404, 566, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10731, 9405, 566, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10745, 9426, 598, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10746, 9427, 598, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10747, 1421, 598, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10748, 6672, 598, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10749, 9428, 598, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10750, 9429, 598, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10751, 9430, 598, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10752, 9431, 598, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10753, 9432, 598, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10754, 9433, 598, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10755, 9434, 598, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10756, 9435, 598, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10865, 9585, 636, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10821, 9545, 624, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10822, 9546, 624, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10823, 9548, 624, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10824, 9425, 624, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10815, 9543, 617, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10757, 9453, 596, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10758, 9454, 596, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11056, 233, 659, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11057, 9168, 659, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11058, 1492, 659, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11059, 3383, 659, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11060, 2034, 659, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11061, 9778, 659, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11062, 3317, 659, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11063, 9779, 659, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11064, 9780, 659, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11065, 9781, 659, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11066, 4841, 659, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11067, 9782, 659, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11068, 9783, 659, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11069, 5777, 659, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11070, 9784, 659, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11071, 6387, 659, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11072, 9785, 659, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11073, 802, 659, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11074, 9786, 659, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10974, 9680, 649, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10975, 9681, 649, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10976, 9682, 649, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10977, 9683, 649, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10978, 9684, 649, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11075, 9788, 660, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10816, 5209, 623, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10817, 1473, 623, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10835, 9559, 623, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10818, 7654, 623, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10737, 9409, 568, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10738, 9410, 568, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10759, 9455, 596, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10760, 9456, 596, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10761, 9457, 596, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10762, 9458, 596, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10763, 9459, 596, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10764, 9460, 596, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10787, 9497, 599, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10788, 9498, 599, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10789, 8831, 599, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10850, 458, 632, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11076, 5990, 660, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11077, 9789, 660, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11078, 9790, 660, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11079, 9791, 660, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11080, 9792, 660, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11081, 9793, 660, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11082, 9794, 660, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10796, 9506, 608, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10797, 9507, 608, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10798, 8741, 608, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10799, 9508, 608, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10800, 9509, 608, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10801, 9510, 608, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10802, 9511, 608, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10803, 9512, 608, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11083, 9795, 660, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10790, 9499, 599, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10791, 9500, 599, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10732, 9406, 567, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10734, 1907, 567, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10733, 9407, 567, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10735, 1075, 567, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10736, 9408, 567, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10792, 9501, 599, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10793, 9502, 599, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10794, 9503, 599, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10979, 9685, 649, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10980, 9686, 649, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10981, 9687, 649, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11028, 9738, 657, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11029, 9739, 657, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11032, 9746, 657, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11030, 9744, 657, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11033, 9747, 657, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11031, 9745, 657, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10851, 9571, 633, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10852, 9572, 633, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10853, 9573, 633, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10855, 9574, 633, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10854, 9575, 633, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10856, 9576, 633, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10864, 9577, 633, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10858, 9578, 633, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10857, 9579, 633, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10859, 9580, 633, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10860, 9581, 633, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10861, 9582, 633, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10944, 9649, 654, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10945, 9560, 654, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10946, 9650, 654, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10947, 9651, 654, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10948, 9652, 654, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10949, 9540, 654, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10950, 9653, 654, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10951, 9654, 654, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10952, 9655, 654, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10953, 9656, 654, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10954, 9657, 654, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10955, 9658, 654, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10956, 9659, 654, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10957, 9660, 654, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11043, 9759, 658, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11044, 9760, 658, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11045, 9761, 658, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11046, 9762, 658, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11047, 9764, 658, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11048, 9061, 658, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11049, 9765, 658, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11050, 9766, 658, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11179, 7648, 613, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11218, 10057, 692, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11219, 10058, 692, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11220, 10059, 692, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11221, 10060, 692, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11222, 10061, 692, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11223, 10062, 692, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11224, 10063, 692, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11225, 10064, 692, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11091, 9803, 661, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11105, 9547, 661, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11106, 9820, 661, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11107, 9821, 661, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11108, 9822, 661, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11109, 9823, 661, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11110, 9824, 661, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11111, 9825, 661, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11112, 9826, 661, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11113, 9827, 661, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11114, 9828, 661, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11226, 10065, 692, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11227, 10066, 692, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11228, 10067, 692, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11201, 10026, 676, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11202, 10027, 676, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11203, 10028, 676, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11204, 10029, 676, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11205, 10030, 676, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11206, 10031, 676, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11207, 10032, 676, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11208, 10033, 676, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11209, 10034, 676, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11210, 10035, 676, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11211, 10036, 676, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11212, 10037, 676, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11213, 10038, 676, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11214, 10039, 676, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11215, 10040, 676, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11216, 10041, 676, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11217, 10042, 676, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11130, 8956, 666, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11131, 9926, 666, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11132, 9927, 666, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11116, 9912, 665, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11117, 9913, 665, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11118, 9914, 665, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11119, 9915, 665, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11120, 6681, 665, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11121, 9916, 665, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11122, 9917, 665, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11123, 9918, 665, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11124, 9919, 665, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11027, 1708, 394, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11156, 9951, 382, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11157, 9952, 382, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11158, 9953, 382, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11159, 9954, 382, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11160, 5233, 382, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11161, 8491, 382, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11162, 9955, 382, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11163, 9956, 382, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11164, 9957, 382, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11165, 9958, 382, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11166, 9959, 382, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11180, 3571, 309, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11181, 9974, 309, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11182, 9989, 309, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11183, 9990, 309, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11184, 9991, 309, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11185, 8703, 309, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11186, 9992, 309, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11187, 9993, 309, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11188, 9585, 309, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11189, 9994, 309, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11133, 9928, 666, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11134, 9929, 666, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11135, 9930, 666, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11136, 9931, 666, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11137, 9932, 666, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11138, 8931, 666, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11139, 9934, 666, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11140, 9935, 666, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11141, 9936, 666, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11337, 9882, 649, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11338, 9891, 649, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11095, 2717, 662, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11096, 9814, 662, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11097, 9815, 662, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11417, 10236, 644, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11418, 10238, 644, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (677, 793, 465, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (692, 809, 465, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11323, 10172, 762, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11324, 10173, 762, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11325, 10174, 762, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11326, 10175, 762, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11327, 10176, 762, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11328, 10177, 762, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11329, 10178, 762, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11330, 10179, 762, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11331, 10180, 762, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11332, 10181, 762, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11333, 10182, 762, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11334, 10183, 762, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11335, 10184, 762, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11336, 10185, 762, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11303, 10089, 684, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11304, 10012, 684, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11305, 10155, 684, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11306, 10156, 684, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11307, 10157, 684, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11308, 10158, 684, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11309, 10159, 684, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11310, 10160, 684, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11311, 9980, 684, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11615, 8923, 538, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11468, 7287, 785, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11469, 7295, 785, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11466, 10309, 784, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11467, 10308, 784, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11543, 10402, 784, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11544, 10403, 784, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11545, 387, 784, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11481, 7276, 792, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11480, 7277, 792, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11483, 7275, 792, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11484, 8639, 792, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11482, 7281, 792, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11478, 7288, 792, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11479, 7280, 792, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11115, 9911, 564, 30, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11034, 9748, 657, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11035, 9749, 657, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11036, 9750, 657, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11037, 9751, 657, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11038, 9752, 657, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11039, 9753, 657, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11040, 9754, 657, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11041, 9755, 657, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11042, 9756, 657, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11374, 8728, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11375, 8998, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11376, 5093, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11377, 2423, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11378, 4388, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11379, 8094, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11380, 8739, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11381, 8097, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11382, 8812, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11383, 8996, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11546, 9883, 784, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11547, 10404, 784, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11548, 10405, 784, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11549, 10406, 784, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (748, 872, 465, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11614, 4140, 430, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11542, 1912, 476, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11523, 10370, 794, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11524, 10369, 794, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11525, 10371, 794, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11526, 9544, 794, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11527, 10372, 794, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11528, 10373, 794, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11616, 8925, 538, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11617, 8178, 538, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11618, 8193, 538, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11619, 10515, 538, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11620, 8929, 538, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11621, 10516, 538, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11529, 10374, 794, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11530, 10375, 794, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11531, 10376, 794, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11532, 10377, 794, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11533, 10378, 794, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11534, 10379, 794, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11535, 10381, 794, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11536, 10380, 794, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11537, 10382, 794, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11538, 10383, 794, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11591, 10464, 537, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11592, 10465, 537, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11593, 9844, 537, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11594, 10188, 537, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11595, 10466, 537, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (749, 874, 465, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (757, 882, 465, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (821, 952, 465, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11470, 7327, 785, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11471, 7329, 785, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11472, 7320, 785, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11473, 7291, 785, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11474, 7310, 785, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11475, 7298, 785, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11476, 7303, 785, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11477, 7299, 785, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11570, 10427, 819, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11571, 1911, 819, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11572, 10429, 819, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11664, 10596, 827, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11668, 10611, 828, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11590, 10007, 821, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11643, 8679, 824, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11644, 8691, 824, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11645, 8689, 824, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11669, 10612, 828, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11659, 10604, 826, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11660, 10605, 826, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11661, 10606, 826, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11662, 10607, 826, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11663, 3075, 826, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11339, 10196, 767, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11340, 10197, 767, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11341, 10198, 767, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11342, 10199, 767, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11343, 10200, 767, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11344, 10201, 767, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11299, 8809, 759, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11300, 10151, 759, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11301, 10153, 759, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11454, 10276, 782, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11455, 10275, 782, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11456, 10273, 782, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11457, 10279, 782, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11458, 10277, 782, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11459, 10280, 782, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11460, 10278, 782, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11461, 10281, 782, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11462, 10282, 782, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11463, 10274, 782, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11465, 7173, 39, 99, 18);
INSERT INTO 'dancespublicationsmap' VALUES (11654, 10299, 252, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11596, 10475, 820, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11598, 693, 820, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11597, 10476, 820, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11599, 10477, 820, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11345, 10202, 767, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11346, 10203, 767, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11347, 10204, 767, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11348, 10205, 767, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11349, 10206, 767, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11350, 10207, 767, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11351, 10208, 767, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11352, 10209, 767, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11353, 10210, 767, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11354, 10211, 767, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11355, 10212, 767, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11356, 10213, 767, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11357, 10214, 767, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11358, 10215, 767, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11419, 10237, 644, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11420, 10239, 644, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11421, 10240, 644, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11422, 10241, 644, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11423, 10242, 644, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11424, 10243, 644, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11425, 10244, 644, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11426, 10245, 644, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11427, 10246, 644, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11428, 10248, 644, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11429, 10249, 644, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11430, 10250, 644, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11431, 10251, 644, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11432, 10252, 644, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11433, 10253, 644, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11434, 10254, 644, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11781, 10719, 834, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11782, 10720, 834, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11783, 10721, 834, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11784, 10722, 834, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11785, 10723, 834, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11786, 10724, 834, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11787, 10725, 834, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11788, 10726, 834, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11789, 10727, 834, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11790, 10728, 834, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19, 24, 465, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (28, 35, 465, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11696, 10640, 831, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11697, 10642, 831, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11698, 10643, 831, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11699, 10644, 831, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11700, 10645, 831, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11701, 10646, 831, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11702, 10648, 831, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11703, 9194, 831, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11704, 9193, 831, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11705, 9192, 831, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11791, 10729, 835, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11792, 10730, 835, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11793, 10731, 835, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11794, 10732, 835, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11795, 10733, 835, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11796, 10734, 835, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11797, 10735, 835, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11798, 10736, 835, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11799, 10737, 835, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11800, 10738, 835, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11681, 10625, 830, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11682, 10626, 830, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11683, 10627, 830, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11684, 10628, 830, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11685, 10629, 830, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11686, 10630, 830, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11687, 10631, 830, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11688, 10632, 830, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11689, 10633, 830, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11690, 10634, 830, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11691, 10635, 830, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11692, 10636, 830, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11693, 10637, 830, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11694, 10638, 830, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11695, 10639, 830, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (41, 49, 465, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (53, 63, 465, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (60, 71, 465, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (98, 111, 465, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11843, 10783, 784, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11961, 9847, 447, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11962, 9853, 447, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11963, 9856, 447, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11964, 9858, 447, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11844, 10653, 839, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (11845, 159, 839, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (11846, 10787, 839, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (11847, 10788, 839, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (11848, 10789, 839, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (11849, 10790, 839, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (11850, 10791, 839, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (11851, 10792, 839, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (11852, 10793, 839, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12003, 7864, 854, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12004, 10969, 854, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12005, 10970, 854, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12006, 10971, 854, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12007, 10972, 854, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12008, 10973, 854, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12009, 9047, 854, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12010, 4964, 854, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12011, 10974, 854, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (216, 254, 465, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11855, 10795, 840, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11854, 10796, 840, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11856, 7530, 840, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11857, 3996, 840, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11858, 10797, 840, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11953, 10782, 850, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11954, 10912, 850, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11955, 10913, 850, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11956, 10914, 850, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11957, 10915, 850, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11958, 10916, 850, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11959, 1247, 850, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11960, 10917, 850, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11965, 10918, 851, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11966, 10919, 851, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11967, 10920, 851, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11968, 10921, 851, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (276, 322, 465, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (297, 345, 465, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11899, 10868, 616, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11900, 10869, 616, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11901, 10870, 616, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11653, 10553, 646, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11802, 10462, 836, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11801, 10739, 836, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11803, 10740, 836, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11804, 10741, 836, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11805, 10742, 836, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11672, 10615, 829, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11673, 10616, 829, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11674, 10617, 829, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11675, 10618, 829, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11676, 10619, 829, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11677, 10620, 829, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11678, 10621, 829, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11679, 10622, 829, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11680, 10623, 829, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11833, 10769, 821, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11834, 10770, 821, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11835, 10463, 821, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11836, 10771, 821, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11837, 10772, 821, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11839, 10773, 821, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11840, 10774, 821, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11993, 7557, 853, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11994, 2050, 853, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11995, 7558, 853, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11996, 10962, 853, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11997, 10963, 853, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11998, 10456, 853, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11999, 10964, 853, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11841, 10775, 821, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11838, 10578, 821, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11646, 5745, 824, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11649, 10550, 824, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11650, 10551, 824, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11647, 8669, 824, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11648, 8674, 824, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11651, 9850, 824, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11652, 10552, 824, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11810, 10747, 837, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11811, 10748, 837, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11812, 10749, 837, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11813, 10750, 837, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11814, 10751, 837, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11815, 10752, 837, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11816, 10753, 837, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11859, 10459, 840, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11860, 548, 840, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11670, 10613, 828, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11671, 10614, 828, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11656, 3640, 825, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11657, 586, 825, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11658, 4600, 825, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11655, 10603, 825, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11902, 10871, 616, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11903, 10872, 616, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11904, 10873, 616, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11905, 10874, 616, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11906, 10875, 616, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11907, 10876, 616, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11831, 10766, 838, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11832, 10767, 838, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11927, 10888, 845, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (323, 376, 465, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (326, 379, 465, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (359, 418, 465, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11928, 10786, 845, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11925, 10885, 845, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12096, 11056, 862, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12097, 11057, 862, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12098, 11058, 862, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12099, 11059, 862, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12100, 11060, 862, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12101, 11061, 862, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12102, 11062, 862, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12103, 11063, 862, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12104, 11064, 862, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12105, 11065, 862, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12106, 11066, 862, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12107, 11067, 862, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (376, 438, 465, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11929, 10889, 845, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12108, 11068, 862, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12109, 11069, 862, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12123, 10536, 864, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12124, 11083, 864, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12125, 10568, 864, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12126, 10527, 864, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12127, 11084, 864, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12128, 11085, 864, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12129, 11086, 864, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12130, 11087, 864, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12131, 11088, 864, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12132, 11089, 864, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12064, 11029, 849, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12065, 10768, 849, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12066, 11030, 849, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12067, 11031, 849, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12068, 11032, 849, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12069, 11033, 849, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12070, 11034, 849, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12071, 11035, 849, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12072, 11036, 849, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12073, 11037, 849, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12074, 10457, 849, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12075, 11038, 849, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12076, 11039, 849, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12090, 11052, 860, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12091, 11053, 860, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12092, 11054, 860, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12093, 8030, 860, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12094, 11055, 860, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12095, 3799, 860, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12016, 10979, 856, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12017, 10980, 856, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12018, 10982, 856, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12019, 10983, 856, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12020, 10984, 856, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12021, 10985, 856, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12022, 10986, 856, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12023, 10987, 856, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12024, 10988, 856, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12025, 10989, 856, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12026, 10981, 856, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12049, 11012, 856, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12176, 11123, 888, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12177, 11124, 888, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12178, 11125, 888, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12179, 11126, 888, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12180, 11127, 888, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12181, 11128, 888, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12182, 11129, 888, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12183, 11130, 888, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12200, 11147, 889, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12168, 11115, 886, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12169, 11116, 886, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12170, 11117, 886, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11946, 10904, 846, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11945, 10903, 846, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11947, 10905, 846, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11948, 10906, 846, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11949, 10907, 847, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11950, 10908, 847, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11951, 10909, 847, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11952, 10910, 847, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (388, 450, 465, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (412, 479, 465, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (422, 492, 465, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (477, 558, 465, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (535, 623, 465, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (581, 675, 465, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12245, 11205, 895, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12246, 11206, 895, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12247, 11207, 895, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12248, 11208, 895, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12249, 11209, 895, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12250, 11210, 895, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12251, 11211, 895, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12275, 11223, 897, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12276, 11224, 897, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12277, 11225, 897, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12278, 11226, 897, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12279, 9865, 897, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12280, 11227, 897, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12281, 9884, 897, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12282, 11228, 897, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12156, 11108, 884, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12157, 11109, 884, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12158, 8103, 884, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12159, 2016, 884, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12160, 1113, 884, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12031, 10994, 858, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12032, 10995, 858, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12033, 10996, 858, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12034, 10997, 858, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12035, 10998, 858, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12036, 10999, 858, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12161, 11110, 884, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12162, 9043, 884, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21238, 2350, 1407, 66, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21245, 13585, 1407, 67, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21244, 2394, 1407, 67, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21242, 695, 1407, 67, 101);
INSERT INTO 'dancespublicationsmap' VALUES (11930, 10890, 845, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11926, 10886, 845, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11931, 10892, 845, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12110, 11070, 863, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12112, 11071, 863, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12111, 11072, 863, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12113, 11073, 863, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12114, 11074, 863, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12115, 11075, 863, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12116, 11076, 863, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12117, 11077, 863, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12118, 11078, 863, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12119, 11079, 863, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12284, 11231, 898, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12285, 11232, 898, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12286, 11233, 898, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12287, 11234, 898, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12288, 11235, 898, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12289, 11236, 898, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12290, 11237, 898, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12291, 11238, 898, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12292, 11239, 898, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12293, 11240, 898, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12027, 10990, 857, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12028, 10991, 857, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12029, 10992, 857, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12030, 10993, 857, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12283, 11229, 897, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12319, 5161, 424, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12320, 11269, 900, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12212, 11171, 892, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12213, 11172, 892, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12214, 11173, 892, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12215, 11174, 892, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12216, 11175, 892, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12217, 11176, 892, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12218, 10232, 892, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12219, 11177, 892, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12220, 11178, 892, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12221, 11179, 892, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12222, 11180, 892, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12223, 11181, 892, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12224, 11182, 892, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12225, 11183, 892, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12256, 9862, 861, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12257, 10115, 861, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12258, 10116, 861, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12259, 11164, 861, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12260, 11170, 861, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12261, 11216, 861, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12262, 11217, 861, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12263, 10554, 861, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12264, 10557, 861, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12265, 11218, 861, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12266, 11219, 861, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12267, 11220, 861, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12268, 11221, 861, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12201, 11148, 889, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12202, 11149, 889, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12203, 11150, 889, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12204, 11151, 889, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12205, 11152, 889, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12538, 11557, 921, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12539, 11558, 921, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12540, 11559, 921, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12541, 11560, 921, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12542, 11561, 921, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12543, 11562, 921, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12544, 11563, 921, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12545, 11565, 921, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12546, 11566, 921, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12550, 11571, 920, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12552, 8375, 920, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12553, 10507, 920, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12554, 11572, 920, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12555, 11573, 920, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12556, 11574, 920, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12557, 11575, 920, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12558, 11576, 920, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12559, 11577, 920, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12560, 11578, 920, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12561, 11579, 920, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12480, 11410, 914, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12527, 3020, 914, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12528, 9787, 914, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12529, 11539, 914, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12530, 11540, 914, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12531, 9728, 914, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12532, 11541, 914, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12533, 11542, 914, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12534, 11543, 914, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12535, 11544, 914, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12536, 3395, 914, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12481, 11411, 915, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12482, 11412, 915, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12483, 11413, 915, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12484, 8641, 915, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12485, 11414, 915, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12486, 8643, 915, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12487, 7309, 915, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12488, 11415, 915, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12489, 8647, 915, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12490, 11416, 915, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12491, 11417, 915, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12568, 7608, 635, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12492, 11418, 916, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12493, 11419, 916, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12494, 11420, 916, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12495, 11421, 916, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12642, 11673, 929, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12675, 11726, 538, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12676, 11727, 538, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12677, 10519, 538, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12678, 4954, 538, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12679, 4677, 538, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12526, 5487, 710, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12569, 916, 923, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (12570, 1485, 923, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (12680, 11735, 932, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12681, 10348, 932, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12682, 10350, 932, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12683, 10343, 932, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12684, 10090, 932, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12685, 11736, 932, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12686, 11737, 932, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12687, 11738, 932, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12688, 7856, 932, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12633, 7650, 238, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12718, 11769, 935, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12443, 11367, 911, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12444, 11368, 911, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12445, 11369, 911, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12446, 11370, 911, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12447, 11371, 911, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12448, 11372, 911, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12449, 11373, 911, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12450, 11374, 911, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12453, 11377, 912, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12454, 11378, 912, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12455, 11379, 912, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12456, 11380, 912, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12457, 11381, 912, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12458, 11382, 912, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12459, 11383, 912, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12418, 11341, 909, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12419, 11342, 909, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12420, 11343, 909, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12421, 11344, 909, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12422, 11345, 909, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12423, 11346, 909, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12424, 11347, 909, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12425, 11348, 909, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12460, 11384, 912, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12429, 11351, 910, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12430, 11352, 910, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12432, 11354, 910, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12431, 11353, 910, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12433, 11355, 910, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12434, 11356, 910, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12435, 11357, 910, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12436, 11358, 910, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12437, 11359, 910, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12438, 11360, 910, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12439, 11361, 910, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12575, 11602, 924, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12576, 11603, 924, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12577, 11604, 924, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12578, 11605, 924, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12579, 11606, 924, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12580, 11607, 924, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12581, 11608, 924, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12582, 11609, 924, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12583, 11610, 924, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12601, 11631, 925, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12672, 9839, 663, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12643, 11672, 929, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12644, 11671, 929, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12645, 11670, 929, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12646, 11674, 929, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12647, 11675, 929, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12648, 11676, 929, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12649, 11677, 929, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12689, 7856, 933, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12690, 3587, 933, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12691, 7760, 933, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12692, 9987, 933, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12693, 10187, 933, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12694, 10090, 933, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12695, 11739, 933, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12696, 11740, 933, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12697, 11741, 933, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12698, 11742, 933, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12699, 11743, 933, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12503, 11427, 919, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12385, 11308, 41, 102, 18);
INSERT INTO 'dancespublicationsmap' VALUES (12504, 9067, 919, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12505, 11428, 919, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12506, 11429, 919, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12507, 11430, 919, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12508, 11431, 919, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12600, 1560, 604, 4, 35);
INSERT INTO 'dancespublicationsmap' VALUES (12409, 11331, 683, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12551, 10507, 361, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12700, 11744, 933, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12701, 11745, 933, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12702, 7290, 933, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12650, 11682, 928, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12651, 11683, 928, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12652, 11685, 928, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12653, 11686, 928, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12654, 11687, 928, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12655, 11688, 928, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12656, 11689, 928, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12657, 11690, 928, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12658, 11691, 928, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12659, 11692, 928, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12660, 11693, 928, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12661, 11694, 928, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12662, 11695, 928, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12663, 11696, 928, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12664, 11697, 928, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12665, 11698, 928, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12666, 11699, 928, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12667, 11700, 928, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12668, 11701, 928, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12634, 10235, 927, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12635, 11662, 927, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12636, 11663, 927, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12637, 11664, 927, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12638, 11665, 927, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12639, 11666, 927, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12640, 11667, 927, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12641, 11668, 927, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4617, 5334, 469, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4618, 5335, 469, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4691, 5420, 469, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4865, 5627, 469, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4867, 5629, 469, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12875, 11930, 944, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12876, 11931, 944, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12877, 11932, 944, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12878, 11300, 944, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12879, 11933, 944, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12880, 11934, 944, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12881, 11301, 944, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12760, 11816, 680, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12761, 11817, 680, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12762, 11818, 680, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12763, 11819, 680, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12764, 11820, 680, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12765, 11821, 680, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12766, 11822, 680, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12767, 11823, 680, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12768, 11824, 680, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12769, 11825, 680, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12882, 11935, 944, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12883, 11936, 944, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12901, 11946, 945, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12902, 11947, 945, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12903, 11948, 945, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12904, 11949, 945, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12905, 11950, 945, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12906, 11951, 945, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12907, 11952, 945, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12908, 11953, 945, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12909, 11954, 945, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12910, 11955, 945, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12770, 10526, 937, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12771, 11762, 937, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12773, 3486, 937, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12774, 11529, 937, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12775, 11765, 937, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12776, 11767, 937, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12777, 2459, 937, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12830, 11878, 940, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12831, 11879, 940, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12832, 11880, 940, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12833, 11881, 940, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12834, 11882, 940, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12835, 11883, 940, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12836, 11884, 940, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12837, 11885, 940, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12838, 11886, 940, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12839, 11887, 940, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12840, 11888, 940, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12841, 11889, 940, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4911, 5684, 469, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4959, 5739, 469, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12725, 11775, 936, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12571, 5558, 923, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (12867, 11678, 942, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12868, 11922, 942, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12869, 11923, 942, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12870, 11924, 942, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12871, 11925, 942, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12872, 11926, 942, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12873, 11927, 942, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12970, 12052, 949, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12971, 12053, 949, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12972, 12054, 949, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12973, 12055, 949, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12974, 12057, 949, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12975, 12056, 949, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12976, 12058, 949, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12977, 12059, 949, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12978, 9742, 949, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12979, 9741, 949, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12980, 12060, 949, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12842, 11704, 646, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12704, 9774, 934, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12884, 8839, 943, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12810, 9899, 938, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12811, 11866, 938, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12812, 11867, 938, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12813, 11868, 938, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12885, 8834, 943, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12886, 8835, 943, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12874, 11919, 943, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12814, 11869, 938, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12815, 11870, 938, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12843, 11267, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12816, 11871, 938, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12817, 11872, 938, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12818, 10189, 938, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12819, 5853, 938, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12572, 540, 923, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (12573, 2746, 923, 5, 31);
INSERT INTO 'dancespublicationsmap' VALUES (12574, 3431, 923, 6, 31);
INSERT INTO 'dancespublicationsmap' VALUES (12927, 9867, 917, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12926, 9838, 917, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12934, 11997, 917, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12935, 11998, 917, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12936, 11999, 917, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12931, 11994, 917, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12940, 10501, 917, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12937, 12000, 917, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12938, 12001, 917, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12929, 11992, 917, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12930, 11993, 917, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12928, 11991, 917, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12932, 11995, 917, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12933, 11996, 917, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12939, 12002, 917, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12962, 12044, 947, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12963, 12046, 947, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12964, 12045, 947, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12965, 12047, 947, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12966, 12048, 947, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12967, 12049, 947, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12968, 12050, 947, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12969, 12051, 947, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12946, 11299, 946, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12947, 12016, 946, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12948, 12017, 946, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12949, 12015, 946, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13007, 12095, 952, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13008, 12096, 952, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13009, 12097, 952, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13010, 12098, 952, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13011, 12099, 952, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13012, 12100, 952, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13013, 12101, 952, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13014, 12102, 952, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12997, 3057, 337, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12996, 12079, 950, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12674, 11402, 931, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13015, 12103, 952, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12998, 3552, 951, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12999, 12087, 951, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13000, 12088, 951, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13001, 12089, 951, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13002, 12090, 951, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13003, 12091, 951, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13004, 12092, 951, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13005, 12093, 951, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13006, 12094, 951, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13055, 12124, 953, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13891, 12148, 299, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13892, 12157, 299, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13893, 12183, 299, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13894, 12226, 299, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13895, 12230, 299, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13890, 12254, 299, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13928, 12312, 299, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12945, 7125, 939, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13828, 12163, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13829, 12125, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13830, 12126, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13831, 12127, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13832, 12151, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13833, 12158, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13969, 12400, 966, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13970, 12401, 966, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13971, 12403, 966, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13972, 12404, 966, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4231, 4886, 469, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4288, 4955, 469, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4292, 4961, 469, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13837, 12176, 957, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13838, 12129, 957, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13841, 12184, 957, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13850, 12208, 957, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13973, 12405, 966, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13974, 12402, 966, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4312, 4986, 469, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4333, 5010, 469, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13999, 1814, 968, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14000, 2203, 968, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14001, 3201, 968, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14002, 3403, 968, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14003, 3566, 968, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14004, 4741, 968, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14005, 4774, 968, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14006, 5438, 968, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13932, 2928, 965, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13933, 4839, 965, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13934, 10394, 965, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13842, 12175, 896, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13843, 12130, 896, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13844, 12141, 896, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13845, 12156, 896, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13911, 12268, 896, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13964, 12359, 896, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13965, 12360, 896, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13966, 12361, 896, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13867, 8781, 962, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13868, 1708, 962, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13869, 7572, 962, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13870, 3994, 962, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13871, 358, 962, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13872, 859, 962, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13873, 1124, 962, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13874, 4120, 962, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13875, 5170, 962, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13851, 12211, 959, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13912, 12269, 959, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13925, 12300, 959, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13955, 12350, 959, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13956, 12351, 959, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13975, 12420, 967, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13976, 12135, 967, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13977, 12144, 967, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13978, 12162, 967, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13979, 12192, 967, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13980, 12194, 967, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13981, 12215, 967, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13982, 12256, 967, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13983, 12276, 967, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13984, 12292, 967, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4334, 5011, 469, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4476, 5169, 469, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21283, 2717, 1407, 78, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21284, 2725, 1407, 78, 101);
INSERT INTO 'dancespublicationsmap' VALUES (14015, 9527, 970, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13914, 12280, 791, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12942, 12005, 930, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12943, 12006, 930, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12944, 12007, 930, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21282, 8482, 1407, 78, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21276, 2745, 1407, 79, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21277, 2747, 1407, 79, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21278, 2778, 1407, 79, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21275, 10790, 1407, 79, 101);
INSERT INTO 'dancespublicationsmap' VALUES (13950, 12345, 299, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13951, 12346, 299, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13952, 12347, 299, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13953, 12348, 299, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13954, 12349, 299, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4481, 5177, 469, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12983, 11760, 644, 57, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4526, 5227, 469, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4612, 5329, 469, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5338, 6174, 470, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5422, 6274, 470, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5423, 6275, 470, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5564, 6435, 470, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5615, 6495, 470, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5719, 6622, 470, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5734, 6639, 470, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5748, 6656, 470, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5823, 6749, 470, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5940, 6881, 470, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6001, 6958, 470, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6043, 7005, 470, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6122, 7097, 470, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6180, 7167, 470, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6268, 7266, 470, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14038, 8101, 575, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14183, 12487, 981, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14184, 12495, 981, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14069, 7061, 841, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14070, 11512, 841, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14071, 10663, 841, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14072, 10381, 841, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14073, 1087, 841, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14074, 5885, 841, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14075, 12454, 841, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14076, 10535, 841, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14077, 2039, 841, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14185, 12120, 981, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14186, 12496, 981, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14187, 12497, 981, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14022, 12210, 971, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14023, 10823, 971, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14024, 10822, 971, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14025, 10821, 972, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14026, 12302, 972, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14027, 11892, 972, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14028, 11896, 973, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14029, 11895, 973, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14030, 11897, 973, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14031, 11894, 974, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14032, 10051, 974, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14033, 12291, 974, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14037, 11899, 975, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14034, 11898, 976, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14035, 11891, 976, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14036, 11893, 976, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14055, 10101, 953, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14056, 11977, 953, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14057, 10564, 953, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14058, 12445, 953, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14059, 12446, 953, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14060, 12447, 953, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14061, 12448, 953, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14062, 8727, 953, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14063, 11756, 953, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14064, 12449, 953, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14065, 12450, 953, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14066, 12451, 953, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14067, 12452, 953, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14068, 12453, 953, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14079, 12455, 978, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14080, 12456, 978, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14081, 12457, 978, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14082, 12458, 978, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14083, 12459, 978, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14084, 12460, 978, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13834, 12153, 956, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14085, 12461, 978, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14086, 12462, 978, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14087, 12463, 978, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14088, 12464, 978, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14309, 12629, 989, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14310, 12147, 989, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14311, 12152, 989, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14312, 12154, 989, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14313, 10461, 989, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14314, 12218, 989, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14315, 12260, 989, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14316, 12327, 989, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14317, 12370, 989, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14318, 12371, 989, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14319, 12373, 989, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14257, 12577, 986, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14258, 12578, 986, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14259, 12579, 986, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14260, 12580, 986, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14261, 12581, 986, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14262, 12583, 986, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14263, 12584, 986, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14264, 12585, 986, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14265, 12586, 986, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14266, 12587, 986, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14228, 10304, 897, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14384, 7318, 768, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14385, 7322, 768, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14224, 12523, 984, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14225, 12524, 984, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14226, 12529, 984, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14227, 12535, 984, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14229, 12546, 694, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14230, 12547, 694, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14231, 12548, 694, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14232, 12549, 694, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14233, 12550, 694, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14234, 12551, 694, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14235, 12552, 694, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14236, 12553, 694, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14237, 12554, 694, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3486, 4016, 471, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3573, 4108, 471, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13917, 11805, 958, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13942, 11978, 958, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13946, 11983, 958, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13943, 11980, 958, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21280, 2807, 1407, 80, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21279, 2781, 1407, 80, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21281, 2813, 1407, 80, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21285, 2822, 1407, 81, 101);
INSERT INTO 'dancespublicationsmap' VALUES (14016, 9529, 970, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14017, 9528, 970, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14018, 9531, 970, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14019, 9530, 970, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14020, 9532, 970, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14021, 9533, 970, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14199, 6055, 866, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14321, 12219, 990, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14322, 12630, 990, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14323, 11600, 990, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14324, 12631, 990, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14325, 12632, 990, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14326, 12633, 990, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14327, 12634, 990, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14328, 11908, 990, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14329, 12635, 990, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14377, 7297, 380, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14378, 7300, 380, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14379, 7301, 380, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14380, 7304, 380, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14382, 7311, 380, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14381, 7312, 380, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14383, 7313, 380, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13916, 12105, 958, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13945, 12342, 958, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14200, 12242, 983, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14201, 68, 983, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14202, 12243, 983, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14203, 10786, 983, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14204, 11778, 983, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14205, 11779, 983, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14206, 12514, 983, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14207, 1796, 983, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14208, 9980, 983, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14209, 10160, 983, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13944, 12341, 958, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13839, 12178, 958, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13918, 12221, 958, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13919, 12224, 958, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13915, 12285, 958, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13924, 12296, 958, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14099, 11757, 644, 58, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14100, 12493, 644, 59, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14101, 11759, 644, 60, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14102, 11761, 644, 61, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14103, 11444, 644, 62, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14104, 12482, 644, 63, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14105, 12142, 644, 64, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14106, 11472, 644, 65, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14107, 11450, 644, 66, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14108, 12479, 644, 67, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14109, 11491, 644, 68, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14110, 11453, 644, 69, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13941, 12335, 958, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13947, 12343, 958, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3362, 3873, 471, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3577, 4113, 471, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3949, 4547, 471, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14413, 79, 67, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14488, 12411, 994, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14489, 11629, 994, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14490, 12833, 994, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14491, 12834, 994, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14492, 12835, 994, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14493, 12836, 994, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14494, 12837, 994, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14495, 10053, 994, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14496, 11990, 994, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14497, 9802, 994, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3970, 4569, 471, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4100, 4724, 471, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4129, 4756, 471, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4141, 4772, 471, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4361, 5038, 471, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4551, 5258, 471, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5089, 5887, 471, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5616, 6497, 471, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5405, 6255, 472, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14039, 12430, 977, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14040, 12431, 977, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14041, 12432, 977, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14043, 12433, 977, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14042, 12434, 977, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14044, 12435, 977, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14045, 12436, 977, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5523, 6390, 472, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5614, 6494, 472, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5655, 6548, 472, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14477, 9562, 774, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14478, 10356, 774, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14479, 1697, 774, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14480, 10014, 774, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14481, 9811, 774, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14482, 12827, 774, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14483, 12828, 774, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14484, 12829, 774, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14485, 12830, 774, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14486, 12831, 774, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14487, 12832, 774, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14414, 12736, 769, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14415, 12737, 769, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14416, 12738, 769, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14417, 12739, 769, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14418, 12740, 769, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14419, 12675, 769, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14420, 12741, 769, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14421, 12742, 769, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14422, 12743, 769, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14423, 12744, 769, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14424, 12745, 769, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14425, 12746, 769, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14498, 12838, 994, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14499, 9165, 994, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14500, 12839, 994, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14501, 12840, 994, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14386, 7326, 768, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14387, 7328, 768, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14388, 8640, 768, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14389, 8642, 768, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14390, 8644, 768, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14391, 12697, 768, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14392, 12698, 768, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14393, 12699, 768, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14394, 12700, 768, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14395, 12701, 768, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14396, 12702, 768, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14397, 12703, 768, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14398, 12704, 768, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14399, 12705, 768, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14505, 12842, 995, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14506, 12844, 995, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14507, 12843, 995, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14674, 13056, 1007, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14675, 13057, 1007, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14676, 13058, 1007, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14677, 13059, 1007, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14678, 13060, 1007, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14679, 13061, 1007, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14680, 13063, 1007, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14681, 13065, 1007, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14682, 13064, 1007, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14683, 13062, 1007, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14748, 13128, 1013, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14749, 12867, 1013, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14750, 1533, 1013, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14751, 12696, 1013, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14752, 13129, 1013, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14753, 13130, 1013, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14754, 11814, 1013, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14755, 13131, 1013, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14664, 13046, 1006, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14665, 13047, 1006, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14666, 13048, 1006, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14667, 13049, 1006, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14439, 12759, 771, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14440, 12760, 771, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14441, 12761, 771, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14442, 12762, 771, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14443, 12763, 771, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14444, 12764, 771, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14445, 12765, 771, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14446, 12766, 771, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14447, 12767, 771, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14448, 12768, 771, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14688, 13070, 1009, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14689, 13071, 1009, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14695, 13075, 1009, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14696, 13076, 1009, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14697, 13077, 1009, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14698, 13078, 1009, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14690, 12248, 1009, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14699, 13079, 1009, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14700, 13080, 1009, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14701, 13082, 1009, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14736, 13120, 1012, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14737, 8653, 1012, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14738, 2484, 1012, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14739, 13001, 1012, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14740, 13121, 1012, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14741, 13122, 1012, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14742, 13123, 1012, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14743, 13124, 1012, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14744, 13125, 1012, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14745, 10388, 1012, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14746, 11802, 1012, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14747, 13126, 1012, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14217, 9215, 983, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14218, 12516, 983, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14219, 6145, 983, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14220, 11794, 983, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14221, 11795, 983, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14668, 13050, 1006, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14669, 13051, 1006, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14670, 13052, 1006, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14671, 13053, 1006, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14672, 13054, 1006, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14673, 13055, 1006, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14719, 8816, 1011, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14720, 157, 1011, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14721, 8817, 1011, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14722, 8815, 1011, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14723, 8818, 1011, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14724, 8820, 1011, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14725, 8819, 1011, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14726, 8821, 1011, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14727, 8822, 1011, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14728, 13105, 1011, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14601, 9987, 1002, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14602, 13004, 1002, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14603, 7989, 1002, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14604, 11743, 1002, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14605, 13005, 1002, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14606, 13006, 1002, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14607, 9978, 1002, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14608, 13007, 1002, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14609, 7861, 1002, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14610, 3587, 1002, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14611, 11745, 1002, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14612, 11741, 1002, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14613, 7982, 1002, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14614, 13008, 1002, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14615, 10091, 1002, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14616, 2359, 1002, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14596, 4706, 303, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14597, 7726, 303, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14619, 7290, 304, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14620, 13011, 1003, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14621, 13012, 1003, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14622, 13013, 1003, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14623, 13014, 1003, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14624, 13015, 1003, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14625, 13016, 1003, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14626, 13017, 1003, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14627, 13018, 1003, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14628, 13019, 1003, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14629, 10338, 1003, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14630, 1123, 1003, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14631, 13020, 1003, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14632, 13021, 1003, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14633, 13022, 1003, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14634, 13008, 1004, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14635, 13023, 1004, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14636, 13024, 1004, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14637, 13025, 1004, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14638, 13026, 1004, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14361, 12680, 724, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14362, 12681, 724, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14363, 12682, 724, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14364, 12683, 724, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14365, 12684, 724, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14366, 12685, 724, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14367, 12686, 724, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14368, 12687, 724, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14369, 12688, 724, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14370, 12689, 724, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14371, 12690, 724, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14372, 12691, 724, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14639, 13027, 1004, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14640, 11743, 1004, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14641, 13028, 1004, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14642, 13029, 1004, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14643, 13030, 1004, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14644, 13005, 1004, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14645, 13031, 1004, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14776, 13234, 1018, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14837, 6397, 1023, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14838, 4181, 1023, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14839, 2636, 1023, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14840, 941, 1023, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14841, 1096, 1023, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14842, 2082, 1023, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14843, 942, 1023, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14844, 6560, 1023, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14845, 1084, 1023, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14786, 13244, 1017, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14787, 13245, 1017, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14788, 13246, 1017, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14789, 13247, 1017, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14790, 13248, 1017, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14791, 13249, 1017, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14792, 13250, 1017, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14793, 13251, 1017, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14794, 13252, 1017, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14795, 13253, 1017, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14796, 13254, 1017, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14797, 13255, 1017, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14798, 13256, 1017, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14799, 13257, 1017, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14800, 13258, 1017, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14801, 11946, 1017, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5739, 6647, 472, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14966, 8829, 1031, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14967, 8830, 1031, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14968, 10496, 1031, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14969, 13303, 1031, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14970, 13691, 1031, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14756, 13132, 1013, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14757, 13133, 1013, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14758, 13134, 1013, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14759, 13135, 1013, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14760, 13136, 1013, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14761, 13137, 1013, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14762, 13138, 1013, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14763, 13139, 1013, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14971, 10290, 1031, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14972, 13692, 1031, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14973, 13693, 1031, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14974, 13694, 1031, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14909, 13650, 1026, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14910, 13651, 1026, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14911, 13652, 1026, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14912, 13653, 1026, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14913, 2883, 1026, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14914, 13654, 1026, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14915, 13450, 1026, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14916, 13655, 1026, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14917, 12890, 1026, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14918, 8991, 1026, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14919, 13657, 1026, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14920, 13658, 1026, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14921, 13659, 1026, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14922, 13660, 1026, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14923, 13661, 1026, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14924, 8985, 1026, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14925, 9184, 1026, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14926, 13662, 1026, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14927, 13663, 1026, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14928, 13664, 1026, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14827, 2360, 1022, 1, 11);
INSERT INTO 'dancespublicationsmap' VALUES (14828, 3323, 1022, 2, 11);
INSERT INTO 'dancespublicationsmap' VALUES (14829, 5308, 1022, 3, 11);
INSERT INTO 'dancespublicationsmap' VALUES (14953, 13584, 1030, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14954, 13585, 1030, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14955, 10920, 1030, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14956, 13149, 1030, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14957, 10376, 1030, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14958, 13586, 1030, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14959, 12426, 1030, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14960, 13587, 1030, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15017, 13602, 1024, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14893, 13629, 1025, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14811, 807, 1021, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14812, 1046, 1021, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14813, 1587, 1021, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14814, 1847, 1021, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14815, 1899, 1021, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14816, 2491, 1021, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14817, 2565, 1021, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14818, 8841, 1021, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14773, 13213, 1015, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14774, 12441, 1015, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (21314, 11890, 1407, 91, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21312, 3231, 1407, 91, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21319, 3326, 1407, 92, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21317, 16535, 1407, 92, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21316, 3310, 1407, 92, 101);
INSERT INTO 'dancespublicationsmap' VALUES (14802, 13260, 1019, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14803, 13261, 1019, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14804, 13262, 1019, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14805, 13263, 1019, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14806, 13264, 1019, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14807, 13521, 1019, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14808, 13266, 1019, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14809, 13267, 1019, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14810, 13268, 1019, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14961, 12941, 1030, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14962, 13588, 1030, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14963, 13589, 1030, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15063, 13707, 1036, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15064, 13708, 1036, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15065, 13709, 1036, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15066, 10469, 1036, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15067, 10467, 1036, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15068, 13710, 1036, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15069, 11160, 1036, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15070, 13711, 1036, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15018, 13598, 1024, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15019, 13600, 1024, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15020, 13272, 1024, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15021, 13611, 1024, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15022, 13597, 1024, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15023, 13275, 1024, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15024, 13603, 1024, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15025, 13610, 1024, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15026, 13605, 1024, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15027, 13601, 1024, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15028, 13612, 1024, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15029, 11928, 1024, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15030, 13596, 1024, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15031, 13608, 1024, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15032, 13599, 1024, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15132, 13757, 1042, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15133, 13758, 1042, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15134, 13759, 1042, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15135, 13760, 1042, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15150, 13764, 1042, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15151, 13768, 1042, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15152, 13769, 1042, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15153, 13770, 1042, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15154, 13771, 1042, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5222, 6040, 473, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4093, 4717, 473, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4111, 4736, 473, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4261, 4922, 473, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15259, 13847, 1049, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15261, 13849, 1049, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15262, 13850, 1049, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15264, 13852, 1049, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15094, 13732, 1039, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15095, 13733, 1039, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15096, 13734, 1039, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15097, 13735, 1039, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15098, 13736, 1039, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15099, 13737, 1039, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15205, 868, 539, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15158, 13774, 110, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15268, 199, 1050, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15269, 13376, 1050, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15270, 6023, 1050, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15271, 3649, 1050, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15272, 13853, 1050, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15273, 13854, 1050, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15159, 51, 1044, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14976, 10887, 1033, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14977, 11776, 1033, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14978, 11777, 1033, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14979, 12179, 1033, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15100, 13738, 1039, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14980, 10891, 1033, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15101, 13739, 1039, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15102, 13741, 1039, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15237, 13730, 1038, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15291, 13436, 1027, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15292, 13437, 1027, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15293, 9875, 1027, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15294, 13438, 1027, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15295, 13439, 1027, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15296, 13440, 1027, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15297, 13441, 1027, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15298, 13442, 1027, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15299, 1474, 1027, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15300, 13443, 1027, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15301, 13444, 1027, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14981, 11778, 1033, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15238, 13731, 1038, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15239, 12108, 1038, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15240, 13567, 1038, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14982, 11779, 1033, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14983, 11780, 1033, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14990, 11585, 1033, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14991, 10899, 1033, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14975, 13695, 1032, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15071, 13696, 1032, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15072, 13712, 1032, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15073, 13697, 1032, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15074, 13698, 1032, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15075, 13713, 1032, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15076, 13714, 1032, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15077, 13715, 1032, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14993, 10946, 1033, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14943, 13328, 1029, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15302, 13445, 1027, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15303, 13446, 1027, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15093, 13729, 821, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15282, 13859, 1051, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15283, 13860, 1051, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15284, 13861, 1051, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15285, 12672, 1051, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15286, 13863, 1051, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15287, 13864, 1051, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15288, 13865, 1051, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15289, 13866, 1051, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15290, 13867, 1051, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15104, 13742, 1040, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15105, 13743, 1040, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15106, 13744, 1040, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15107, 13745, 1040, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15108, 13746, 1040, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15109, 13747, 1040, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15110, 13748, 1040, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15111, 13749, 1040, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15112, 13750, 1040, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15113, 13751, 1040, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15274, 13855, 1050, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15275, 13856, 1050, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15276, 13857, 1050, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15277, 1332, 1050, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15278, 6147, 1050, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15404, 13935, 1058, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15405, 13936, 1058, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15406, 13937, 1058, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15407, 13938, 1058, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15408, 13939, 1058, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4454, 5144, 473, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15409, 13940, 1058, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15410, 13941, 1058, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15411, 13942, 1058, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15412, 13943, 1058, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15413, 13944, 1058, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15414, 13945, 1058, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4563, 5270, 473, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4729, 5472, 473, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4897, 5668, 473, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5006, 5792, 473, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5401, 6248, 473, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5577, 6452, 473, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5764, 6674, 473, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5952, 6896, 473, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15526, 9340, 1064, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15527, 14041, 1064, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15528, 11553, 1064, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15529, 14043, 1064, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15530, 14044, 1064, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15531, 14045, 1064, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15532, 14046, 1064, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15533, 14047, 1064, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15534, 14048, 1064, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15535, 14049, 1064, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15536, 14050, 1064, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15537, 14051, 1064, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15352, 13896, 1056, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15353, 13897, 1056, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15354, 13898, 1056, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15623, 10934, 1069, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15624, 2459, 1069, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15625, 9855, 1069, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15626, 14134, 1069, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15627, 9474, 1069, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15628, 10014, 1069, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15629, 10507, 1069, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15630, 11767, 1069, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15631, 387, 1069, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15632, 8970, 1069, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15633, 10519, 1069, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15634, 10937, 1069, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15635, 10935, 1069, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15636, 10936, 1069, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15637, 10526, 1069, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15638, 7563, 1069, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15639, 14135, 1069, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15640, 11762, 1069, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15642, 3700, 1069, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15643, 842, 1069, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15644, 11529, 1069, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15645, 10111, 1069, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15646, 11765, 1069, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15647, 7104, 1069, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15355, 13899, 1056, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15559, 14072, 1066, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15560, 14073, 1066, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15561, 14074, 1066, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15562, 14075, 1066, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15563, 14076, 1066, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15564, 14077, 1066, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15567, 14080, 1066, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15565, 14078, 1066, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15566, 14079, 1066, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15569, 14082, 1066, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15568, 14081, 1066, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15445, 13960, 1060, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15446, 13961, 1060, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15448, 13963, 1060, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15449, 13964, 1060, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15450, 13965, 1060, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15451, 13966, 1060, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15206, 13805, 1046, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15207, 13806, 1046, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15208, 13807, 1046, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15209, 13808, 1046, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15211, 13809, 1046, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15212, 13810, 1046, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15213, 13811, 1046, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15214, 13812, 1046, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15215, 13813, 1046, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15216, 13814, 1046, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15587, 14100, 1067, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15588, 14101, 1067, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15589, 2604, 1067, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15590, 9003, 1067, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15591, 14102, 1067, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15592, 14103, 1067, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15452, 10102, 1060, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15454, 12427, 1060, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15455, 12251, 1060, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15456, 13973, 1060, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15217, 13815, 1046, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15225, 13823, 1047, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15226, 13824, 1047, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15227, 13825, 1047, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15228, 13826, 1047, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15229, 12777, 1047, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15230, 11434, 1047, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15231, 13827, 1047, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15232, 13828, 1047, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15233, 11436, 1047, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15234, 13829, 1047, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15235, 13830, 1047, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15236, 13831, 1047, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15339, 13885, 1055, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15340, 8654, 1055, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15341, 13886, 1055, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15342, 13887, 1055, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15343, 13888, 1055, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15344, 13889, 1055, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15345, 13890, 1055, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15346, 13891, 1055, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15347, 13892, 1055, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15348, 13893, 1055, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15349, 13894, 1055, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15350, 13895, 1055, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15351, 10966, 853, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15513, 13553, 1063, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15474, 10517, 1061, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15356, 13900, 1056, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15357, 13901, 1056, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15358, 13902, 1056, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15359, 13903, 1056, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14764, 13146, 1014, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14765, 13145, 1014, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14766, 13144, 1014, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14767, 13143, 1014, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15360, 13904, 1056, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15361, 13905, 1056, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15362, 13906, 1056, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15363, 13907, 1056, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15364, 13908, 1056, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15365, 13909, 1056, 33, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15366, 13910, 1056, 35, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15367, 13911, 1056, 37, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15368, 13912, 1056, 39, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15369, 13913, 1056, 41, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15497, 14013, 1062, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15498, 14014, 1062, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15500, 14016, 1062, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15501, 14017, 1062, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15504, 14019, 1062, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15505, 14020, 1062, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15506, 14021, 1062, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15546, 14059, 1065, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15547, 14060, 1065, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15548, 14061, 1065, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15549, 14062, 1065, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15550, 14063, 1065, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15551, 14064, 1065, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15552, 14065, 1065, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15553, 14066, 1065, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15554, 14067, 1065, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15555, 14068, 1065, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15556, 14069, 1065, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15557, 14070, 1065, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15558, 14071, 1065, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15684, 13415, 1072, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15785, 13497, 1081, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15786, 13498, 1081, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15787, 13499, 1081, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15788, 13500, 1081, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15789, 13501, 1081, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15790, 13502, 1081, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15791, 13503, 1081, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15792, 13504, 1081, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15793, 13505, 1081, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15794, 13506, 1081, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13393, 3672, 954, 104, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13394, 3678, 954, 104, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13397, 3701, 954, 105, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13396, 3695, 954, 105, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13400, 3722, 954, 106, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13398, 3710, 954, 106, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15701, 14148, 1074, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15702, 14149, 1074, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15703, 14150, 1074, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15704, 14151, 1074, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15705, 14152, 1074, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15706, 14153, 1074, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15707, 14154, 1074, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15708, 14155, 1075, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15709, 14156, 1075, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15710, 7274, 1075, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15711, 12769, 1075, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15712, 12771, 1075, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15713, 12772, 1075, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15714, 14161, 1075, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15715, 14162, 1076, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15716, 14163, 1076, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15717, 7293, 1076, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15718, 1784, 1076, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15719, 7296, 1076, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15720, 7289, 1076, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15721, 14168, 1076, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15846, 13385, 1085, 1, 11);
INSERT INTO 'dancespublicationsmap' VALUES (15856, 14242, 1087, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15855, 14241, 1087, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15696, 14143, 1073, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15697, 14144, 1073, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15850, 13579, 1086, 1, 11);
INSERT INTO 'dancespublicationsmap' VALUES (15851, 13580, 1086, 2, 11);
INSERT INTO 'dancespublicationsmap' VALUES (15852, 13581, 1086, 3, 11);
INSERT INTO 'dancespublicationsmap' VALUES (15853, 13582, 1086, 4, 11);
INSERT INTO 'dancespublicationsmap' VALUES (15854, 13583, 1086, 5, 11);
INSERT INTO 'dancespublicationsmap' VALUES (15847, 4411, 1085, 2, 11);
INSERT INTO 'dancespublicationsmap' VALUES (15848, 12792, 1085, 3, 11);
INSERT INTO 'dancespublicationsmap' VALUES (15849, 13316, 1085, 4, 11);
INSERT INTO 'dancespublicationsmap' VALUES (15981, 11763, 1069, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15507, 14022, 1062, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15508, 14023, 1062, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15963, 14321, 1093, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15765, 13329, 1080, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15769, 12124, 1080, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15770, 7923, 1080, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15982, 14340, 1095, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16063, 14376, 1095, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16058, 14371, 1095, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16061, 14374, 1095, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16060, 14373, 1095, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16064, 14377, 1095, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16062, 14375, 1095, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15726, 14173, 1078, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15727, 14174, 1078, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15729, 12631, 1078, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15873, 14281, 1090, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15874, 14282, 1090, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15875, 14283, 1090, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15876, 14284, 1090, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15877, 14285, 1090, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15878, 14286, 1090, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15879, 14287, 1090, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15880, 14288, 1090, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15881, 14289, 1090, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15882, 14290, 1090, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15965, 14323, 1094, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15966, 14324, 1094, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15967, 14325, 1094, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15968, 13359, 1094, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15969, 13364, 1094, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15970, 14326, 1094, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15971, 9676, 1094, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15972, 14327, 1094, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15973, 13363, 1094, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15974, 13366, 1094, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15730, 14177, 1078, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15731, 14178, 1078, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15732, 12219, 1078, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15733, 14179, 1078, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15734, 14180, 1078, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15735, 14181, 1078, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15722, 14169, 1077, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15723, 14170, 1077, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15724, 14171, 1077, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15725, 14172, 1077, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15509, 14024, 1062, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15510, 14025, 1062, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15740, 14186, 1016, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15741, 14187, 1016, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15742, 14188, 1016, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15743, 14189, 1016, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15744, 14190, 1016, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15745, 14191, 1016, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15746, 14192, 1016, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15747, 14193, 1016, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15748, 14194, 1016, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15749, 14195, 1016, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15750, 14196, 1016, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15857, 14243, 1088, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15858, 14244, 1088, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15859, 13762, 1088, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15751, 14197, 1016, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15752, 14198, 1016, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15753, 14199, 1016, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15511, 14026, 1062, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15512, 14027, 1062, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21358, 17133, 1407, 103, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21356, 3743, 1407, 103, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21355, 3725, 1407, 103, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21359, 3783, 1407, 104, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21360, 3786, 1407, 104, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21362, 13588, 1407, 105, 101);
INSERT INTO 'dancespublicationsmap' VALUES (15736, 14182, 1078, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16540, 14578, 1135, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16532, 14579, 1135, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16533, 14580, 1135, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16535, 14581, 1135, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16534, 14582, 1135, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16536, 14583, 1135, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16537, 14585, 1135, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15672, 14142, 1071, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15673, 13404, 1071, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15674, 13405, 1071, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15675, 13406, 1071, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15676, 13407, 1071, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15677, 13408, 1071, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15678, 13409, 1071, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15679, 13410, 1071, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15680, 13411, 1071, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16538, 14586, 1135, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16539, 14587, 1135, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16076, 12793, 1098, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16077, 12794, 1098, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (549, 640, 103, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1075, 1246, 103, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16072, 14317, 1091, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1262, 1466, 103, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1530, 1774, 103, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1531, 1775, 103, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16073, 13309, 1091, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16074, 13310, 1091, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1578, 1834, 103, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1606, 1866, 103, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10027, 2498, 103, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (8161, 8087, 103, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2583, 2978, 103, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12599, 3561, 103, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3245, 3737, 103, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (150, 170, 715, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1747, 2020, 715, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5421, 6273, 715, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3516, 4048, 715, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11642, 10549, 822, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11641, 10548, 822, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11640, 10428, 822, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11639, 10547, 822, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11638, 10546, 822, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11635, 10306, 822, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11637, 10545, 822, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11636, 10544, 822, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16907, 14996, 1149, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16848, 14960, 1144, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16813, 14925, 1119, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16812, 14924, 1119, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16811, 14923, 1119, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16810, 14922, 1119, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16809, 14921, 1119, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16808, 14920, 1119, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16807, 14919, 1119, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (91, 104, 445, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16563, 9350, 1136, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1412, 1637, 445, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3216, 3701, 103, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3237, 3729, 103, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16606, 14797, 1139, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16612, 14796, 1139, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16607, 14794, 1139, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16608, 14793, 1139, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (753, 878, 445, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1240, 1434, 445, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5835, 6762, 445, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4986, 5769, 445, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1238, 1432, 445, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5751, 6659, 445, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5028, 5814, 445, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16530, 14634, 1134, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16564, 9874, 1136, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16565, 10010, 1136, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16516, 14364, 1133, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16517, 14729, 1133, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16518, 14730, 1133, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16519, 14731, 1133, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16520, 14732, 1133, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16521, 14733, 1133, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16522, 14734, 1133, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16523, 14735, 1133, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16524, 14736, 1133, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16525, 14737, 1133, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14984, 11782, 1033, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14985, 11705, 1033, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14986, 11750, 1033, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14987, 11784, 1033, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14988, 11524, 1033, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14989, 11785, 1033, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16596, 14776, 1138, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16595, 14777, 1138, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16597, 14778, 1138, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16598, 14779, 1138, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16599, 14780, 1138, 29, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16600, 14781, 1138, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16601, 14782, 1138, 31, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16602, 14783, 1138, 32, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16603, 14784, 1138, 33, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16604, 14785, 1138, 34, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16605, 14786, 1138, 35, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16626, 14800, 1138, 37, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16628, 14800, 1138, 37, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16627, 14801, 1138, 38, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16629, 14801, 1138, 38, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16630, 14802, 1138, 39, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16631, 14803, 1138, 40, 20);
INSERT INTO 'dancespublicationsmap' VALUES (21361, 16534, 1407, 105, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21363, 3802, 1407, 105, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21367, 3862, 1407, 106, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21364, 3829, 1407, 106, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21365, 11284, 1407, 106, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21366, 3834, 1407, 106, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21429, 11524, 1407, 106, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21370, 3941, 1407, 107, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21368, 10306, 1407, 107, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21369, 3932, 1407, 107, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21374, 3972, 1407, 108, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21373, 3963, 1407, 108, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21371, 3953, 1407, 108, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21372, 7811, 1407, 108, 101);
INSERT INTO 'dancespublicationsmap' VALUES (3271, 3769, 103, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3348, 3859, 103, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (8723, 1782, 775, 199, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8736, 4933, 775, 229, 16);
INSERT INTO 'dancespublicationsmap' VALUES (16806, 1669, 1119, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16872, 14346, 1146, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16871, 10232, 1146, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16870, 14685, 1146, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16825, 14931, 1120, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16824, 8080, 1120, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16823, 14930, 1120, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16822, 8704, 1120, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16821, 13099, 1120, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16869, 14977, 1146, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16868, 13730, 1146, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16867, 14976, 1146, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16866, 5093, 1146, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16865, 14975, 1146, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16820, 14929, 1120, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16819, 14928, 1120, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16818, 13098, 1120, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16817, 10482, 1120, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16816, 14927, 1120, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16815, 10476, 1120, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16814, 14926, 1120, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12414, 14750, 683, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16764, 14884, 1141, 119, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16765, 7271, 1141, 120, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16766, 9141, 1141, 121, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16767, 12667, 1141, 122, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16768, 14885, 1141, 123, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16769, 14886, 1141, 124, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16770, 8646, 1141, 125, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16771, 14887, 1141, 126, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16864, 14974, 1146, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16863, 11483, 1146, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16862, 11284, 1146, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16861, 13577, 1146, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16860, 14972, 1145, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16859, 14971, 1145, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16858, 14970, 1145, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16857, 14969, 1145, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16856, 14968, 1145, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16855, 14967, 1145, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16854, 14966, 1145, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16853, 14965, 1145, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16852, 14964, 1145, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16851, 14963, 1145, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16850, 14962, 1145, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16849, 14961, 1145, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16909, 14998, 1149, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16910, 14999, 1149, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16911, 15000, 1149, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16965, 11103, 1152, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16906, 14995, 1149, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17112, 15128, 1160, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17111, 15147, 1160, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17110, 15146, 1160, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17109, 15145, 1160, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17113, 7520, 1161, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17014, 8674, 1156, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17013, 8669, 1156, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17012, 8679, 1156, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17011, 15096, 1155, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17010, 15095, 1155, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17009, 15094, 1155, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17008, 15093, 1155, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17007, 15092, 1155, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17006, 15091, 1155, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17005, 15089, 1155, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17004, 15088, 1155, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17003, 15087, 1155, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17002, 15086, 1155, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17001, 15085, 1155, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17000, 15084, 1155, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16999, 15083, 1155, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16998, 15082, 1155, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16997, 15081, 1155, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16996, 15080, 1155, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16995, 15079, 1155, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16994, 15078, 1155, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16993, 15077, 1155, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17108, 15144, 1160, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17107, 15143, 1160, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17106, 15142, 1160, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17104, 15140, 1160, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17103, 15139, 1160, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17102, 15138, 1160, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17101, 15137, 1160, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17100, 15136, 1160, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17099, 15135, 1160, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17098, 15134, 1160, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17097, 15133, 1160, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17096, 15132, 1160, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17095, 15131, 1160, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17094, 15130, 1160, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17093, 15129, 1160, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16992, 15073, 1154, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16991, 15072, 1154, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16990, 15071, 1154, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16989, 15070, 1154, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16988, 15069, 1154, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16943, 15033, 1151, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16944, 15034, 1151, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16945, 15035, 1151, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16946, 15036, 1151, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16947, 15037, 1151, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16948, 15038, 1151, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16949, 14352, 1151, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16950, 15040, 1151, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16881, 14518, 1148, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16882, 14984, 1148, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16883, 14419, 1148, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16891, 11680, 1148, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16884, 11681, 1148, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16885, 5717, 1148, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16886, 2214, 1148, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16892, 6163, 1148, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16887, 1951, 1148, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16888, 6265, 1148, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16889, 3676, 1148, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17056, 13679, 1159, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17057, 15099, 1159, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17058, 15100, 1159, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17059, 15101, 1159, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17060, 15102, 1159, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17061, 15103, 1159, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17062, 15104, 1159, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17063, 15105, 1159, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16987, 15068, 1154, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16986, 15067, 1154, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16985, 15066, 1154, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16984, 15065, 1154, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16983, 15064, 1154, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16982, 15063, 1154, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16981, 15062, 1154, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16980, 15061, 1154, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16979, 15060, 1154, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16978, 15059, 1154, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16977, 15058, 1154, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17144, 3654, 338, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17143, 6148, 338, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2006, 2315, 152, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4091, 4715, 152, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4123, 4750, 152, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12961, 12043, 948, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12960, 12042, 948, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12959, 12041, 948, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12958, 9336, 948, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12957, 12040, 948, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12956, 12039, 948, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12955, 12038, 948, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12950, 12020, 948, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12954, 12037, 948, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12953, 12036, 948, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17227, 15261, 1166, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17223, 15254, 1166, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17222, 15252, 1166, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17221, 15251, 1166, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17220, 15250, 1166, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17219, 15249, 1166, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16908, 14997, 1149, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16912, 15001, 1149, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16927, 15017, 1149, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16913, 15002, 1149, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16779, 14893, 1142, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16780, 14894, 1142, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16781, 14895, 1142, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16782, 14896, 1142, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16783, 14897, 1142, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16784, 14898, 1142, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16785, 14900, 1142, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16786, 14901, 1142, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16787, 14902, 1142, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16788, 14903, 1142, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16789, 14904, 1142, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16790, 14905, 1142, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16791, 14906, 1142, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16792, 14907, 1142, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16793, 14908, 1142, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16966, 5486, 1153, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16967, 6866, 1153, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16968, 5196, 1153, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16969, 3353, 1153, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16970, 4062, 1153, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16971, 3193, 1153, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16972, 2967, 1153, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16973, 204, 1153, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16974, 2679, 1153, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16975, 4492, 1153, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16976, 3417, 1153, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17015, 8088, 1157, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16775, 9139, 1141, 130, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16776, 14889, 1141, 131, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16777, 13280, 1141, 132, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16778, 9140, 1141, 133, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16914, 15004, 1149, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16915, 15005, 1149, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16916, 15006, 1149, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16917, 15007, 1149, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16918, 15008, 1149, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16919, 15009, 1149, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16920, 15010, 1149, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16921, 15011, 1149, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16922, 15012, 1149, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16923, 15013, 1149, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16924, 15014, 1149, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16925, 15015, 1149, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16926, 15016, 1149, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7645, 7826, 277, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5181, 5992, 277, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4568, 5277, 277, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17252, 11629, 1169, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17251, 15286, 1169, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17250, 15285, 1169, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17249, 9898, 1169, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17248, 15284, 1169, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17247, 15283, 1169, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17246, 15282, 1169, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17245, 12892, 1169, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17244, 15281, 1169, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17243, 15280, 1169, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17242, 14654, 1169, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17241, 10458, 1169, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17240, 15279, 1169, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17239, 15278, 1169, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17238, 10459, 1169, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17237, 15277, 1169, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17236, 15276, 1169, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17235, 11278, 1169, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17234, 15275, 1169, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17233, 12249, 1169, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17231, 15262, 1167, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17230, 15260, 1167, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17229, 15259, 1167, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17228, 15258, 1167, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17226, 15257, 1167, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17225, 15255, 1167, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17224, 15256, 1167, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17146, 15183, 1097, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17147, 15184, 1097, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17148, 15186, 1097, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17149, 14389, 1097, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17150, 15188, 1097, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17151, 15189, 1097, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17152, 14674, 1097, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10604, 9297, 529, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17271, 15304, 1171, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17153, 14239, 1097, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17154, 15190, 1097, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12611, 11640, 925, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12610, 11639, 925, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12609, 11638, 925, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12608, 11637, 925, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12607, 11636, 925, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12606, 11635, 925, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12605, 11634, 925, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12604, 11633, 925, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12603, 8624, 925, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12602, 11632, 925, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17142, 1215, 1163, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21389, 10789, 1407, 114, 101);
INSERT INTO 'dancespublicationsmap' VALUES (17358, 15396, 1176, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17357, 15395, 1176, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17356, 15394, 1176, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17355, 15393, 1176, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17354, 15392, 1176, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17353, 15391, 1176, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17352, 15390, 1176, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17351, 15389, 1176, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17350, 15387, 1176, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17349, 15386, 1176, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17348, 15385, 1176, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17347, 15384, 1176, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17346, 15383, 1176, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17345, 15382, 1176, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17344, 15381, 1176, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17343, 15380, 1176, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17342, 15379, 1176, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17293, 15333, 1131, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21390, 4248, 1407, 114, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21416, 4561, 1407, 119, 101);
INSERT INTO 'dancespublicationsmap' VALUES (17259, 15293, 1170, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17260, 15294, 1170, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17261, 15295, 1170, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17262, 15296, 1170, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17263, 15297, 1170, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17264, 15298, 1170, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17265, 15299, 1170, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17266, 15300, 1170, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17268, 15301, 1170, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17267, 15302, 1170, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17269, 15303, 1170, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17270, 11163, 1170, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17208, 15238, 1165, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17210, 15239, 1165, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17211, 15240, 1165, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17212, 15241, 1165, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17213, 15242, 1165, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17214, 15243, 1165, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17215, 15244, 1165, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17566, 15552, 1189, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17567, 15553, 1189, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17568, 15554, 1189, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17569, 15555, 1189, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17570, 15556, 1189, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2492, 2873, 71, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17475, 15404, 1183, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17474, 14138, 1183, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5096, 5894, 151, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3883, 4464, 151, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17373, 15443, 1177, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17372, 15442, 1177, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17371, 15441, 1177, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17370, 15440, 1177, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17369, 15439, 1177, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17368, 15438, 1177, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17367, 15437, 1177, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17366, 15436, 1177, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17365, 15435, 1177, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17364, 15434, 1177, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17363, 12437, 1177, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5369, 6206, 65, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2469, 2848, 71, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17473, 12124, 1183, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17472, 14649, 1183, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17471, 13544, 1183, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17470, 15403, 1183, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17469, 13766, 1183, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17468, 9770, 1183, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17467, 14712, 1183, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17466, 13847, 1183, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17465, 13163, 1183, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17464, 14688, 1183, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17463, 15402, 1183, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17362, 15432, 1177, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17361, 15431, 1177, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5877, 6811, 209, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1699, 1969, 209, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17284, 15318, 1172, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17285, 15319, 1172, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17286, 15320, 1172, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17287, 15321, 1172, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17288, 15322, 1172, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17289, 15323, 1172, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17290, 15324, 1172, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17291, 15325, 1172, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17292, 15326, 1172, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (456, 535, 209, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (503, 584, 209, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (687, 804, 209, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17571, 15557, 1189, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17572, 8301, 1189, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17573, 15558, 1189, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17574, 15559, 1189, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17575, 15560, 1189, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17576, 15561, 1189, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17415, 15478, 1181, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17414, 15477, 1181, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17413, 15476, 1181, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17416, 15481, 1182, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17417, 15482, 1182, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17418, 15483, 1182, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17419, 15484, 1182, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17420, 15485, 1182, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17421, 15486, 1182, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17422, 15487, 1182, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17423, 15488, 1182, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17424, 15489, 1182, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17425, 15490, 1182, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17426, 15491, 1182, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17427, 15492, 1182, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17428, 15493, 1182, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17429, 15494, 1182, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17430, 15495, 1182, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17431, 15496, 1182, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17432, 15497, 1182, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17433, 15498, 1182, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17434, 15499, 1182, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17435, 15500, 1182, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17436, 15501, 1182, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17437, 15502, 1182, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17438, 15503, 1182, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17439, 15504, 1182, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17440, 15505, 1182, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17441, 15506, 1182, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17442, 15507, 1182, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17443, 15508, 1182, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17444, 15509, 1182, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17445, 15510, 1182, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17446, 15511, 1182, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17447, 15512, 1182, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17448, 15513, 1182, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17449, 15514, 1182, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17450, 15515, 1182, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17451, 15516, 1182, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4092, 4716, 157, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17359, 15397, 1176, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17383, 15454, 1178, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17382, 15453, 1178, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17381, 15452, 1178, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17546, 642, 1187, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17577, 15562, 1189, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17397, 1562, 1180, 2, 17);
INSERT INTO 'dancespublicationsmap' VALUES (17398, 8154, 1180, 3, 17);
INSERT INTO 'dancespublicationsmap' VALUES (17399, 15429, 1180, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17400, 8162, 1180, 5, 17);
INSERT INTO 'dancespublicationsmap' VALUES (17401, 7552, 1180, 6, 17);
INSERT INTO 'dancespublicationsmap' VALUES (17273, 15306, 1171, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17274, 15307, 1171, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17275, 15308, 1171, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17276, 15309, 1171, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17277, 14356, 1171, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17278, 15310, 1171, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17279, 15311, 1171, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17280, 15312, 1171, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15320, 13869, 1053, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15321, 13870, 1053, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17490, 685, 1185, 101, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17491, 1030, 1185, 102, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17492, 3103, 1185, 103, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17493, 5344, 1185, 104, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17494, 6144, 1185, 105, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17495, 1064, 1185, 106, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17496, 3621, 1185, 107, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17497, 2370, 1185, 108, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17498, 4330, 1185, 109, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17536, 15528, 1186, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17537, 15529, 1186, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17538, 15530, 1186, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17539, 15531, 1186, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17540, 15532, 1186, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17402, 5330, 1180, 7, 39);
INSERT INTO 'dancespublicationsmap' VALUES (17412, 15428, 1180, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17403, 7553, 1180, 9, 17);
INSERT INTO 'dancespublicationsmap' VALUES (17410, 5525, 1180, 10, 17);
INSERT INTO 'dancespublicationsmap' VALUES (17404, 8143, 1180, 11, 17);
INSERT INTO 'dancespublicationsmap' VALUES (15322, 13871, 1053, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15323, 13872, 1053, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17384, 15461, 1179, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15324, 13873, 1053, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17541, 15533, 1186, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17542, 15534, 1186, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17405, 15427, 1180, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17406, 1931, 1180, 13, 17);
INSERT INTO 'dancespublicationsmap' VALUES (17385, 3251, 1179, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17386, 12128, 1179, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17387, 15462, 1179, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17388, 15463, 1179, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17390, 15465, 1179, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17392, 15467, 1179, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17393, 7871, 1179, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17543, 15535, 1186, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17544, 15536, 1186, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17545, 15537, 1186, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17332, 15365, 1175, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17333, 15366, 1175, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17334, 15265, 1175, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17335, 15367, 1175, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17336, 15368, 1175, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17554, 5308, 1188, 8, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17553, 3894, 1188, 7, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17552, 3857, 1188, 6, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17551, 3485, 1188, 5, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17550, 1891, 1188, 4, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17549, 924, 1188, 3, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17548, 56, 1188, 2, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17547, 549, 1188, 1, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17596, 371, 1190, 18, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17595, 4192, 1190, 17, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17594, 4590, 1190, 16, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17593, 6360, 1190, 15, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17592, 4401, 1190, 14, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17591, 4475, 1190, 13, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17590, 2849, 1190, 12, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17589, 91, 1190, 11, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17588, 453, 1190, 10, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17598, 3941, 1192, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11026, 2641, 653, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11025, 9737, 653, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11024, 9736, 653, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11023, 9735, 653, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11022, 9734, 653, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11021, 9733, 653, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11020, 9732, 653, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11019, 8962, 653, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11018, 9731, 653, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11017, 9730, 653, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11016, 9729, 653, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12133, 11090, 865, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16722, 7281, 1141, 77, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16723, 9029, 1141, 78, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17281, 15315, 1172, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17282, 15316, 1172, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17283, 15317, 1172, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15985, 12003, 1096, 2, 50);
INSERT INTO 'dancespublicationsmap' VALUES (15986, 11365, 1096, 3, 50);
INSERT INTO 'dancespublicationsmap' VALUES (17533, 1058, 1185, 320, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17534, 4651, 1185, 321, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17535, 6085, 1185, 322, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17396, 7546, 1180, 1, 17);
INSERT INTO 'dancespublicationsmap' VALUES (17558, 15544, 1189, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17559, 15545, 1189, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17560, 15546, 1189, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17561, 15547, 1189, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17562, 15548, 1189, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17563, 15549, 1189, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17564, 15550, 1189, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17565, 15551, 1189, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15514, 8559, 1063, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15515, 13554, 1063, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11261, 10117, 747, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11262, 10118, 747, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11263, 10119, 747, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11264, 10120, 747, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11265, 10121, 747, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11266, 10122, 747, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3334, 3843, 112, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16637, 14813, 1140, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16639, 14814, 1140, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16638, 14815, 1140, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16640, 14816, 1140, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16641, 14817, 1140, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16642, 14818, 1140, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16643, 14819, 1140, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16644, 14820, 1140, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10352, 9001, 427, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10353, 9002, 427, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10354, 9003, 427, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10355, 9004, 427, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10356, 9005, 427, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10357, 9006, 427, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10358, 9007, 427, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10359, 9008, 427, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10360, 9009, 427, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10361, 9010, 427, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15114, 13753, 1040, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15115, 13755, 1040, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15516, 13555, 1063, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15518, 13556, 1063, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15519, 13557, 1063, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15520, 13558, 1063, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15521, 13559, 1063, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15522, 13560, 1063, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15523, 14038, 1063, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15524, 14039, 1063, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15525, 14040, 1063, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10739, 9411, 568, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10740, 9412, 568, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10741, 9413, 568, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10742, 9414, 568, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10743, 9415, 568, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10744, 9416, 568, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11267, 10123, 747, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11268, 10124, 747, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11270, 10125, 747, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11269, 3766, 747, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11271, 10127, 747, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11272, 10128, 747, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11273, 10129, 747, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14547, 12946, 998, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14546, 12945, 998, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14545, 12944, 998, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14544, 12943, 998, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12318, 11265, 899, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12317, 7723, 899, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12316, 11264, 899, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12315, 11157, 899, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12314, 11154, 899, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12313, 11153, 899, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12312, 11263, 899, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12311, 11262, 899, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12121, 11081, 863, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12122, 11082, 863, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10388, 9074, 433, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10389, 9075, 433, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10390, 9076, 433, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10391, 9077, 433, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10392, 9078, 433, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10393, 9079, 433, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11634, 7656, 538, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11633, 10525, 538, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11632, 6751, 538, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11631, 10524, 538, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11630, 10523, 538, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11629, 10522, 538, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11628, 10521, 538, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11627, 10147, 538, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11626, 8107, 538, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11625, 10520, 538, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11624, 10518, 538, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11623, 8937, 538, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11622, 10517, 538, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12866, 11918, 941, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12865, 11917, 941, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12864, 11916, 941, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12863, 11915, 941, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12862, 11914, 941, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12861, 11913, 941, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17597, 3058, 1191, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12860, 11912, 941, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12859, 10521, 941, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12858, 11911, 941, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12857, 11910, 941, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15570, 14083, 1066, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15571, 14084, 1066, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15572, 14085, 1066, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15573, 14086, 1066, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15574, 14087, 1066, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15575, 14088, 1066, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12043, 11006, 858, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12044, 11007, 858, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15576, 14089, 1066, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15579, 14092, 1066, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15578, 14091, 1066, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10394, 9080, 433, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10395, 9081, 433, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11909, 10878, 843, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11910, 4439, 843, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11911, 6087, 843, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11912, 2597, 843, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11913, 5511, 843, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11914, 9331, 843, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12139, 11095, 865, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12142, 10569, 865, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12144, 11099, 865, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12137, 11093, 865, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12136, 9338, 865, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12140, 11096, 865, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10940, 9640, 647, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10941, 9641, 647, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10942, 9642, 647, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10943, 9643, 647, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15803, 14226, 1082, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15804, 14227, 1082, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15805, 14228, 1082, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15806, 14229, 1082, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15807, 14230, 1082, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6275, 43, 39, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6338, 1280, 39, 15, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6341, 1367, 39, 16, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6342, 1368, 39, 17, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6356, 1773, 39, 18, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6376, 2153, 39, 21, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6386, 2350, 39, 22, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6349, 1624, 39, 32, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16708, 7309, 1141, 63, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16709, 14854, 1141, 64, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16710, 14851, 1141, 65, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16711, 14853, 1141, 66, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16712, 7310, 1141, 67, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16713, 8645, 1141, 68, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16714, 14521, 1141, 69, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16715, 14855, 1141, 70, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6451, 3589, 39, 40, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6452, 3595, 39, 41, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6456, 3611, 39, 42, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6457, 3616, 39, 43, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6458, 3623, 39, 44, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16303, 14664, 1121, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11711, 10654, 832, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11712, 10655, 832, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11713, 10656, 832, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11714, 10657, 832, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11715, 10658, 832, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11716, 10659, 832, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14238, 12555, 702, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14239, 12556, 702, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14240, 12557, 702, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14241, 12558, 702, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14242, 12559, 702, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14243, 12560, 702, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14244, 12561, 702, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14245, 12562, 702, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14246, 12563, 702, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15577, 14090, 1066, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15580, 14093, 1066, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15581, 14094, 1066, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11088, 9800, 660, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11089, 9801, 660, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12045, 11008, 858, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12046, 11009, 858, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12047, 11010, 858, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12048, 11011, 858, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11717, 10660, 832, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11718, 10661, 832, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11719, 10662, 832, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11720, 10663, 832, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16546, 10069, 1136, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16547, 10070, 1136, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16552, 10071, 1136, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16548, 9985, 1136, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16553, 10016, 1136, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16554, 9984, 1136, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16549, 10073, 1136, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16555, 10072, 1136, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16556, 10076, 1136, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16550, 10077, 1136, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16551, 10011, 1136, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16557, 10080, 1136, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16558, 10008, 1136, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16559, 10082, 1136, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (129, 145, 678, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (104, 117, 678, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2863, 3292, 678, 37, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11274, 10130, 747, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11275, 10131, 747, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11276, 10132, 747, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11277, 10133, 747, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11278, 9048, 747, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11279, 10134, 747, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11280, 10135, 747, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11281, 10136, 747, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11282, 10137, 747, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11283, 10138, 747, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11284, 10139, 747, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11915, 2253, 843, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11916, 10437, 843, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11917, 10535, 843, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11918, 10531, 843, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13859, 7049, 960, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13858, 12232, 960, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13857, 12231, 960, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13856, 12132, 960, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6870, 6, 152, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4304, 4975, 152, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16233, 14517, 1111, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16232, 14516, 1111, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16231, 14507, 1111, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16230, 14515, 1111, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16229, 14513, 1111, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16228, 14514, 1111, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16223, 14505, 1111, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16222, 14511, 1111, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16221, 14510, 1111, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16220, 14504, 1111, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4444, 5133, 668, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2641, 3043, 668, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (106, 120, 710, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16316, 3689, 710, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6661, 4704, 764, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6659, 7059, 764, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6660, 7130, 764, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12255, 11215, 895, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12254, 11214, 895, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12253, 11213, 895, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12252, 11212, 895, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15796, 13508, 1081, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15795, 13507, 1081, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5071, 5864, 93, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (306, 355, 189, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16703, 14849, 1141, 58, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16704, 14850, 1141, 59, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16705, 7287, 1141, 60, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16706, 11423, 1141, 61, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16707, 14852, 1141, 62, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6032, 6993, 146, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1835, 2119, 146, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3095, 3564, 146, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1874, 2164, 146, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5435, 6288, 146, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4752, 5499, 146, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5025, 5811, 146, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3061, 3523, 146, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6031, 6992, 146, 38, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1444, 1674, 146, 39, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2100, 2420, 674, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2138, 2462, 674, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2069, 2388, 674, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (860, 998, 674, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (989, 1144, 674, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2351, 2708, 674, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4109, 4734, 246, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4112, 4737, 246, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12002, 10497, 853, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (575, 669, 612, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5292, 6118, 612, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15883, 14291, 1090, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15884, 14292, 1090, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16583, 14763, 1138, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16584, 14764, 1138, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16585, 14765, 1138, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16586, 14766, 1138, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16587, 2014, 1138, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16588, 14768, 1138, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16591, 14771, 1138, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16590, 14772, 1138, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16592, 14770, 1138, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16589, 13231, 1138, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14715, 13100, 1010, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14716, 13101, 1010, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14717, 13102, 1010, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14718, 13103, 1010, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9989, 8608, 378, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9990, 8609, 378, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9991, 8610, 378, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9992, 8611, 378, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9993, 8612, 378, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9994, 8613, 378, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9995, 8614, 378, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16594, 14775, 1138, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16593, 14774, 1138, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9996, 8615, 378, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9997, 8616, 378, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9998, 8617, 378, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9999, 8618, 378, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10000, 8619, 378, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10001, 8620, 378, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15241, 13568, 1038, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15242, 13569, 1038, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15243, 13570, 1038, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15244, 13571, 1038, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15245, 13572, 1038, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14098, 12474, 964, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14097, 12473, 964, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14096, 12472, 964, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14095, 12471, 964, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14094, 12470, 964, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14093, 12469, 964, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14092, 12467, 964, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10878, 9598, 638, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10877, 9597, 638, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10876, 9596, 638, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10875, 9595, 638, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10874, 9594, 638, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10873, 9593, 638, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15157, 13773, 1042, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15156, 10283, 1042, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15155, 13772, 1042, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4780, 5532, 3, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4952, 5731, 6, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1097, 1274, 5, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (8616, 4931, 80, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2386, 2750, 548, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4059, 4679, 11, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3143, 3615, 18, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5540, 6407, 18, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4297, 4968, 19, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4789, 5543, 23, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2225, 2562, 23, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4446, 5136, 34, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10428, 9111, 437, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10427, 9110, 437, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10426, 9109, 437, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (11853, 10794, 839, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14078, 10433, 841, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14965, 13591, 1030, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14964, 13590, 1030, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17461, 15401, 1183, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17462, 14548, 1183, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4101, 4725, 54, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2523, 2910, 54, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6022, 6981, 54, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4665, 5393, 601, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14543, 12942, 998, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14542, 12941, 998, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14541, 12940, 998, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14540, 12939, 998, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14539, 12938, 998, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14538, 12937, 998, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14537, 12431, 998, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14536, 12019, 998, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14535, 12437, 998, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14534, 9575, 998, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14533, 9749, 998, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14532, 9748, 998, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14531, 12429, 998, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14530, 9746, 998, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14529, 9751, 998, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14528, 9576, 998, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8617, 1203, 80, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8618, 7656, 80, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15797, 14220, 1082, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16645, 7333, 1141, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16646, 7331, 1141, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16647, 7330, 1141, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16648, 7332, 1141, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16649, 7302, 1141, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16650, 14821, 1141, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6310, 794, 39, 7, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6315, 848, 39, 8, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6390, 2436, 39, 24, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6399, 2644, 39, 25, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6558, 5463, 39, 79, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6560, 5497, 39, 80, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6574, 5754, 39, 81, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6578, 5889, 39, 82, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6581, 5937, 39, 83, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6584, 5981, 39, 84, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6587, 6029, 39, 85, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6589, 6061, 39, 86, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6623, 6885, 39, 94, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6628, 6952, 39, 95, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6640, 7210, 39, 97, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6641, 7219, 39, 98, 18);
INSERT INTO 'dancespublicationsmap' VALUES (12428, 11332, 683, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12415, 11338, 683, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12416, 11339, 683, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12417, 11340, 683, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12724, 11543, 935, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12451, 11375, 911, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12452, 11376, 911, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2381, 2742, 30, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5539, 6406, 29, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (258, 301, 27, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16302, 14663, 1121, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (8619, 8090, 80, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21504, 5529, 1407, 151, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21505, 5552, 1407, 151, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21532, 5713, 1407, 154, 101);
INSERT INTO 'dancespublicationsmap' VALUES (2968, 3412, 14, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16301, 14662, 1121, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16299, 9989, 1121, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16300, 9990, 1121, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1961, 2267, 38, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (11706, 10650, 832, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11707, 10367, 832, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11708, 10651, 832, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11709, 10652, 832, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11710, 10653, 832, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17555, 15541, 1189, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7473, 7630, 293, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7477, 7637, 293, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7690, 7884, 293, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7691, 5195, 293, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17556, 15542, 1189, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17557, 15543, 1189, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (107, 121, 258, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (108, 122, 258, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12856, 11909, 941, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12855, 10518, 941, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2237, 2574, 64, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1211, 1400, 65, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4757, 5504, 65, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1218, 1407, 69, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (589, 683, 70, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15885, 10663, 1092, 1, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15887, 14320, 1092, 1, 102);
INSERT INTO 'dancespublicationsmap' VALUES (16224, 14508, 1111, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7557, 2832, 322, 4, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7574, 3102, 322, 5, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7605, 3636, 322, 6, 40);
INSERT INTO 'dancespublicationsmap' VALUES (16315, 1960, 710, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9716, 8345, 312, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9717, 8346, 312, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9718, 8347, 312, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9719, 8348, 312, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9720, 8165, 312, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9721, 8349, 312, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9722, 8350, 312, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9723, 8351, 312, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9724, 8352, 312, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9725, 8353, 312, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9726, 8355, 312, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10684, 5192, 554, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15397, 4537, 1057, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15398, 13455, 1057, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15399, 13456, 1057, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15400, 6860, 1057, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9727, 250, 312, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9728, 8356, 312, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9729, 8357, 312, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9730, 8358, 312, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9731, 3244, 312, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9732, 8360, 312, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9733, 8361, 312, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9734, 8362, 312, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9735, 8363, 312, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9736, 8364, 312, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9737, 8365, 312, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9738, 8366, 312, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9739, 8367, 312, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9740, 8368, 312, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9741, 8369, 312, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13940, 12340, 957, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13939, 12339, 957, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13938, 12338, 957, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13935, 12333, 957, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13927, 12305, 957, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13926, 12304, 957, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13913, 12272, 957, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13855, 12217, 957, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14502, 12841, 994, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14503, 11970, 994, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14504, 10458, 994, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14091, 12468, 964, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14090, 12466, 964, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14089, 12465, 964, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (723, 843, 527, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6651, 5073, 764, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6652, 5379, 764, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4078, 4699, 673, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5102, 5900, 501, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5960, 6905, 511, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15776, 14214, 1080, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15777, 14215, 1080, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15778, 13379, 1080, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15779, 4010, 1080, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15780, 14216, 1080, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15781, 14217, 1080, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15782, 14218, 1080, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15783, 14219, 1080, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15784, 7922, 1080, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15169, 5703, 1044, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15170, 2556, 1044, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4320, 4995, 28, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1518, 1760, 77, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16571, 14751, 1138, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16572, 14752, 1138, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9782, 8414, 363, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9783, 8415, 363, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9784, 8416, 363, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9785, 8417, 363, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9786, 8418, 363, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9787, 8419, 363, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17253, 15287, 1170, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17254, 15288, 1170, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17255, 15289, 1170, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17256, 15290, 1170, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17257, 15291, 1170, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17258, 15292, 1170, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14705, 13090, 1010, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14706, 13091, 1010, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14707, 13092, 1010, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14708, 13093, 1010, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9788, 8420, 363, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9789, 8421, 363, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9790, 8422, 363, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9791, 8423, 363, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9792, 8424, 363, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7488, 191, 569, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1120, 1298, 593, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (291, 338, 212, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (313, 365, 212, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6653, 6145, 764, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6654, 6219, 764, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6655, 6249, 764, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4616, 5333, 212, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7626, 4005, 322, 7, 40);
INSERT INTO 'dancespublicationsmap' VALUES (16573, 14753, 1138, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16574, 14754, 1138, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16578, 14756, 1138, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16576, 14757, 1138, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16577, 14758, 1138, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16575, 14755, 1138, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16579, 14759, 1138, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16580, 14760, 1138, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4249, 4908, 201, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (586, 680, 201, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12236, 11204, 893, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12237, 9534, 893, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6409, 2910, 39, 27, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6413, 2979, 39, 28, 18);
INSERT INTO 'dancespublicationsmap' VALUES (1632, 1894, 146, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12410, 11333, 683, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12411, 11334, 683, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12412, 11335, 683, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12413, 11336, 683, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14709, 13094, 1010, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14710, 13095, 1010, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14711, 13096, 1010, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14712, 13097, 1010, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14713, 13098, 1010, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14714, 13099, 1010, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6656, 6450, 764, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6657, 6909, 764, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6658, 6985, 764, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5575, 6449, 682, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1320, 1528, 682, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7633, 4085, 322, 8, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7648, 4382, 322, 9, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7660, 4611, 322, 10, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7679, 4902, 322, 11, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7686, 5071, 322, 12, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7697, 5240, 322, 13, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2347, 2704, 511, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2377, 2738, 511, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1438, 1667, 576, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2001, 2310, 502, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (533, 621, 503, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4436, 5125, 504, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2613, 3011, 507, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4575, 5284, 509, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4641, 5363, 509, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15886, 9838, 1092, 1, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15890, 13577, 1092, 2, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15889, 439, 1092, 2, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15888, 413, 1092, 2, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15891, 13449, 1092, 3, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15893, 1087, 1092, 3, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15892, 13581, 1092, 3, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15894, 12962, 1092, 4, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15895, 11771, 1092, 4, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15897, 9083, 1092, 5, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15896, 9157, 1092, 5, 102);
INSERT INTO 'dancespublicationsmap' VALUES (16114, 14445, 1107, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6834, 7502, 788, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6818, 7483, 788, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6861, 7535, 788, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6757, 7405, 788, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9589, 8219, 346, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9590, 8220, 346, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9591, 8221, 346, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9592, 8222, 346, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9593, 8223, 346, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9594, 8224, 346, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9595, 8225, 346, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9596, 8226, 346, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9597, 8227, 346, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9598, 8228, 346, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9599, 8229, 346, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9600, 8230, 346, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9601, 8231, 346, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9772, 8404, 347, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9773, 8405, 347, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9780, 8412, 347, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9774, 8406, 347, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9775, 8407, 347, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9776, 8408, 347, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9777, 8409, 347, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9778, 8410, 347, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9779, 8411, 347, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10582, 9275, 525, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10583, 9276, 525, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10584, 9277, 525, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10922, 9623, 645, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10923, 9624, 645, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5592, 6469, 240, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5904, 6840, 613, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15898, 1465, 1092, 5, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15900, 11512, 1092, 6, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15899, 10016, 1092, 6, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15901, 10433, 1092, 7, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15903, 12793, 1092, 8, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15902, 9853, 1092, 8, 102);
INSERT INTO 'dancespublicationsmap' VALUES (12295, 11242, 898, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12296, 11243, 898, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12297, 11244, 898, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12298, 11245, 898, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12981, 11760, 949, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12982, 10270, 949, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12984, 12061, 949, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12985, 8709, 949, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12986, 12062, 949, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12987, 12063, 949, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12988, 12064, 949, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12989, 12065, 949, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12990, 12066, 949, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12991, 9486, 949, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12992, 12067, 949, 29, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12993, 9484, 949, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12994, 9740, 949, 31, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12995, 12068, 949, 32, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15415, 13946, 1058, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15416, 13947, 1058, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15417, 13948, 1058, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15418, 13949, 1058, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15419, 13950, 1058, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15420, 13951, 1058, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15421, 13952, 1058, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15422, 13953, 1058, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15423, 13954, 1058, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15424, 13955, 1058, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15425, 13956, 1058, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15426, 13957, 1058, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15427, 13958, 1058, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15428, 7611, 1058, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2818, 3243, 94, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (710, 829, 238, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1611, 1871, 518, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6250, 7246, 518, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1084, 1258, 193, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9503, 1657, 722, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12427, 11350, 909, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9504, 4994, 722, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9505, 5069, 722, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9506, 5940, 722, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9507, 4880, 722, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9508, 7163, 722, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9509, 288, 722, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9510, 2505, 722, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9511, 5570, 722, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9512, 6418, 722, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (228, 268, 207, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1194, 1382, 207, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11842, 10776, 821, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10405, 9088, 434, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2012, 2321, 207, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2439, 2813, 207, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7391, 387, 763, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7392, 485, 763, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10406, 9089, 434, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7393, 695, 763, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7394, 708, 763, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7395, 1232, 763, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7396, 1429, 763, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7397, 6236, 763, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7398, 1566, 763, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12584, 11611, 924, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12585, 11612, 924, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12586, 11613, 924, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12587, 11614, 924, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12588, 11615, 924, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12589, 11616, 924, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12590, 11618, 924, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12591, 11619, 924, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12592, 11620, 924, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6718, 7362, 790, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9987, 8602, 377, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10255, 8874, 410, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (985, 1140, 578, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6098, 7070, 578, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (284, 330, 579, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5763, 6673, 579, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5151, 5958, 579, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10256, 8875, 410, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10257, 8876, 410, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10258, 8877, 410, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6927, 7568, 802, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6928, 7576, 802, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6929, 7577, 802, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6930, 7578, 802, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11229, 10068, 692, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2542, 2931, 92, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4823, 5582, 556, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12952, 12035, 948, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12951, 8734, 948, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12012, 10975, 854, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12013, 10513, 854, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12014, 10804, 854, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12015, 10976, 854, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12911, 11956, 945, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12912, 11957, 945, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12913, 11958, 945, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12914, 11959, 945, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12915, 11960, 945, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12916, 11961, 945, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12917, 11962, 945, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12918, 11963, 945, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12919, 11964, 945, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12920, 11966, 945, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12921, 11967, 945, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12922, 11965, 945, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14320, 12417, 989, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (845, 978, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (850, 983, 49, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8648, 8127, 302, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8649, 8128, 302, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8650, 8129, 302, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8651, 8130, 302, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8652, 8131, 302, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8653, 8132, 302, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8654, 8133, 302, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12547, 11567, 921, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12548, 11568, 921, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12549, 11569, 921, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10259, 8878, 410, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10260, 8879, 410, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10261, 8880, 410, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12304, 11251, 898, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12077, 11040, 849, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12078, 11041, 849, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12079, 11042, 849, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12080, 11043, 849, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12081, 11044, 849, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12082, 11045, 849, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12083, 11046, 849, 32, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12084, 11047, 849, 33, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12085, 10937, 849, 35, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12086, 11048, 849, 36, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12087, 11049, 849, 37, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12088, 11050, 849, 38, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12089, 11051, 849, 39, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1113, 1291, 208, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1220, 1409, 208, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4977, 5759, 209, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12305, 11252, 898, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12306, 11253, 898, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12307, 11254, 898, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12308, 11255, 898, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12309, 11256, 898, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1423, 1648, 441, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5629, 6512, 558, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12562, 11580, 920, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12563, 11581, 920, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12564, 11582, 920, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12565, 10351, 920, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9482, 5064, 725, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9483, 4672, 725, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9484, 6873, 725, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9485, 3745, 725, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9486, 2472, 725, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16103, 14434, 1106, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5375, 6213, 449, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5864, 6794, 79, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10087, 8784, 395, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10088, 8785, 395, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10619, 9312, 530, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10924, 9625, 645, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10925, 9626, 645, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10926, 9627, 645, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10927, 9628, 645, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10928, 9629, 645, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10929, 9630, 645, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5252, 6072, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (10089, 8786, 395, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4584, 5299, 699, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6785, 7439, 791, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7411, 5616, 84, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7412, 3152, 84, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7413, 4047, 84, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7414, 3913, 84, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7415, 6205, 84, 16, 31);
INSERT INTO 'dancespublicationsmap' VALUES (7416, 6382, 84, 17, 31);
INSERT INTO 'dancespublicationsmap' VALUES (7417, 4130, 84, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7418, 3154, 84, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7419, 1659, 84, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7420, 3767, 84, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7421, 4102, 84, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7422, 5198, 84, 24, 31);
INSERT INTO 'dancespublicationsmap' VALUES (7423, 5282, 84, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7424, 5726, 84, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7425, 2045, 84, 27, 31);
INSERT INTO 'dancespublicationsmap' VALUES (7426, 6271, 84, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7427, 6443, 84, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7428, 6978, 84, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14775, 13230, 1016, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12828, 10052, 938, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12829, 8705, 938, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14267, 12588, 986, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14268, 12589, 986, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14269, 12591, 986, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14270, 12590, 986, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14271, 12592, 986, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14272, 12593, 986, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14273, 12594, 986, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14274, 12595, 986, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14275, 12596, 986, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14276, 12597, 986, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14277, 12598, 986, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14278, 12599, 986, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14279, 12600, 986, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14280, 12601, 986, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14281, 12602, 986, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14282, 10872, 986, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1989, 2297, 75, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2559, 2952, 489, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1583, 1842, 704, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11142, 9937, 666, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11143, 9938, 666, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11144, 9939, 666, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11145, 9940, 666, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11146, 8936, 666, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11147, 9941, 666, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11148, 9942, 666, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11149, 8850, 666, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11150, 9871, 666, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11151, 9943, 666, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11152, 8852, 666, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11153, 9933, 666, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (206, 239, 618, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5572, 6446, 618, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5576, 6451, 618, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5702, 6602, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5772, 6684, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2254, 2599, 619, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11174, 9905, 669, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11175, 9968, 669, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11176, 9842, 669, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11177, 9969, 669, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11178, 9970, 669, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15936, 12454, 1092, 24, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15937, 5355, 1092, 25, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15938, 5443, 1092, 26, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15939, 13466, 1092, 27, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15942, 9110, 1092, 27, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15941, 13467, 1092, 27, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15940, 8088, 1092, 27, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15943, 11369, 1092, 28, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15946, 5885, 1092, 29, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15945, 10381, 1092, 29, 102);
INSERT INTO 'dancespublicationsmap' VALUES (10086, 5170, 394, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10083, 8781, 394, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10084, 8782, 394, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11751, 10689, 833, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11752, 10690, 833, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11753, 10691, 833, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11754, 10692, 833, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11173, 9966, 382, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11192, 8088, 309, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11193, 9997, 309, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11194, 9998, 309, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11195, 9999, 309, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11196, 10000, 309, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11197, 10001, 309, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15944, 8970, 1092, 29, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15947, 10920, 1092, 30, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15949, 6104, 1092, 30, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15948, 6964, 1092, 30, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15951, 6210, 1092, 31, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15950, 6177, 1092, 31, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15953, 12792, 1092, 32, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15952, 8709, 1092, 32, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15954, 6393, 1092, 33, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15955, 9897, 1092, 34, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15956, 6768, 1092, 34, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15957, 13582, 1092, 35, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15958, 14322, 1092, 36, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15960, 7061, 1092, 37, 102);
INSERT INTO 'dancespublicationsmap' VALUES (9975, 8594, 376, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10262, 8881, 410, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10263, 8882, 410, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10264, 8883, 410, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10265, 8884, 410, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16089, 14411, 1091, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16094, 14416, 1091, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16095, 14417, 1091, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16093, 14415, 1091, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16343, 14709, 1124, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1133, 1314, 100, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2510, 2896, 679, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2981, 3426, 701, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17579, 2305, 1190, 1, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17580, 276, 1190, 2, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17581, 1447, 1190, 3, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17582, 2232, 1190, 4, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17583, 2671, 1190, 5, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17584, 6947, 1190, 7, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17585, 1840, 1190, 8, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17586, 2552, 1190, 6, 48);
INSERT INTO 'dancespublicationsmap' VALUES (17587, 3909, 1190, 9, 48);
INSERT INTO 'dancespublicationsmap' VALUES (11539, 10384, 794, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11540, 10385, 794, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11541, 8975, 794, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5395, 6241, 403, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (9923, 8553, 371, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9922, 8552, 371, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9917, 8547, 371, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9921, 8551, 371, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9916, 8546, 371, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9920, 8550, 371, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9918, 8548, 371, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9914, 8544, 371, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9913, 8543, 371, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9919, 8549, 371, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9915, 8545, 371, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6733, 7377, 786, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17069, 15111, 1159, 33, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17070, 15112, 1159, 35, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17071, 14366, 1159, 37, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17072, 15113, 1159, 39, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17073, 15114, 1159, 41, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17074, 15115, 1159, 43, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17075, 15116, 1159, 45, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17079, 14361, 1159, 47, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17085, 15118, 1159, 49, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17086, 15119, 1159, 51, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17082, 15120, 1159, 53, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17088, 15121, 1159, 55, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17089, 15122, 1159, 57, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17090, 15123, 1159, 58, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17091, 15124, 1159, 63, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10230, 3474, 818, 11, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10231, 5741, 818, 12, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10232, 6978, 818, 13, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10233, 1593, 818, 14, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10234, 670, 818, 15, 32);
INSERT INTO 'dancespublicationsmap' VALUES (5419, 6271, 47, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17200, 15233, 1165, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17202, 12880, 1165, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17201, 15234, 1165, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17203, 11797, 1165, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17204, 15235, 1165, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17205, 13547, 1165, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17206, 15236, 1165, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17207, 15237, 1165, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7838, 8038, 315, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7837, 8037, 315, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4738, 5483, 111, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2253, 2595, 526, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2111, 2431, 526, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17065, 15107, 1159, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17066, 15108, 1159, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1223, 1413, 155, 10, 40);
INSERT INTO 'dancespublicationsmap' VALUES (17067, 15109, 1159, 29, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17068, 15110, 1159, 31, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2793, 3213, 621, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4799, 5554, 621, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10769, 9465, 596, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10205, 5606, 817, 9, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10206, 6025, 817, 6, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10207, 6586, 817, 2, 33);
INSERT INTO 'dancespublicationsmap' VALUES (10190, 7122, 816, 10, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10164, 4188, 815, 16, 31);
INSERT INTO 'dancespublicationsmap' VALUES (10165, 5161, 815, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (12537, 11545, 914, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13967, 12362, 896, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13968, 12363, 896, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14400, 12706, 768, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14401, 12707, 768, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14402, 12708, 768, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14403, 12709, 768, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14404, 12710, 768, 32, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14405, 12711, 768, 34, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14406, 12712, 768, 35, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14407, 12713, 768, 36, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14408, 12714, 768, 37, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14409, 12715, 768, 38, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14410, 12716, 768, 40, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14411, 12717, 768, 42, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14412, 12718, 768, 43, 20);
INSERT INTO 'dancespublicationsmap' VALUES (534, 622, 117, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (238, 279, 139, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3012, 3462, 139, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7902, 40, 191, 1, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7903, 43, 191, 1, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7901, 15, 191, 1, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7904, 51, 191, 1, 104);
INSERT INTO 'dancespublicationsmap' VALUES (10770, 9466, 596, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10771, 9467, 596, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10774, 9469, 596, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10775, 9470, 596, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10776, 9471, 596, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10777, 9472, 596, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10773, 9090, 596, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21529, 5703, 1407, 153, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21516, 13648, 1407, 154, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21518, 5731, 1407, 154, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21534, 9110, 1407, 155, 101);
INSERT INTO 'dancespublicationsmap' VALUES (7905, 54, 191, 2, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7906, 55, 191, 2, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7907, 56, 191, 2, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7908, 76, 191, 3, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7909, 83, 191, 3, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7910, 89, 191, 3, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7911, 109, 191, 4, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7912, 116, 191, 4, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7913, 132, 191, 4, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7914, 140, 191, 4, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7915, 153, 191, 4, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7916, 183, 191, 5, 104);
INSERT INTO 'dancespublicationsmap' VALUES (21536, 5755, 1407, 155, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21535, 5741, 1407, 155, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21507, 5794, 1407, 157, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21520, 9561, 1407, 157, 101);
INSERT INTO 'dancespublicationsmap' VALUES (7917, 218, 191, 5, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7918, 219, 191, 5, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7921, 224, 191, 6, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7922, 221, 191, 6, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7920, 223, 191, 6, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7919, 222, 191, 6, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7929, 352, 191, 9, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7931, 355, 191, 9, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7930, 353, 191, 9, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7928, 335, 191, 9, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7935, 392, 191, 10, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7932, 373, 191, 10, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7933, 377, 191, 10, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7934, 389, 191, 10, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7937, 430, 191, 11, 104);
INSERT INTO 'dancespublicationsmap' VALUES (15224, 13821, 1046, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5956, 6901, 228, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7936, 410, 191, 11, 104);
INSERT INTO 'dancespublicationsmap' VALUES (21523, 5860, 1407, 158, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21525, 5885, 1407, 158, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21524, 10381, 1407, 158, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21527, 5889, 1407, 159, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21517, 5921, 1407, 160, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21528, 5915, 1407, 160, 101);
INSERT INTO 'dancespublicationsmap' VALUES (10765, 9461, 596, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10766, 9462, 596, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10767, 9463, 596, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10768, 9464, 596, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11230, 10069, 733, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11231, 10070, 733, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11232, 10071, 733, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11238, 9985, 733, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11237, 10016, 733, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11236, 9984, 733, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11235, 10074, 733, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11234, 10073, 733, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11239, 9350, 733, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11233, 10072, 733, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11243, 10075, 733, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11249, 10078, 733, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11240, 9874, 733, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11244, 9541, 733, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11245, 10076, 733, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11246, 10077, 733, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11247, 10010, 733, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11248, 10011, 733, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11250, 10079, 733, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11251, 10080, 733, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11241, 10008, 733, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11252, 10081, 733, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11253, 10082, 733, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11254, 10083, 733, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11255, 10084, 733, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11256, 10085, 733, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11257, 10086, 733, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11258, 10087, 733, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11242, 9897, 733, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11259, 10088, 733, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10772, 9468, 596, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21531, 5927, 1407, 161, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21514, 7267, 1407, 192, 101);
INSERT INTO 'dancespublicationsmap' VALUES (10778, 9473, 596, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10779, 9474, 596, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10780, 9475, 596, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10781, 9476, 596, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10782, 9477, 596, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10783, 9478, 596, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10784, 9479, 596, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10785, 9480, 596, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10786, 9481, 596, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10544, 9236, 519, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10545, 9237, 519, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10546, 9238, 519, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8665, 1210, 775, 94, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8666, 1244, 775, 96, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8667, 1280, 775, 98, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8668, 1304, 775, 99, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8669, 1478, 775, 101, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8670, 1562, 775, 102, 16);
INSERT INTO 'dancespublicationsmap' VALUES (17136, 15177, 1149, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17137, 15178, 1149, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17138, 15179, 1149, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17139, 13362, 1149, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17140, 13365, 1149, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17141, 15180, 1149, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15648, 3486, 1069, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15649, 8737, 1069, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15650, 11766, 1069, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15651, 12124, 1069, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15652, 11599, 1069, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15653, 7544, 1069, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15654, 13368, 1069, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15655, 11193, 1069, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13876, 5272, 962, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13877, 7935, 962, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7938, 442, 191, 11, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7939, 445, 191, 11, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7944, 522, 191, 12, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7940, 462, 191, 12, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7941, 480, 191, 12, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7942, 497, 191, 12, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7943, 521, 191, 12, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7948, 570, 191, 13, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7945, 541, 191, 13, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7946, 549, 191, 13, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7947, 559, 191, 13, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7949, 571, 191, 14, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7951, 584, 191, 14, 104);
INSERT INTO 'dancespublicationsmap' VALUES (6724, 7368, 778, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2451, 2826, 155, 3, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6725, 7369, 778, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2620, 3019, 639, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2388, 2752, 639, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2624, 3025, 639, 36, 20);
INSERT INTO 'dancespublicationsmap' VALUES (888, 1027, 639, 42, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2366, 2727, 639, 50, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7952, 588, 191, 14, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7950, 578, 191, 14, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7953, 594, 191, 15, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7955, 611, 191, 15, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7956, 633, 191, 15, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7954, 608, 191, 15, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7961, 658, 191, 16, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7957, 640, 191, 16, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7958, 650, 191, 16, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7959, 654, 191, 16, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7960, 655, 191, 16, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7962, 674, 191, 17, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7963, 682, 191, 17, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7966, 743, 191, 17, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7965, 741, 191, 17, 104);
INSERT INTO 'dancespublicationsmap' VALUES (1776, 2056, 277, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4957, 5736, 539, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6141, 7118, 588, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4763, 5512, 605, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15698, 14145, 1073, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15699, 14146, 1073, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15700, 14147, 1073, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2005, 2314, 491, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10321, 8952, 423, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10322, 8953, 423, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10323, 8954, 423, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10324, 8955, 423, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16284, 14212, 1118, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16285, 14217, 1118, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16286, 14219, 1118, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16287, 14622, 1118, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16288, 14623, 1118, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16289, 14624, 1118, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16290, 14625, 1118, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16291, 14626, 1118, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16294, 14629, 1118, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16296, 14631, 1118, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16297, 14632, 1118, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10113, 8806, 397, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5828, 6754, 138, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16325, 14690, 1088, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16326, 14691, 1088, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16331, 14696, 1088, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16332, 14697, 1088, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16333, 14698, 1088, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6116, 7090, 128, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6286, 389, 40, 80, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6287, 392, 40, 86, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6279, 140, 40, 88, 18);
INSERT INTO 'dancespublicationsmap' VALUES (1949, 2252, 138, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5925, 6864, 138, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5928, 6868, 138, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17452, 15517, 1182, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17453, 15518, 1182, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17454, 15519, 1182, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17455, 15520, 1182, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17456, 15521, 1182, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17457, 15522, 1182, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17458, 15523, 1182, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17459, 15524, 1182, 52, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17460, 15525, 1182, 53, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14777, 13235, 1018, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14778, 13236, 1018, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14779, 13237, 1018, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14780, 13238, 1018, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4404, 5089, 700, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4437, 5126, 700, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5548, 6415, 695, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1885, 2177, 695, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5313, 6142, 595, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4829, 5589, 586, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5351, 6187, 260, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12440, 11362, 910, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12441, 11363, 910, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12442, 11364, 910, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14704, 13081, 1009, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14703, 2254, 1009, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (252, 295, 670, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (721, 841, 670, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (732, 853, 670, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5857, 6787, 670, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6067, 7035, 670, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7848, 8044, 297, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7847, 8045, 297, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7849, 8046, 297, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7850, 8047, 297, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7851, 8048, 297, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7854, 8049, 297, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7855, 8050, 297, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7856, 2513, 297, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7857, 8051, 297, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7858, 8052, 297, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7859, 8053, 297, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7860, 2686, 297, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7861, 8054, 297, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7862, 8055, 297, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7863, 8056, 297, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7864, 8057, 297, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7866, 8058, 297, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7867, 8059, 297, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7868, 8060, 297, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7869, 8061, 297, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7870, 8062, 297, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7871, 8063, 297, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7872, 8064, 297, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7873, 8065, 297, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7874, 8066, 297, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7875, 8067, 297, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7876, 8068, 297, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7877, 8069, 297, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7900, 8085, 297, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14781, 13239, 1018, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14782, 13240, 1018, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14783, 13241, 1018, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14784, 13242, 1018, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14785, 13243, 1018, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7964, 738, 191, 17, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7967, 745, 191, 18, 104);
INSERT INTO 'dancespublicationsmap' VALUES (14846, 273, 1023, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14847, 5434, 1023, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14848, 3502, 1023, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14849, 5261, 1023, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14850, 3377, 1023, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14851, 6687, 1023, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14852, 12440, 1023, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14853, 12433, 1023, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14854, 6563, 1023, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14855, 5836, 1023, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14856, 765, 1023, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14857, 9747, 1023, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14858, 13333, 1023, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14859, 13334, 1023, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14860, 13335, 1023, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14861, 9752, 1023, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14862, 9750, 1023, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14863, 7438, 1023, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14864, 7385, 1023, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14865, 9584, 1023, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14866, 9571, 1023, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14867, 9745, 1023, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14868, 9573, 1023, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14869, 9572, 1023, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14870, 9579, 1023, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14871, 9581, 1023, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14872, 12434, 1023, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14873, 12442, 1023, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14874, 12439, 1023, 49, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14875, 13336, 1023, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14876, 12430, 1023, 51, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14877, 12432, 1023, 52, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14878, 12435, 1023, 53, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14879, 13337, 1023, 54, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14880, 13338, 1023, 55, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14881, 13339, 1023, 56, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14882, 13340, 1023, 57, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14883, 13341, 1023, 58, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14884, 13342, 1023, 59, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14885, 13343, 1023, 60, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14886, 13344, 1023, 61, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14887, 13345, 1023, 62, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14888, 13346, 1023, 63, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14889, 13347, 1023, 64, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14890, 13348, 1023, 65, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14891, 13349, 1023, 66, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14892, 13350, 1023, 67, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16259, 14574, 1115, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12171, 11118, 886, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12172, 11119, 886, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12173, 11120, 886, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12174, 11121, 886, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12175, 11122, 886, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14046, 12019, 977, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14047, 12437, 977, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14048, 12438, 977, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14049, 12439, 977, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10491, 5307, 499, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10492, 1650, 499, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10493, 9178, 499, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10494, 9185, 499, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10495, 9186, 499, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10496, 9187, 499, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10497, 9188, 499, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10498, 9189, 499, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10499, 9190, 499, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3773, 4342, 135, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12669, 11702, 928, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12670, 11684, 928, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1352, 1563, 162, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4604, 5320, 85, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5858, 6788, 127, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (803, 934, 50, 8, 18);
INSERT INTO 'dancespublicationsmap' VALUES (1733, 2004, 50, 14, 18);
INSERT INTO 'dancespublicationsmap' VALUES (1867, 2156, 50, 15, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2282, 2631, 50, 18, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16351, 578, 1125, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16357, 819, 1125, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16369, 2004, 1125, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16370, 2156, 1125, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16371, 2350, 1125, 25, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16372, 2419, 1125, 26, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16373, 2504, 1125, 27, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16376, 2781, 1125, 30, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17232, 15274, 1169, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1126, 1305, 245, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2423, 2795, 245, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6020, 6979, 245, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3448, 3971, 245, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3757, 4321, 245, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (528, 616, 269, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3541, 4074, 269, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5149, 5956, 549, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7968, 751, 191, 18, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7969, 753, 191, 18, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7970, 754, 191, 18, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7971, 760, 191, 18, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7976, 794, 191, 19, 104);
INSERT INTO 'dancespublicationsmap' VALUES (12190, 11137, 890, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12191, 11138, 890, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12192, 11139, 890, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12193, 11140, 890, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12194, 11141, 890, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12195, 11142, 890, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12196, 11143, 890, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (271, 317, 533, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1586, 1845, 533, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (988, 1143, 727, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15374, 13918, 1056, 51, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15375, 13919, 1056, 55, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12197, 11144, 890, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12198, 11145, 890, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12199, 11146, 890, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3226, 3715, 195, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1728, 1999, 195, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1635, 1897, 708, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10694, 9371, 559, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10695, 9372, 559, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10696, 4819, 559, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10697, 9373, 559, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10698, 9374, 559, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10699, 9375, 559, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10700, 9376, 559, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10701, 9377, 559, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10702, 9378, 559, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10703, 9379, 559, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3493, 4023, 90, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6478, 3876, 90, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3524, 4057, 90, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12184, 11131, 887, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12185, 11132, 887, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12186, 11133, 887, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12187, 11134, 887, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12188, 11135, 887, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12189, 11136, 887, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (280, 326, 233, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5691, 6589, 233, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3546, 4079, 233, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (766, 892, 517, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (841, 973, 597, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5379, 6218, 597, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6284, 323, 221, 5, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6362, 1838, 221, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6407, 2886, 221, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6476, 3854, 221, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6468, 3732, 222, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6404, 2757, 223, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6292, 519, 225, 5, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6489, 4018, 225, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6378, 2170, 226, 0, 31);
INSERT INTO 'dancespublicationsmap' VALUES (277, 323, 227, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (445, 519, 227, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5229, 6048, 227, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (790, 919, 227, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (852, 985, 227, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5453, 6309, 227, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1580, 1838, 227, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3240, 3732, 227, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3488, 4018, 227, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9502, 5535, 730, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15808, 10428, 1083, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15809, 13754, 1083, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15810, 13625, 1083, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15811, 14231, 1083, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15812, 14232, 1083, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15813, 14233, 1083, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15814, 14234, 1083, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15815, 13068, 1083, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15816, 14235, 1083, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15817, 14236, 1083, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15818, 13765, 1083, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15819, 14237, 1083, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15820, 10545, 1083, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15821, 14238, 1083, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13985, 12421, 967, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13986, 12314, 967, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13987, 12318, 967, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13988, 12326, 967, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13989, 12367, 967, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13990, 12372, 967, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13991, 12377, 967, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13992, 12422, 967, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13993, 12387, 967, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13994, 12388, 967, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13995, 12395, 967, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13996, 12423, 967, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13997, 12410, 967, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13998, 7000, 967, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (448, 524, 101, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (561, 653, 101, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14508, 12846, 995, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14509, 12847, 995, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14510, 12849, 995, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14511, 12850, 995, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14512, 12851, 995, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14513, 12852, 995, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14514, 12853, 995, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14515, 12854, 995, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14516, 12855, 995, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14517, 12856, 995, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14518, 12857, 995, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14519, 12858, 995, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14520, 12859, 995, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14521, 12860, 995, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14522, 12861, 995, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14523, 12862, 995, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14524, 12863, 995, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14525, 12864, 995, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14526, 12865, 995, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14527, 12848, 995, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2059, 2374, 563, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3651, 4197, 563, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3729, 4287, 563, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3272, 3770, 514, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5177, 5986, 514, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3626, 4170, 514, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5129, 5929, 514, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1577, 1833, 514, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1567, 1821, 514, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5328, 6162, 514, 29, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14992, 11786, 1033, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14994, 10947, 1033, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14995, 10948, 1033, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14996, 11787, 1033, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14997, 11788, 1033, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14998, 11791, 1033, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (796, 927, 521, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5124, 5924, 262, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2091, 2411, 137, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14050, 12440, 977, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3259, 3754, 234, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3777, 4346, 552, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5331, 6166, 552, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7010, 3152, 806, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (2860, 17261, 515, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14051, 12441, 977, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5859, 6789, 521, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (443, 517, 521, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14222, 9220, 983, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14223, 7267, 983, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16509, 1148, 1132, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16510, 14722, 1132, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16511, 14723, 1132, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16512, 14724, 1132, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16513, 14725, 1132, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16514, 14726, 1132, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16515, 5451, 1132, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16526, 14727, 1132, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9879, 8509, 368, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9895, 8525, 369, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9896, 8526, 369, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9897, 8527, 369, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9912, 8542, 370, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15079, 13717, 1032, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15080, 13718, 1032, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15081, 13719, 1032, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (569, 662, 50, 5, 18);
INSERT INTO 'dancespublicationsmap' VALUES (1496, 1733, 50, 12, 18);
INSERT INTO 'dancespublicationsmap' VALUES (1544, 1793, 50, 13, 18);
INSERT INTO 'dancespublicationsmap' VALUES (497, 578, 51, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (1181, 1368, 51, 8, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3124, 3595, 51, 18, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3233, 3723, 51, 21, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16527, 14728, 1132, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3627, 4171, 513, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (408, 475, 513, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (613, 716, 513, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (340, 395, 513, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12895, 11940, 943, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12887, 11533, 943, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12888, 8837, 943, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2938, 3379, 512, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3721, 4276, 512, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5159, 5967, 512, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3796, 4368, 512, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3184, 3663, 512, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3710, 4264, 512, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3698, 4249, 512, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12896, 11941, 943, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12889, 8833, 943, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12890, 7243, 943, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12897, 11942, 943, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12891, 8838, 943, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12898, 11943, 943, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12899, 11944, 943, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12892, 8832, 943, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12900, 11945, 943, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12893, 8836, 943, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12894, 8840, 943, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7972, 769, 191, 19, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7973, 773, 191, 19, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7975, 779, 191, 19, 104);
INSERT INTO 'dancespublicationsmap' VALUES (6877, 2250, 799, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6878, 6359, 799, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6879, 1792, 799, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6880, 5658, 799, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6881, 2166, 799, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6882, 1478, 799, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6883, 4325, 799, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6884, 3562, 799, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6885, 862, 799, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6886, 2498, 799, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6887, 6233, 799, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6888, 5222, 799, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6889, 6182, 799, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6890, 5376, 799, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6891, 2682, 799, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6892, 1615, 799, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6893, 608, 799, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6894, 2820, 799, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6895, 1931, 799, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6896, 5964, 799, 25, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6897, 1562, 799, 26, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6898, 5847, 799, 27, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6899, 3237, 799, 28, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6900, 588, 799, 29, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6901, 2044, 799, 30, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6902, 5641, 799, 31, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7072, 6539, 807, 33, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7073, 222, 807, 34, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7074, 6518, 807, 35, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7075, 6957, 807, 36, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7148, 5522, 810, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7149, 2747, 810, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7150, 373, 810, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7151, 2962, 810, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7152, 3743, 810, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7153, 4358, 810, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7154, 5208, 810, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7155, 4407, 810, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7156, 4890, 810, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7157, 3659, 810, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7158, 4511, 810, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7159, 116, 810, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7162, 4336, 810, 103, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7163, 1579, 810, 104, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7164, 2389, 810, 105, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7165, 2910, 810, 106, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7166, 3594, 810, 107, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7167, 2972, 810, 108, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7168, 4725, 810, 109, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7169, 4744, 810, 110, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7176, 4433, 810, 117, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7177, 6981, 810, 118, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7178, 3537, 810, 119, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7179, 6471, 810, 120, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7180, 5539, 810, 121, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7181, 3435, 810, 122, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7182, 223, 810, 123, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7236, 4935, 812, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7237, 4558, 812, 25, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7238, 4959, 812, 26, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7239, 1776, 812, 27, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7240, 877, 812, 28, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7241, 6489, 812, 29, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7242, 5858, 812, 30, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7243, 5713, 812, 31, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7244, 5519, 812, 32, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7245, 5982, 812, 33, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7246, 3558, 812, 34, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7247, 4563, 812, 35, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7248, 301, 812, 36, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7337, 6368, 711, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7338, 4046, 711, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7339, 2600, 711, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7340, 3326, 711, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7341, 3165, 711, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7342, 442, 711, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7343, 4404, 711, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7344, 895, 711, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7345, 5734, 711, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7346, 2501, 711, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7347, 4894, 711, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7380, 4720, 718, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7381, 6386, 718, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7382, 4477, 718, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7383, 6734, 718, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11400, 9105, 781, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11401, 9106, 781, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11402, 9107, 781, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11403, 9108, 781, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11404, 9109, 781, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11405, 9110, 781, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11406, 9111, 781, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11407, 5209, 781, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11408, 1473, 781, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11409, 9559, 781, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17016, 10653, 1158, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17017, 159, 1158, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17018, 10787, 1158, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17019, 10788, 1158, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17020, 10789, 1158, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17021, 10790, 1158, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17022, 10791, 1158, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17023, 10792, 1158, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17024, 10793, 1158, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17025, 10794, 1158, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17026, 11367, 1158, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17027, 11368, 1158, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17028, 11369, 1158, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17029, 11370, 1158, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17030, 11371, 1158, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17031, 11372, 1158, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17032, 11373, 1158, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17033, 11374, 1158, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17034, 11375, 1158, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17035, 11376, 1158, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17036, 11769, 1158, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17037, 9787, 1158, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17038, 6964, 1158, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17039, 11770, 1158, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17040, 11771, 1158, 25, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17041, 11772, 1158, 26, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17042, 11773, 1158, 27, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17043, 11763, 1158, 28, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17044, 11543, 1158, 29, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17045, 9093, 1158, 30, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17046, 7061, 1158, 31, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17047, 11512, 1158, 32, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17048, 10663, 1158, 33, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17049, 10381, 1158, 34, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17050, 1087, 1158, 35, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17051, 5885, 1158, 36, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17052, 12454, 1158, 37, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17053, 10535, 1158, 38, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17054, 10433, 1158, 39, 14);
INSERT INTO 'dancespublicationsmap' VALUES (17055, 2039, 1158, 40, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7145, 7210, 809, 34, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7146, 4086, 809, 35, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7147, 6323, 809, 36, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7974, 778, 191, 19, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7979, 848, 191, 20, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7978, 819, 191, 20, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7977, 816, 191, 20, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7981, 877, 191, 21, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7980, 873, 191, 21, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7982, 887, 191, 21, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7985, 894, 191, 22, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7984, 893, 191, 22, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7986, 895, 191, 23, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7989, 905, 191, 23, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7987, 899, 191, 23, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7988, 902, 191, 23, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7992, 936, 191, 24, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7990, 909, 191, 24, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7991, 910, 191, 24, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7995, 980, 191, 25, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7994, 972, 191, 25, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7993, 964, 191, 25, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7999, 1018, 191, 26, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7998, 1017, 191, 26, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7996, 984, 191, 26, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7997, 985, 191, 26, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8004, 1060, 191, 27, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8000, 1019, 191, 27, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8001, 1020, 191, 27, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8002, 1024, 191, 27, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8003, 1034, 191, 27, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8009, 1215, 191, 28, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8005, 1100, 191, 28, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8006, 1154, 191, 28, 104);
INSERT INTO 'dancespublicationsmap' VALUES (16244, 14532, 1113, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16245, 14533, 1113, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16248, 14536, 1113, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16249, 14537, 1113, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (8007, 1163, 191, 28, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8008, 1210, 191, 28, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8010, 1218, 191, 28, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8015, 1246, 191, 29, 104);
INSERT INTO 'dancespublicationsmap' VALUES (16189, 7300, 1109, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11051, 9767, 658, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11052, 9768, 658, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11053, 9769, 658, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11054, 9770, 658, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11055, 7570, 658, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5260, 6084, 263, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (849, 982, 263, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2355, 2712, 263, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6319, 896, 263, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3505, 4035, 263, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3580, 4116, 263, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3676, 4226, 263, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6527, 4748, 263, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16190, 7301, 1109, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14729, 13106, 1011, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14730, 13107, 1011, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14731, 13108, 1011, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14732, 13109, 1011, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14733, 13110, 1011, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14734, 13111, 1011, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14735, 13112, 1011, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15033, 13273, 1024, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15034, 13606, 1024, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15035, 13609, 1024, 32, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15036, 13604, 1024, 34, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7478, 7639, 308, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5142, 5947, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (373, 435, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (426, 496, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (436, 509, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (527, 613, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (531, 619, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1570, 1824, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1975, 2283, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2919, 3359, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2998, 3445, 140, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14617, 13009, 1002, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14618, 13010, 1002, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1253, 1453, 197, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16928, 2585, 1150, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16929, 7999, 1150, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16930, 15019, 1150, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16931, 13276, 1150, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6979, 1296, 805, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6974, 6477, 805, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6975, 1018, 805, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6976, 2745, 805, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (16932, 15025, 1150, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6977, 4356, 805, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6978, 754, 805, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6980, 6763, 805, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6981, 5207, 805, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6982, 958, 805, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6983, 3972, 805, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6984, 5591, 805, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6985, 3722, 805, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6986, 738, 805, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (1285, 1489, 698, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (833, 965, 698, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1911, 2206, 698, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1982, 2290, 698, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1257, 1458, 698, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7470, 7625, 290, 1, 35);
INSERT INTO 'dancespublicationsmap' VALUES (1299, 1503, 445, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11410, 7654, 781, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6965, 3046, 804, 34, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6966, 6130, 804, 35, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6967, 4782, 804, 36, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7184, 2821, 811, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7185, 4752, 811, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7186, 7055, 811, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7187, 2367, 811, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7188, 6224, 811, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7189, 289, 811, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (273, 319, 698, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1293, 1497, 698, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2052, 2366, 698, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (404, 469, 698, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (345, 403, 698, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6931, 4441, 272, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6382, 2275, 272, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6932, 3268, 272, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6474, 3778, 272, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6417, 3054, 272, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6933, 4617, 272, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6318, 889, 272, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (770, 896, 272, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1269, 1473, 281, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3800, 4373, 73, 108, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3183, 3662, 73, 109, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6283, 281, 757, 3, 35);
INSERT INTO 'dancespublicationsmap' VALUES (1350, 1561, 757, 4, 35);
INSERT INTO 'dancespublicationsmap' VALUES (6373, 2032, 757, 5, 35);
INSERT INTO 'dancespublicationsmap' VALUES (2143, 2467, 757, 8, 35);
INSERT INTO 'dancespublicationsmap' VALUES (5871, 6803, 757, 10, 35);
INSERT INTO 'dancespublicationsmap' VALUES (5888, 6823, 281, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1970, 2278, 281, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2361, 2722, 281, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5217, 6035, 281, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (471, 551, 281, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (538, 629, 281, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7460, 7609, 303, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7465, 7618, 303, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7483, 5324, 303, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7637, 3779, 303, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7461, 7614, 304, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7484, 7646, 304, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7661, 7846, 304, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7680, 7865, 304, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7681, 7867, 304, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7452, 7592, 300, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7492, 1333, 300, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7534, 7722, 300, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7582, 7765, 300, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7593, 7773, 300, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7616, 7805, 300, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7621, 7809, 300, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7669, 7858, 300, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7798, 7995, 300, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7818, 7094, 300, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7447, 7579, 295, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7493, 7659, 295, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7497, 7673, 295, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7513, 7706, 295, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7580, 7759, 295, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7612, 7799, 295, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7618, 7806, 295, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7624, 7813, 295, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7650, 7832, 295, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7695, 7887, 295, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7718, 7898, 295, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7734, 7920, 295, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7790, 7982, 295, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7795, 7991, 295, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7800, 7996, 295, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14646, 13032, 1004, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14647, 13010, 1004, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14648, 13033, 1004, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14649, 13034, 1005, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14650, 13035, 1005, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14651, 13036, 1005, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14652, 13037, 1005, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14653, 13007, 1005, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14654, 13038, 1005, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14655, 13039, 1005, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14656, 13040, 1005, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14657, 13041, 1005, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14658, 13042, 1005, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14659, 13043, 1005, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14660, 13044, 1005, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14661, 13045, 1005, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14662, 9976, 1005, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14663, 10584, 1005, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8011, 1223, 191, 29, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8016, 1260, 191, 29, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8014, 8086, 191, 29, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8012, 1244, 191, 29, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8018, 1283, 191, 30, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8019, 1296, 191, 30, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8020, 1348, 191, 30, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8021, 1358, 191, 30, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8022, 1366, 191, 30, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8017, 1280, 191, 30, 104);
INSERT INTO 'dancespublicationsmap' VALUES (15502, 14018, 1062, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15503, 13367, 1062, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15103, 13740, 1039, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5216, 6034, 276, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3158, 3630, 276, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3476, 4001, 276, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3592, 4131, 276, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3614, 4157, 276, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6425, 3200, 276, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4760, 5507, 276, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14347, 12655, 992, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14348, 12656, 992, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14349, 12657, 992, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14350, 12658, 992, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14351, 12659, 992, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14352, 9073, 992, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14353, 9841, 992, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14354, 10325, 992, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14355, 10930, 992, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14356, 11230, 992, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14357, 11804, 992, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14358, 12275, 992, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14359, 12582, 992, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14360, 12660, 992, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5852, 6781, 635, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2369, 2730, 635, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2856, 3285, 635, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6214, 7207, 635, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3333, 3842, 635, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5017, 5803, 635, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5033, 5819, 635, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (418, 487, 109, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5344, 6180, 109, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2054, 2368, 109, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2929, 3370, 109, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2017, 2326, 705, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4150, 4785, 705, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5050, 5840, 705, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14584, 12984, 1000, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14585, 12985, 1000, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14586, 12986, 1000, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14587, 12987, 1000, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14588, 12988, 1000, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14589, 12989, 1000, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14590, 12990, 1000, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14591, 12991, 1000, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14592, 12992, 1000, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14593, 12994, 1000, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14594, 12995, 1000, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14595, 12993, 1000, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14286, 12606, 987, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14287, 12607, 987, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14289, 12608, 987, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14288, 12609, 987, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14290, 12610, 987, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14291, 12611, 987, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14292, 12612, 987, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14293, 12613, 987, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1254, 1455, 283, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (504, 585, 283, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1600, 1860, 283, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6255, 7251, 283, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4675, 5403, 199, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3540, 4073, 199, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3635, 4179, 199, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5862, 6792, 199, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5697, 6597, 199, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4232, 4888, 199, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4119, 4746, 199, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5701, 6601, 199, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3323, 3829, 199, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1562, 1816, 199, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5645, 6532, 199, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7443, 7359, 287, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7464, 7617, 287, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7469, 5588, 287, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7491, 6244, 287, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7738, 7925, 287, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7803, 8000, 287, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7808, 8006, 287, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7923, 245, 191, 6, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7924, 289, 191, 7, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7925, 301, 191, 7, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7926, 312, 191, 7, 104);
INSERT INTO 'dancespublicationsmap' VALUES (7927, 314, 191, 8, 104);
INSERT INTO 'dancespublicationsmap' VALUES (13503, 4662, 954, 133, 102);
INSERT INTO 'dancespublicationsmap' VALUES (5199, 6014, 165, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2958, 3401, 165, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7551, 2761, 324, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7563, 2904, 324, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14376, 12695, 724, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (355, 414, 141, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (421, 491, 141, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5657, 6550, 714, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (405, 472, 714, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3464, 3987, 714, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13505, 4679, 954, 133, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13504, 4663, 954, 133, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13728, 4720, 954, 134, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13737, 7286, 954, 134, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13799, 10653, 954, 134, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13506, 4725, 954, 135, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13509, 4755, 954, 135, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13508, 4744, 954, 135, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13510, 4759, 954, 135, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13507, 4728, 954, 135, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13512, 4784, 954, 136, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13739, 4796, 954, 136, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13511, 4765, 954, 136, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13513, 4782, 954, 136, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13515, 4804, 954, 137, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13514, 4803, 954, 137, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13517, 4806, 954, 137, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13516, 4805, 954, 137, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13519, 4830, 954, 138, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13518, 4827, 954, 138, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13826, 4808, 954, 138, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13521, 4862, 954, 139, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13827, 9560, 954, 139, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13520, 4844, 954, 139, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13725, 4857, 954, 139, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13522, 4864, 954, 139, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13523, 4865, 954, 140, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13524, 4871, 954, 140, 102);
INSERT INTO 'dancespublicationsmap' VALUES (5116, 5914, 248, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5383, 6225, 248, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1599, 1859, 248, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2802, 3223, 248, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12496, 11422, 916, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12497, 11423, 916, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12498, 11424, 916, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12499, 11425, 916, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12500, 11426, 916, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12501, 8671, 916, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12502, 10574, 916, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5068, 5860, 53, 9, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5265, 6091, 53, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (1525, 1768, 53, 5, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5787, 6701, 53, 11, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5799, 6720, 53, 21, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2046, 2357, 53, 22, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2925, 3365, 53, 19, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3266, 3762, 53, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3702, 4256, 53, 13, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4693, 5422, 53, 6, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4777, 5529, 53, 7, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2042, 2353, 53, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2022, 2332, 53, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2014, 2323, 53, 8, 18);
INSERT INTO 'dancespublicationsmap' VALUES (15279, 6087, 1050, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15280, 4439, 1050, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15281, 13858, 1050, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1644, 1908, 55, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2839, 3267, 55, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3558, 4092, 55, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12238, 11184, 894, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12239, 11185, 894, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12240, 11186, 894, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12241, 11187, 894, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12242, 11188, 894, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12243, 11189, 894, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12244, 11190, 894, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (8024, 1372, 191, 31, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8025, 1375, 191, 31, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8026, 1376, 191, 31, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8023, 1368, 191, 31, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8028, 1388, 191, 32, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8029, 1405, 191, 32, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8027, 1382, 191, 32, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8032, 1437, 191, 33, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8030, 1428, 191, 33, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8034, 1466, 191, 33, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8033, 1446, 191, 33, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8031, 1431, 191, 33, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8036, 1478, 191, 34, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8037, 1480, 191, 34, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8035, 1469, 191, 34, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8040, 1544, 191, 35, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8038, 1501, 191, 35, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8039, 1521, 191, 35, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8044, 1588, 191, 36, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8041, 1562, 191, 36, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8043, 1586, 191, 36, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8042, 1578, 191, 36, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8046, 1615, 191, 37, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8049, 1677, 191, 37, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8048, 1647, 191, 37, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8047, 1624, 191, 37, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8045, 1582, 191, 37, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8050, 1733, 191, 38, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8055, 1774, 191, 38, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8051, 1758, 191, 38, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8052, 1762, 191, 38, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8053, 1768, 191, 38, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8054, 1773, 191, 38, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8059, 1780, 191, 39, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8057, 1776, 191, 39, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8060, 1782, 191, 39, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8061, 1783, 191, 39, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8056, 1775, 191, 39, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8058, 1777, 191, 39, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8063, 1790, 191, 40, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8066, 1834, 191, 40, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8067, 1838, 191, 40, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8062, 1786, 191, 40, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8064, 1792, 191, 40, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8065, 1799, 191, 40, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8069, 1864, 191, 41, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8068, 1857, 191, 41, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8070, 1866, 191, 41, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8072, 1884, 191, 42, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8073, 1891, 191, 42, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8071, 1883, 191, 42, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8077, 1965, 191, 43, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8074, 1903, 191, 43, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8075, 1909, 191, 43, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8076, 1931, 191, 43, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8080, 1998, 191, 44, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8079, 1990, 191, 44, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8078, 1966, 191, 44, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8082, 2024, 191, 44, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8081, 2004, 191, 44, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8085, 2044, 191, 45, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8083, 2030, 191, 45, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8087, 2084, 191, 45, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8088, 6957, 191, 45, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8086, 2063, 191, 45, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8084, 2042, 191, 45, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8092, 2153, 191, 46, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8093, 2156, 191, 46, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8089, 2136, 191, 46, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8090, 2140, 191, 46, 104);
INSERT INTO 'dancespublicationsmap' VALUES (507, 589, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5646, 6535, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1905, 2197, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1918, 2216, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5838, 6765, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2147, 2473, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3103, 3573, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3155, 3627, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3755, 4319, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3798, 4370, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4916, 5689, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4956, 5735, 481, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (9949, 8574, 374, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9950, 8575, 374, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9951, 8576, 374, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9952, 8577, 374, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9954, 8578, 374, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9953, 3252, 374, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (8091, 868, 191, 46, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8094, 2158, 191, 47, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8095, 2166, 191, 47, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8096, 2189, 191, 47, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8098, 2250, 191, 48, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8097, 2242, 191, 48, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8100, 2263, 191, 48, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8099, 2257, 191, 48, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8101, 2294, 191, 49, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8102, 2302, 191, 49, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8103, 2321, 191, 49, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8105, 2332, 191, 50, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8104, 2323, 191, 50, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8106, 2349, 191, 50, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8107, 2350, 191, 50, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8110, 2367, 191, 51, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8108, 2353, 191, 51, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8109, 2360, 191, 51, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8111, 2389, 191, 52, 104);
INSERT INTO 'dancespublicationsmap' VALUES (1958, 2264, 547, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3315, 3821, 547, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (893, 1036, 547, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (8115, 2415, 191, 52, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8113, 2408, 191, 52, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8112, 2394, 191, 52, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8114, 2409, 191, 52, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8116, 2419, 191, 53, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8118, 2428, 191, 53, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8117, 2421, 191, 53, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8120, 2436, 191, 54, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8119, 2431, 191, 54, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8122, 2469, 191, 54, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8121, 2437, 191, 54, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8125, 2498, 191, 55, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8126, 2501, 191, 55, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8123, 2494, 191, 55, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8124, 2495, 191, 55, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8128, 2506, 191, 56, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8127, 2504, 191, 56, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8129, 2556, 191, 56, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8132, 2600, 191, 57, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8130, 2562, 191, 57, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8131, 2593, 191, 57, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8133, 2631, 191, 57, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8135, 2645, 191, 58, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8137, 2682, 191, 58, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8138, 2700, 191, 58, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8134, 2644, 191, 58, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8136, 2661, 191, 58, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8143, 2747, 191, 59, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8139, 2713, 191, 59, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8140, 2725, 191, 59, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8141, 2742, 191, 59, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8142, 2745, 191, 59, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8144, 2777, 191, 60, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8146, 2807, 191, 60, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8145, 2781, 191, 60, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8148, 2820, 191, 61, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8147, 2813, 191, 61, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8165, 2957, 191, 64, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8164, 2956, 191, 64, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8163, 2947, 191, 64, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8162, 8087, 191, 64, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8170, 2979, 191, 65, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8169, 2978, 191, 65, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8168, 2972, 191, 65, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8166, 2962, 191, 65, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8167, 2970, 191, 65, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8174, 3057, 191, 66, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8173, 3046, 191, 66, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8172, 3045, 191, 66, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8171, 3038, 191, 66, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8175, 3084, 191, 67, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8179, 3111, 191, 67, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8178, 3108, 191, 67, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8177, 3105, 191, 67, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8176, 3104, 191, 67, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8182, 3152, 191, 68, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8180, 3129, 191, 68, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8181, 3154, 191, 68, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8183, 3165, 191, 68, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8185, 3176, 191, 69, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8186, 3177, 191, 69, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8184, 3172, 191, 69, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8187, 3225, 191, 70, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8191, 3281, 191, 70, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8189, 3235, 191, 70, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8190, 3246, 191, 70, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8188, 3231, 191, 70, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8194, 3323, 191, 71, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8195, 3326, 191, 71, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8196, 3338, 191, 71, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8192, 3284, 191, 71, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8193, 3310, 191, 71, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8199, 3365, 191, 72, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8198, 3342, 191, 72, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8197, 3339, 191, 72, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8203, 3436, 191, 73, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8204, 3444, 191, 73, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8202, 3435, 191, 73, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8201, 3424, 191, 73, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8200, 3412, 191, 73, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8205, 3474, 191, 74, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8207, 3506, 191, 74, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8206, 3475, 191, 74, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8208, 3526, 191, 74, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8210, 3529, 191, 75, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8212, 3541, 191, 75, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8209, 3528, 191, 75, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8211, 3537, 191, 75, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8214, 3561, 191, 76, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8216, 3567, 191, 76, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8215, 3562, 191, 76, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8213, 3558, 191, 76, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8218, 3575, 191, 77, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8217, 3570, 191, 77, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8220, 3585, 191, 77, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8219, 3580, 191, 77, 104);
INSERT INTO 'dancespublicationsmap' VALUES (10029, 3577, 191, 77, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8225, 3601, 191, 78, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8226, 3607, 191, 78, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8221, 3588, 191, 78, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8224, 3595, 191, 78, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8223, 3594, 191, 78, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8222, 3589, 191, 78, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8229, 3615, 191, 79, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8228, 3611, 191, 79, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8227, 3609, 191, 79, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8231, 3617, 191, 79, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8230, 3616, 191, 79, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8236, 3635, 191, 80, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8232, 3620, 191, 80, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8233, 3623, 191, 80, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8234, 3625, 191, 80, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8235, 3631, 191, 80, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8237, 3636, 191, 81, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8241, 3659, 191, 81, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8239, 3638, 191, 81, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8240, 3656, 191, 81, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8238, 3637, 191, 81, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8244, 3685, 191, 82, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8243, 3678, 191, 82, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8245, 3695, 191, 82, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8242, 3672, 191, 82, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8247, 3710, 191, 83, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8248, 3711, 191, 83, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8246, 3701, 191, 83, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8250, 3723, 191, 84, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8249, 3722, 191, 84, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8253, 3729, 191, 84, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8251, 3725, 191, 84, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8254, 3737, 191, 84, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8252, 3730, 191, 84, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8255, 3735, 191, 85, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8256, 3743, 191, 85, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8257, 3748, 191, 85, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8258, 3759, 191, 85, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8261, 3774, 191, 86, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8259, 3762, 191, 86, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8260, 3769, 191, 86, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8262, 3775, 191, 86, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8265, 3788, 191, 87, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8263, 3783, 191, 87, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8264, 3786, 191, 87, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8268, 3829, 191, 88, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8266, 3789, 191, 88, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8267, 3802, 191, 88, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8269, 3834, 191, 88, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8270, 3859, 191, 88, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8275, 3915, 191, 89, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8271, 3862, 191, 89, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8272, 3887, 191, 89, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8273, 3888, 191, 89, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8274, 3912, 191, 89, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8280, 3938, 191, 90, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8281, 3940, 191, 90, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8279, 3934, 191, 90, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8278, 3932, 191, 90, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8277, 3931, 191, 90, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8276, 3921, 191, 90, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8284, 3963, 191, 91, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8283, 3953, 191, 91, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8285, 3972, 191, 91, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8282, 3941, 191, 91, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8286, 3980, 191, 92, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8287, 3986, 191, 92, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8290, 4046, 191, 93, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8288, 4015, 191, 93, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8289, 4032, 191, 93, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8293, 4068, 191, 94, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8299, 4144, 191, 95, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8297, 4106, 191, 95, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8298, 4126, 191, 95, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8333, 4491, 191, 102, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8334, 4499, 191, 102, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8332, 4484, 191, 102, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8385, 4968, 191, 113, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8384, 4894, 191, 113, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8386, 4998, 191, 114, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8389, 5040, 191, 115, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8388, 5033, 191, 115, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8387, 5028, 191, 115, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8391, 5099, 191, 115, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8390, 5065, 191, 115, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8393, 5136, 191, 116, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8392, 5111, 191, 116, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8396, 5207, 191, 117, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8397, 5208, 191, 117, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8395, 5200, 191, 117, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8394, 5198, 191, 117, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8399, 5223, 191, 118, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8400, 5239, 191, 118, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8398, 5222, 191, 118, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8401, 5243, 191, 118, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8404, 5308, 191, 119, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8402, 5260, 191, 119, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8403, 5296, 191, 119, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8408, 5345, 191, 120, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8406, 5326, 191, 120, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8405, 5310, 191, 120, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8407, 5330, 191, 120, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8409, 5347, 191, 121, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8414, 5398, 191, 121, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8422, 5462, 191, 124, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8424, 5480, 191, 124, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8423, 5463, 191, 124, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8498, 6359, 191, 141, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8499, 6362, 191, 142, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8503, 6391, 191, 142, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8501, 6380, 191, 142, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8500, 6373, 191, 142, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8502, 6382, 191, 142, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8504, 6406, 191, 143, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8505, 6407, 191, 143, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8553, 7173, 191, 156, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8555, 7182, 191, 157, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8554, 7180, 191, 157, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8556, 7188, 191, 157, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8558, 7210, 191, 157, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8557, 7189, 191, 157, 104);
INSERT INTO 'dancespublicationsmap' VALUES (22222, 18631, 1482, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22223, 18632, 1482, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22224, 18633, 1482, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21010, 18181, 1369, 49, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21011, 18182, 1369, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22383, 19141, 1488, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22373, 18946, 1488, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22374, 19134, 1488, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22375, 19135, 1488, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22376, 18941, 1488, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22377, 18956, 1488, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22378, 18655, 1488, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22379, 19136, 1488, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22384, 19137, 1488, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22380, 19138, 1488, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22381, 19139, 1488, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22382, 19140, 1488, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8506, 6420, 191, 143, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8509, 6518, 191, 144, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8507, 6448, 191, 144, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8508, 6471, 191, 144, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8510, 6523, 191, 144, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8512, 6539, 191, 145, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8511, 6532, 191, 145, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8513, 6552, 191, 145, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8516, 6577, 191, 146, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8519, 6658, 191, 146, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8518, 6634, 191, 146, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8517, 6599, 191, 146, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8515, 6575, 191, 146, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8514, 6566, 191, 146, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8522, 6711, 191, 147, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8521, 6710, 191, 147, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8520, 6701, 191, 147, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8523, 6712, 191, 147, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8528, 6797, 191, 148, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8527, 6763, 191, 148, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8524, 6721, 191, 148, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8525, 6736, 191, 148, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8526, 6756, 191, 148, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8529, 6800, 191, 149, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8530, 6817, 191, 149, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8531, 6848, 191, 150, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8532, 6885, 191, 151, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8535, 6981, 191, 152, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8534, 6978, 191, 152, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8533, 6897, 191, 152, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8536, 6995, 191, 152, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8537, 7037, 191, 153, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8541, 7073, 191, 153, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8540, 7068, 191, 153, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8539, 7055, 191, 153, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8538, 7042, 191, 153, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8545, 7109, 191, 154, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8544, 7105, 191, 154, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8542, 7090, 191, 154, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8543, 7093, 191, 154, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8547, 7120, 191, 155, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8548, 7139, 191, 155, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8549, 7143, 191, 155, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8546, 7111, 191, 155, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8551, 7152, 191, 156, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8552, 7172, 191, 156, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8550, 7147, 191, 156, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8777, 51, 74, 1, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8776, 43, 74, 1, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8774, 15, 74, 1, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8775, 40, 74, 1, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8780, 56, 74, 2, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8778, 54, 74, 2, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8779, 55, 74, 2, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8781, 76, 74, 3, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8782, 83, 74, 3, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8783, 89, 74, 3, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8788, 153, 74, 4, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8784, 109, 74, 4, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8787, 140, 74, 4, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8785, 116, 74, 4, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8786, 132, 74, 4, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8790, 218, 74, 5, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8789, 183, 74, 5, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8791, 219, 74, 5, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8794, 224, 74, 6, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8795, 221, 74, 6, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8796, 245, 74, 6, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8793, 223, 74, 6, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8792, 222, 74, 6, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8797, 289, 74, 7, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8799, 312, 74, 7, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8798, 301, 74, 7, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8800, 314, 74, 8, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8801, 335, 74, 9, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8802, 352, 74, 9, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8803, 353, 74, 9, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8808, 392, 74, 10, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8805, 373, 74, 10, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8807, 389, 74, 10, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8806, 377, 74, 10, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8804, 355, 74, 10, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8811, 442, 74, 11, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8812, 445, 74, 11, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8809, 410, 74, 11, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8810, 430, 74, 11, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8817, 522, 74, 12, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8816, 521, 74, 12, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8814, 480, 74, 12, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8813, 462, 74, 12, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8815, 497, 74, 12, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8818, 541, 74, 13, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8819, 549, 74, 13, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8823, 578, 74, 14, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8820, 559, 74, 14, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8824, 584, 74, 14, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8821, 570, 74, 14, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8828, 611, 74, 15, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8822, 571, 74, 15, 103);
INSERT INTO 'dancespublicationsmap' VALUES (22385, 98, 1489, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22386, 17802, 1489, 9, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22387, 782, 1489, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3447, 3970, 474, 65, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22370, 19035, 1370, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22371, 19034, 1370, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22372, 19132, 1370, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3527, 4060, 474, 66, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3595, 4134, 474, 67, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3622, 4166, 474, 68, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8825, 588, 74, 15, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8826, 594, 74, 15, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8827, 608, 74, 15, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8829, 633, 74, 16, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8831, 650, 74, 16, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8830, 640, 74, 16, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8833, 655, 74, 17, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8835, 674, 74, 17, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8832, 654, 74, 17, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8834, 658, 74, 17, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8836, 682, 74, 18, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8838, 741, 74, 18, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8840, 745, 74, 18, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8837, 738, 74, 18, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8839, 743, 74, 18, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8842, 753, 74, 19, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8843, 754, 74, 19, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8841, 751, 74, 19, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8844, 760, 74, 19, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8847, 778, 74, 20, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8848, 779, 74, 20, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8849, 794, 74, 20, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8845, 769, 74, 20, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8846, 773, 74, 20, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8851, 819, 74, 21, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8850, 816, 74, 21, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8852, 848, 74, 21, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8853, 873, 74, 22, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8854, 877, 74, 22, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8855, 887, 74, 22, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8856, 893, 74, 23, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8857, 894, 74, 23, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8858, 895, 74, 24, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8859, 899, 74, 24, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8861, 905, 74, 24, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8860, 902, 74, 24, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8864, 936, 74, 25, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8863, 910, 74, 25, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8862, 909, 74, 25, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8865, 964, 74, 26, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8867, 980, 74, 26, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8866, 972, 74, 26, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8869, 985, 74, 27, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8868, 984, 74, 27, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8871, 1018, 74, 28, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8872, 1019, 74, 28, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8873, 1020, 74, 28, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8875, 1034, 74, 28, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8874, 1024, 74, 28, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8870, 1017, 74, 28, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8879, 1163, 74, 29, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8878, 1154, 74, 29, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8877, 1100, 74, 29, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8876, 1060, 74, 29, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8880, 1210, 74, 30, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8881, 1215, 74, 30, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8882, 1218, 74, 30, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8883, 1223, 74, 30, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8887, 1260, 74, 31, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8885, 8086, 74, 31, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8889, 1283, 74, 31, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8886, 1246, 74, 31, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8884, 1244, 74, 31, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8888, 1280, 74, 31, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8890, 1296, 74, 32, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8891, 1348, 74, 32, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8893, 1366, 74, 32, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8894, 1368, 74, 32, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8892, 1358, 74, 32, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8897, 1376, 74, 33, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8896, 1375, 74, 33, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8895, 1372, 74, 33, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8899, 1388, 74, 34, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8900, 1405, 74, 34, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8898, 1382, 74, 34, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8903, 1437, 74, 35, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8902, 1431, 74, 35, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8901, 1428, 74, 35, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8920, 1677, 74, 39, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8924, 1768, 74, 40, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8926, 1774, 74, 40, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8925, 1773, 74, 40, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8922, 1758, 74, 40, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8921, 1733, 74, 40, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8923, 1762, 74, 40, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8932, 1783, 74, 41, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8931, 1782, 74, 41, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8929, 1777, 74, 41, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8930, 1780, 74, 41, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8928, 1776, 74, 41, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8927, 1775, 74, 41, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8937, 1834, 74, 42, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8935, 1792, 74, 42, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8938, 1838, 74, 42, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8933, 1786, 74, 42, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8934, 1790, 74, 42, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8936, 1799, 74, 42, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8941, 1866, 74, 43, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8940, 1864, 74, 43, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8939, 1857, 74, 43, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8944, 1891, 74, 44, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8942, 1883, 74, 44, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8943, 1884, 74, 44, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8946, 1909, 74, 45, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8948, 1965, 74, 45, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8945, 1903, 74, 45, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8947, 1931, 74, 45, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8952, 2004, 74, 46, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8949, 1966, 74, 46, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8950, 1990, 74, 46, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8951, 1998, 74, 46, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8953, 2024, 74, 46, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8954, 2030, 74, 47, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8955, 2042, 74, 47, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8957, 2063, 74, 47, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8959, 6957, 74, 47, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8956, 2044, 74, 47, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8958, 2084, 74, 47, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8963, 2153, 74, 48, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8961, 2140, 74, 48, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8960, 2136, 74, 48, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8964, 2156, 74, 48, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8962, 868, 74, 48, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8965, 2158, 74, 49, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8967, 2189, 74, 49, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8966, 2166, 74, 49, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8968, 2242, 74, 50, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8969, 2250, 74, 50, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8970, 2257, 74, 50, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8971, 2263, 74, 50, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8973, 2302, 74, 51, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8972, 2294, 74, 51, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8976, 2332, 74, 52, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8974, 2321, 74, 52, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8975, 2323, 74, 52, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8977, 2349, 74, 53, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8980, 2360, 74, 53, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8978, 2350, 74, 53, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8979, 2353, 74, 53, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8981, 2367, 74, 53, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8982, 2389, 74, 54, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8986, 2415, 74, 54, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8985, 2409, 74, 54, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8984, 2408, 74, 54, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8983, 2394, 74, 54, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8987, 2419, 74, 55, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8989, 2428, 74, 55, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8988, 2421, 74, 55, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8991, 2436, 74, 56, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8990, 2431, 74, 56, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8992, 2437, 74, 56, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8994, 2494, 74, 57, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8996, 2498, 74, 57, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8995, 2495, 74, 57, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8993, 2469, 74, 57, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8999, 2506, 74, 58, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8997, 2501, 74, 58, 103);
INSERT INTO 'dancespublicationsmap' VALUES (8998, 2504, 74, 58, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9002, 2593, 74, 59, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9001, 2562, 74, 59, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9000, 2556, 74, 59, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9005, 2644, 74, 60, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9003, 2600, 74, 60, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9004, 2631, 74, 60, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9006, 2645, 74, 61, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9008, 2682, 74, 61, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9007, 2661, 74, 61, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9009, 2700, 74, 61, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9014, 2747, 74, 62, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9013, 2745, 74, 62, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9011, 2725, 74, 62, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9012, 2742, 74, 62, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9010, 2713, 74, 62, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9015, 2777, 74, 63, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9017, 2807, 74, 63, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9016, 2781, 74, 63, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9019, 2820, 74, 64, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9018, 2813, 74, 64, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9023, 2878, 74, 65, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9021, 2822, 74, 65, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9020, 2821, 74, 65, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9024, 2903, 74, 65, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9022, 2868, 74, 65, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9027, 2918, 74, 66, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9025, 2910, 74, 66, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9030, 2925, 74, 66, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9029, 2924, 74, 66, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9028, 6477, 74, 66, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9026, 2916, 74, 66, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9032, 8087, 74, 67, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9031, 2934, 74, 67, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9035, 2957, 74, 67, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9034, 2956, 74, 67, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9033, 2947, 74, 67, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9036, 2962, 74, 68, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9040, 2979, 74, 68, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9039, 2978, 74, 68, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9038, 2972, 74, 68, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9037, 2970, 74, 68, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9043, 3046, 74, 69, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9042, 3045, 74, 69, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9041, 3038, 74, 69, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9044, 3057, 74, 69, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9049, 3111, 74, 70, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9048, 3108, 74, 70, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9047, 3105, 74, 70, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9046, 3104, 74, 70, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9045, 3084, 74, 70, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9051, 3154, 74, 71, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9053, 3165, 74, 71, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9052, 3152, 74, 71, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9050, 3129, 74, 71, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9054, 3172, 74, 72, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9055, 3176, 74, 72, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9056, 3177, 74, 72, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9057, 3225, 74, 73, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9058, 3231, 74, 73, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9059, 3235, 74, 73, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9060, 3246, 74, 73, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9061, 3281, 74, 73, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9064, 3323, 74, 74, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9066, 3338, 74, 74, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9062, 3284, 74, 74, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9063, 3310, 74, 74, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9065, 3326, 74, 74, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9069, 3365, 74, 75, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9068, 3342, 74, 75, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9067, 3339, 74, 75, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9070, 3412, 74, 76, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9073, 3436, 74, 76, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9071, 3424, 74, 76, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9072, 3435, 74, 76, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9075, 3474, 74, 77, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9074, 3444, 74, 77, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9076, 3475, 74, 78, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9077, 3506, 74, 78, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9079, 3528, 74, 78, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9078, 3526, 74, 78, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9081, 3537, 74, 79, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9082, 3541, 74, 79, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9080, 3529, 74, 79, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9084, 3561, 74, 80, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9085, 3562, 74, 80, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9086, 3567, 74, 80, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9083, 3558, 74, 80, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9087, 3570, 74, 81, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9090, 3585, 74, 81, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9089, 3580, 74, 81, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9088, 3575, 74, 81, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9092, 3589, 74, 82, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9091, 3588, 74, 82, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9096, 3607, 74, 82, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9095, 3601, 74, 82, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9094, 3595, 74, 82, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9093, 3594, 74, 82, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9097, 3609, 74, 83, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9098, 3611, 74, 83, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9101, 3617, 74, 83, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9100, 3616, 74, 83, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9099, 3615, 74, 83, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9106, 3635, 74, 84, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9104, 3625, 74, 84, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9105, 3631, 74, 84, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9103, 3623, 74, 84, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9102, 3620, 74, 84, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9111, 3659, 74, 85, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9110, 3656, 74, 85, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9107, 3636, 74, 85, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9108, 3637, 74, 85, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9109, 3638, 74, 85, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9115, 3695, 74, 86, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9112, 3672, 74, 86, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9113, 3678, 74, 86, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9114, 3685, 74, 86, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9117, 3710, 74, 87, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9118, 3711, 74, 87, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9116, 3701, 74, 87, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9121, 3725, 74, 88, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9120, 3723, 74, 88, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9123, 3729, 74, 88, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9122, 3730, 74, 88, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9124, 3737, 74, 88, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9119, 3722, 74, 88, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9127, 3748, 74, 89, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9125, 3735, 74, 89, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9126, 3743, 74, 89, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9128, 3759, 74, 89, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9129, 3762, 74, 90, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9131, 3774, 74, 90, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9130, 3769, 74, 90, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9132, 3775, 74, 90, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9134, 3786, 74, 91, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9133, 3783, 74, 91, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9135, 3788, 74, 91, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9139, 3834, 74, 92, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9140, 3859, 74, 92, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9138, 3829, 74, 92, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9137, 3802, 74, 92, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9136, 3789, 74, 92, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9141, 3862, 74, 93, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9144, 3912, 74, 93, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9145, 3915, 74, 93, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9143, 3888, 74, 93, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9142, 3887, 74, 93, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9148, 3932, 74, 94, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9147, 3931, 74, 94, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9146, 3921, 74, 94, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9149, 3934, 74, 94, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9151, 3940, 74, 94, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9150, 3938, 74, 94, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9152, 3941, 74, 95, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9154, 3963, 74, 95, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9155, 3972, 74, 95, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9153, 3953, 74, 95, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9157, 3986, 74, 96, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9156, 3980, 74, 96, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9159, 4032, 74, 97, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9158, 4015, 74, 97, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9160, 4046, 74, 97, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9165, 4102, 74, 98, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9164, 4086, 74, 98, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9163, 4068, 74, 98, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9162, 4064, 74, 98, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9161, 4051, 74, 98, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9168, 4126, 74, 99, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9166, 4103, 74, 99, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9167, 4106, 74, 99, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9169, 4144, 74, 99, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9170, 4155, 74, 100, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9172, 4209, 74, 100, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9171, 4196, 74, 100, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9176, 4270, 74, 101, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9174, 4239, 74, 101, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9175, 4248, 74, 101, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9173, 4227, 74, 101, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9177, 4291, 74, 101, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9182, 4334, 74, 102, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9181, 4325, 74, 102, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9180, 4324, 74, 102, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9178, 4309, 74, 102, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9179, 4318, 74, 102, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9183, 4358, 74, 102, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9184, 4359, 74, 103, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9185, 4356, 74, 103, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9189, 4424, 74, 104, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9187, 4404, 74, 104, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9188, 4407, 74, 104, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9186, 4374, 74, 104, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9190, 4431, 74, 104, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9191, 4433, 74, 104, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9195, 4444, 74, 105, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9194, 4442, 74, 105, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9193, 4440, 74, 105, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9192, 4438, 74, 105, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9196, 4447, 74, 105, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9201, 4476, 74, 106, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9198, 4451, 74, 106, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9199, 4455, 74, 106, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9200, 4461, 74, 106, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9197, 4450, 74, 106, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9204, 4499, 74, 107, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9203, 4491, 74, 107, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9202, 4484, 74, 107, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9207, 4512, 74, 108, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9206, 4511, 74, 108, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9205, 4506, 74, 108, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9212, 4555, 74, 109, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9209, 4518, 74, 109, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9208, 4517, 74, 109, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9211, 4548, 74, 109, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9210, 4543, 74, 109, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9216, 4579, 74, 110, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9215, 4565, 74, 110, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9213, 4561, 74, 110, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9214, 4562, 74, 110, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9217, 4595, 74, 110, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9218, 4602, 74, 111, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9219, 4638, 74, 111, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9220, 4641, 74, 111, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9221, 4646, 74, 111, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9223, 4663, 74, 112, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9222, 4662, 74, 112, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9224, 4679, 74, 112, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9225, 4725, 74, 113, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9228, 4755, 74, 114, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9230, 4765, 74, 114, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9226, 4728, 74, 114, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9227, 4744, 74, 114, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9229, 4759, 74, 114, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9231, 4784, 74, 115, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9232, 4782, 74, 115, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9233, 4803, 74, 115, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9237, 4827, 74, 116, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9238, 4830, 74, 116, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9234, 4804, 74, 116, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9235, 4805, 74, 116, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9236, 4806, 74, 116, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9241, 4864, 74, 117, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9242, 4865, 74, 117, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9239, 4844, 74, 117, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9240, 4862, 74, 117, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9243, 4871, 74, 118, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9244, 4890, 74, 119, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9247, 4919, 74, 119, 103);
INSERT INTO 'dancespublicationsmap' VALUES (21442, 9560, 1407, 127, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21444, 10535, 1407, 128, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21445, 4890, 1407, 128, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21446, 16522, 1407, 128, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21448, 4911, 1407, 129, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21447, 12539, 1407, 129, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21450, 4928, 1407, 130, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21451, 4931, 1407, 130, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21449, 4925, 1407, 130, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21452, 4933, 1407, 131, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21453, 15401, 1407, 131, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21456, 4968, 1407, 132, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21455, 11372, 1407, 132, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21454, 9104, 1407, 132, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21458, 5006, 1407, 133, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21457, 4998, 1407, 133, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21461, 5065, 1407, 134, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21464, 5111, 1407, 135, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21463, 5093, 1407, 135, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21466, 15406, 1407, 137, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21467, 16523, 1407, 137, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21468, 5136, 1407, 137, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21543, 18204, 1408, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21544, 18206, 1408, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21545, 18207, 1408, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9446, 340, 74, 9, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9461, 535, 74, 13, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9440, 652, 74, 16, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9459, 822, 74, 21, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9454, 7284, 74, 27, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9462, 1176, 74, 29, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9445, 2267, 74, 51, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9460, 2453, 74, 56, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9437, 2616, 74, 60, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9455, 7285, 74, 70, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9452, 7283, 74, 75, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9457, 3418, 74, 76, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9463, 3441, 74, 77, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9464, 4008, 74, 98, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9465, 4365, 74, 103, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9449, 4477, 74, 107, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9436, 4629, 74, 111, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9447, 4720, 74, 113, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9456, 7286, 74, 113, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9458, 4796, 74, 115, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9444, 4857, 74, 117, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9248, 4925, 74, 119, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9245, 4907, 74, 119, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9246, 4911, 74, 119, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9249, 4928, 74, 119, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9252, 4932, 74, 120, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9250, 4929, 74, 120, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9251, 4931, 74, 120, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9453, 4933, 74, 121, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9254, 4894, 74, 122, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9255, 4968, 74, 122, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9253, 4935, 74, 122, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9441, 5006, 74, 123, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9256, 4998, 74, 123, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9259, 5040, 74, 124, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9257, 5028, 74, 124, 103);
INSERT INTO 'dancespublicationsmap' VALUES (472, 552, 106, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (406, 473, 106, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5166, 5974, 106, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5088, 5886, 106, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (159, 179, 106, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9258, 5033, 74, 124, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9260, 5065, 74, 124, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9261, 5099, 74, 124, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9263, 5136, 74, 125, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9262, 5111, 74, 125, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9264, 5198, 74, 126, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9266, 5207, 74, 126, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9443, 5204, 74, 126, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9265, 5200, 74, 126, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9268, 5222, 74, 127, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9267, 5208, 74, 127, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9270, 5239, 74, 127, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9269, 5223, 74, 127, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9271, 5243, 74, 128, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9272, 5260, 74, 128, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9274, 5308, 74, 129, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9273, 5296, 74, 129, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9276, 5326, 74, 129, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9275, 5310, 74, 129, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9279, 5347, 74, 130, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9278, 5345, 74, 130, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9280, 5358, 74, 130, 103);
INSERT INTO 'dancespublicationsmap' VALUES (21546, 18208, 1408, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21547, 18209, 1408, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21548, 18210, 1408, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21549, 18211, 1408, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21550, 18212, 1408, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21551, 18213, 1408, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21552, 18214, 1408, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21553, 18215, 1408, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21554, 18216, 1408, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21555, 18217, 1408, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21556, 18218, 1408, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21558, 18221, 1408, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21559, 18222, 1408, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21560, 18223, 1408, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21561, 18224, 1408, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21443, 4857, 1407, 127, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21440, 4827, 1407, 127, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21441, 4844, 1407, 127, 101);
INSERT INTO 'dancespublicationsmap' VALUES (9277, 5330, 74, 130, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9282, 5389, 74, 131, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9281, 5364, 74, 131, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9284, 5398, 74, 131, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9283, 723, 74, 131, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9442, 5412, 74, 132, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9287, 5407, 74, 132, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9285, 5402, 74, 132, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9286, 5403, 74, 132, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9289, 5426, 74, 133, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9288, 5421, 74, 133, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9291, 5441, 74, 133, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9290, 5436, 74, 133, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9293, 5463, 74, 134, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9294, 5480, 74, 134, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9295, 5495, 74, 134, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9296, 5497, 74, 134, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9292, 5462, 74, 134, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9300, 5529, 74, 135, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9301, 5539, 74, 135, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9299, 5525, 74, 135, 103);
INSERT INTO 'dancespublicationsmap' VALUES (13568, 5407, 954, 156, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13570, 5426, 954, 157, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13571, 5436, 954, 157, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13569, 5421, 954, 157, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13572, 5441, 954, 157, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13575, 5480, 954, 158, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13573, 5462, 954, 158, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13574, 5463, 954, 158, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13576, 5495, 954, 159, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13578, 5520, 954, 159, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13577, 5497, 954, 159, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13805, 10008, 954, 159, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13579, 5522, 954, 160, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13581, 5529, 954, 160, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13806, 8956, 954, 160, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13580, 5525, 954, 160, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13716, 5555, 954, 161, 102);
INSERT INTO 'dancespublicationsmap' VALUES (21469, 13727, 1407, 138, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21470, 11788, 1407, 138, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21471, 5198, 1407, 138, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21472, 5204, 1407, 139, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21473, 13589, 1407, 139, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21485, 5330, 1407, 143, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21486, 5403, 1407, 146, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21492, 5443, 1407, 147, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21494, 5463, 1407, 148, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21495, 10166, 1407, 148, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21493, 5462, 1407, 148, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21502, 8088, 1407, 150, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21501, 5525, 1407, 150, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21522, 5612, 1407, 151, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21521, 5555, 1407, 151, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21510, 5637, 1407, 152, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21509, 5621, 1407, 152, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21526, 5658, 1407, 152, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21512, 5671, 1407, 152, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21508, 5616, 1407, 152, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21513, 9563, 1407, 153, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21530, 14649, 1407, 153, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21540, 13163, 1407, 156, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21511, 5897, 1407, 159, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21542, 10920, 1407, 161, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21541, 5936, 1407, 161, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21565, 6010, 1407, 162, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21564, 5982, 1407, 162, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21563, 5964, 1407, 162, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21562, 5963, 1407, 162, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21566, 14025, 1407, 163, 101);
INSERT INTO 'dancespublicationsmap' VALUES (13584, 5552, 954, 161, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13582, 5539, 954, 161, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13585, 5574, 954, 161, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13583, 5543, 954, 161, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13588, 5616, 954, 162, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13586, 5591, 954, 162, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13587, 5612, 954, 162, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13589, 5621, 954, 162, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13590, 5624, 954, 162, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13591, 5637, 954, 163, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13592, 5641, 954, 163, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13594, 5658, 954, 163, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13593, 5643, 954, 163, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13595, 5671, 954, 163, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13597, 5691, 954, 164, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13598, 5702, 954, 164, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13807, 9563, 954, 164, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13596, 5688, 954, 164, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13599, 5703, 954, 164, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13600, 5713, 954, 165, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13602, 5734, 954, 165, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13601, 5731, 954, 165, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13603, 5741, 954, 166, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13605, 5755, 954, 166, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13604, 5754, 954, 166, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13606, 5765, 954, 167, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13607, 5766, 954, 167, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13810, 9561, 954, 168, 102);
INSERT INTO 'dancespublicationsmap' VALUES (21567, 6048, 1407, 163, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21568, 6052, 1407, 163, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21569, 7517, 1407, 163, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21571, 6091, 1407, 164, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21570, 6964, 1407, 164, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21572, 9093, 1407, 164, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21574, 6116, 1407, 165, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21573, 6104, 1407, 165, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21576, 6161, 1407, 166, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21577, 6177, 1407, 166, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21575, 6153, 1407, 166, 101);
INSERT INTO 'dancespublicationsmap' VALUES (9298, 5522, 74, 135, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9297, 5520, 74, 135, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9435, 5555, 74, 136, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9303, 5552, 74, 136, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9302, 5543, 74, 136, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9305, 5591, 74, 136, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9304, 5574, 74, 136, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9309, 5624, 74, 137, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9306, 5612, 74, 137, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9307, 5616, 74, 137, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9308, 5621, 74, 137, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9310, 5637, 74, 138, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9311, 5641, 74, 138, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9312, 5643, 74, 138, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9313, 5658, 74, 138, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9314, 5671, 74, 138, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9316, 5691, 74, 139, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9317, 5702, 74, 139, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9315, 5688, 74, 139, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9319, 5713, 74, 139, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9318, 5703, 74, 139, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9323, 5754, 74, 140, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9320, 5731, 74, 140, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9321, 5734, 74, 140, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9322, 5741, 74, 140, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9325, 5765, 74, 141, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9324, 5755, 74, 141, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9326, 5766, 74, 141, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9333, 5878, 74, 142, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9334, 5889, 74, 142, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9332, 5860, 74, 142, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9331, 5858, 74, 142, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9327, 5794, 74, 142, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9337, 5906, 74, 143, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9336, 5904, 74, 143, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9335, 5897, 74, 143, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9338, 5915, 74, 144, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9339, 5921, 74, 144, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9343, 5945, 74, 145, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9340, 5927, 74, 145, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9341, 5934, 74, 145, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9342, 5937, 74, 145, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9352, 6058, 74, 147, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9353, 6061, 74, 147, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9351, 6052, 74, 147, 103);
INSERT INTO 'dancespublicationsmap' VALUES (3030, 3484, 450, 24, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3048, 3508, 450, 25, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3179, 3657, 450, 26, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3378, 3889, 450, 27, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3408, 3926, 450, 28, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3410, 3928, 450, 29, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3500, 4030, 450, 30, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3526, 4059, 450, 31, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3534, 4067, 450, 32, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3618, 4162, 450, 33, 40);
INSERT INTO 'dancespublicationsmap' VALUES (21583, 5808, 1407, 168, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21582, 5802, 1407, 168, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21581, 16255, 1407, 168, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21584, 7520, 1407, 169, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21585, 6271, 1407, 169, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21587, 6287, 1407, 170, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21586, 11769, 1407, 170, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21588, 6349, 1407, 170, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21589, 11371, 1407, 171, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21591, 12792, 1407, 171, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21590, 6359, 1407, 171, 101);
INSERT INTO 'dancespublicationsmap' VALUES (5047, 5837, 450, 73, 40);
INSERT INTO 'dancespublicationsmap' VALUES (683, 799, 450, 76, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3882, 4463, 450, 77, 40);
INSERT INTO 'dancespublicationsmap' VALUES (9355, 6116, 74, 148, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9357, 6153, 74, 148, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9354, 6091, 74, 148, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9356, 6152, 74, 148, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9360, 6212, 74, 149, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9361, 6224, 74, 149, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9359, 6182, 74, 149, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9466, 6161, 74, 149, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9358, 6178, 74, 149, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9439, 5808, 74, 150, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9328, 5800, 74, 150, 103);
INSERT INTO 'dancespublicationsmap' VALUES (4565, 5274, 450, 78, 40);
INSERT INTO 'dancespublicationsmap' VALUES (9329, 5802, 74, 150, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9362, 6233, 74, 150, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9330, 5804, 74, 151, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9365, 6311, 74, 151, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9363, 6271, 74, 151, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9364, 6287, 74, 151, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9368, 6359, 74, 152, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9367, 6349, 74, 152, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9370, 6373, 74, 152, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9366, 6323, 74, 152, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9369, 6362, 74, 152, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9373, 6391, 74, 153, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9371, 6380, 74, 153, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9372, 6382, 74, 153, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9374, 6406, 74, 153, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9448, 6386, 74, 153, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9376, 6420, 74, 154, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9375, 6407, 74, 154, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9451, 7282, 74, 154, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9377, 6448, 74, 155, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9380, 6523, 74, 155, 103);
INSERT INTO 'dancespublicationsmap' VALUES (102, 115, 450, 79, 40);
INSERT INTO 'dancespublicationsmap' VALUES (21593, 6380, 1407, 172, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21594, 6382, 1407, 172, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21595, 13766, 1407, 172, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21592, 6373, 1407, 172, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21596, 6386, 1407, 173, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21597, 6393, 1407, 173, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21598, 14712, 1407, 174, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21599, 14741, 1407, 174, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21600, 6420, 1407, 174, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21601, 7282, 1407, 175, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21603, 8526, 1407, 176, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21602, 6448, 1407, 176, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21604, 17134, 1407, 176, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21605, 6532, 1407, 177, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21607, 6634, 1407, 178, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21608, 9897, 1407, 178, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21606, 9220, 1407, 178, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21609, 13077, 1407, 179, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21610, 6701, 1407, 179, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21611, 9770, 1407, 179, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21613, 17141, 1407, 180, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21612, 6711, 1407, 180, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21615, 6734, 1407, 180, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21614, 6712, 1407, 180, 101);
INSERT INTO 'dancespublicationsmap' VALUES (9379, 6518, 74, 155, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9378, 6471, 74, 155, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9382, 6539, 74, 156, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9381, 6532, 74, 156, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9383, 6552, 74, 156, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9387, 6599, 74, 157, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9386, 6577, 74, 157, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9389, 6658, 74, 157, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9388, 6634, 74, 157, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9384, 6566, 74, 157, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9385, 6575, 74, 157, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9390, 6701, 74, 158, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9391, 6710, 74, 158, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9393, 6712, 74, 158, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9392, 6711, 74, 158, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9397, 6763, 74, 159, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9398, 6797, 74, 159, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9394, 6721, 74, 159, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9450, 6734, 74, 159, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9396, 6756, 74, 159, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9400, 6817, 74, 160, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9399, 6800, 74, 160, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9401, 6848, 74, 161, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9402, 6885, 74, 161, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9405, 6981, 74, 162, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9404, 6978, 74, 162, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9406, 6995, 74, 162, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9403, 6897, 74, 162, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9407, 7037, 74, 163, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9411, 7073, 74, 163, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9410, 7068, 74, 163, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9408, 7042, 74, 163, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9409, 7055, 74, 163, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9414, 7105, 74, 164, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9415, 7109, 74, 164, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9413, 7093, 74, 164, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9412, 7090, 74, 164, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9417, 7120, 74, 165, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9467, 7124, 74, 165, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9416, 7111, 74, 165, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9418, 7139, 74, 166, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9421, 7152, 74, 166, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9420, 7147, 74, 166, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9419, 7143, 74, 166, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9422, 7172, 74, 167, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9423, 7173, 74, 167, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9424, 7180, 74, 167, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9426, 7188, 74, 167, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9425, 7182, 74, 167, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9429, 7219, 74, 168, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9438, 7204, 74, 168, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9427, 7189, 74, 168, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9428, 7210, 74, 168, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9430, 7220, 74, 168, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9432, 7245, 74, 169, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9431, 7242, 74, 169, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9434, 7267, 74, 169, 103);
INSERT INTO 'dancespublicationsmap' VALUES (9433, 7247, 74, 169, 103);
INSERT INTO 'dancespublicationsmap' VALUES (21963, 18434, 1461, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21910, 17768, 1458, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21911, 18396, 1458, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21912, 18283, 1458, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21913, 18397, 1458, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21914, 18398, 1458, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21915, 18399, 1458, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21916, 18400, 1458, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21917, 18401, 1458, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21918, 18402, 1458, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21919, 18219, 1458, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21920, 18403, 1458, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21921, 18404, 1458, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21922, 18405, 1458, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21923, 18406, 1458, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21924, 18407, 1458, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21964, 18435, 1461, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21965, 18436, 1461, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21966, 18437, 1461, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21967, 18438, 1461, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11435, 9833, 644, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11436, 10255, 644, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22005, 18474, 1464, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21926, 18408, 1459, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21927, 18409, 1459, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21928, 17460, 1459, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21929, 17121, 1459, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21930, 9800, 1459, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21931, 16566, 1459, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21932, 18272, 1459, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21933, 18410, 1459, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21934, 14401, 1459, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21935, 17122, 1459, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21936, 16838, 1459, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21937, 14903, 1459, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22006, 18475, 1464, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22007, 12733, 1464, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22008, 18476, 1464, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22009, 18477, 1464, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22010, 18478, 1464, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22011, 18479, 1464, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22012, 18480, 1464, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21968, 17176, 1462, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21969, 18440, 1462, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21970, 18441, 1462, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21971, 18442, 1462, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21972, 18443, 1462, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21973, 18444, 1462, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21974, 18445, 1462, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21977, 18446, 1462, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21978, 17328, 1462, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21938, 18411, 1460, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21939, 18412, 1460, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21940, 18413, 1460, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21941, 18414, 1460, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21945, 18417, 1460, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21946, 18418, 1460, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21947, 18419, 1460, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21948, 18420, 1460, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21949, 18421, 1460, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21950, 18422, 1460, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21951, 8812, 1460, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21952, 18424, 1460, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21953, 18425, 1460, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21975, 18448, 1462, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21976, 18449, 1462, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21979, 18450, 1462, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21980, 18451, 1462, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21981, 18452, 1462, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11437, 10256, 644, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11438, 10257, 644, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11439, 10258, 644, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11440, 10259, 644, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21955, 15309, 1461, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21956, 18427, 1461, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21957, 18428, 1461, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21958, 18429, 1461, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21961, 18432, 1461, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21962, 18433, 1461, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11441, 10260, 644, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11442, 10261, 644, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14112, 11476, 644, 71, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14113, 11508, 644, 72, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14114, 12173, 644, 73, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21995, 18466, 1464, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21996, 18467, 1464, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21982, 18453, 1463, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21983, 18454, 1463, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21984, 18455, 1463, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21985, 18456, 1463, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21986, 18457, 1463, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21987, 18458, 1463, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21988, 18459, 1463, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21989, 18460, 1463, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21990, 18461, 1463, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21991, 18462, 1463, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21992, 18463, 1463, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21993, 18464, 1463, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21994, 18465, 1463, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21997, 18468, 1464, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21998, 18469, 1464, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21999, 9893, 1464, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22013, 18481, 1464, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22014, 18482, 1464, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22015, 12723, 1464, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22016, 12722, 1464, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22017, 18483, 1464, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22018, 18484, 1464, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22019, 12734, 1464, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14115, 11499, 644, 74, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14116, 11441, 644, 75, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14117, 11468, 644, 76, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14118, 11454, 644, 77, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14119, 12488, 644, 78, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14120, 11465, 644, 79, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14121, 11456, 644, 80, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14122, 11459, 644, 81, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14123, 11488, 644, 82, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14124, 11442, 644, 83, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14125, 11446, 644, 84, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22020, 12732, 1464, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22021, 12731, 1464, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22022, 9873, 1464, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22023, 9864, 1464, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22000, 18470, 1464, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22001, 18471, 1464, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22002, 12730, 1464, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14126, 11494, 644, 85, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14127, 11455, 644, 86, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22003, 18472, 1464, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22004, 18473, 1464, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4495, 5193, 450, 48, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4453, 5143, 450, 49, 40);
INSERT INTO 'dancespublicationsmap' VALUES (15904, 12794, 1092, 8, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15905, 2039, 1092, 9, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15906, 2077, 1092, 9, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15908, 11367, 1092, 10, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15907, 11773, 1092, 10, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15909, 12803, 1092, 11, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15911, 2365, 1092, 12, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15910, 13583, 1092, 12, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15912, 8674, 1092, 13, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15913, 2604, 1092, 13, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15914, 13580, 1092, 13, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15915, 9332, 1092, 14, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15916, 12802, 1092, 14, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15917, 2956, 1092, 15, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15918, 13579, 1092, 15, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15919, 9636, 1092, 16, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15920, 7560, 1092, 16, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15921, 9836, 1092, 16, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15923, 11890, 1092, 17, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15922, 12542, 1092, 17, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15924, 9787, 1092, 18, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15928, 7811, 1092, 19, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15927, 10306, 1092, 19, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15926, 11524, 1092, 19, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15925, 3593, 1092, 19, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15931, 4692, 1092, 20, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15929, 10589, 1092, 20, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15930, 11814, 1092, 20, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15932, 14321, 1092, 21, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13065, 89, 954, 4, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13066, 109, 954, 4, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13064, 83, 954, 4, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13067, 116, 954, 4, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13068, 132, 954, 5, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13070, 153, 954, 5, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13069, 140, 954, 5, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13752, 159, 954, 6, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13071, 183, 954, 6, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13753, 188, 954, 7, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13072, 218, 954, 7, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13073, 219, 954, 8, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13754, 11376, 954, 8, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13077, 221, 954, 9, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13078, 245, 954, 9, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13075, 223, 954, 9, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13076, 224, 954, 9, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13074, 222, 954, 9, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13080, 301, 954, 10, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13079, 289, 954, 10, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13755, 9138, 954, 10, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13082, 314, 954, 11, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13081, 312, 954, 11, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13083, 335, 954, 12, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13084, 352, 954, 12, 102);
INSERT INTO 'dancespublicationsmap' VALUES (210, 245, 125, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (775, 902, 125, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (922, 1068, 125, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (927, 1073, 125, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1564, 1818, 125, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3114, 3584, 125, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1640, 1903, 125, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6227, 7220, 125, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5234, 6053, 125, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15306, 93, 1052, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15307, 4337, 1052, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15308, 7120, 1052, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15309, 4878, 1052, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15310, 2588, 1052, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15311, 3366, 1052, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15312, 4552, 1052, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15313, 3909, 1052, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15314, 893, 1052, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15315, 218, 1052, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15316, 7980, 1052, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15317, 1533, 1052, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15318, 1544, 1052, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11908, 10877, 616, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13727, 340, 954, 12, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13085, 353, 954, 12, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13088, 377, 954, 13, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13089, 389, 954, 13, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13090, 392, 954, 13, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13087, 373, 954, 13, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13086, 355, 954, 13, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13756, 413, 954, 14, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13091, 410, 954, 14, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13092, 430, 954, 14, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13168, 1246, 954, 37, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13170, 1280, 954, 37, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13171, 1283, 954, 37, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13169, 1260, 954, 37, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13181, 1388, 954, 41, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13219, 1834, 954, 53, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13218, 1799, 954, 53, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13220, 1838, 954, 53, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13216, 1790, 954, 53, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13217, 1792, 954, 53, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13221, 1857, 954, 54, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13222, 1864, 954, 54, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13223, 1866, 954, 54, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13776, 1847, 954, 54, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13226, 1891, 954, 55, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13229, 1931, 954, 56, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13228, 1909, 954, 56, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13227, 1903, 954, 56, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13777, 9107, 954, 56, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13232, 1990, 954, 57, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13231, 1966, 954, 57, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13233, 1998, 954, 57, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13230, 1965, 954, 57, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13234, 2004, 954, 57, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15247, 9773, 1048, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15246, 13835, 1048, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15248, 13837, 1048, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15249, 13838, 1048, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15250, 9062, 1048, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15251, 13840, 1048, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15252, 13841, 1048, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15253, 13842, 1048, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15254, 13843, 1048, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15255, 13844, 1048, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15256, 13845, 1048, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15257, 13846, 1048, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15258, 11298, 1048, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10018, 8163, 381, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10021, 8713, 381, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10022, 8721, 381, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10023, 8675, 381, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15822, 3870, 1084, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15823, 8202, 1084, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15824, 845, 1084, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15825, 8203, 1084, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15826, 13617, 1084, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15827, 413, 1084, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15828, 13618, 1084, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15829, 14239, 1084, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15830, 13619, 1084, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15831, 5499, 1084, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15832, 9084, 1084, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15833, 12428, 1084, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15834, 9087, 1084, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15835, 13620, 1084, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15836, 9008, 1084, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15837, 6972, 1084, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15838, 11001, 1084, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15839, 13621, 1084, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15840, 5384, 1084, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15841, 14339, 1084, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15842, 12634, 1084, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15843, 7795, 1084, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15844, 8932, 1084, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15845, 1543, 1084, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15429, 13524, 1059, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15430, 13525, 1059, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15431, 13526, 1059, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15432, 13527, 1059, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15433, 11512, 1059, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15434, 13528, 1059, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15435, 13529, 1059, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15436, 13530, 1059, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15437, 13531, 1059, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15438, 13532, 1059, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15439, 13533, 1059, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15440, 13534, 1059, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15441, 13535, 1059, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15442, 13536, 1059, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (978, 1133, 436, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5296, 6122, 436, 7, 40);
INSERT INTO 'dancespublicationsmap' VALUES (202, 235, 436, 8, 40);
INSERT INTO 'dancespublicationsmap' VALUES (653, 763, 436, 15, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5085, 5881, 436, 16, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5312, 6140, 436, 26, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1137, 1318, 436, 30, 40);
INSERT INTO 'dancespublicationsmap' VALUES (15443, 13537, 1059, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15444, 13538, 1059, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1344, 1554, 266, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1448, 1678, 266, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1684, 1953, 266, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1686, 1955, 266, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1688, 1957, 266, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1817, 2101, 266, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5767, 6677, 266, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2900, 3340, 266, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5031, 5817, 266, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (629, 735, 267, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5267, 6093, 267, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5543, 6410, 267, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5935, 6876, 267, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2241, 2578, 267, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2649, 3051, 267, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2651, 3053, 267, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7716, 5433, 267, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10006, 1998, 267, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1162, 1347, 667, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5518, 6385, 667, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5612, 6491, 667, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5633, 6517, 667, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1860, 2146, 667, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2928, 3369, 667, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3640, 4184, 667, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6437, 3384, 667, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4687, 5416, 667, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4713, 5454, 667, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7840, 5101, 667, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11573, 10430, 819, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11574, 10431, 819, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11575, 10432, 819, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11576, 10433, 819, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11577, 10434, 819, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11578, 10435, 819, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11579, 10436, 819, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11580, 10439, 819, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11581, 10440, 819, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11582, 10441, 819, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11583, 10442, 819, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11584, 10443, 819, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11585, 10444, 819, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11586, 10445, 819, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11587, 10446, 819, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11588, 10447, 819, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11589, 10448, 819, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1614, 1875, 450, 12, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1746, 2019, 450, 13, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1891, 2183, 450, 14, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2156, 2482, 450, 15, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2180, 2512, 450, 16, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2208, 2541, 450, 17, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3897, 4482, 450, 34, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3952, 4551, 450, 35, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3974, 4573, 450, 36, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3985, 4584, 450, 37, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4114, 4739, 450, 38, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4139, 4770, 450, 39, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4186, 4829, 450, 40, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4203, 4854, 450, 41, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13235, 2024, 954, 58, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13237, 2042, 954, 59, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13236, 2030, 954, 59, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13238, 2044, 954, 59, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13239, 2063, 954, 59, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13240, 2084, 954, 59, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13241, 6957, 954, 60, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13778, 2110, 954, 60, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13244, 868, 954, 61, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13243, 2140, 954, 61, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13245, 2153, 954, 61, 102);
INSERT INTO 'dancespublicationsmap' VALUES (5098, 5896, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (197, 228, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (553, 645, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (918, 1063, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5535, 6402, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1305, 1509, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5693, 6593, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5782, 6695, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5791, 6706, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2007, 2316, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5975, 6926, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2579, 2973, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3265, 3761, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4680, 5408, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4766, 5515, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4962, 5743, 98, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12516, 11479, 83, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12517, 11480, 83, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12518, 11481, 83, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12519, 11482, 83, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12520, 11483, 83, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12521, 11484, 83, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12522, 11485, 83, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12523, 11478, 83, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10475, 9179, 494, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10476, 9180, 494, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10477, 9181, 494, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10478, 8963, 494, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10479, 8971, 494, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10480, 9182, 494, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10481, 9183, 494, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11155, 8562, 366, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10407, 9091, 435, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10408, 9092, 435, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10409, 9093, 435, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10410, 9094, 435, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10411, 9095, 435, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10412, 9096, 435, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10413, 9054, 435, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10414, 9097, 435, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10415, 9098, 435, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10416, 9099, 435, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10417, 9100, 435, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (223, 262, 584, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2223, 2558, 584, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5897, 6833, 584, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6071, 7039, 584, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6108, 7081, 584, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16305, 15181, 1097, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16075, 15182, 1097, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17155, 15191, 1097, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17156, 15192, 1097, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17157, 15193, 1097, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17158, 15194, 1097, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17159, 15195, 1097, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17160, 13118, 1097, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17161, 15196, 1097, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17162, 15197, 1097, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17163, 15198, 1097, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17164, 15200, 1097, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17165, 13117, 1097, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17166, 15201, 1097, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17167, 15202, 1097, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17168, 15203, 1097, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17169, 15206, 1097, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17170, 15207, 1097, 29, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17171, 15208, 1097, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17172, 15209, 1097, 31, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17173, 15210, 1097, 32, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17174, 15211, 1097, 33, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17175, 15212, 1097, 34, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17176, 15213, 1097, 35, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17177, 15214, 1097, 36, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17178, 15215, 1097, 37, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17179, 8932, 1097, 38, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17180, 15216, 1097, 39, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14684, 13066, 1008, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14685, 13067, 1008, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14686, 13068, 1008, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14687, 13069, 1008, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14691, 13072, 1008, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14692, 13073, 1008, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14693, 13074, 1008, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14694, 12900, 1008, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4221, 4874, 450, 42, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4237, 4893, 450, 43, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4270, 4934, 450, 44, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4285, 4952, 450, 45, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4313, 4987, 450, 46, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6542, 5055, 450, 47, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4498, 5197, 450, 50, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5243, 6063, 450, 52, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5276, 6102, 450, 52, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6592, 6122, 450, 53, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5335, 6170, 450, 54, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5442, 6297, 450, 55, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13242, 2136, 954, 61, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13246, 2156, 954, 61, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13247, 2158, 954, 62, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13248, 2166, 954, 62, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13249, 2189, 954, 62, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13252, 2257, 954, 63, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13250, 2242, 954, 63, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13781, 2222, 954, 63, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13251, 2250, 954, 63, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13253, 2263, 954, 64, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13272, 2431, 954, 70, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13273, 2436, 954, 70, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13274, 2437, 954, 70, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13275, 2469, 954, 71, 102);
INSERT INTO 'dancespublicationsmap' VALUES (12395, 11317, 908, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12396, 11318, 908, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12397, 11319, 908, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12398, 11320, 908, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12399, 11321, 908, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12400, 11322, 908, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12401, 11323, 908, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12402, 11324, 908, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12403, 11325, 908, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12404, 11326, 908, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12405, 11327, 908, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12406, 11328, 908, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12407, 11329, 908, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12408, 11330, 908, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (704, 822, 715, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5476, 6336, 715, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1816, 2100, 715, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6063, 7031, 715, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11817, 10754, 838, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11818, 10755, 838, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11819, 10364, 838, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11820, 10756, 838, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11821, 10757, 838, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11822, 10758, 838, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11823, 10759, 838, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11824, 10760, 838, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11825, 9851, 838, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11826, 10761, 838, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11827, 10762, 838, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11828, 10763, 838, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11829, 10764, 838, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11830, 10765, 838, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6788, 7443, 780, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6793, 7448, 780, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6800, 7460, 780, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6803, 7464, 780, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6808, 7472, 780, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6815, 7480, 780, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6820, 7486, 780, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6697, 7340, 780, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6713, 7356, 780, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6715, 7358, 780, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6722, 7366, 780, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6742, 7387, 780, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6753, 7401, 780, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6765, 7414, 780, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6777, 7429, 780, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6780, 7433, 780, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6835, 7504, 780, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6844, 7513, 780, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6849, 7518, 780, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5708, 6611, 450, 56, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13278, 2498, 954, 71, 102);
INSERT INTO 'dancespublicationsmap' VALUES (12050, 11014, 859, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12051, 11015, 859, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10825, 9549, 624, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10826, 9550, 624, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10827, 9551, 624, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10828, 9126, 624, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10829, 9552, 624, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10830, 9553, 624, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10831, 9554, 624, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10832, 9555, 624, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10833, 9557, 624, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10834, 9556, 624, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11090, 9341, 624, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10982, 9111, 650, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10983, 3020, 650, 29, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10984, 9702, 650, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10985, 9703, 650, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10986, 9704, 650, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10987, 9705, 650, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10988, 9706, 650, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10989, 9708, 650, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10990, 9709, 650, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10991, 8960, 650, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10992, 9710, 650, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10993, 9711, 650, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10994, 9712, 650, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (391, 455, 582, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (936, 1083, 582, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1503, 1740, 582, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1607, 1867, 582, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5805, 6727, 582, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2758, 3174, 582, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12052, 11016, 859, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (48, 57, 689, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (536, 624, 689, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1692, 1961, 689, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1934, 2236, 689, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3596, 4136, 689, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12465, 11389, 913, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12466, 11390, 913, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12467, 11391, 913, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12468, 11392, 913, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12470, 10105, 913, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12469, 11393, 913, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12471, 11394, 913, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12472, 11395, 913, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12473, 9127, 913, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12474, 11396, 913, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12475, 11397, 913, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12476, 11398, 913, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10418, 9101, 435, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12053, 11017, 859, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12054, 11018, 859, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12055, 11019, 859, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12056, 11020, 859, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12057, 11021, 859, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12058, 11022, 859, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12059, 11023, 859, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12060, 11024, 859, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13949, 11984, 958, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13948, 12344, 958, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10995, 9713, 650, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10996, 9714, 650, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10997, 9715, 650, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10998, 8959, 650, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10999, 9716, 650, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11004, 9717, 650, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11005, 9718, 650, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11006, 9719, 650, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11007, 9720, 650, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11008, 9721, 650, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11009, 9722, 650, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11010, 9723, 650, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11011, 9724, 650, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11012, 9725, 650, 31, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11013, 9726, 650, 32, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11014, 9727, 650, 34, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11015, 9728, 650, 35, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13291, 2700, 954, 75, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13783, 10790, 954, 76, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13294, 2742, 954, 76, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13293, 2725, 954, 76, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13295, 2745, 954, 76, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13292, 2713, 954, 76, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13784, 11770, 954, 77, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13785, 2760, 954, 77, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13296, 2747, 954, 77, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13297, 2777, 954, 77, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13300, 2813, 954, 78, 102);
INSERT INTO 'dancespublicationsmap' VALUES (7674, 4814, 338, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7675, 4470, 338, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5816, 6740, 450, 57, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6027, 6988, 450, 58, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6081, 7052, 450, 59, 40);
INSERT INTO 'dancespublicationsmap' VALUES (301, 349, 450, 60, 40);
INSERT INTO 'dancespublicationsmap' VALUES (353, 412, 450, 61, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1781, 2061, 450, 62, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2335, 2690, 450, 63, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6091, 7063, 450, 64, 40);
INSERT INTO 'dancespublicationsmap' VALUES (331, 384, 450, 65, 40);
INSERT INTO 'dancespublicationsmap' VALUES (875, 1014, 450, 66, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4520, 5220, 450, 67, 40);
INSERT INTO 'dancespublicationsmap' VALUES (188, 217, 450, 68, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6243, 7238, 450, 69, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6272, 7270, 450, 70, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1060, 1228, 450, 71, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1112, 1290, 450, 72, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5736, 6641, 450, 74, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1289, 1493, 450, 75, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5408, 6258, 542, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1512, 1752, 542, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5668, 6561, 542, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1979, 2287, 542, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2159, 2486, 542, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2239, 2576, 542, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2534, 2921, 542, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6130, 7106, 542, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4412, 5097, 542, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4791, 5545, 542, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4895, 5664, 542, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16805, 14918, 1119, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16804, 14917, 1119, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16803, 14916, 1119, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16799, 14915, 1119, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16798, 14914, 1119, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16797, 14913, 1119, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16796, 14912, 1119, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16795, 14911, 1119, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16794, 14910, 1119, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16505, 14715, 1119, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16506, 14716, 1119, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16507, 14717, 1119, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13298, 2781, 954, 78, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13299, 2807, 954, 78, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13302, 2821, 954, 79, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13303, 2822, 954, 79, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13304, 2868, 954, 79, 102);
INSERT INTO 'dancespublicationsmap' VALUES (11978, 10942, 845, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11979, 10943, 845, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11980, 10944, 845, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5374, 6211, 594, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5165, 5973, 594, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1943, 2246, 594, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4435, 5124, 594, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2734, 3149, 594, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (399, 464, 594, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4536, 5241, 594, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5038, 5826, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4848, 5610, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4730, 5473, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4686, 5414, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4349, 5026, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3862, 4443, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6532, 4845, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6523, 4669, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6463, 3710, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2694, 3106, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2026, 2336, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (832, 964, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11981, 10945, 845, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11932, 10344, 845, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11933, 10893, 845, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11935, 10895, 845, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11934, 10894, 845, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11936, 10345, 845, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11937, 10896, 845, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11938, 10897, 845, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11939, 10898, 845, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11940, 10095, 845, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11982, 10949, 845, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11941, 10096, 845, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11975, 10938, 845, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11976, 10940, 845, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11977, 10941, 845, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (378, 440, 590, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2372, 2733, 590, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5092, 5890, 590, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (923, 1069, 590, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4134, 4763, 590, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5332, 6167, 590, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5376, 6214, 590, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6154, 7134, 590, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4948, 5726, 590, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15538, 9125, 1064, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15540, 14053, 1064, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15541, 13084, 1064, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15542, 14055, 1064, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15543, 11549, 1064, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15544, 14057, 1064, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15545, 14058, 1064, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5284, 6110, 587, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2152, 2478, 587, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2195, 2528, 587, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2485, 2866, 587, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3251, 3744, 587, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4201, 4852, 587, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4839, 5600, 587, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4891, 5660, 587, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13897, 550, 73, 16, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13898, 2223, 73, 18, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13899, 7120, 73, 19, 40);
INSERT INTO 'dancespublicationsmap' VALUES (22885, 19661, 73, 90, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13043, 3909, 73, 100, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13900, 6464, 73, 110, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13030, 445, 73, 133, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13042, 5868, 73, 134, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13038, 2535, 73, 136, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13901, 4552, 73, 137, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13037, 1639, 73, 138, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13028, 77, 73, 141, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13902, 3705, 73, 145, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13036, 1625, 73, 146, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5069, 5862, 121, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1593, 1853, 121, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5880, 6814, 121, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2702, 3115, 121, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3092, 3559, 121, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5380, 6221, 609, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1453, 1684, 609, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1894, 2186, 609, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6140, 7117, 609, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5164, 5972, 609, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6316, 873, 121, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3909, 4494, 121, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4958, 5737, 587, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5478, 6338, 192, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1435, 1664, 192, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3615, 4158, 192, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11, 14, 561, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1452, 1683, 561, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1560, 1812, 561, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6299, 652, 561, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16234, 13750, 1112, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16235, 14520, 1112, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16236, 12790, 1112, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16237, 14521, 1112, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16238, 14522, 1112, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16239, 14523, 1112, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16240, 14524, 1112, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16241, 14525, 1112, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16242, 14526, 1112, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16243, 14527, 1112, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7454, 7595, 301, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7762, 6291, 301, 3, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13301, 2820, 954, 79, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13307, 2910, 954, 80, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13305, 2878, 954, 80, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13308, 2916, 954, 80, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13310, 6477, 954, 80, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13306, 2903, 954, 80, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13309, 2918, 954, 80, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13311, 2924, 954, 81, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13314, 8087, 954, 81, 102);
INSERT INTO 'dancespublicationsmap' VALUES (16840, 14954, 1143, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16839, 14953, 1143, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16838, 14952, 1143, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16837, 14951, 1143, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16836, 14950, 1143, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16835, 14949, 1143, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16834, 11904, 1143, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16833, 11404, 1143, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16832, 14948, 1143, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16831, 14947, 1143, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16830, 14946, 1143, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16829, 14945, 1143, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16828, 14944, 1143, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16827, 14943, 1143, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16826, 12121, 1143, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13313, 2934, 954, 81, 102);
INSERT INTO 'dancespublicationsmap' VALUES (915, 1060, 589, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12269, 10092, 845, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12270, 10093, 845, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12271, 10291, 845, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11991, 10957, 845, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12272, 10097, 845, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12273, 10346, 845, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11992, 10960, 845, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22865, 19645, 1515, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22866, 19646, 1515, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22867, 19647, 1515, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22868, 19648, 1515, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22869, 19649, 1515, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22870, 19650, 1515, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22871, 19557, 1515, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22872, 19559, 1515, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22873, 19556, 1515, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22874, 19651, 1515, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10889, 9482, 644, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10890, 9483, 644, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10891, 9484, 644, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10892, 9485, 644, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10893, 9486, 644, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10894, 9487, 644, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10895, 9488, 644, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10896, 9489, 644, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10897, 9490, 644, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10898, 9491, 644, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10899, 9492, 644, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10900, 9493, 644, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10901, 9494, 644, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10902, 9566, 644, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10903, 9495, 644, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10904, 9496, 644, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10905, 9567, 644, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10906, 9568, 644, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10907, 9569, 644, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11443, 10262, 644, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11444, 10263, 644, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11445, 10264, 644, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11446, 10265, 644, 49, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11447, 10266, 644, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11449, 10268, 644, 52, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11450, 10269, 644, 53, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11451, 10270, 644, 54, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11452, 10271, 644, 55, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11453, 10272, 644, 56, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14111, 11463, 644, 70, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22893, 1784, 1519, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22894, 7274, 1519, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22895, 12769, 1519, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22896, 7289, 1519, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22897, 7293, 1519, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22890, 6204, 1519, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22891, 7296, 1519, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22892, 6148, 1519, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13315, 2947, 954, 81, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13312, 2925, 954, 81, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13319, 2972, 954, 82, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13317, 2962, 954, 82, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13320, 2978, 954, 82, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13321, 2979, 954, 82, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13318, 2970, 954, 82, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13325, 3057, 954, 83, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13322, 3038, 954, 83, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13323, 3045, 954, 84, 102);
INSERT INTO 'dancespublicationsmap' VALUES (66, 77, 203, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (71, 83, 203, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (74, 86, 203, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (114, 129, 203, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (139, 158, 203, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (184, 212, 203, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (307, 356, 203, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (333, 388, 203, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6277, 68, 203, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6285, 354, 203, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15016, 360, 203, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5139, 5943, 745, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5394, 6240, 745, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5436, 6289, 745, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5461, 6321, 745, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5832, 6759, 745, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6018, 6977, 745, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6076, 7045, 745, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6123, 7099, 745, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6229, 7222, 745, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6626, 6919, 745, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6638, 7175, 745, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15015, 7226, 1034, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15014, 7222, 1034, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15013, 7201, 1034, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15012, 7175, 1034, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15011, 7099, 1034, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15010, 7045, 1034, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15009, 6977, 1034, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15008, 6919, 1034, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15007, 6759, 1034, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15006, 6675, 1034, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (668, 780, 738, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (698, 815, 738, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (897, 1040, 738, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1099, 1276, 738, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1270, 1474, 738, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1346, 1556, 738, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1357, 1570, 738, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6312, 827, 738, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6334, 1162, 738, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6340, 1307, 738, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1871, 2161, 740, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2086, 2406, 740, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2198, 2531, 740, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13032, 893, 73, 159, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13904, 4337, 73, 166, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13034, 1300, 73, 175, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13029, 218, 73, 178, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13040, 4047, 73, 180, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2202, 2535, 740, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2273, 2621, 740, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2538, 2926, 740, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2598, 2995, 740, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2634, 3036, 740, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6406, 2822, 740, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2672, 3082, 741, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2719, 3134, 741, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2795, 3216, 741, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2894, 3333, 741, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2943, 3385, 741, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2949, 3391, 741, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3003, 3450, 741, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3016, 3466, 741, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3029, 3483, 741, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3085, 3550, 741, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3294, 3797, 742, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3357, 3868, 742, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3390, 3902, 742, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3397, 3913, 742, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3437, 3959, 742, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3667, 4216, 742, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6485, 3963, 742, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3915, 4503, 742, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3936, 4531, 743, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4253, 4913, 743, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4260, 4921, 743, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4272, 4937, 743, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4406, 5091, 743, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4635, 5355, 743, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4660, 5387, 743, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4718, 5461, 743, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4725, 5468, 743, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4868, 5630, 743, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5074, 5867, 744, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5100, 5898, 744, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5122, 5922, 744, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5127, 5927, 744, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5726, 6629, 744, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6580, 5932, 744, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4954, 5733, 744, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4963, 5744, 744, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5007, 5793, 744, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5042, 5830, 744, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13786, 11186, 954, 84, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13324, 3046, 954, 84, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13736, 7285, 954, 85, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13329, 3108, 954, 85, 102);
INSERT INTO 'dancespublicationsmap' VALUES (4296, 4966, 760, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7455, 7602, 760, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7462, 7615, 760, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7490, 1794, 760, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7496, 7672, 760, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7506, 7688, 760, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7530, 7674, 760, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7584, 7768, 760, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7599, 7784, 760, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7623, 7811, 760, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7628, 7817, 760, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7632, 7821, 760, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7694, 7885, 760, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7729, 2810, 760, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7749, 7939, 760, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7760, 7952, 760, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7763, 7957, 760, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7766, 7961, 760, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7771, 7321, 760, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (679, 795, 751, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (694, 811, 751, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1066, 1236, 751, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1067, 1237, 751, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5930, 6870, 751, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17182, 15220, 1164, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17183, 14546, 1164, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17185, 15222, 1164, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17186, 13747, 1164, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2443, 2818, 751, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3515, 4047, 751, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (336, 391, 737, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (395, 460, 737, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (458, 537, 737, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (482, 563, 737, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (502, 583, 737, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (519, 602, 737, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (551, 643, 737, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (617, 722, 737, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (648, 757, 737, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6289, 462, 737, 0, 31);
INSERT INTO 'dancespublicationsmap' VALUES (1234, 1427, 749, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (432, 504, 749, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (382, 444, 749, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6554, 5414, 750, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6009, 6968, 750, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5130, 5930, 750, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (189, 218, 750, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4733, 5476, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4638, 5359, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6544, 5188, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6305, 767, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3205, 3689, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2849, 3277, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5980, 6933, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2265, 2611, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2169, 2497, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5005, 5791, 754, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4681, 5409, 754, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6583, 5980, 754, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6363, 1848, 754, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3293, 3796, 754, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3056, 3516, 754, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5527, 6394, 754, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (257, 300, 754, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13327, 3104, 954, 85, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13330, 3111, 954, 85, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15136, 13388, 1043, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15137, 13282, 1043, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15138, 13389, 1043, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15139, 13286, 1043, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15140, 13390, 1043, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15141, 13387, 1043, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15142, 12603, 1043, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15143, 13391, 1043, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15144, 13392, 1043, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15145, 13766, 1043, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15146, 13393, 1043, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15147, 13394, 1043, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15148, 13395, 1043, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15149, 13396, 1043, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13328, 3105, 954, 85, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13326, 3084, 954, 85, 102);
INSERT INTO 'dancespublicationsmap' VALUES (14007, 9424, 969, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14008, 9421, 969, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14009, 9422, 969, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14010, 9420, 969, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14011, 9423, 969, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14012, 9419, 969, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14013, 9418, 969, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14014, 9417, 969, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3660, 4206, 181, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3685, 4235, 181, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4379, 5057, 181, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1439, 1668, 181, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4787, 5541, 181, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6077, 7046, 181, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (175, 201, 182, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1190, 1377, 182, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1306, 1510, 182, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1307, 1511, 182, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2752, 3168, 182, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2753, 3169, 182, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2944, 3386, 183, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (130, 146, 183, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4430, 5119, 183, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1311, 1516, 185, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5635, 6519, 185, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5676, 6570, 185, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1656, 1922, 185, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4786, 5540, 185, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4890, 5659, 185, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6119, 7093, 278, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3051, 3511, 278, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2456, 2833, 278, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1171, 1356, 278, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2102, 2422, 278, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4910, 5683, 278, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7772, 7966, 229, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13840, 12181, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13852, 12212, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13853, 12213, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13921, 12288, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13923, 12294, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13929, 12319, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13931, 12331, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13936, 2908, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13937, 12337, 955, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (574, 668, 187, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1155, 1340, 187, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1164, 1349, 187, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1735, 2006, 187, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2298, 2650, 187, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2650, 3052, 187, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3398, 3914, 187, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3929, 4524, 187, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3969, 4568, 187, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4734, 5477, 187, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17380, 15451, 1178, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17379, 15450, 1178, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17378, 15449, 1178, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17377, 15448, 1178, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17376, 15447, 1178, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17375, 15446, 1178, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17374, 15445, 1178, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5334, 6169, 475, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5673, 6567, 475, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5737, 6643, 475, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1759, 2038, 475, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2754, 3170, 475, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3084, 3549, 475, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10385, 9071, 432, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10386, 7994, 432, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10718, 9392, 565, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10719, 9393, 565, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10720, 9394, 565, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10721, 9395, 565, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10722, 9396, 565, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10723, 9397, 565, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10724, 9398, 565, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10725, 9399, 565, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10726, 9400, 565, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7441, 32, 218, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7451, 231, 218, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7480, 1093, 218, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7504, 1756, 218, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7658, 4597, 218, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7709, 4151, 218, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13337, 3177, 954, 87, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13335, 3172, 954, 87, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13787, 10794, 954, 88, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13788, 10792, 954, 89, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13339, 3231, 954, 89, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13338, 3225, 954, 89, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13345, 3323, 954, 90, 102);
INSERT INTO 'dancespublicationsmap' VALUES (3744, 4304, 475, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4360, 5037, 475, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4362, 5039, 475, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4399, 5084, 475, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4759, 5506, 475, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4906, 5679, 475, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13341, 3246, 954, 90, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13340, 3235, 954, 90, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13344, 3310, 954, 90, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13343, 3284, 954, 90, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13342, 3281, 954, 90, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13349, 3342, 954, 91, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13733, 7283, 954, 91, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13348, 3339, 954, 91, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13347, 3338, 954, 91, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13350, 3365, 954, 92, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13352, 3424, 954, 93, 102);
INSERT INTO 'dancespublicationsmap' VALUES (157, 177, 535, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1693, 1963, 535, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2425, 2797, 535, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2816, 3241, 535, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3340, 3851, 535, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14250, 12567, 985, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14251, 12568, 985, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14252, 12569, 985, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (167, 189, 498, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2043, 2354, 498, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2297, 2649, 498, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22, 28, 581, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (963, 1115, 581, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1049, 1216, 581, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1491, 1728, 581, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1625, 1887, 581, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1848, 2132, 581, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14253, 12570, 985, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14254, 12571, 985, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14255, 12572, 985, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14256, 12573, 985, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14283, 12603, 985, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14284, 12604, 985, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14285, 12605, 985, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15190, 13789, 985, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15191, 13790, 985, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15192, 13791, 985, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15193, 13792, 985, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15194, 13793, 985, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15195, 13794, 985, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15196, 13795, 985, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15197, 13796, 985, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15198, 13797, 985, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15199, 13798, 985, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15200, 13799, 985, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15201, 13800, 985, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15202, 13801, 985, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15203, 13802, 985, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15204, 13803, 985, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13738, 3418, 954, 93, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13351, 3412, 954, 93, 102);
INSERT INTO 'dancespublicationsmap' VALUES (35, 42, 250, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5717, 6620, 250, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2391, 2756, 250, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2466, 2844, 250, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2742, 3157, 250, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2922, 3362, 250, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6206, 7198, 250, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (31, 38, 607, 0, 20);
INSERT INTO 'dancespublicationsmap' VALUES (584, 678, 607, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (754, 879, 607, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5471, 6331, 607, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5652, 6544, 607, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1708, 1978, 607, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2188, 2520, 607, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2213, 2547, 607, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2503, 2889, 607, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4158, 4794, 607, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4228, 4883, 607, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (198, 229, 171, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5333, 6168, 171, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4521, 5221, 480, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (719, 839, 480, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4745, 5492, 480, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1896, 2188, 480, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4649, 5372, 480, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6143, 7120, 480, 6, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2332, 2686, 480, 8, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4608, 5325, 480, 10, 40);
INSERT INTO 'dancespublicationsmap' VALUES (609, 712, 480, 16, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5491, 6355, 480, 18, 40);
INSERT INTO 'dancespublicationsmap' VALUES (352, 411, 480, 20, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6445, 3552, 480, 26, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1046, 1211, 480, 32, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3717, 4271, 480, 33, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2093, 2413, 480, 37, 40);
INSERT INTO 'dancespublicationsmap' VALUES (583, 677, 480, 39, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7773, 7967, 229, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7774, 7968, 229, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13835, 12159, 956, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2697, 3109, 480, 45, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1117, 1295, 171, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5630, 6513, 171, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1900, 2192, 171, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1999, 2308, 171, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2291, 2640, 171, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4244, 4903, 171, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14929, 13665, 1026, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14930, 13666, 1026, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14931, 13667, 1026, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14932, 13668, 1026, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14933, 13669, 1026, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14934, 13670, 1026, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14935, 13671, 1026, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14936, 13672, 1026, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14937, 13673, 1026, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14938, 13674, 1026, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14939, 13675, 1026, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14598, 9083, 1001, 1, 11);
INSERT INTO 'dancespublicationsmap' VALUES (14599, 12542, 1001, 2, 11);
INSERT INTO 'dancespublicationsmap' VALUES (14600, 9836, 1001, 3, 11);
INSERT INTO 'dancespublicationsmap' VALUES (628, 734, 477, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5477, 6337, 477, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6466, 3727, 477, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1534, 1778, 477, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5044, 5833, 477, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1085, 1259, 477, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (660, 772, 477, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1550, 1801, 477, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17476, 8526, 1184, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17477, 15405, 1184, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17478, 15411, 1184, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17479, 1426, 1184, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17480, 13727, 1184, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17481, 7375, 1184, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17482, 8482, 1184, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17483, 14025, 1184, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17484, 3397, 1184, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17485, 15177, 1184, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17486, 7351, 1184, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17487, 695, 1184, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (13353, 3435, 954, 93, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13354, 3436, 954, 93, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13355, 3444, 954, 94, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13744, 3441, 954, 94, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13789, 3463, 954, 94, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13357, 3475, 954, 95, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13356, 3474, 954, 95, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13359, 3526, 954, 96, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13790, 3485, 954, 96, 102);
INSERT INTO 'dancespublicationsmap' VALUES (7682, 4933, 336, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13360, 3528, 954, 96, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13358, 3506, 954, 96, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13363, 3541, 954, 97, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13362, 3537, 954, 97, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13361, 3529, 954, 97, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13366, 3562, 954, 98, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13365, 3561, 954, 98, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13364, 3558, 954, 98, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13367, 3567, 954, 98, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13371, 3585, 954, 99, 102);
INSERT INTO 'dancespublicationsmap' VALUES (15038, 13374, 1035, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15039, 13376, 1035, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15040, 13373, 1035, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15041, 1173, 1035, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15042, 1204, 1035, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15043, 13700, 1035, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15044, 13424, 1035, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15045, 13377, 1035, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15046, 13701, 1035, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15047, 13378, 1035, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15048, 9261, 1035, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15049, 13379, 1035, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15050, 13380, 1035, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15051, 13512, 1035, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15052, 13702, 1035, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15053, 12290, 1035, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15054, 11874, 1035, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15055, 11873, 1035, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15056, 13703, 1035, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15037, 587, 1035, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15057, 13381, 1035, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10593, 9286, 529, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10594, 9287, 529, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10595, 9288, 529, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10596, 9289, 529, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10597, 9290, 529, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10598, 9291, 529, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10601, 9294, 529, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10602, 9295, 529, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10603, 9296, 529, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11889, 10853, 574, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11890, 10854, 574, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11891, 10855, 574, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11892, 10856, 574, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11893, 10857, 574, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11894, 10858, 574, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11896, 10049, 574, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11895, 10859, 574, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11897, 8702, 574, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11898, 10860, 574, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15058, 13704, 1035, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15059, 12971, 1035, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15060, 13706, 1035, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15061, 13513, 1035, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15062, 13705, 1035, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (932, 1079, 96, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5511, 6378, 96, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1229, 1419, 96, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2125, 2446, 96, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2695, 3107, 96, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6281, 217, 96, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3597, 4137, 96, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (69, 81, 532, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (670, 783, 532, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5468, 6328, 532, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5723, 6626, 532, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1832, 2116, 532, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1927, 2229, 532, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5798, 6719, 532, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6025, 6984, 532, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2586, 2981, 532, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2665, 3073, 532, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2917, 3357, 532, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3388, 3900, 532, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3491, 4021, 532, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4556, 5263, 532, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4751, 5498, 532, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7700, 7893, 532, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (78, 90, 686, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5336, 6171, 686, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5339, 6175, 686, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5355, 6192, 686, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (908, 1053, 686, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5469, 6329, 686, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1394, 1617, 686, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1566, 1820, 686, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1715, 1985, 686, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8565, 1348, 342, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8566, 1582, 342, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8567, 1792, 342, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8568, 2250, 342, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8569, 4239, 342, 5, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8570, 4782, 342, 6, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8571, 4641, 342, 7, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8572, 5239, 342, 8, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8573, 5525, 342, 9, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2, 4, 524, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6459, 3626, 524, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5743, 6651, 686, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6058, 7023, 686, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3261, 3756, 686, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3820, 4395, 686, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4827, 5586, 686, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1244, 1440, 583, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1319, 1527, 583, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5769, 6680, 583, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5786, 6700, 583, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3824, 4400, 583, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (572, 666, 446, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1231, 1422, 446, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1914, 2211, 446, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2484, 2865, 446, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3106, 3576, 446, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3481, 4009, 446, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4711, 5452, 446, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5206, 6021, 446, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5255, 6076, 446, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3810, 4385, 446, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5752, 6660, 446, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6124, 7100, 446, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6672, 6803, 697, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2941, 3382, 697, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6044, 7007, 697, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6011, 6970, 697, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4478, 5173, 697, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5387, 6230, 697, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5704, 6606, 697, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5609, 6487, 697, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4062, 4683, 697, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (709, 828, 697, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2966, 3410, 697, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5004, 5790, 697, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (242, 283, 697, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5731, 6636, 697, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15325, 13874, 1054, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15326, 13875, 1054, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15327, 13876, 1054, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15328, 13877, 1054, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15329, 13878, 1054, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15331, 6252, 1054, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15332, 13879, 1054, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15333, 13880, 1054, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15334, 13881, 1054, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15335, 13882, 1054, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15336, 13883, 1054, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15337, 12567, 1054, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15338, 13884, 1054, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16847, 14959, 1144, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16846, 14958, 1144, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16845, 14957, 1144, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16844, 13517, 1144, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16843, 13678, 1144, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13368, 3570, 954, 99, 102);
INSERT INTO 'dancespublicationsmap' VALUES (16841, 13677, 1144, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16317, 10341, 684, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11312, 10161, 684, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11313, 10162, 684, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11314, 10163, 684, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11315, 10164, 684, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11316, 10165, 684, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11317, 10166, 684, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11319, 10168, 684, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11320, 10169, 684, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11321, 10170, 684, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11322, 10171, 684, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13370, 3580, 954, 99, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13369, 3575, 954, 99, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13749, 3577, 954, 99, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13372, 3588, 954, 100, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13374, 3594, 954, 100, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13375, 3595, 954, 100, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13373, 3589, 954, 100, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13376, 3601, 954, 100, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13377, 3607, 954, 100, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13381, 3616, 954, 101, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13382, 3617, 954, 101, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13379, 3611, 954, 101, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13380, 3615, 954, 101, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13378, 3609, 954, 101, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13383, 3620, 954, 102, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13384, 3623, 954, 102, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13386, 3631, 954, 102, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13387, 3635, 954, 102, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13385, 3625, 954, 102, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13392, 3659, 954, 103, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13391, 3656, 954, 103, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13390, 3638, 954, 103, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13388, 3636, 954, 103, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13389, 3637, 954, 103, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13792, 3691, 954, 104, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13395, 3685, 954, 104, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13399, 3711, 954, 106, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13401, 3723, 954, 107, 102);
INSERT INTO 'dancespublicationsmap' VALUES (6812, 7476, 793, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6721, 7365, 793, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6741, 7386, 793, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6720, 7364, 793, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6737, 7381, 793, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6747, 7394, 793, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6796, 7456, 793, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6792, 7447, 793, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6809, 7473, 793, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6813, 7478, 793, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1136, 1317, 217, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1791, 2071, 217, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1813, 2096, 217, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2245, 2584, 217, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2592, 2987, 217, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12145, 10598, 866, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12146, 11100, 866, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12147, 11101, 866, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12149, 10587, 866, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12148, 11102, 866, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12150, 11103, 866, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12151, 10593, 866, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12152, 11104, 866, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12153, 11105, 866, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12154, 10592, 866, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12155, 10594, 866, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (627, 733, 89, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1778, 2058, 89, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1782, 2062, 89, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6385, 2332, 46, 1, 11);
INSERT INTO 'dancespublicationsmap' VALUES (6471, 3762, 46, 2, 11);
INSERT INTO 'dancespublicationsmap' VALUES (6355, 1768, 46, 3, 11);
INSERT INTO 'dancespublicationsmap' VALUES (3188, 3667, 89, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3204, 3687, 89, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3373, 3884, 89, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6254, 7250, 89, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3490, 4020, 89, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3548, 4081, 89, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4340, 5017, 89, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5626, 6509, 89, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3823, 4399, 703, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (268, 313, 703, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5225, 6043, 703, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1096, 1273, 703, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2218, 2553, 703, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6127, 7103, 703, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1195, 1383, 703, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4566, 5275, 703, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6107, 7080, 703, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4529, 5232, 703, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16954, 15045, 1152, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16955, 15046, 1152, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16956, 15047, 1152, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16957, 15048, 1152, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16958, 15049, 1152, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16959, 15051, 1152, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16960, 15052, 1152, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16961, 13576, 1152, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16962, 15053, 1152, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16963, 15054, 1152, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16964, 7457, 1152, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4199, 4849, 736, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3606, 4148, 736, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2673, 3083, 736, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2999, 3446, 736, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4735, 5479, 736, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (142, 161, 736, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2685, 3095, 736, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (259, 302, 736, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2654, 3056, 736, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5843, 6770, 736, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16205, 14489, 1110, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16206, 14490, 1110, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16217, 12271, 1110, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16218, 14494, 1110, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16304, 14553, 1122, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4712, 5453, 174, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3872, 4453, 174, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4368, 5045, 174, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4707, 5448, 174, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2127, 2450, 174, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5966, 6914, 174, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3104, 3574, 174, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3227, 3717, 174, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3845, 4423, 174, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (718, 838, 174, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1062, 1230, 174, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4465, 5157, 174, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6693, 7336, 777, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6695, 7338, 777, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6801, 7462, 777, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6732, 7376, 777, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6736, 7380, 777, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6791, 7446, 777, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6797, 7457, 777, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6799, 7459, 777, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6806, 7470, 777, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6710, 7353, 777, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6866, 7541, 777, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6858, 7532, 777, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (153, 173, 179, 23, 31);
INSERT INTO 'dancespublicationsmap' VALUES (5058, 5848, 179, 18, 31);
INSERT INTO 'dancespublicationsmap' VALUES (5141, 5945, 179, 8, 31);
INSERT INTO 'dancespublicationsmap' VALUES (427, 497, 179, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (515, 598, 179, 17, 31);
INSERT INTO 'dancespublicationsmap' VALUES (559, 651, 179, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (576, 670, 179, 15, 31);
INSERT INTO 'dancespublicationsmap' VALUES (1376, 1593, 179, 14, 31);
INSERT INTO 'dancespublicationsmap' VALUES (2089, 2409, 179, 10, 31);
INSERT INTO 'dancespublicationsmap' VALUES (5953, 6897, 179, 16, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6019, 6978, 179, 13, 31);
INSERT INTO 'dancespublicationsmap' VALUES (2464, 2842, 179, 19, 31);
INSERT INTO 'dancespublicationsmap' VALUES (2715, 3129, 179, 22, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6135, 7111, 179, 9, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6198, 7189, 179, 6, 31);
INSERT INTO 'dancespublicationsmap' VALUES (3020, 3474, 179, 11, 31);
INSERT INTO 'dancespublicationsmap' VALUES (3567, 4102, 179, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (3631, 4175, 179, 20, 31);
INSERT INTO 'dancespublicationsmap' VALUES (4854, 5616, 179, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (4961, 5741, 179, 12, 31);
INSERT INTO 'dancespublicationsmap' VALUES (13406, 3735, 954, 107, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13404, 3729, 954, 107, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13402, 3725, 954, 107, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13405, 3737, 954, 107, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13403, 3730, 954, 107, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13407, 3743, 954, 108, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13409, 3759, 954, 108, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13408, 3748, 954, 108, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13412, 3774, 954, 109, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13413, 3775, 954, 109, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13411, 3769, 954, 109, 102);
INSERT INTO 'dancespublicationsmap' VALUES (419, 488, 188, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (466, 545, 188, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2082, 2401, 188, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4295, 4965, 188, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4557, 5264, 188, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4610, 5327, 188, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4661, 5388, 188, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4844, 5605, 188, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4858, 5620, 188, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5465, 6325, 148, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2395, 2760, 148, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (133, 149, 232, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (494, 575, 232, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12566, 501, 922, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12567, 199, 922, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3142, 3614, 42, 0, 18);
INSERT INTO 'dancespublicationsmap' VALUES (212, 248, 723, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1081, 1254, 723, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1419, 1644, 723, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1966, 2272, 723, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2079, 2398, 723, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4409, 5094, 723, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4599, 5314, 723, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4978, 5760, 723, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4979, 5762, 723, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12386, 11309, 907, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12387, 11310, 907, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12388, 11311, 907, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12389, 11312, 907, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12390, 11313, 907, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12391, 7422, 907, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12392, 11314, 907, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12393, 11315, 907, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12394, 11316, 907, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16, 19, 585, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5407, 6257, 585, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5456, 6315, 585, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1166, 1351, 585, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2405, 2774, 585, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6085, 7056, 585, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4254, 4915, 585, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4761, 5510, 585, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13410, 3762, 954, 109, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13414, 3783, 954, 110, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13416, 3788, 954, 110, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13415, 3786, 954, 110, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13419, 3829, 954, 111, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13418, 3802, 954, 111, 102);
INSERT INTO 'dancespublicationsmap' VALUES (14548, 12948, 996, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14549, 12949, 996, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14550, 12950, 996, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14551, 12951, 996, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14552, 12952, 996, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14553, 12953, 996, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14554, 12954, 996, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14555, 12955, 996, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14556, 12956, 996, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14557, 12957, 996, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14559, 12959, 996, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14560, 12960, 997, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14561, 12961, 997, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14562, 12962, 997, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14563, 12963, 997, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14564, 12964, 997, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14565, 12965, 997, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14566, 12966, 997, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14567, 12967, 997, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14568, 12968, 997, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14569, 12969, 997, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14570, 12970, 997, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14571, 12971, 997, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15685, 13416, 1072, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15686, 13417, 1072, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15687, 13418, 1072, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15688, 13419, 1072, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15689, 13420, 1072, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15690, 13421, 1072, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15691, 13422, 1072, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15692, 13423, 1072, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15693, 13424, 1072, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15694, 13425, 1072, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15695, 13426, 1072, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10842, 3212, 626, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10843, 1114, 626, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10440, 9139, 478, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10441, 9140, 478, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11551, 10407, 797, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11550, 10408, 797, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11552, 10409, 797, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11553, 10410, 797, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11554, 10411, 797, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11555, 10412, 797, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11556, 10413, 797, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11557, 10414, 797, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11558, 10415, 797, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16209, 7450, 1110, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16210, 14496, 1110, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15180, 13779, 1045, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15181, 13780, 1045, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16211, 14497, 1110, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16212, 14498, 1110, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16214, 14500, 1110, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7505, 1758, 313, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7564, 2947, 313, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6776, 7428, 793, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6763, 7411, 793, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1615, 1876, 159, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3954, 4553, 159, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4083, 4707, 159, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13417, 3789, 954, 111, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13421, 3859, 954, 111, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13420, 3834, 954, 111, 102);
INSERT INTO 'dancespublicationsmap' VALUES (6674, 2, 726, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6675, 193, 726, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6676, 1943, 726, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6677, 2168, 726, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6678, 2361, 726, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6679, 2375, 726, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6680, 2767, 726, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6681, 2858, 726, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6682, 5692, 726, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6683, 5728, 726, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6684, 5946, 726, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6685, 5991, 726, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6686, 6430, 726, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6687, 6454, 726, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6688, 6574, 726, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6689, 6714, 726, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6690, 6726, 726, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6691, 6928, 726, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6692, 7048, 726, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7780, 6582, 726, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5987, 6942, 717, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5988, 6943, 717, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5989, 6944, 717, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1032, 1192, 150, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1341, 1551, 150, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1536, 1781, 150, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5706, 6609, 150, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2048, 2360, 150, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6205, 7197, 150, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3465, 3988, 150, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3532, 4065, 150, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3576, 4112, 150, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4179, 4821, 150, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4861, 5623, 150, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4951, 5730, 150, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13422, 3862, 954, 112, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13424, 3888, 954, 112, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13423, 3887, 954, 112, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13427, 3921, 954, 113, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13425, 3912, 954, 113, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13429, 3932, 954, 113, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13426, 3915, 954, 113, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13428, 3931, 954, 113, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13434, 3953, 954, 114, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13430, 3934, 954, 114, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13431, 3938, 954, 114, 102);
INSERT INTO 'dancespublicationsmap' VALUES (10844, 7042, 630, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10845, 2008, 630, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7640, 7451, 332, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7641, 7785, 332, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7817, 8012, 332, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8607, 265, 332, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1854, 2138, 95, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (799, 930, 95, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2357, 2714, 95, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16312, 14431, 1102, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16306, 14686, 1102, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16307, 14685, 1102, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16308, 14684, 1102, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14900, 13635, 1025, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14901, 13636, 1025, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14902, 13637, 1025, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14903, 11720, 1025, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14904, 13638, 1025, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14905, 13639, 1025, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14906, 13640, 1025, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14907, 13641, 1025, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14908, 13642, 1025, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10958, 9661, 655, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10959, 9662, 655, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10960, 9663, 655, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10961, 9664, 655, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10962, 9665, 655, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10963, 9666, 655, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10964, 9667, 655, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10965, 9668, 655, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10966, 9669, 655, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10967, 9671, 655, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10968, 9670, 655, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10969, 9672, 655, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (541, 632, 729, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2181, 2513, 729, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5399, 6246, 729, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5839, 6766, 729, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15656, 6259, 1070, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15657, 2580, 1070, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15658, 203, 1070, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15659, 8201, 1070, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15660, 10532, 1070, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15661, 10533, 1070, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15662, 10437, 1070, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15663, 14136, 1070, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15664, 10535, 1070, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4422, 5110, 544, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6090, 7062, 544, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6023, 6982, 544, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4804, 5560, 544, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4778, 5530, 544, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4064, 4685, 544, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4063, 4684, 544, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4782, 5534, 544, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5977, 6930, 544, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1741, 2013, 544, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15603, 14114, 1068, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15604, 14115, 1068, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15605, 14116, 1068, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15606, 14117, 1068, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15607, 14118, 1068, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15608, 14119, 1068, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15609, 14120, 1068, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15610, 14121, 1068, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15611, 14122, 1068, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15612, 14123, 1068, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15613, 14124, 1068, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15614, 14125, 1068, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15615, 14126, 1068, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15616, 14127, 1068, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15617, 14128, 1068, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15618, 14129, 1068, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15619, 14130, 1068, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15620, 14131, 1068, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15621, 14132, 1068, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15622, 14133, 1068, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15665, 10531, 1070, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15666, 14137, 1070, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15667, 14138, 1070, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15668, 14139, 1070, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10047, 7400, 124, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10048, 7436, 124, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10049, 7519, 124, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10050, 7622, 124, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10051, 8746, 124, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10052, 8754, 124, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10053, 8755, 124, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11943, 790, 848, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12612, 11641, 848, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11942, 10901, 848, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11944, 10902, 848, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14575, 12974, 999, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14574, 12973, 999, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14583, 12982, 999, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14573, 9837, 999, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14580, 12979, 999, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14572, 12972, 999, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14576, 12975, 999, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3522, 4055, 106, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2872, 3307, 106, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6102, 7074, 106, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1627, 1889, 106, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5583, 6460, 106, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (724, 844, 106, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (614, 718, 106, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13433, 3941, 954, 114, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13432, 3940, 954, 114, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13438, 3986, 954, 115, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13437, 3980, 954, 115, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13436, 3972, 954, 115, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13435, 3963, 954, 115, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13440, 4032, 954, 116, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13441, 4046, 954, 116, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13439, 4015, 954, 116, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13445, 4086, 954, 117, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13446, 4102, 954, 117, 102);
INSERT INTO 'dancespublicationsmap' VALUES (310, 361, 463, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (346, 405, 463, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (431, 503, 463, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (579, 673, 463, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (797, 928, 463, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (873, 1012, 463, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1019, 1178, 463, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1159, 1344, 463, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1440, 1670, 463, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1449, 1680, 463, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1497, 1734, 463, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1678, 1947, 463, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1705, 1975, 463, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1859, 2145, 463, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2508, 2894, 463, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2868, 3301, 463, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2895, 3334, 463, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3069, 3533, 463, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3139, 3610, 463, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3332, 3841, 463, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3426, 3947, 463, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3554, 4088, 463, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3638, 4182, 463, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3745, 4307, 463, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3928, 4523, 463, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3972, 4571, 463, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4182, 4825, 463, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4299, 4970, 463, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4381, 5059, 463, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4456, 5146, 463, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1145, 1326, 466, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1149, 1330, 466, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1208, 1397, 466, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1212, 1401, 466, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1264, 1468, 466, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1278, 1482, 466, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1290, 1494, 466, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1328, 1538, 466, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1397, 1620, 466, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1400, 1623, 466, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1403, 1626, 466, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1427, 1652, 466, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1502, 1739, 466, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1454, 1685, 466, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1458, 1691, 466, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1475, 1710, 466, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1552, 1803, 466, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1561, 1815, 466, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1568, 1822, 466, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1590, 1849, 466, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1595, 1855, 466, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1623, 1885, 466, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1652, 1918, 466, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1653, 1919, 466, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1659, 1925, 466, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1753, 2028, 466, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1800, 2081, 466, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1866, 2155, 466, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2002, 2311, 466, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2009, 2318, 466, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2024, 2334, 466, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2030, 2340, 466, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2090, 2410, 467, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2119, 2440, 467, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2121, 2442, 467, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2142, 2466, 467, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2148, 2474, 467, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2153, 2479, 467, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2168, 2496, 467, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2295, 2646, 467, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2316, 2669, 467, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2336, 2692, 467, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2378, 2739, 467, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2424, 2796, 467, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2444, 2819, 467, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2449, 2824, 467, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2479, 2860, 467, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2491, 2872, 467, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2493, 2874, 467, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2549, 2940, 467, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2555, 2946, 467, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2599, 2996, 467, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2622, 3023, 467, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2619, 3018, 467, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2630, 3032, 467, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2638, 3040, 467, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2642, 3044, 467, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2706, 3119, 467, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2714, 3128, 467, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2762, 3178, 467, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2778, 3194, 467, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2886, 3322, 467, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2934, 3375, 467, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2847, 3275, 467, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3008, 3455, 468, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3292, 3795, 468, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1080, 1253, 466, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (491, 572, 451, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (825, 956, 451, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1300, 1504, 451, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1370, 1584, 451, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (218, 256, 462, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (263, 307, 462, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (529, 617, 462, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (530, 618, 462, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (674, 788, 462, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (898, 1041, 462, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3415, 3933, 462, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1089, 1263, 462, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1822, 2106, 462, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1940, 2243, 462, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1998, 2307, 462, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2117, 2438, 462, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2126, 2449, 462, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2556, 2948, 462, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (290, 337, 461, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (484, 565, 461, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1139, 1320, 461, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1176, 1362, 461, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7629, 7818, 461, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1790, 2070, 461, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2061, 2377, 461, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2073, 2392, 461, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2360, 2721, 461, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2486, 2867, 461, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3255, 3749, 461, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3431, 3952, 461, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7630, 7819, 461, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3587, 4125, 461, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4019, 4626, 461, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4136, 4766, 461, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4341, 5018, 461, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4434, 5123, 461, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4458, 5148, 461, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4469, 5162, 461, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4723, 5466, 461, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4784, 5538, 461, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3319, 3825, 468, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3338, 3848, 468, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3345, 3856, 468, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3497, 4027, 468, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3498, 4028, 468, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3517, 4049, 468, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3533, 4066, 468, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3561, 4095, 468, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3562, 4096, 468, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3648, 4194, 468, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3656, 4202, 468, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3739, 4298, 468, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3762, 4327, 468, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3817, 4392, 468, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3833, 4410, 468, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3835, 4412, 468, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3894, 4478, 468, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3903, 4488, 468, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3905, 4490, 468, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3908, 4493, 468, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3916, 4504, 468, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3926, 4520, 468, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3925, 4519, 468, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3937, 4532, 468, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3943, 4539, 468, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3948, 4546, 468, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3967, 4566, 468, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3975, 4574, 468, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3981, 4580, 468, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3979, 4578, 469, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3983, 4582, 469, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3988, 4587, 469, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3994, 4593, 469, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4003, 4606, 469, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4077, 4698, 469, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4098, 4722, 469, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4099, 4723, 469, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4110, 4735, 469, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4118, 4745, 469, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4133, 4762, 469, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4130, 4757, 469, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4169, 4807, 469, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4174, 4812, 469, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4997, 5783, 470, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5010, 5796, 470, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5024, 5810, 470, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5054, 5844, 470, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5083, 5879, 470, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5087, 5884, 470, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5200, 6015, 470, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5215, 6033, 470, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6148, 7127, 470, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5223, 6041, 470, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5224, 6042, 470, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5227, 6045, 470, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5289, 6115, 470, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5326, 6160, 470, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5330, 6164, 470, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5406, 6256, 470, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5353, 6189, 470, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2566, 2960, 472, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2846, 3274, 472, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13443, 4064, 954, 117, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13442, 4051, 954, 117, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13444, 4068, 954, 117, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13745, 4008, 954, 117, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13447, 4103, 954, 118, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13450, 4144, 954, 118, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13448, 4106, 954, 118, 102);
INSERT INTO 'dancespublicationsmap' VALUES (2870, 3305, 472, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3081, 3546, 472, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3146, 3618, 472, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3440, 3962, 472, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3574, 4109, 472, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3662, 4208, 472, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3791, 4362, 472, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3900, 4485, 472, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3921, 4509, 472, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4107, 4732, 472, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4164, 4802, 472, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4215, 4868, 472, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4482, 5178, 472, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4737, 5482, 472, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5285, 6111, 472, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5293, 6119, 472, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (831, 963, 471, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (846, 979, 471, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (877, 1016, 471, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1001, 1156, 471, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1175, 1361, 471, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1366, 1580, 471, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1390, 1611, 471, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1636, 1898, 471, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1806, 2087, 471, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1827, 2111, 471, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1895, 2187, 471, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1909, 2204, 471, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2049, 2362, 471, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2325, 2678, 471, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2633, 3035, 471, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2956, 3399, 471, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3075, 3539, 471, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3344, 3855, 471, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (411, 478, 472, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (716, 836, 472, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (784, 912, 472, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (820, 951, 472, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (955, 1104, 472, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1469, 1703, 472, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1787, 2067, 472, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1863, 2149, 472, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1907, 2200, 472, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2230, 2567, 472, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2513, 2899, 472, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (59, 70, 473, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (201, 234, 473, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (256, 299, 473, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (362, 422, 473, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (330, 383, 473, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (944, 1092, 473, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1287, 1491, 473, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1298, 1502, 473, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1515, 1755, 473, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1815, 2098, 473, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1624, 1886, 473, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1768, 2047, 473, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2219, 2554, 473, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2279, 2628, 473, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2310, 2662, 473, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2313, 2665, 473, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2330, 2684, 473, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2489, 2870, 473, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2571, 2965, 473, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2611, 3009, 473, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3849, 4428, 473, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2766, 3182, 473, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3816, 4391, 473, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2843, 3271, 473, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3453, 3976, 473, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3347, 3858, 473, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3868, 4449, 473, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3895, 4480, 473, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4081, 4703, 473, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13449, 4126, 954, 118, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13451, 4155, 954, 119, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13453, 4209, 954, 119, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13452, 4196, 954, 119, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13794, 10789, 954, 120, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13455, 4239, 954, 120, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13456, 4248, 954, 120, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13454, 4227, 954, 120, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13457, 4270, 954, 120, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13461, 4324, 954, 121, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13459, 4309, 954, 121, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13462, 4325, 954, 121, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13460, 4318, 954, 121, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13458, 4291, 954, 121, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13463, 4334, 954, 121, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13464, 4358, 954, 122, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13465, 4359, 954, 122, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13466, 4356, 954, 122, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13746, 4365, 954, 123, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13467, 4374, 954, 123, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13468, 4404, 954, 124, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13795, 7543, 954, 124, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13469, 4407, 954, 124, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13470, 4424, 954, 124, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13796, 4411, 954, 124, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13473, 4438, 954, 125, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13475, 4442, 954, 125, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13474, 4440, 954, 125, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13472, 4433, 954, 125, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13471, 4431, 954, 125, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13477, 4447, 954, 126, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13478, 4450, 954, 126, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13476, 4444, 954, 126, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13479, 4451, 954, 126, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13481, 4461, 954, 127, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13480, 4455, 954, 127, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13482, 4476, 954, 127, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13730, 4477, 954, 127, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13483, 4484, 954, 127, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13487, 4511, 954, 128, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13484, 4491, 954, 128, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13485, 4499, 954, 128, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13486, 4506, 954, 128, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13489, 4517, 954, 129, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13797, 9638, 954, 129, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13490, 4518, 954, 129, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13488, 4512, 954, 129, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13495, 4562, 954, 130, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13494, 4561, 954, 130, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13492, 4548, 954, 130, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13493, 4555, 954, 130, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13496, 4565, 954, 130, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13491, 4543, 954, 130, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13497, 4579, 954, 131, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13498, 4595, 954, 131, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13798, 10800, 954, 131, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13499, 4602, 954, 131, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13500, 4638, 954, 132, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13501, 4641, 954, 132, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13717, 4629, 954, 132, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13502, 4646, 954, 132, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13526, 4907, 954, 141, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13527, 4911, 954, 141, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13529, 4925, 954, 141, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13525, 4890, 954, 141, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13528, 4919, 954, 141, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13530, 4928, 954, 141, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13532, 4931, 954, 142, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13531, 4929, 954, 142, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13533, 4932, 954, 142, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13734, 4933, 954, 143, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13800, 9104, 954, 144, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13534, 4935, 954, 144, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13535, 4894, 954, 144, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13801, 11372, 954, 145, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13537, 4998, 954, 145, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13536, 4968, 954, 145, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13722, 5006, 954, 146, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13539, 5033, 954, 147, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13542, 5099, 954, 147, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13540, 5040, 954, 147, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13541, 5065, 954, 147, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13538, 5028, 954, 147, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13544, 5136, 954, 148, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13543, 5111, 954, 148, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13546, 5200, 954, 149, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13547, 5207, 954, 149, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13545, 5198, 954, 149, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13724, 5204, 954, 149, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13548, 5208, 954, 150, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13803, 5209, 954, 150, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13802, 9074, 954, 150, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13550, 5223, 954, 151, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13551, 5239, 954, 151, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13552, 5243, 954, 151, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13549, 5222, 954, 151, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13553, 5260, 954, 152, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13804, 11189, 954, 152, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13554, 5296, 954, 153, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13557, 5326, 954, 153, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13556, 5310, 954, 153, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13555, 5308, 954, 153, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13559, 5345, 954, 154, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13558, 5330, 954, 154, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13560, 5347, 954, 154, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13561, 5358, 954, 154, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13563, 5389, 954, 155, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13562, 5364, 954, 155, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13564, 723, 954, 155, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13565, 5398, 954, 155, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13723, 5412, 954, 156, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13567, 5403, 954, 156, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13566, 5402, 954, 156, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13612, 5858, 954, 168, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13657, 6420, 954, 184, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13661, 6523, 954, 185, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13659, 6471, 954, 185, 102);
INSERT INTO 'dancespublicationsmap' VALUES (7601, 7787, 458, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6092, 7064, 458, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6152, 7132, 458, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6173, 7158, 458, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6175, 7160, 458, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6178, 7165, 458, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6183, 7170, 458, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6221, 7214, 458, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6207, 7199, 458, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (624, 730, 458, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5418, 6270, 458, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (862, 1000, 458, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (148, 167, 454, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (182, 210, 454, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (455, 534, 454, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (539, 630, 454, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (550, 641, 454, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (587, 681, 454, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (649, 759, 454, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (664, 776, 454, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (696, 813, 454, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (741, 863, 454, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (795, 926, 454, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (857, 995, 454, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (771, 897, 454, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3147, 3619, 456, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3152, 3624, 456, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3290, 3793, 456, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7604, 7790, 456, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3369, 3880, 456, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3231, 3721, 456, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3434, 3956, 456, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3444, 3966, 456, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3458, 3981, 456, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3591, 4129, 456, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3584, 4122, 456, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3610, 4153, 456, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3759, 4323, 456, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1807, 2088, 458, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1308, 336, 453, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (289, 1513, 453, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (409, 476, 453, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5001, 5787, 453, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (522, 482, 453, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (414, 606, 453, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (479, 560, 453, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1505, 1742, 453, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (420, 489, 453, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4144, 4777, 453, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (492, 573, 453, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5345, 6181, 453, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5307, 6134, 458, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3815, 4390, 456, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4460, 5150, 458, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (230, 270, 459, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (244, 285, 459, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (260, 304, 459, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (691, 808, 459, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (733, 854, 459, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (760, 885, 459, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (791, 920, 459, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (824, 955, 459, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (865, 1003, 459, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1014, 1172, 459, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7655, 1571, 459, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1811, 2094, 459, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1844, 2128, 459, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1903, 2195, 459, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (226, 266, 450, 2, 40);
INSERT INTO 'dancespublicationsmap' VALUES (251, 294, 450, 3, 40);
INSERT INTO 'dancespublicationsmap' VALUES (287, 333, 450, 4, 40);
INSERT INTO 'dancespublicationsmap' VALUES (357, 416, 450, 5, 40);
INSERT INTO 'dancespublicationsmap' VALUES (755, 880, 450, 6, 40);
INSERT INTO 'dancespublicationsmap' VALUES (439, 512, 450, 7, 40);
INSERT INTO 'dancespublicationsmap' VALUES (573, 667, 450, 8, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1446, 1676, 450, 10, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1548, 1798, 450, 11, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12778, 11833, 939, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12779, 11834, 939, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12780, 11836, 939, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12781, 11837, 939, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12782, 11838, 939, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12783, 11839, 939, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12784, 11840, 939, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12785, 11841, 939, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12786, 11844, 939, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12787, 11845, 939, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12788, 11846, 939, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12789, 11847, 939, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12790, 11848, 939, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12791, 11849, 939, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12792, 11850, 939, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12793, 11851, 939, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12794, 11852, 939, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12795, 11853, 939, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12796, 11854, 939, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12797, 11855, 939, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12798, 11856, 939, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12799, 11857, 939, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12800, 11858, 939, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12801, 11859, 939, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12802, 11860, 939, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12803, 11861, 939, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12804, 11863, 939, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12805, 11864, 939, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12806, 11865, 939, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12807, 11158, 939, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12808, 11842, 939, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12809, 11843, 939, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22952, 11892, 1519, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22953, 12662, 1519, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22954, 11897, 1519, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22955, 10822, 1519, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22956, 12665, 1519, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22957, 9420, 1519, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22958, 9528, 1519, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22959, 9422, 1519, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22960, 12302, 1519, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16269, 14608, 1117, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16270, 14609, 1117, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16271, 14610, 1117, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16272, 14611, 1117, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16273, 14612, 1117, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16274, 14613, 1117, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16275, 14614, 1117, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16276, 14615, 1117, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16277, 14616, 1117, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16278, 14617, 1117, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16279, 14618, 1117, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16281, 14619, 1117, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16282, 14620, 1117, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16280, 14621, 1117, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13660, 6518, 954, 185, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13658, 6448, 954, 185, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13822, 11582, 954, 192, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13824, 10791, 954, 193, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13823, 10548, 954, 193, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13825, 11772, 954, 200, 102);
INSERT INTO 'dancespublicationsmap' VALUES (6146, 7124, 136, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6280, 159, 136, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1288, 1492, 136, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1935, 2237, 136, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4012, 4618, 136, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (248, 290, 251, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (622, 728, 251, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (941, 1089, 251, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (979, 1134, 251, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5445, 6300, 251, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1476, 1711, 251, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5876, 6810, 251, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2196, 2529, 251, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6026, 6986, 251, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4044, 4655, 251, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6238, 7233, 691, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4631, 5350, 691, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1015, 1173, 691, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2627, 3029, 691, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (225, 264, 691, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1712, 1982, 691, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6401, 2657, 691, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4882, 5648, 691, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5642, 6526, 691, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (612, 715, 516, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4155, 4791, 457, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3707, 4261, 457, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3719, 4274, 457, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4239, 4895, 457, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4303, 4974, 457, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4323, 4999, 457, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4380, 5058, 457, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4416, 5103, 457, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4569, 5278, 457, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4732, 5475, 457, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4744, 5491, 457, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5023, 5809, 457, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5152, 5959, 457, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1620, 1882, 756, 1, 35);
INSERT INTO 'dancespublicationsmap' VALUES (2662, 3069, 756, 4, 35);
INSERT INTO 'dancespublicationsmap' VALUES (800, 931, 756, 5, 35);
INSERT INTO 'dancespublicationsmap' VALUES (1131, 1311, 756, 7, 35);
INSERT INTO 'dancespublicationsmap' VALUES (5856, 6786, 756, 9, 35);
INSERT INTO 'dancespublicationsmap' VALUES (3026, 3480, 458, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3112, 3582, 458, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1391, 1614, 458, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1314, 1522, 458, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2755, 3171, 458, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2984, 3429, 458, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4335, 5012, 458, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7603, 7789, 458, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2398, 2764, 458, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2452, 2827, 459, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2646, 3048, 459, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2845, 3273, 459, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2893, 3332, 459, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3411, 3929, 459, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3421, 3942, 459, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3642, 4186, 459, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3914, 4502, 459, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3774, 4343, 459, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3941, 4536, 459, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4148, 4783, 459, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4157, 4793, 459, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4337, 5014, 459, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4365, 5042, 459, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4459, 5149, 459, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4582, 5297, 459, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6113, 7087, 691, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3392, 3908, 691, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21942, 8937, 1460, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21943, 18416, 1460, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21944, 15573, 1460, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21954, 18426, 1460, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21959, 18430, 1461, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21960, 18431, 1461, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14128, 11473, 644, 87, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14129, 11474, 644, 88, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14130, 11500, 644, 89, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6613, 6637, 206, 0, 31);
INSERT INTO 'dancespublicationsmap' VALUES (3189, 3668, 206, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2480, 2861, 206, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2238, 2575, 206, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5893, 6828, 206, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1734, 2005, 206, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6282, 235, 450, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7536, 905, 450, 9, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2416, 2787, 450, 18, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2431, 2804, 450, 19, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2461, 2839, 450, 20, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2595, 2991, 450, 21, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2567, 2961, 450, 22, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2728, 3143, 450, 23, 40);
INSERT INTO 'dancespublicationsmap' VALUES (61, 72, 242, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (701, 818, 242, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (867, 1005, 242, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (912, 1057, 242, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1024, 1184, 242, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5470, 6330, 242, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1226, 1416, 242, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5534, 6401, 242, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5581, 6457, 242, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1810, 2091, 242, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1889, 2181, 242, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5868, 6799, 242, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2306, 2658, 242, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6080, 7051, 242, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2659, 3064, 242, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2822, 3248, 242, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6241, 7236, 242, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6253, 7249, 242, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3171, 3648, 242, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3751, 4314, 242, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4742, 5488, 242, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (44, 53, 244, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (438, 511, 244, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (595, 692, 244, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1268, 1472, 244, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1417, 1642, 244, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1618, 1879, 244, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1732, 2003, 244, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2569, 2963, 244, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2806, 3227, 244, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6142, 7119, 244, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2923, 3363, 244, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3133, 3604, 244, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3528, 4061, 244, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3683, 4233, 244, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7802, 6798, 318, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7512, 7705, 318, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7606, 3646, 318, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7852, 3492, 318, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7548, 2688, 318, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (262, 306, 156, 2, 11);
INSERT INTO 'dancespublicationsmap' VALUES (278, 324, 156, 4, 11);
INSERT INTO 'dancespublicationsmap' VALUES (819, 950, 156, 6, 11);
INSERT INTO 'dancespublicationsmap' VALUES (931, 1077, 156, 8, 11);
INSERT INTO 'dancespublicationsmap' VALUES (1968, 2276, 156, 10, 11);
INSERT INTO 'dancespublicationsmap' VALUES (2065, 2383, 156, 12, 11);
INSERT INTO 'dancespublicationsmap' VALUES (2501, 2887, 156, 14, 11);
INSERT INTO 'dancespublicationsmap' VALUES (6034, 6995, 156, 32, 11);
INSERT INTO 'dancespublicationsmap' VALUES (2670, 3080, 156, 16, 11);
INSERT INTO 'dancespublicationsmap' VALUES (2884, 3320, 156, 18, 11);
INSERT INTO 'dancespublicationsmap' VALUES (4211, 4863, 156, 22, 11);
INSERT INTO 'dancespublicationsmap' VALUES (4220, 4873, 156, 24, 11);
INSERT INTO 'dancespublicationsmap' VALUES (6093, 7065, 156, 28, 11);
INSERT INTO 'dancespublicationsmap' VALUES (5352, 6188, 156, 26, 11);
INSERT INTO 'dancespublicationsmap' VALUES (2889, 3325, 156, 20, 11);
INSERT INTO 'dancespublicationsmap' VALUES (15962, 14320, 1093, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15964, 14322, 1093, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21414, 56, 1407, 3, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21059, 9838, 1407, 5, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21058, 159, 1407, 5, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21061, 183, 1407, 6, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21060, 14320, 1407, 6, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21062, 188, 1407, 7, 101);
INSERT INTO 'dancespublicationsmap' VALUES (17674, 15714, 1202, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17675, 15715, 1202, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17676, 15716, 1202, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17677, 15717, 1202, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17678, 15718, 1202, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17679, 15719, 1202, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17680, 15720, 1202, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17681, 15721, 1202, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17682, 15722, 1202, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17683, 15723, 1202, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17684, 15724, 1202, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17685, 15725, 1202, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17704, 15742, 1205, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17705, 15743, 1205, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17706, 15744, 1205, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17707, 15745, 1205, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17708, 15746, 1205, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17709, 15747, 1205, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17710, 15748, 1205, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17711, 15749, 1205, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17712, 15750, 1205, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17713, 15751, 1205, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17714, 15752, 1205, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17715, 15753, 1205, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17716, 15754, 1205, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17717, 15755, 1205, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17718, 15756, 1205, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17719, 15757, 1205, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17720, 15758, 1205, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17721, 15759, 1205, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17722, 15760, 1205, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17723, 15761, 1205, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17724, 9505, 1205, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17725, 15764, 1206, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17726, 13299, 1206, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17727, 12729, 1206, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17728, 15776, 1206, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17729, 12728, 1206, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17730, 15765, 1206, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17731, 15766, 1206, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17732, 15767, 1206, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17733, 15768, 1206, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17734, 15769, 1206, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17686, 15726, 1203, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17687, 15727, 1203, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17688, 8264, 1203, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17689, 15728, 1203, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17690, 15729, 1203, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17691, 15730, 1203, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22938, 19668, 1520, 605, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22939, 19669, 1520, 606, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22940, 19670, 1520, 607, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22946, 19675, 1520, 613, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22947, 13553, 1520, 614, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22948, 12902, 1520, 615, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22949, 19676, 1520, 616, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22951, 19677, 1520, 618, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17692, 14680, 1203, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6313, 828, 756, 2, 35);
INSERT INTO 'dancespublicationsmap' VALUES (6379, 2177, 756, 3, 35);
INSERT INTO 'dancespublicationsmap' VALUES (3366, 3877, 756, 6, 35);
INSERT INTO 'dancespublicationsmap' VALUES (3157, 3629, 756, 8, 35);
INSERT INTO 'dancespublicationsmap' VALUES (7782, 6587, 756, 10, 35);
INSERT INTO 'dancespublicationsmap' VALUES (15984, 12014, 1096, 1, 50);
INSERT INTO 'dancespublicationsmap' VALUES (15987, 12278, 1096, 4, 50);
INSERT INTO 'dancespublicationsmap' VALUES (15988, 12277, 1096, 5, 50);
INSERT INTO 'dancespublicationsmap' VALUES (15989, 13003, 1096, 6, 50);
INSERT INTO 'dancespublicationsmap' VALUES (15990, 12884, 1096, 7, 50);
INSERT INTO 'dancespublicationsmap' VALUES (15991, 13002, 1096, 8, 50);
INSERT INTO 'dancespublicationsmap' VALUES (15992, 13001, 1096, 9, 50);
INSERT INTO 'dancespublicationsmap' VALUES (17735, 15770, 1206, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17736, 15771, 1206, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17737, 15772, 1206, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17738, 15773, 1206, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17739, 15774, 1206, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17740, 15775, 1206, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17666, 13517, 1201, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17667, 13430, 1201, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17668, 13429, 1201, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17669, 13439, 1201, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17670, 13435, 1201, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17671, 15713, 1201, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17672, 13434, 1201, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17673, 13264, 1201, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17819, 15857, 1212, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17820, 15858, 1212, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17821, 15859, 1212, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17822, 15860, 1212, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17823, 15861, 1212, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17824, 15862, 1212, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17825, 15863, 1212, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17826, 15586, 1212, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17827, 15864, 1212, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17828, 15865, 1212, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17829, 15866, 1212, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17830, 15867, 1212, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17759, 15777, 1208, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17760, 15778, 1208, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17761, 15779, 1208, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17762, 15780, 1208, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17763, 15781, 1208, 29, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17764, 15782, 1208, 35, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17765, 14310, 1208, 43, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17766, 15783, 1208, 49, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17767, 15812, 1208, 55, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17768, 15813, 1208, 59, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17809, 15848, 1211, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17810, 15849, 1211, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17811, 15850, 1211, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17812, 15851, 1211, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17813, 15852, 1211, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17814, 13756, 1211, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17815, 15853, 1211, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17816, 15854, 1211, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17817, 15855, 1211, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17818, 15856, 1211, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17831, 15868, 1212, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17832, 15869, 1212, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17833, 15871, 1213, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17834, 15872, 1213, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17835, 15873, 1213, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17836, 15874, 1213, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17837, 15875, 1213, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17838, 15876, 1213, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17839, 15877, 1213, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17840, 15878, 1213, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17841, 15879, 1213, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17842, 15880, 1213, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21228, 12941, 1407, 63, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21232, 2267, 1407, 64, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21233, 2321, 1407, 64, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21231, 2263, 1407, 64, 101);
INSERT INTO 'dancespublicationsmap' VALUES (17780, 15823, 1210, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17779, 13446, 1210, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17781, 15825, 1210, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17782, 15826, 1210, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17783, 15827, 1210, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17328, 15361, 1175, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17325, 12517, 1175, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17769, 15814, 1209, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17770, 15815, 1209, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17771, 15816, 1209, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17772, 3487, 1209, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17773, 15817, 1209, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17774, 15818, 1209, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17775, 15819, 1209, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17776, 15820, 1209, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17777, 15821, 1209, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17784, 13209, 1210, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17785, 14422, 1210, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17786, 12279, 1210, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17326, 11156, 1175, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17329, 15362, 1175, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17330, 15363, 1175, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17331, 15364, 1175, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17327, 14988, 1175, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17337, 15369, 1175, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17338, 15370, 1175, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17339, 15371, 1175, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17340, 15372, 1175, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17778, 15822, 1210, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17853, 15892, 1215, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17854, 15893, 1215, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17855, 15895, 1215, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17856, 15896, 1215, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17857, 15897, 1215, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17858, 15898, 1215, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17859, 15899, 1215, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17860, 15900, 1215, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17861, 15901, 1215, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17862, 15902, 1215, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17863, 15903, 1215, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17864, 15904, 1215, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17865, 15905, 1215, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17866, 15906, 1215, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17867, 15907, 1215, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2293, 2644, 12, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2309, 2661, 12, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3178, 3656, 12, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1856, 2140, 12, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3066, 3528, 12, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6251, 7247, 12, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4771, 5520, 12, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5342, 6178, 12, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (462, 541, 12, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1621, 1883, 12, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3502, 4032, 12, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14940, 13681, 1028, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14941, 13682, 1028, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14942, 13683, 1028, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14944, 13328, 1028, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14945, 13684, 1028, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14946, 13685, 1028, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14947, 13686, 1028, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14948, 13687, 1028, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14949, 13688, 1028, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14950, 13689, 1028, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14951, 13690, 1028, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14952, 7563, 1028, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11287, 8923, 752, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11288, 10141, 752, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11289, 8925, 752, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11290, 10142, 752, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11291, 10143, 752, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11292, 10144, 752, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11293, 10145, 752, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11294, 10146, 752, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11295, 10147, 752, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11296, 10148, 752, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11297, 10149, 752, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11969, 10922, 852, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11970, 10923, 852, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11971, 10924, 852, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11973, 8864, 852, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14188, 12503, 982, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14189, 12504, 982, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14190, 12505, 982, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14191, 12506, 982, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14192, 12507, 982, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14193, 12508, 982, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14194, 12509, 982, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14195, 12510, 982, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14198, 12511, 982, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17741, 15762, 1207, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17742, 15763, 1207, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17743, 15784, 1207, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17744, 15785, 1207, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17745, 15786, 1207, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17746, 15787, 1207, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17747, 15788, 1207, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17748, 15789, 1207, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17749, 15790, 1207, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17750, 15791, 1207, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17751, 15792, 1207, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17752, 15793, 1207, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17753, 15794, 1207, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (11298, 10150, 752, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17894, 15924, 1219, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17895, 15925, 1219, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17896, 15926, 1219, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17897, 15927, 1219, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17898, 15928, 1219, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17899, 15930, 1219, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17900, 15931, 1219, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17901, 15932, 1219, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17902, 15933, 1219, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17903, 15934, 1219, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17904, 15935, 1219, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17905, 15936, 1219, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17906, 15937, 1219, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17907, 15938, 1219, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17908, 15939, 1219, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17909, 15940, 1219, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17910, 14388, 1220, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17911, 15941, 1220, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17912, 15942, 1220, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17913, 15943, 1220, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17914, 15944, 1220, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17915, 15945, 1220, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17916, 15946, 1220, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17917, 15947, 1220, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17918, 15948, 1220, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17919, 15949, 1220, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17920, 15950, 1220, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17921, 15951, 1220, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17922, 15952, 1220, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17923, 15953, 1220, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17924, 15954, 1220, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17925, 15955, 1220, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17868, 15908, 1216, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17869, 15909, 1216, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17870, 15910, 1216, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17871, 15911, 1216, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17872, 15912, 1216, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17873, 15914, 1216, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17874, 15177, 1216, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17875, 15915, 1216, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17876, 15180, 1216, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17877, 15916, 1216, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17878, 15917, 1216, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17879, 15918, 1216, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17880, 15919, 1216, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17943, 15960, 1222, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17944, 15967, 1222, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17945, 10352, 1222, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17946, 15962, 1222, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17947, 15963, 1222, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17948, 15964, 1222, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17949, 15965, 1222, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17950, 15966, 1222, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17931, 13487, 1221, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17932, 13476, 1221, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17933, 13485, 1221, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17934, 13483, 1221, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17935, 13481, 1221, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17936, 13489, 1221, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17937, 13486, 1221, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17929, 13351, 1221, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17938, 13488, 1221, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17939, 13478, 1221, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17881, 15920, 1216, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17882, 15921, 1216, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17883, 15178, 1216, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17884, 15922, 1216, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17885, 15923, 1216, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17951, 3695, 1223, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17952, 8725, 1223, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17953, 10468, 1223, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17954, 10467, 1223, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17955, 15969, 1223, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17956, 15970, 1223, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17957, 15971, 1223, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17958, 15972, 1223, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17959, 15973, 1223, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17960, 15974, 1223, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17961, 15975, 1223, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17341, 15373, 1175, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17940, 13475, 1221, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17930, 13479, 1221, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17941, 13477, 1221, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (13608, 5794, 954, 168, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13614, 5878, 954, 169, 102);
INSERT INTO 'dancespublicationsmap' VALUES (18009, 16019, 1228, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18010, 16020, 1228, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18011, 16021, 1228, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18012, 16022, 1228, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18013, 16023, 1228, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18014, 16024, 1228, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (13615, 5889, 954, 169, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13616, 5897, 954, 169, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13613, 5860, 954, 169, 102);
INSERT INTO 'dancespublicationsmap' VALUES (21293, 2956, 1407, 82, 101);
INSERT INTO 'dancespublicationsmap' VALUES (13618, 5906, 954, 170, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13617, 5904, 954, 170, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13620, 5921, 954, 171, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13619, 5915, 954, 171, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13621, 5927, 954, 172, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13811, 5936, 954, 172, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13622, 5934, 954, 172, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13623, 5937, 954, 172, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13626, 5964, 954, 173, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13625, 5963, 954, 173, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13624, 5945, 954, 173, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13627, 5981, 954, 173, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13630, 6029, 954, 174, 102);
INSERT INTO 'dancespublicationsmap' VALUES (18015, 15342, 1229, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18016, 15343, 1229, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18017, 16026, 1229, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18018, 15414, 1229, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18019, 16027, 1229, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17998, 13897, 1227, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (18047, 15676, 1070, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21296, 2979, 1407, 83, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18043, 16057, 1221, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18044, 16058, 1221, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16129, 14460, 1108, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16130, 13932, 1108, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16132, 292, 1108, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16133, 7598, 1108, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16134, 9543, 1108, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16135, 481, 1108, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16136, 699, 1108, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16137, 849, 1108, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16138, 917, 1108, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16140, 14461, 1108, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10041, 5829, 497, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6579, 5904, 497, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6521, 4642, 497, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (980, 1135, 497, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3180, 3658, 497, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3575, 4110, 497, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22417, 6858, 1489, 63, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22418, 17798, 1489, 64, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22419, 16382, 1489, 65, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22420, 7027, 1489, 66, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22421, 7164, 1489, 67, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22422, 7204, 1489, 68, 35);
INSERT INTO 'dancespublicationsmap' VALUES (17989, 16004, 1225, 33, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17990, 16005, 1225, 34, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17991, 16006, 1225, 35, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17962, 15980, 1224, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17963, 15981, 1224, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17964, 14738, 1224, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17965, 15982, 1224, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17967, 15984, 1224, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17968, 15985, 1224, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17969, 15986, 1224, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17970, 15987, 1224, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17971, 15988, 1224, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17973, 15990, 1224, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17974, 15991, 1224, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17975, 15992, 1224, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17976, 15993, 1224, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16141, 1171, 1108, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16142, 1207, 1108, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16143, 13270, 1108, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16144, 1549, 1108, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16145, 8532, 1108, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16147, 14462, 1108, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16148, 14463, 1108, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16150, 1991, 1108, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16151, 2008, 1108, 54, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16152, 14464, 1108, 56, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16153, 2298, 1108, 58, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16154, 7716, 1108, 60, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16155, 9332, 1108, 62, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16157, 13931, 1108, 68, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16159, 3212, 1108, 72, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16160, 11890, 1108, 74, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16161, 13207, 1108, 76, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16162, 14466, 1108, 78, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16163, 3490, 1108, 80, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16165, 3726, 1108, 84, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16166, 4398, 1108, 86, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16168, 12954, 1108, 90, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16169, 8068, 1108, 92, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16171, 14467, 1108, 96, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16172, 14468, 1108, 98, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16174, 14470, 1108, 102, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16176, 5936, 1108, 106, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16177, 6217, 1108, 108, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16181, 13933, 1108, 118, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18020, 16028, 1229, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18021, 16030, 1229, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18022, 16029, 1229, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18023, 16031, 1229, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18024, 16032, 1229, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18025, 16033, 1229, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18026, 16034, 1229, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18027, 16035, 1229, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18028, 16036, 1229, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18029, 16037, 1230, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18030, 16038, 1230, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18031, 15606, 1230, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18032, 16039, 1230, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15669, 10534, 1070, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15670, 14140, 1070, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15671, 14141, 1070, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18045, 14346, 1070, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18046, 16068, 1070, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18033, 16040, 1230, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18034, 16041, 1230, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18035, 16042, 1230, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18036, 16043, 1230, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18037, 16047, 1230, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18038, 15360, 1230, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16182, 7531, 1108, 120, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16183, 14472, 1108, 124, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16184, 7042, 1108, 126, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17843, 15881, 1214, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17844, 15882, 1214, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17845, 15883, 1214, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21295, 13579, 1407, 83, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21297, 3057, 1407, 84, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21299, 7285, 1407, 85, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21298, 11186, 1407, 85, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21300, 9636, 1407, 86, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21301, 7560, 1407, 86, 101);
INSERT INTO 'dancespublicationsmap' VALUES (16100, 14427, 1106, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16104, 13210, 1106, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16105, 14435, 1106, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16106, 14436, 1106, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16109, 14438, 1106, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16110, 14439, 1106, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13057, 40, 954, 1, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13751, 11543, 954, 1, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13750, 9106, 954, 1, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13056, 15, 954, 1, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13058, 43, 954, 2, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13059, 51, 954, 2, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13060, 54, 954, 2, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13062, 56, 954, 3, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13063, 76, 954, 3, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13061, 55, 954, 3, 102);
INSERT INTO 'dancespublicationsmap' VALUES (22994, 19748, 1522, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22995, 19749, 1522, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22996, 19750, 1522, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22997, 19751, 1522, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22998, 19752, 1522, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22999, 19753, 1522, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23000, 19754, 1522, 29, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23001, 19755, 1522, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23002, 19756, 1522, 31, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23003, 19757, 1522, 32, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23004, 19758, 1522, 33, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22962, 17628, 1521, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22963, 19705, 1521, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22964, 19706, 1521, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22965, 19707, 1521, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22966, 19708, 1521, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22967, 19709, 1521, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22968, 19710, 1521, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22969, 19711, 1521, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22970, 19713, 1521, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22971, 19714, 1521, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22972, 19715, 1521, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22973, 19716, 1521, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22974, 19728, 1522, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22975, 19729, 1522, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22976, 19730, 1522, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22977, 19731, 1522, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16952, 14711, 1151, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (21302, 9836, 1407, 86, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21303, 3105, 1407, 86, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21304, 3108, 1407, 87, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21305, 3129, 1407, 87, 101);
INSERT INTO 'dancespublicationsmap' VALUES (15319, 13868, 1053, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22978, 19732, 1522, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22979, 19733, 1522, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22980, 19734, 1522, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22981, 19735, 1522, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22982, 19736, 1522, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22983, 19737, 1522, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22984, 19738, 1522, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22985, 19739, 1522, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22986, 19740, 1522, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22987, 19741, 1522, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22988, 19742, 1522, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22989, 19743, 1522, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22990, 19744, 1522, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22991, 19745, 1522, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22992, 19746, 1522, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22993, 19747, 1522, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (21635, 7093, 1407, 186, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21633, 7061, 1407, 186, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21638, 7111, 1407, 187, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21637, 7109, 1407, 187, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21639, 7124, 1407, 187, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21636, 7105, 1407, 187, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21640, 7139, 1407, 188, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21642, 7152, 1407, 188, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21641, 7147, 1407, 188, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21643, 7180, 1407, 189, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21645, 7188, 1407, 189, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21644, 7182, 1407, 189, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21646, 7189, 1407, 189, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21647, 11772, 1407, 190, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21648, 7204, 1407, 190, 101);
INSERT INTO 'dancespublicationsmap' VALUES (17983, 16000, 1224, 26, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17984, 16001, 1224, 27, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17985, 16002, 1224, 28, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17986, 16004, 1224, 33, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17987, 16005, 1224, 34, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17988, 16006, 1224, 35, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22400, 17797, 1489, 40, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22401, 5174, 1489, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22440, 19162, 1489, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22402, 5206, 1489, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22403, 5279, 1489, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22441, 19163, 1489, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22404, 17795, 1489, 47, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22405, 11661, 1489, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22406, 5696, 1489, 49, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22407, 13278, 1489, 50, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22408, 17796, 1489, 51, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22409, 17794, 1489, 52, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22410, 12516, 1489, 53, 35);
INSERT INTO 'dancespublicationsmap' VALUES (14153, 11445, 644, 112, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14154, 12485, 644, 113, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14155, 11502, 644, 114, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14156, 11492, 644, 115, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14157, 11458, 644, 116, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14158, 12480, 644, 117, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14159, 11451, 644, 118, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14160, 11471, 644, 119, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22219, 18628, 1482, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22220, 18629, 1482, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22221, 18630, 1482, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22225, 18634, 1482, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22226, 18635, 1482, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22227, 18636, 1482, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22228, 18637, 1482, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22229, 18638, 1482, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22230, 18639, 1482, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22231, 18640, 1482, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22232, 18641, 1482, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22233, 18642, 1482, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22234, 18643, 1482, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22235, 14400, 1482, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22236, 18644, 1482, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22237, 18645, 1482, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22238, 18646, 1482, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22239, 18647, 1482, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22240, 18648, 1482, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22241, 18649, 1482, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22242, 18650, 1482, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22243, 18651, 1482, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22244, 18652, 1482, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22245, 18653, 1482, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22246, 10361, 1482, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22046, 16078, 1466, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22041, 16064, 1466, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22047, 5142, 1466, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22048, 7890, 1466, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22049, 16063, 1466, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22059, 18506, 1466, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22058, 18504, 1466, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22057, 18505, 1466, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22050, 16059, 1466, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10450, 9149, 479, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10451, 9150, 479, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10452, 9151, 479, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10453, 9152, 479, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10454, 9153, 479, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10455, 9154, 479, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10456, 9155, 479, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10457, 9156, 479, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14131, 12494, 644, 90, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14132, 12490, 644, 91, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14133, 11469, 644, 92, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14134, 11466, 644, 93, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14135, 11467, 644, 94, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14136, 11490, 644, 95, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14137, 11443, 644, 96, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14138, 11509, 644, 97, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14139, 12486, 644, 98, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14140, 11495, 644, 99, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14141, 10900, 644, 100, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14142, 12483, 644, 101, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14143, 12492, 644, 102, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14144, 12489, 644, 103, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14145, 10247, 644, 104, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14146, 11497, 644, 105, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14147, 11461, 644, 106, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14148, 11460, 644, 107, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14149, 11496, 644, 108, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14150, 11457, 644, 109, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14151, 12484, 644, 110, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14152, 11449, 644, 111, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14161, 11504, 644, 120, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14162, 12481, 644, 121, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14163, 11462, 644, 122, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14164, 11507, 644, 123, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14165, 11510, 644, 124, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14166, 11452, 644, 125, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14167, 12478, 644, 126, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14168, 11470, 644, 127, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14169, 11447, 644, 128, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14170, 11503, 644, 129, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14171, 11501, 644, 130, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14172, 11498, 644, 131, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14173, 11505, 644, 132, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14174, 11440, 644, 133, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14175, 11493, 644, 134, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14176, 11506, 644, 135, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14177, 11439, 644, 136, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14178, 11448, 644, 137, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14179, 11489, 644, 138, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14180, 12491, 644, 139, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14181, 11464, 644, 140, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14182, 11475, 644, 141, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12593, 11621, 924, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12594, 11622, 924, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12595, 11623, 924, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12596, 11624, 924, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12597, 11625, 924, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12598, 11626, 924, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22252, 18979, 1483, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22253, 18998, 1483, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22254, 18982, 1483, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22255, 19001, 1483, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22256, 18991, 1483, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22257, 18986, 1483, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22258, 18985, 1483, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22259, 19004, 1483, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22260, 19002, 1483, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22261, 19007, 1483, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22262, 18999, 1483, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22263, 18983, 1483, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22264, 19006, 1483, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22265, 18987, 1483, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22266, 18992, 1483, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22267, 18989, 1483, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22268, 18988, 1483, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22269, 18996, 1483, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22270, 19000, 1483, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22271, 18997, 1483, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22272, 18981, 1483, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22273, 19008, 1483, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22274, 18994, 1483, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22275, 19005, 1483, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22276, 18995, 1483, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22277, 18984, 1483, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22278, 18993, 1483, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22279, 18980, 1483, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22280, 19003, 1483, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22281, 18990, 1483, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22282, 19009, 1483, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22286, 19013, 1128, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22283, 17472, 1128, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22284, 18969, 1128, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3328, 3835, 439, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2993, 3438, 439, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (746, 870, 439, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3060, 3522, 439, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3641, 4185, 439, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (689, 806, 439, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3102, 3572, 439, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1214, 1403, 439, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2475, 2854, 439, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3361, 3872, 439, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6317, 878, 439, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2214, 2548, 439, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (123, 139, 439, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5455, 6313, 439, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (424, 494, 439, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4899, 5670, 439, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2375, 2736, 439, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (640, 749, 439, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5484, 6345, 439, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2457, 2834, 439, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1316, 1524, 439, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1078, 1251, 439, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3709, 4263, 439, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2881, 3316, 439, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3364, 3875, 439, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (400, 465, 439, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (641, 750, 439, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2229, 2566, 439, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (338, 393, 439, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (27, 34, 439, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6199, 7190, 439, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2185, 2517, 439, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6394, 2560, 439, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6336, 1217, 439, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5371, 6208, 439, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2162, 2489, 439, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6562, 5517, 439, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7510, 7697, 296, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7489, 7655, 296, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7620, 7808, 296, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7814, 357, 296, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7653, 7838, 296, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7511, 7701, 296, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7471, 7626, 296, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7479, 7641, 296, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21653, 2499, 1409, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21689, 7605, 1420, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21654, 4834, 1410, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8620, 8091, 80, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8621, 8093, 80, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10849, 4514, 631, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10848, 7075, 631, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21681, 1991, 1414, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21682, 481, 1414, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21677, 699, 1412, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21678, 1804, 1412, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21683, 9332, 1415, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21686, 4983, 1417, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21687, 5936, 1418, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21688, 6217, 1419, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10840, 9564, 625, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10841, 9565, 625, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10846, 1171, 630, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10847, 3678, 630, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11866, 10805, 842, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11867, 10806, 842, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11868, 10807, 842, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11869, 10808, 842, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11870, 10809, 842, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11871, 10810, 842, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11872, 10811, 842, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12163, 8102, 884, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12164, 11111, 884, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12165, 8138, 884, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3718, 4273, 136, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5113, 5911, 136, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2882, 3317, 136, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2023, 2333, 136, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11861, 9888, 840, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11862, 10798, 840, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11865, 5952, 840, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11863, 9124, 840, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11864, 10799, 840, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11873, 10812, 842, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11874, 10813, 842, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11875, 10814, 842, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11876, 10815, 842, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11877, 10816, 842, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6750, 7397, 793, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6865, 7540, 793, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6749, 7396, 793, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6823, 7489, 793, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6782, 7435, 793, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6759, 7407, 793, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6833, 7500, 793, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21690, 18225, 1421, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21691, 5440, 1422, 1, 35);
INSERT INTO 'dancespublicationsmap' VALUES (18039, 16048, 1230, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18040, 16049, 1230, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18041, 16050, 1230, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18042, 16051, 1230, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21655, 192, 1411, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21656, 215, 1411, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21657, 1543, 1411, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21658, 2770, 1411, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21659, 2941, 1411, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21660, 4610, 1411, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21661, 5271, 1411, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21662, 6057, 1411, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (170, 194, 736, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2769, 3185, 736, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5820, 6745, 736, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2788, 3206, 736, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5093, 5891, 736, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5160, 5968, 736, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4852, 5614, 736, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4846, 5608, 736, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17694, 15732, 1204, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17695, 15733, 1204, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17696, 15734, 1204, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17697, 15735, 1204, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17698, 15736, 1204, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17699, 15737, 1204, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17700, 15738, 1204, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17701, 15739, 1204, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17702, 15740, 1204, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17703, 15741, 1204, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21663, 6177, 1411, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21664, 6801, 1411, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21665, 93, 1411, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21666, 1066, 1411, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21667, 1315, 1411, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21668, 1499, 1411, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21669, 1843, 1411, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21670, 1913, 1411, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21671, 2809, 1411, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21672, 2157, 1411, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21673, 3351, 1411, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21674, 5721, 1411, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21675, 6020, 1411, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21676, 6431, 1411, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22070, 18524, 1472, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22071, 18525, 1472, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22072, 18526, 1472, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22073, 18527, 1472, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22074, 18528, 1472, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22075, 18529, 1472, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22076, 18530, 1472, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22077, 18531, 1472, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22078, 18532, 1472, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18631, 16507, 1268, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18736, 16617, 1268, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18685, 16567, 1268, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18740, 16618, 1268, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18739, 16619, 1268, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22024, 10820, 1465, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22025, 18490, 1465, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22026, 17882, 1465, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22027, 18491, 1465, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22028, 18492, 1465, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22029, 18493, 1465, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22030, 18494, 1465, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22031, 12036, 1465, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22032, 152, 1465, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22033, 428, 1465, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18738, 16620, 1268, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18633, 15455, 1268, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18737, 16621, 1268, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21679, 917, 1413, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21680, 4426, 1413, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21684, 3726, 1416, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21685, 849, 1416, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22060, 18511, 1471, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22061, 18279, 1471, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22062, 18512, 1471, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22063, 18513, 1471, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22064, 18514, 1471, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22065, 18515, 1471, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12613, 11642, 926, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12614, 11643, 926, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12615, 11644, 926, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12616, 11645, 926, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12617, 11646, 926, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12618, 11647, 926, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10056, 8758, 124, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10057, 8759, 124, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10058, 8760, 124, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6673, 4858, 155, 9, 40);
INSERT INTO 'dancespublicationsmap' VALUES (794, 924, 155, 18, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5992, 6947, 155, 21, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1581, 1840, 155, 22, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3393, 3909, 155, 23, 40);
INSERT INTO 'dancespublicationsmap' VALUES (469, 549, 155, 30, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12619, 11648, 926, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12620, 11649, 926, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12621, 11650, 926, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18792, 16622, 1268, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18793, 16623, 1268, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18634, 16509, 1268, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18794, 16673, 1268, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18798, 16674, 1268, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18797, 16675, 1268, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18796, 16676, 1268, 26, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18795, 16677, 1268, 29, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18632, 16508, 1268, 30, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22085, 18545, 1473, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22086, 18546, 1473, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22087, 18547, 1473, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21040, 18198, 1406, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21041, 18199, 1406, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21042, 18200, 1406, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21043, 6607, 1406, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21044, 18202, 1406, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21045, 502, 1406, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22079, 18539, 1473, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22080, 18540, 1473, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22081, 18541, 1473, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22082, 18542, 1473, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22083, 18543, 1473, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22084, 18544, 1473, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22098, 18594, 1475, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22088, 10495, 1474, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22089, 12725, 1474, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22090, 12724, 1474, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22091, 12726, 1474, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22092, 18509, 1474, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22093, 18593, 1474, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22094, 18592, 1474, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22095, 18591, 1474, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22096, 18590, 1474, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22097, 18589, 1474, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22099, 18595, 1475, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22100, 14952, 1475, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22101, 18597, 1475, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22102, 18598, 1475, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22103, 18599, 1475, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22104, 18600, 1475, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22105, 18601, 1475, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22106, 18602, 1475, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22107, 18603, 1475, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22108, 18604, 1475, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22109, 18605, 1475, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22110, 18606, 1475, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22111, 18607, 1475, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22112, 18608, 1475, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22034, 282, 1466, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22035, 454, 1466, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22036, 1142, 1466, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22037, 12196, 1466, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22038, 12206, 1466, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22039, 12228, 1466, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22040, 2513, 1466, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22051, 18498, 1466, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22052, 18499, 1466, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22055, 18500, 1466, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22054, 18501, 1466, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22042, 13216, 1466, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22043, 13215, 1466, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22053, 18502, 1466, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22044, 15217, 1466, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22045, 4075, 1466, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22056, 18503, 1466, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13167, 8086, 954, 37, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13766, 1330, 954, 38, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13172, 1296, 954, 38, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13765, 7654, 954, 38, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13173, 1348, 954, 39, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13174, 1358, 954, 39, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13175, 1366, 954, 39, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13767, 11374, 954, 39, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13178, 1375, 954, 40, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13177, 1372, 954, 40, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13179, 1376, 954, 40, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13176, 1368, 954, 40, 102);
INSERT INTO 'dancespublicationsmap' VALUES (18156, 16136, 1240, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18157, 15179, 1240, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18158, 16137, 1240, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18159, 16138, 1240, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18160, 16139, 1240, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18161, 16140, 1240, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18162, 16141, 1240, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18163, 16142, 1240, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21063, 11184, 1407, 7, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21064, 218, 1407, 8, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21065, 11376, 1407, 8, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21068, 224, 1407, 9, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21069, 9138, 1407, 9, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21067, 223, 1407, 9, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21066, 221, 1407, 9, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21074, 335, 1407, 12, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21075, 340, 1407, 12, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21076, 377, 1407, 13, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21080, 413, 1407, 13, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21079, 13149, 1407, 13, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21081, 439, 1407, 14, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21082, 442, 1407, 14, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21083, 445, 1407, 14, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21110, 773, 1407, 23, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21113, 794, 1407, 23, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21111, 9456, 1407, 23, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21114, 816, 1407, 24, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21116, 11188, 1407, 24, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21115, 822, 1407, 24, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21119, 887, 1407, 25, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21117, 848, 1407, 25, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21118, 873, 1407, 25, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21121, 894, 1407, 26, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21144, 13584, 1407, 34, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21158, 1405, 1407, 38, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18048, 14996, 1231, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18049, 16073, 1231, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18050, 16074, 1231, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18051, 16075, 1231, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18052, 12789, 1231, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18053, 16076, 1231, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18054, 16077, 1231, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18055, 16078, 1231, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18056, 16079, 1231, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18057, 13349, 1231, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18058, 13336, 1231, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18059, 16080, 1232, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18060, 16081, 1232, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18061, 16082, 1232, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18062, 16083, 1232, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18063, 16084, 1232, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18064, 14697, 1232, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18065, 16085, 1232, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18066, 14393, 1232, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18067, 16086, 1232, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18068, 15687, 1233, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18069, 15688, 1233, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18070, 15689, 1233, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18071, 15690, 1233, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18072, 15691, 1233, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18073, 15692, 1233, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18074, 15693, 1233, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18075, 15694, 1233, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18076, 15695, 1233, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18077, 15696, 1233, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18078, 14672, 1233, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18079, 12390, 1233, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18080, 16087, 1234, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18081, 16088, 1234, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18082, 16089, 1234, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18083, 16090, 1234, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18084, 16091, 1234, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18085, 16092, 1234, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18086, 16093, 1234, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18087, 16094, 1234, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18088, 16095, 1234, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18089, 16096, 1234, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18090, 16097, 1235, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18091, 14393, 1235, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18092, 8167, 1235, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18093, 16098, 1235, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18094, 16099, 1235, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18095, 8169, 1235, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18096, 16100, 1235, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18097, 16101, 1235, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18098, 16102, 1235, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18099, 16103, 1235, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18100, 16104, 1235, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18101, 16105, 1235, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18102, 16111, 1235, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18103, 16112, 1235, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18104, 8166, 1235, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20066, 16065, 1351, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20067, 17595, 1351, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20068, 17596, 1351, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20070, 17597, 1351, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20071, 17598, 1351, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20072, 17599, 1351, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20073, 17600, 1351, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18105, 16113, 1235, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18106, 15270, 1236, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18107, 15267, 1236, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18108, 15269, 1236, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18109, 2531, 1236, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18110, 12107, 1236, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18111, 15266, 1236, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18112, 16114, 1236, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18113, 16115, 1236, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18114, 14216, 1236, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18115, 9224, 1236, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18116, 1872, 1236, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18117, 16116, 1236, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18118, 4010, 1236, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18119, 8366, 1236, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18120, 8361, 1236, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18121, 2509, 1236, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18122, 1002, 1236, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18124, 16117, 1237, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18125, 16118, 1237, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18126, 16119, 1237, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18127, 16120, 1237, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18128, 16121, 1237, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18129, 16122, 1237, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18130, 16123, 1237, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18131, 16124, 1237, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18132, 16125, 1237, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15766, 13330, 1080, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15767, 13331, 1080, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15771, 11756, 1080, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15768, 13332, 1080, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15772, 14211, 1080, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15773, 14212, 1080, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15774, 14213, 1080, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15775, 12169, 1080, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5, 8, 102, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (88, 101, 102, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (909, 1054, 102, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5452, 6308, 102, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1407, 1630, 102, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1990, 2299, 102, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3857, 4437, 102, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4835, 5596, 102, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18133, 16126, 1238, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18134, 13270, 1238, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18135, 10800, 1238, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18136, 6689, 1238, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18137, 15023, 1238, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18138, 224, 1238, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18139, 10298, 1238, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18140, 6073, 1238, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18141, 16127, 1238, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18142, 13593, 1238, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18143, 13594, 1238, 26, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18166, 10113, 1241, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18167, 16145, 1241, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18168, 16146, 1241, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18169, 16147, 1241, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18170, 16148, 1241, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18171, 16149, 1241, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18172, 1943, 1241, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18173, 16150, 1241, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18174, 16151, 1241, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (7643, 4326, 333, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7740, 5849, 333, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7806, 6887, 280, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7787, 6646, 280, 2, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7442, 7136, 280, 3, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7707, 2175, 280, 4, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8773, 4008, 280, 5, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7708, 6314, 280, 6, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1514, 1754, 622, 2, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1493, 1730, 622, 8, 40);
INSERT INTO 'dancespublicationsmap' VALUES (18175, 16152, 622, 13, 40);
INSERT INTO 'dancespublicationsmap' VALUES (18176, 4250, 868, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18164, 16143, 1240, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18165, 16144, 1240, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21157, 7375, 1407, 38, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21159, 9157, 1407, 38, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21163, 1426, 1407, 39, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21160, 11763, 1407, 39, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21162, 9083, 1407, 39, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21165, 1465, 1407, 40, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21164, 8165, 1407, 40, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21166, 1466, 1407, 40, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21169, 1478, 1407, 41, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21167, 1469, 1407, 41, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21168, 1473, 1407, 41, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21170, 1480, 1407, 42, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21174, 10788, 1407, 43, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21185, 11512, 1407, 47, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21188, 1758, 1407, 48, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21189, 1777, 1407, 48, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21187, 10433, 1407, 48, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21191, 1786, 1407, 49, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21195, 1847, 1407, 49, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21190, 1782, 1407, 49, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21194, 1838, 1407, 49, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21193, 1834, 1407, 49, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21192, 1792, 1407, 49, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21196, 1864, 1407, 50, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21197, 1884, 1407, 51, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21198, 1891, 1407, 51, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21201, 1931, 1407, 52, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21199, 9853, 1407, 52, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21200, 9107, 1407, 52, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21204, 1965, 1407, 53, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21202, 12793, 1407, 53, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21203, 12794, 1407, 53, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21205, 1966, 1407, 54, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21208, 2024, 1407, 54, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21207, 2004, 1407, 54, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21206, 1998, 1407, 54, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21211, 15307, 1407, 55, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21209, 2030, 1407, 55, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21210, 2063, 1407, 55, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21212, 2077, 1407, 56, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21213, 2084, 1407, 56, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21215, 2110, 1407, 57, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21214, 14138, 1407, 57, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21216, 6957, 1407, 57, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21217, 11773, 1407, 58, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21218, 15403, 1407, 58, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21219, 2153, 1407, 58, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21227, 2166, 1407, 59, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21221, 11367, 1407, 59, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21220, 2158, 1407, 59, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21223, 2222, 1407, 60, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21222, 13544, 1407, 60, 101);
INSERT INTO 'dancespublicationsmap' VALUES (2536, 2924, 81, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5728, 6632, 81, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18249, 16178, 1244, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18250, 15221, 1245, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17192, 14545, 1164, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17195, 15227, 1164, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17193, 14547, 1164, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17187, 15223, 1164, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17196, 15228, 1164, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17191, 14563, 1164, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17189, 15225, 1164, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18191, 15226, 1164, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17190, 14548, 1164, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17188, 15224, 1164, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17194, 14541, 1164, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14463, 12795, 773, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14464, 12796, 773, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14465, 7629, 773, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14466, 12797, 773, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14467, 12798, 773, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14468, 2364, 773, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14469, 12799, 773, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14470, 12800, 773, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14471, 12801, 773, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14472, 12802, 773, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14473, 12803, 773, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14474, 12804, 773, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14475, 12805, 773, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14476, 12806, 773, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15179, 12807, 773, 32, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6766, 7415, 786, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6829, 7495, 786, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6767, 7417, 786, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6863, 7538, 786, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6714, 7357, 786, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15160, 974, 1044, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15161, 6382, 1044, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15162, 992, 1044, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15163, 5686, 1044, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15164, 3569, 1044, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15165, 6819, 1044, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15166, 981, 1044, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15167, 400, 1044, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15168, 1470, 1044, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15171, 2510, 1044, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15172, 5090, 1044, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15173, 2085, 1044, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15174, 6744, 1044, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15175, 2352, 1044, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15176, 4026, 1044, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15177, 4652, 1044, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15178, 4813, 1044, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4042, 4652, 58, 7, 21);
INSERT INTO 'dancespublicationsmap' VALUES (4175, 4813, 58, 8, 21);
INSERT INTO 'dancespublicationsmap' VALUES (2268, 2615, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6072, 7040, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3256, 3751, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6354, 1765, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6375, 2141, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3723, 4281, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6481, 3923, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4625, 5343, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (274, 320, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5112, 5910, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5133, 5933, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (298, 346, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (367, 429, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5194, 6009, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (743, 866, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5323, 6157, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5366, 6203, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (961, 1111, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5480, 6340, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5481, 6341, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1358, 1572, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1460, 1694, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1481, 1717, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1649, 1915, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5684, 6580, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5714, 6617, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5829, 6755, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1938, 2241, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1971, 2279, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18177, 16162, 1242, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18178, 14321, 1242, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18179, 16164, 1242, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18180, 16165, 1242, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18181, 14322, 1242, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18182, 16167, 1242, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18183, 16168, 1242, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18184, 16169, 1242, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18185, 15359, 1242, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18186, 16171, 1242, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18187, 16172, 1242, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18188, 14320, 1242, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18189, 16174, 1242, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18190, 16175, 1242, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5885, 6820, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5899, 6835, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3014, 3464, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6231, 7224, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6233, 7228, 78, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7481, 1118, 78, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7610, 3760, 78, 52, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7770, 6458, 78, 53, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6109, 7082, 217, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2746, 3162, 217, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3501, 4031, 217, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3771, 4340, 217, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4298, 4969, 217, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4558, 5265, 217, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4663, 5390, 217, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21423, 16525, 1407, 60, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21224, 11483, 1407, 61, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21225, 12803, 1407, 62, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21226, 16533, 1407, 63, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21230, 2250, 1407, 63, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21229, 2242, 1407, 63, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21236, 15411, 1407, 65, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21235, 2332, 1407, 65, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21234, 2323, 1407, 65, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21241, 2367, 1407, 66, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21237, 2349, 1407, 66, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21239, 2353, 1407, 66, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21240, 2360, 1407, 66, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21243, 2389, 1407, 67, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21249, 2428, 1407, 68, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21246, 2409, 1407, 68, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21248, 2421, 1407, 68, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21247, 2415, 1407, 68, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21251, 2436, 1407, 69, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21253, 2453, 1407, 69, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21250, 2431, 1407, 69, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21252, 2437, 1407, 69, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21257, 2501, 1407, 70, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21256, 2498, 1407, 70, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21254, 2469, 1407, 70, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21255, 2494, 1407, 70, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21258, 10232, 1407, 71, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21260, 250, 1407, 71, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21259, 2506, 1407, 71, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21262, 2562, 1407, 72, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21261, 13078, 1407, 72, 101);
INSERT INTO 'dancespublicationsmap' VALUES (16456, 1768, 1127, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16457, 1884, 1127, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16458, 2323, 1127, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16459, 2332, 1127, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16460, 2353, 1127, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16461, 2357, 1127, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16462, 2453, 1127, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16463, 3365, 1127, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16464, 3418, 1127, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16466, 3762, 1127, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16467, 4256, 1127, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16468, 4424, 1127, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16469, 4444, 1127, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16470, 4484, 1127, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16471, 4555, 1127, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16472, 4796, 1127, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16473, 4803, 1127, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16474, 4871, 1127, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16475, 7613, 1127, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16476, 8729, 1127, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16477, 5219, 1127, 25, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16478, 5422, 1127, 26, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17693, 15731, 1203, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2597, 2994, 524, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4690, 5419, 524, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (599, 698, 524, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6314, 843, 524, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6585, 5993, 524, 9, 31);
INSERT INTO 'dancespublicationsmap' VALUES (3433, 3954, 524, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6010, 6969, 524, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16479, 5529, 1127, 27, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16480, 5860, 1127, 28, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16481, 5904, 1127, 29, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16482, 6091, 1127, 30, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16483, 6701, 1127, 31, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16528, 14740, 1134, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16529, 14741, 1134, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16531, 14636, 1134, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21264, 2593, 1407, 73, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21265, 2600, 1407, 73, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21263, 8674, 1407, 73, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21266, 15402, 1407, 74, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21267, 2604, 1407, 74, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21268, 2616, 1407, 74, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21269, 13580, 1407, 75, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21270, 2661, 1407, 75, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21272, 12802, 1407, 76, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21271, 9332, 1407, 76, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21273, 2700, 1407, 77, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21274, 2713, 1407, 78, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21286, 13587, 1407, 81, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21287, 2910, 1407, 81, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21289, 2924, 1407, 81, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21288, 2918, 1407, 81, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21294, 2962, 1407, 82, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21290, 2934, 1407, 82, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21291, 8087, 1407, 82, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21292, 2947, 1407, 82, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21306, 14685, 1407, 88, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21307, 3165, 1407, 88, 101);
INSERT INTO 'dancespublicationsmap' VALUES (8630, 8105, 80, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8623, 8095, 80, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8624, 8096, 80, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8625, 8097, 80, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8626, 8098, 80, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8627, 8099, 80, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8628, 8100, 80, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14300, 12620, 988, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14301, 12621, 988, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14302, 12622, 988, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14303, 12623, 988, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14304, 12624, 988, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14305, 12625, 988, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14306, 12626, 988, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14307, 12627, 988, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14308, 12628, 988, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14294, 12614, 987, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14295, 12615, 987, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14296, 12616, 987, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14297, 12617, 987, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14298, 12618, 987, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14299, 12619, 987, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18338, 16215, 1248, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18339, 16216, 1248, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18340, 16217, 1248, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18341, 16218, 1248, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18342, 16219, 1248, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18343, 16220, 1248, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (8629, 8104, 80, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8631, 8106, 80, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18367, 16245, 1250, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18368, 16246, 1250, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18369, 16247, 1250, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18370, 16248, 1250, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18371, 16249, 1250, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18372, 16250, 1250, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18373, 16251, 1250, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18374, 16252, 1250, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18375, 16254, 1250, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18376, 16253, 1250, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18377, 4303, 1251, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18378, 16260, 1251, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18379, 5524, 1251, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18380, 16261, 1251, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18381, 16262, 1251, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18382, 16263, 1251, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18383, 16264, 1251, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18384, 16265, 1251, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18385, 16266, 1251, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18386, 16267, 1251, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18387, 16268, 1251, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18388, 16269, 1251, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18389, 16270, 1251, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18390, 16286, 1252, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18391, 16283, 1252, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18392, 16278, 1252, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18393, 16275, 1252, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18394, 16273, 1252, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18395, 16281, 1252, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18396, 16279, 1252, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18397, 16274, 1252, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18398, 16276, 1252, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18399, 16287, 1252, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18400, 16284, 1252, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18401, 14930, 1252, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18402, 16271, 1252, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18403, 16272, 1252, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18404, 16285, 1252, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18405, 15618, 1252, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18406, 16280, 1252, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18407, 16277, 1252, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18408, 16282, 1252, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17611, 7900, 1197, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17610, 15611, 1197, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17613, 15625, 1197, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17614, 15626, 1197, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17615, 15627, 1197, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17616, 15628, 1197, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17617, 15629, 1197, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17618, 15630, 1197, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (8632, 8107, 80, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8633, 8108, 80, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8634, 8109, 80, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21308, 3172, 1407, 89, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18409, 16296, 1253, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18410, 16297, 1253, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18411, 16298, 1253, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18412, 16299, 1253, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18413, 16300, 1253, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18414, 16301, 1253, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18415, 16302, 1253, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18416, 16303, 1253, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18417, 16304, 1253, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18418, 16305, 1253, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21309, 10794, 1407, 89, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18419, 16307, 1253, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18420, 16308, 1253, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18421, 16309, 1253, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18422, 16310, 1253, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18423, 16311, 1253, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18424, 16312, 1253, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18425, 16314, 1253, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18426, 16315, 1253, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18427, 16316, 1253, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18428, 16317, 1253, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18429, 16318, 1253, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18430, 16319, 1253, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21310, 10792, 1407, 90, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21311, 12542, 1407, 90, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21313, 3246, 1407, 91, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21315, 3281, 1407, 91, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21318, 3323, 1407, 92, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21320, 3338, 1407, 93, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21321, 7283, 1407, 93, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21322, 3365, 1407, 93, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21326, 3441, 1407, 94, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21323, 3397, 1407, 94, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21325, 3435, 1407, 94, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21324, 3418, 1407, 94, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21328, 3475, 1407, 95, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21327, 3463, 1407, 95, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21332, 3529, 1407, 96, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21339, 3528, 1407, 96, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21329, 3485, 1407, 96, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21330, 3506, 1407, 96, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21334, 9787, 1407, 97, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21333, 14977, 1407, 97, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21336, 3558, 1407, 98, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21335, 17143, 1407, 98, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21337, 3561, 1407, 98, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21343, 3593, 1407, 99, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21341, 3577, 1407, 99, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18431, 16320, 1253, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18432, 16321, 1253, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18433, 16322, 1253, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18434, 16323, 1253, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18435, 16324, 1253, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18436, 16325, 1253, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18437, 16326, 1253, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18438, 16327, 1253, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18439, 16328, 1253, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18440, 16329, 1253, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18441, 16330, 1253, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18442, 16332, 1253, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18443, 16333, 1253, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18444, 16331, 1253, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18445, 16334, 1254, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18446, 16335, 1254, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18447, 16336, 1254, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21342, 3588, 1407, 99, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18528, 16417, 1260, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18529, 11989, 1260, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18530, 16418, 1260, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18531, 11679, 1260, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18532, 16419, 1260, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18533, 16420, 1260, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18534, 16421, 1260, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18535, 16422, 1260, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18536, 16423, 1260, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18537, 16424, 1260, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18538, 16425, 1260, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18539, 11988, 1260, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18540, 16426, 1260, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18541, 16427, 1260, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14894, 13630, 1025, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18307, 14636, 1246, 74, 12);
INSERT INTO 'dancespublicationsmap' VALUES (14895, 13631, 1025, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14896, 10469, 1025, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14897, 13632, 1025, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14898, 13633, 1025, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14899, 13634, 1025, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (21340, 3580, 1407, 99, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21338, 3562, 1407, 99, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21347, 12124, 1407, 100, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21346, 3609, 1407, 100, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21345, 3607, 1407, 100, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21344, 3594, 1407, 100, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21349, 3637, 1407, 101, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21348, 3636, 1407, 101, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21350, 3672, 1407, 101, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21352, 3659, 1407, 101, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21351, 3678, 1407, 102, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21353, 3691, 1407, 102, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21354, 3710, 1407, 102, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21357, 3759, 1407, 103, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21375, 3980, 1407, 109, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21377, 4015, 1407, 110, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18542, 16428, 1261, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18543, 15903, 1261, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18544, 16429, 1261, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18545, 16430, 1261, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18546, 16431, 1261, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18547, 15893, 1261, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18548, 16432, 1261, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18549, 16433, 1261, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18550, 16434, 1261, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18551, 15679, 1261, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18552, 16435, 1261, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18553, 16436, 1261, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18554, 16437, 1261, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18555, 16438, 1261, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18556, 16439, 1261, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18557, 16440, 1261, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18558, 16441, 1261, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18559, 16442, 1261, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18560, 16443, 1261, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6370, 1969, 197, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6493, 4179, 197, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21376, 16536, 1407, 110, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21378, 4032, 1407, 110, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21380, 4008, 1407, 111, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21379, 4046, 1407, 111, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21383, 4102, 1407, 111, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21384, 4103, 1407, 111, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21385, 4155, 1407, 112, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21381, 4106, 1407, 112, 101);
INSERT INTO 'dancespublicationsmap' VALUES (6176, 7161, 197, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2124, 2445, 197, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21382, 4127, 1407, 112, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21387, 17138, 1407, 113, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21388, 4239, 1407, 113, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21386, 4209, 1407, 113, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21415, 4555, 1407, 119, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21417, 4562, 1407, 119, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18475, 16365, 1257, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18476, 16366, 1257, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18477, 16367, 1257, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12941, 12004, 930, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18478, 16368, 1257, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18480, 16369, 1257, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18479, 11659, 1257, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18481, 16370, 1257, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18482, 16371, 1257, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18483, 16372, 1257, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18484, 16373, 1257, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18486, 16375, 1257, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18485, 16374, 1257, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18487, 16376, 1257, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18488, 16377, 1257, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18490, 16379, 1257, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18489, 16378, 1257, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18492, 16381, 1257, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18491, 16380, 1257, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18493, 16382, 1257, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18494, 16383, 1257, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18495, 16384, 1257, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18496, 16385, 1257, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18498, 16387, 1257, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18497, 16386, 1257, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18501, 16390, 1258, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18499, 16388, 1258, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18500, 16389, 1258, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18504, 16393, 1258, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18503, 16392, 1258, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18502, 16391, 1258, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18506, 16395, 1258, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18505, 16394, 1258, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18507, 16396, 1258, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18508, 16397, 1258, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18510, 16399, 1258, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18561, 16444, 1261, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18562, 16445, 1261, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18563, 16446, 1261, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18564, 16447, 1261, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18565, 16448, 1261, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18566, 16449, 1261, 25, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18567, 15900, 1261, 26, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18568, 15897, 1261, 27, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18569, 16450, 1261, 28, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18570, 15892, 1261, 29, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18571, 16451, 1261, 30, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18572, 16452, 1261, 31, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18573, 16453, 1261, 32, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18574, 15902, 1261, 33, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18575, 16454, 1261, 34, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18576, 16455, 1261, 35, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21161, 4629, 1407, 120, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21418, 4565, 1407, 120, 101);
INSERT INTO 'dancespublicationsmap' VALUES (11000, 9679, 646, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11001, 9167, 646, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11002, 8811, 646, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11003, 8922, 646, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11092, 9812, 646, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11093, 4799, 646, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11373, 8853, 646, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11464, 10284, 646, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12671, 11706, 646, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21419, 10376, 1407, 120, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18664, 16547, 1271, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18665, 16548, 1271, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18666, 16549, 1271, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18667, 16550, 1271, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18448, 17501, 1255, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18668, 16551, 1272, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18669, 16552, 1272, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18670, 16553, 1272, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18671, 16554, 1272, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18672, 16555, 1272, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18673, 4623, 1272, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18674, 16557, 1272, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18675, 4269, 1272, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18644, 16522, 1264, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18645, 16523, 1264, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18646, 16524, 1264, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21422, 11814, 1407, 121, 101);
INSERT INTO 'dancespublicationsmap' VALUES (16620, 14601, 1139, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16622, 11627, 1139, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16621, 14566, 1139, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16615, 14798, 1139, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16613, 14792, 1139, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16611, 14791, 1139, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16623, 13113, 1139, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16624, 13114, 1139, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16625, 11628, 1139, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16616, 14790, 1139, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18593, 10782, 1139, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16618, 14788, 1139, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16619, 14787, 1139, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21421, 4641, 1407, 121, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21420, 14688, 1407, 121, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18612, 16488, 1266, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18613, 16489, 1266, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18614, 16490, 1266, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18615, 16491, 1266, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18616, 16492, 1266, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18621, 16497, 1266, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18617, 16493, 1266, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18622, 16498, 1266, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18623, 16499, 1266, 25, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18618, 16494, 1266, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18619, 16495, 1266, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18620, 16496, 1266, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18624, 16500, 1267, 42, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18625, 16501, 1267, 44, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18626, 16502, 1267, 45, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18627, 16503, 1267, 48, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18628, 16504, 1267, 49, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18629, 16505, 1267, 51, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18630, 16506, 1267, 54, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18579, 15338, 1263, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18580, 16465, 1263, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18647, 16525, 1264, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18648, 16526, 1264, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18649, 16527, 1264, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18643, 13648, 1264, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18650, 16533, 1264, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18651, 16534, 1264, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18652, 16535, 1264, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18653, 16536, 1264, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18654, 16537, 1264, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12719, 9787, 935, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12716, 6964, 935, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12720, 11770, 935, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12721, 11771, 935, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12722, 11772, 935, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12723, 11773, 935, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12717, 11763, 935, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12715, 9093, 935, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18365, 16243, 1249, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18366, 16244, 1249, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18656, 16539, 1270, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18657, 16540, 1270, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18658, 16541, 1270, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18659, 16542, 1270, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18660, 16543, 1270, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18661, 16544, 1270, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18662, 16545, 1270, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18663, 16546, 1270, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21178, 4646, 1407, 122, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21425, 12690, 1407, 122, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21424, 4662, 1407, 122, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21331, 4679, 1407, 122, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18687, 16463, 1262, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18577, 10751, 1262, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18578, 10753, 1262, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18686, 10749, 1262, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18688, 16572, 1262, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18689, 16573, 1262, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18690, 16574, 1262, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18691, 16575, 1262, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18692, 16576, 1262, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18693, 16577, 1262, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18694, 16578, 1262, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18695, 16579, 1262, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18581, 16466, 1263, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18655, 15706, 1263, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18583, 14405, 1263, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (21427, 4692, 1407, 123, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21426, 7286, 1407, 123, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21430, 14321, 1407, 124, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21432, 4728, 1407, 124, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21431, 4720, 1407, 124, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18696, 16580, 1274, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18697, 16581, 1274, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18698, 16582, 1274, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18699, 16584, 1274, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18700, 16583, 1274, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18701, 16585, 1274, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18702, 16586, 1274, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18703, 16587, 1274, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18704, 16588, 1274, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18705, 16589, 1274, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18706, 16590, 1274, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18707, 16591, 1274, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18708, 16592, 1274, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18709, 16593, 1274, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18710, 16594, 1274, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18841, 16724, 1281, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18842, 16726, 1281, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18843, 16727, 1281, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18844, 16728, 1281, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18845, 15341, 1281, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18846, 12907, 1281, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18847, 16729, 1281, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18848, 16730, 1281, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18840, 16725, 1281, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21428, 10653, 1407, 124, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18849, 6394, 1281, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21433, 4759, 1407, 125, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21434, 4782, 1407, 125, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21435, 4784, 1407, 125, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21436, 4796, 1407, 125, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21437, 4803, 1407, 126, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21439, 4808, 1407, 126, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21438, 4805, 1407, 126, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21459, 5033, 1407, 134, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21462, 11787, 1407, 134, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21460, 5040, 1407, 134, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21465, 12538, 1407, 136, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21474, 5207, 1407, 139, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21476, 5208, 1407, 140, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21475, 9074, 1407, 140, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21477, 5209, 1407, 140, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21478, 5239, 1407, 140, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21480, 5260, 1407, 141, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21479, 5243, 1407, 141, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21481, 11189, 1407, 142, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21482, 5296, 1407, 142, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21483, 5308, 1407, 143, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21484, 5326, 1407, 143, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21489, 5355, 1407, 144, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21488, 12454, 1407, 144, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21490, 5389, 1407, 145, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21491, 5412, 1407, 146, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21487, 5407, 1407, 146, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18812, 16692, 1279, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18813, 16693, 1279, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18814, 16694, 1279, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21496, 10773, 1407, 148, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18815, 16695, 1279, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18678, 15405, 1273, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18679, 16560, 1273, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18680, 16561, 1273, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18681, 16562, 1273, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18682, 16563, 1273, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18636, 16512, 1269, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18637, 16513, 1269, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18638, 16514, 1269, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18639, 16515, 1269, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18640, 16516, 1269, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18683, 16564, 1273, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18684, 16565, 1273, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18676, 16558, 1272, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18677, 16559, 1272, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18711, 16595, 1275, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18712, 16596, 1275, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18713, 16597, 1275, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18714, 16598, 1275, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18734, 16616, 1275, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18715, 16599, 1275, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18716, 16600, 1275, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18717, 16601, 1275, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18718, 16602, 1275, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18719, 16603, 1275, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18721, 16155, 1275, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18724, 16606, 1275, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18723, 16607, 1275, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18722, 16608, 1275, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18733, 16615, 1275, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18732, 16614, 1275, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18725, 16478, 1275, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18731, 16613, 1275, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18730, 16612, 1275, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18729, 16611, 1275, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18726, 14789, 1275, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18728, 16610, 1275, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18727, 16609, 1275, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18735, 14964, 1275, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18816, 16696, 1279, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18818, 16697, 1279, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21498, 10008, 1407, 149, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21497, 5480, 1407, 149, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21499, 5497, 1407, 149, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21500, 9882, 1407, 150, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21503, 8956, 1407, 150, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21506, 8970, 1407, 157, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21580, 8709, 1407, 167, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21578, 6210, 1407, 167, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18799, 16679, 1278, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18800, 16680, 1278, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18801, 16681, 1278, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18802, 16682, 1278, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18803, 16683, 1278, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18804, 16684, 1278, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18805, 16685, 1278, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18806, 16686, 1278, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6662, 4933, 761, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6665, 7284, 761, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6666, 7285, 761, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6667, 7286, 761, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17499, 939, 1185, 110, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17500, 3973, 1185, 111, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17501, 6788, 1185, 112, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18807, 16687, 1279, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18808, 16688, 1279, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18809, 16689, 1279, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18810, 16690, 1279, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18811, 16691, 1279, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6670, 5354, 761, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17502, 559, 1185, 201, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17503, 89, 1185, 202, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17504, 7090, 1185, 203, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17505, 1826, 1185, 204, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17506, 3920, 1185, 205, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17507, 5615, 1185, 206, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17508, 6099, 1185, 207, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17509, 1150, 1185, 208, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17510, 3869, 1185, 209, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17511, 3176, 1185, 210, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17512, 2313, 1185, 211, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17513, 5801, 1185, 212, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17514, 4383, 1185, 301, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17515, 4564, 1185, 302, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17516, 2295, 1185, 303, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18819, 16701, 1280, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18820, 16702, 1280, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18821, 16703, 1280, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18822, 16704, 1280, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18823, 16705, 1280, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18824, 16707, 1280, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18825, 16708, 1280, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18826, 16710, 1280, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18827, 16711, 1280, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18828, 16712, 1280, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18829, 16713, 1280, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18830, 16714, 1280, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18831, 16715, 1280, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18832, 16716, 1280, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18833, 16717, 1280, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18834, 16718, 1280, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18835, 16719, 1280, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18836, 16720, 1280, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18837, 16721, 1280, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18838, 16722, 1280, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18839, 16723, 1280, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17517, 6685, 1185, 304, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17518, 5016, 1185, 305, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17519, 6996, 1185, 306, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17520, 803, 1185, 307, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17521, 6348, 1185, 308, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17522, 6614, 1185, 309, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17523, 5617, 1185, 310, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17524, 3536, 1185, 311, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17525, 6615, 1185, 312, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17526, 54, 1185, 313, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17527, 2269, 1185, 314, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17528, 3833, 1185, 315, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17529, 4808, 1185, 316, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17530, 2033, 1185, 317, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17531, 5928, 1185, 318, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17532, 6545, 1185, 319, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21579, 6224, 1407, 167, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18890, 16755, 1284, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18891, 16756, 1284, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18892, 16757, 1284, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18893, 16758, 1284, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18894, 16759, 1284, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18895, 16760, 1284, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4941, 5719, 77, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6622, 6830, 751, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6644, 7267, 751, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4324, 5000, 751, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4869, 5631, 751, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18850, 15128, 1179, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17394, 15468, 1179, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17395, 15469, 1179, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10226, 3861, 818, 7, 32);
INSERT INTO 'dancespublicationsmap' VALUES (10227, 5945, 818, 8, 32);
INSERT INTO 'dancespublicationsmap' VALUES (18851, 497, 1282, 1, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18852, 651, 1282, 2, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18853, 5616, 1282, 3, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18854, 4102, 1282, 4, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18855, 3567, 1282, 5, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18856, 7189, 1282, 6, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18857, 3861, 1282, 7, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18858, 5945, 1282, 8, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18859, 7111, 1282, 9, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18860, 2409, 1282, 10, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18861, 3474, 1282, 11, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18862, 5741, 1282, 12, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18863, 6978, 1282, 13, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18864, 1593, 1282, 14, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18865, 670, 1282, 15, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18866, 6897, 1282, 16, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18867, 598, 1282, 17, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18868, 5848, 1282, 18, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18869, 2842, 1282, 19, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18870, 4175, 1282, 20, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18871, 4069, 1282, 21, 4);
INSERT INTO 'dancespublicationsmap' VALUES (18872, 3129, 1282, 22, 4);
INSERT INTO 'dancespublicationsmap' VALUES (2400, 2769, 257, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10090, 8787, 395, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10091, 8788, 395, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10092, 8789, 395, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10093, 8790, 395, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10094, 8791, 395, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18873, 16739, 1283, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18874, 16740, 1283, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18875, 16741, 1283, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18876, 16742, 1283, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18877, 16743, 1283, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18878, 16744, 1283, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18879, 16745, 1283, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18880, 16747, 1283, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18881, 16746, 1283, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18882, 16748, 1283, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18883, 16749, 1283, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15975, 12089, 1094, 16, 31);
INSERT INTO 'dancespublicationsmap' VALUES (15976, 13358, 1094, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15977, 13362, 1094, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15978, 13360, 1094, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15979, 13361, 1094, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15980, 13365, 1094, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18906, 16787, 1288, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18907, 16788, 1288, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18915, 16961, 1288, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18884, 16750, 1284, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18885, 16751, 1284, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18886, 16752, 1284, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18887, 16738, 1284, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18888, 16753, 1284, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18889, 16754, 1284, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21618, 6756, 1407, 181, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21617, 6748, 1407, 181, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21616, 6736, 1407, 181, 101);
INSERT INTO 'dancespublicationsmap' VALUES (18750, 16018, 1276, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18751, 16632, 1276, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18752, 14355, 1276, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16933, 15026, 1150, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16934, 15027, 1150, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16935, 7580, 1150, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16936, 15028, 1150, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16937, 14357, 1150, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16938, 5502, 1150, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16939, 15030, 1150, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18898, 16777, 1287, 101, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18899, 16778, 1287, 102, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18900, 16779, 1287, 103, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18901, 16780, 1287, 104, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18902, 16781, 1287, 105, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18903, 16782, 1287, 106, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18904, 16783, 1287, 107, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18905, 16784, 1287, 108, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16581, 14761, 1138, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18741, 16625, 1276, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18742, 16511, 1276, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18743, 16626, 1276, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18744, 16627, 1276, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18745, 14991, 1276, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18746, 14385, 1276, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18747, 16628, 1276, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18748, 16629, 1276, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16940, 15031, 1150, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16941, 8064, 1150, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16942, 15032, 1150, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18749, 16630, 1276, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21620, 6848, 1407, 182, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21619, 11582, 1407, 182, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21622, 6885, 1407, 183, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21621, 13582, 1407, 183, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21623, 14975, 1407, 183, 101);
INSERT INTO 'dancespublicationsmap' VALUES (16582, 14762, 1138, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16633, 14805, 1138, 43, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16634, 14806, 1138, 44, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16635, 14807, 1138, 45, 20);
INSERT INTO 'dancespublicationsmap' VALUES (21624, 6897, 1407, 184, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21626, 10548, 1407, 184, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21627, 10791, 1407, 184, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21625, 17139, 1407, 184, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21629, 6995, 1407, 185, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21631, 7037, 1407, 185, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21628, 6978, 1407, 185, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21630, 13730, 1407, 185, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21632, 7055, 1407, 186, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21634, 7090, 1407, 186, 101);
INSERT INTO 'dancespublicationsmap' VALUES (22287, 19014, 1128, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22285, 18967, 1128, 34, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12061, 11025, 859, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12062, 11026, 859, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12063, 11027, 859, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22369, 11028, 859, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7502, 1668, 670, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7635, 4120, 670, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17216, 15245, 1165, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17217, 15246, 1165, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17407, 7554, 1180, 14, 17);
INSERT INTO 'dancespublicationsmap' VALUES (17408, 6359, 1180, 15, 17);
INSERT INTO 'dancespublicationsmap' VALUES (17218, 15247, 1165, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1247, 1446, 29, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5889, 6824, 28, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3107, 3577, 26, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5180, 5989, 670, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5184, 5995, 670, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5185, 5996, 670, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5901, 6837, 670, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10819, 9074, 623, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10836, 9560, 623, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10820, 7543, 623, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10837, 9561, 623, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10838, 9562, 623, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (10839, 9563, 623, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6987, 571, 805, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6988, 3246, 805, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (9836, 8465, 298, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9831, 8354, 298, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9837, 8466, 298, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9834, 8463, 298, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9830, 4435, 298, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9832, 8461, 298, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9829, 4403, 298, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9842, 8471, 362, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9839, 8468, 362, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6991, 3730, 805, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6989, 6599, 805, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6990, 5032, 805, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6992, 4450, 805, 25, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6993, 3284, 805, 26, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6994, 1773, 805, 27, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6995, 4862, 805, 28, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6996, 4755, 805, 29, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6997, 1501, 805, 30, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6998, 4928, 805, 31, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6999, 745, 805, 32, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7000, 4064, 805, 33, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7001, 909, 805, 34, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7002, 1100, 805, 35, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7003, 521, 805, 36, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7080, 936, 808, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7081, 6634, 808, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7082, 6362, 808, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (18918, 16805, 1289, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18919, 16806, 1289, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18920, 16807, 1289, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18921, 16808, 1289, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18922, 16809, 1289, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18923, 16810, 1289, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18924, 16812, 1289, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18925, 16813, 1289, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18927, 16814, 1289, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18928, 16819, 1289, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (7083, 899, 808, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7084, 2593, 808, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7085, 4728, 808, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7086, 3934, 808, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7087, 7219, 808, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7088, 6711, 808, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7089, 3444, 808, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7090, 1017, 808, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7091, 1366, 808, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7092, 2436, 808, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7093, 4499, 808, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7094, 3986, 808, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7095, 654, 808, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7096, 611, 808, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7097, 5223, 808, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7098, 6800, 808, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7099, 1677, 808, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7100, 3339, 808, 25, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7101, 3588, 808, 26, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7102, 3589, 808, 27, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7103, 3615, 808, 28, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7104, 3735, 808, 29, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7105, 3774, 808, 30, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7106, 3921, 808, 31, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7107, 5033, 808, 32, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7108, 5364, 808, 33, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7109, 4239, 808, 34, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7110, 6407, 808, 35, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7111, 327, 808, 36, 14);
INSERT INTO 'dancespublicationsmap' VALUES (21884, 10262, 1456, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18333, 16205, 1247, 42, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18332, 16206, 1247, 42, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18334, 16207, 1247, 43, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18335, 16208, 1247, 43, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18786, 16666, 1277, 37, 10);
INSERT INTO 'dancespublicationsmap' VALUES (8577, 2349, 342, 13, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8578, 2745, 342, 14, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8579, 3580, 342, 15, 18);
INSERT INTO 'dancespublicationsmap' VALUES (7139, 132, 809, 28, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7140, 3759, 809, 29, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7141, 3506, 809, 30, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7142, 743, 809, 31, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7143, 848, 809, 32, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7144, 4827, 809, 33, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7301, 314, 685, 28, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7302, 5934, 685, 29, 14);
INSERT INTO 'dancespublicationsmap' VALUES (18940, 16844, 1291, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18941, 16845, 1291, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18942, 16846, 1291, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18943, 16847, 1291, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18944, 16848, 1291, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18945, 16849, 1291, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18946, 16850, 1291, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18947, 16855, 1291, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18948, 15710, 1291, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18949, 16853, 1291, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18950, 16852, 1291, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18951, 16854, 1291, 25, 10);
INSERT INTO 'dancespublicationsmap' VALUES (9859, 8488, 365, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7303, 6116, 685, 30, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7304, 1428, 685, 31, 14);
INSERT INTO 'dancespublicationsmap' VALUES (19033, 7245, 1293, 1, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19034, 5497, 1293, 2, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19035, 5351, 1293, 4, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19036, 7242, 1293, 5, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19037, 3623, 1293, 6, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19038, 4309, 1293, 7, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19039, 1296, 1293, 8, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19040, 6477, 1293, 9, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19041, 1018, 1293, 10, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19042, 2745, 1293, 11, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19043, 4356, 1293, 12, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19044, 754, 1293, 13, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19045, 6763, 1293, 14, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19046, 5207, 1293, 15, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19047, 958, 1293, 16, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19048, 3972, 1293, 17, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19049, 5591, 1293, 18, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19050, 3722, 1293, 19, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19051, 738, 1293, 20, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19052, 571, 1293, 22, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19053, 3246, 1293, 23, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19054, 3730, 1293, 24, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19055, 6599, 1293, 25, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19056, 5032, 1293, 26, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18929, 16830, 1285, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18930, 16831, 1285, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18931, 16832, 1285, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18932, 13781, 1285, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18933, 16833, 1285, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18934, 16834, 1285, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18935, 2398, 1285, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18936, 11316, 1285, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6708, 7351, 778, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6731, 7375, 778, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6743, 7388, 778, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6770, 7420, 778, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6805, 7466, 778, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6810, 7474, 778, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6811, 7475, 778, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6855, 7527, 778, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6857, 7529, 778, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6859, 7533, 778, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15125, 13470, 1041, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15126, 13473, 1041, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15127, 13461, 1041, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15128, 13449, 1041, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15129, 13466, 1041, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20493, 11422, 1384, 53, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20494, 14848, 1384, 54, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20495, 14850, 1384, 55, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7211, 40, 811, 28, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7212, 4103, 811, 29, 14);
INSERT INTO 'dancespublicationsmap' VALUES (19057, 4450, 1293, 27, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19058, 3284, 1293, 28, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19059, 1773, 1293, 30, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19060, 4862, 1293, 31, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19061, 4755, 1293, 32, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19062, 1501, 1293, 33, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19063, 4928, 1293, 34, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19064, 745, 1293, 35, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19065, 4064, 1293, 36, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19066, 909, 1293, 38, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19067, 1100, 1293, 40, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19068, 521, 1293, 41, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20707, 7111, 1389, 208, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20708, 7147, 1389, 210, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18961, 5239, 1292, 1, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18962, 6748, 1292, 2, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18963, 1210, 1292, 4, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18964, 5007, 1292, 5, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18965, 4293, 1292, 6, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18966, 2250, 1292, 7, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18967, 6359, 1292, 8, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18968, 1792, 1292, 10, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18969, 5658, 1292, 11, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18970, 2166, 1292, 12, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18971, 1478, 1292, 13, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18972, 4325, 1292, 14, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18973, 3562, 1292, 16, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18974, 862, 1292, 18, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18975, 2498, 1292, 20, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18976, 6233, 1292, 23, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18977, 5222, 1292, 24, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18978, 6182, 1292, 26, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18979, 5376, 1292, 27, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18980, 2682, 1292, 28, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18981, 1615, 1292, 29, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18982, 608, 1292, 30, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18983, 2820, 1292, 31, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18984, 1931, 1292, 32, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18985, 5964, 1292, 34, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18986, 1562, 1292, 35, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18987, 5847, 1292, 36, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18988, 3237, 1292, 37, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18989, 588, 1292, 38, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18990, 2044, 1292, 39, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18991, 5641, 1292, 40, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18992, 5450, 1292, 41, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19069, 4641, 1293, 42, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19070, 3091, 1293, 43, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19071, 2428, 1293, 44, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19072, 3611, 1293, 45, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19073, 1415, 1293, 46, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19074, 6036, 1293, 47, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19075, 3152, 1293, 48, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19076, 4068, 1293, 49, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19077, 5937, 1293, 50, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19078, 6523, 1293, 51, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19079, 4548, 1293, 52, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19080, 3642, 1293, 53, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19081, 3541, 1293, 54, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19082, 4646, 1293, 55, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19083, 3342, 1293, 56, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19084, 3084, 1293, 57, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19085, 6152, 1293, 58, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19086, 1496, 1293, 59, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19087, 4679, 1293, 60, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19088, 3912, 1293, 61, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19089, 2495, 1293, 63, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19090, 3105, 1293, 64, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19091, 5462, 1293, 65, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19092, 4559, 1293, 66, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19093, 2644, 1293, 67, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19094, 2661, 1293, 68, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19095, 3235, 1293, 69, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20601, 17990, 1386, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20741, 4359, 1388, 147, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20742, 4641, 1388, 149, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20743, 4646, 1388, 151, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20744, 4782, 1388, 153, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20774, 2931, 1388, 217, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20775, 3789, 1388, 219, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20776, 3941, 1388, 220, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20777, 4784, 1388, 222, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20778, 4102, 1388, 224, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20779, 3172, 1388, 226, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20780, 4931, 1388, 228, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20781, 4933, 1388, 229, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20782, 5330, 1388, 232, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20783, 5637, 1388, 234, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20784, 5703, 1388, 236, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20785, 5829, 1388, 237, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20786, 6010, 1388, 239, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20787, 6048, 1388, 242, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20788, 6535, 1388, 244, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20789, 6712, 1388, 249, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20790, 7111, 1388, 251, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20791, 7574, 1388, 254, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20634, 18015, 1383, 61, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20635, 18016, 1383, 63, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20170, 8485, 1359, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20171, 17687, 1359, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20126, 8471, 1353, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20127, 8468, 1353, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18336, 16209, 1247, 44, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19450, 2431, 1310, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (19451, 4024, 1310, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (19452, 576, 1310, 5, 31);
INSERT INTO 'dancespublicationsmap' VALUES (4794, 5548, 212, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5143, 5948, 212, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2106, 2426, 710, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6647, 4306, 764, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2135, 2458, 709, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6267, 7265, 709, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1933, 2235, 709, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10516, 9210, 500, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10517, 9211, 500, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10518, 9212, 500, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10519, 9213, 500, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10538, 9232, 519, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10539, 8977, 519, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10540, 9053, 519, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10541, 9233, 519, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10542, 9234, 519, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10543, 9235, 519, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10547, 9239, 519, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10548, 9240, 519, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10549, 9241, 519, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17800, 13458, 1210, 26, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17801, 15840, 1210, 27, 10);
INSERT INTO 'dancespublicationsmap' VALUES (8738, 5637, 775, 234, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8762, 8153, 775, 271, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8763, 7554, 775, 272, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8764, 8154, 775, 273, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8765, 8155, 775, 274, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8766, 8156, 775, 275, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8767, 8157, 775, 276, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8768, 8158, 775, 277, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8769, 8159, 775, 278, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8770, 8160, 775, 279, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8771, 8161, 775, 280, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8772, 8162, 775, 281, 16);
INSERT INTO 'dancespublicationsmap' VALUES (19225, 2136, 1296, 8, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19226, 1154, 1296, 9, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19227, 760, 1296, 10, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19228, 1586, 1296, 11, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19229, 4438, 1296, 12, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19230, 2807, 1296, 13, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19231, 4506, 1296, 14, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19232, 3631, 1296, 15, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19233, 5906, 1296, 16, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19234, 6566, 1296, 17, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19235, 4461, 1296, 18, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19236, 753, 1296, 20, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19237, 55, 1296, 21, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19238, 4374, 1296, 22, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19239, 2042, 1296, 23, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19240, 3620, 1296, 24, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19241, 3932, 1296, 25, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19242, 5065, 1296, 26, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19243, 5624, 1296, 27, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19244, 3625, 1296, 28, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19245, 6373, 1296, 29, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19246, 2349, 1296, 30, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19247, 3577, 1296, 31, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19248, 4935, 1296, 32, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19249, 4558, 1296, 34, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19250, 4959, 1296, 35, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19251, 1776, 1296, 36, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19252, 877, 1296, 37, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19253, 6489, 1296, 38, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19254, 5858, 1296, 39, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19255, 5713, 1296, 40, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19256, 5519, 1296, 41, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19257, 5982, 1296, 42, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19258, 3558, 1296, 43, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19259, 4563, 1296, 44, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19260, 301, 1296, 45, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19261, 6710, 1296, 46, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19262, 5347, 1296, 47, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19263, 656, 1296, 48, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19264, 6285, 1296, 49, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19265, 4927, 1296, 50, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19266, 4100, 1296, 51, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19267, 4767, 1296, 52, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19268, 1480, 1296, 54, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19269, 2010, 1296, 55, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19270, 4579, 1296, 56, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19271, 6824, 1296, 57, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19272, 4995, 1296, 58, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19273, 3685, 1296, 59, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19274, 3938, 1296, 60, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19275, 7037, 1296, 61, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19276, 2030, 1296, 62, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19277, 6406, 1296, 63, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19278, 1163, 1296, 64, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19279, 1446, 1296, 65, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19280, 773, 1296, 66, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19096, 3656, 1293, 70, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19097, 2140, 1293, 71, 12);
INSERT INTO 'dancespublicationsmap' VALUES (12206, 11165, 891, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12207, 11166, 891, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12208, 11167, 891, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12209, 11168, 891, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12210, 11169, 891, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16057, 14370, 1095, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16056, 14369, 1095, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16059, 14372, 1095, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16065, 14378, 1095, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15983, 14341, 1095, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7784, 7977, 296, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7696, 7888, 296, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7698, 7891, 296, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7654, 7839, 296, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7529, 4740, 296, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7683, 7870, 296, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7754, 5780, 296, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7666, 7854, 296, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10550, 9242, 519, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22288, 19015, 1128, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22289, 19016, 1128, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22290, 19019, 1128, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22291, 19020, 1128, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22292, 19022, 1128, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22293, 19025, 1128, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22294, 19027, 1128, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22295, 19026, 1128, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22296, 19024, 1128, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3677, 4227, 103, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18993, 3617, 1292, 42, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18994, 1927, 1292, 43, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18995, 2317, 1292, 44, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18996, 5532, 1292, 45, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18997, 6658, 1292, 47, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18998, 4324, 1292, 48, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18999, 5436, 1292, 49, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19000, 3437, 1292, 50, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19001, 3802, 1292, 51, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19002, 4195, 1292, 52, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19003, 2302, 1292, 53, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19004, 6915, 1292, 55, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19005, 2916, 1292, 56, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19006, 2812, 1292, 57, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19007, 2053, 1292, 58, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19008, 1348, 1292, 59, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19009, 6505, 1292, 60, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19010, 1799, 1292, 61, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19011, 3236, 1292, 62, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19012, 5708, 1292, 63, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19013, 723, 1292, 64, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19014, 3834, 1292, 65, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19015, 5963, 1292, 66, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19016, 1790, 1292, 67, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19017, 3637, 1292, 68, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19018, 1476, 1292, 69, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19019, 7109, 1292, 70, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19020, 1274, 1292, 71, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19021, 5731, 1292, 72, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19022, 1916, 1292, 73, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19023, 5702, 1292, 74, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19024, 3775, 1292, 75, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19025, 5141, 1292, 76, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19026, 6585, 1292, 78, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19027, 610, 1292, 79, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19028, 5362, 1292, 80, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19029, 3940, 1292, 81, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19030, 3046, 1292, 82, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19031, 4782, 1292, 83, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19032, 6130, 1292, 84, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19281, 2777, 1296, 67, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19282, 5691, 1296, 68, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19283, 1283, 1296, 69, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19284, 2742, 1296, 70, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19285, 2918, 1296, 71, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19286, 430, 1296, 72, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19287, 4126, 1296, 73, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19288, 2700, 1296, 74, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19455, 1578, 1310, 11, 31);
INSERT INTO 'dancespublicationsmap' VALUES (19456, 3314, 1310, 13, 31);
INSERT INTO 'dancespublicationsmap' VALUES (19289, 910, 1296, 75, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19290, 6058, 1296, 76, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19098, 3528, 1293, 72, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19099, 7247, 1293, 73, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19100, 5520, 1293, 74, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19101, 6178, 1293, 75, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19102, 541, 1293, 76, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19103, 1883, 1293, 77, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19104, 4032, 1293, 78, 12);
INSERT INTO 'dancespublicationsmap' VALUES (1963, 2269, 129, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7463, 520, 307, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7689, 5154, 307, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3754, 4318, 103, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4774, 5523, 103, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4815, 5574, 103, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4878, 5643, 103, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5680, 6575, 103, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22297, 19023, 1128, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22298, 19021, 1128, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22299, 19018, 1128, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22300, 19017, 1128, 29, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22301, 19029, 1128, 32, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22302, 19028, 1128, 35, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19105, 1864, 1294, 1, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19106, 4442, 1294, 2, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19107, 4806, 1294, 3, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19108, 410, 1294, 4, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19109, 2925, 1294, 5, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19110, 3526, 1294, 6, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19111, 4907, 1294, 7, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19112, 2257, 1294, 8, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19113, 6349, 1294, 9, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19114, 5525, 1294, 10, 12);
INSERT INTO 'dancespublicationsmap' VALUES (22317, 19059, 1486, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22318, 19060, 1486, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22319, 19061, 1486, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22320, 19062, 1486, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22321, 19063, 1486, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22322, 19064, 1486, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12524, 11486, 83, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12525, 11487, 83, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22323, 19076, 1486, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22324, 19077, 1486, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22325, 19078, 1486, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22333, 19065, 1487, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22334, 19066, 1487, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22335, 19067, 1487, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22336, 18522, 1487, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22337, 18523, 1487, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11665, 10608, 827, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22326, 19079, 1486, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22327, 19080, 1486, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22328, 19081, 1486, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11666, 10609, 827, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11667, 10610, 827, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19296, 550, 1298, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19297, 5067, 1298, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19298, 3999, 1298, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19299, 6304, 1298, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19300, 5385, 1298, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19301, 1065, 1298, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19302, 5697, 1298, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19303, 3743, 1298, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19304, 6376, 1298, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19305, 6377, 1298, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19306, 2076, 1298, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19307, 2260, 1298, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19311, 11299, 1179, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (7845, 8043, 297, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7846, 7653, 297, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7878, 8070, 297, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7879, 8071, 297, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7880, 8072, 297, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7881, 5252, 297, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7882, 8073, 297, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7883, 8074, 297, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7884, 8075, 297, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7885, 8076, 297, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7886, 8077, 297, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7887, 8078, 297, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7888, 7935, 297, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7889, 243, 297, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7890, 1088, 297, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7891, 1749, 297, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7892, 5635, 297, 49, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7893, 6347, 297, 51, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7894, 8079, 297, 52, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7895, 8080, 297, 53, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7896, 8081, 297, 54, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7897, 8082, 297, 55, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7898, 8083, 297, 56, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7899, 8084, 297, 57, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11806, 10743, 836, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11807, 10744, 836, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11808, 10745, 836, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11809, 10746, 836, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9541, 8186, 343, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9542, 8187, 343, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9543, 8188, 343, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9544, 8189, 343, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9545, 8190, 343, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9547, 8192, 343, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9546, 8191, 343, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9548, 8193, 343, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10442, 9141, 478, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10443, 9142, 478, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10444, 9143, 478, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10445, 8736, 478, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10446, 9144, 478, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10447, 9145, 478, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10448, 9146, 478, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19313, 16942, 1300, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19314, 16943, 1300, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19315, 16944, 1300, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19316, 16945, 1300, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19317, 16946, 1300, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19318, 16947, 1300, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19319, 16948, 1300, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14247, 12564, 702, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14248, 12565, 702, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14249, 5340, 702, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12426, 11349, 909, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10467, 7953, 493, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10472, 9175, 493, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10473, 9176, 493, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10474, 9177, 493, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7636, 3750, 310, 4, 35);
INSERT INTO 'dancespublicationsmap' VALUES (7676, 4117, 310, 5, 35);
INSERT INTO 'dancespublicationsmap' VALUES (10970, 9673, 655, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10971, 9674, 655, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10972, 9675, 655, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (920, 1065, 487, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3098, 3568, 487, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4836, 5597, 487, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4387, 5067, 487, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3474, 3999, 487, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (470, 550, 487, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3019, 3473, 487, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1796, 2076, 487, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19291, 9946, 1297, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19292, 9947, 1297, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19293, 9945, 1297, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19294, 9948, 1297, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19295, 9949, 1297, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (9824, 8456, 364, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9825, 8457, 364, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (919, 1064, 127, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (808, 939, 127, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9826, 8458, 364, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9827, 8459, 364, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5430, 6283, 757, 7, 35);
INSERT INTO 'dancespublicationsmap' VALUES (3025, 3479, 114, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11759, 10694, 833, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11760, 10695, 833, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11762, 10697, 833, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11761, 10696, 833, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11764, 10699, 833, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11763, 10698, 833, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11766, 10701, 833, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11765, 10700, 833, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11767, 10702, 833, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11768, 10703, 833, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11769, 10704, 833, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11770, 10705, 833, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19320, 16949, 1300, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19321, 16950, 1300, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19322, 16951, 1300, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2721, 3136, 634, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16951, 15041, 1151, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16953, 15042, 1151, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19312, 15043, 1151, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (11084, 9796, 660, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11085, 9797, 660, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11086, 9798, 660, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11087, 9799, 660, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11285, 9829, 747, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11286, 10140, 747, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (282, 328, 211, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (317, 369, 211, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1395, 1618, 211, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1598, 1858, 211, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6735, 7379, 790, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6717, 7361, 790, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6716, 7360, 790, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6769, 7419, 790, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5256, 6077, 200, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5562, 6432, 200, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1980, 2288, 200, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2808, 3231, 200, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5095, 5893, 200, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (844, 977, 200, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4567, 5276, 200, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1554, 1806, 200, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (945, 1094, 200, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4753, 5500, 200, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3379, 3890, 200, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4450, 5140, 200, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4279, 4946, 200, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3589, 4127, 200, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9568, 8210, 345, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9569, 8211, 345, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16196, 14477, 1109, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16203, 14484, 1109, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8671, 1582, 775, 103, 16);
INSERT INTO 'dancespublicationsmap' VALUES (10387, 9072, 432, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13631, 6048, 954, 174, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13628, 5982, 954, 174, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13629, 6010, 954, 174, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13634, 6061, 954, 175, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13632, 6052, 954, 175, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13633, 6058, 954, 175, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13814, 9093, 954, 176, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13635, 6091, 954, 176, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13637, 6152, 954, 177, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13747, 6161, 954, 177, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13636, 6116, 954, 177, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13638, 6153, 954, 177, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13642, 6224, 954, 178, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13641, 6212, 954, 178, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13639, 6178, 954, 178, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13640, 6182, 954, 178, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13643, 6233, 954, 178, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13609, 5800, 954, 179, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13610, 5802, 954, 179, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13720, 5808, 954, 179, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13611, 5804, 954, 180, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13644, 6271, 954, 180, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13816, 7520, 954, 180, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13646, 6311, 954, 181, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13645, 6287, 954, 181, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13647, 6323, 954, 181, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13817, 11769, 954, 181, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13650, 6362, 954, 182, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13818, 11371, 954, 182, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13649, 6359, 954, 182, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13648, 6349, 954, 182, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13654, 6391, 954, 183, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13651, 6373, 954, 183, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13653, 6382, 954, 183, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13652, 6380, 954, 183, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13729, 6386, 954, 183, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13656, 6407, 954, 184, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13732, 7282, 954, 184, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13655, 6406, 954, 184, 102);
INSERT INTO 'dancespublicationsmap' VALUES (7406, 4046, 84, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7407, 5867, 84, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7408, 118, 84, 8, 31);
INSERT INTO 'dancespublicationsmap' VALUES (7409, 1862, 84, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7410, 4275, 84, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15305, 13448, 1027, 29, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10513, 9207, 500, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10514, 9208, 500, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10515, 9209, 500, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10520, 9214, 500, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10521, 9215, 500, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10522, 9216, 500, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10523, 9217, 500, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10524, 9218, 500, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10525, 9219, 500, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19332, 16955, 1302, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19333, 16956, 1302, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19334, 16957, 1302, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19329, 16857, 1302, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19331, 16958, 1302, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19330, 16887, 1302, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8672, 1786, 775, 104, 16);
INSERT INTO 'dancespublicationsmap' VALUES (10526, 9220, 500, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10527, 9221, 500, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12727, 10887, 936, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12726, 11776, 936, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12729, 11777, 936, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12728, 10891, 936, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12730, 11778, 936, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12731, 11779, 936, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12732, 11780, 936, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12733, 11781, 936, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12734, 11782, 936, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12735, 11705, 936, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12736, 11750, 936, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12737, 11783, 936, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12738, 11784, 936, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12739, 11524, 936, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12740, 11785, 936, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12741, 11585, 936, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12742, 10899, 936, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12743, 11786, 936, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12744, 10946, 936, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12745, 10947, 936, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12746, 10948, 936, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12747, 11787, 936, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12748, 11788, 936, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5949, 6893, 89, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14330, 12636, 990, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14331, 12637, 990, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14332, 11523, 990, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11559, 10416, 797, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11567, 10417, 797, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11560, 10418, 797, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11561, 10419, 797, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11562, 10420, 797, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11563, 10421, 797, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11564, 10422, 797, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11565, 10423, 797, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11566, 10424, 797, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11568, 10425, 797, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11569, 10426, 797, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12749, 11789, 936, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12750, 11790, 936, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19339, 8986, 1303, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12751, 11791, 936, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2594, 2990, 201, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19308, 3231, 201, 21, 25);
INSERT INTO 'dancespublicationsmap' VALUES (11774, 10709, 833, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11773, 10708, 833, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11775, 10710, 833, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11776, 10711, 833, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14196, 12512, 982, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14197, 12513, 982, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12752, 10958, 936, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8673, 1792, 775, 106, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8674, 1884, 775, 108, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8675, 1931, 775, 110, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8676, 2024, 775, 113, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8677, 2250, 775, 115, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8678, 2302, 775, 116, 16);
INSERT INTO 'dancespublicationsmap' VALUES (19340, 16966, 1304, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19341, 16967, 1304, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19342, 16968, 1304, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19343, 16969, 1304, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19344, 16970, 1304, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19345, 16971, 1304, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19346, 16972, 1304, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19347, 16973, 1304, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19348, 16974, 1304, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19349, 16975, 1304, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19350, 16976, 1304, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19351, 16977, 1304, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19352, 16978, 1304, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19353, 16979, 1304, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19354, 16980, 1304, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19355, 16981, 1304, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19356, 16982, 1304, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19357, 9388, 1304, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19358, 16983, 1304, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19359, 16984, 1304, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19360, 16993, 1304, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19361, 16994, 1304, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19362, 16985, 1304, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19363, 16986, 1304, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19364, 16987, 1304, 25, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19365, 16988, 1304, 26, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19366, 16989, 1304, 27, 10);
INSERT INTO 'dancespublicationsmap' VALUES (8679, 2317, 775, 118, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8680, 2428, 775, 120, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8681, 2498, 775, 122, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8682, 2745, 775, 125, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8683, 2777, 775, 126, 16);
INSERT INTO 'dancespublicationsmap' VALUES (19367, 16990, 1304, 28, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19368, 16991, 1304, 29, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19369, 16992, 1304, 30, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4415, 5102, 699, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6066, 7034, 729, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2393, 2758, 729, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2521, 2908, 729, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2827, 3254, 729, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19375, 16995, 1305, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19376, 16996, 1305, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19377, 16997, 1305, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19370, 12131, 1305, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19371, 12125, 1305, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19372, 12214, 1305, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19373, 12293, 1305, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19374, 12331, 1305, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19378, 16999, 1305, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19379, 17000, 1305, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19380, 17001, 1305, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19381, 17002, 1305, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19382, 17003, 1305, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19383, 17004, 1305, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19384, 17005, 1305, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19385, 17006, 1305, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2832, 3260, 729, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2859, 3288, 729, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3934, 4529, 729, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1386, 1605, 700, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3406, 3922, 700, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (917, 1062, 700, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3329, 3836, 700, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (975, 1130, 697, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5591, 6468, 697, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5716, 6619, 697, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (792, 921, 697, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6138, 7114, 697, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4989, 5772, 697, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5599, 6476, 697, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5619, 6501, 256, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12037, 11000, 858, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19386, 17007, 1306, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19387, 17008, 1306, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19388, 17009, 1306, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2290, 2639, 697, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2353, 2710, 695, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6734, 7378, 791, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6728, 7372, 791, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9793, 8425, 363, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9794, 8426, 363, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9513, 4308, 722, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9514, 3072, 722, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9515, 4817, 722, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9516, 3158, 722, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9517, 3661, 722, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9518, 987, 722, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9519, 5738, 722, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9520, 1565, 722, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9521, 7148, 722, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9522, 2213, 722, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9523, 5287, 722, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19115, 794, 1294, 12, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19116, 3580, 1294, 13, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19117, 7172, 1294, 14, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19118, 2645, 1294, 15, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19119, 5398, 1294, 16, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19120, 1437, 1294, 17, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19121, 4562, 1294, 18, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19122, 3412, 1294, 19, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19123, 1582, 1294, 20, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19124, 6029, 1294, 21, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19125, 7068, 1294, 22, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19126, 682, 1294, 23, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19127, 3281, 1294, 24, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19128, 3672, 1294, 25, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19129, 4864, 1294, 26, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19130, 3045, 1294, 27, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19131, 980, 1294, 28, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19132, 972, 1294, 29, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19133, 2415, 1294, 30, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19134, 3953, 1294, 31, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19135, 3887, 1294, 32, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19136, 4359, 1294, 33, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19137, 6539, 1294, 34, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19138, 222, 1294, 35, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19139, 6518, 1294, 36, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19140, 6957, 1294, 37, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19141, 2153, 1294, 39, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19142, 522, 1294, 40, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19143, 1786, 1294, 41, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19144, 3608, 1294, 42, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19145, 936, 1294, 43, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19146, 6634, 1294, 44, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19147, 6362, 1294, 45, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19148, 899, 1294, 46, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19149, 2593, 1294, 47, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19150, 4728, 1294, 48, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19151, 3934, 1294, 49, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19152, 7219, 1294, 50, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19153, 6711, 1294, 51, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19154, 3444, 1294, 52, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19155, 1017, 1294, 53, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19156, 1366, 1294, 54, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19157, 2436, 1294, 55, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19158, 4499, 1294, 56, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19159, 3986, 1294, 57, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19160, 654, 1294, 58, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19161, 611, 1294, 59, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19162, 5223, 1294, 60, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19163, 6800, 1294, 61, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19164, 1677, 1294, 62, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19165, 3339, 1294, 63, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19166, 3588, 1294, 64, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19167, 3589, 1294, 65, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19168, 3615, 1294, 66, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19169, 3735, 1294, 67, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19170, 3774, 1294, 68, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19171, 3921, 1294, 69, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19172, 5033, 1294, 70, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19173, 5364, 1294, 71, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19174, 4239, 1294, 72, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19175, 6407, 1294, 73, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19176, 327, 1294, 74, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19389, 17010, 1306, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19390, 17011, 1306, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19391, 17012, 1306, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19392, 17013, 1306, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19393, 17014, 1306, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19394, 17015, 1306, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19395, 17016, 1306, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (26, 33, 736, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (270, 316, 736, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19418, 17042, 1307, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19416, 6047, 1307, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19419, 17043, 1307, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19420, 17044, 1307, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19421, 17045, 1307, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4726, 5469, 703, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5441, 6295, 703, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2474, 2853, 703, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2172, 2503, 703, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4917, 5690, 703, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5528, 6395, 703, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6117, 7091, 579, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19336, 16964, 1288, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11302, 10154, 759, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (64, 75, 703, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (513, 595, 703, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4909, 5682, 703, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6778, 7430, 798, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6781, 7434, 798, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6854, 7526, 798, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6862, 7537, 798, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19422, 17046, 1307, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19423, 17047, 1307, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19417, 2794, 1307, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19525, 17058, 1318, 2, 21);
INSERT INTO 'dancespublicationsmap' VALUES (19526, 17059, 1318, 3, 21);
INSERT INTO 'dancespublicationsmap' VALUES (19527, 9655, 1318, 4, 21);
INSERT INTO 'dancespublicationsmap' VALUES (19528, 17061, 1318, 5, 21);
INSERT INTO 'dancespublicationsmap' VALUES (19529, 17062, 1318, 6, 21);
INSERT INTO 'dancespublicationsmap' VALUES (19530, 17063, 1318, 9, 21);
INSERT INTO 'dancespublicationsmap' VALUES (19531, 17064, 1318, 10, 21);
INSERT INTO 'dancespublicationsmap' VALUES (19532, 17065, 1318, 11, 21);
INSERT INTO 'dancespublicationsmap' VALUES (19533, 17066, 1318, 12, 21);
INSERT INTO 'dancespublicationsmap' VALUES (19457, 1828, 1311, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19458, 6794, 1311, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19459, 2441, 1311, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19460, 86, 1311, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19461, 3390, 1311, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19462, 3897, 1311, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12039, 11002, 858, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19473, 2931, 1313, 16, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19474, 2260, 1313, 18, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19475, 8154, 1313, 20, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19476, 4336, 1313, 21, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19477, 7552, 1313, 22, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19478, 5713, 1313, 24, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19479, 7546, 1313, 26, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19510, 2745, 1317, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19511, 5525, 1317, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19512, 4646, 1317, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19513, 1792, 1317, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19514, 2260, 1317, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12038, 11001, 858, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12040, 11003, 858, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12041, 11004, 858, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12042, 11005, 858, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19552, 17081, 1320, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19545, 17075, 1319, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19546, 17076, 1319, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19547, 9877, 1319, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19548, 17077, 1319, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19549, 17078, 1319, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19497, 2389, 1315, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19498, 4336, 1315, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19499, 3594, 1315, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19500, 3267, 1315, 5, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19501, 3435, 1315, 6, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19553, 17082, 1320, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19554, 17083, 1320, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19555, 17084, 1320, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19556, 17085, 1320, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19557, 17086, 1320, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19558, 17087, 1320, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19559, 17088, 1320, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19449, 2811, 249, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19448, 173, 249, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19550, 17079, 1319, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19502, 2250, 1315, 7, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19503, 7553, 1315, 8, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19560, 17089, 1320, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19561, 17090, 1320, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19542, 17072, 1319, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19543, 17073, 1319, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19544, 17074, 1319, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19516, 17048, 1311, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19517, 17049, 1311, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19518, 17050, 1311, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19519, 17051, 1311, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19520, 17052, 1311, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19521, 17053, 1311, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19522, 17054, 1311, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19523, 17055, 1311, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19524, 17056, 1311, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19515, 17057, 1311, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19534, 14252, 1321, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19537, 17067, 1321, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19536, 17068, 1321, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19538, 17069, 1321, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19535, 16678, 1321, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19539, 17070, 1321, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19540, 10537, 1321, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19541, 17071, 1321, 26, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19551, 17080, 1319, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19572, 17102, 1323, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19562, 17091, 1322, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19563, 17099, 1322, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19564, 17092, 1322, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19565, 17093, 1322, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19566, 17094, 1322, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19567, 17095, 1322, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19568, 17100, 1322, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19569, 17096, 1322, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19570, 17097, 1322, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19571, 17098, 1322, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19573, 17103, 1323, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19574, 17104, 1323, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19575, 17105, 1323, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19576, 17106, 1323, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19577, 17107, 1323, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19578, 17108, 1323, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19579, 17109, 1323, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19580, 17110, 1323, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19581, 17111, 1323, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19582, 17112, 1323, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19583, 17113, 1323, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19584, 17114, 1323, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19585, 17115, 1323, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19586, 17116, 1323, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19587, 17117, 1323, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19588, 17118, 1323, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19589, 17119, 1323, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19590, 17120, 1323, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (14819, 3702, 1021, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14820, 3747, 1021, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14821, 4078, 1021, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14836, 4188, 1021, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14822, 4278, 1021, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14823, 12320, 1021, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14824, 5161, 1021, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14825, 5245, 1021, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19504, 588, 1316, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19505, 1908, 1316, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19506, 3310, 1316, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19491, 3763, 1314, 1, 16);
INSERT INTO 'dancespublicationsmap' VALUES (19492, 1304, 1314, 2, 16);
INSERT INTO 'dancespublicationsmap' VALUES (19493, 1562, 1314, 3, 16);
INSERT INTO 'dancespublicationsmap' VALUES (19494, 5713, 1314, 4, 16);
INSERT INTO 'dancespublicationsmap' VALUES (19495, 8154, 1314, 5, 16);
INSERT INTO 'dancespublicationsmap' VALUES (19496, 7546, 1314, 6, 16);
INSERT INTO 'dancespublicationsmap' VALUES (14830, 5273, 1021, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14826, 5549, 1021, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14831, 5606, 1021, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14832, 6025, 1021, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14833, 6586, 1021, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14834, 3563, 1021, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14835, 7122, 1021, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19594, 17123, 1324, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19595, 17124, 1324, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19596, 17125, 1324, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19593, 17121, 1324, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19598, 17126, 1324, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19599, 17127, 1324, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19597, 17128, 1324, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19600, 17129, 1324, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19601, 17130, 1324, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19602, 17131, 1324, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19603, 17132, 1324, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19591, 14739, 1045, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19616, 17145, 1326, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19463, 2910, 1312, 28, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19464, 3594, 1312, 29, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19465, 3246, 1312, 30, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19466, 4782, 1312, 30, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19467, 4864, 1312, 31, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19468, 2153, 1312, 32, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19469, 6349, 1312, 32, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19470, 2925, 1312, 33, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19471, 743, 1312, 34, 18);
INSERT INTO 'dancespublicationsmap' VALUES (19472, 5713, 1312, 34, 18);
INSERT INTO 'dancespublicationsmap' VALUES (12461, 11385, 912, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12462, 11386, 912, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12463, 11387, 912, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12464, 11388, 912, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19620, 17178, 1327, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19621, 17179, 1327, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19622, 17180, 1327, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19623, 17181, 1327, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19624, 17182, 1327, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19625, 17183, 1327, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19626, 17184, 1327, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19627, 17185, 1327, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19628, 17186, 1327, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19629, 17187, 1327, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19630, 17188, 1327, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19631, 17189, 1327, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19632, 17190, 1327, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19633, 17191, 1327, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19634, 17192, 1327, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19635, 17193, 1327, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2918, 3358, 640, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12705, 10599, 934, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12706, 10589, 934, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12703, 11746, 934, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12707, 10591, 934, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12708, 11747, 934, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12709, 10590, 934, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12710, 10588, 934, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12711, 10597, 934, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12712, 10595, 934, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12714, 11530, 934, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12713, 11748, 934, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19680, 17240, 1299, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19681, 17241, 1299, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19682, 17242, 1299, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19683, 17243, 1299, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19685, 15708, 1299, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19684, 12023, 1299, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19686, 17244, 1299, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19687, 17245, 1299, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19663, 17223, 1328, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19667, 17227, 1328, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19665, 17225, 1328, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19660, 17220, 1328, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19666, 17226, 1328, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19662, 17222, 1328, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19661, 17221, 1328, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19664, 17224, 1328, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19688, 16054, 1299, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19689, 17246, 1299, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19690, 17247, 1299, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19691, 17248, 1299, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19692, 17249, 1299, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19693, 15959, 1299, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19694, 17250, 1299, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19695, 17251, 1299, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19696, 17252, 1299, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19697, 5272, 1299, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19698, 17253, 1299, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19699, 17254, 1299, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19700, 17255, 1299, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19701, 17256, 1299, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19702, 17257, 1299, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19703, 17258, 1299, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19704, 16939, 1299, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19668, 17228, 1329, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19669, 17229, 1329, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19670, 17230, 1329, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19671, 17231, 1329, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19672, 17232, 1329, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19673, 17233, 1329, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19674, 17234, 1329, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19675, 17235, 1329, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19676, 17236, 1329, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19677, 17237, 1329, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19678, 17238, 1329, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19679, 17239, 1329, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19705, 1146, 1330, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19706, 3406, 1330, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19707, 4171, 1330, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19708, 3917, 1330, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19641, 17201, 1287, 111, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19646, 17206, 1287, 112, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19649, 17209, 1287, 113, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19658, 17218, 1287, 114, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19645, 17205, 1287, 201, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19648, 17208, 1287, 202, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19657, 17217, 1287, 203, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19651, 17211, 1287, 205, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19643, 17203, 1287, 206, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19642, 17202, 1287, 207, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19647, 17207, 1287, 208, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19644, 17204, 1287, 212, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19656, 17216, 1287, 213, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19652, 17212, 1287, 214, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19653, 17213, 1287, 215, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19655, 17215, 1287, 303, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19709, 1450, 1330, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19710, 3000, 1330, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19711, 5712, 1330, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19712, 812, 1330, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19713, 3221, 1330, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19714, 716, 1330, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19715, 395, 1330, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19716, 3849, 1330, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19717, 4556, 1330, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19592, 16798, 1288, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19619, 17152, 820, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11600, 10478, 820, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11613, 10479, 820, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11601, 10480, 820, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11602, 10481, 820, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11603, 10482, 820, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11604, 10483, 820, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11605, 10484, 820, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11606, 10485, 820, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11607, 10486, 820, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11608, 10487, 820, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11609, 10488, 820, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11610, 10489, 820, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11611, 10490, 820, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11612, 10455, 820, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19618, 17147, 1326, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19617, 17148, 1326, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19718, 4170, 1330, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8713, 6915, 775, 179, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8714, 6957, 775, 181, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8715, 7055, 775, 183, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8691, 3580, 775, 140, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8692, 3672, 775, 142, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8693, 3759, 775, 143, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8694, 3834, 775, 144, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8695, 4032, 775, 145, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8696, 4239, 775, 146, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8697, 4359, 775, 147, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8698, 4641, 775, 149, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8699, 4646, 775, 151, 16);
INSERT INTO 'dancespublicationsmap' VALUES (19606, 16255, 1325, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19604, 17133, 1325, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19605, 17134, 1325, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19607, 17136, 1325, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19608, 17137, 1325, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19609, 17138, 1325, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (8700, 4782, 775, 153, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8701, 4862, 775, 154, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8702, 4890, 775, 155, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8703, 5239, 775, 157, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8704, 5525, 775, 159, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8705, 5529, 775, 161, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8706, 5532, 775, 163, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8707, 5713, 775, 166, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8708, 5794, 775, 168, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8709, 5964, 775, 169, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8710, 6130, 775, 171, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8711, 6359, 775, 175, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8712, 6748, 775, 177, 16);
INSERT INTO 'dancespublicationsmap' VALUES (19757, 475, 1330, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19754, 5859, 1330, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19756, 3770, 1330, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19755, 5986, 1330, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19744, 3220, 1330, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19753, 7604, 1330, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19758, 5929, 1330, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19751, 1833, 1330, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19719, 4875, 1330, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19720, 2667, 1330, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19721, 2913, 1330, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19752, 2852, 1330, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19722, 4721, 1330, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19723, 3475, 1330, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19724, 852, 1330, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19750, 3387, 1330, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19749, 6670, 1330, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19725, 5296, 1330, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19726, 7017, 1330, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19727, 1821, 1330, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19728, 174, 1330, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19729, 2516, 1330, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19747, 6162, 1330, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19730, 275, 1330, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19731, 150, 1330, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19748, 4636, 1330, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19746, 17261, 1330, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19732, 6839, 1330, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19733, 5875, 1330, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19734, 3846, 1330, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19735, 881, 1330, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19736, 6453, 1330, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19737, 6650, 1330, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19738, 44, 1330, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19739, 78, 1330, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19740, 4596, 1330, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19741, 2988, 1330, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19742, 10833, 1330, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19743, 7545, 1330, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19745, 17260, 1330, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19786, 17286, 1287, 110, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19775, 17279, 1054, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19776, 17280, 829, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19791, 15607, 1287, 204, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19802, 17298, 1287, 209, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19827, 17376, 1333, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19828, 17377, 1333, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19781, 8709, 1331, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19780, 8859, 1331, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19785, 17283, 1331, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8717, 7147, 775, 185, 16);
INSERT INTO 'dancespublicationsmap' VALUES (19759, 1485, 775, 197, 31);
INSERT INTO 'dancespublicationsmap' VALUES (8728, 2924, 775, 215, 31);
INSERT INTO 'dancespublicationsmap' VALUES (8729, 2931, 775, 217, 31);
INSERT INTO 'dancespublicationsmap' VALUES (8730, 3789, 775, 219, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8731, 3941, 775, 220, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8732, 4784, 775, 222, 31);
INSERT INTO 'dancespublicationsmap' VALUES (8733, 4102, 775, 224, 31);
INSERT INTO 'dancespublicationsmap' VALUES (19771, 17276, 1196, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19768, 17273, 1196, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19769, 17275, 1196, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19770, 16052, 1196, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19772, 17272, 1196, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19787, 16117, 1287, 210, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19793, 17289, 1287, 211, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19790, 17287, 1287, 301, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19829, 17378, 1333, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19830, 10009, 1333, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19831, 17379, 1333, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19832, 17380, 1333, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19833, 17381, 1333, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19766, 17271, 1196, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19767, 17274, 1196, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19763, 17268, 1196, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19762, 17267, 1196, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19761, 17266, 1196, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19764, 17269, 1196, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19819, 2238, 477, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19788, 17214, 1287, 302, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19792, 17288, 1287, 304, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19794, 17290, 1287, 305, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19796, 17292, 1287, 306, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19798, 17294, 1287, 307, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19650, 17210, 1287, 308, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19804, 17300, 1287, 309, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19800, 17296, 1287, 402, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19803, 17299, 1287, 403, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19797, 17293, 1287, 404, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19799, 17295, 1287, 405, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19480, 4725, 1313, 28, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19481, 8144, 1313, 30, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19485, 1562, 1313, 38, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19486, 6359, 1313, 40, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19487, 5525, 1313, 42, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19801, 17297, 1287, 407, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19765, 17270, 1196, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19789, 15591, 1287, 109, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19488, 7548, 1313, 44, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19490, 1792, 1313, 46, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19489, 1931, 1313, 48, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19820, 17371, 1333, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19821, 17372, 1333, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19822, 9037, 1333, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19823, 17373, 1333, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19824, 17374, 1333, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19825, 17375, 1333, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19826, 8987, 1333, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19482, 2250, 1313, 32, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19483, 7147, 1313, 34, 17);
INSERT INTO 'dancespublicationsmap' VALUES (19484, 4092, 1313, 36, 17);
INSERT INTO 'dancespublicationsmap' VALUES (17488, 15406, 1184, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17489, 14552, 1184, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (8716, 7109, 775, 184, 16);
INSERT INTO 'dancespublicationsmap' VALUES (19835, 17394, 1334, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19836, 17395, 1334, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19837, 17396, 1334, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19838, 17397, 1334, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19839, 17398, 1334, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19840, 17194, 1334, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19841, 8992, 1334, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19842, 14901, 1334, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19843, 17399, 1334, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19847, 15022, 1335, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19848, 15020, 1335, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19844, 17400, 1334, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19845, 17401, 1334, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19846, 17402, 1334, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19863, 15044, 1336, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19849, 17403, 1335, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19850, 15913, 1335, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19851, 17404, 1335, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19852, 16927, 1335, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19853, 15600, 1335, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19854, 17405, 1335, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19855, 17406, 1335, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19856, 16930, 1335, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19857, 15021, 1335, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19858, 15657, 1335, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19773, 17278, 1224, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19774, 17277, 1224, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19805, 17304, 1332, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19806, 17305, 1332, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19807, 17306, 1332, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19808, 14543, 1332, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19859, 17407, 1335, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19860, 17360, 1335, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19861, 13771, 1335, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19862, 17408, 1335, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19899, 17464, 1339, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5831, 6758, 570, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4516, 5216, 589, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19929, 17492, 1344, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19930, 17493, 1344, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19931, 17494, 1344, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19932, 17265, 1344, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19936, 17498, 1344, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19937, 17499, 1344, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19933, 17495, 1344, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8734, 3172, 775, 226, 31);
INSERT INTO 'dancespublicationsmap' VALUES (19783, 1961, 1331, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19779, 624, 1331, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19777, 4136, 1331, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19778, 57, 1331, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19922, 15605, 1344, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19923, 17487, 1344, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19924, 17488, 1344, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2114, 2434, 589, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1794, 2074, 589, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5350, 6186, 261, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3160, 3632, 589, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1775, 2055, 589, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1121, 1299, 589, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3733, 4291, 589, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14, 17, 589, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1338, 1548, 589, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5458, 6317, 691, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2507, 2893, 691, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2572, 2966, 691, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19917, 5606, 1343, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19918, 3702, 1343, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8735, 4931, 775, 228, 31);
INSERT INTO 'dancespublicationsmap' VALUES (19934, 17496, 1344, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19935, 17497, 1344, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19925, 17489, 1344, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19926, 16337, 1344, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19927, 17490, 1344, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19928, 17491, 1344, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19782, 2236, 1331, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19867, 8858, 1331, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19868, 1914, 1331, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19869, 8857, 1331, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6419, 3093, 706, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6397, 2613, 706, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6396, 2602, 706, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19919, 6025, 1343, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19920, 4078, 1343, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19921, 807, 1343, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8737, 5330, 775, 232, 31);
INSERT INTO 'dancespublicationsmap' VALUES (5444, 6299, 593, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5545, 6412, 593, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5324, 6158, 593, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5404, 6254, 593, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4834, 5595, 595, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4338, 5015, 594, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4392, 5076, 594, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4390, 5074, 594, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2259, 2605, 594, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1923, 2221, 594, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5115, 5913, 594, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6171, 7154, 594, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19784, 17282, 1331, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8739, 5703, 775, 236, 16);
INSERT INTO 'dancespublicationsmap' VALUES (15304, 13447, 1027, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19914, 1847, 1343, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19915, 2565, 1343, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19916, 3747, 1343, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8740, 5829, 775, 237, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8741, 6010, 775, 239, 31);
INSERT INTO 'dancespublicationsmap' VALUES (8742, 6048, 775, 242, 31);
INSERT INTO 'dancespublicationsmap' VALUES (8743, 6535, 775, 244, 16);
INSERT INTO 'dancespublicationsmap' VALUES (19947, 17339, 1345, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19946, 13614, 1345, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19948, 17510, 1345, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19949, 17511, 1345, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19950, 17512, 1345, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19951, 17513, 1345, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19952, 17514, 1345, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19953, 17516, 1345, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19954, 17515, 1345, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19955, 17517, 1345, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19956, 17518, 1345, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19957, 17519, 1345, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19958, 17520, 1345, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8744, 6712, 775, 249, 16);
INSERT INTO 'dancespublicationsmap' VALUES (19959, 17521, 1345, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19960, 17522, 1345, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19984, 12374, 1347, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5508, 6375, 672, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6498, 4238, 533, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4023, 4632, 533, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4607, 5323, 533, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5063, 5855, 533, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5505, 6372, 533, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5536, 6403, 533, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5585, 6462, 533, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10727, 9401, 565, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10728, 9402, 565, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6768, 7418, 777, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6828, 7494, 777, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (81, 93, 133, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (921, 1066, 133, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1134, 1315, 133, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1295, 1499, 133, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1584, 1843, 133, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1648, 1913, 133, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2436, 2809, 133, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1868, 2157, 133, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2911, 3351, 133, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4943, 5721, 133, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5205, 6020, 133, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14999, 10958, 1033, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15000, 12245, 1033, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15001, 11792, 1033, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15002, 11795, 1033, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15003, 10959, 1033, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15004, 11796, 1033, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15005, 10961, 1033, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2892, 3331, 207, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5840, 6767, 207, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5986, 6941, 207, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (329, 382, 213, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5718, 6621, 213, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6003, 6961, 213, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19976, 7297, 1346, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19977, 7300, 1346, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19978, 7304, 1346, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19979, 7311, 1346, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19980, 7301, 1346, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19981, 7312, 1346, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19982, 7313, 1346, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19983, 14476, 1346, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19962, 17523, 1342, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19963, 17524, 1342, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19964, 17526, 1342, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19965, 17527, 1342, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19966, 17528, 1342, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19967, 17529, 1342, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19968, 17538, 1342, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19969, 17530, 1342, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19970, 17531, 1342, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19971, 17532, 1342, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19972, 17533, 1342, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19973, 17535, 1342, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19974, 17536, 1342, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (798, 929, 212, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4960, 5740, 212, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5188, 6001, 212, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20000, 6259, 1348, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20001, 2580, 1348, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20002, 203, 1348, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19938, 17502, 1255, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19939, 17503, 1255, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19940, 17504, 1255, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19941, 19380, 1255, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19834, 19381, 1255, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19942, 17505, 1255, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19943, 15399, 1255, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19944, 17506, 1255, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19945, 17507, 1255, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10076, 4217, 394, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2926, 3367, 719, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5757, 6666, 719, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20003, 8201, 1348, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20004, 10532, 1348, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20005, 10533, 1348, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20006, 10437, 1348, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2660, 3065, 634, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10362, 9011, 427, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10363, 9012, 427, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10364, 9013, 427, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10365, 9014, 427, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10366, 9015, 427, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5561, 6431, 133, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19985, 12231, 1347, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10401, 9086, 434, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3699, 4251, 255, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1172, 1357, 721, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10285, 8904, 413, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10286, 8905, 413, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10287, 8906, 413, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10288, 8907, 413, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10289, 8908, 413, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10290, 8909, 413, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1206, 1395, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1207, 1396, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5781, 6694, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1847, 2131, 186, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10639, 549, 553, 12, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10640, 658, 553, 13, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10641, 1210, 553, 14, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10642, 1244, 553, 15, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10643, 1501, 553, 16, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10644, 1562, 553, 17, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10645, 1786, 553, 18, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10646, 1782, 553, 19, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10647, 1792, 553, 20, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10648, 1931, 553, 22, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10649, 7542, 553, 23, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10650, 7546, 553, 24, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10651, 2498, 553, 25, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10652, 2745, 553, 26, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10653, 6233, 553, 27, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10654, 3129, 553, 28, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10655, 3172, 553, 29, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10656, 3336, 553, 30, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10657, 3659, 553, 32, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10658, 3953, 553, 34, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10659, 4032, 553, 36, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10660, 4102, 553, 38, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10661, 4359, 553, 40, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10662, 4562, 553, 41, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10663, 4641, 553, 42, 41);
INSERT INTO 'dancespublicationsmap' VALUES (20016, 3432, 1349, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19961, 17525, 1049, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3995, 4594, 160, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20017, 16483, 1349, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20018, 6010, 1349, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20019, 17549, 1349, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20020, 16484, 1349, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20021, 16485, 1349, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20022, 16486, 1349, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15475, 13992, 1061, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15476, 13993, 1061, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15477, 13994, 1061, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15478, 11727, 1061, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15479, 12536, 1061, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15480, 10524, 1061, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15481, 13998, 1061, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15482, 13999, 1061, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15483, 11267, 1061, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15582, 14095, 1066, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15583, 14096, 1066, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15585, 14098, 1066, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15584, 14097, 1066, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15586, 14099, 1066, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15484, 14000, 1061, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15485, 14001, 1061, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20007, 14136, 1348, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20008, 10535, 1348, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20009, 10531, 1348, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20010, 14137, 1348, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20011, 14138, 1348, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20012, 14139, 1348, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20013, 10534, 1348, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20014, 14140, 1348, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20015, 14141, 1348, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15486, 11707, 1061, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15487, 14003, 1061, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15488, 9834, 1061, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10664, 4928, 553, 44, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10665, 5239, 553, 46, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10666, 5330, 553, 48, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10667, 5525, 553, 50, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10668, 5964, 553, 51, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10669, 6010, 553, 52, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10670, 6048, 553, 53, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10671, 7172, 553, 54, 41);
INSERT INTO 'dancespublicationsmap' VALUES (10672, 7180, 553, 56, 41);
INSERT INTO 'dancespublicationsmap' VALUES (19986, 7049, 1347, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19987, 17541, 1347, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19988, 17542, 1347, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19989, 12132, 1347, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17787, 15828, 1210, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17788, 15829, 1210, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17789, 15830, 1210, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17790, 15831, 1210, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17791, 15832, 1210, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17792, 15833, 1210, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17793, 15834, 1210, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15754, 14200, 1016, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16632, 14804, 1138, 41, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17794, 8520, 1210, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17795, 15835, 1210, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17796, 15836, 1210, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17797, 15837, 1210, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17798, 15838, 1210, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17799, 15839, 1210, 25, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20047, 17581, 1350, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20046, 16904, 1350, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20044, 17578, 1350, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20045, 17135, 1350, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19990, 17543, 1347, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19991, 12138, 1347, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19992, 17544, 1347, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19993, 12195, 1347, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19994, 17545, 1347, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19995, 17546, 1347, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19996, 12209, 1347, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19997, 17547, 1347, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19998, 17614, 1347, 15, 90);
INSERT INTO 'dancespublicationsmap' VALUES (19999, 17548, 1347, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14702, 13083, 1009, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (19900, 17465, 1339, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19901, 17466, 1339, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19902, 17467, 1339, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19913, 17468, 1339, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19903, 17469, 1339, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19904, 17470, 1339, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19905, 17471, 1339, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19906, 17472, 1339, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19907, 17473, 1339, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19908, 17474, 1339, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19909, 17475, 1339, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19910, 17476, 1339, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19911, 17477, 1339, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19912, 17478, 1339, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17653, 15667, 1200, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17656, 15670, 1200, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17659, 15673, 1200, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17661, 15674, 1200, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17662, 15675, 1200, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17664, 15677, 1200, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20194, 15013, 1361, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19975, 17537, 1342, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17802, 15841, 1210, 28, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17803, 15842, 1210, 29, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19396, 13233, 1195, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19397, 17026, 1195, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19398, 11601, 1195, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19399, 17027, 1195, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19400, 15612, 1195, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19401, 17028, 1195, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19402, 17029, 1195, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19403, 17030, 1195, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19404, 17031, 1195, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19405, 11906, 1195, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19406, 17032, 1195, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19407, 17033, 1195, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19408, 17034, 1195, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19760, 17263, 1195, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19409, 17035, 1195, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19410, 17036, 1195, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19411, 17037, 1195, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19412, 15604, 1195, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19413, 17038, 1195, 25, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19415, 17040, 1195, 26, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19414, 17039, 1195, 26, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20195, 17707, 1361, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20196, 17708, 1361, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20197, 15014, 1361, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20198, 17709, 1361, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20199, 17710, 1361, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20200, 17712, 1361, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20201, 17713, 1361, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20202, 17714, 1361, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20173, 17678, 1360, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20174, 17679, 1360, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20175, 17680, 1360, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12477, 11399, 913, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12479, 7941, 913, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12478, 11400, 913, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (20176, 17681, 1360, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20177, 17682, 1360, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20178, 17683, 1360, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20179, 17684, 1360, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19795, 17291, 1287, 406, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20133, 17633, 1287, 408, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20134, 17634, 1287, 409, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20135, 17635, 1287, 410, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20136, 17638, 1287, 411, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20137, 17639, 1287, 412, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20138, 17640, 1287, 413, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20139, 17641, 1287, 414, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20140, 17642, 1287, 501, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20141, 17643, 1287, 502, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20142, 17644, 1287, 503, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20143, 17645, 1287, 504, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20144, 17664, 1358, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20145, 17665, 1358, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20146, 17666, 1358, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20147, 17667, 1358, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20148, 7572, 1358, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20149, 17668, 1358, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20150, 5272, 1358, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20151, 7935, 1358, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20152, 17669, 1358, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20153, 11724, 1358, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20154, 17670, 1358, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20155, 6056, 1358, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20156, 12247, 1358, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20157, 2413, 1358, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20158, 17671, 1358, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20159, 17672, 1358, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20160, 17673, 1358, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20161, 17674, 1358, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20128, 17629, 1353, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20118, 8478, 1353, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20119, 17631, 1353, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20120, 8472, 1353, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20121, 8470, 1353, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20122, 8473, 1353, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20123, 8476, 1353, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20124, 8477, 1353, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20125, 8469, 1353, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17804, 15843, 1210, 30, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17805, 15844, 1210, 31, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17806, 15845, 1210, 32, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17807, 15846, 1210, 33, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17846, 15884, 1214, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17847, 15885, 1214, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17848, 15886, 1214, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17808, 15847, 1210, 34, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20172, 17677, 1360, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17849, 15887, 1214, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17850, 15888, 1214, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17851, 15889, 1214, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17852, 15890, 1214, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20162, 8486, 1359, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20163, 8479, 1359, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20164, 8482, 1359, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20165, 8480, 1359, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20166, 17685, 1359, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20167, 17686, 1359, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20168, 14339, 1359, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20169, 8483, 1359, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20203, 9805, 727, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20204, 9804, 727, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20205, 9806, 727, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20206, 9807, 727, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20207, 4931, 1362, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11098, 9816, 662, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11099, 9817, 662, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11100, 7696, 662, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11101, 9818, 662, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11102, 9022, 662, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11103, 9819, 662, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11104, 7028, 662, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (20210, 17730, 1364, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20211, 17731, 1364, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20212, 17732, 1364, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20213, 17733, 1364, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20214, 17734, 1364, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20215, 17735, 1364, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20216, 17737, 1365, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20217, 17648, 1365, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20218, 17738, 1365, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20219, 17649, 1365, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20220, 17650, 1365, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20221, 17654, 1365, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20222, 17739, 1365, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20223, 7802, 1365, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20224, 17651, 1365, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20225, 17655, 1365, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20226, 17740, 1365, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20227, 17652, 1365, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20228, 17653, 1365, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20229, 17741, 1365, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20230, 17742, 1365, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20231, 17647, 1365, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20232, 17743, 1365, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20184, 17694, 1350, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20234, 17746, 1366, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20235, 17747, 1366, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20233, 17745, 1366, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20236, 17748, 1366, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20307, 17803, 1375, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20308, 17804, 1375, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20309, 17805, 1375, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20310, 17806, 1375, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20311, 17807, 1375, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20185, 17695, 1350, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20187, 17696, 1350, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12513, 11435, 919, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12514, 11436, 919, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12515, 9120, 919, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15218, 13816, 1046, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20069, 4828, 1351, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20075, 17601, 1351, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20074, 8520, 1351, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20076, 17602, 1351, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15219, 13817, 1046, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15220, 13818, 1046, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15221, 13352, 1046, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14452, 12780, 772, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14451, 12779, 772, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14450, 12778, 772, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14449, 12777, 772, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20129, 5289, 1354, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20131, 15587, 1354, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (20130, 12869, 1354, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20132, 12449, 1354, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20186, 17697, 1350, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20188, 17698, 1350, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20189, 17699, 1350, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20190, 17700, 1350, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20191, 17701, 1350, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20192, 17702, 1350, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20193, 17703, 1350, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20312, 17808, 1375, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20313, 17809, 1375, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20314, 17811, 1375, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20315, 17812, 1375, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20316, 16940, 1375, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20317, 17813, 1375, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2940, 3381, 147, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16560, 10084, 1136, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16561, 10085, 1136, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16562, 9897, 1136, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20285, 5915, 1373, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20278, 12475, 1371, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20318, 17814, 1375, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20279, 12476, 1371, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20208, 4765, 1363, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20319, 17815, 1375, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20320, 17816, 1375, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20209, 4558, 1363, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20321, 17817, 1375, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20322, 17818, 1375, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20280, 12477, 1371, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20323, 17810, 1376, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20324, 17819, 1376, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20325, 17820, 1376, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20326, 17821, 1376, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20327, 17822, 1376, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20328, 17823, 1376, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20329, 17824, 1376, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20330, 17825, 1376, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20331, 17826, 1376, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20332, 17827, 1376, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20333, 17828, 1376, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20334, 17829, 1376, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20180, 17689, 1350, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20181, 17690, 1350, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20182, 17691, 1350, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20183, 17693, 1350, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20335, 17830, 1376, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20336, 17463, 1376, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20337, 17831, 1376, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20338, 17832, 1376, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20339, 17833, 1377, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20340, 17834, 1377, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20341, 17835, 1377, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20342, 17836, 1377, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20343, 17837, 1377, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20344, 17838, 1377, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20345, 17839, 1377, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20346, 17840, 1377, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20347, 17841, 1377, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20348, 17842, 1377, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20349, 17843, 1377, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20350, 17844, 1377, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20351, 17845, 1377, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20352, 17846, 1377, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20353, 17847, 1377, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20354, 17848, 1377, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20355, 17849, 1377, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15490, 13214, 1061, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3285, 3786, 526, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4603, 5318, 512, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15491, 14007, 1061, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16890, 2453, 1148, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16893, 9353, 1148, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15492, 10525, 1061, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20381, 17869, 1380, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20382, 17870, 1380, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20383, 17871, 1380, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20384, 17872, 1380, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15493, 14009, 1061, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15494, 14010, 1061, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15495, 14011, 1061, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15496, 14012, 1061, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20391, 17891, 1381, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20394, 17892, 1381, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20385, 17873, 1380, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20386, 17874, 1380, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20387, 17875, 1380, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20388, 17876, 1380, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20389, 17877, 1380, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20390, 17878, 1380, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20364, 17858, 1379, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20365, 17827, 1379, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20366, 17859, 1379, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20367, 17860, 1379, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20368, 17807, 1379, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20369, 17861, 1379, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20370, 17808, 1379, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20371, 17841, 1379, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20372, 16940, 1379, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20373, 17862, 1379, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20375, 17863, 1379, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20374, 17832, 1379, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20376, 17864, 1379, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20377, 17865, 1379, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20378, 17866, 1379, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20379, 17867, 1379, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20380, 17868, 1379, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20356, 17850, 1378, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20357, 17851, 1378, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20358, 17852, 1378, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20359, 17853, 1378, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20360, 17854, 1378, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20361, 17855, 1378, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20362, 17856, 1378, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20363, 17857, 1378, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20405, 17906, 1382, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20406, 17907, 1382, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20407, 17908, 1382, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20408, 17909, 1382, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20409, 17910, 1382, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20410, 17911, 1382, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20411, 17912, 1382, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20412, 17913, 1382, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20413, 17914, 1382, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20414, 17915, 1382, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20415, 17916, 1382, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20416, 17917, 1382, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19177, 4968, 1295, 1, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19178, 3888, 1295, 2, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19179, 1624, 1295, 3, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19180, 76, 1295, 4, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19181, 6797, 1295, 5, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19182, 5463, 1295, 6, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19183, 7143, 1295, 7, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19184, 43, 1295, 8, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19185, 6721, 1295, 9, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19186, 6817, 1295, 10, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19187, 4925, 1295, 11, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19188, 5878, 1295, 12, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19189, 1020, 1295, 13, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20085, 17609, 1351, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20086, 17610, 1351, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20080, 7994, 1351, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20087, 17611, 1351, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20088, 17612, 1351, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20282, 17784, 1372, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20283, 17783, 1372, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20284, 17785, 1372, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20286, 17792, 1374, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20287, 17793, 1374, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20288, 17794, 1374, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20289, 17795, 1374, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20290, 16384, 1374, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20291, 12516, 1374, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20292, 14350, 1374, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20293, 3277, 1374, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20294, 17796, 1374, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20295, 17797, 1374, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20296, 17798, 1374, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20297, 6858, 1374, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20298, 17799, 1374, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20299, 4246, 1374, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19190, 6848, 1295, 14, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19191, 4431, 1295, 15, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19192, 6885, 1295, 16, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19193, 4440, 1295, 17, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19194, 4455, 1295, 18, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19195, 1762, 1295, 20, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19196, 4565, 1295, 21, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19197, 4518, 1295, 22, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19198, 5441, 1295, 23, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19199, 2024, 1295, 24, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19200, 1280, 1295, 25, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19201, 4144, 1295, 26, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19202, 4865, 1295, 27, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19203, 3862, 1295, 29, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19204, 132, 1295, 30, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19205, 3759, 1295, 31, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19206, 3506, 1295, 32, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19207, 743, 1295, 33, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19208, 848, 1295, 34, 12);
INSERT INTO 'dancespublicationsmap' VALUES (8622, 8094, 80, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12166, 9083, 884, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12167, 11112, 884, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1594, 1854, 115, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15489, 14005, 1061, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20395, 17893, 1381, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20396, 16803, 1381, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20397, 17895, 1381, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20398, 17896, 1381, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20399, 17897, 1381, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20400, 17898, 1381, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20401, 17899, 1381, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20402, 9486, 1381, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20403, 17900, 1381, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20404, 17901, 1381, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19209, 4827, 1295, 36, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19210, 7210, 1295, 37, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19211, 4086, 1295, 38, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19212, 6323, 1295, 39, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19213, 5522, 1295, 41, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19214, 2747, 1295, 42, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19215, 373, 1295, 44, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19216, 2962, 1295, 46, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19217, 3743, 1295, 48, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19218, 4358, 1295, 49, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19219, 5208, 1295, 50, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19220, 4407, 1295, 51, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19221, 4890, 1295, 52, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19222, 3659, 1295, 53, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19223, 4511, 1295, 54, 12);
INSERT INTO 'dancespublicationsmap' VALUES (19224, 116, 1295, 57, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20417, 289, 1295, 58, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20418, 109, 1295, 60, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20419, 2562, 1295, 61, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20420, 1588, 1295, 62, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20421, 4491, 1295, 63, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20422, 2494, 1295, 64, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20423, 5543, 1295, 66, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20424, 6420, 1295, 67, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20425, 4759, 1295, 68, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20426, 5765, 1295, 69, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20427, 6287, 1295, 70, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20428, 3788, 1295, 71, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20429, 5921, 1295, 72, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20430, 377, 1295, 73, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20431, 7147, 1295, 74, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20432, 5794, 1295, 75, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20433, 5800, 1295, 76, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20434, 5040, 1295, 77, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20435, 3038, 1295, 78, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20436, 2956, 1295, 79, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20437, 1783, 1295, 80, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20438, 984, 1295, 81, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20439, 40, 1295, 82, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20440, 4103, 1295, 83, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20602, 17991, 1387, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20603, 17889, 1387, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20604, 17888, 1387, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20605, 16126, 1387, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12820, 11873, 938, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12821, 11874, 938, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12822, 11875, 938, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20606, 17941, 1383, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20607, 16775, 1383, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20591, 17978, 1386, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20592, 17979, 1386, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20593, 17980, 1386, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20594, 17981, 1386, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20595, 17984, 1386, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20596, 17985, 1386, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20597, 17986, 1386, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20598, 17987, 1386, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20599, 17988, 1386, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20600, 17989, 1386, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20608, 17943, 1383, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20609, 17944, 1383, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20610, 17997, 1383, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20611, 17946, 1383, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20612, 17947, 1383, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20613, 17998, 1383, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20614, 17999, 1383, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20615, 18000, 1383, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20616, 18001, 1383, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20617, 18002, 1383, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20618, 18003, 1383, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20619, 18004, 1383, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20620, 18005, 1383, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20621, 18006, 1383, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20622, 17711, 1383, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20623, 15622, 1383, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20624, 18007, 1383, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20625, 16776, 1383, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20626, 18008, 1383, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20627, 16774, 1383, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20628, 18009, 1383, 49, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20629, 18010, 1383, 51, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20630, 18011, 1383, 53, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20300, 17800, 1374, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20301, 7204, 1374, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20302, 17801, 1374, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20303, 5696, 1374, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20304, 17802, 1374, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20305, 13278, 1374, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20306, 8579, 1374, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20631, 18012, 1383, 55, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12823, 11876, 938, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12824, 8983, 938, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12825, 10866, 938, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12826, 10192, 938, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12827, 10190, 938, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20632, 18013, 1383, 57, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20633, 18014, 1383, 59, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8749, 7553, 775, 257, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20709, 1210, 1388, 94, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20710, 1244, 1388, 96, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20711, 1280, 1388, 98, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20712, 1304, 1388, 99, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20713, 1478, 1388, 101, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20714, 1562, 1388, 102, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20715, 1582, 1388, 103, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20716, 1786, 1388, 104, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20717, 1792, 1388, 106, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20718, 1884, 1388, 108, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20719, 1931, 1388, 110, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8750, 8144, 775, 258, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8751, 8145, 775, 259, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8752, 8146, 775, 260, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8753, 8147, 775, 261, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8754, 7546, 775, 262, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20720, 2024, 1388, 113, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20721, 2250, 1388, 115, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8755, 8148, 775, 263, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8756, 7548, 775, 264, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8757, 8149, 775, 265, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20722, 2302, 1388, 116, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20723, 2317, 1388, 118, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20724, 2428, 1388, 120, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20725, 2498, 1388, 122, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20726, 2745, 1388, 125, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20727, 2777, 1388, 126, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20728, 2820, 1388, 128, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20729, 2910, 1388, 130, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20730, 2979, 1388, 131, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20731, 6233, 1388, 133, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20732, 3339, 1388, 134, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20733, 3561, 1388, 136, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20734, 3562, 1388, 138, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20735, 3580, 1388, 140, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20736, 3672, 1388, 142, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20737, 3759, 1388, 143, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20738, 3834, 1388, 144, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20739, 4032, 1388, 145, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20740, 4239, 1388, 146, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20637, 7574, 1389, 58, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20646, 8142, 1389, 60, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20647, 10288, 1389, 62, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20648, 8143, 1389, 64, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8758, 8150, 775, 266, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20638, 7553, 1389, 66, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20650, 1210, 1389, 68, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20651, 8144, 1389, 70, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20652, 1478, 1389, 72, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20653, 1479, 1389, 74, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20654, 1562, 1389, 77, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8759, 8151, 775, 267, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20658, 1841, 1389, 79, 31);
INSERT INTO 'dancespublicationsmap' VALUES (20660, 1931, 1389, 81, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20661, 8146, 1389, 84, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20663, 2260, 1389, 86, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20664, 7546, 1389, 88, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8760, 7552, 775, 268, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20665, 2604, 1389, 92, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8761, 8152, 775, 269, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20668, 8148, 1389, 96, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20670, 7548, 1389, 98, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20671, 2931, 1389, 100, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20640, 8151, 1389, 102, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20679, 9834, 1389, 105, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20682, 7552, 1389, 108, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20683, 8152, 1389, 110, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20690, 10327, 1389, 113, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20691, 9000, 1389, 115, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20693, 5330, 1389, 117, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20694, 7554, 1389, 120, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20699, 13595, 1389, 122, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20700, 5713, 1389, 124, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20702, 17983, 1389, 126, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20641, 17791, 1389, 128, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8745, 7111, 775, 251, 31);
INSERT INTO 'dancespublicationsmap' VALUES (8746, 7574, 775, 254, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8747, 8142, 775, 255, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8748, 8143, 775, 256, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20745, 4862, 1388, 154, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20746, 4890, 1388, 155, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20747, 5239, 1388, 157, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20748, 5525, 1388, 159, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20749, 5529, 1388, 161, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20750, 5532, 1388, 163, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20751, 5713, 1388, 166, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20752, 5794, 1388, 168, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20753, 5964, 1388, 169, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20754, 6130, 1388, 171, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20755, 6359, 1388, 175, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20655, 1582, 1389, 148, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20756, 6748, 1388, 177, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20757, 6915, 1388, 179, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20758, 6957, 1388, 181, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20657, 1786, 1389, 150, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20656, 1792, 1389, 152, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20659, 5693, 1389, 154, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20642, 2498, 1389, 158, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20759, 7055, 1388, 183, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20760, 7109, 1388, 184, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20761, 7147, 1388, 185, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20762, 445, 1388, 188, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20763, 462, 1388, 191, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20764, 584, 1388, 193, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20765, 1128, 1388, 195, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20766, 1485, 1388, 197, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20767, 1782, 1388, 199, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20768, 1841, 1388, 201, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20769, 5693, 1388, 203, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20770, 14713, 1388, 209, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20771, 2604, 1388, 212, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20772, 2935, 1388, 213, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20773, 2924, 1388, 215, 32);
INSERT INTO 'dancespublicationsmap' VALUES (20666, 2745, 1389, 162, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20669, 2910, 1389, 164, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20688, 4827, 1389, 164, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20672, 2979, 1389, 166, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20674, 3172, 1389, 168, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20675, 3561, 1389, 170, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20676, 3562, 1389, 173, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20678, 4032, 1389, 176, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20677, 4102, 1389, 178, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20831, 18036, 1302, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1812, 2095, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1201, 1390, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (861, 999, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (314, 366, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20441, 7333, 1384, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19507, 4782, 1316, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19508, 5462, 1316, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19509, 8144, 1316, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (265, 309, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (173, 197, 753, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14210, 10344, 983, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14211, 12515, 983, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14212, 2822, 983, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14213, 11750, 983, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14214, 9209, 983, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14215, 12301, 983, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14216, 11788, 983, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (621, 727, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5253, 6074, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (236, 277, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (118, 134, 204, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (738, 860, 211, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2725, 3140, 211, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20817, 8162, 1388, 281, 16);
INSERT INTO 'dancespublicationsmap' VALUES (13051, 7020, 73, 147, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13048, 3366, 73, 150, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13049, 2588, 73, 150, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13050, 5932, 73, 164, 40);
INSERT INTO 'dancespublicationsmap' VALUES (16313, 1709, 73, 168, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13047, 4211, 73, 171, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13905, 5307, 73, 209, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5909, 6846, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2177, 2509, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20821, 18023, 1390, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20822, 18024, 1390, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20819, 18020, 1389, 90, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20820, 18021, 1389, 94, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20818, 2250, 1389, 156, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20843, 1916, 1392, 0, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20862, 4438, 1392, 0, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20866, 5065, 1395, 0, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20867, 2349, 1395, 0, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20868, 4558, 1397, 0, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20869, 4959, 1398, 0, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20871, 1776, 1400, 0, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20864, 3631, 1394, 0, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20865, 4461, 1394, 0, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20872, 877, 1394, 0, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20875, 18076, 1390, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20884, 1647, 1403, 9, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20885, 1244, 1403, 10, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20886, 4155, 1403, 11, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20887, 5310, 1403, 12, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20888, 314, 1403, 14, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20889, 5934, 1403, 16, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20890, 6116, 1403, 18, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20891, 1428, 1403, 19, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20892, 3338, 1403, 20, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20893, 5111, 1403, 21, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20894, 3695, 1403, 22, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20895, 2084, 1403, 23, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20896, 4561, 1403, 24, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20897, 6736, 1403, 25, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20898, 2432, 1403, 26, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20899, 1223, 1403, 28, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20900, 4844, 1403, 30, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20901, 6368, 1403, 31, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20902, 4046, 1403, 32, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20903, 2600, 1403, 34, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20904, 3326, 1403, 35, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20905, 3165, 1403, 36, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20906, 442, 1403, 37, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20907, 4404, 1403, 38, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20908, 895, 1403, 39, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20909, 5734, 1403, 40, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20910, 2501, 1403, 41, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20911, 4894, 1403, 42, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20912, 5136, 1403, 44, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20913, 4929, 1403, 45, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20914, 1376, 1403, 47, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20915, 5099, 1403, 48, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20916, 4805, 1403, 49, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20917, 3108, 1403, 50, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20918, 221, 1403, 51, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20919, 4106, 1403, 52, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20920, 2437, 1403, 53, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20921, 6756, 1403, 54, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20922, 5804, 1403, 55, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20873, 17904, 1401, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20874, 17905, 1401, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20876, 18082, 1402, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20877, 18084, 1402, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20878, 17383, 1402, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20879, 18085, 1402, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20880, 18086, 1402, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20881, 18087, 1402, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13046, 10368, 73, 239, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13053, 11192, 73, 242, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13054, 11191, 73, 242, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13052, 10893, 73, 246, 40);
INSERT INTO 'dancespublicationsmap' VALUES (20844, 18056, 1391, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20841, 16731, 1391, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20845, 18057, 1391, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20846, 18058, 1391, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20847, 18059, 1391, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15993, 13000, 1096, 10, 50);
INSERT INTO 'dancespublicationsmap' VALUES (15994, 12999, 1096, 11, 50);
INSERT INTO 'dancespublicationsmap' VALUES (15995, 12998, 1096, 12, 50);
INSERT INTO 'dancespublicationsmap' VALUES (15996, 12997, 1096, 13, 50);
INSERT INTO 'dancespublicationsmap' VALUES (15997, 12640, 1096, 14, 50);
INSERT INTO 'dancespublicationsmap' VALUES (15998, 12810, 1096, 15, 50);
INSERT INTO 'dancespublicationsmap' VALUES (15999, 12929, 1096, 16, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16000, 13104, 1096, 17, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16001, 13116, 1096, 18, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16002, 13115, 1096, 19, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16003, 13149, 1096, 20, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16004, 12789, 1096, 21, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16005, 13277, 1096, 22, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16006, 13218, 1096, 23, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16007, 13276, 1096, 24, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16008, 13278, 1096, 25, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16009, 10784, 1096, 26, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16010, 10845, 1096, 27, 50);
INSERT INTO 'dancespublicationsmap' VALUES (20882, 18088, 1402, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20883, 18089, 1402, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20863, 1586, 1393, 0, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20923, 6380, 1403, 56, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20924, 5326, 1403, 58, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20925, 5612, 1403, 60, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20926, 5407, 1403, 61, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20927, 2394, 1403, 62, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20928, 7105, 1403, 63, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20929, 219, 1403, 64, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20930, 183, 1403, 66, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20931, 2469, 1403, 67, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20932, 5555, 1403, 68, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20933, 4629, 1403, 69, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20934, 2616, 1403, 70, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20935, 7204, 1403, 71, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20936, 5808, 1403, 72, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20937, 652, 1403, 74, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20938, 5006, 1403, 75, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20939, 5412, 1403, 76, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20940, 5204, 1403, 78, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20941, 4857, 1403, 79, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20942, 2267, 1403, 80, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20943, 340, 1403, 81, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20944, 4720, 1403, 82, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20945, 6386, 1403, 83, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20946, 4477, 1403, 84, 12);
INSERT INTO 'dancespublicationsmap' VALUES (20947, 6734, 1403, 85, 12);
INSERT INTO 'dancespublicationsmap' VALUES (21034, 18193, 1406, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21035, 18194, 1406, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21036, 18195, 1406, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18144, 16128, 1239, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18145, 14673, 1239, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18146, 16129, 1239, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18147, 16130, 1239, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18148, 6853, 1239, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18149, 16131, 1239, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18150, 16132, 1239, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18151, 16133, 1239, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18152, 16134, 1239, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18153, 16135, 1239, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18154, 4943, 1239, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18155, 9931, 1239, 26, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20970, 7643, 321, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20969, 1744, 321, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6745, 7391, 790, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20948, 18091, 1404, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20949, 18092, 1404, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20950, 18093, 1404, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20951, 18094, 1404, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20952, 18095, 1404, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20953, 15587, 1404, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20954, 18096, 1404, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20955, 18098, 1404, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20956, 18099, 1404, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20957, 18100, 1404, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20958, 18101, 1404, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8296, 4103, 191, 94, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8295, 4102, 191, 94, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8294, 4086, 191, 94, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8292, 4064, 191, 94, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8291, 4051, 191, 94, 104);
INSERT INTO 'dancespublicationsmap' VALUES (21037, 12024, 1406, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21038, 18196, 1406, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21039, 18197, 1406, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20964, 18124, 1369, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20965, 18125, 1369, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16503, 13582, 1130, 33, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20966, 18126, 1369, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20967, 18127, 1369, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20968, 18128, 1369, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20972, 18133, 1369, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20973, 18134, 1369, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20974, 18135, 1369, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20975, 18146, 1369, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20976, 18147, 1369, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20977, 18148, 1369, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20978, 18149, 1369, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12753, 11792, 936, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8300, 4155, 191, 95, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8303, 4227, 191, 96, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8302, 4209, 191, 96, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8301, 4196, 191, 96, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8304, 4239, 191, 96, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8309, 4318, 191, 97, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8305, 4248, 191, 97, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8306, 4270, 191, 97, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8307, 4291, 191, 97, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8308, 4309, 191, 97, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8314, 4359, 191, 98, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8310, 4324, 191, 98, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8315, 4356, 191, 98, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8313, 4358, 191, 98, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8312, 4334, 191, 98, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8311, 4325, 191, 98, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8321, 4433, 191, 99, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8319, 4424, 191, 99, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8318, 4407, 191, 99, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8320, 4431, 191, 99, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8317, 4404, 191, 99, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8316, 4374, 191, 99, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8323, 4440, 191, 100, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8326, 4447, 191, 100, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8325, 4444, 191, 100, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8322, 4438, 191, 100, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8324, 4442, 191, 100, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8328, 4451, 191, 101, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8329, 4455, 191, 101, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8327, 4450, 191, 101, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8331, 4476, 191, 101, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8330, 4461, 191, 101, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8335, 4506, 191, 102, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8336, 4511, 191, 102, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8338, 4517, 191, 103, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8339, 4518, 191, 103, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8337, 4512, 191, 103, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8340, 4543, 191, 103, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8345, 4565, 191, 104, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8342, 4555, 191, 104, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8346, 4579, 191, 104, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8341, 4548, 191, 104, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8344, 4562, 191, 104, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8343, 4561, 191, 104, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8347, 4595, 191, 105, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8350, 4641, 191, 105, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8348, 4602, 191, 105, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8349, 4638, 191, 105, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8351, 4646, 191, 105, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8352, 4662, 191, 106, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8355, 4725, 191, 106, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8353, 4663, 191, 106, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8354, 4679, 191, 106, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8356, 4728, 191, 107, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8358, 4755, 191, 107, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8359, 4759, 191, 107, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8360, 4765, 191, 107, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8357, 4744, 191, 107, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8363, 4803, 191, 108, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8364, 4804, 191, 108, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8365, 4805, 191, 108, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8366, 4806, 191, 108, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8361, 4784, 191, 108, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8362, 4782, 191, 108, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8367, 4827, 191, 109, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8368, 4830, 191, 109, 104);
INSERT INTO 'dancespublicationsmap' VALUES (20962, 18108, 1351, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20963, 18107, 1351, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20961, 18106, 1351, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20959, 18104, 1351, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20960, 18105, 1351, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8369, 4844, 191, 109, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8370, 4862, 191, 109, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8371, 4864, 191, 109, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8373, 4871, 191, 110, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8372, 4865, 191, 110, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8379, 4928, 191, 111, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8378, 4925, 191, 111, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8376, 4911, 191, 111, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8374, 4890, 191, 111, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8375, 4907, 191, 111, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8377, 4919, 191, 111, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8382, 4932, 191, 112, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8381, 4931, 191, 112, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8383, 4935, 191, 112, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8380, 4929, 191, 112, 104);
INSERT INTO 'dancespublicationsmap' VALUES (12754, 11793, 936, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12755, 11794, 936, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12756, 11795, 936, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12757, 10959, 936, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12758, 11796, 936, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12759, 10961, 936, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22342, 12811, 1487, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22343, 19071, 1487, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22344, 19072, 1487, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22345, 19073, 1487, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22346, 19074, 1487, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22329, 19082, 1486, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22330, 19083, 1486, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22331, 19084, 1486, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22332, 19085, 1486, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8413, 723, 191, 121, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8412, 5389, 191, 121, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8411, 5364, 191, 121, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8410, 5358, 191, 121, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8415, 5402, 191, 122, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8417, 5407, 191, 122, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8418, 5421, 191, 122, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8419, 5426, 191, 122, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8416, 5403, 191, 122, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8420, 5436, 191, 123, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8421, 5441, 191, 123, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8425, 5495, 191, 124, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8426, 5497, 191, 124, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8428, 5522, 191, 125, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8427, 5520, 191, 125, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8431, 5539, 191, 125, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8430, 5529, 191, 125, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8429, 5525, 191, 125, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8434, 5574, 191, 126, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8435, 5591, 191, 126, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8436, 5612, 191, 126, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8432, 5543, 191, 126, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8433, 5552, 191, 126, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8437, 5616, 191, 127, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8438, 5621, 191, 127, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8441, 5641, 191, 127, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8440, 5637, 191, 127, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8439, 5624, 191, 127, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8443, 5658, 191, 128, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8446, 5691, 191, 128, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8447, 5702, 191, 128, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8442, 5643, 191, 128, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8445, 5688, 191, 128, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8444, 5671, 191, 128, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8451, 5734, 191, 129, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8448, 5703, 191, 129, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8449, 5713, 191, 129, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8450, 5731, 191, 129, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8453, 5754, 191, 130, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8455, 5765, 191, 130, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8454, 5755, 191, 130, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8452, 5741, 191, 130, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8456, 5766, 191, 131, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8460, 5804, 191, 132, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8457, 5794, 191, 132, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8458, 5800, 191, 132, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8459, 5802, 191, 132, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8461, 5858, 191, 133, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8462, 5860, 191, 133, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8464, 5889, 191, 133, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8463, 5878, 191, 133, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8467, 5906, 191, 134, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8466, 5904, 191, 134, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8465, 5897, 191, 134, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8469, 5921, 191, 135, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8468, 5915, 191, 135, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8471, 5934, 191, 136, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8472, 5937, 191, 136, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8473, 5945, 191, 136, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8470, 5927, 191, 136, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8477, 5982, 191, 137, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8476, 5981, 191, 137, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8475, 5964, 191, 137, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8474, 5963, 191, 137, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8478, 6010, 191, 137, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8481, 6052, 191, 138, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8479, 6029, 191, 138, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8480, 6048, 191, 138, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8483, 6061, 191, 138, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8482, 6058, 191, 138, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8487, 6153, 191, 139, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8488, 6178, 191, 139, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8484, 6091, 191, 139, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8485, 6116, 191, 139, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8486, 6152, 191, 139, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8490, 6212, 191, 140, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8491, 6224, 191, 140, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8489, 6182, 191, 140, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8493, 6271, 191, 140, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8492, 6233, 191, 140, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8497, 6349, 191, 141, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8494, 6287, 191, 141, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8495, 6311, 191, 141, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8496, 6323, 191, 141, 104);
INSERT INTO 'dancespublicationsmap' VALUES (21692, 13480, 1221, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21726, 4806, 1436, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21702, 4239, 1428, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21705, 2645, 1428, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21706, 980, 1428, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21707, 2415, 1428, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21708, 3444, 1428, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21709, 3339, 1428, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21710, 3735, 1428, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21703, 7172, 1429, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21704, 3412, 1430, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21713, 4442, 1431, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21714, 4907, 1431, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21715, 6349, 1431, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21716, 794, 1431, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21718, 522, 1432, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21721, 7068, 1435, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7500, 7681, 299, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7503, 7686, 299, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1272, 1476, 5, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12120, 11080, 863, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15370, 13914, 1056, 43, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15371, 13915, 1056, 45, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15372, 13916, 1056, 47, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15373, 13917, 1056, 49, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15376, 13920, 1056, 57, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15377, 13921, 1056, 59, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15378, 13922, 1056, 61, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15379, 13923, 1056, 63, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15380, 13924, 1056, 65, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15381, 13925, 1056, 67, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15382, 13926, 1056, 69, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15383, 13927, 1056, 71, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15384, 13928, 1056, 73, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15385, 13929, 1056, 75, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15386, 13930, 1056, 77, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15387, 13931, 1056, 81, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15388, 13932, 1056, 83, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15389, 13933, 1056, 85, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15390, 13934, 1056, 87, 20);
INSERT INTO 'dancespublicationsmap' VALUES (21729, 6957, 1439, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21717, 5398, 1432, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21733, 1786, 1432, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21732, 6518, 1433, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21725, 3672, 1433, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21724, 3281, 1433, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17578, 15563, 1189, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8560, 7220, 191, 158, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8559, 7219, 191, 158, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8562, 7245, 191, 159, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8561, 7242, 191, 159, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8564, 7267, 191, 159, 104);
INSERT INTO 'dancespublicationsmap' VALUES (8563, 7247, 191, 159, 104);
INSERT INTO 'dancespublicationsmap' VALUES (13663, 6539, 954, 186, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13662, 6532, 954, 186, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13664, 6552, 954, 186, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13668, 6599, 954, 187, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13665, 6566, 954, 187, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13666, 6575, 954, 187, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13819, 9220, 954, 187, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13667, 6577, 954, 187, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13670, 6658, 954, 188, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13669, 6634, 954, 188, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13671, 6701, 954, 188, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13672, 6710, 954, 189, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13674, 6712, 954, 189, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13675, 6721, 954, 189, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13673, 6711, 954, 189, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13679, 6797, 954, 190, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13678, 6763, 954, 190, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13677, 6756, 954, 190, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13821, 6748, 954, 190, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13731, 6734, 954, 190, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13676, 6736, 954, 190, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13681, 6817, 954, 191, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13680, 6800, 954, 191, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13683, 6885, 954, 192, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13682, 6848, 954, 192, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13684, 6897, 954, 193, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13686, 6981, 954, 194, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13685, 6978, 954, 194, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13689, 7042, 954, 194, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13688, 7037, 954, 194, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13687, 6995, 954, 194, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13691, 7068, 954, 195, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13693, 7090, 954, 195, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13690, 7055, 954, 195, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13692, 7073, 954, 195, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13694, 7093, 954, 195, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13697, 7111, 954, 196, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13695, 7105, 954, 196, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13696, 7109, 954, 196, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13698, 7120, 954, 196, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13699, 7139, 954, 197, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13748, 7124, 954, 197, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13700, 7143, 954, 197, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13704, 7173, 954, 198, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13701, 7147, 954, 198, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13702, 7152, 954, 198, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13703, 7172, 954, 198, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13706, 7182, 954, 199, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13708, 7189, 954, 199, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13707, 7188, 954, 199, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13705, 7180, 954, 199, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13719, 7204, 954, 200, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13711, 7220, 954, 200, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13710, 7219, 954, 200, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13709, 7210, 954, 200, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13713, 7245, 954, 201, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13715, 7267, 954, 201, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13714, 7247, 954, 201, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13712, 7242, 954, 201, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13764, 11771, 954, 9037, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13779, 11773, 954, 9060, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13780, 11367, 954, 9062, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13316, 2956, 954, 9081, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13791, 9787, 954, 9097, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13793, 10306, 954, 9112, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13808, 9110, 954, 9165, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13809, 11369, 954, 9166, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13812, 10920, 954, 9173, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13813, 6964, 954, 9175, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13815, 6104, 954, 9176, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13820, 9897, 954, 9188, 102);
INSERT INTO 'dancespublicationsmap' VALUES (21046, 9106, 1407, 1, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21047, 11543, 1407, 1, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21048, 17136, 1407, 1, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21050, 14974, 1407, 2, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21051, 51, 1407, 2, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21049, 40, 1407, 2, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21053, 55, 1407, 3, 101);
INSERT INTO 'dancespublicationsmap' VALUES (20496, 7287, 1384, 56, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21693, 18251, 1427, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21694, 18252, 1427, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21695, 18253, 1427, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21696, 18254, 1427, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21697, 18078, 1427, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21698, 18256, 1427, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21699, 18257, 1427, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21700, 18258, 1427, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21701, 18259, 1427, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21052, 54, 1407, 3, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21057, 153, 1407, 4, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21056, 109, 1407, 4, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21055, 89, 1407, 4, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21054, 10663, 1407, 4, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21711, 6711, 1429, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21722, 1582, 1434, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18449, 16340, 1256, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18450, 16341, 1256, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18452, 16343, 1256, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18451, 16342, 1256, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18454, 16345, 1256, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18453, 16344, 1256, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18455, 16346, 1256, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18456, 16347, 1256, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18457, 16348, 1256, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18458, 16349, 1256, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18460, 16351, 1256, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18459, 16350, 1256, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (9635, 8267, 353, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9636, 8268, 353, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9637, 8269, 353, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9638, 8270, 353, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9639, 8271, 353, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9640, 8272, 353, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9641, 8273, 353, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9642, 8274, 353, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9643, 8275, 353, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9644, 8276, 353, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9645, 8277, 353, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9646, 8278, 353, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18461, 16352, 1256, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18462, 16353, 1256, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18463, 16354, 1256, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18464, 16355, 1256, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18465, 16356, 1256, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (21728, 3045, 1438, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18466, 16357, 1256, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18468, 16359, 1256, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18467, 16358, 1256, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18469, 16360, 1256, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18470, 16361, 1256, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (13094, 445, 954, 15, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13757, 11373, 954, 15, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13093, 442, 954, 15, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13099, 522, 954, 16, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13097, 497, 954, 16, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13096, 480, 954, 16, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13095, 462, 954, 16, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13098, 521, 954, 16, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13742, 535, 954, 17, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13101, 549, 954, 17, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13100, 541, 954, 17, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13758, 9562, 954, 18, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13102, 559, 954, 18, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13103, 570, 954, 18, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13105, 578, 954, 19, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13107, 588, 954, 19, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13104, 571, 954, 19, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13106, 584, 954, 19, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13108, 594, 954, 20, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13109, 608, 954, 20, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13110, 611, 954, 20, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13111, 633, 954, 20, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13114, 654, 954, 21, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13721, 652, 954, 21, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13115, 655, 954, 21, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13113, 650, 954, 21, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13112, 640, 954, 21, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13118, 682, 954, 22, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13117, 674, 954, 22, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13119, 738, 954, 22, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13116, 658, 954, 22, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13124, 753, 954, 23, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13123, 751, 954, 23, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13120, 741, 954, 23, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13121, 743, 954, 23, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13122, 745, 954, 23, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13128, 773, 954, 24, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13126, 760, 954, 24, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13125, 754, 954, 24, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13127, 769, 954, 24, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13129, 778, 954, 25, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13131, 794, 954, 25, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13130, 779, 954, 25, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13759, 10545, 954, 25, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13740, 822, 954, 26, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13132, 816, 954, 26, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13760, 11188, 954, 26, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13133, 819, 954, 26, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13136, 877, 954, 27, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13135, 873, 954, 27, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13134, 848, 954, 27, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13137, 887, 954, 28, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13139, 894, 954, 28, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13138, 893, 954, 28, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13142, 902, 954, 29, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13144, 909, 954, 29, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13143, 905, 954, 29, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13141, 899, 954, 29, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13146, 936, 954, 30, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13147, 964, 954, 30, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13145, 910, 954, 30, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13150, 984, 954, 31, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13148, 972, 954, 31, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13149, 980, 954, 31, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13151, 985, 954, 31, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13153, 1018, 954, 32, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13154, 1019, 954, 32, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13155, 1020, 954, 32, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13735, 7284, 954, 32, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13152, 1017, 954, 32, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13156, 1024, 954, 33, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13761, 11375, 954, 33, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13157, 1034, 954, 33, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13158, 1060, 954, 33, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13160, 1154, 954, 34, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13159, 1100, 954, 34, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13140, 895, 954, 34, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13762, 11368, 954, 34, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13161, 1163, 954, 35, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13743, 1176, 954, 35, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13162, 1210, 954, 35, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13763, 10787, 954, 35, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13163, 1215, 954, 36, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13166, 1244, 954, 36, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13165, 1223, 954, 36, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13164, 1218, 954, 36, 102);
INSERT INTO 'dancespublicationsmap' VALUES (21712, 6362, 1430, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21742, 1017, 1433, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21719, 4562, 1433, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21720, 6029, 1433, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21723, 682, 1433, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21744, 654, 1433, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21745, 611, 1442, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21746, 5223, 1443, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21747, 3588, 1444, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21751, 1465, 1447, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21752, 1072, 1447, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21753, 5888, 1447, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21754, 2275, 1447, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21755, 3268, 1447, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21756, 3778, 1447, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21757, 607, 1447, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21758, 3671, 1447, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21759, 6276, 1447, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21760, 3054, 1447, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21761, 4617, 1447, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21762, 720, 1447, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21763, 889, 1447, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21764, 3691, 1447, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21765, 7107, 1447, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3309, 3813, 160, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6505, 4432, 160, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2201, 2534, 160, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1511, 1751, 160, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5210, 6028, 160, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4080, 4701, 160, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1284, 1488, 160, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6263, 7261, 160, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3511, 4042, 160, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4040, 4650, 160, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21412, 9638, 1407, 119, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21407, 4725, 1407, 124, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21795, 18308, 1449, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18471, 11751, 1256, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18472, 16362, 1256, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18473, 16363, 1256, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18474, 16364, 1256, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22349, 19075, 1487, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22350, 18330, 1487, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22351, 19086, 1487, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22352, 19087, 1487, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22353, 19088, 1487, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22354, 19089, 1487, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22355, 19090, 1487, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22368, 19091, 1487, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22367, 18332, 1487, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22356, 19092, 1487, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22357, 19093, 1487, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22358, 19094, 1487, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22359, 19095, 1487, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22360, 19096, 1487, 49, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13182, 1405, 954, 41, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13180, 1382, 954, 41, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13183, 1428, 954, 42, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13768, 11763, 954, 42, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13184, 1431, 954, 42, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13185, 1437, 954, 42, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13283, 2562, 954, 43, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13769, 8165, 954, 43, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13187, 1466, 954, 43, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13188, 1469, 954, 43, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13186, 1446, 954, 43, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13770, 1473, 954, 44, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13190, 1480, 954, 44, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13189, 1478, 954, 44, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13772, 1537, 954, 45, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13773, 10788, 954, 45, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13771, 9559, 954, 45, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13191, 1501, 954, 45, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13192, 1521, 954, 45, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13193, 1544, 954, 46, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13194, 1562, 954, 46, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13195, 1578, 954, 47, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13774, 10793, 954, 47, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13196, 1586, 954, 47, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13197, 1588, 954, 48, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13199, 1615, 954, 48, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13198, 1582, 954, 48, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13200, 1624, 954, 48, 102);
INSERT INTO 'dancespublicationsmap' VALUES (21743, 1366, 1441, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21750, 6407, 1446, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13201, 1647, 954, 49, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13202, 1677, 954, 49, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13203, 1733, 954, 50, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13775, 11572, 954, 50, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13206, 1768, 954, 51, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13209, 1775, 954, 51, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13208, 1774, 954, 51, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13207, 1773, 954, 51, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13205, 1762, 954, 51, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13204, 1758, 954, 51, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13214, 1783, 954, 52, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13211, 1777, 954, 52, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13210, 1776, 954, 52, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13213, 1782, 954, 52, 102);
INSERT INTO 'dancespublicationsmap' VALUES (13212, 1780, 954, 52, 102);
INSERT INTO 'dancespublicationsmap' VALUES (22361, 19097, 1487, 51, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22362, 19098, 1487, 53, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22363, 19099, 1487, 54, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21391, 4291, 1407, 114, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21392, 14976, 1407, 114, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21394, 4324, 1407, 115, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21396, 4325, 1407, 115, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21393, 14346, 1407, 115, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21395, 4365, 1407, 116, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21397, 16524, 1407, 116, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21404, 4411, 1407, 117, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21405, 4424, 1407, 117, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21403, 4407, 1407, 117, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21402, 4404, 1407, 117, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21401, 7543, 1407, 117, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21408, 16526, 1407, 118, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21406, 10589, 1407, 118, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21409, 4477, 1407, 118, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21410, 4484, 1407, 118, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21413, 4548, 1407, 119, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21411, 4491, 1407, 119, 101);
INSERT INTO 'dancespublicationsmap' VALUES (22364, 19100, 1487, 55, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22365, 19101, 1487, 57, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22366, 19102, 1487, 59, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22338, 19068, 1487, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22339, 19069, 1487, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22340, 15408, 1487, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22341, 19070, 1487, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22347, 18333, 1487, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22348, 18331, 1487, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20979, 18150, 1369, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20980, 18151, 1369, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20981, 18152, 1369, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20982, 18153, 1369, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20983, 18154, 1369, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20984, 18155, 1369, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20985, 18156, 1369, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20986, 18157, 1369, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20987, 18158, 1369, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20988, 18159, 1369, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20989, 18160, 1369, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20990, 18161, 1369, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20991, 18162, 1369, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20992, 18163, 1369, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20993, 18164, 1369, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20994, 18165, 1369, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20995, 18166, 1369, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20996, 17041, 1369, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20997, 18168, 1369, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20998, 18169, 1369, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20999, 18170, 1369, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21000, 18171, 1369, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21001, 18172, 1369, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21002, 18173, 1369, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21003, 18174, 1369, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21004, 18175, 1369, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21005, 18176, 1369, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21006, 18177, 1369, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21007, 18178, 1369, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21008, 18179, 1369, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21009, 18180, 1369, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21538, 16527, 1407, 156, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21539, 14548, 1407, 156, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21537, 11369, 1407, 156, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21515, 5904, 1407, 159, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21533, 5934, 1407, 161, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21649, 7210, 1407, 190, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21650, 7227, 1407, 191, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21652, 16761, 1407, 192, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21651, 7239, 1407, 192, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21519, 13590, 1407, 193, 101);
INSERT INTO 'dancespublicationsmap' VALUES (21781, 18301, 1449, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21782, 6242, 1449, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21783, 18302, 1449, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21790, 18303, 1449, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21791, 18304, 1449, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21792, 18305, 1449, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21793, 16108, 1449, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21794, 18307, 1449, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21829, 367, 1452, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (21830, 4920, 1452, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (21831, 5590, 1452, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (21832, 2675, 1453, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (21833, 2927, 1453, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (21834, 3137, 1453, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (21835, 1025, 1454, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (21796, 18312, 1450, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21797, 18313, 1450, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21798, 16433, 1450, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21799, 16434, 1450, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21800, 18314, 1450, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21801, 18315, 1450, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21802, 18316, 1450, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21803, 18317, 1450, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21804, 18318, 1450, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21805, 18319, 1450, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21806, 18320, 1450, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21807, 18321, 1450, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21808, 18322, 1450, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21809, 18323, 1450, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21810, 18324, 1450, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21811, 18325, 1450, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21812, 18326, 1450, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21813, 18327, 1450, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21769, 18290, 1448, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21770, 18291, 1448, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21771, 18292, 1448, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21766, 6433, 1448, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21772, 18293, 1448, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21773, 18294, 1448, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21774, 18295, 1448, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21775, 18296, 1448, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21776, 15076, 1448, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21777, 18297, 1448, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21767, 12027, 1448, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21778, 18298, 1448, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21768, 11617, 1448, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21779, 18299, 1448, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21780, 18300, 1448, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21816, 17534, 1049, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11359, 10216, 767, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21836, 3323, 1454, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (21837, 4726, 1454, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (11360, 10217, 767, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11361, 10218, 767, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11362, 10219, 767, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11363, 10220, 767, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11364, 10221, 767, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11365, 10222, 767, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11366, 10223, 767, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21885, 11450, 1457, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21886, 11453, 1457, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21887, 11508, 1457, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21888, 11454, 1457, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21889, 11456, 1457, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21890, 11449, 1457, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21817, 18337, 1288, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18908, 16789, 1288, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18916, 16791, 1288, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18910, 16792, 1288, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21818, 17920, 1288, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21819, 18339, 1288, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21820, 18340, 1288, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21825, 18346, 1288, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18911, 16793, 1288, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18912, 16794, 1288, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18917, 16796, 1288, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18914, 16797, 1288, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21826, 18347, 1288, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11367, 10224, 767, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11368, 10225, 767, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11369, 10226, 767, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11370, 10227, 767, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11371, 10228, 767, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11372, 10229, 767, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12294, 11241, 898, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12299, 11246, 898, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12300, 11247, 898, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12301, 11248, 898, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12302, 11249, 898, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18509, 16398, 1258, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (12303, 11250, 898, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4605, 5321, 81, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3604, 4145, 81, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5770, 6682, 81, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6082, 7053, 81, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4900, 5671, 81, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3645, 4190, 81, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3353, 3864, 81, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22216, 18625, 1482, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22217, 18626, 1482, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22218, 18627, 1482, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20792, 8142, 1388, 255, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20793, 8143, 1388, 256, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20794, 7553, 1388, 257, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20795, 8144, 1388, 258, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20796, 8145, 1388, 259, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20797, 8146, 1388, 260, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20798, 8147, 1388, 261, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20799, 7546, 1388, 262, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20800, 8148, 1388, 263, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20801, 7548, 1388, 264, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20802, 8149, 1388, 265, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20803, 8150, 1388, 266, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20804, 8151, 1388, 267, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20805, 7552, 1388, 268, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20806, 8152, 1388, 269, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20807, 8153, 1388, 271, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20808, 7554, 1388, 272, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20809, 8154, 1388, 273, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20810, 8155, 1388, 274, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20811, 8156, 1388, 275, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20812, 8157, 1388, 276, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20813, 8158, 1388, 277, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20814, 8159, 1388, 278, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20815, 8160, 1388, 279, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20816, 8161, 1388, 280, 16);
INSERT INTO 'dancespublicationsmap' VALUES (18584, 16469, 1263, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18585, 16470, 1263, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18586, 16471, 1263, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18587, 16472, 1263, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18588, 16473, 1263, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18589, 16474, 1263, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18590, 16475, 1263, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18591, 16476, 1263, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (18592, 16477, 1263, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16309, 14683, 1102, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16310, 14682, 1102, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16311, 14681, 1102, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22446, 16898, 1490, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22447, 16900, 1490, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22448, 7637, 1490, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22449, 12895, 1490, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22450, 8347, 1490, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22451, 365, 1490, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22452, 16897, 1490, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22453, 15613, 1490, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22454, 16899, 1490, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22455, 16901, 1490, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22456, 11392, 1490, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22457, 16902, 1490, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22458, 19213, 1491, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22459, 19214, 1491, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22460, 19215, 1491, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22461, 19216, 1491, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22462, 19217, 1491, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22463, 19218, 1491, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22464, 19219, 1491, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22465, 19220, 1491, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22466, 19221, 1491, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (8684, 2820, 775, 128, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8685, 2910, 775, 130, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8686, 2979, 775, 131, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8687, 6233, 775, 133, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8688, 3339, 775, 134, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8689, 3561, 775, 136, 16);
INSERT INTO 'dancespublicationsmap' VALUES (8690, 3562, 775, 138, 16);
INSERT INTO 'dancespublicationsmap' VALUES (20701, 8154, 1389, 130, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20704, 6359, 1389, 132, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20689, 12071, 1389, 135, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20705, 8162, 1389, 138, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20667, 2820, 1389, 140, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20644, 6915, 1389, 143, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20645, 522, 1389, 146, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20680, 4196, 1389, 181, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20681, 4239, 1389, 183, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20684, 4641, 1389, 185, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20685, 4646, 1389, 188, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20686, 4782, 1389, 190, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20692, 5239, 1389, 192, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20695, 5384, 1389, 194, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20696, 8796, 1389, 194, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20697, 5525, 1389, 196, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20698, 5529, 1389, 198, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20703, 6048, 1389, 201, 31);
INSERT INTO 'dancespublicationsmap' VALUES (20673, 6233, 1389, 204, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20706, 7109, 1389, 206, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16191, 7304, 1109, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16192, 7311, 1109, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16193, 7312, 1109, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16197, 14478, 1109, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16198, 14479, 1109, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16199, 14480, 1109, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16201, 14482, 1109, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16202, 14483, 1109, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22605, 19344, 1502, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22606, 19345, 1502, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22491, 19259, 1494, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22492, 19260, 1494, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22493, 19261, 1494, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22494, 19262, 1494, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22495, 19263, 1494, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22496, 19264, 1494, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22497, 19265, 1494, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22498, 19266, 1494, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22499, 19267, 1494, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22500, 18017, 1494, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22501, 19268, 1494, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21860, 18375, 1455, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21838, 9492, 1455, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21839, 9493, 1455, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21840, 9491, 1455, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21841, 10236, 1455, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21876, 10254, 1456, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21877, 10248, 1456, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21878, 10256, 1456, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21879, 10259, 1456, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21880, 10260, 1456, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22423, 19145, 1489, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22424, 19146, 1489, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22425, 19147, 1489, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13027, 6870, 73, 182, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13031, 795, 73, 184, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13041, 5026, 73, 185, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13035, 1544, 73, 189, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13033, 964, 73, 191, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13039, 3106, 73, 196, 40);
INSERT INTO 'dancespublicationsmap' VALUES (22445, 18553, 73, 305, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4027, 4637, 674, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22488, 19255, 1493, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22490, 19256, 1493, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22467, 18581, 1492, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22468, 15339, 1492, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22469, 12866, 1492, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22470, 15341, 1492, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18609, 11713, 1265, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22489, 19257, 1493, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22607, 19346, 1502, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22608, 17382, 1502, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22609, 19347, 1502, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22610, 19348, 1502, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22611, 15621, 1502, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22612, 17053, 1502, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22613, 19349, 1502, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22614, 19249, 1502, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22615, 19350, 1502, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22616, 19351, 1502, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22617, 19352, 1502, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22618, 19353, 1502, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22545, 113, 592, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22544, 3838, 592, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22543, 7078, 592, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22542, 1795, 592, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22512, 1647, 31, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22513, 1244, 31, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22514, 4155, 31, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22515, 5310, 31, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22516, 314, 31, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22517, 5934, 31, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22518, 6116, 31, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22519, 1428, 31, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22546, 19292, 1497, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22547, 19293, 1497, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22548, 19294, 1497, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22549, 19295, 1497, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22550, 19296, 1497, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22551, 19297, 1497, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22552, 19298, 1497, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22553, 19299, 1497, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22554, 19300, 1497, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22555, 19301, 1497, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22556, 19302, 1497, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22619, 11277, 903, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22620, 11278, 903, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22621, 11279, 903, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22622, 11280, 903, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22623, 11281, 903, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22624, 11282, 903, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22557, 19303, 1497, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22558, 19304, 1497, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22559, 19305, 1497, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22560, 19311, 1498, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22561, 19281, 1498, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22562, 19312, 1498, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22563, 19313, 1498, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22564, 19314, 1498, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22565, 19315, 1498, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22566, 19316, 1498, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22567, 19317, 1498, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22568, 19318, 1498, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22569, 18669, 1498, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22570, 19319, 1498, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22571, 16903, 1499, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22572, 19320, 1499, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22573, 19321, 1500, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22574, 19322, 1500, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22575, 12538, 1500, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22576, 19323, 1500, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22577, 19324, 1500, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22578, 19325, 1500, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22579, 19326, 1500, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22580, 19327, 1500, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22581, 16158, 1500, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22582, 19328, 1500, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22583, 19329, 1500, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22584, 19330, 1500, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22585, 19331, 1500, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22586, 19332, 1500, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22587, 13622, 1500, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22588, 19333, 1500, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22589, 19334, 1500, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22590, 19335, 1500, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22591, 16014, 1501, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22592, 7831, 1501, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22593, 19336, 1501, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22594, 19337, 1501, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22595, 7670, 1501, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22596, 19338, 1501, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22597, 19339, 1501, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22598, 19340, 1501, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22599, 16013, 1501, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22600, 19341, 1501, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22601, 16015, 1501, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22602, 19342, 1501, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22603, 19343, 1501, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22604, 16837, 1501, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22625, 4165, 903, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22626, 11283, 903, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22627, 11284, 903, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22628, 11285, 903, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22629, 9701, 903, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22630, 11286, 903, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22631, 11287, 903, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22632, 11288, 903, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22633, 11289, 903, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22634, 11290, 903, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22635, 11291, 903, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22636, 11292, 903, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22637, 11293, 903, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22638, 11294, 903, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22639, 11295, 903, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22640, 11296, 903, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22750, 19469, 1508, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22751, 19470, 1508, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22696, 19367, 1504, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22697, 19368, 1504, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22698, 19369, 1504, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22699, 1007, 1504, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22700, 19370, 1504, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22701, 19371, 1504, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22702, 19372, 1504, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22703, 19373, 1504, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22704, 19374, 1504, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22705, 19375, 1504, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22706, 15330, 1505, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22707, 16176, 1505, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22708, 19228, 1505, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22709, 19376, 1505, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22710, 18576, 1505, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22711, 19377, 1505, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22712, 16177, 1505, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22713, 17948, 1505, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22714, 16460, 1505, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22715, 19378, 1505, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16566, 14742, 1137, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16567, 14743, 1137, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16568, 14744, 1137, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16569, 12520, 1137, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22502, 19210, 1137, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22503, 10661, 1137, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22717, 17508, 1255, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22718, 17509, 1255, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7516, 168, 454, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7515, 198, 454, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7514, 205, 454, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (958, 1108, 454, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22670, 13654, 1341, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22671, 8978, 1341, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22672, 17554, 1341, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22673, 17555, 1341, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22674, 17556, 1341, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22675, 17557, 1341, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22676, 17558, 1341, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22677, 17559, 1341, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22678, 17560, 1341, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22679, 17561, 1341, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22680, 17562, 1341, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22681, 17563, 1341, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22752, 19472, 848, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18896, 16768, 1285, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22641, 18, 198, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22642, 68, 198, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22682, 17564, 1341, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22683, 17565, 1341, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22684, 17566, 1341, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22685, 17567, 1341, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22686, 17275, 1341, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22687, 17320, 1341, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22688, 10048, 1341, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22689, 17568, 1341, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22690, 17569, 1341, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22691, 7371, 1503, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22692, 7374, 1503, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22693, 7390, 1503, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22694, 7463, 1503, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22695, 7507, 1503, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22716, 19379, 1505, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22719, 19382, 1505, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22720, 19383, 1505, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22721, 19384, 1505, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22722, 19385, 1505, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22723, 19386, 1505, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22724, 19387, 1505, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22725, 19388, 1505, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22726, 16461, 1505, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22727, 19389, 1505, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22728, 19390, 1505, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22729, 19391, 1505, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22730, 19392, 1505, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22731, 7878, 1506, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22744, 15601, 1508, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22745, 19464, 1508, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22746, 19465, 1508, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22747, 19466, 1508, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22748, 19467, 1508, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22749, 19468, 1508, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22755, 14667, 1509, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18344, 7284, 1249, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18345, 16224, 1249, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18346, 16225, 1249, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18347, 16226, 1249, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18348, 16227, 1249, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18349, 16228, 1249, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18350, 16229, 1249, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18351, 16230, 1249, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18352, 16231, 1249, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18353, 16232, 1249, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18354, 16233, 1249, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18355, 16234, 1249, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18356, 16235, 1249, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18357, 16236, 1249, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18358, 16237, 1249, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18359, 16238, 1249, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18360, 16239, 1249, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18361, 10441, 1249, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18362, 16240, 1249, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18363, 16241, 1249, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18364, 16242, 1249, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17999, 13884, 1227, 2, 40);
INSERT INTO 'dancespublicationsmap' VALUES (18000, 16012, 1227, 3, 40);
INSERT INTO 'dancespublicationsmap' VALUES (18001, 16013, 1227, 4, 40);
INSERT INTO 'dancespublicationsmap' VALUES (18002, 16014, 1227, 5, 40);
INSERT INTO 'dancespublicationsmap' VALUES (18003, 16015, 1227, 6, 40);
INSERT INTO 'dancespublicationsmap' VALUES (18004, 16016, 1227, 7, 40);
INSERT INTO 'dancespublicationsmap' VALUES (18005, 12030, 1227, 8, 40);
INSERT INTO 'dancespublicationsmap' VALUES (18006, 12027, 1227, 9, 40);
INSERT INTO 'dancespublicationsmap' VALUES (18007, 13420, 1227, 10, 40);
INSERT INTO 'dancespublicationsmap' VALUES (18008, 2876, 1227, 11, 40);
INSERT INTO 'dancespublicationsmap' VALUES (22817, 12530, 1513, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22818, 12018, 1513, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22819, 19531, 1513, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22820, 19532, 1513, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22821, 19533, 1513, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22822, 19534, 1513, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22823, 19535, 1513, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22824, 16939, 1513, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22825, 19536, 1513, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22826, 19537, 1513, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15737, 14183, 1078, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15738, 14184, 1078, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15739, 14185, 1078, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22794, 14678, 1512, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22795, 14677, 1512, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22796, 19518, 1512, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22797, 11113, 1512, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22798, 14659, 1512, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22799, 19519, 1512, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22800, 19520, 1512, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22801, 19521, 1512, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22802, 14531, 1512, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22803, 19522, 1512, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22804, 11114, 1512, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22805, 19523, 1512, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22761, 19477, 1511, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22762, 19478, 1511, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22756, 16878, 1511, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22763, 19479, 1511, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22764, 19480, 1511, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (332, 386, 455, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1082, 1256, 455, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1169, 1354, 455, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1456, 1688, 455, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1793, 2073, 455, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1824, 2108, 455, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1795, 2075, 455, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1988, 2296, 455, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2154, 2480, 455, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2190, 2522, 455, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2215, 2550, 455, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22765, 19481, 1511, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22766, 19482, 1511, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22767, 19483, 1511, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22768, 19484, 1511, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22769, 19485, 1511, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22770, 19486, 1511, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22771, 19487, 1511, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22772, 19488, 1511, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22773, 19489, 1511, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22774, 19490, 1511, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22775, 19491, 1511, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22753, 47, 454, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7517, 52, 454, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (996, 1151, 454, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1026, 1186, 454, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1036, 1196, 454, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22776, 19492, 1511, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22777, 19493, 1511, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22426, 19148, 1489, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22427, 19149, 1489, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22428, 19150, 1489, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22389, 999, 1489, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22429, 19151, 1489, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22430, 19152, 1489, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2235, 2572, 455, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2242, 2579, 455, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2260, 2606, 455, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2520, 2907, 455, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2543, 2932, 455, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7719, 5509, 322, 16, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7728, 5695, 322, 17, 40);
INSERT INTO 'dancespublicationsmap' VALUES (22806, 19524, 1509, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22807, 7133, 1509, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22808, 19520, 1509, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22809, 19525, 1509, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22810, 19526, 1509, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22811, 19527, 1509, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22812, 19528, 1509, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22813, 19529, 1509, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22814, 12023, 1509, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22815, 14665, 1509, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22816, 19530, 1509, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7753, 6047, 322, 18, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7758, 6079, 322, 19, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7759, 6146, 322, 20, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7768, 6419, 322, 21, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7815, 7009, 322, 22, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7853, 736, 322, 23, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5397, 6243, 76, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10795, 9504, 599, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2873, 3308, 464, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2883, 3318, 464, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3024, 3478, 464, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3129, 3600, 464, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3230, 3720, 464, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4181, 4823, 462, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4252, 4912, 462, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4366, 5043, 462, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4596, 5311, 462, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4597, 5312, 462, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4628, 5346, 462, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4809, 5566, 461, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5065, 5857, 461, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5385, 6227, 461, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5390, 6235, 461, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5593, 6470, 461, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7631, 3328, 461, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2647, 3049, 461, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4070, 4691, 461, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4488, 5185, 463, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4548, 5255, 463, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4606, 5322, 463, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5162, 5970, 463, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5213, 6031, 463, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5310, 6138, 463, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5559, 6428, 463, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5722, 6625, 463, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5842, 6769, 463, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5933, 6874, 463, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6159, 7140, 463, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6179, 7166, 463, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6182, 7169, 463, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6228, 7221, 463, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (75, 87, 464, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (178, 206, 464, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (180, 208, 464, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (254, 297, 464, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (457, 536, 464, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (887, 1026, 464, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1245, 1443, 464, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1361, 1575, 464, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1443, 1673, 464, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1457, 1689, 464, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1587, 1846, 464, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1674, 1941, 464, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2066, 2384, 464, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7540, 7733, 464, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2420, 2791, 464, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2509, 2895, 464, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2551, 2942, 464, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2699, 3112, 464, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2848, 3276, 464, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3586, 4124, 464, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3679, 4229, 464, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3843, 4420, 464, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4049, 4664, 464, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4082, 4705, 464, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4160, 4797, 464, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4204, 4855, 464, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4473, 5166, 464, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5427, 6279, 464, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6195, 7183, 464, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1978, 2286, 464, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2359, 2720, 464, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2779, 3195, 464, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3335, 3844, 464, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3471, 3995, 464, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4474, 5167, 464, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5984, 6939, 464, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18329, 16204, 1247, 39, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18330, 14973, 1247, 41, 10);
INSERT INTO 'dancespublicationsmap' VALUES (5996, 6953, 457, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7656, 7840, 459, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5698, 6598, 459, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5919, 6857, 459, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7611, 7225, 459, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1031, 1191, 454, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1043, 1206, 454, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1058, 1226, 454, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1091, 1266, 454, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1095, 1272, 454, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1108, 1286, 454, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1111, 1289, 454, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1114, 1292, 454, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1143, 1324, 454, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1243, 1438, 454, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1367, 1581, 454, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2554, 2945, 455, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2614, 3012, 455, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2615, 3013, 455, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2639, 3041, 455, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2686, 3096, 455, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2731, 3146, 455, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2767, 3183, 455, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2757, 3173, 455, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2835, 3263, 455, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2888, 3324, 455, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2930, 3371, 455, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3875, 4456, 456, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3876, 4457, 456, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3878, 4459, 456, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3881, 4462, 456, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3896, 4481, 456, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3935, 4530, 456, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3947, 4545, 456, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3958, 4557, 456, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3993, 4592, 456, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4033, 4643, 456, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4045, 4656, 456, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4065, 4686, 456, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4079, 4700, 456, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4090, 4714, 456, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1575, 1829, 452, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (55, 66, 452, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1160, 1345, 452, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1004, 1159, 452, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1527, 1770, 452, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1129, 1309, 452, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2718, 3133, 452, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2019, 2328, 452, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3712, 4266, 452, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2785, 3202, 452, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2976, 3420, 452, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3047, 3507, 455, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3125, 3596, 455, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18753, 16633, 1277, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18754, 16634, 1277, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18755, 16635, 1277, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18756, 16636, 1277, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18757, 16637, 1277, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18758, 16672, 1277, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18759, 16639, 1277, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18760, 16640, 1277, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18761, 16641, 1277, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18762, 16642, 1277, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18763, 16643, 1277, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18764, 16644, 1277, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18765, 16645, 1277, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18766, 16646, 1277, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18767, 16647, 1277, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18768, 16648, 1277, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18769, 16649, 1277, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18770, 16650, 1277, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4419, 5106, 696, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1951, 2256, 696, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5565, 6437, 696, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5446, 6301, 696, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2314, 2666, 696, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4585, 5300, 696, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5525, 6392, 696, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5107, 5905, 696, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5745, 6653, 696, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1177, 1364, 696, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2133, 2456, 696, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (49, 59, 696, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5155, 5962, 696, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4671, 5399, 696, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4067, 4688, 696, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (204, 237, 696, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2585, 2980, 696, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4489, 5186, 696, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1726, 1997, 696, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3992, 4591, 696, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (950, 1099, 696, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (295, 343, 696, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1834, 2118, 735, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5251, 6071, 735, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1770, 2049, 735, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3005, 3452, 735, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (711, 830, 735, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2397, 2763, 735, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5845, 6773, 735, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1489, 1726, 735, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4410, 5095, 735, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (292, 339, 735, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6266, 7264, 735, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2134, 2457, 735, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5438, 6292, 735, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5567, 6440, 735, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1742, 2015, 735, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5679, 6573, 735, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2301, 2653, 735, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1437, 1666, 735, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5824, 6750, 735, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4832, 5592, 735, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1997, 2306, 735, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23035, 9406, 1524, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23036, 1075, 1524, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23037, 1937, 1524, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23038, 9408, 1524, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23039, 1358, 1524, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23040, 5667, 1524, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23041, 9407, 1524, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23042, 5430, 1524, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23043, 9234, 1524, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23044, 9202, 1524, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23045, 1907, 1524, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23046, 9241, 1524, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23047, 9207, 1524, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23048, 4300, 1524, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23049, 11877, 1524, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15082, 13720, 1037, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15083, 13721, 1037, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15084, 13722, 1037, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15085, 13723, 1037, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15086, 13318, 1037, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15087, 13511, 1037, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15088, 13725, 1037, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15089, 13726, 1037, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15090, 13727, 1037, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15091, 13615, 1037, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15092, 13728, 1037, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18511, 16400, 1259, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18512, 16401, 1259, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18513, 16402, 1259, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18514, 16403, 1259, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18516, 16405, 1259, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18515, 16404, 1259, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18519, 16408, 1259, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18518, 16407, 1259, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18517, 16406, 1259, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18521, 16410, 1259, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18522, 16411, 1259, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18520, 16409, 1259, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18525, 16414, 1259, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18526, 16415, 1259, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18523, 16412, 1259, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18524, 16413, 1259, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18527, 16416, 1259, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (6350, 1625, 739, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6351, 1639, 739, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1424, 1649, 739, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1465, 1699, 739, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1484, 1721, 739, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6357, 1777, 739, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1641, 1905, 739, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1658, 1924, 739, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1691, 1960, 739, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7399, 868, 739, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20823, 18025, 1286, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20824, 18026, 1286, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20825, 18027, 1286, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20826, 18028, 1286, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20827, 18029, 1286, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20828, 18030, 1286, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20829, 18031, 1286, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20830, 18032, 1286, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18897, 16770, 1286, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17116, 15152, 1162, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17117, 15153, 1162, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17118, 15154, 1162, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17119, 15155, 1162, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17120, 15156, 1162, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17121, 15161, 1162, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17122, 15158, 1162, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17123, 15159, 1162, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17124, 15160, 1162, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17125, 15162, 1162, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17127, 15168, 1162, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17128, 15169, 1162, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17129, 15170, 1162, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17130, 15171, 1162, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17131, 15172, 1162, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17132, 15173, 1162, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17133, 15174, 1162, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17134, 15175, 1162, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17135, 15176, 1162, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18771, 16651, 1277, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18772, 16652, 1277, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18773, 16653, 1277, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18774, 16654, 1277, 25, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18775, 15589, 1277, 26, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18776, 16656, 1277, 27, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18777, 16657, 1277, 28, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18778, 16658, 1277, 29, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19424, 11587, 1308, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19425, 11590, 1308, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19426, 11591, 1308, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19427, 11592, 1308, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19428, 11593, 1308, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19429, 11594, 1308, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19430, 12669, 1308, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19431, 15681, 1308, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19432, 11595, 1308, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19433, 15683, 1308, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19434, 15538, 1308, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19435, 11597, 1308, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19870, 17428, 1338, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19871, 17429, 1338, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19872, 17430, 1338, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19873, 8102, 1338, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19874, 17432, 1338, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19875, 17433, 1338, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19876, 17434, 1338, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19877, 17435, 1338, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19878, 17436, 1338, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19879, 17437, 1338, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19880, 17438, 1338, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19881, 17439, 1338, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19882, 17440, 1338, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19883, 17441, 1338, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19884, 17442, 1338, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19885, 17443, 1338, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19886, 17444, 1338, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19887, 17445, 1338, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19888, 17446, 1338, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19889, 17447, 1338, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19890, 17448, 1338, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19891, 17449, 1338, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19892, 17450, 1338, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19893, 7503, 1338, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19894, 17452, 1338, 52, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19895, 17453, 1338, 54, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19896, 17454, 1338, 56, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19897, 17455, 1338, 58, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19898, 17456, 1338, 60, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21033, 17457, 1338, 62, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21731, 4359, 1437, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21730, 3953, 1437, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21727, 4864, 1437, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21738, 2593, 1437, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21842, 10239, 1455, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21843, 9494, 1455, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21844, 10245, 1455, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21845, 9495, 1455, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21846, 9568, 1455, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21847, 10240, 1455, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21848, 9569, 1455, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21849, 10237, 1455, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21850, 10246, 1455, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21851, 9483, 1455, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21852, 10244, 1455, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21853, 9566, 1455, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21854, 10238, 1455, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21855, 10242, 1455, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21856, 9490, 1455, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21857, 9567, 1455, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21858, 10243, 1455, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21859, 9487, 1455, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21925, 18376, 1456, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21861, 10253, 1456, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21862, 10247, 1456, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21863, 10264, 1456, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21864, 10269, 1456, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21865, 10252, 1456, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21866, 10261, 1456, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21867, 10265, 1456, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21868, 10268, 1456, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21869, 10263, 1456, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21870, 10257, 1456, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21871, 10251, 1456, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21872, 11500, 1456, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21873, 10249, 1456, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21874, 10266, 1456, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21875, 10258, 1456, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21881, 10250, 1456, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21882, 9833, 1456, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21883, 10255, 1456, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21909, 18377, 1457, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21893, 11446, 1457, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21891, 10272, 1457, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21892, 11509, 1457, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21894, 11502, 1457, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21895, 11451, 1457, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21896, 11504, 1457, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21897, 11507, 1457, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21898, 11510, 1457, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21899, 11447, 1457, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21900, 11503, 1457, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21901, 11501, 1457, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21903, 10271, 1457, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21902, 10900, 1457, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21904, 11457, 1457, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21905, 11452, 1457, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21906, 11505, 1457, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21907, 11506, 1457, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21908, 11448, 1457, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22066, 18516, 1471, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22067, 18517, 1471, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22068, 18518, 1471, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22069, 18520, 1471, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22732, 19411, 1507, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22733, 19412, 1507, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22734, 19413, 1507, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22735, 19414, 1507, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22736, 19415, 1507, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22737, 19416, 1507, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22738, 19417, 1507, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22739, 19418, 1507, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22740, 19419, 1507, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22741, 19420, 1507, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22742, 19421, 1507, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22743, 19422, 1507, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9673, 8305, 356, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9674, 8306, 356, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9676, 8308, 356, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9675, 8307, 356, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9678, 8310, 356, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9677, 8309, 356, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9680, 8312, 356, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9679, 8311, 356, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9681, 8313, 356, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9682, 8314, 356, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9684, 8316, 356, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9683, 8315, 356, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18781, 16661, 1277, 32, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18782, 16662, 1277, 33, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18783, 16663, 1277, 34, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18784, 16664, 1277, 35, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18785, 16665, 1277, 36, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18787, 16667, 1277, 38, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18788, 16668, 1277, 39, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18789, 16669, 1277, 40, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18790, 16670, 1277, 41, 10);
INSERT INTO 'dancespublicationsmap' VALUES (34, 41, 474, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (172, 196, 474, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (86, 99, 474, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1850, 2134, 474, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (264, 308, 474, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (451, 527, 474, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (361, 421, 474, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (639, 748, 474, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1771, 2051, 474, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12622, 11651, 926, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12623, 11652, 926, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12624, 11653, 926, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12625, 11654, 926, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12626, 11655, 926, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12627, 11656, 926, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12628, 11657, 926, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12629, 11658, 926, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12630, 11659, 926, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (673, 787, 474, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20239, 9125, 1370, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20240, 9126, 1370, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20241, 802, 1370, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20243, 9166, 1370, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20242, 9340, 1370, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20244, 9341, 1370, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20245, 9701, 1370, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20246, 10460, 1370, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20247, 10580, 1370, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20248, 10672, 1370, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20249, 11553, 1370, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20250, 11549, 1370, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20251, 12427, 1370, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20252, 10102, 1370, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20253, 14328, 1370, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20254, 14329, 1370, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20256, 13355, 1370, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20255, 13356, 1370, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20257, 13357, 1370, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20258, 12996, 1370, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20259, 14334, 1370, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20260, 14336, 1370, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20261, 14335, 1370, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20262, 14333, 1370, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20263, 14332, 1370, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20264, 14330, 1370, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20265, 14331, 1370, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20266, 15566, 1370, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20271, 17763, 1370, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20273, 15697, 1370, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20274, 17764, 1370, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20276, 17765, 1370, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20272, 17762, 1370, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20267, 17760, 1370, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20268, 12475, 1370, 101, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20269, 12476, 1370, 102, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20270, 12477, 1370, 103, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23050, 19205, 1370, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23051, 19793, 1370, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23052, 19794, 1370, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23053, 19795, 1370, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23054, 937, 1525, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23055, 1133, 1525, 3, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23056, 9084, 1525, 5, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23057, 19801, 1525, 14, 40);
INSERT INTO 'dancespublicationsmap' VALUES (22511, 19206, 1137, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22504, 19207, 1137, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22505, 19208, 1137, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22506, 10650, 1137, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22507, 19040, 1137, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22508, 19209, 1137, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22509, 19211, 1137, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16570, 14745, 1137, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23058, 19802, 1137, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23059, 7921, 1526, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23060, 1715, 1526, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23061, 4832, 1526, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23062, 19822, 1527, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23063, 19823, 1527, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23064, 19824, 1527, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23065, 19825, 1527, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23066, 19826, 1527, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23067, 19618, 1527, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23068, 19827, 1527, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23069, 19828, 1527, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23070, 19829, 1527, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23071, 19830, 1527, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23072, 16479, 1527, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23073, 19789, 1527, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2029, 2339, 474, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2031, 2341, 474, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22861, 2382, 474, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2105, 2425, 474, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2317, 2670, 474, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2323, 2676, 474, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2407, 2776, 474, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2380, 2741, 474, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2498, 2884, 474, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2506, 2892, 474, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2528, 2915, 474, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2540, 2929, 474, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2560, 2953, 474, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2557, 2949, 474, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2687, 3098, 474, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2688, 3099, 474, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2679, 3089, 474, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2765, 3181, 474, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16327, 14692, 1088, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16328, 14693, 1088, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16329, 14694, 1088, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16330, 14695, 1088, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16334, 14699, 1088, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16096, 14420, 1104, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17294, 15344, 1173, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17295, 15345, 1173, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17296, 15346, 1173, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17297, 15347, 1173, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17298, 15348, 1173, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17299, 15349, 1173, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17300, 15350, 1173, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17301, 15351, 1173, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17302, 15352, 1173, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17303, 15353, 1173, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17304, 15354, 1173, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17305, 15355, 1173, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17306, 15356, 1173, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17307, 15357, 1173, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15755, 14201, 1079, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15756, 11533, 1079, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15757, 13432, 1079, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15758, 14204, 1079, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15759, 13518, 1079, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15760, 13431, 1079, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15761, 13523, 1079, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15763, 13260, 1079, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15764, 13428, 1079, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15681, 13412, 1071, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15682, 13413, 1071, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15683, 13414, 1071, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21741, 7219, 1440, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21740, 3934, 1440, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21735, 936, 1440, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21736, 6634, 1440, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21737, 899, 1440, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21739, 4728, 1440, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15593, 14104, 1067, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15594, 14105, 1067, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15595, 14106, 1067, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15596, 14107, 1067, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20048, 17584, 1351, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20049, 17585, 1351, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20050, 17123, 1351, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20051, 17586, 1351, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20052, 13212, 1351, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20053, 9071, 1351, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20057, 17588, 1351, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20058, 17589, 1351, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20059, 9056, 1351, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20060, 1552, 1351, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20062, 17591, 1351, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20063, 17592, 1351, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20064, 17593, 1351, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20065, 17594, 1351, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20078, 17603, 1351, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20079, 17604, 1351, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20077, 9064, 1351, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2761, 3177, 125, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3519, 4052, 125, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (779, 907, 125, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (883, 1022, 125, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2146, 2471, 125, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1897, 2189, 125, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2959, 3402, 125, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3001, 3448, 125, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3063, 3525, 125, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3819, 4394, 125, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4573, 5282, 125, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5912, 6849, 125, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5500, 6366, 125, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2645, 3047, 125, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2564, 2957, 125, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1237, 1431, 125, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3041, 3499, 125, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3113, 3583, 125, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3489, 4019, 125, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5272, 6098, 125, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3563, 4097, 125, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4342, 5019, 125, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3735, 4294, 125, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15597, 14108, 1067, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15598, 14109, 1067, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15599, 14110, 1067, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15600, 14111, 1067, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15601, 14112, 1067, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15602, 14113, 1067, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22918, 6128, 1520, 504, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22919, 6949, 1520, 505, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22920, 3496, 1520, 506, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22921, 3160, 1520, 507, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22922, 6183, 1520, 508, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22923, 726, 1520, 509, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22924, 7171, 1520, 510, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22925, 3500, 1520, 511, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22926, 2371, 1520, 512, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22927, 424, 1520, 513, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17620, 15632, 1198, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17621, 15633, 1198, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17622, 15634, 1198, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17623, 11181, 1198, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17624, 15635, 1198, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17625, 15636, 1198, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17626, 15637, 1198, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17627, 15638, 1198, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17641, 15651, 1198, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17642, 15652, 1198, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22928, 3808, 1520, 514, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22929, 6785, 1520, 515, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22930, 2799, 1520, 516, 10);
INSERT INTO 'dancespublicationsmap' VALUES (15457, 8992, 1060, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15458, 13975, 1060, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15459, 12996, 1060, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15460, 13977, 1060, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15461, 13978, 1060, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15462, 13979, 1060, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15463, 13980, 1060, 24, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15464, 13085, 1060, 25, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15465, 13982, 1060, 26, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15466, 13983, 1060, 27, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15467, 13984, 1060, 28, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15468, 13985, 1060, 29, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15469, 13986, 1060, 30, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15470, 13987, 1060, 31, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15471, 13988, 1060, 32, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15472, 13989, 1060, 33, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15473, 13990, 1060, 34, 20);
INSERT INTO 'dancespublicationsmap' VALUES (20081, 17605, 1351, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20082, 17606, 1351, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20083, 17607, 1351, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20084, 17608, 1351, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23074, 19543, 1528, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23075, 19394, 1528, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23076, 12918, 1528, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23077, 12913, 1528, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23078, 12908, 1528, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23079, 12924, 1528, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23080, 19542, 1528, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23081, 19131, 1528, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23082, 12923, 1528, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23083, 19843, 1528, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23084, 19393, 1528, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23085, 12366, 1528, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23086, 19842, 1528, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23149, 19905, 1535, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23150, 19400, 1535, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23151, 19907, 1535, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23099, 19192, 1532, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17643, 15653, 1198, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17644, 15654, 1198, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17645, 15655, 1198, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17646, 15656, 1198, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (23087, 11183, 1198, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23088, 15631, 1529, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23089, 15632, 1529, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23090, 15633, 1529, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23091, 15634, 1529, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23092, 11181, 1529, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23093, 15635, 1529, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23094, 15636, 1529, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23095, 15637, 1529, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23096, 15638, 1529, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23097, 15651, 1529, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12321, 11276, 901, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12322, 11273, 901, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12323, 11270, 901, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12324, 11275, 901, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12325, 11272, 901, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12327, 11271, 901, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12326, 11274, 901, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22303, 11806, 901, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22304, 19042, 901, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22305, 15836, 901, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22306, 19048, 901, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22307, 18534, 901, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22308, 14599, 901, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22309, 19043, 901, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22310, 19044, 901, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22311, 19045, 901, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22312, 19046, 901, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22313, 19047, 901, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22314, 18533, 901, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22315, 15201, 901, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22316, 15206, 901, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18308, 16186, 1247, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18309, 16187, 1247, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18310, 13645, 1247, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18311, 16188, 1247, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18312, 16189, 1247, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18313, 16190, 1247, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18314, 16191, 1247, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18315, 16192, 1247, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18316, 16193, 1247, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18317, 16194, 1247, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18318, 16195, 1247, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18319, 16196, 1247, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18320, 14719, 1247, 25, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18321, 16197, 1247, 28, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18322, 14418, 1247, 30, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18323, 16198, 1247, 32, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18324, 16199, 1247, 34, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18325, 16200, 1247, 36, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18326, 16201, 1247, 37, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18327, 16203, 1247, 38, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18328, 16202, 1247, 38, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18337, 16210, 1247, 45, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18331, 16211, 1247, 46, 10);
INSERT INTO 'dancespublicationsmap' VALUES (23110, 19169, 1533, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4364, 5041, 451, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (354, 413, 122, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (600, 700, 122, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23112, 19860, 1533, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23113, 19861, 1533, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23114, 19862, 1533, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23115, 19863, 1533, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23116, 19864, 1533, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23111, 19831, 1533, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23117, 19865, 1533, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23118, 19866, 1533, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23119, 19867, 1533, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23120, 19868, 1533, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23121, 19869, 1533, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23152, 18939, 1535, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23153, 19908, 1535, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23154, 19909, 1535, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23155, 18273, 1535, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23156, 19910, 1535, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23157, 19911, 1535, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23139, 19898, 1534, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23140, 19899, 1534, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23141, 18576, 1534, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23142, 19900, 1534, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23146, 19901, 1534, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23144, 19902, 1534, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23145, 19903, 1534, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23098, 19854, 1532, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23158, 19912, 1535, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23159, 18729, 1535, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23124, 19872, 1533, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23125, 19873, 1533, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23122, 19870, 1533, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23123, 19871, 1533, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23126, 19874, 1533, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23127, 19875, 1533, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23128, 19876, 1533, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23129, 19877, 1533, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23130, 19879, 1533, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23131, 19880, 1533, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23132, 19881, 1533, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23133, 19882, 1533, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23134, 19883, 1533, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23135, 19884, 1533, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23136, 19885, 1533, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23137, 19886, 1533, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (995, 1150, 128, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5015, 5801, 128, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5049, 5839, 130, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23160, 19913, 1535, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23161, 19914, 1535, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23100, 19195, 1532, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23101, 19803, 1532, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23102, 19855, 1532, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23103, 19197, 1532, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23104, 18378, 1532, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23105, 18549, 1532, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23106, 16046, 1532, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23162, 19915, 1535, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23107, 19194, 1532, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23108, 18379, 1532, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23109, 19188, 1532, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23163, 18751, 1535, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23164, 19690, 1535, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23138, 19897, 1534, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23165, 19916, 1535, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23166, 19917, 1535, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23167, 19918, 1535, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23168, 19919, 1535, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23169, 14955, 1535, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23170, 18818, 1535, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23171, 19920, 1535, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23172, 19455, 1535, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23173, 19921, 1535, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23174, 12022, 1535, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23175, 18841, 1535, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23176, 19922, 1535, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23177, 19923, 1535, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23178, 10013, 1535, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23179, 18930, 1535, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18641, 16517, 1269, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18642, 16518, 1269, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18635, 15271, 1269, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (23005, 445, 1523, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23006, 9157, 1523, 6, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23007, 1544, 1523, 8, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23008, 2979, 1523, 10, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23009, 3057, 1523, 12, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23010, 7283, 1523, 14, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23011, 5209, 1523, 16, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23012, 5330, 1523, 18, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23013, 13077, 1523, 20, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23014, 7111, 1523, 22, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23015, 549, 1523, 26, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23016, 769, 1523, 28, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23017, 1492, 1523, 30, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23018, 1884, 1523, 32, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23019, 2924, 1523, 34, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23020, 3129, 1523, 36, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23021, 3172, 1523, 38, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23022, 4102, 1523, 40, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23023, 9638, 1523, 42, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23024, 6048, 1523, 44, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23025, 3791, 1523, 46, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23026, 1176, 1523, 48, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23027, 1473, 1523, 50, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23028, 1615, 1523, 52, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23029, 10433, 1523, 54, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23030, 2437, 1523, 56, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23031, 4015, 1523, 58, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23032, 4411, 1523, 60, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23033, 4555, 1523, 62, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23034, 7180, 1523, 64, 18);
INSERT INTO 'dancespublicationsmap' VALUES (22898, 7110, 1520, 401, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22899, 6506, 1520, 402, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22900, 2573, 1520, 403, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22901, 1461, 1520, 404, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22902, 2163, 1520, 405, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22903, 544, 1520, 406, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22904, 3352, 1520, 407, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22905, 1385, 1520, 408, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22906, 2828, 1520, 409, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22907, 5839, 1520, 410, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22908, 7079, 1520, 411, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22909, 3830, 1520, 412, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22910, 1338, 1520, 413, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22911, 5571, 1520, 414, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22912, 2734, 1520, 415, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22913, 566, 1520, 416, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22914, 5788, 1520, 417, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22915, 4347, 1520, 501, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22916, 6854, 1520, 502, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22917, 5418, 1520, 503, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22931, 5306, 1520, 517, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22932, 4572, 1520, 518, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22933, 3251, 1520, 519, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22934, 12186, 1520, 601, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22935, 19666, 1520, 602, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22936, 13558, 1520, 603, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22937, 19667, 1520, 604, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22941, 19671, 1520, 608, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22942, 8559, 1520, 609, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22943, 19672, 1520, 610, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22944, 19673, 1520, 611, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22945, 19674, 1520, 612, 10);
INSERT INTO 'dancespublicationsmap' VALUES (22950, 13555, 1520, 617, 10);
INSERT INTO 'dancespublicationsmap' VALUES (23182, 19926, 1534, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23183, 19892, 1534, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23185, 19927, 1534, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23186, 19929, 1534, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23187, 19930, 1534, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23188, 19931, 1534, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23184, 8335, 1534, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23189, 19258, 1538, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23180, 19925, 1538, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23190, 19938, 1538, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23191, 19723, 1538, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23192, 4273, 1538, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23193, 19724, 1538, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23194, 19939, 1538, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23195, 19934, 1538, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23196, 19940, 1538, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23197, 19935, 1538, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23181, 19924, 1538, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23198, 19936, 1538, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23199, 17318, 1538, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6293, 522, 41, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (12141, 11097, 865, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12143, 11098, 865, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12135, 11092, 865, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12138, 11094, 865, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12134, 11091, 865, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7586, 154, 329, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12350, 9453, 905, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12351, 10069, 905, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12352, 9454, 905, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12353, 9455, 905, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12354, 9456, 905, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12355, 9457, 905, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12356, 9458, 905, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12357, 9985, 905, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12358, 9459, 905, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12359, 9460, 905, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12360, 9461, 905, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12361, 9462, 905, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12362, 9469, 905, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12363, 9470, 905, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12364, 9471, 905, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12365, 9472, 905, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12366, 9463, 905, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12367, 9464, 905, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12368, 9350, 905, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12369, 9465, 905, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12370, 9466, 905, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12371, 9467, 905, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12372, 9090, 905, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12373, 9468, 905, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12374, 9874, 905, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12375, 9473, 905, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12376, 9474, 905, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12377, 9475, 905, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12378, 9476, 905, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12379, 9478, 905, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12380, 9477, 905, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12381, 9897, 905, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12382, 9479, 905, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12383, 9221, 905, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12384, 9480, 905, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12925, 6816, 330, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7598, 3490, 330, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23200, 19961, 1539, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23201, 19962, 1539, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23202, 19963, 1539, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23203, 19964, 1539, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23204, 19965, 1539, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23213, 19966, 1539, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2745, 3161, 162, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4487, 5184, 166, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5179, 5988, 166, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (211, 247, 166, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (199, 230, 166, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1230, 1420, 167, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23217, 19198, 1532, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23214, 19967, 1541, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23215, 19968, 1541, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23216, 3417, 1541, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2515, 2901, 163, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3705, 4259, 163, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6294, 541, 41, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6296, 610, 41, 5, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6303, 723, 41, 6, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6304, 754, 41, 7, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16636, 14811, 1045, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16251, 14539, 1045, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16252, 14540, 1045, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16508, 14720, 1045, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15182, 13781, 1045, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15183, 13782, 1045, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15184, 13783, 1045, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15185, 13784, 1045, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15189, 13785, 1045, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15187, 13787, 1045, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15186, 13786, 1045, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15188, 13788, 1045, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16250, 14538, 1045, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23234, 19733, 1547, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23235, 19987, 1547, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23236, 19988, 1547, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5571, 6445, 578, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5682, 6578, 578, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5193, 6007, 578, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5364, 6201, 579, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18779, 16659, 1277, 30, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18780, 16660, 1277, 31, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18791, 16671, 1277, 42, 10);
INSERT INTO 'dancespublicationsmap' VALUES (23227, 19517, 1545, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23228, 19979, 1545, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23229, 19516, 1545, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23230, 19514, 1545, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10930, 9631, 647, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10931, 9632, 647, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10932, 9633, 647, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10933, 9634, 647, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10934, 9635, 647, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10935, 9040, 647, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10936, 9636, 647, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10937, 9637, 647, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10938, 9638, 647, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10939, 9639, 647, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13044, 1533, 73, 238, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13045, 11257, 73, 239, 40);
INSERT INTO 'dancespublicationsmap' VALUES (22444, 18356, 73, 306, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3110, 3580, 13, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (23254, 20002, 73, 312, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23237, 19989, 1547, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23238, 19990, 1547, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23239, 18446, 1547, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5730, 6634, 16, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (772, 899, 16, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (23240, 19991, 1547, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23253, 20001, 1547, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23241, 18339, 1547, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23242, 19992, 1547, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23243, 18451, 1547, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23244, 19993, 1547, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23262, 20013, 1551, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23263, 20014, 1551, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23264, 20015, 1551, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23265, 20016, 1551, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23266, 20017, 1551, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23267, 20018, 1551, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23268, 20019, 1551, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23269, 20020, 1551, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23270, 20021, 1551, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23271, 20022, 1551, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23272, 20023, 1551, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23273, 20024, 1551, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23274, 20025, 1551, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23275, 20026, 1551, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23245, 19994, 1548, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23246, 19995, 1548, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23247, 19996, 1548, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23248, 19815, 1548, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23249, 19814, 1548, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23250, 19997, 1548, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23251, 19998, 1548, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23252, 19999, 1548, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23255, 4172, 1549, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23256, 20003, 1549, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23257, 20004, 1549, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23258, 20005, 1550, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23259, 20006, 1550, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23260, 20007, 1550, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23261, 20008, 1550, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3050, 3510, 452, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3057, 3517, 452, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3987, 4586, 452, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4124, 4751, 452, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3728, 4286, 452, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5325, 6159, 452, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (555, 647, 453, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6225, 7218, 453, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3844, 4421, 453, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5297, 6123, 453, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4525, 5225, 453, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15116, 13460, 1041, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15117, 13463, 1041, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15118, 13465, 1041, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15119, 13468, 1041, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15120, 13471, 1041, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15121, 13472, 1041, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15122, 13462, 1041, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15123, 13464, 1041, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15124, 13467, 1041, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15130, 13469, 1041, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15131, 13353, 1041, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21025, 18188, 1405, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21026, 18189, 1405, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21027, 18132, 1405, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21028, 18131, 1405, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21029, 18190, 1405, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21030, 18191, 1405, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21031, 18130, 1405, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21032, 18192, 1405, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5099, 5897, 261, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23218, 18808, 1290, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23224, 19972, 1290, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23219, 18806, 1290, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23220, 16842, 1290, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23221, 17577, 1290, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23222, 15951, 1290, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23225, 19973, 1290, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23223, 15435, 1290, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23226, 19974, 1290, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23231, 19985, 1547, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23232, 19826, 1547, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23233, 19986, 1547, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13896, 5385, 73, 16, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8663, 4878, 73, 165, 40);
INSERT INTO 'dancespublicationsmap' VALUES (8664, 7980, 73, 205, 40);
INSERT INTO 'dancespublicationsmap' VALUES (10688, 9350, 73, 230, 40);
INSERT INTO 'dancespublicationsmap' VALUES (10973, 9472, 73, 231, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13906, 10169, 73, 238, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13907, 10086, 73, 238, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1630, 1892, 268, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1729, 2000, 268, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7485, 7650, 268, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4615, 5332, 268, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23276, 7153, 268, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9880, 8510, 368, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9881, 8511, 368, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9882, 8512, 368, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9893, 8523, 369, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9894, 8524, 369, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9905, 8535, 370, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9906, 8536, 370, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9907, 8537, 370, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9908, 8538, 370, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9909, 8539, 370, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9910, 8540, 370, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9911, 8541, 370, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7537, 2543, 268, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5175, 5984, 268, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2262, 2608, 268, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7569, 7745, 268, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3860, 4441, 268, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11125, 9921, 665, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11126, 9922, 665, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11127, 9923, 665, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11128, 9924, 665, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11129, 9925, 665, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22388, 9227, 1489, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22431, 19153, 1489, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22432, 19154, 1489, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22433, 19155, 1489, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22390, 17340, 1489, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22434, 19156, 1489, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22435, 19157, 1489, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22391, 3277, 1489, 24, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22436, 19158, 1489, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22392, 17800, 1489, 26, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22437, 19159, 1489, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22438, 19160, 1489, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22393, 4149, 1489, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22394, 4246, 1489, 31, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22395, 17793, 1489, 32, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22396, 4354, 1489, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22397, 4632, 1489, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22439, 19161, 1489, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22398, 17792, 1489, 37, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22399, 5000, 1489, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22411, 16384, 1489, 54, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22754, 19474, 454, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1362, 1576, 454, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1461, 1695, 454, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1655, 1921, 454, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1689, 1958, 454, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1731, 2002, 454, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11972, 10925, 852, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11974, 10926, 852, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11983, 10950, 852, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11984, 10951, 852, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11985, 10952, 852, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11986, 10953, 852, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11989, 9910, 852, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11987, 10954, 852, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11988, 10955, 852, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11990, 10956, 852, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23277, 20061, 1555, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7507, 7690, 311, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7509, 7695, 311, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7731, 7915, 311, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7805, 8004, 311, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7819, 8013, 311, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23278, 7823, 311, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5448, 6304, 487, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12274, 3743, 487, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4658, 5385, 487, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4920, 5697, 487, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5509, 6376, 487, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6381, 2260, 487, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5510, 6377, 487, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23292, 8684, 1556, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23291, 8683, 1556, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23288, 20072, 1556, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23286, 1609, 1556, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23293, 8856, 1556, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12631, 11660, 926, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12632, 11661, 926, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22412, 14350, 1489, 55, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22413, 17801, 1489, 56, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22414, 8579, 1489, 57, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22415, 17799, 1489, 60, 35);
INSERT INTO 'dancespublicationsmap' VALUES (22416, 6725, 1489, 61, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22442, 19164, 1489, 62, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22443, 19165, 1489, 69, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23289, 11872, 1556, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23294, 20075, 1556, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23287, 13405, 1556, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23284, 16623, 1556, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23290, 20073, 1556, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23285, 14401, 1556, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23295, 15268, 1556, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23296, 18571, 1556, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23297, 8710, 1556, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23298, 14577, 1556, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23299, 8720, 1556, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19337, 16962, 1288, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19338, 16963, 1288, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21827, 18348, 1288, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21828, 18278, 1288, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1474, 1709, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3321, 3827, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23301, 4354, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23302, 1384, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23303, 3454, 205, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15798, 14221, 1082, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15799, 14222, 1082, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15800, 14223, 1082, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15801, 14224, 1082, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15802, 14225, 1082, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15078, 13716, 1032, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23306, 20091, 1557, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23307, 20092, 1557, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23304, 20048, 1557, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23308, 20093, 1557, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23309, 20094, 1557, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23310, 20095, 1557, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23305, 20058, 1557, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23311, 20096, 1557, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23312, 20097, 1557, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13878, 12233, 963, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13879, 12167, 963, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13880, 12193, 963, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13881, 12234, 963, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13882, 12235, 963, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13883, 12236, 963, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13884, 12237, 963, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13885, 12238, 963, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13886, 12239, 963, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13887, 12240, 963, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22863, 1484, 474, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (742, 865, 474, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1013, 1169, 474, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23324, 20103, 1558, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23315, 19033, 1558, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23326, 20104, 1558, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23327, 20105, 1558, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23316, 19812, 1558, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23328, 20106, 1558, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23325, 20102, 1558, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23317, 14640, 1558, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23318, 14597, 1558, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23329, 20107, 1558, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23319, 9800, 1558, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23320, 17675, 1558, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23330, 20108, 1558, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4501, 5200, 436, 5, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4085, 4709, 436, 6, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7701, 5273, 284, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11499, 6206, 284, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1271, 1475, 436, 10, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5707, 6610, 436, 11, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5861, 6791, 436, 33, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4923, 5701, 436, 34, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23331, 20109, 1558, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23332, 20110, 1558, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23321, 20079, 1558, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23333, 20111, 1558, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23334, 20112, 1558, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23322, 12476, 1558, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23323, 20057, 1558, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23335, 20113, 1558, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23336, 20114, 1558, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23337, 20116, 1558, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23338, 20115, 1558, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (658, 769, 201, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19309, 5403, 201, 22, 25);
INSERT INTO 'dancespublicationsmap' VALUES (19310, 2263, 201, 23, 25);
INSERT INTO 'dancespublicationsmap' VALUES (1487, 1724, 474, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1093, 1270, 474, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1170, 1355, 474, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1510, 1748, 474, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1542, 1791, 474, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23339, 20120, 1559, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23340, 20121, 1559, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23341, 20122, 1559, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23342, 20123, 1559, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23343, 20124, 1559, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23344, 20125, 1559, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23345, 20126, 1559, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23346, 20127, 1559, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23347, 20128, 1559, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23348, 20129, 1559, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1109, 1287, 474, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1547, 1797, 474, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23313, 20098, 1557, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23314, 20099, 1557, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (112, 126, 474, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1430, 1655, 474, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1788, 2068, 474, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1836, 2120, 474, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2768, 3184, 474, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2502, 2888, 474, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2980, 3425, 474, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2775, 3191, 474, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2871, 3306, 474, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2876, 3311, 474, 49, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2915, 3355, 474, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2916, 3356, 474, 51, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2989, 3434, 474, 52, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3083, 3548, 474, 53, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2996, 3442, 474, 54, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3305, 3809, 474, 55, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2387, 2751, 474, 56, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3156, 3628, 455, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23349, 20136, 1557, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23350, 9059, 1351, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16651, 14828, 1141, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16652, 14829, 1141, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16654, 14831, 1141, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16655, 14832, 1141, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16656, 14833, 1141, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16657, 12677, 1141, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16658, 12676, 1141, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16659, 14822, 1141, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16660, 14823, 1141, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16661, 14824, 1141, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16662, 14825, 1141, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16663, 14826, 1141, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16664, 14827, 1141, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16665, 12871, 1141, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16666, 11418, 1141, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16667, 7305, 1141, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16668, 11419, 1141, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16669, 14834, 1141, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16670, 14835, 1141, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16671, 12678, 1141, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16672, 7299, 1141, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16673, 14836, 1141, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16674, 7276, 1141, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16675, 10114, 1141, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16676, 14837, 1141, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16677, 11416, 1141, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16678, 7277, 1141, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16679, 9143, 1141, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16680, 14838, 1141, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3877, 4458, 474, 71, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1157, 1342, 474, 72, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3984, 4583, 474, 73, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4058, 4678, 474, 74, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1740, 2012, 474, 75, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4087, 4711, 474, 76, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4308, 4980, 474, 77, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4086, 4710, 474, 78, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1280, 1484, 474, 79, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4126, 4753, 474, 80, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4407, 5092, 474, 81, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4131, 4758, 474, 82, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4209, 4861, 474, 83, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4262, 4923, 474, 84, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4400, 5085, 474, 85, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22860, 3328, 474, 86, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4425, 5113, 474, 87, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4540, 5246, 474, 88, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4600, 5315, 474, 89, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4611, 5328, 474, 90, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4639, 5360, 474, 91, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4643, 5365, 474, 92, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4645, 5367, 474, 93, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4646, 5368, 474, 94, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2013, 2322, 474, 95, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4664, 5392, 474, 96, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4683, 5411, 474, 97, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4727, 5470, 474, 98, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5521, 6388, 474, 99, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4088, 4712, 474, 100, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4810, 5567, 474, 101, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4931, 5709, 474, 102, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4938, 5716, 474, 103, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4991, 5774, 474, 104, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5003, 5789, 474, 105, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5048, 5838, 474, 106, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5051, 5841, 474, 107, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5242, 6062, 474, 108, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5755, 6664, 474, 109, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5282, 6108, 474, 110, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5817, 6741, 474, 111, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5806, 6728, 474, 112, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5295, 6121, 474, 113, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5299, 6125, 474, 114, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5617, 6499, 474, 115, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5865, 6795, 474, 116, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5913, 6850, 474, 117, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2421, 2792, 474, 118, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5951, 6895, 474, 119, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5958, 6903, 474, 120, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1528, 1772, 474, 121, 30);
INSERT INTO 'dancespublicationsmap' VALUES (392, 456, 474, 122, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6147, 7126, 474, 123, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6270, 7268, 474, 124, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6246, 7241, 474, 125, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16681, 14839, 1141, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16682, 7303, 1141, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16683, 14840, 1141, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16684, 14841, 1141, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16685, 14842, 1141, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16686, 14642, 1141, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16687, 2432, 1141, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16688, 11413, 1141, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16689, 11417, 1141, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16690, 7306, 1141, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16691, 11420, 1141, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16692, 12661, 1141, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16693, 14843, 1141, 49, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16694, 7279, 1141, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16696, 9144, 1141, 51, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16697, 14847, 1141, 52, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16698, 14845, 1141, 53, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16699, 7307, 1141, 54, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11488, 1512, 284, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16700, 14846, 1141, 55, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16701, 11422, 1141, 56, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16702, 14848, 1141, 57, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16716, 11424, 1141, 71, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16717, 14856, 1141, 72, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16718, 7288, 1141, 73, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16719, 14857, 1141, 74, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16720, 11425, 1141, 75, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16721, 13281, 1141, 76, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16724, 7275, 1141, 79, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16725, 14858, 1141, 80, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16726, 14859, 1141, 81, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16727, 14860, 1141, 82, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16728, 14861, 1141, 83, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16729, 14862, 1141, 84, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16730, 14863, 1141, 85, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16731, 7315, 1141, 86, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16732, 14864, 1141, 87, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16733, 14865, 1141, 88, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16734, 14866, 1141, 89, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16735, 14867, 1141, 90, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16736, 14868, 1141, 91, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16737, 14869, 1141, 92, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16738, 14870, 1141, 93, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16739, 7291, 1141, 94, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16740, 14871, 1141, 95, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16741, 14872, 1141, 96, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16742, 14873, 1141, 97, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16743, 11426, 1141, 98, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16744, 14874, 1141, 99, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16745, 7319, 1141, 100, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16746, 14875, 1141, 101, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16747, 14876, 1141, 102, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16748, 13115, 1141, 103, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16749, 7295, 1141, 104, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16750, 7320, 1141, 105, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16751, 10574, 1141, 106, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16752, 14877, 1141, 107, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16753, 14878, 1141, 108, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16754, 8647, 1141, 109, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16755, 14879, 1141, 110, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16756, 14880, 1141, 111, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16757, 9145, 1141, 112, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16758, 11414, 1141, 113, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16759, 14881, 1141, 114, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16760, 14882, 1141, 115, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16761, 8736, 1141, 116, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16762, 14883, 1141, 117, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16763, 8671, 1141, 118, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16772, 7273, 1141, 127, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16773, 14888, 1141, 128, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16774, 7325, 1141, 129, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23351, 11411, 1141, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20861, 18072, 1391, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12509, 11432, 919, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12510, 11433, 919, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12511, 9121, 919, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12512, 11434, 919, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10082, 8779, 394, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10085, 8783, 394, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23353, 10397, 394, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23354, 10398, 394, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23355, 10399, 394, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23356, 10400, 394, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23357, 10401, 394, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16215, 14501, 1110, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16216, 14502, 1110, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22778, 19494, 1511, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22757, 14603, 1511, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22779, 19495, 1511, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22780, 19496, 1511, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22781, 19497, 1511, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22782, 12252, 1511, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22783, 19498, 1511, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22758, 12274, 1511, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22784, 19499, 1511, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22759, 12375, 1511, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22785, 19500, 1511, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22793, 19513, 1511, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22760, 12394, 1511, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22786, 19501, 1511, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12923, 2372, 759, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23358, 15482, 1564, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23359, 20151, 1564, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23360, 20152, 1564, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23361, 20153, 1564, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23362, 20154, 1564, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14459, 11798, 772, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14458, 12786, 772, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14460, 12787, 772, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17754, 15795, 1207, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17755, 15796, 1207, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17756, 15797, 1207, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (23363, 20155, 1564, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23364, 20156, 1564, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23365, 20157, 1564, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23366, 20158, 1564, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23367, 20159, 1564, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23368, 20160, 1564, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23369, 20161, 1564, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23370, 20162, 1564, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23371, 20163, 1564, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23372, 20164, 1564, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23373, 20165, 1564, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23374, 20166, 1564, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23375, 20167, 1564, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23376, 20168, 1564, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23377, 20169, 1564, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23378, 20170, 1564, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23379, 20171, 1564, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23380, 20172, 1564, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23381, 20173, 1564, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23382, 20174, 1564, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17757, 15798, 1207, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17758, 15799, 1207, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (23403, 15800, 1207, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23404, 15801, 1207, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23405, 15802, 1207, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23406, 15803, 1207, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23407, 15804, 1207, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23408, 15805, 1207, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23409, 15806, 1207, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23410, 15807, 1207, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23411, 15808, 1207, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23412, 15809, 1207, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23413, 15810, 1207, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23414, 15811, 1207, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23383, 20175, 1564, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23384, 20176, 1564, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23385, 20177, 1564, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23386, 20194, 1564, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23387, 20178, 1564, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23388, 20195, 1564, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23389, 20179, 1564, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23390, 20180, 1564, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23391, 20183, 1564, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23392, 20184, 1564, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23393, 20185, 1564, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23394, 20186, 1564, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23395, 20187, 1564, 49, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23396, 20188, 1564, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23397, 20189, 1564, 51, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23398, 20190, 1564, 52, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23399, 20191, 1564, 54, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23400, 20192, 1564, 55, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23401, 20193, 1564, 56, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23402, 19895, 1564, 58, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20848, 18060, 1391, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20849, 18061, 1391, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20850, 18062, 1391, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20851, 18063, 1391, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20842, 15702, 1391, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20852, 18064, 1391, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20853, 18065, 1391, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20854, 7671, 1391, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14457, 12785, 772, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20855, 18067, 1391, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20856, 18068, 1391, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20857, 15363, 1391, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20858, 15698, 1391, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20859, 18070, 1391, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20860, 18071, 1391, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14461, 12788, 772, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14456, 12720, 772, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14455, 12784, 772, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14454, 12783, 772, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14453, 12782, 772, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14462, 12781, 772, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15222, 13819, 1046, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15223, 13820, 1046, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13963, 12358, 956, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13846, 12187, 956, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13848, 12205, 956, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13849, 12207, 956, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13854, 12214, 956, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23416, 10580, 1573, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23417, 10666, 1573, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23418, 10665, 1573, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7614, 3816, 480, 4, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12310, 4646, 480, 7, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6565, 5576, 480, 22, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4113, 4738, 480, 35, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3753, 4317, 480, 54, 40);
INSERT INTO 'dancespublicationsmap' VALUES (13908, 12264, 956, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23419, 10664, 1573, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23420, 10667, 1573, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23421, 10668, 1573, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23422, 10672, 1573, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23423, 10669, 1573, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23424, 10675, 1573, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13910, 12267, 956, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13920, 12286, 956, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13930, 12330, 956, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13957, 12352, 956, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13958, 12353, 956, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13960, 12355, 956, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11739, 10678, 833, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11756, 10641, 833, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11740, 10679, 833, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11741, 10680, 833, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11742, 10233, 833, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11743, 10681, 833, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11744, 10682, 833, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11746, 10684, 833, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11747, 10685, 833, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11745, 10683, 833, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23425, 10670, 1573, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23426, 10194, 1573, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23427, 10460, 1573, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23428, 10671, 1573, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23429, 10673, 1573, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23430, 10674, 1573, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23431, 10195, 1573, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23432, 10677, 1573, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23433, 10676, 1573, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23434, 10678, 1573, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23435, 10679, 1573, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23436, 10641, 1573, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23437, 10680, 1573, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23438, 10233, 1573, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23439, 10681, 1573, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23440, 10682, 1573, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23441, 10684, 1573, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23442, 10683, 1573, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23443, 10685, 1573, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23444, 10686, 1573, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23445, 10687, 1573, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23446, 10688, 1573, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11755, 10693, 833, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11757, 10647, 833, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11758, 10649, 833, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11772, 10707, 833, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11778, 10713, 833, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11777, 10712, 833, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11779, 10714, 833, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11780, 10715, 833, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11721, 10580, 833, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11724, 10666, 833, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11723, 10665, 833, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11725, 10667, 833, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11722, 10664, 833, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11732, 10672, 833, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11726, 10668, 833, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11727, 10669, 833, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23448, 10689, 1574, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23449, 10690, 1574, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23450, 10691, 1574, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23451, 10692, 1574, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23452, 10693, 1574, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23453, 10641, 1574, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23454, 10647, 1574, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23455, 10649, 1574, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23456, 10694, 1574, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23457, 10695, 1574, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23458, 10696, 1574, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23459, 10697, 1574, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23460, 10698, 1574, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23461, 10699, 1574, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23462, 10700, 1574, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23463, 10701, 1574, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23464, 10702, 1574, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23465, 10703, 1574, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23466, 10704, 1574, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23467, 10705, 1574, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23468, 10706, 1574, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23469, 10707, 1574, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23470, 10708, 1574, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23471, 10709, 1574, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23472, 10710, 1574, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23473, 10711, 1574, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23474, 10712, 1574, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23475, 10713, 1574, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23476, 10714, 1574, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23477, 10715, 1574, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11735, 10675, 833, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11728, 10670, 833, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11729, 10194, 833, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11730, 10460, 833, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11731, 10671, 833, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11734, 10674, 833, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11733, 10673, 833, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11736, 10195, 833, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11738, 10677, 833, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11737, 10676, 833, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11771, 10706, 833, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11748, 10686, 833, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11749, 10687, 833, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11750, 10688, 833, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10301, 8910, 796, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10302, 8911, 796, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10303, 8912, 796, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10304, 8913, 796, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10305, 8914, 796, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10306, 8915, 796, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10307, 8916, 796, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10308, 8917, 796, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10309, 8918, 796, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10310, 8919, 796, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13903, 68, 73, 152, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23508, 15460, 73, 280, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23510, 19247, 73, 308, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23509, 20219, 73, 313, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23513, 1747, 480, 2, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23514, 3621, 480, 5, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23515, 4928, 480, 9, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23516, 4641, 480, 11, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23512, 4041, 480, 12, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23517, 5497, 480, 13, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23511, 3568, 480, 14, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23518, 2498, 480, 15, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23519, 1100, 480, 17, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23520, 5964, 480, 19, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23521, 6188, 480, 24, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23522, 2675, 480, 25, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23523, 5552, 480, 27, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23524, 3323, 480, 28, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23525, 4436, 480, 29, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23526, 153, 480, 31, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23527, 823, 480, 33, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23528, 164, 480, 34, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2955, 3398, 516, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2969, 3413, 516, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6005, 6963, 516, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2450, 2825, 516, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1862, 2148, 516, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3700, 4252, 516, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4247, 4906, 516, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4764, 5513, 516, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4555, 5262, 516, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4685, 5413, 516, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4748, 5495, 516, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4875, 5640, 516, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5947, 6890, 516, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23529, 6783, 480, 40, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23530, 6535, 480, 42, 40);
INSERT INTO 'dancespublicationsmap' VALUES (23598, 4043, 1580, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23599, 3651, 1580, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23600, 3680, 1580, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23531, 17321, 1575, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23532, 19122, 1575, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23533, 20241, 1575, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23534, 20242, 1575, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23535, 20243, 1575, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23536, 18697, 1575, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23537, 20244, 1575, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23538, 16473, 1575, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23539, 20245, 1575, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23540, 20246, 1575, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23541, 20247, 1575, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23542, 15438, 1575, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23543, 20248, 1575, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23544, 20249, 1575, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23545, 19119, 1575, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23546, 17577, 1575, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6004, 6962, 656, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1950, 2254, 656, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (884, 1023, 656, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1490, 1727, 656, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3670, 4220, 656, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1760, 2039, 656, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23608, 4044, 1583, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23609, 5699, 1583, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23601, 742, 1581, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23602, 5799, 1581, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23547, 20260, 1576, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23548, 20261, 1576, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23549, 19663, 1576, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23550, 16055, 1576, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23551, 17364, 1576, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23552, 20262, 1576, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23553, 13588, 1576, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23554, 17343, 1576, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23555, 20263, 1576, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23556, 18352, 1576, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23557, 20264, 1576, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23558, 20265, 1576, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23559, 20266, 1576, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23560, 20267, 1576, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23561, 18353, 1576, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23562, 20268, 1576, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23563, 20269, 1576, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23564, 20270, 1576, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23565, 20271, 1576, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23566, 20272, 1576, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23604, 4680, 1581, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23603, 5807, 1581, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4967, 5749, 61, 12, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4929, 5707, 61, 13, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5013, 5799, 61, 14, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23613, 3777, 1585, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23567, 1210, 1577, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23568, 1348, 1577, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23569, 1562, 1577, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23570, 1792, 1577, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23571, 1799, 1577, 5, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23572, 1931, 1577, 6, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23573, 2250, 1577, 7, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23574, 2317, 1577, 8, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23575, 2498, 1577, 9, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23576, 2682, 1577, 10, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23614, 4474, 1585, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (9627, 8259, 352, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9628, 8260, 352, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9629, 8261, 352, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9630, 8262, 352, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23577, 2812, 1577, 11, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23578, 3236, 1577, 12, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23579, 3637, 1577, 13, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23582, 4195, 1577, 14, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23580, 4324, 1577, 15, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23581, 5239, 1577, 16, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23583, 723, 1577, 17, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23584, 5963, 1577, 18, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23585, 5964, 1577, 19, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23586, 6233, 1577, 20, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23587, 6505, 1577, 21, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23588, 6748, 1577, 22, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23589, 6915, 1577, 23, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23590, 7109, 1577, 24, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16441, 4044, 1126, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16443, 4283, 1126, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16444, 4474, 1126, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16452, 6037, 1126, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16451, 5807, 1126, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16436, 3777, 1126, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16437, 3883, 1126, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16440, 4043, 1126, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16445, 4680, 1126, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16442, 4282, 1126, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16446, 5128, 1126, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16447, 5699, 1126, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16449, 5749, 1126, 25, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16448, 5707, 1126, 26, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16450, 5799, 1126, 27, 10);
INSERT INTO 'dancespublicationsmap' VALUES (9631, 8263, 352, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9632, 8264, 352, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9633, 8265, 352, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (9634, 8266, 352, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23610, 3883, 1583, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (22859, 3327, 474, 57, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3135, 3606, 474, 58, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3409, 3927, 474, 59, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3161, 3633, 474, 60, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3200, 3683, 474, 61, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3262, 3757, 474, 62, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3311, 3815, 474, 63, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3429, 3950, 474, 64, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3978, 4577, 474, 69, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3940, 4535, 474, 70, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23615, 20296, 1586, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23616, 20297, 1586, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23617, 20298, 1586, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23618, 19641, 1586, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23619, 20299, 1586, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23620, 20300, 1586, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23594, 633, 1578, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23593, 5128, 1578, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23592, 805, 1578, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23605, 441, 1582, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23606, 5749, 1582, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23607, 3428, 1582, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23591, 4271, 1578, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23621, 20301, 1586, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23622, 20302, 1586, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23623, 20303, 1586, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23624, 20304, 1586, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3841, 4418, 456, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3851, 4430, 456, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3867, 4448, 456, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4104, 4729, 456, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5170, 5979, 457, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5207, 6024, 457, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5221, 6039, 457, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7756, 5823, 457, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5247, 6067, 457, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5437, 6290, 457, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5462, 6322, 457, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5493, 6357, 457, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5549, 6416, 457, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5557, 6426, 457, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23625, 20305, 1586, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17658, 15672, 1200, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (3722, 4280, 714, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5908, 6845, 714, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23675, 11680, 1594, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23676, 11681, 1594, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4156, 4792, 755, 7, 35);
INSERT INTO 'dancespublicationsmap' VALUES (11167, 9960, 382, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11168, 9961, 382, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23646, 16959, 73, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23659, 20220, 73, 313, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11169, 9962, 382, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11170, 9963, 382, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11171, 9964, 382, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10347, 4358, 314, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10348, 5432, 314, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23595, 1789, 1579, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23596, 1881, 1579, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23597, 3225, 1579, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4990, 5773, 141, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4892, 5661, 141, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5370, 6207, 141, 23, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3890, 4474, 60, 11, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23611, 4283, 1584, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23612, 6616, 1584, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23679, 20352, 1122, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23648, 20327, 1589, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23649, 20325, 1589, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23650, 20329, 1589, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23651, 19194, 1589, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23652, 19192, 1589, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23653, 20326, 1589, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23654, 20333, 1589, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23655, 20332, 1589, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23656, 20331, 1589, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23657, 20330, 1589, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23658, 20323, 1589, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23680, 11808, 1122, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23647, 6091, 1585, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (12226, 11195, 893, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12227, 11196, 893, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12228, 11197, 893, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12229, 11198, 893, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12230, 8529, 893, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12231, 11199, 893, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12232, 11200, 893, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12233, 11201, 893, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12234, 11202, 893, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12235, 11203, 893, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6300, 655, 39, 5, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6331, 1034, 39, 13, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6333, 1100, 39, 14, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6366, 1909, 39, 19, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6372, 2024, 39, 20, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6405, 2781, 39, 26, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6415, 3045, 39, 29, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6424, 3154, 39, 30, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6431, 3281, 39, 31, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6434, 3339, 39, 33, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6438, 3424, 39, 34, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6439, 3444, 39, 35, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6442, 3529, 39, 36, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6447, 3575, 39, 37, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6449, 3585, 39, 38, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6450, 3588, 39, 39, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6460, 3638, 39, 45, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6465, 3723, 39, 46, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6469, 3735, 39, 47, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6470, 3759, 39, 48, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6472, 3774, 39, 49, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6473, 3775, 39, 50, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6477, 3862, 39, 51, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6479, 3888, 39, 52, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6482, 3931, 39, 53, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6500, 4270, 39, 54, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6492, 4068, 39, 55, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6496, 4196, 39, 56, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6499, 4239, 39, 57, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6503, 4336, 39, 58, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6508, 4440, 39, 59, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6506, 4434, 39, 60, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6509, 4447, 39, 62, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6510, 4450, 39, 63, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6511, 4451, 39, 64, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6524, 4679, 39, 69, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6534, 4865, 39, 70, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6535, 4919, 39, 71, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6538, 4932, 39, 72, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6539, 4968, 39, 73, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6541, 5028, 39, 74, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6545, 5223, 39, 75, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6550, 5351, 39, 76, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6552, 5362, 39, 77, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6556, 5441, 39, 78, 18);
INSERT INTO 'dancespublicationsmap' VALUES (23677, 9166, 1122, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23681, 20353, 1122, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23682, 20354, 1122, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10349, 6205, 314, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10350, 7026, 314, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10351, 4209, 314, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5269, 6095, 230, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4314, 4988, 714, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4191, 4835, 714, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23683, 20355, 1122, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23684, 20356, 1122, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23678, 18978, 1122, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23685, 20357, 1122, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23686, 20358, 1122, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2123, 2444, 181, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3274, 3773, 182, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3623, 4167, 182, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13016, 12109, 950, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13017, 12110, 950, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13018, 12111, 950, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13019, 12112, 950, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13020, 12113, 950, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13021, 12114, 950, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13022, 12115, 950, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13023, 12116, 950, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13024, 12117, 950, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13025, 12118, 950, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (13026, 12119, 950, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5733, 6638, 230, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2101, 2421, 228, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2222, 2557, 228, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (509, 591, 278, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2055, 2369, 278, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4539, 5244, 278, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5356, 6193, 278, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7456, 350, 278, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7607, 3728, 278, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11172, 9965, 382, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11154, 3259, 382, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6712, 7355, 789, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11190, 9995, 309, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11191, 9996, 309, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7602, 7788, 458, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (882, 1021, 458, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1146, 1327, 458, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11198, 10002, 309, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23660, 19973, 1590, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23661, 17285, 1590, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23662, 20344, 1590, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23663, 20283, 1590, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23664, 19974, 1590, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23628, 20310, 1588, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23629, 17621, 1588, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23630, 20311, 1588, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23631, 20312, 1588, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23632, 17618, 1588, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23633, 20313, 1588, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23634, 20314, 1588, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23635, 20315, 1588, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23636, 20316, 1588, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23637, 20317, 1588, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23638, 20318, 1588, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23639, 19792, 1588, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23640, 20319, 1588, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23641, 20320, 1588, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3131, 3602, 455, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5573, 6447, 457, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5560, 6429, 457, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5625, 6508, 457, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5637, 6521, 457, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5649, 6540, 457, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5683, 6579, 457, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5695, 6595, 457, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5738, 6645, 457, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6311, 819, 41, 8, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6326, 980, 41, 10, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6330, 1024, 41, 12, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6335, 1210, 41, 13, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8660, 8086, 41, 14, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6339, 1296, 41, 15, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6343, 1415, 41, 16, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6345, 1478, 41, 17, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6346, 1501, 41, 18, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6347, 1562, 41, 19, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6348, 1582, 41, 20, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6353, 1733, 41, 21, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6359, 1792, 41, 22, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6358, 1786, 41, 23, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6360, 1793, 41, 24, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6361, 1799, 41, 25, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6367, 1927, 41, 27, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6368, 1931, 41, 28, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6365, 1883, 41, 29, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6371, 2004, 41, 30, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6374, 2044, 41, 31, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6377, 2156, 41, 32, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6384, 2317, 41, 33, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6380, 2250, 41, 34, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6391, 2495, 41, 35, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6387, 2415, 41, 36, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6392, 2498, 41, 37, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6393, 2504, 41, 38, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6395, 2593, 41, 39, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6398, 2631, 41, 40, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6400, 2645, 41, 41, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6403, 2745, 41, 42, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2344, 2701, 451, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23626, 2353, 1584, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23627, 4282, 1584, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6402, 2713, 41, 43, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6410, 2925, 41, 44, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6408, 2903, 41, 45, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8661, 2934, 41, 46, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6412, 2970, 41, 47, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6416, 3046, 41, 48, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6421, 3111, 41, 49, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6423, 3152, 41, 50, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6427, 3236, 41, 51, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6429, 3246, 41, 52, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6426, 3235, 41, 53, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6435, 3342, 41, 54, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6444, 3541, 41, 55, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8662, 3561, 41, 56, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6448, 3580, 41, 57, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6461, 3672, 41, 58, 18);
INSERT INTO 'dancespublicationsmap' VALUES (7386, 3722, 41, 60, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6475, 3834, 41, 61, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6480, 3915, 41, 62, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6484, 3953, 41, 63, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6486, 3972, 41, 64, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6490, 4032, 41, 65, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6491, 4064, 41, 66, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6495, 4195, 41, 67, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6501, 4325, 41, 68, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6502, 4334, 41, 69, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6504, 4359, 41, 70, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6516, 4562, 41, 71, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6514, 4548, 41, 72, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6520, 4641, 41, 73, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6522, 4646, 41, 74, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6528, 4755, 41, 75, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6529, 4782, 41, 76, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6540, 5007, 41, 78, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6536, 4928, 41, 79, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6546, 5239, 41, 80, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6551, 5358, 41, 81, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6553, 5402, 41, 82, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6555, 5421, 41, 83, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6557, 5462, 41, 84, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6564, 5532, 41, 85, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6563, 5525, 41, 86, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6566, 5591, 41, 87, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6568, 5641, 41, 88, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6570, 5658, 41, 89, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6571, 5688, 41, 90, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6572, 5731, 41, 91, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6575, 5766, 41, 92, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6582, 5964, 41, 93, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6594, 6152, 41, 94, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6600, 6349, 41, 95, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6636, 7109, 41, 98, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6625, 6915, 41, 99, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6643, 7245, 41, 101, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2517, 2903, 50, 21, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2692, 3104, 50, 23, 18);
INSERT INTO 'dancespublicationsmap' VALUES (2698, 3111, 50, 24, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3122, 3593, 50, 25, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3130, 3601, 50, 26, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3767, 4334, 50, 32, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4915, 5688, 50, 38, 18);
INSERT INTO 'dancespublicationsmap' VALUES (880, 1019, 51, 6, 18);
INSERT INTO 'dancespublicationsmap' VALUES (3715, 4270, 51, 24, 18);
INSERT INTO 'dancespublicationsmap' VALUES (4028, 4638, 51, 29, 18);
INSERT INTO 'dancespublicationsmap' VALUES (6186, 7173, 51, 38, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8574, 5713, 342, 10, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8575, 5921, 342, 11, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8576, 1786, 342, 12, 18);
INSERT INTO 'dancespublicationsmap' VALUES (8594, 6373, 342, 30, 18);
INSERT INTO 'dancespublicationsmap' VALUES (16355, 778, 1125, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16356, 779, 1125, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16360, 1024, 1125, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16361, 1034, 1125, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16362, 1158, 1125, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16363, 8086, 1125, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16364, 1367, 1125, 18, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16366, 1733, 1125, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16367, 1793, 1125, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16368, 1909, 1125, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16377, 2903, 1125, 31, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16378, 2934, 1125, 32, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16379, 2970, 1125, 33, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16381, 3104, 1125, 35, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16382, 3111, 1125, 36, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16386, 3575, 1125, 40, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16387, 3585, 1125, 41, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16388, 3593, 1125, 42, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16389, 3595, 1125, 43, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16390, 3601, 1125, 44, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16391, 3607, 1125, 45, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16392, 3609, 1125, 46, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16393, 3616, 1125, 47, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16394, 3638, 1125, 48, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16395, 3711, 1125, 49, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16396, 3723, 1125, 50, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16397, 3915, 1125, 51, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16398, 3931, 1125, 52, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16399, 4196, 1125, 53, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16400, 4270, 1125, 54, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16403, 4447, 1125, 57, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16412, 5358, 1125, 66, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16413, 5402, 1125, 67, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16414, 5421, 1125, 68, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16415, 5688, 1125, 69, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16416, 5754, 1125, 70, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16417, 5766, 1125, 71, 10);
INSERT INTO 'dancespublicationsmap' VALUES (1092, 1269, 609, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11199, 10003, 309, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11200, 10004, 309, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5931, 6871, 674, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23751, 13778, 1597, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23752, 13776, 1597, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23753, 13777, 1597, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23754, 19116, 1597, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23755, 13775, 1597, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23756, 7948, 1597, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23777, 12771, 1357, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23774, 20411, 1356, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23775, 20412, 1356, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23776, 20413, 1356, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23665, 20182, 1590, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23666, 20351, 1590, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23667, 20345, 1590, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23668, 20346, 1590, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23669, 20224, 1590, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23729, 14308, 1595, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23691, 1789, 59, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23692, 1881, 59, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23693, 2846, 59, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23694, 3225, 59, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23695, 3428, 59, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23696, 3651, 59, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23697, 3680, 59, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23698, 3777, 59, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23699, 3883, 59, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23700, 4014, 59, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23701, 4282, 59, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23702, 4271, 59, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23687, 441, 59, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23688, 633, 59, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23689, 742, 59, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23690, 805, 59, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23769, 4470, 1356, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23770, 20407, 1356, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23771, 20408, 1356, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23772, 20409, 1356, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23773, 20410, 1356, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23670, 20281, 1590, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23671, 20342, 1590, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23672, 20347, 1590, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23673, 20282, 1590, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23674, 20223, 1590, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23778, 20206, 1590, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13961, 12356, 956, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13836, 12131, 956, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13909, 12265, 956, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13922, 12293, 956, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23779, 20414, 1357, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23780, 20417, 1357, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23782, 20418, 1357, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23781, 20419, 1357, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23784, 20420, 1357, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23783, 4814, 1357, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23785, 6213, 1357, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13959, 12354, 956, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13962, 12357, 956, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19453, 3781, 1310, 7, 31);
INSERT INTO 'dancespublicationsmap' VALUES (19454, 5083, 1310, 9, 31);
INSERT INTO 'dancespublicationsmap' VALUES (3599, 4139, 497, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3598, 4138, 497, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3688, 4238, 497, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3756, 4320, 497, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4369, 5046, 497, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4907, 5680, 497, 18, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5101, 5899, 497, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6599, 6310, 497, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5537, 6404, 497, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16011, 13313, 1096, 28, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16012, 14342, 1096, 29, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16013, 13352, 1096, 30, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16014, 13354, 1096, 31, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16015, 13306, 1096, 32, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16016, 13643, 1096, 33, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16017, 14343, 1096, 34, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16018, 14344, 1096, 35, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16019, 14345, 1096, 36, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16020, 14346, 1096, 37, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16021, 13745, 1096, 38, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16022, 14347, 1096, 39, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16023, 14348, 1096, 40, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16024, 14349, 1096, 41, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16025, 14350, 1096, 42, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16033, 14355, 1096, 43, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16026, 13806, 1096, 44, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16028, 13815, 1096, 45, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16027, 13823, 1096, 46, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16029, 14351, 1096, 47, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16030, 14352, 1096, 48, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16031, 14353, 1096, 49, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16032, 14354, 1096, 50, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16034, 13587, 1096, 51, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16035, 14356, 1096, 52, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16036, 14357, 1096, 53, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16037, 14358, 1096, 54, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16038, 13578, 1096, 55, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16039, 14359, 1096, 56, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16040, 13810, 1096, 57, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16041, 13818, 1096, 58, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16051, 13811, 1096, 59, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16042, 13814, 1096, 60, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16043, 13822, 1096, 61, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16044, 14360, 1096, 62, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16045, 14361, 1096, 63, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16046, 14362, 1096, 64, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16047, 14363, 1096, 65, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16048, 14364, 1096, 66, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16049, 14366, 1096, 67, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16050, 14365, 1096, 68, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16052, 14367, 1096, 69, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16053, 14368, 1096, 70, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16054, 13679, 1096, 71, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16055, 13804, 1096, 72, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16066, 14379, 1096, 73, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16067, 14381, 1096, 74, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16068, 14382, 1096, 75, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16069, 14383, 1096, 76, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16070, 14384, 1096, 77, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16071, 14385, 1096, 78, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16900, 14989, 1096, 79, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16901, 14988, 1096, 80, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16902, 14428, 1096, 81, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16903, 14991, 1096, 82, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16904, 14993, 1096, 83, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16905, 14661, 1096, 84, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16899, 14987, 1096, 85, 50);
INSERT INTO 'dancespublicationsmap' VALUES (16898, 14986, 1096, 86, 50);
INSERT INTO 'dancespublicationsmap' VALUES (17145, 15055, 1096, 87, 50);
INSERT INTO 'dancespublicationsmap' VALUES (17197, 15229, 1096, 88, 50);
INSERT INTO 'dancespublicationsmap' VALUES (17198, 15230, 1096, 89, 50);
INSERT INTO 'dancespublicationsmap' VALUES (17199, 15231, 1096, 90, 50);
INSERT INTO 'dancespublicationsmap' VALUES (17665, 15412, 1096, 91, 50);
INSERT INTO 'dancespublicationsmap' VALUES (20833, 15430, 1096, 92, 50);
INSERT INTO 'dancespublicationsmap' VALUES (20834, 15444, 1096, 93, 50);
INSERT INTO 'dancespublicationsmap' VALUES (20835, 15685, 1096, 94, 50);
INSERT INTO 'dancespublicationsmap' VALUES (20836, 15686, 1096, 95, 50);
INSERT INTO 'dancespublicationsmap' VALUES (20837, 15684, 1096, 96, 50);
INSERT INTO 'dancespublicationsmap' VALUES (20838, 18042, 1096, 97, 50);
INSERT INTO 'dancespublicationsmap' VALUES (20839, 18043, 1096, 98, 50);
INSERT INTO 'dancespublicationsmap' VALUES (20840, 16571, 1096, 99, 50);
INSERT INTO 'dancespublicationsmap' VALUES (23799, 20428, 1599, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23800, 19120, 1599, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23801, 20458, 1599, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23802, 20430, 1599, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23803, 20431, 1599, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23804, 20225, 1599, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23805, 20286, 1599, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23806, 20433, 1599, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23807, 20434, 1599, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23808, 20459, 1599, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23809, 20444, 1599, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23812, 20447, 1599, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23848, 20503, 1601, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23849, 20504, 1601, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23850, 20505, 1601, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23851, 20506, 1601, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23852, 20507, 1601, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23853, 20508, 1601, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23854, 20509, 1601, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23855, 20510, 1601, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23856, 20511, 1601, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23857, 20512, 1601, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23813, 20448, 1599, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23786, 20432, 1598, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23789, 20437, 1598, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23788, 20436, 1598, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23787, 20435, 1598, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23790, 20438, 1598, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23791, 20439, 1598, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23792, 20440, 1598, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23793, 20441, 1598, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23794, 20442, 1598, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23795, 20443, 1598, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23796, 20445, 1598, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23797, 20446, 1598, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23798, 12140, 1599, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23814, 20460, 1340, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23815, 19168, 1340, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23816, 20461, 1340, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23817, 20462, 1340, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23818, 20463, 1340, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23819, 20464, 1340, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23820, 20465, 1340, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23821, 20466, 1340, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23822, 20467, 1340, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23823, 20468, 1340, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23824, 20469, 1340, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23825, 20470, 1340, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23842, 20488, 1600, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23843, 20489, 1600, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23844, 20490, 1600, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23845, 20491, 1600, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23846, 20450, 1600, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12000, 3277, 853, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (12001, 10965, 853, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5443, 6298, 524, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (209, 244, 524, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23757, 16876, 1530, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23736, 19820, 1596, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23737, 20376, 1596, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23738, 20377, 1596, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23758, 20396, 1530, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23759, 20397, 1530, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23764, 20402, 1530, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23810, 20454, 1290, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23811, 20455, 1290, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23838, 20484, 1600, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23839, 20485, 1600, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23840, 20486, 1600, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23841, 20487, 1600, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1186, 1373, 524, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2365, 2726, 524, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23858, 20514, 1602, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23859, 20515, 1602, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23860, 20516, 1602, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23861, 20517, 1602, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23862, 20518, 1602, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23863, 20519, 1602, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23905, 848, 1608, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23864, 20520, 1602, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23865, 20521, 1602, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23866, 18349, 1602, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23867, 20522, 1602, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (516, 599, 612, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17977, 15994, 1224, 20, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17978, 15995, 1224, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17979, 15996, 1224, 22, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17980, 15997, 1224, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17981, 15998, 1224, 24, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17982, 15999, 1224, 25, 10);
INSERT INTO 'dancespublicationsmap' VALUES (23868, 20523, 1603, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23869, 20524, 1603, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23870, 20525, 1603, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23871, 20526, 1603, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23872, 20527, 1603, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23873, 20528, 1603, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23874, 20529, 1603, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23875, 20530, 1603, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23876, 20531, 1603, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23877, 20532, 1603, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23878, 20533, 1603, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23879, 20534, 1603, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23880, 20535, 1603, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23881, 20536, 1603, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23906, 980, 1608, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23907, 899, 1608, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23908, 1280, 1608, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23909, 5591, 1608, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23910, 1501, 1608, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23911, 1582, 1608, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23912, 1786, 1608, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23883, 20544, 1604, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23884, 20067, 1604, 6, 31);
INSERT INTO 'dancespublicationsmap' VALUES (23882, 20537, 1604, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23885, 20545, 1604, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23886, 20546, 1604, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23887, 20547, 1604, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23888, 20548, 1604, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23889, 20549, 1604, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23890, 20550, 1604, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23891, 20551, 1604, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23892, 20552, 1604, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19809, 17307, 1332, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19810, 17308, 1332, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19811, 17309, 1332, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19812, 17310, 1332, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19815, 17311, 1332, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19814, 17312, 1332, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19813, 17313, 1332, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19816, 17314, 1332, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19817, 17315, 1332, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19818, 17316, 1332, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23642, 20321, 1588, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23643, 17706, 1588, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23644, 18383, 1588, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23645, 20322, 1588, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23913, 2153, 1608, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23914, 2349, 1608, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23915, 2415, 1608, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23916, 3339, 1608, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23917, 4491, 1608, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23918, 2745, 1608, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23919, 2807, 1608, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23920, 6477, 1608, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23921, 2979, 1608, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23922, 3246, 1608, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23893, 20566, 1607, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23894, 20567, 1607, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23895, 20568, 1607, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23896, 20569, 1607, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23897, 20570, 1607, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23898, 20571, 1607, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23899, 20572, 1607, 52, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23900, 20573, 1607, 56, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23923, 3281, 1608, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23924, 3580, 1608, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23925, 3672, 1608, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23926, 3580, 1608, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23927, 3932, 1608, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23928, 3953, 1608, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23929, 4032, 1608, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23930, 4239, 1608, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23931, 4641, 1608, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23932, 4646, 1608, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23933, 1020, 1608, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23934, 4782, 1608, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23935, 794, 1608, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23936, 4562, 1608, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23937, 4928, 1608, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23938, 5462, 1608, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23939, 5921, 1608, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23940, 3152, 1608, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23941, 6349, 1608, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23942, 6373, 1608, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23943, 2428, 1608, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23901, 301, 1608, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23902, 480, 1608, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23944, 6848, 1608, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23945, 6957, 1608, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23946, 7055, 1608, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23903, 522, 1608, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23904, 743, 1608, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23947, 7147, 1608, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23948, 4064, 1608, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23949, 5982, 1608, 49, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23950, 5525, 1608, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23826, 20471, 1451, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22541, 20063, 1451, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22787, 19286, 1451, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23827, 20472, 1451, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23828, 20473, 1451, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21821, 19503, 1451, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22247, 18342, 1451, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22248, 18851, 1451, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23829, 20474, 1451, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21822, 20064, 1451, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22792, 18852, 1451, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21823, 18343, 1451, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22249, 19510, 1451, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23830, 20475, 1451, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23831, 20476, 1451, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22961, 18344, 1451, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23832, 20477, 1451, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22791, 20065, 1451, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21824, 18853, 1451, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22250, 19689, 1451, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22790, 19509, 1451, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22789, 18208, 1451, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22251, 20066, 1451, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22788, 18854, 1451, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23279, 19506, 1451, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23280, 20067, 1451, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23833, 20478, 1451, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23834, 20479, 1451, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23835, 20480, 1451, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23281, 19505, 1451, 49, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23282, 18855, 1451, 52, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23283, 19504, 1451, 53, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23836, 20481, 1451, 55, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23760, 20398, 1530, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7575, 7752, 316, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7533, 7721, 316, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7547, 7740, 316, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7769, 7964, 316, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23955, 20580, 1610, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23956, 20581, 1610, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23957, 20582, 1610, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23952, 20553, 1609, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23953, 20576, 1609, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23954, 20577, 1609, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23951, 20482, 1609, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23761, 20399, 1530, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23958, 20583, 1610, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23959, 20584, 1610, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2021, 2331, 555, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2187, 2519, 555, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5932, 6872, 555, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2296, 2648, 555, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2705, 3118, 555, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23762, 20400, 1530, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23763, 16873, 1530, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23765, 20403, 1530, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23992, 20619, 1613, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23993, 20620, 1613, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23994, 11303, 1613, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23995, 11938, 1613, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23996, 20621, 1613, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23997, 20622, 1613, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23998, 11302, 1613, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23999, 14368, 1613, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24000, 13804, 1613, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24001, 14661, 1613, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24002, 11304, 1613, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23960, 20585, 1610, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23961, 20586, 1610, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23962, 20587, 1610, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23963, 20588, 1610, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23964, 20589, 1610, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23965, 20590, 1610, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23966, 20591, 1610, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23967, 20592, 1610, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4245, 4904, 63, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3708, 4262, 63, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5498, 6363, 63, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1467, 1701, 63, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3741, 4301, 63, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2858, 3287, 63, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3078, 3543, 63, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5627, 6510, 63, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1783, 2063, 63, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23968, 20593, 1611, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23969, 20594, 1611, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23970, 20595, 1611, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23971, 20596, 1611, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23972, 20597, 1611, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23973, 20598, 1611, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23974, 20599, 1611, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23975, 20600, 1611, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23976, 20601, 1611, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23977, 20602, 1611, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23978, 20603, 1611, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23979, 20604, 1611, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20590, 17950, 1385, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20589, 17951, 1385, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20588, 17952, 1385, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20587, 17953, 1385, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20586, 17882, 1385, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20585, 17955, 1385, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20584, 17582, 1385, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20580, 17957, 1385, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20582, 17958, 1385, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20578, 17959, 1385, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20577, 17960, 1385, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20576, 17961, 1385, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20575, 17962, 1385, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20574, 17963, 1385, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20573, 17964, 1385, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20572, 17965, 1385, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20571, 17966, 1385, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20570, 17967, 1385, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20569, 17968, 1385, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20568, 17969, 1385, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20567, 17970, 1385, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20566, 17971, 1385, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20565, 17972, 1385, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20564, 17973, 1385, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20563, 17974, 1385, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20562, 17975, 1385, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20561, 17976, 1385, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20560, 17977, 1385, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23980, 20606, 1385, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23981, 20607, 1385, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2459, 2836, 63, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5570, 6444, 63, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (906, 1051, 63, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (299, 347, 610, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (543, 634, 610, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (23982, 20608, 1612, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23983, 20609, 1612, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23984, 20610, 1612, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23985, 20611, 1612, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23986, 20612, 1612, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23987, 20613, 1612, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23988, 20614, 1612, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23989, 20615, 1612, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23990, 20616, 1612, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23991, 20617, 1612, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1556, 1808, 610, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2179, 2511, 610, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4151, 4786, 610, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2175, 2507, 611, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3296, 3799, 611, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3477, 4002, 611, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4666, 5394, 611, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5236, 6056, 611, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5795, 6713, 262, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4710, 5451, 137, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5392, 6237, 239, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5569, 6443, 239, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3222, 3708, 239, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (237, 278, 239, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2209, 2543, 239, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1507, 1745, 239, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2896, 3336, 239, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1415, 1640, 239, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2533, 2920, 239, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16894, 14985, 1147, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16875, 14982, 1147, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16880, 14984, 1147, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16876, 11681, 1147, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16877, 14518, 1147, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17360, 15425, 1147, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16874, 14980, 1147, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16873, 14981, 1147, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16878, 9353, 1147, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16895, 14983, 1147, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16879, 14419, 1147, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (16896, 11107, 1147, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17607, 15594, 1194, 0, 10);
INSERT INTO 'dancespublicationsmap' VALUES (17608, 15597, 1194, 0, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18952, 13752, 1194, 0, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18953, 16861, 1194, 0, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18954, 16860, 1194, 0, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18955, 16866, 1194, 0, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18956, 16865, 1194, 0, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18957, 16867, 1194, 0, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18958, 16862, 1194, 0, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18959, 8648, 1194, 0, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18960, 8649, 1194, 0, 10);
INSERT INTO 'dancespublicationsmap' VALUES (2850, 3278, 664, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1104, 1282, 664, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3282, 3782, 664, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2390, 2755, 664, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10016, 3233, 664, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3312, 3818, 664, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (593, 690, 664, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (934, 1081, 664, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1954, 2259, 664, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (714, 834, 664, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4442, 5131, 664, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4159, 4795, 664, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5632, 6516, 664, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5306, 6133, 664, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1808, 2089, 664, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2342, 2699, 664, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4172, 4810, 664, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4054, 4673, 664, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1069, 1239, 664, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4838, 5599, 664, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2877, 3312, 664, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7446, 7562, 294, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7459, 7606, 294, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7472, 7628, 294, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7476, 7636, 294, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7499, 7680, 294, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7615, 7804, 294, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7622, 7810, 294, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7642, 7824, 294, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7717, 7894, 294, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7741, 7929, 294, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7745, 7937, 294, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7752, 5742, 294, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7813, 8010, 294, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7816, 6581, 294, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7824, 8020, 294, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7825, 8021, 294, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2616, 3014, 239, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2729, 3144, 239, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4682, 5410, 239, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2216, 2551, 239, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5425, 6277, 239, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (37, 45, 239, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12924, 11974, 641, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6050, 7014, 86, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3093, 3560, 86, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4714, 5455, 86, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5019, 5805, 86, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23731, 20371, 1596, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23732, 20372, 1596, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23733, 20373, 1596, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23734, 20374, 1596, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23735, 20375, 1596, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23739, 20378, 1596, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23740, 20379, 1596, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23741, 20380, 1596, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23742, 20381, 1596, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23743, 20382, 1596, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23744, 20383, 1596, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23745, 20384, 1596, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23746, 20385, 1596, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23747, 20386, 1596, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23748, 20387, 1596, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23749, 20388, 1596, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23750, 20389, 1596, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5900, 6836, 690, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3682, 4232, 690, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3856, 4436, 522, 6, 31);
INSERT INTO 'dancespublicationsmap' VALUES (1009, 1164, 120, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1144, 1325, 120, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2465, 2843, 120, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9604, 8234, 350, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13889, 8235, 350, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9605, 8236, 350, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9606, 8237, 350, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10673, 7139, 554, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10674, 5993, 554, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10675, 1862, 554, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10676, 3626, 554, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10677, 6424, 554, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10678, 4436, 554, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10679, 784, 554, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10680, 2696, 554, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10681, 1424, 554, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10682, 5349, 554, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10683, 5675, 554, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10685, 4779, 554, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10686, 4837, 554, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10687, 6536, 554, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24003, 20626, 693, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24004, 20627, 693, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (12673, 15027, 693, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (24005, 20628, 693, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24006, 20629, 693, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24007, 20630, 693, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4624, 5341, 545, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1749, 2022, 555, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (964, 1116, 555, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5482, 6343, 555, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (984, 1139, 555, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (601, 703, 555, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (872, 1011, 555, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5797, 6718, 555, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (1434, 1662, 234, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3945, 4542, 234, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2985, 3430, 234, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4321, 4997, 234, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3242, 3734, 444, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4966, 5748, 444, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (13888, 7883, 350, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9607, 8239, 350, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9608, 8240, 350, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4779, 5531, 573, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7589, 3330, 324, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7625, 4253, 324, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7677, 4866, 324, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7684, 4964, 324, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7703, 5342, 324, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7712, 1386, 324, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7713, 362, 324, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7714, 425, 324, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7715, 1379, 324, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (7812, 6929, 324, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (24008, 896, 264, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (523, 607, 264, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2257, 2602, 264, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5203, 6018, 264, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5424, 6276, 264, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (616, 720, 264, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (926, 1072, 264, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3207, 3691, 264, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2003, 2312, 264, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10054, 8756, 124, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10055, 8757, 124, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10059, 8761, 124, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10060, 8762, 124, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10061, 8763, 124, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10062, 8764, 124, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10063, 8765, 124, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10064, 8766, 124, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10065, 8767, 124, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10066, 8768, 124, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11260, 5009, 324, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11094, 7703, 317, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24009, 20638, 1618, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24010, 14301, 1618, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15391, 10339, 1057, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15392, 13453, 1057, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15393, 10324, 1057, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15394, 7873, 1057, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15395, 9699, 1057, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15396, 11749, 1057, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15401, 13458, 1057, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (15403, 5832, 1057, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (22471, 15603, 1492, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22472, 11222, 1492, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22473, 9983, 1492, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22474, 19230, 1492, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22475, 15712, 1492, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22476, 19231, 1492, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22477, 19232, 1492, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22478, 19233, 1492, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22479, 15340, 1492, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22480, 19234, 1492, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22481, 12903, 1492, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22482, 12904, 1492, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22483, 12906, 1492, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22484, 15378, 1492, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22485, 19235, 1492, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22486, 12907, 1492, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22487, 17392, 1492, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5760, 6669, 120, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1777, 2057, 120, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1215, 1404, 120, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1667, 1934, 120, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2211, 2545, 120, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5413, 6264, 120, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3370, 3881, 120, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24011, 20643, 1619, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24012, 20644, 1619, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24013, 20645, 1619, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24014, 20646, 1619, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24015, 20647, 1619, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24016, 20648, 1619, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24017, 20649, 1619, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24018, 20650, 1619, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24019, 20651, 1619, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19864, 17410, 1337, 1, 29);
INSERT INTO 'dancespublicationsmap' VALUES (19865, 16817, 1337, 2, 29);
INSERT INTO 'dancespublicationsmap' VALUES (19866, 16801, 1337, 3, 29);
INSERT INTO 'dancespublicationsmap' VALUES (3004, 3451, 438, 1, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5918, 6856, 438, 2, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5303, 6129, 438, 3, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6219, 7212, 438, 4, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2724, 3139, 438, 5, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5110, 5908, 438, 6, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24020, 20652, 1619, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24021, 20653, 1619, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24022, 20654, 1619, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5643, 7973, 438, 7, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24023, 20655, 1619, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24024, 20656, 1619, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24025, 20657, 1619, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24026, 20658, 1619, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22886, 2846, 1518, 1, 18);
INSERT INTO 'dancespublicationsmap' VALUES (22887, 4014, 1518, 2, 18);
INSERT INTO 'dancespublicationsmap' VALUES (22888, 5707, 1518, 3, 18);
INSERT INTO 'dancespublicationsmap' VALUES (22889, 6037, 1518, 4, 18);
INSERT INTO 'dancespublicationsmap' VALUES (5578, 6453, 515, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (67, 78, 515, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17886, 15929, 1217, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (17926, 15956, 1217, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (17887, 15374, 1217, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (17927, 15957, 1217, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (17928, 15958, 1217, 5, 31);
INSERT INTO 'dancespublicationsmap' VALUES (17889, 14447, 1217, 6, 31);
INSERT INTO 'dancespublicationsmap' VALUES (16112, 14442, 1107, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16113, 14443, 1107, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16115, 14446, 1107, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16116, 14447, 1107, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16117, 14448, 1107, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16118, 14449, 1107, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16119, 14450, 1107, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16120, 14451, 1107, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16124, 14456, 1107, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16125, 14457, 1107, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (16126, 14458, 1107, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3633, 4177, 436, 29, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6239, 7234, 436, 31, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2320, 2673, 436, 32, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3853, 4432, 436, 35, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1294, 1498, 436, 36, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6260, 7257, 436, 37, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2857, 3286, 436, 39, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2842, 3270, 436, 40, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4976, 5758, 436, 41, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5740, 6648, 436, 42, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3802, 4376, 436, 43, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2207, 2540, 436, 44, 40);
INSERT INTO 'dancespublicationsmap' VALUES (16127, 14459, 1107, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3383, 3894, 155, 2, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4903, 5674, 155, 5, 40);
INSERT INTO 'dancespublicationsmap' VALUES (16322, 4015, 155, 8, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1996, 2305, 155, 11, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1248, 1447, 155, 13, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2217, 2552, 155, 16, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1509, 1747, 155, 17, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1991, 2300, 155, 19, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2470, 2849, 155, 26, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3457, 3980, 155, 28, 40);
INSERT INTO 'dancespublicationsmap' VALUES (342, 399, 155, 29, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6308, 784, 155, 31, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3503, 4033, 155, 33, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3456, 3979, 155, 34, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5391, 6236, 155, 34, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3015, 3465, 155, 35, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3891, 4475, 155, 36, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3825, 4401, 155, 37, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5496, 6360, 155, 38, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3991, 4590, 155, 39, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3647, 4192, 155, 40, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3445, 3968, 155, 43, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3059, 3521, 155, 44, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5692, 6592, 155, 45, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2158, 2485, 155, 47, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3175, 3653, 155, 48, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6295, 570, 155, 49, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1880, 2171, 155, 50, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24027, 20574, 1620, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24028, 20578, 1620, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24029, 20452, 1620, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24030, 20663, 1620, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24031, 20513, 1620, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24032, 20671, 1620, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24033, 20672, 1620, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24034, 20635, 1620, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24035, 20673, 1620, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24036, 20641, 1620, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21734, 3608, 1440, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21748, 1677, 1440, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21749, 3589, 1440, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23300, 20080, 1290, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23415, 20207, 1290, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24071, 20702, 1290, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24038, 20677, 1621, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24039, 20100, 1621, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24040, 20678, 1621, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24041, 20679, 1621, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24042, 20031, 1621, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24043, 20680, 1621, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24076, 20706, 1623, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24077, 20707, 1623, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24078, 20708, 1623, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24090, 20732, 1625, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24091, 19507, 1625, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24092, 20733, 1625, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24093, 20734, 1625, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24094, 20537, 1625, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24095, 20542, 1625, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24096, 20736, 1625, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24097, 20737, 1625, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24098, 20738, 1625, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24099, 20739, 1625, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24100, 20740, 1625, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24101, 20576, 1625, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24102, 20741, 1626, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24103, 20742, 1626, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24104, 20743, 1626, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24105, 20746, 1626, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24106, 20747, 1626, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24107, 20748, 1626, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24079, 20709, 1624, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24080, 20710, 1624, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24081, 20711, 1624, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24082, 20712, 1624, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24083, 20713, 1624, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24084, 20714, 1624, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24085, 20715, 1624, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24086, 20716, 1624, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24087, 20717, 1624, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24044, 20681, 1621, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24045, 20682, 1621, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24046, 19114, 1621, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24047, 20683, 1621, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24088, 20730, 1625, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24089, 20731, 1625, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24048, 20684, 1621, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24049, 20685, 1621, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24050, 20686, 1621, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24051, 20687, 1621, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24136, 18657, 1627, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24109, 20238, 1627, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24138, 20256, 1627, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24139, 20753, 1627, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24140, 20239, 1627, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24141, 19688, 1627, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24127, 16568, 1627, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24143, 18658, 1627, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24072, 19712, 1622, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24075, 20705, 1622, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24073, 18536, 1622, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24052, 20688, 1621, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24053, 20689, 1621, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24054, 20217, 1621, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24055, 20690, 1621, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24056, 20691, 1621, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24057, 20692, 1621, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24058, 20693, 1621, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24059, 20694, 1621, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24060, 20695, 1621, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24061, 20696, 1621, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24062, 20697, 1621, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24063, 20101, 1621, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24064, 20698, 1621, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24065, 20699, 1621, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24066, 19275, 1621, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24074, 17098, 1622, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24037, 20605, 1621, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24067, 20676, 1621, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24068, 20675, 1621, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15860, 14270, 1089, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15861, 13127, 1089, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15862, 14271, 1089, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15863, 14272, 1089, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15864, 14273, 1089, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15865, 14274, 1089, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15866, 14275, 1089, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15867, 14276, 1089, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15868, 14277, 1089, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15869, 14278, 1089, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15870, 14279, 1089, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15871, 14280, 1089, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (15872, 12910, 1089, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24201, 20829, 1634, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24182, 20808, 1633, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24177, 20797, 1632, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24178, 20798, 1632, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24179, 20799, 1632, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24180, 20800, 1632, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24181, 20801, 1632, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10243, 7536, 411, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10244, 8847, 411, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10245, 8849, 411, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10246, 8861, 411, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24183, 20348, 1633, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24184, 20810, 1633, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24229, 20857, 1637, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24230, 20858, 1637, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24231, 20859, 1637, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24185, 20809, 1633, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24186, 20811, 1633, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24187, 20812, 1633, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24188, 20813, 1633, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24189, 20814, 1633, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24190, 20815, 1633, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24191, 20816, 1633, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24142, 20255, 1627, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24130, 17880, 1627, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24131, 18663, 1627, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24147, 20258, 1627, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24148, 15126, 1627, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24149, 20240, 1627, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24120, 15413, 1627, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24121, 20257, 1627, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24150, 20540, 1630, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24151, 20042, 1630, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24158, 20774, 1630, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24159, 20775, 1630, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24152, 20139, 1630, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24153, 19970, 1630, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24154, 20543, 1630, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24155, 20541, 1630, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24156, 20050, 1630, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24157, 19797, 1630, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24160, 20776, 1630, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24161, 20777, 1630, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24202, 20830, 1635, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24203, 20831, 1635, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24204, 20832, 1635, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24205, 20833, 1635, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24206, 20834, 1635, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24207, 20835, 1635, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24208, 20836, 1635, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24209, 20837, 1635, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24210, 20838, 1635, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24211, 20839, 1635, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24212, 20840, 1636, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24162, 20781, 1631, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24163, 20782, 1631, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24164, 20783, 1631, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24165, 20784, 1631, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24166, 20785, 1631, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24167, 20786, 1631, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24168, 20787, 1631, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24169, 20788, 1631, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24170, 20789, 1631, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24171, 20790, 1631, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24192, 20820, 1634, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24193, 20821, 1634, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24194, 20822, 1634, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24195, 20823, 1634, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24196, 20824, 1634, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24197, 20825, 1634, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24198, 20826, 1634, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24199, 20827, 1634, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24200, 20828, 1634, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24213, 20841, 1636, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24214, 20842, 1636, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24215, 20843, 1636, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24216, 20844, 1636, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24217, 20845, 1636, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24218, 20846, 1636, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24219, 20847, 1636, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24220, 20848, 1636, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24221, 20849, 1636, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24222, 20850, 1637, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24223, 20851, 1637, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24224, 20852, 1637, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24225, 20853, 1637, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24226, 20854, 1637, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24227, 20855, 1637, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24228, 20856, 1637, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17992, 16007, 1226, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17993, 16008, 1226, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17994, 16009, 1226, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17995, 16010, 1226, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17996, 16011, 1226, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17997, 1562, 1226, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5603, 6481, 436, 2, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4697, 5435, 436, 3, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4945, 5723, 436, 4, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4370, 5047, 436, 12, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6593, 6150, 436, 13, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3665, 4212, 436, 14, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1772, 2052, 436, 17, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1886, 2178, 436, 19, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5037, 5825, 436, 20, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4562, 5269, 436, 21, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5517, 6384, 436, 22, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1633, 1895, 436, 24, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2274, 2622, 436, 25, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1337, 1547, 436, 27, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24176, 20796, 1290, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11878, 10842, 282, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11879, 10843, 282, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11887, 10844, 282, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11880, 10845, 282, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11881, 10846, 282, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11882, 10847, 282, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11883, 10848, 282, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11884, 10849, 282, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11885, 10850, 282, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11888, 10851, 282, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11886, 10852, 282, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2149, 2475, 547, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6196, 7186, 547, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (349, 408, 547, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (24232, 20874, 1638, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24233, 20875, 1638, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24172, 20791, 1631, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24173, 20792, 1631, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24174, 20793, 1631, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24175, 20794, 1631, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24246, 20901, 1609, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24247, 20902, 1609, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24248, 20903, 1609, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24249, 20904, 1609, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24250, 20905, 1609, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24235, 20877, 1639, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24236, 20878, 1639, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24237, 20879, 1639, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24238, 20880, 1639, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24239, 20881, 1639, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24240, 20882, 1639, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24241, 20883, 1639, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24242, 20884, 1639, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24234, 20875, 1639, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24243, 20885, 1639, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24244, 20886, 1639, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24245, 20887, 1639, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24275, 18586, 1641, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24267, 20676, 1641, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24276, 20932, 1641, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24251, 20907, 1640, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24252, 20908, 1640, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24253, 20909, 1640, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24254, 20910, 1640, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24255, 20911, 1640, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24256, 20912, 1640, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24257, 20913, 1640, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24258, 20914, 1640, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24259, 20915, 1640, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24260, 20916, 1640, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24261, 20917, 1640, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24262, 14994, 1640, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24263, 20918, 1640, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24264, 20919, 1640, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24265, 20920, 1640, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24266, 20921, 1640, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24268, 19833, 1641, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24277, 20933, 1641, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24278, 20934, 1641, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24279, 20935, 1641, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24269, 18283, 1641, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24270, 17768, 1641, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24271, 18219, 1641, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24272, 19810, 1641, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24273, 14989, 1641, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (839, 971, 436, 86, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4462, 5153, 436, 87, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5910, 6847, 436, 88, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6608, 6525, 436, 89, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1251, 1451, 436, 90, 40);
INSERT INTO 'dancespublicationsmap' VALUES (95, 108, 436, 91, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1494, 1731, 436, 92, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1464, 1698, 436, 93, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5288, 6114, 436, 94, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1727, 1998, 436, 95, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2741, 3156, 436, 96, 40);
INSERT INTO 'dancespublicationsmap' VALUES (464, 543, 436, 97, 40);
INSERT INTO 'dancespublicationsmap' VALUES (14333, 12643, 991, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14334, 12644, 991, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14335, 12645, 991, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14336, 12646, 991, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14337, 12647, 991, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14338, 12648, 991, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14339, 11636, 991, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14340, 12649, 991, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14341, 12650, 991, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14342, 11633, 991, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14343, 12651, 991, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14344, 12652, 991, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14345, 12653, 991, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14346, 12654, 991, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24303, 1464, 1644, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24304, 898, 1644, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24305, 6146, 1644, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24306, 5240, 1644, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24299, 736, 1643, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24300, 3636, 1643, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24301, 887, 1643, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24302, 2208, 1643, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24280, 20936, 1641, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24281, 20937, 1641, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24282, 20938, 1641, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24285, 20939, 1641, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24283, 20767, 1641, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24284, 20216, 1641, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24286, 20940, 1641, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24287, 20941, 1641, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24274, 17988, 1641, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24288, 20942, 1641, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24289, 20943, 1641, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24290, 20944, 1641, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24291, 20945, 1641, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24307, 3102, 1645, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24308, 1235, 1645, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24309, 6047, 1645, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24310, 6419, 1645, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24311, 5509, 1646, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24312, 1454, 1646, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24313, 2832, 1646, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24314, 4382, 1646, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (6830, 7497, 788, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6755, 7403, 788, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6817, 7482, 788, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6826, 7492, 788, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6774, 7426, 788, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6827, 7493, 788, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6773, 7425, 788, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6762, 7410, 788, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6843, 7512, 788, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6816, 7481, 788, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6719, 7363, 788, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6851, 7522, 788, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9582, 8212, 346, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9583, 8213, 346, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9584, 8214, 346, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9585, 8215, 346, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9586, 8216, 346, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9587, 8217, 346, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9588, 8218, 346, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9602, 8232, 346, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9603, 8233, 346, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9764, 8396, 347, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9765, 8397, 347, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9766, 8398, 347, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9767, 8399, 347, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9768, 8400, 347, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9769, 8401, 347, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9770, 8402, 347, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9771, 8403, 347, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19659, 17219, 530, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10614, 9307, 530, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10615, 9308, 530, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10616, 9309, 530, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10617, 9310, 530, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10618, 9311, 530, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10620, 9313, 530, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10621, 9314, 530, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10622, 9315, 530, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10623, 9316, 530, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10624, 9317, 530, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5574, 6448, 91, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (246, 287, 91, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1470, 1704, 91, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (646, 755, 91, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4180, 4822, 91, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2193, 2525, 91, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4230, 4885, 91, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24292, 8736, 1642, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24293, 7310, 1642, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24294, 7287, 1642, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24295, 7281, 1642, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24296, 8639, 1642, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24297, 8647, 1642, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24298, 7320, 1642, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23766, 20404, 1530, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23767, 20405, 1530, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23847, 16520, 1530, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10625, 9318, 530, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10572, 9265, 525, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10573, 9266, 525, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10574, 9267, 525, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10575, 9268, 525, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10576, 9269, 525, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10577, 9270, 525, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10578, 9271, 525, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10579, 9272, 525, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10580, 9273, 525, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10581, 9274, 525, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10908, 9609, 645, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10909, 9610, 645, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10910, 9611, 645, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10911, 9612, 645, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10912, 9613, 645, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10913, 9614, 645, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10914, 9615, 645, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10915, 9616, 645, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10916, 9617, 645, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10917, 9618, 645, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10918, 9619, 645, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10919, 9620, 645, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10920, 9621, 645, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10921, 1526, 645, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24315, 1758, 1647, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24316, 2947, 1647, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24317, 19958, 1648, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24318, 19901, 1648, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24319, 19959, 1648, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24320, 20149, 1648, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (785, 913, 460, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (946, 1095, 460, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1022, 1181, 460, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1052, 1219, 460, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (953, 1102, 460, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1088, 1262, 460, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1517, 1759, 460, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24321, 20131, 1648, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24322, 20197, 1648, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24323, 20215, 1648, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24324, 20558, 1648, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24325, 20642, 1648, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24326, 20559, 1648, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24327, 20457, 1648, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2191, 2523, 460, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2522, 2909, 460, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3120, 3591, 460, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3273, 3771, 460, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3270, 3768, 460, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24328, 20951, 1648, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24329, 20952, 1648, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3320, 3826, 460, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3375, 3886, 460, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24330, 20953, 1648, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (10046, 1087, 344, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9556, 7709, 344, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9557, 8198, 344, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24331, 20726, 1648, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24332, 20954, 1648, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24333, 20955, 1648, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24334, 20956, 1648, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24335, 20891, 1648, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24336, 20957, 1648, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24337, 20335, 1648, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11919, 10879, 844, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11920, 10880, 844, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11921, 10881, 844, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11922, 10882, 844, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11923, 10883, 844, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11924, 10884, 844, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14427, 12747, 770, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14428, 12748, 770, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14429, 12749, 770, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14430, 12750, 770, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14431, 12751, 770, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14426, 11703, 770, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14432, 12752, 770, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14433, 12753, 770, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14434, 12754, 770, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14435, 12755, 770, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14436, 12756, 770, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14437, 12757, 770, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14438, 12758, 770, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18595, 16480, 1265, 1, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18596, 11716, 1265, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18597, 11714, 1265, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18598, 16481, 1265, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18599, 16482, 1265, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18600, 11712, 1265, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18601, 11550, 1265, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18602, 11715, 1265, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18603, 11717, 1265, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18604, 3432, 1265, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18605, 16483, 1265, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18606, 16484, 1265, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18607, 16485, 1265, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18608, 16486, 1265, 14, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18610, 16487, 1265, 16, 10);
INSERT INTO 'dancespublicationsmap' VALUES (18611, 6010, 1265, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (24338, 1760, 1649, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24339, 2563, 1649, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24340, 5071, 1650, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24341, 1363, 1650, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24342, 2596, 1650, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24343, 6079, 1650, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24344, 758, 1651, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24345, 427, 1651, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24346, 532, 1651, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24347, 1459, 1651, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24348, 925, 1652, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24349, 2766, 1652, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24350, 4944, 1652, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24351, 7009, 1652, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24352, 2582, 1653, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24353, 4005, 1653, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24354, 2037, 1653, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24355, 2793, 1653, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24356, 5695, 1654, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24357, 4611, 1654, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24358, 4085, 1654, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24359, 4902, 1654, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (17308, 10861, 1174, 1, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17309, 10862, 1174, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17310, 10863, 1174, 3, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17311, 9854, 1174, 4, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17312, 10052, 1174, 5, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17313, 9353, 1174, 6, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17314, 10864, 1174, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17315, 10865, 1174, 8, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17316, 9986, 1174, 9, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17317, 10866, 1174, 10, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17318, 10778, 1174, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17319, 10867, 1174, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17320, 3980, 1174, 13, 70);
INSERT INTO 'dancespublicationsmap' VALUES (17321, 10797, 1174, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17322, 9352, 1174, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17323, 9869, 1174, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (17324, 15264, 1174, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (24360, 20963, 1655, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9558, 8199, 344, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (9559, 8200, 344, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24376, 20980, 1657, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24377, 20981, 1657, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24378, 20982, 1657, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24379, 20983, 1657, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24380, 20985, 1657, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24381, 20986, 1657, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24382, 20987, 1657, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24383, 20988, 1657, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24384, 20989, 1657, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24385, 20984, 1657, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24367, 20969, 1656, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24368, 20970, 1656, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24366, 20971, 1656, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24363, 20670, 1656, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24365, 20972, 1656, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24369, 20973, 1656, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24370, 20974, 1656, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24371, 20975, 1656, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24372, 20976, 1656, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24373, 20977, 1656, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24362, 18080, 1656, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24364, 17576, 1656, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24374, 20978, 1656, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24375, 20979, 1656, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24361, 20995, 1656, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24386, 18373, 1656, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24069, 20700, 1621, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24070, 20701, 1621, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24387, 1782, 1658, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24388, 373, 1658, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24389, 2962, 1658, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24390, 11369, 1658, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24391, 1931, 1658, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24392, 7282, 1659, 7, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24393, 7283, 1659, 9, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24394, 4933, 1659, 10, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24395, 7284, 1659, 12, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24396, 7285, 1659, 13, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24397, 7286, 1659, 14, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24398, 1782, 1659, 16, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24399, 5637, 1659, 17, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24400, 5354, 1659, 18, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24401, 9102, 1659, 21, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24402, 9103, 1659, 22, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24403, 9104, 1659, 23, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24404, 9105, 1659, 24, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24405, 9106, 1659, 25, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24406, 9107, 1659, 26, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24407, 9108, 1659, 27, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24408, 9109, 1659, 28, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24409, 9110, 1659, 29, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24410, 9111, 1659, 30, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24411, 5209, 1659, 32, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24412, 1473, 1659, 33, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24413, 9559, 1659, 34, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24414, 7654, 1659, 35, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24415, 9074, 1659, 36, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24416, 9560, 1659, 38, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24417, 7543, 1659, 39, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24418, 9561, 1659, 40, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24419, 9562, 1659, 41, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24420, 9563, 1659, 42, 12);
INSERT INTO 'dancespublicationsmap' VALUES (22643, 5188, 198, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22644, 354, 198, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22645, 1162, 198, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22646, 1307, 198, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22647, 1393, 198, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22648, 1625, 198, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22649, 1639, 198, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22650, 2822, 198, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22651, 1777, 198, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22652, 2674, 198, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22653, 3454, 198, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22654, 3710, 198, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24421, 10653, 1659, 44, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24422, 159, 1659, 46, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24423, 10787, 1659, 48, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24424, 10788, 1659, 50, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24425, 10789, 1659, 51, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24426, 10790, 1659, 52, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24427, 10791, 1659, 53, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24428, 10792, 1659, 54, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24429, 10793, 1659, 56, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24430, 10794, 1659, 58, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24431, 11367, 1659, 60, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24432, 11368, 1659, 62, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24433, 11369, 1659, 63, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24434, 11370, 1659, 64, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24435, 11371, 1659, 68, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24436, 11372, 1659, 70, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24437, 11373, 1659, 71, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24438, 11374, 1659, 72, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24439, 11375, 1659, 73, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24440, 221, 1659, 74, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24441, 11769, 1659, 77, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24442, 9787, 1659, 78, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24443, 6964, 1659, 79, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24444, 11770, 1659, 80, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24445, 11771, 1659, 83, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24446, 11772, 1659, 84, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24447, 11773, 1659, 85, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24448, 11763, 1659, 86, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24449, 11543, 1659, 88, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24450, 9093, 1659, 89, 12);
INSERT INTO 'dancespublicationsmap' VALUES (22655, 4354, 198, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22656, 3963, 198, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22657, 4211, 198, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24452, 21108, 1660, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24453, 20996, 1660, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24454, 21106, 1660, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24455, 21105, 1660, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24456, 20990, 1660, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24457, 20994, 1660, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24458, 21104, 1660, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24459, 21107, 1660, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18937, 16835, 1285, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18938, 16836, 1285, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18939, 16837, 1285, 12, 31);
INSERT INTO 'dancespublicationsmap' VALUES (1107, 1285, 122, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1233, 1426, 122, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3643, 4187, 122, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3834, 4411, 122, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4278, 4943, 122, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4357, 5034, 122, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4533, 5237, 122, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4657, 5384, 122, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5582, 6459, 122, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6756, 7404, 778, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6860, 7534, 778, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6864, 7539, 778, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22658, 4845, 198, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22659, 5932, 198, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22660, 5980, 198, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22661, 6637, 198, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22662, 6675, 198, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22663, 6830, 198, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22664, 7201, 198, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22665, 6919, 198, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22666, 7152, 198, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22667, 7175, 198, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22668, 7267, 198, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22669, 4669, 198, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14577, 12976, 999, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14581, 12980, 999, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14579, 12978, 999, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14578, 12977, 999, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14582, 12981, 999, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5262, 6086, 279, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5040, 5828, 279, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5278, 6104, 279, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4947, 5725, 279, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4879, 5644, 279, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2977, 3422, 279, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4970, 5752, 279, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (744, 867, 279, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1267, 1471, 279, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1348, 1559, 279, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6242, 7237, 279, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (17272, 14363, 1171, 2, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14768, 13148, 1014, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14769, 13141, 1014, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14770, 13147, 1014, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14771, 13142, 1014, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14772, 13140, 1014, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24513, 21161, 1662, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24512, 20749, 1662, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24514, 21164, 1662, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24460, 21113, 1661, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24461, 21114, 1661, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24517, 21165, 1663, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24518, 19078, 1663, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24519, 21173, 1663, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24520, 21174, 1663, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24521, 21175, 1663, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24522, 21176, 1663, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24462, 21115, 1661, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6910, 4796, 801, 2, 11);
INSERT INTO 'dancespublicationsmap' VALUES (6911, 822, 801, 3, 11);
INSERT INTO 'dancespublicationsmap' VALUES (6908, 2453, 801, 4, 11);
INSERT INTO 'dancespublicationsmap' VALUES (24511, 21155, 1662, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24515, 21165, 1662, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24523, 21177, 1663, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24524, 21178, 1663, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24525, 21179, 1663, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24526, 21180, 1663, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24527, 21181, 1663, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24528, 21182, 1663, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24529, 21183, 1663, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24530, 21184, 1663, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24516, 21166, 1662, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24531, 19848, 1662, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (19610, 17139, 1325, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19611, 17140, 1325, 8, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19612, 17144, 1325, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19613, 17141, 1325, 10, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19614, 17142, 1325, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (19615, 17143, 1325, 12, 10);
INSERT INTO 'dancespublicationsmap' VALUES (20442, 7331, 1384, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20443, 7330, 1384, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20444, 7332, 1384, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20445, 7302, 1384, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20446, 14828, 1384, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20447, 14829, 1384, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23352, 11411, 1384, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20449, 14831, 1384, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20450, 14832, 1384, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20451, 17928, 1384, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20452, 14833, 1384, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20453, 12677, 1384, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20454, 12676, 1384, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20455, 14823, 1384, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20456, 14824, 1384, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20457, 14825, 1384, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20458, 14826, 1384, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20459, 14827, 1384, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20460, 17929, 1384, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20461, 12871, 1384, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20462, 17930, 1384, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20463, 11418, 1384, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20464, 7305, 1384, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20465, 11419, 1384, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20466, 14834, 1384, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20467, 14835, 1384, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20468, 12678, 1384, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20469, 7299, 1384, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20470, 14836, 1384, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20471, 7276, 1384, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20472, 14837, 1384, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20473, 7277, 1384, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20474, 9143, 1384, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20475, 17931, 1384, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20476, 14838, 1384, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20477, 7303, 1384, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20478, 17932, 1384, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20479, 17933, 1384, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20480, 14842, 1384, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20481, 14642, 1384, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20482, 17934, 1384, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20483, 11417, 1384, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20484, 7306, 1384, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20485, 11420, 1384, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20486, 14843, 1384, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20487, 7279, 1384, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20488, 8643, 1384, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20489, 14847, 1384, 49, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20490, 14845, 1384, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20491, 7307, 1384, 51, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20492, 14846, 1384, 52, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20497, 11423, 1384, 57, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20498, 14852, 1384, 58, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20499, 14854, 1384, 59, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20500, 14851, 1384, 60, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20501, 14853, 1384, 61, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20502, 7310, 1384, 62, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20503, 8645, 1384, 63, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20504, 14521, 1384, 64, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20505, 11424, 1384, 65, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20506, 14856, 1384, 66, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20507, 7288, 1384, 67, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20508, 11425, 1384, 68, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20509, 13281, 1384, 69, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20510, 7281, 1384, 70, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20511, 9029, 1384, 71, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20512, 7275, 1384, 72, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20513, 17935, 1384, 73, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20514, 17936, 1384, 74, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20515, 14858, 1384, 75, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20516, 14859, 1384, 76, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20517, 14860, 1384, 77, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20518, 14861, 1384, 78, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20519, 14862, 1384, 79, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20520, 14863, 1384, 80, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20521, 14867, 1384, 81, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20522, 14868, 1384, 82, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20523, 14870, 1384, 83, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20524, 7291, 1384, 84, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20525, 14871, 1384, 85, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20526, 14872, 1384, 86, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20527, 14873, 1384, 87, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20528, 11426, 1384, 88, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20529, 14874, 1384, 89, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20530, 14875, 1384, 90, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20531, 13115, 1384, 91, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20532, 7295, 1384, 92, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20533, 7320, 1384, 93, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20534, 10574, 1384, 94, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20535, 14877, 1384, 95, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20536, 17937, 1384, 96, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20537, 14879, 1384, 97, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20538, 14880, 1384, 98, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20539, 17938, 1384, 99, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20540, 9145, 1384, 100, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20541, 14882, 1384, 101, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20542, 8736, 1384, 102, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20543, 14883, 1384, 103, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20544, 8671, 1384, 104, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20545, 17752, 1384, 105, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20546, 7271, 1384, 106, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20547, 9141, 1384, 107, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20548, 12667, 1384, 108, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20549, 14885, 1384, 109, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20550, 14886, 1384, 110, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20551, 17939, 1384, 111, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20552, 14887, 1384, 112, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20553, 7273, 1384, 113, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20554, 9139, 1384, 114, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20555, 13280, 1384, 115, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20556, 9140, 1384, 116, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20557, 8639, 1384, 117, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20558, 12679, 1384, 118, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20559, 17940, 1384, 119, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14373, 12692, 724, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14374, 12693, 724, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (14375, 12694, 724, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24532, 153, 1664, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3163, 3635, 436, 28, 40);
INSERT INTO 'dancespublicationsmap' VALUES (777, 905, 436, 46, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5962, 6910, 451, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2128, 2451, 581, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (3317, 3823, 581, 12, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4020, 4627, 581, 13, 20);
INSERT INTO 'dancespublicationsmap' VALUES (4289, 4956, 581, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6120, 7095, 581, 16, 20);
INSERT INTO 'dancespublicationsmap' VALUES (6248, 7244, 581, 17, 20);
INSERT INTO 'dancespublicationsmap' VALUES (21012, 18185, 1405, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21013, 18184, 1405, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21014, 18129, 1405, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21015, 18186, 1405, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21016, 17006, 1405, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21017, 18183, 1405, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21018, 18139, 1405, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21019, 18140, 1405, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21020, 18145, 1405, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21021, 18144, 1405, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21022, 18187, 1405, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21023, 18143, 1405, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (21024, 18141, 1405, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7688, 7880, 339, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (18251, 2353, 1246, 7, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18252, 6616, 1246, 8, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18253, 6091, 1246, 10, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18254, 4803, 1246, 11, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18255, 3365, 1246, 12, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18256, 4555, 1246, 13, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18257, 2332, 1246, 14, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18258, 3762, 1246, 15, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18259, 1768, 1246, 17, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18260, 6720, 1246, 18, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18261, 2357, 1246, 19, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18262, 4424, 1246, 20, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18263, 4484, 1246, 21, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18264, 5904, 1246, 22, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18265, 6701, 1246, 23, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18266, 5422, 1246, 24, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18267, 1884, 1246, 26, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18268, 4256, 1246, 28, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18269, 4444, 1246, 30, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18270, 4871, 1246, 31, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18271, 5529, 1246, 32, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18272, 2323, 1246, 33, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18273, 5860, 1246, 34, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18274, 3418, 1246, 36, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18275, 4796, 1246, 37, 12);
INSERT INTO 'dancespublicationsmap' VALUES (4622, 5339, 436, 107, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1819, 2103, 436, 108, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1913, 2210, 436, 109, 40);
INSERT INTO 'dancespublicationsmap' VALUES (407, 474, 436, 110, 40);
INSERT INTO 'dancespublicationsmap' VALUES (7596, 3415, 436, 111, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4708, 5449, 436, 112, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6213, 7206, 436, 113, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2499, 2885, 436, 114, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3236, 3728, 436, 115, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2490, 2871, 436, 116, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1680, 1949, 436, 117, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2354, 2711, 436, 118, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3467, 3990, 436, 119, 40);
INSERT INTO 'dancespublicationsmap' VALUES (902, 1045, 436, 120, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4105, 4730, 436, 121, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1761, 2040, 436, 122, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5762, 6671, 436, 123, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2797, 3218, 436, 124, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2589, 2984, 436, 125, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1669, 1936, 436, 126, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4995, 5781, 436, 127, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3578, 4114, 436, 129, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5747, 6655, 436, 130, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4826, 5585, 436, 131, 40);
INSERT INTO 'dancespublicationsmap' VALUES (10003, 7826, 436, 132, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6432, 3299, 436, 133, 40);
INSERT INTO 'dancespublicationsmap' VALUES (302, 350, 436, 134, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5056, 5846, 436, 135, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6428, 3245, 436, 136, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6136, 7112, 436, 137, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5789, 6703, 436, 138, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2524, 2911, 436, 139, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2951, 3393, 436, 140, 40);
INSERT INTO 'dancespublicationsmap' VALUES (987, 1142, 436, 141, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5144, 5950, 436, 142, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4480, 5176, 436, 143, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5552, 6421, 436, 144, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4145, 4778, 436, 145, 40);
INSERT INTO 'dancespublicationsmap' VALUES (947, 1096, 436, 146, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4886, 5653, 436, 147, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3244, 3736, 436, 148, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1210, 1399, 436, 149, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3246, 3739, 436, 150, 40);
INSERT INTO 'dancespublicationsmap' VALUES (596, 694, 436, 151, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1801, 2082, 436, 152, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2602, 2999, 436, 153, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5522, 6389, 436, 154, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1485, 1722, 436, 155, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4717, 5460, 436, 156, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5204, 6019, 436, 157, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5628, 6511, 436, 158, 40);
INSERT INTO 'dancespublicationsmap' VALUES (18276, 822, 1246, 38, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18277, 2453, 1246, 39, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18278, 7613, 1246, 40, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18279, 8729, 1246, 42, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18280, 8730, 1246, 44, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18281, 5219, 1246, 45, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18282, 8732, 1246, 46, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18283, 2821, 1246, 47, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18284, 4752, 1246, 48, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18285, 7055, 1246, 49, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18286, 2367, 1246, 50, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18287, 6224, 1246, 51, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18288, 2158, 1246, 52, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18289, 1469, 1246, 54, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18290, 6271, 1246, 55, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18291, 2868, 1246, 56, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18292, 2725, 1246, 58, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18293, 5802, 1246, 59, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18294, 3310, 1246, 60, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18295, 5755, 1246, 61, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18296, 6391, 1246, 62, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18297, 11184, 1246, 63, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18298, 11185, 1246, 64, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18299, 11186, 1246, 65, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18300, 11187, 1246, 67, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18301, 11188, 1246, 68, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18302, 11189, 1246, 69, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18303, 11190, 1246, 70, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18304, 14634, 1246, 71, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18305, 14740, 1246, 72, 12);
INSERT INTO 'dancespublicationsmap' VALUES (18306, 14741, 1246, 73, 12);
INSERT INTO 'dancespublicationsmap' VALUES (24533, 6365, 1665, 2, 10);
INSERT INTO 'dancespublicationsmap' VALUES (24534, 612, 1665, 4, 10);
INSERT INTO 'dancespublicationsmap' VALUES (24535, 2875, 1665, 6, 10);
INSERT INTO 'dancespublicationsmap' VALUES (7007, 3611, 806, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7008, 1415, 806, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7009, 6036, 806, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7011, 4068, 806, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7012, 5937, 806, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7013, 6523, 806, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7014, 4548, 806, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7015, 3642, 806, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7016, 3541, 806, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7017, 4646, 806, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7018, 3342, 806, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7019, 3084, 806, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7020, 6152, 806, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7021, 1496, 806, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7022, 4679, 806, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7023, 3912, 806, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7024, 2495, 806, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7025, 3105, 806, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7026, 5462, 806, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7027, 4559, 806, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7028, 2644, 806, 25, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7029, 2661, 806, 26, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7030, 3235, 806, 27, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7031, 3656, 806, 28, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7032, 2140, 806, 29, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7033, 3528, 806, 30, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7034, 7247, 806, 31, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7035, 5520, 806, 32, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7036, 6178, 806, 33, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7037, 541, 806, 34, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7038, 1883, 806, 35, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7039, 4032, 806, 36, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6903, 5450, 799, 32, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6904, 3617, 799, 33, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6905, 1927, 799, 34, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6906, 2317, 799, 35, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6907, 5532, 799, 36, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7045, 3526, 807, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7046, 4907, 807, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7047, 2257, 807, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7048, 6349, 807, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7049, 5525, 807, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7050, 794, 807, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7051, 3580, 807, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7052, 7172, 807, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7053, 2645, 807, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7054, 5398, 807, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7055, 1437, 807, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7056, 4562, 807, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7057, 3412, 807, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7058, 1582, 807, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7059, 6029, 807, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7060, 7068, 807, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7061, 682, 807, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7062, 3281, 807, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7063, 3672, 807, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7064, 4864, 807, 25, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7065, 3045, 807, 26, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7066, 980, 807, 27, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7067, 972, 807, 28, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7068, 2415, 807, 29, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7069, 3953, 807, 30, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7070, 3887, 807, 31, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7071, 4359, 807, 32, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7183, 4476, 810, 124, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7217, 4438, 812, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7218, 2807, 812, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7219, 4506, 812, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7220, 3631, 812, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7221, 5906, 812, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7222, 6566, 812, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7223, 4461, 812, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7224, 753, 812, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7225, 55, 812, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7226, 4374, 812, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7227, 2042, 812, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7228, 3620, 812, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7229, 3932, 812, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7230, 5065, 812, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7231, 5624, 812, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7232, 3625, 812, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7233, 6373, 812, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7234, 2349, 812, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7235, 3577, 812, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7330, 4871, 688, 25, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7331, 4803, 688, 26, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7332, 3365, 688, 27, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7333, 4555, 688, 28, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7334, 6720, 688, 29, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7335, 2357, 688, 30, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7373, 5808, 718, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7374, 652, 718, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7375, 5006, 718, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7368, 5412, 718, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7376, 5204, 718, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7377, 4857, 718, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7378, 2267, 718, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7379, 340, 718, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11388, 7282, 781, 1, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11389, 7283, 781, 2, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11390, 4933, 781, 3, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11391, 7284, 781, 4, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11392, 7285, 781, 5, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11393, 7286, 781, 6, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11394, 1782, 781, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11395, 5637, 781, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11396, 5354, 781, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11397, 9102, 781, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11398, 9103, 781, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11399, 9104, 781, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11411, 9074, 781, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11412, 9560, 781, 25, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11413, 7543, 781, 26, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11414, 9561, 781, 27, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11415, 9562, 781, 28, 14);
INSERT INTO 'dancespublicationsmap' VALUES (11416, 9563, 781, 29, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6961, 6585, 804, 30, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6962, 610, 804, 31, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6963, 5362, 804, 32, 14);
INSERT INTO 'dancespublicationsmap' VALUES (6964, 3940, 804, 33, 14);
INSERT INTO 'dancespublicationsmap' VALUES (16488, 12794, 1130, 3, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16489, 9083, 1130, 5, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16497, 12542, 1130, 7, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16496, 9836, 1130, 9, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16493, 2360, 1130, 11, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16498, 3323, 1130, 13, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16500, 5308, 1130, 15, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16491, 13385, 1130, 17, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16499, 4411, 1130, 19, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16501, 12792, 1130, 21, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16502, 13316, 1130, 23, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16495, 13579, 1130, 27, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16494, 13580, 1130, 29, 10);
INSERT INTO 'dancespublicationsmap' VALUES (7190, 109, 811, 7, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7191, 2562, 811, 8, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7192, 1588, 811, 9, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7193, 4491, 811, 10, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7194, 2494, 811, 11, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7195, 5543, 811, 12, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7196, 6420, 811, 13, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7197, 4759, 811, 14, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7198, 5765, 811, 15, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7199, 6287, 811, 16, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7200, 3788, 811, 17, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7201, 5921, 811, 18, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7202, 377, 811, 19, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7203, 7147, 811, 20, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7204, 5794, 811, 21, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7205, 5800, 811, 22, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7206, 5040, 811, 23, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7207, 3038, 811, 24, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7208, 2956, 811, 25, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7209, 1783, 811, 26, 14);
INSERT INTO 'dancespublicationsmap' VALUES (7210, 984, 811, 27, 14);
INSERT INTO 'dancespublicationsmap' VALUES (16490, 13581, 1130, 31, 10);
INSERT INTO 'dancespublicationsmap' VALUES (16492, 13583, 1130, 35, 10);
INSERT INTO 'dancespublicationsmap' VALUES (4588, 5303, 141, 19, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2130, 2453, 82, 7, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11489, 4597, 284, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11490, 4274, 284, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11491, 4278, 284, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11492, 4991, 284, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7726, 3335, 284, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11493, 1679, 284, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11494, 1191, 284, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11495, 4276, 284, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7704, 5382, 284, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7627, 4007, 284, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11496, 6216, 284, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11497, 4050, 284, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11498, 3612, 284, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7720, 5645, 284, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7657, 4540, 284, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11500, 2072, 284, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11501, 4611, 284, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11502, 4043, 284, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11503, 4045, 284, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11504, 4044, 284, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11505, 54, 284, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11506, 6269, 284, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11507, 735, 284, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11508, 2378, 284, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11509, 2512, 284, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11510, 3687, 284, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11511, 944, 284, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11512, 2043, 284, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7565, 2950, 284, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11513, 7133, 284, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11514, 5278, 284, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7722, 5657, 284, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24536, 9042, 1666, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24537, 9663, 1666, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24538, 8863, 1666, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24539, 11511, 1666, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24540, 9830, 1666, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24541, 8864, 1666, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24542, 9831, 1666, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24543, 21205, 1666, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24544, 9668, 1666, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24545, 8865, 1666, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24546, 9772, 1666, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24547, 9909, 1666, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24548, 12241, 1666, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24549, 21206, 1666, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24550, 15527, 1666, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24551, 9832, 1666, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22875, 19652, 1515, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22876, 19653, 1515, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22877, 19644, 1515, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22878, 19555, 1515, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22879, 19558, 1515, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22880, 19654, 1515, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22884, 19655, 1515, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22881, 15015, 1515, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (22882, 19657, 1515, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6533, 4857, 498, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4162, 4800, 498, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4190, 4833, 498, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4316, 4990, 498, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4352, 5029, 498, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5039, 5827, 498, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (7448, 7582, 498, 0, 30);
INSERT INTO 'dancespublicationsmap' VALUES (20089, 441, 1352, 1, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20090, 742, 1352, 2, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20091, 1881, 1352, 3, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20092, 2846, 1352, 4, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20093, 3428, 1352, 5, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20094, 3680, 1352, 6, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20095, 4014, 1352, 7, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20096, 4271, 1352, 8, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20097, 4044, 1352, 9, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20098, 4283, 1352, 10, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20099, 4474, 1352, 11, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20100, 6037, 1352, 12, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20101, 5807, 1352, 13, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20102, 633, 1352, 14, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20103, 805, 1352, 15, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20104, 3225, 1352, 16, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20105, 3651, 1352, 17, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20106, 3777, 1352, 18, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20107, 3883, 1352, 19, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20108, 4043, 1352, 20, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20109, 4680, 1352, 21, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20110, 4282, 1352, 22, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20111, 5128, 1352, 23, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20112, 5699, 1352, 24, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20113, 5749, 1352, 25, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20114, 5707, 1352, 26, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20115, 5799, 1352, 27, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20116, 1789, 1352, 28, 100);
INSERT INTO 'dancespublicationsmap' VALUES (20117, 6616, 1352, 29, 100);
INSERT INTO 'dancespublicationsmap' VALUES (7746, 5939, 707, 38, 20);
INSERT INTO 'dancespublicationsmap' VALUES (11515, 3422, 284, 42, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11516, 3801, 284, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11517, 3674, 284, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11518, 6070, 284, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11519, 3960, 284, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11522, 3910, 284, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11520, 5242, 284, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11521, 5078, 284, 49, 30);
INSERT INTO 'dancespublicationsmap' VALUES (1445, 1675, 284, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24552, 21228, 1667, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24553, 21229, 1667, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24554, 21230, 1667, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24555, 6826, 1668, 1, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24556, 46, 1668, 2, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24557, 56, 1668, 3, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24558, 91, 1668, 4, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24559, 155, 1668, 5, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24560, 241, 1668, 6, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24561, 276, 1668, 7, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24562, 306, 1668, 8, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24563, 312, 1668, 9, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24564, 323, 1668, 10, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24565, 324, 1668, 11, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24566, 371, 1668, 12, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24567, 394, 1668, 13, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24568, 399, 1668, 14, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24569, 7608, 1668, 15, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24570, 431, 1668, 16, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24571, 453, 1668, 17, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24572, 463, 1668, 18, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24573, 498, 1668, 19, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24574, 519, 1668, 20, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24575, 549, 1668, 21, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24576, 557, 1668, 22, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24577, 570, 1668, 23, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24578, 576, 1668, 24, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24579, 674, 1668, 25, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24580, 665, 1668, 26, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24581, 686, 1668, 27, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24582, 705, 1668, 28, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24583, 784, 1668, 29, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24584, 800, 1668, 30, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24585, 843, 1668, 31, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24586, 919, 1668, 32, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24587, 924, 1668, 33, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24588, 932, 1668, 34, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24589, 937, 1668, 35, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24590, 950, 1668, 36, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24591, 975, 1668, 37, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24592, 985, 1668, 38, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24593, 986, 1668, 39, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24594, 1004, 1668, 40, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24595, 1013, 1668, 41, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24596, 1027, 1668, 42, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24597, 1077, 1668, 43, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24598, 1086, 1668, 44, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24599, 1195, 1668, 45, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24600, 1322, 1668, 46, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24601, 12816, 1668, 47, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24602, 1389, 1668, 48, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24603, 1413, 1668, 49, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24681, 7778, 1668, 127, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24682, 3465, 1668, 128, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24683, 3472, 1668, 129, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24684, 3485, 1668, 130, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24685, 7780, 1668, 131, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24686, 3521, 1668, 132, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24687, 3524, 1668, 133, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24688, 3653, 1668, 134, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24689, 3666, 1668, 135, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24690, 12820, 1668, 136, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24691, 3703, 1668, 137, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24692, 3732, 1668, 138, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24693, 3781, 1668, 139, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24694, 3784, 1668, 140, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24653, 12819, 1668, 99, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24654, 2806, 1668, 100, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24655, 2826, 1668, 101, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24656, 2849, 1668, 102, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24657, 2851, 1668, 103, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24658, 2886, 1668, 104, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24659, 2887, 1668, 105, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24660, 2890, 1668, 106, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24730, 4590, 1668, 176, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24731, 4594, 1668, 177, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24732, 4642, 1668, 178, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24733, 4650, 1668, 179, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24734, 4701, 1668, 180, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24735, 4768, 1668, 181, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24736, 12823, 1668, 182, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24737, 4848, 1668, 183, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24738, 4858, 1668, 184, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24739, 4863, 1668, 185, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24740, 4873, 1668, 186, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24741, 4882, 1668, 187, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24742, 4930, 1668, 188, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24743, 4941, 1668, 189, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24744, 4991, 1668, 190, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24745, 5083, 1668, 191, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24746, 5308, 1668, 192, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24747, 5330, 1668, 193, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24748, 5576, 1668, 194, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24749, 5609, 1668, 195, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24750, 5621, 1668, 196, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24751, 5647, 1668, 197, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24752, 5674, 1668, 198, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24753, 5720, 1668, 199, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24754, 5732, 1668, 200, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24755, 5951, 1668, 201, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24757, 5978, 1668, 203, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24761, 6044, 1668, 207, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24762, 6048, 1668, 208, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24765, 6188, 1668, 211, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24766, 6236, 1668, 212, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24768, 6245, 1668, 214, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24769, 6263, 1668, 215, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24772, 6294, 1668, 218, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24773, 6309, 1668, 219, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24774, 6316, 1668, 220, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24777, 6434, 1668, 223, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24779, 6464, 1668, 225, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24780, 6482, 1668, 226, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24783, 6592, 1668, 229, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24784, 6612, 1668, 230, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24786, 5961, 1668, 202, 31);
INSERT INTO 'dancespublicationsmap' VALUES (571, 665, 436, 47, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2552, 2943, 436, 48, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4014, 4620, 436, 49, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1191, 1378, 436, 50, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2907, 3347, 436, 51, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4094, 4718, 436, 52, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1433, 1661, 436, 53, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1473, 1707, 436, 54, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6053, 7017, 436, 55, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1347, 1558, 436, 56, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3836, 4413, 436, 57, 40);
INSERT INTO 'dancespublicationsmap' VALUES (76, 88, 436, 58, 40);
INSERT INTO 'dancespublicationsmap' VALUES (10017, 3233, 436, 59, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4602, 5317, 436, 60, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5287, 6113, 436, 61, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4950, 5729, 436, 62, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4998, 5784, 436, 63, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2367, 2728, 436, 64, 40);
INSERT INTO 'dancespublicationsmap' VALUES (680, 796, 436, 65, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2626, 3027, 436, 66, 40);
INSERT INTO 'dancespublicationsmap' VALUES (905, 1050, 436, 67, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4662, 5389, 436, 68, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3223, 3709, 436, 69, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3341, 3852, 436, 70, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6430, 3280, 436, 71, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3212, 3697, 436, 72, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1165, 1350, 436, 74, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1353, 1564, 436, 75, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4319, 4993, 436, 76, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4553, 5260, 436, 77, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5268, 6094, 436, 78, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2494, 2878, 436, 79, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2937, 3378, 436, 80, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3054, 3514, 436, 81, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1789, 2069, 436, 82, 40);
INSERT INTO 'dancespublicationsmap' VALUES (453, 530, 436, 83, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4513, 5212, 436, 84, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6559, 5480, 436, 85, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5257, 6078, 436, 98, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4377, 5055, 436, 99, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6021, 6980, 436, 100, 40);
INSERT INTO 'dancespublicationsmap' VALUES (577, 671, 436, 101, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4884, 5651, 436, 102, 40);
INSERT INTO 'dancespublicationsmap' VALUES (592, 687, 436, 103, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4074, 4695, 436, 104, 40);
INSERT INTO 'dancespublicationsmap' VALUES (10005, 7745, 436, 105, 40);
INSERT INTO 'dancespublicationsmap' VALUES (626, 732, 436, 106, 40);
INSERT INTO 'dancespublicationsmap' VALUES (50, 60, 436, 128, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5837, 6764, 436, 159, 40);
INSERT INTO 'dancespublicationsmap' VALUES (948, 1097, 436, 160, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2727, 3142, 436, 161, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3730, 4288, 436, 162, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3235, 3725, 436, 163, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4457, 5147, 436, 164, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2927, 3368, 436, 165, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6609, 6536, 436, 166, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2814, 3239, 436, 167, 40);
INSERT INTO 'dancespublicationsmap' VALUES (811, 942, 436, 168, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4506, 5205, 436, 169, 40);
INSERT INTO 'dancespublicationsmap' VALUES (6265, 7263, 436, 170, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2346, 2703, 436, 171, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1173, 1359, 436, 172, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1683, 1952, 436, 173, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2000, 2309, 436, 174, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4700, 5439, 436, 175, 40);
INSERT INTO 'dancespublicationsmap' VALUES (868, 1007, 436, 176, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5957, 6902, 436, 177, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4601, 5316, 436, 178, 40);
INSERT INTO 'dancespublicationsmap' VALUES (10004, 1634, 436, 179, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5388, 6231, 436, 180, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4452, 5142, 436, 181, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4071, 4692, 436, 182, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2376, 2737, 436, 183, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3462, 3985, 436, 184, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3365, 3876, 436, 185, 40);
INSERT INTO 'dancespublicationsmap' VALUES (986, 1141, 436, 186, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1596, 1856, 436, 187, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4496, 5194, 436, 188, 40);
INSERT INTO 'dancespublicationsmap' VALUES (3611, 4154, 436, 189, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2176, 2508, 436, 190, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24836, 21231, 1669, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24837, 21232, 1669, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24838, 21233, 1669, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24839, 21234, 1669, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24840, 21235, 1669, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24834, 20455, 1669, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23703, 4043, 59, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23704, 4044, 59, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23705, 4283, 59, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23706, 4474, 59, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23707, 4680, 59, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23708, 5128, 59, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23709, 5699, 59, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24841, 21236, 1669, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24842, 21237, 1669, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24843, 21238, 1669, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24844, 21239, 1669, 10, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24845, 21240, 1669, 11, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24846, 21241, 1669, 12, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24847, 21242, 1669, 13, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24848, 21243, 1669, 14, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24849, 21244, 1669, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24835, 20080, 1669, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24850, 21245, 1669, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24851, 21246, 1669, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24852, 21247, 1669, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24853, 21248, 1669, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24854, 21249, 1669, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24855, 21250, 1669, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24856, 21251, 1669, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24857, 21252, 1669, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24858, 21253, 1669, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24859, 21254, 1669, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24860, 21255, 1669, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24861, 21256, 1669, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24862, 21257, 1669, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24863, 21258, 1669, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24864, 21259, 1669, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24865, 21260, 1669, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23710, 5707, 59, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24866, 21261, 1669, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24867, 21262, 1669, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23711, 5749, 59, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23712, 5799, 59, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23713, 5807, 59, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24868, 21263, 1669, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24869, 21264, 1669, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24870, 21265, 1669, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24871, 21266, 1669, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24872, 21267, 1669, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24873, 21268, 1669, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23714, 6037, 59, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23715, 6616, 59, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23716, 1607, 59, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23730, 3614, 59, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23717, 4045, 59, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23718, 15781, 59, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24874, 21269, 1669, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24875, 21270, 1669, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24876, 21271, 1669, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24877, 21272, 1669, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24878, 21273, 1669, 45, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24879, 21274, 1669, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24880, 21275, 1669, 47, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24881, 21276, 1669, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23719, 20209, 59, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23720, 14313, 59, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24827, 7013, 1668, 243, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24828, 7030, 1668, 244, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24829, 6967, 1668, 245, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24830, 7065, 1668, 246, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24831, 7174, 1668, 247, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24832, 7207, 1668, 248, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24833, 7261, 1668, 249, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24918, 18117, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24917, 16936, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24916, 18120, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24915, 18114, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24914, 21156, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24913, 15097, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24912, 18119, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24911, 18116, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24910, 18115, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24909, 18113, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24908, 18112, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24907, 18111, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24906, 13573, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24905, 18109, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24904, 8926, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24903, 13574, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24902, 20579, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24901, 18110, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24900, 15577, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12854, 10395, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12853, 11723, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11387, 8813, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11386, 8997, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11385, 9391, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12852, 11722, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12851, 10396, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12850, 9000, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12849, 11797, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12848, 9834, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12847, 11365, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12846, 11570, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12845, 11707, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (12844, 8999, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (11384, 9536, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (24919, 8104, 671, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2655, 7436, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (5588, 6465, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (2582, 2977, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (745, 869, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (697, 814, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (500, 581, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4311, 4985, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (1383, 1601, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (4242, 4899, 564, 0, 40);
INSERT INTO 'dancespublicationsmap' VALUES (14052, 12442, 977, 20, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14053, 12443, 977, 21, 20);
INSERT INTO 'dancespublicationsmap' VALUES (14054, 12444, 977, 22, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10862, 9583, 633, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10863, 9584, 633, 15, 20);
INSERT INTO 'dancespublicationsmap' VALUES (2965, 3409, 486, 11, 20);
INSERT INTO 'dancespublicationsmap' VALUES (5955, 6899, 483, 14, 20);
INSERT INTO 'dancespublicationsmap' VALUES (10039, 8732, 386, 5, 11);
INSERT INTO 'dancespublicationsmap' VALUES (24604, 1447, 1668, 50, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24605, 1488, 1668, 51, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24606, 11807, 1668, 52, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24607, 1577, 1668, 53, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24608, 1578, 1668, 54, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24609, 1595, 1668, 55, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24610, 1681, 1668, 56, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24611, 12817, 1668, 57, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24612, 1747, 1668, 58, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24613, 1751, 1668, 59, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24898, 21294, 59, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24899, 21295, 59, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23722, 15778, 59, 53, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23723, 2239, 59, 54, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23724, 8738, 59, 56, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23725, 10570, 59, 59, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23726, 5926, 59, 60, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23728, 8749, 59, 61, 30);
INSERT INTO 'dancespublicationsmap' VALUES (23727, 14314, 59, 62, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24882, 21280, 59, 71, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24883, 21281, 59, 72, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24884, 21282, 59, 73, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24885, 21283, 59, 74, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24886, 21284, 59, 75, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24887, 14303, 59, 76, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24888, 21285, 59, 77, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24889, 21286, 59, 78, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24890, 14308, 59, 79, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24891, 21287, 59, 80, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24892, 21288, 59, 81, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24897, 21289, 59, 82, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24893, 21290, 59, 83, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24894, 21291, 59, 84, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24895, 21292, 59, 85, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24896, 21293, 59, 86, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11486, 8646, 792, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11485, 8645, 792, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (11487, 7319, 792, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24614, 1811, 1668, 60, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24615, 1823, 1668, 61, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24616, 1838, 1668, 62, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24617, 1840, 1668, 63, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24618, 1891, 1668, 64, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24619, 1901, 1668, 65, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24620, 2021, 1668, 66, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24621, 2069, 1668, 67, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24622, 2079, 1668, 68, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24623, 12818, 1668, 69, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24624, 2170, 1668, 70, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24625, 2171, 1668, 71, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24626, 2180, 1668, 72, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24627, 2232, 1668, 73, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24628, 2276, 1668, 74, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24629, 2300, 1668, 75, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24630, 2305, 1668, 76, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24631, 2363, 1668, 77, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24632, 2383, 1668, 78, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24633, 2421, 1668, 79, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24634, 2427, 1668, 80, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24635, 2431, 1668, 81, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24636, 2485, 1668, 82, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24637, 2492, 1668, 83, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24638, 2534, 1668, 84, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24639, 2536, 1668, 85, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24640, 2544, 1668, 86, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24641, 2552, 1668, 87, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24920, 21320, 1670, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24921, 21321, 1670, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24922, 21322, 1670, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24923, 21323, 1670, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24924, 21324, 1670, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24925, 21326, 1670, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24926, 21327, 1670, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24927, 21328, 1670, 30, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24928, 21329, 1670, 32, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24929, 21331, 1670, 34, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24930, 21332, 1670, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24931, 21333, 1670, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24932, 21334, 1670, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2590, 2985, 462, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2632, 3034, 462, 16, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2653, 3055, 462, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2637, 3039, 462, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2763, 3179, 462, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2801, 3222, 462, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2844, 3272, 462, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3034, 3488, 462, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3127, 3598, 462, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3249, 3742, 462, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3602, 4143, 462, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3758, 4322, 462, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3804, 4378, 462, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5887, 6822, 462, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4851, 5613, 462, 35, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4888, 5655, 462, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5246, 6066, 462, 37, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5283, 6109, 462, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5291, 6117, 462, 39, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5322, 6156, 462, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5834, 6761, 462, 41, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5961, 6906, 462, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (6237, 7232, 462, 43, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3419, 3939, 460, 18, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4039, 4649, 460, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4386, 5066, 460, 20, 30);
INSERT INTO 'dancespublicationsmap' VALUES (3884, 4465, 460, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4470, 5163, 460, 22, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4527, 5230, 460, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (4790, 5544, 460, 24, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5061, 5852, 460, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (5117, 5916, 460, 26, 30);
INSERT INTO 'dancespublicationsmap' VALUES (179, 207, 460, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (2047, 2358, 460, 28, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24642, 2557, 1668, 88, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24643, 2595, 1668, 89, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24644, 2664, 1668, 90, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24645, 2671, 1668, 91, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24646, 7741, 1668, 92, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24647, 2698, 1668, 93, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24648, 2707, 1668, 94, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24649, 2727, 1668, 95, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24650, 15213, 1668, 96, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24651, 2752, 1668, 97, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24652, 2757, 1668, 98, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24661, 4621, 1668, 107, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24662, 2896, 1668, 108, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24663, 3019, 1668, 109, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24664, 3025, 1668, 110, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24665, 3057, 1668, 111, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24666, 3065, 1668, 112, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24667, 3066, 1668, 113, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24668, 3080, 1668, 114, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24669, 3101, 1668, 115, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24670, 3136, 1668, 116, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24671, 3147, 1668, 117, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24672, 3196, 1668, 118, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24673, 3266, 1668, 119, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24674, 3282, 1668, 120, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24675, 3285, 1668, 121, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24676, 3291, 1668, 122, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24677, 3314, 1668, 123, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24678, 3320, 1668, 124, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24679, 3325, 1668, 125, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24680, 3337, 1668, 126, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24695, 3786, 1668, 141, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24696, 3798, 1668, 142, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24697, 3805, 1668, 143, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24698, 3813, 1668, 144, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24699, 3828, 1668, 145, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24700, 3837, 1668, 146, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24701, 3842, 1668, 147, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24702, 3854, 1668, 148, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24703, 3857, 1668, 149, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24704, 3894, 1668, 150, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24705, 3909, 1668, 151, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24706, 3916, 1668, 152, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24707, 3943, 1668, 153, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24708, 12821, 1668, 154, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24709, 3968, 1668, 155, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24710, 3979, 1668, 156, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24711, 3980, 1668, 157, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24712, 4015, 1668, 158, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24713, 4018, 1668, 159, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24714, 4024, 1668, 160, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24715, 4033, 1668, 161, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24716, 4042, 1668, 162, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24717, 4192, 1668, 163, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24718, 4225, 1668, 164, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24719, 4231, 1668, 165, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24720, 4257, 1668, 166, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24721, 12822, 1668, 167, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24722, 4401, 1668, 168, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24723, 4427, 1668, 169, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24724, 4432, 1668, 170, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24725, 4445, 1668, 171, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24726, 4475, 1668, 172, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24727, 4489, 1668, 173, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24728, 4521, 1668, 174, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24729, 4585, 1668, 175, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24788, 6017, 1668, 204, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24789, 6030, 1668, 205, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24790, 6028, 1668, 206, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24793, 6103, 1668, 209, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24794, 6112, 1668, 210, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24797, 6239, 1668, 213, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24800, 5803, 1668, 216, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24801, 5819, 1668, 217, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24805, 6360, 1668, 221, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24806, 6424, 1668, 222, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24808, 6455, 1668, 224, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24811, 6558, 1668, 227, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24812, 6583, 1668, 228, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24815, 6679, 1668, 231, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24816, 6738, 1668, 232, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24817, 6781, 1668, 233, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24818, 6818, 1668, 234, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24819, 6838, 1668, 235, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24820, 6853, 1668, 236, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24821, 6902, 1668, 237, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24822, 6901, 1668, 238, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24823, 6947, 1668, 239, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24824, 6954, 1668, 240, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24825, 6995, 1668, 241, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24826, 13283, 1668, 242, 31);
INSERT INTO 'dancespublicationsmap' VALUES (24463, 19835, 1661, 15, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24464, 21116, 1661, 17, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24465, 21117, 1661, 19, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24466, 20674, 1661, 21, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24467, 21118, 1661, 23, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24468, 21119, 1661, 25, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24469, 21120, 1661, 27, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24470, 18275, 1661, 29, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24471, 21121, 1661, 31, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24472, 21122, 1661, 33, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24473, 18555, 1661, 36, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24474, 19637, 1661, 38, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24475, 18276, 1661, 40, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24476, 21123, 1661, 42, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24477, 21124, 1661, 44, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24478, 21125, 1661, 46, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24479, 19049, 1661, 48, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24480, 21001, 1661, 50, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24481, 21126, 1661, 52, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24482, 21127, 1661, 54, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24483, 19975, 1661, 56, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24484, 21128, 1661, 58, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24485, 21129, 1661, 60, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24486, 21130, 1661, 62, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24487, 21131, 1661, 64, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24488, 21132, 1661, 66, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24489, 21133, 1661, 68, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24490, 21134, 1661, 70, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24491, 19306, 1661, 72, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24492, 21135, 1661, 74, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24493, 21136, 1661, 78, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24494, 20665, 1661, 80, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24495, 20554, 1661, 82, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24496, 21137, 1661, 84, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24497, 19639, 1661, 86, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24498, 20773, 1661, 88, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24499, 21138, 1661, 90, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24500, 21139, 1661, 92, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24501, 20929, 1661, 94, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24502, 21140, 1661, 96, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24503, 19638, 1661, 99, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24504, 19640, 1661, 101, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24505, 19053, 1661, 103, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24506, 21141, 1661, 106, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24507, 18285, 1661, 108, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24508, 18341, 1661, 110, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24509, 21142, 1661, 112, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24510, 18277, 1661, 114, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24933, 2250, 1671, 1, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24934, 5462, 1671, 2, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24935, 3580, 1671, 3, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24936, 4968, 1671, 4, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24937, 4890, 1671, 5, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24938, 5062, 1671, 6, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24939, 2616, 1671, 7, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24940, 159, 1671, 8, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24941, 10920, 1671, 9, 30);
INSERT INTO 'dancespublicationsmap' VALUES (24942, 18272, 1671, 10, 30);


--
INSERT INTO 'dancesrecordingsmap' VALUES (1, 55, NULL, 4);
INSERT INTO 'dancesrecordingsmap' VALUES (2, 89, NULL, 5);
INSERT INTO 'dancesrecordingsmap' VALUES (4, 116, NULL, 7);
INSERT INTO 'dancesrecordingsmap' VALUES (6, 314, NULL, 9);
INSERT INTO 'dancesrecordingsmap' VALUES (7, 327, NULL, 10);
INSERT INTO 'dancesrecordingsmap' VALUES (58, 2004, NULL, 83);
INSERT INTO 'dancesrecordingsmap' VALUES (9, 352, NULL, 13);
INSERT INTO 'dancesrecordingsmap' VALUES (10, 392, NULL, 14);
INSERT INTO 'dancesrecordingsmap' VALUES (11, 441, NULL, 15);
INSERT INTO 'dancesrecordingsmap' VALUES (12, 445, NULL, 16);
INSERT INTO 'dancesrecordingsmap' VALUES (13, 522, NULL, 17);
INSERT INTO 'dancesrecordingsmap' VALUES (14, 541, NULL, 19);
INSERT INTO 'dancesrecordingsmap' VALUES (15, 549, NULL, 20);
INSERT INTO 'dancesrecordingsmap' VALUES (17, 584, NULL, 22);
INSERT INTO 'dancesrecordingsmap' VALUES (18, 633, NULL, 25);
INSERT INTO 'dancesrecordingsmap' VALUES (19, 658, NULL, 27);
INSERT INTO 'dancesrecordingsmap' VALUES (20, 682, NULL, 28);
INSERT INTO 'dancesrecordingsmap' VALUES (21, 743, NULL, 31);
INSERT INTO 'dancesrecordingsmap' VALUES (22, 769, NULL, 32);
INSERT INTO 'dancesrecordingsmap' VALUES (23, 779, NULL, 34);
INSERT INTO 'dancesrecordingsmap' VALUES (24, 805, NULL, 35);
INSERT INTO 'dancesrecordingsmap' VALUES (25, 848, NULL, 36);
INSERT INTO 'dancesrecordingsmap' VALUES (26, 873, NULL, 37);
INSERT INTO 'dancesrecordingsmap' VALUES (27, 887, NULL, 38);
INSERT INTO 'dancesrecordingsmap' VALUES (28, 899, NULL, 39);
INSERT INTO 'dancesrecordingsmap' VALUES (30, 909, NULL, 41);
INSERT INTO 'dancesrecordingsmap' VALUES (31, 936, NULL, 42);
INSERT INTO 'dancesrecordingsmap' VALUES (34, 1034, NULL, 46);
INSERT INTO 'dancesrecordingsmap' VALUES (35, 1100, NULL, 48);
INSERT INTO 'dancesrecordingsmap' VALUES (36, 1176, NULL, 49);
INSERT INTO 'dancesrecordingsmap' VALUES (37, 1210, NULL, 50);
INSERT INTO 'dancesrecordingsmap' VALUES (38, 1223, NULL, 52);
INSERT INTO 'dancesrecordingsmap' VALUES (39, 1244, NULL, 53);
INSERT INTO 'dancesrecordingsmap' VALUES (40, 1280, NULL, 54);
INSERT INTO 'dancesrecordingsmap' VALUES (41, 1358, NULL, 55);
INSERT INTO 'dancesrecordingsmap' VALUES (42, 1452, NULL, 56);
INSERT INTO 'dancesrecordingsmap' VALUES (44, 1501, NULL, 58);
INSERT INTO 'dancesrecordingsmap' VALUES (45, 1562, NULL, 59);
INSERT INTO 'dancesrecordingsmap' VALUES (46, 1582, NULL, 61);
INSERT INTO 'dancesrecordingsmap' VALUES (48, 1647, NULL, 64);
INSERT INTO 'dancesrecordingsmap' VALUES (49, 1677, NULL, 65);
INSERT INTO 'dancesrecordingsmap' VALUES (50, 1758, NULL, 67);
INSERT INTO 'dancesrecordingsmap' VALUES (51, 1777, NULL, 69);
INSERT INTO 'dancesrecordingsmap' VALUES (52, 1786, NULL, 70);
INSERT INTO 'dancesrecordingsmap' VALUES (53, 1792, NULL, 72);
INSERT INTO 'dancesrecordingsmap' VALUES (54, 1884, NULL, 77);
INSERT INTO 'dancesrecordingsmap' VALUES (55, 1891, NULL, 79);
INSERT INTO 'dancesrecordingsmap' VALUES (56, 1931, NULL, 80);
INSERT INTO 'dancesrecordingsmap' VALUES (57, 1961, NULL, 82);
INSERT INTO 'dancesrecordingsmap' VALUES (59, 2030, NULL, 85);
INSERT INTO 'dancesrecordingsmap' VALUES (60, 2166, NULL, 87);
INSERT INTO 'dancesrecordingsmap' VALUES (61, 2250, NULL, 88);
INSERT INTO 'dancesrecordingsmap' VALUES (62, 2350, NULL, 91);
INSERT INTO 'dancesrecordingsmap' VALUES (63, 2389, NULL, 93);
INSERT INTO 'dancesrecordingsmap' VALUES (64, 2409, NULL, 96);
INSERT INTO 'dancesrecordingsmap' VALUES (66, 2428, NULL, 103);
INSERT INTO 'dancesrecordingsmap' VALUES (67, 2436, NULL, 104);
INSERT INTO 'dancesrecordingsmap' VALUES (68, 2437, NULL, 105);
INSERT INTO 'dancesrecordingsmap' VALUES (69, 2498, NULL, 106);
INSERT INTO 'dancesrecordingsmap' VALUES (70, 2506, NULL, 108);
INSERT INTO 'dancesrecordingsmap' VALUES (71, 2593, NULL, 109);
INSERT INTO 'dancesrecordingsmap' VALUES (73, 2700, NULL, 112);
INSERT INTO 'dancesrecordingsmap' VALUES (74, 2745, NULL, 113);
INSERT INTO 'dancesrecordingsmap' VALUES (75, 2777, NULL, 114);
INSERT INTO 'dancesrecordingsmap' VALUES (77, 2812, NULL, 117);
INSERT INTO 'dancesrecordingsmap' VALUES (78, 2846, NULL, 119);
INSERT INTO 'dancesrecordingsmap' VALUES (79, 2956, NULL, 124);
INSERT INTO 'dancesrecordingsmap' VALUES (80, 2978, NULL, 125);
INSERT INTO 'dancesrecordingsmap' VALUES (81, 2979, NULL, 126);
INSERT INTO 'dancesrecordingsmap' VALUES (82, 3057, NULL, 127);
INSERT INTO 'dancesrecordingsmap' VALUES (83, 3104, NULL, 128);
INSERT INTO 'dancesrecordingsmap' VALUES (84, 3129, NULL, 130);
INSERT INTO 'dancesrecordingsmap' VALUES (87, 3246, NULL, 134);
INSERT INTO 'dancesrecordingsmap' VALUES (88, 3281, NULL, 136);
INSERT INTO 'dancesrecordingsmap' VALUES (89, 3323, NULL, 137);
INSERT INTO 'dancesrecordingsmap' VALUES (90, 3326, NULL, 139);
INSERT INTO 'dancesrecordingsmap' VALUES (91, 3336, NULL, 140);
INSERT INTO 'dancesrecordingsmap' VALUES (92, 3365, NULL, 143);
INSERT INTO 'dancesrecordingsmap' VALUES (3171, 7442, NULL, 4007);
INSERT INTO 'dancesrecordingsmap' VALUES (3172, 7499, NULL, 3996);
INSERT INTO 'dancesrecordingsmap' VALUES (3173, 7385, NULL, 4004);
INSERT INTO 'dancesrecordingsmap' VALUES (3174, 7355, NULL, 4014);
INSERT INTO 'dancesrecordingsmap' VALUES (3175, 2747, NULL, 4025);
INSERT INTO 'dancesrecordingsmap' VALUES (3176, 7546, NULL, 4027);
INSERT INTO 'dancesrecordingsmap' VALUES (3177, 8146, NULL, 4032);
INSERT INTO 'dancesrecordingsmap' VALUES (4303, 2409, NULL, 5270);
INSERT INTO 'dancesrecordingsmap' VALUES (4304, 2396, NULL, 5271);
INSERT INTO 'dancesrecordingsmap' VALUES (4305, 4548, NULL, 5272);
INSERT INTO 'dancesrecordingsmap' VALUES (4306, 7105, NULL, 5273);
INSERT INTO 'dancesrecordingsmap' VALUES (4307, 775, NULL, 5274);
INSERT INTO 'dancesrecordingsmap' VALUES (4308, 2747, NULL, 5276);
INSERT INTO 'dancesrecordingsmap' VALUES (4309, 909, NULL, 5277);
INSERT INTO 'dancesrecordingsmap' VALUES (4310, 22, NULL, 5278);
INSERT INTO 'dancesrecordingsmap' VALUES (4311, 5168, NULL, 5279);
INSERT INTO 'dancesrecordingsmap' VALUES (4312, 7105, NULL, 5280);
INSERT INTO 'dancesrecordingsmap' VALUES (4313, 3365, NULL, 5281);
INSERT INTO 'dancesrecordingsmap' VALUES (4314, 10066, NULL, 5282);
INSERT INTO 'dancesrecordingsmap' VALUES (4315, 10014, NULL, 5283);
INSERT INTO 'dancesrecordingsmap' VALUES (4316, 2747, NULL, 5284);
INSERT INTO 'dancesrecordingsmap' VALUES (4317, 56, NULL, 5285);
INSERT INTO 'dancesrecordingsmap' VALUES (4318, 6848, NULL, 5286);
INSERT INTO 'dancesrecordingsmap' VALUES (4319, 7286, NULL, 5287);
INSERT INTO 'dancesrecordingsmap' VALUES (4320, 7286, NULL, 5288);
INSERT INTO 'dancesrecordingsmap' VALUES (4321, 3700, NULL, 5289);
INSERT INTO 'dancesrecordingsmap' VALUES (4322, 10068, NULL, 5290);
INSERT INTO 'dancesrecordingsmap' VALUES (4323, 4491, NULL, 5291);
INSERT INTO 'dancesrecordingsmap' VALUES (4324, 9974, NULL, 5292);
INSERT INTO 'dancesrecordingsmap' VALUES (4325, 8703, NULL, 5293);
INSERT INTO 'dancesrecordingsmap' VALUES (4326, 9992, NULL, 5294);
INSERT INTO 'dancesrecordingsmap' VALUES (4327, 9993, NULL, 5295);
INSERT INTO 'dancesrecordingsmap' VALUES (4328, 9585, NULL, 5296);
INSERT INTO 'dancesrecordingsmap' VALUES (4329, 8088, NULL, 5297);
INSERT INTO 'dancesrecordingsmap' VALUES (4330, 9998, NULL, 5298);
INSERT INTO 'dancesrecordingsmap' VALUES (4331, 9999, NULL, 5299);
INSERT INTO 'dancesrecordingsmap' VALUES (4332, 10002, NULL, 5300);
INSERT INTO 'dancesrecordingsmap' VALUES (4333, 10003, NULL, 5301);
INSERT INTO 'dancesrecordingsmap' VALUES (4334, 10004, NULL, 5302);
INSERT INTO 'dancesrecordingsmap' VALUES (4335, 905, NULL, 5303);
INSERT INTO 'dancesrecordingsmap' VALUES (4336, 5504, NULL, 5304);
INSERT INTO 'dancesrecordingsmap' VALUES (4337, 7090, NULL, 5305);
INSERT INTO 'dancesrecordingsmap' VALUES (4338, 1544, NULL, 5306);
INSERT INTO 'dancesrecordingsmap' VALUES (4339, 594, NULL, 5307);
INSERT INTO 'dancesrecordingsmap' VALUES (4340, 5927, NULL, 5309);
INSERT INTO 'dancesrecordingsmap' VALUES (8046, 2250, NULL, 8847);
INSERT INTO 'dancesrecordingsmap' VALUES (8051, 14419, NULL, 6468);
INSERT INTO 'dancesrecordingsmap' VALUES (8052, 14425, NULL, 8871);
INSERT INTO 'dancesrecordingsmap' VALUES (8065, 6152, NULL, 8884);
INSERT INTO 'dancesrecordingsmap' VALUES (93, 3428, NULL, 144);
INSERT INTO 'dancesrecordingsmap' VALUES (94, 3529, NULL, 147);
INSERT INTO 'dancesrecordingsmap' VALUES (95, 3558, NULL, 148);
INSERT INTO 'dancesrecordingsmap' VALUES (96, 3562, NULL, 149);
INSERT INTO 'dancesrecordingsmap' VALUES (97, 3575, NULL, 150);
INSERT INTO 'dancesrecordingsmap' VALUES (99, 3580, NULL, 152);
INSERT INTO 'dancesrecordingsmap' VALUES (100, 3585, NULL, 154);
INSERT INTO 'dancesrecordingsmap' VALUES (101, 3609, NULL, 155);
INSERT INTO 'dancesrecordingsmap' VALUES (102, 3635, NULL, 156);
INSERT INTO 'dancesrecordingsmap' VALUES (103, 3637, NULL, 157);
INSERT INTO 'dancesrecordingsmap' VALUES (104, 3651, NULL, 158);
INSERT INTO 'dancesrecordingsmap' VALUES (105, 3672, NULL, 159);
INSERT INTO 'dancesrecordingsmap' VALUES (106, 3680, NULL, 160);
INSERT INTO 'dancesrecordingsmap' VALUES (107, 3711, NULL, 161);
INSERT INTO 'dancesrecordingsmap' VALUES (108, 3737, NULL, 162);
INSERT INTO 'dancesrecordingsmap' VALUES (109, 3743, NULL, 163);
INSERT INTO 'dancesrecordingsmap' VALUES (110, 3774, NULL, 164);
INSERT INTO 'dancesrecordingsmap' VALUES (112, 3802, NULL, 166);
INSERT INTO 'dancesrecordingsmap' VALUES (113, 3834, NULL, 168);
INSERT INTO 'dancesrecordingsmap' VALUES (114, 3883, NULL, 171);
INSERT INTO 'dancesrecordingsmap' VALUES (115, 3921, NULL, 173);
INSERT INTO 'dancesrecordingsmap' VALUES (116, 3963, NULL, 174);
INSERT INTO 'dancesrecordingsmap' VALUES (117, 3980, NULL, 175);
INSERT INTO 'dancesrecordingsmap' VALUES (118, 3986, NULL, 177);
INSERT INTO 'dancesrecordingsmap' VALUES (119, 4014, NULL, 178);
INSERT INTO 'dancesrecordingsmap' VALUES (120, 4015, NULL, 180);
INSERT INTO 'dancesrecordingsmap' VALUES (121, 4032, NULL, 181);
INSERT INTO 'dancesrecordingsmap' VALUES (123, 4044, NULL, 183);
INSERT INTO 'dancesrecordingsmap' VALUES (124, 4046, NULL, 184);
INSERT INTO 'dancesrecordingsmap' VALUES (125, 4064, NULL, 186);
INSERT INTO 'dancesrecordingsmap' VALUES (126, 4102, NULL, 187);
INSERT INTO 'dancesrecordingsmap' VALUES (127, 4106, NULL, 188);
INSERT INTO 'dancesrecordingsmap' VALUES (128, 4155, NULL, 193);
INSERT INTO 'dancesrecordingsmap' VALUES (129, 4239, NULL, 194);
INSERT INTO 'dancesrecordingsmap' VALUES (130, 4271, NULL, 195);
INSERT INTO 'dancesrecordingsmap' VALUES (131, 4282, NULL, 196);
INSERT INTO 'dancesrecordingsmap' VALUES (133, 4293, NULL, 199);
INSERT INTO 'dancesrecordingsmap' VALUES (135, 4358, NULL, 201);
INSERT INTO 'dancesrecordingsmap' VALUES (136, 4359, NULL, 202);
INSERT INTO 'dancesrecordingsmap' VALUES (47, 1624, NULL, 62);
INSERT INTO 'dancesrecordingsmap' VALUES (32, 985, NULL, 43);
INSERT INTO 'dancesrecordingsmap' VALUES (29, 905, NULL, 40);
INSERT INTO 'dancesrecordingsmap' VALUES (111, 3777, NULL, 165);
INSERT INTO 'dancesrecordingsmap' VALUES (76, 2781, NULL, 116);
INSERT INTO 'dancesrecordingsmap' VALUES (33, 1019, NULL, 45);
INSERT INTO 'dancesrecordingsmap' VALUES (86, 3225, NULL, 133);
INSERT INTO 'dancesrecordingsmap' VALUES (16, 578, NULL, 21);
INSERT INTO 'dancesrecordingsmap' VALUES (43, 1480, NULL, 57);
INSERT INTO 'dancesrecordingsmap' VALUES (137, 4365, NULL, 203);
INSERT INTO 'dancesrecordingsmap' VALUES (5, 140, NULL, 8);
INSERT INTO 'dancesrecordingsmap' VALUES (122, 4043, NULL, 182);
INSERT INTO 'dancesrecordingsmap' VALUES (98, 3577, NULL, 151);
INSERT INTO 'dancesrecordingsmap' VALUES (65, 2419, NULL, 97);
INSERT INTO 'dancesrecordingsmap' VALUES (139, 4424, NULL, 208);
INSERT INTO 'dancesrecordingsmap' VALUES (134, 4324, NULL, 200);
INSERT INTO 'dancesrecordingsmap' VALUES (132, 4283, NULL, 197);
INSERT INTO 'dancesrecordingsmap' VALUES (138, 4404, NULL, 207);
INSERT INTO 'dancesrecordingsmap' VALUES (140, 4474, NULL, 210);
INSERT INTO 'dancesrecordingsmap' VALUES (141, 4484, NULL, 211);
INSERT INTO 'dancesrecordingsmap' VALUES (142, 4491, NULL, 213);
INSERT INTO 'dancesrecordingsmap' VALUES (143, 4543, NULL, 214);
INSERT INTO 'dancesrecordingsmap' VALUES (144, 4548, NULL, 215);
INSERT INTO 'dancesrecordingsmap' VALUES (145, 4555, NULL, 216);
INSERT INTO 'dancesrecordingsmap' VALUES (146, 4618, NULL, 217);
INSERT INTO 'dancesrecordingsmap' VALUES (147, 4641, NULL, 218);
INSERT INTO 'dancesrecordingsmap' VALUES (148, 4646, NULL, 221);
INSERT INTO 'dancesrecordingsmap' VALUES (149, 4661, NULL, 222);
INSERT INTO 'dancesrecordingsmap' VALUES (150, 4680, NULL, 223);
INSERT INTO 'dancesrecordingsmap' VALUES (151, 4728, NULL, 224);
INSERT INTO 'dancesrecordingsmap' VALUES (152, 4744, NULL, 225);
INSERT INTO 'dancesrecordingsmap' VALUES (154, 4803, NULL, 227);
INSERT INTO 'dancesrecordingsmap' VALUES (155, 4805, NULL, 228);
INSERT INTO 'dancesrecordingsmap' VALUES (156, 4827, NULL, 229);
INSERT INTO 'dancesrecordingsmap' VALUES (158, 4890, NULL, 231);
INSERT INTO 'dancesrecordingsmap' VALUES (159, 4925, NULL, 233);
INSERT INTO 'dancesrecordingsmap' VALUES (160, 4927, NULL, 234);
INSERT INTO 'dancesrecordingsmap' VALUES (161, 4968, NULL, 236);
INSERT INTO 'dancesrecordingsmap' VALUES (162, 4998, NULL, 241);
INSERT INTO 'dancesrecordingsmap' VALUES (163, 5128, NULL, 244);
INSERT INTO 'dancesrecordingsmap' VALUES (164, 5198, NULL, 247);
INSERT INTO 'dancesrecordingsmap' VALUES (165, 5207, NULL, 250);
INSERT INTO 'dancesrecordingsmap' VALUES (166, 5208, NULL, 251);
INSERT INTO 'dancesrecordingsmap' VALUES (168, 5296, NULL, 255);
INSERT INTO 'dancesrecordingsmap' VALUES (169, 5308, NULL, 256);
INSERT INTO 'dancesrecordingsmap' VALUES (170, 5310, NULL, 257);
INSERT INTO 'dancesrecordingsmap' VALUES (171, 5320, NULL, 258);
INSERT INTO 'dancesrecordingsmap' VALUES (172, 5330, NULL, 260);
INSERT INTO 'dancesrecordingsmap' VALUES (173, 5345, NULL, 261);
INSERT INTO 'dancesrecordingsmap' VALUES (174, 5422, NULL, 265);
INSERT INTO 'dancesrecordingsmap' VALUES (176, 5525, NULL, 267);
INSERT INTO 'dancesrecordingsmap' VALUES (177, 5529, NULL, 268);
INSERT INTO 'dancesrecordingsmap' VALUES (178, 5552, NULL, 271);
INSERT INTO 'dancesrecordingsmap' VALUES (179, 5555, NULL, 272);
INSERT INTO 'dancesrecordingsmap' VALUES (180, 5637, NULL, 273);
INSERT INTO 'dancesrecordingsmap' VALUES (181, 5699, NULL, 275);
INSERT INTO 'dancesrecordingsmap' VALUES (182, 5703, NULL, 276);
INSERT INTO 'dancesrecordingsmap' VALUES (183, 5707, NULL, 277);
INSERT INTO 'dancesrecordingsmap' VALUES (184, 5713, NULL, 278);
INSERT INTO 'dancesrecordingsmap' VALUES (185, 5749, NULL, 279);
INSERT INTO 'dancesrecordingsmap' VALUES (3143, 216, NULL, 3949);
INSERT INTO 'dancesrecordingsmap' VALUES (3144, 8747, NULL, 3950);
INSERT INTO 'dancesrecordingsmap' VALUES (3145, 8748, NULL, 3951);
INSERT INTO 'dancesrecordingsmap' VALUES (3146, 8749, NULL, 3952);
INSERT INTO 'dancesrecordingsmap' VALUES (3147, 8750, NULL, 3953);
INSERT INTO 'dancesrecordingsmap' VALUES (3148, 8751, NULL, 3954);
INSERT INTO 'dancesrecordingsmap' VALUES (3149, 8752, NULL, 3955);
INSERT INTO 'dancesrecordingsmap' VALUES (3150, 8753, NULL, 3956);
INSERT INTO 'dancesrecordingsmap' VALUES (3151, 1931, NULL, 3958);
INSERT INTO 'dancesrecordingsmap' VALUES (3152, 2745, NULL, 3960);
INSERT INTO 'dancesrecordingsmap' VALUES (3153, 5239, NULL, 3961);
INSERT INTO 'dancesrecordingsmap' VALUES (3154, 418, NULL, 3961);
INSERT INTO 'dancesrecordingsmap' VALUES (3155, 540, NULL, 3961);
INSERT INTO 'dancesrecordingsmap' VALUES (3156, 6483, NULL, 3961);
INSERT INTO 'dancesrecordingsmap' VALUES (3157, 6614, NULL, 3961);
INSERT INTO 'dancesrecordingsmap' VALUES (3158, 4227, NULL, 3963);
INSERT INTO 'dancesrecordingsmap' VALUES (3159, 1562, NULL, 3968);
INSERT INTO 'dancesrecordingsmap' VALUES (3160, 4633, NULL, 3974);
INSERT INTO 'dancesrecordingsmap' VALUES (3161, 7553, NULL, 3975);
INSERT INTO 'dancesrecordingsmap' VALUES (3162, 2498, NULL, 3976);
INSERT INTO 'dancesrecordingsmap' VALUES (3163, 8148, NULL, 3977);
INSERT INTO 'dancesrecordingsmap' VALUES (3164, 7548, NULL, 3978);
INSERT INTO 'dancesrecordingsmap' VALUES (3165, 2250, NULL, 3979);
INSERT INTO 'dancesrecordingsmap' VALUES (3166, 658, NULL, 3989);
INSERT INTO 'dancesrecordingsmap' VALUES (3167, 2389, NULL, 4020);
INSERT INTO 'dancesrecordingsmap' VALUES (3168, 7511, NULL, 4003);
INSERT INTO 'dancesrecordingsmap' VALUES (3169, 7352, NULL, 3997);
INSERT INTO 'dancesrecordingsmap' VALUES (3170, 7438, NULL, 3995);
INSERT INTO 'dancesrecordingsmap' VALUES (3178, 441, NULL, 4034);
INSERT INTO 'dancesrecordingsmap' VALUES (3179, 2428, NULL, 4035);
INSERT INTO 'dancesrecordingsmap' VALUES (3180, 1624, NULL, 4036);
INSERT INTO 'dancesrecordingsmap' VALUES (3181, 6052, NULL, 4037);
INSERT INTO 'dancesrecordingsmap' VALUES (3182, 1966, NULL, 4038);
INSERT INTO 'dancesrecordingsmap' VALUES (3183, 1792, NULL, 4039);
INSERT INTO 'dancesrecordingsmap' VALUES (3184, 1677, NULL, 4040);
INSERT INTO 'dancesrecordingsmap' VALUES (3185, 2846, NULL, 4041);
INSERT INTO 'dancesrecordingsmap' VALUES (3186, 223, NULL, 4042);
INSERT INTO 'dancesrecordingsmap' VALUES (3187, 335, NULL, 4043);
INSERT INTO 'dancesrecordingsmap' VALUES (3188, 7542, NULL, 1789);
INSERT INTO 'dancesrecordingsmap' VALUES (3189, 8782, NULL, 4046);
INSERT INTO 'dancesrecordingsmap' VALUES (199, 6052, NULL, 317);
INSERT INTO 'dancesrecordingsmap' VALUES (8047, 4555, NULL, 8848);
INSERT INTO 'dancesrecordingsmap' VALUES (8053, 14426, NULL, 8872);
INSERT INTO 'dancesrecordingsmap' VALUES (8066, 7147, NULL, 8885);
INSERT INTO 'dancesrecordingsmap' VALUES (186, 5794, NULL, 281);
INSERT INTO 'dancesrecordingsmap' VALUES (188, 5802, NULL, 283);
INSERT INTO 'dancesrecordingsmap' VALUES (189, 5807, NULL, 284);
INSERT INTO 'dancesrecordingsmap' VALUES (190, 5860, NULL, 285);
INSERT INTO 'dancesrecordingsmap' VALUES (191, 5889, NULL, 286);
INSERT INTO 'dancesrecordingsmap' VALUES (192, 5915, NULL, 287);
INSERT INTO 'dancesrecordingsmap' VALUES (193, 5936, NULL, 289);
INSERT INTO 'dancesrecordingsmap' VALUES (194, 5964, NULL, 290);
INSERT INTO 'dancesrecordingsmap' VALUES (195, 5982, NULL, 293);
INSERT INTO 'dancesrecordingsmap' VALUES (196, 6010, NULL, 312);
INSERT INTO 'dancesrecordingsmap' VALUES (197, 6037, NULL, 314);
INSERT INTO 'dancesrecordingsmap' VALUES (198, 6048, NULL, 315);
INSERT INTO 'dancesrecordingsmap' VALUES (200, 6064, NULL, 318);
INSERT INTO 'dancesrecordingsmap' VALUES (201, 6091, NULL, 319);
INSERT INTO 'dancesrecordingsmap' VALUES (202, 6130, NULL, 81);
INSERT INTO 'dancesrecordingsmap' VALUES (205, 6205, NULL, 324);
INSERT INTO 'dancesrecordingsmap' VALUES (206, 6359, NULL, 328);
INSERT INTO 'dancesrecordingsmap' VALUES (207, 6373, NULL, 331);
INSERT INTO 'dancesrecordingsmap' VALUES (208, 6380, NULL, 333);
INSERT INTO 'dancesrecordingsmap' VALUES (209, 6420, NULL, 334);
INSERT INTO 'dancesrecordingsmap' VALUES (212, 6523, NULL, 339);
INSERT INTO 'dancesrecordingsmap' VALUES (213, 6532, NULL, 1);
INSERT INTO 'dancesrecordingsmap' VALUES (214, 6711, NULL, 343);
INSERT INTO 'dancesrecordingsmap' VALUES (215, 6712, NULL, 344);
INSERT INTO 'dancesrecordingsmap' VALUES (216, 6748, NULL, 345);
INSERT INTO 'dancesrecordingsmap' VALUES (217, 6797, NULL, 346);
INSERT INTO 'dancesrecordingsmap' VALUES (219, 6915, NULL, 350);
INSERT INTO 'dancesrecordingsmap' VALUES (220, 6957, NULL, 353);
INSERT INTO 'dancesrecordingsmap' VALUES (221, 6972, NULL, 354);
INSERT INTO 'dancesrecordingsmap' VALUES (222, 7037, NULL, 355);
INSERT INTO 'dancesrecordingsmap' VALUES (223, 7055, NULL, 358);
INSERT INTO 'dancesrecordingsmap' VALUES (224, 7061, NULL, 361);
INSERT INTO 'dancesrecordingsmap' VALUES (225, 7073, NULL, 362);
INSERT INTO 'dancesrecordingsmap' VALUES (227, 7147, NULL, 364);
INSERT INTO 'dancesrecordingsmap' VALUES (228, 7173, NULL, 366);
INSERT INTO 'dancesrecordingsmap' VALUES (229, 7219, NULL, 368);
INSERT INTO 'dancesrecordingsmap' VALUES (230, 7520, NULL, 326);
INSERT INTO 'dancesrecordingsmap' VALUES (231, 7542, NULL, 90);
INSERT INTO 'dancesrecordingsmap' VALUES (233, 7544, NULL, 342);
INSERT INTO 'dancesrecordingsmap' VALUES (235, 7546, NULL, 98);
INSERT INTO 'dancesrecordingsmap' VALUES (236, 7547, NULL, 238);
INSERT INTO 'dancesrecordingsmap' VALUES (237, 7548, NULL, 121);
INSERT INTO 'dancesrecordingsmap' VALUES (238, 7550, NULL, 341);
INSERT INTO 'dancesrecordingsmap' VALUES (239, 7553, NULL, 44);
INSERT INTO 'dancesrecordingsmap' VALUES (240, 7554, NULL, 262);
INSERT INTO 'dancesrecordingsmap' VALUES (241, 7555, NULL, 73);
INSERT INTO 'dancesrecordingsmap' VALUES (242, 3834, NULL, 169);
INSERT INTO 'dancesrecordingsmap' VALUES (243, 3802, NULL, 167);
INSERT INTO 'dancesrecordingsmap' VALUES (244, 1931, NULL, 81);
INSERT INTO 'dancesrecordingsmap' VALUES (245, 522, NULL, 18);
INSERT INTO 'dancesrecordingsmap' VALUES (246, 5982, NULL, 294);
INSERT INTO 'dancesrecordingsmap' VALUES (247, 6420, NULL, 335);
INSERT INTO 'dancesrecordingsmap' VALUES (248, 6373, NULL, 332);
INSERT INTO 'dancesrecordingsmap' VALUES (249, 4890, NULL, 232);
INSERT INTO 'dancesrecordingsmap' VALUES (250, 1624, NULL, 63);
INSERT INTO 'dancesrecordingsmap' VALUES (251, 5529, NULL, 270);
INSERT INTO 'dancesrecordingsmap' VALUES (252, 4968, NULL, 237);
INSERT INTO 'dancesrecordingsmap' VALUES (254, 6048, NULL, 316);
INSERT INTO 'dancesrecordingsmap' VALUES (255, 5239, NULL, 253);
INSERT INTO 'dancesrecordingsmap' VALUES (256, 4484, NULL, 212);
INSERT INTO 'dancesrecordingsmap' VALUES (257, 1884, NULL, 78);
INSERT INTO 'dancesrecordingsmap' VALUES (258, 769, NULL, 33);
INSERT INTO 'dancesrecordingsmap' VALUES (259, 6091, NULL, 320);
INSERT INTO 'dancesrecordingsmap' VALUES (260, 3336, NULL, 141);
INSERT INTO 'dancesrecordingsmap' VALUES (262, 2004, NULL, 84);
INSERT INTO 'dancesrecordingsmap' VALUES (264, 1881, NULL, 76);
INSERT INTO 'dancesrecordingsmap' VALUES (265, 4014, NULL, 179);
INSERT INTO 'dancesrecordingsmap' VALUES (266, 633, NULL, 26);
INSERT INTO 'dancesrecordingsmap' VALUES (267, 3651, NULL, 378);
INSERT INTO 'dancesrecordingsmap' VALUES (269, 7546, NULL, 102);
INSERT INTO 'dancesrecordingsmap' VALUES (270, 7552, NULL, 204);
INSERT INTO 'dancesrecordingsmap' VALUES (271, 6359, NULL, 330);
INSERT INTO 'dancesrecordingsmap' VALUES (272, 1562, NULL, 60);
INSERT INTO 'dancesrecordingsmap' VALUES (273, 6915, NULL, 351);
INSERT INTO 'dancesrecordingsmap' VALUES (274, 7546, NULL, 101);
INSERT INTO 'dancesrecordingsmap' VALUES (275, 4641, NULL, 219);
INSERT INTO 'dancesrecordingsmap' VALUES (276, 7147, NULL, 365);
INSERT INTO 'dancesrecordingsmap' VALUES (3190, 8786, NULL, 2498);
INSERT INTO 'dancesrecordingsmap' VALUES (175, 5497, NULL, 266);
INSERT INTO 'dancesrecordingsmap' VALUES (261, 7520, NULL, 327);
INSERT INTO 'dancesrecordingsmap' VALUES (226, 7139, NULL, 363);
INSERT INTO 'dancesrecordingsmap' VALUES (153, 4765, NULL, 226);
INSERT INTO 'dancesrecordingsmap' VALUES (253, 7055, NULL, 359);
INSERT INTO 'dancesrecordingsmap' VALUES (277, 6010, NULL, 313);
INSERT INTO 'dancesrecordingsmap' VALUES (3192, 8785, NULL, 1890);
INSERT INTO 'dancesrecordingsmap' VALUES (3193, 8787, NULL, 705);
INSERT INTO 'dancesrecordingsmap' VALUES (157, 4830, NULL, 230);
INSERT INTO 'dancesrecordingsmap' VALUES (263, 7055, NULL, 360);
INSERT INTO 'dancesrecordingsmap' VALUES (203, 6152, NULL, 322);
INSERT INTO 'dancesrecordingsmap' VALUES (232, 7543, NULL, 206);
INSERT INTO 'dancesrecordingsmap' VALUES (211, 6505, NULL, 337);
INSERT INTO 'dancesrecordingsmap' VALUES (218, 6817, NULL, 347);
INSERT INTO 'dancesrecordingsmap' VALUES (3194, 8788, NULL, 1335);
INSERT INTO 'dancesrecordingsmap' VALUES (3195, 8789, NULL, 1393);
INSERT INTO 'dancesrecordingsmap' VALUES (268, 6505, NULL, 338);
INSERT INTO 'dancesrecordingsmap' VALUES (210, 6484, NULL, 336);
INSERT INTO 'dancesrecordingsmap' VALUES (187, 5799, NULL, 282);
INSERT INTO 'dancesrecordingsmap' VALUES (204, 6186, NULL, 323);
INSERT INTO 'dancesrecordingsmap' VALUES (3197, 8791, NULL, 3329);
INSERT INTO 'dancesrecordingsmap' VALUES (3198, 353, NULL, 4047);
INSERT INTO 'dancesrecordingsmap' VALUES (3199, 6420, NULL, 4048);
INSERT INTO 'dancesrecordingsmap' VALUES (3200, 3236, NULL, 4049);
INSERT INTO 'dancesrecordingsmap' VALUES (3201, 32, NULL, 4050);
INSERT INTO 'dancesrecordingsmap' VALUES (3202, 7546, NULL, 4051);
INSERT INTO 'dancesrecordingsmap' VALUES (3203, 7548, NULL, 4052);
INSERT INTO 'dancesrecordingsmap' VALUES (3204, 2781, NULL, 4053);
INSERT INTO 'dancesrecordingsmap' VALUES (3205, 4239, NULL, 4054);
INSERT INTO 'dancesrecordingsmap' VALUES (3207, 7546, NULL, 4057);
INSERT INTO 'dancesrecordingsmap' VALUES (3208, 2494, NULL, 4058);
INSERT INTO 'dancesrecordingsmap' VALUES (3209, 4491, NULL, 4059);
INSERT INTO 'dancesrecordingsmap' VALUES (3211, 6900, NULL, 4061);
INSERT INTO 'dancesrecordingsmap' VALUES (3212, 7553, NULL, 4063);
INSERT INTO 'dancesrecordingsmap' VALUES (3213, 7139, NULL, 4064);
INSERT INTO 'dancesrecordingsmap' VALUES (3214, 3743, NULL, 4066);
INSERT INTO 'dancesrecordingsmap' VALUES (3216, 4014, NULL, 4073);
INSERT INTO 'dancesrecordingsmap' VALUES (3217, 6915, NULL, 4074);
INSERT INTO 'dancesrecordingsmap' VALUES (3218, 2717, NULL, 4075);
INSERT INTO 'dancesrecordingsmap' VALUES (3219, 6037, NULL, 4076);
INSERT INTO 'dancesrecordingsmap' VALUES (3220, 7546, NULL, 4079);
INSERT INTO 'dancesrecordingsmap' VALUES (3221, 8142, NULL, 555);
INSERT INTO 'dancesrecordingsmap' VALUES (3222, 7546, NULL, 4083);
INSERT INTO 'dancesrecordingsmap' VALUES (3223, 3365, NULL, 4084);
INSERT INTO 'dancesrecordingsmap' VALUES (3224, 4633, NULL, 4087);
INSERT INTO 'dancesrecordingsmap' VALUES (3225, 4461, NULL, 4088);
INSERT INTO 'dancesrecordingsmap' VALUES (3226, 4663, NULL, 4090);
INSERT INTO 'dancesrecordingsmap' VALUES (3227, 7548, NULL, 4092);
INSERT INTO 'dancesrecordingsmap' VALUES (3228, 7546, NULL, 4094);
INSERT INTO 'dancesrecordingsmap' VALUES (3229, 1931, NULL, 4095);
INSERT INTO 'dancesrecordingsmap' VALUES (3230, 2745, NULL, 4097);
INSERT INTO 'dancesrecordingsmap' VALUES (3231, 1782, NULL, 4098);
INSERT INTO 'dancesrecordingsmap' VALUES (3232, 1792, NULL, 4099);
INSERT INTO 'dancesrecordingsmap' VALUES (3233, 5964, NULL, 4100);
INSERT INTO 'dancesrecordingsmap' VALUES (8048, 2956, NULL, 8849);
INSERT INTO 'dancesrecordingsmap' VALUES (8054, 14427, NULL, 8873);
INSERT INTO 'dancesrecordingsmap' VALUES (8067, 9106, NULL, 8886);
INSERT INTO 'dancesrecordingsmap' VALUES (278, 2777, NULL, 115);
INSERT INTO 'dancesrecordingsmap' VALUES (279, 5407, NULL, 264);
INSERT INTO 'dancesrecordingsmap' VALUES (280, 3323, NULL, 138);
INSERT INTO 'dancesrecordingsmap' VALUES (281, 4106, NULL, 189);
INSERT INTO 'dancesrecordingsmap' VALUES (282, 5529, NULL, 269);
INSERT INTO 'dancesrecordingsmap' VALUES (283, 3980, NULL, 176);
INSERT INTO 'dancesrecordingsmap' VALUES (284, 1758, NULL, 68);
INSERT INTO 'dancesrecordingsmap' VALUES (285, 5915, NULL, 288);
INSERT INTO 'dancesrecordingsmap' VALUES (286, 7546, NULL, 99);
INSERT INTO 'dancesrecordingsmap' VALUES (287, 4046, NULL, 185);
INSERT INTO 'dancesrecordingsmap' VALUES (288, 1677, NULL, 66);
INSERT INTO 'dancesrecordingsmap' VALUES (289, 7546, NULL, 100);
INSERT INTO 'dancesrecordingsmap' VALUES (290, 2389, NULL, 94);
INSERT INTO 'dancesrecordingsmap' VALUES (291, 3580, NULL, 153);
INSERT INTO 'dancesrecordingsmap' VALUES (292, 7548, NULL, 122);
INSERT INTO 'dancesrecordingsmap' VALUES (293, 4844, NULL, 381);
INSERT INTO 'dancesrecordingsmap' VALUES (294, 5898, NULL, 384);
INSERT INTO 'dancesrecordingsmap' VALUES (295, 221, NULL, 388);
INSERT INTO 'dancesrecordingsmap' VALUES (296, 2267, NULL, 389);
INSERT INTO 'dancesrecordingsmap' VALUES (297, 584, NULL, 393);
INSERT INTO 'dancesrecordingsmap' VALUES (298, 4424, NULL, 400);
INSERT INTO 'dancesrecordingsmap' VALUES (301, 7553, NULL, 407);
INSERT INTO 'dancesrecordingsmap' VALUES (303, 816, NULL, 321);
INSERT INTO 'dancesrecordingsmap' VALUES (304, 894, NULL, 375);
INSERT INTO 'dancesrecordingsmap' VALUES (305, 5860, NULL, 376);
INSERT INTO 'dancesrecordingsmap' VALUES (306, 2846, NULL, 377);
INSERT INTO 'dancesrecordingsmap' VALUES (307, 3336, NULL, 409);
INSERT INTO 'dancesrecordingsmap' VALUES (308, 1405, NULL, 410);
INSERT INTO 'dancesrecordingsmap' VALUES (310, 1478, NULL, 412);
INSERT INTO 'dancesrecordingsmap' VALUES (311, 4929, NULL, 413);
INSERT INTO 'dancesrecordingsmap' VALUES (312, 1838, NULL, 414);
INSERT INTO 'dancesrecordingsmap' VALUES (313, 398, NULL, 415);
INSERT INTO 'dancesrecordingsmap' VALUES (314, 462, NULL, 419);
INSERT INTO 'dancesrecordingsmap' VALUES (315, 5446, NULL, 420);
INSERT INTO 'dancesrecordingsmap' VALUES (316, 895, NULL, 421);
INSERT INTO 'dancesrecordingsmap' VALUES (317, 7180, NULL, 422);
INSERT INTO 'dancesrecordingsmap' VALUES (318, 6010, NULL, 423);
INSERT INTO 'dancesrecordingsmap' VALUES (319, 4927, NULL, 424);
INSERT INTO 'dancesrecordingsmap' VALUES (320, 658, NULL, 425);
INSERT INTO 'dancesrecordingsmap' VALUES (323, 1792, NULL, 428);
INSERT INTO 'dancesrecordingsmap' VALUES (324, 5703, NULL, 429);
INSERT INTO 'dancesrecordingsmap' VALUES (325, 5243, NULL, 430);
INSERT INTO 'dancesrecordingsmap' VALUES (326, 4894, NULL, 431);
INSERT INTO 'dancesrecordingsmap' VALUES (327, 1838, NULL, 432);
INSERT INTO 'dancesrecordingsmap' VALUES (328, 816, NULL, 433);
INSERT INTO 'dancesrecordingsmap' VALUES (329, 6532, NULL, 435);
INSERT INTO 'dancesrecordingsmap' VALUES (330, 6420, NULL, 436);
INSERT INTO 'dancesrecordingsmap' VALUES (332, 3636, NULL, 438);
INSERT INTO 'dancesrecordingsmap' VALUES (333, 6161, NULL, 439);
INSERT INTO 'dancesrecordingsmap' VALUES (334, 4015, NULL, 440);
INSERT INTO 'dancesrecordingsmap' VALUES (336, 6048, NULL, 442);
INSERT INTO 'dancesrecordingsmap' VALUES (337, 842, NULL, 443);
INSERT INTO 'dancesrecordingsmap' VALUES (338, 7055, NULL, 444);
INSERT INTO 'dancesrecordingsmap' VALUES (339, 5204, NULL, 445);
INSERT INTO 'dancesrecordingsmap' VALUES (340, 4857, NULL, 446);
INSERT INTO 'dancesrecordingsmap' VALUES (341, 2267, NULL, 447);
INSERT INTO 'dancesrecordingsmap' VALUES (342, 4477, NULL, 448);
INSERT INTO 'dancesrecordingsmap' VALUES (344, 4720, NULL, 450);
INSERT INTO 'dancesrecordingsmap' VALUES (345, 6386, NULL, 451);
INSERT INTO 'dancesrecordingsmap' VALUES (346, 6734, NULL, 452);
INSERT INTO 'dancesrecordingsmap' VALUES (347, 5239, NULL, 455);
INSERT INTO 'dancesrecordingsmap' VALUES (348, 5007, NULL, 457);
INSERT INTO 'dancesrecordingsmap' VALUES (349, 4293, NULL, 458);
INSERT INTO 'dancesrecordingsmap' VALUES (350, 6359, NULL, 460);
INSERT INTO 'dancesrecordingsmap' VALUES (351, 5658, NULL, 462);
INSERT INTO 'dancesrecordingsmap' VALUES (352, 2166, NULL, 463);
INSERT INTO 'dancesrecordingsmap' VALUES (356, 2173, NULL, 468);
INSERT INTO 'dancesrecordingsmap' VALUES (357, 2900, NULL, 469);
INSERT INTO 'dancesrecordingsmap' VALUES (358, 1930, NULL, 470);
INSERT INTO 'dancesrecordingsmap' VALUES (359, 3373, NULL, 473);
INSERT INTO 'dancesrecordingsmap' VALUES (360, 407, NULL, 474);
INSERT INTO 'dancesrecordingsmap' VALUES (361, 4776, NULL, 475);
INSERT INTO 'dancesrecordingsmap' VALUES (362, 1854, NULL, 476);
INSERT INTO 'dancesrecordingsmap' VALUES (363, 6387, NULL, 477);
INSERT INTO 'dancesrecordingsmap' VALUES (364, 4239, NULL, 496);
INSERT INTO 'dancesrecordingsmap' VALUES (365, 223, NULL, 497);
INSERT INTO 'dancesrecordingsmap' VALUES (368, 3659, NULL, 500);
INSERT INTO 'dancesrecordingsmap' VALUES (369, 7189, NULL, 501);
INSERT INTO 'dancesrecordingsmap' VALUES (370, 4933, NULL, 502);
INSERT INTO 'dancesrecordingsmap' VALUES (3234, 5525, NULL, 4101);
INSERT INTO 'dancesrecordingsmap' VALUES (3235, 6233, NULL, 4102);
INSERT INTO 'dancesrecordingsmap' VALUES (3236, 8146, NULL, 4103);
INSERT INTO 'dancesrecordingsmap' VALUES (3237, 7548, NULL, 4104);
INSERT INTO 'dancesrecordingsmap' VALUES (3238, 4491, NULL, 4106);
INSERT INTO 'dancesrecordingsmap' VALUES (3239, 5208, NULL, 4107);
INSERT INTO 'dancesrecordingsmap' VALUES (3240, 7546, NULL, 4110);
INSERT INTO 'dancesrecordingsmap' VALUES (3241, 4633, NULL, 2038);
INSERT INTO 'dancesrecordingsmap' VALUES (3242, 4641, NULL, 2041);
INSERT INTO 'dancesrecordingsmap' VALUES (3243, 6523, NULL, 4023);
INSERT INTO 'dancesrecordingsmap' VALUES (3244, 4548, NULL, 4028);
INSERT INTO 'dancesrecordingsmap' VALUES (3245, 6407, NULL, 4111);
INSERT INTO 'dancesrecordingsmap' VALUES (3246, 4442, NULL, 4112);
INSERT INTO 'dancesrecordingsmap' VALUES (3247, 3735, NULL, 4115);
INSERT INTO 'dancesrecordingsmap' VALUES (3248, 3528, NULL, 4116);
INSERT INTO 'dancesrecordingsmap' VALUES (3249, 3526, NULL, 4117);
INSERT INTO 'dancesrecordingsmap' VALUES (3250, 7574, NULL, 4118);
INSERT INTO 'dancesrecordingsmap' VALUES (3251, 3444, NULL, 4119);
INSERT INTO 'dancesrecordingsmap' VALUES (3252, 4227, NULL, 4120);
INSERT INTO 'dancesrecordingsmap' VALUES (3253, 541, NULL, 4121);
INSERT INTO 'dancesrecordingsmap' VALUES (3254, 654, NULL, 4122);
INSERT INTO 'dancesrecordingsmap' VALUES (3255, 1782, NULL, 4123);
INSERT INTO 'dancesrecordingsmap' VALUES (3256, 1210, NULL, 4127);
INSERT INTO 'dancesrecordingsmap' VALUES (3257, 7546, NULL, 4128);
INSERT INTO 'dancesrecordingsmap' VALUES (3258, 4014, NULL, 4129);
INSERT INTO 'dancesrecordingsmap' VALUES (3259, 1792, NULL, 4130);
INSERT INTO 'dancesrecordingsmap' VALUES (3260, 7546, NULL, 4132);
INSERT INTO 'dancesrecordingsmap' VALUES (3263, 3172, NULL, 4135);
INSERT INTO 'dancesrecordingsmap' VALUES (3264, 1838, NULL, 4136);
INSERT INTO 'dancesrecordingsmap' VALUES (3265, 1834, NULL, 4137);
INSERT INTO 'dancesrecordingsmap' VALUES (3266, 7546, NULL, 4139);
INSERT INTO 'dancesrecordingsmap' VALUES (3267, 2956, NULL, 4140);
INSERT INTO 'dancesrecordingsmap' VALUES (3268, 1792, NULL, 4142);
INSERT INTO 'dancesrecordingsmap' VALUES (3270, 6712, NULL, 4144);
INSERT INTO 'dancesrecordingsmap' VALUES (3271, 353, NULL, 4145);
INSERT INTO 'dancesrecordingsmap' VALUES (3272, 4491, NULL, 4146);
INSERT INTO 'dancesrecordingsmap' VALUES (3273, 2428, NULL, 4147);
INSERT INTO 'dancesrecordingsmap' VALUES (3274, 3057, NULL, 4148);
INSERT INTO 'dancesrecordingsmap' VALUES (3275, 4890, NULL, 4149);
INSERT INTO 'dancesrecordingsmap' VALUES (8049, 4015, NULL, 8850);
INSERT INTO 'dancesrecordingsmap' VALUES (8055, 14432, NULL, 8874);
INSERT INTO 'dancesrecordingsmap' VALUES (8068, 9354, NULL, 8887);
INSERT INTO 'dancesrecordingsmap' VALUES (372, 353, NULL, 506);
INSERT INTO 'dancesrecordingsmap' VALUES (355, 888, NULL, 467);
INSERT INTO 'dancesrecordingsmap' VALUES (367, 1348, NULL, 499);
INSERT INTO 'dancesrecordingsmap' VALUES (321, 385, NULL, 426);
INSERT INTO 'dancesrecordingsmap' VALUES (343, 340, NULL, 449);
INSERT INTO 'dancesrecordingsmap' VALUES (3210, 4633, NULL, 4060);
INSERT INTO 'dancesrecordingsmap' VALUES (3215, 7546, NULL, 4069);
INSERT INTO 'dancesrecordingsmap' VALUES (354, 4325, NULL, 465);
INSERT INTO 'dancesrecordingsmap' VALUES (3196, 8790, NULL, 3327);
INSERT INTO 'dancesrecordingsmap' VALUES (373, 7111, NULL, 507);
INSERT INTO 'dancesrecordingsmap' VALUES (374, 4358, NULL, 508);
INSERT INTO 'dancesrecordingsmap' VALUES (375, 2924, NULL, 509);
INSERT INTO 'dancesrecordingsmap' VALUES (377, 100, NULL, 513);
INSERT INTO 'dancesrecordingsmap' VALUES (378, 7085, NULL, 514);
INSERT INTO 'dancesrecordingsmap' VALUES (335, 410, NULL, 441);
INSERT INTO 'dancesrecordingsmap' VALUES (331, 2421, NULL, 437);
INSERT INTO 'dancesrecordingsmap' VALUES (3269, 1353, NULL, 4143);
INSERT INTO 'dancesrecordingsmap' VALUES (366, 3788, NULL, 498);
INSERT INTO 'dancesrecordingsmap' VALUES (379, 2613, NULL, 515);
INSERT INTO 'dancesrecordingsmap' VALUES (380, 6018, NULL, 516);
INSERT INTO 'dancesrecordingsmap' VALUES (381, 510, NULL, 517);
INSERT INTO 'dancesrecordingsmap' VALUES (382, 842, NULL, 518);
INSERT INTO 'dancesrecordingsmap' VALUES (322, 3310, NULL, 427);
INSERT INTO 'dancesrecordingsmap' VALUES (3261, 5964, NULL, 4133);
INSERT INTO 'dancesrecordingsmap' VALUES (3262, 5525, NULL, 4134);
INSERT INTO 'dancesrecordingsmap' VALUES (353, 1478, NULL, 464);
INSERT INTO 'dancesrecordingsmap' VALUES (383, 3006, NULL, 519);
INSERT INTO 'dancesrecordingsmap' VALUES (384, 4371, NULL, 520);
INSERT INTO 'dancesrecordingsmap' VALUES (386, 4947, NULL, 522);
INSERT INTO 'dancesrecordingsmap' VALUES (387, 2753, NULL, 523);
INSERT INTO 'dancesrecordingsmap' VALUES (388, 2312, NULL, 418);
INSERT INTO 'dancesrecordingsmap' VALUES (389, 3684, NULL, 511);
INSERT INTO 'dancesrecordingsmap' VALUES (390, 3093, NULL, 512);
INSERT INTO 'dancesrecordingsmap' VALUES (391, 7111, NULL, 524);
INSERT INTO 'dancesrecordingsmap' VALUES (392, 2691, NULL, 525);
INSERT INTO 'dancesrecordingsmap' VALUES (393, 984, NULL, 526);
INSERT INTO 'dancesrecordingsmap' VALUES (394, 373, NULL, 527);
INSERT INTO 'dancesrecordingsmap' VALUES (395, 4491, NULL, 528);
INSERT INTO 'dancesrecordingsmap' VALUES (397, 6915, NULL, 531);
INSERT INTO 'dancesrecordingsmap' VALUES (398, 2024, NULL, 533);
INSERT INTO 'dancesrecordingsmap' VALUES (399, 3562, NULL, 534);
INSERT INTO 'dancesrecordingsmap' VALUES (400, 6957, NULL, 537);
INSERT INTO 'dancesrecordingsmap' VALUES (401, 7546, NULL, 538);
INSERT INTO 'dancesrecordingsmap' VALUES (402, 7553, NULL, 540);
INSERT INTO 'dancesrecordingsmap' VALUES (403, 1562, NULL, 543);
INSERT INTO 'dancesrecordingsmap' VALUES (404, 7552, NULL, 544);
INSERT INTO 'dancesrecordingsmap' VALUES (405, 3528, NULL, 547);
INSERT INTO 'dancesrecordingsmap' VALUES (429, 3601, NULL, 585);
INSERT INTO 'dancesrecordingsmap' VALUES (407, 7548, NULL, 549);
INSERT INTO 'dancesrecordingsmap' VALUES (408, 6701, NULL, 550);
INSERT INTO 'dancesrecordingsmap' VALUES (409, 877, NULL, 551);
INSERT INTO 'dancesrecordingsmap' VALUES (410, 2956, NULL, 552);
INSERT INTO 'dancesrecordingsmap' VALUES (411, 1210, NULL, 554);
INSERT INTO 'dancesrecordingsmap' VALUES (412, 7555, NULL, 559);
INSERT INTO 'dancesrecordingsmap' VALUES (413, 7546, NULL, 560);
INSERT INTO 'dancesrecordingsmap' VALUES (414, 1931, NULL, 565);
INSERT INTO 'dancesrecordingsmap' VALUES (416, 1827, NULL, 571);
INSERT INTO 'dancesrecordingsmap' VALUES (417, 4441, NULL, 572);
INSERT INTO 'dancesrecordingsmap' VALUES (418, 1072, NULL, 573);
INSERT INTO 'dancesrecordingsmap' VALUES (419, 5888, NULL, 574);
INSERT INTO 'dancesrecordingsmap' VALUES (420, 2275, NULL, 575);
INSERT INTO 'dancesrecordingsmap' VALUES (421, 3268, NULL, 576);
INSERT INTO 'dancesrecordingsmap' VALUES (422, 3778, NULL, 577);
INSERT INTO 'dancesrecordingsmap' VALUES (424, 4617, NULL, 579);
INSERT INTO 'dancesrecordingsmap' VALUES (425, 889, NULL, 581);
INSERT INTO 'dancesrecordingsmap' VALUES (426, 1465, NULL, 582);
INSERT INTO 'dancesrecordingsmap' VALUES (427, 7107, NULL, 583);
INSERT INTO 'dancesrecordingsmap' VALUES (428, 896, NULL, 584);
INSERT INTO 'dancesrecordingsmap' VALUES (430, 4334, NULL, 586);
INSERT INTO 'dancesrecordingsmap' VALUES (431, 4196, NULL, 587);
INSERT INTO 'dancesrecordingsmap' VALUES (432, 5688, NULL, 588);
INSERT INTO 'dancesrecordingsmap' VALUES (433, 3339, NULL, 590);
INSERT INTO 'dancesrecordingsmap' VALUES (434, 3588, NULL, 591);
INSERT INTO 'dancesrecordingsmap' VALUES (435, 3589, NULL, 592);
INSERT INTO 'dancesrecordingsmap' VALUES (436, 3615, NULL, 593);
INSERT INTO 'dancesrecordingsmap' VALUES (437, 3735, NULL, 594);
INSERT INTO 'dancesrecordingsmap' VALUES (438, 3774, NULL, 595);
INSERT INTO 'dancesrecordingsmap' VALUES (439, 3921, NULL, 596);
INSERT INTO 'dancesrecordingsmap' VALUES (440, 5033, NULL, 597);
INSERT INTO 'dancesrecordingsmap' VALUES (441, 5364, NULL, 598);
INSERT INTO 'dancesrecordingsmap' VALUES (442, 6407, NULL, 599);
INSERT INTO 'dancesrecordingsmap' VALUES (443, 327, NULL, 601);
INSERT INTO 'dancesrecordingsmap' VALUES (444, 6711, NULL, 602);
INSERT INTO 'dancesrecordingsmap' VALUES (445, 3444, NULL, 603);
INSERT INTO 'dancesrecordingsmap' VALUES (446, 1017, NULL, 604);
INSERT INTO 'dancesrecordingsmap' VALUES (447, 1366, NULL, 605);
INSERT INTO 'dancesrecordingsmap' VALUES (448, 4499, NULL, 607);
INSERT INTO 'dancesrecordingsmap' VALUES (449, 654, NULL, 608);
INSERT INTO 'dancesrecordingsmap' VALUES (450, 611, NULL, 609);
INSERT INTO 'dancesrecordingsmap' VALUES (451, 5223, NULL, 610);
INSERT INTO 'dancesrecordingsmap' VALUES (452, 6800, NULL, 611);
INSERT INTO 'dancesrecordingsmap' VALUES (453, 1677, NULL, 612);
INSERT INTO 'dancesrecordingsmap' VALUES (455, 794, NULL, 615);
INSERT INTO 'dancesrecordingsmap' VALUES (456, 7172, NULL, 616);
INSERT INTO 'dancesrecordingsmap' VALUES (457, 2645, NULL, 617);
INSERT INTO 'dancesrecordingsmap' VALUES (458, 5398, NULL, 618);
INSERT INTO 'dancesrecordingsmap' VALUES (459, 4562, NULL, 619);
INSERT INTO 'dancesrecordingsmap' VALUES (460, 7147, NULL, 620);
INSERT INTO 'dancesrecordingsmap' VALUES (461, 2469, NULL, 622);
INSERT INTO 'dancesrecordingsmap' VALUES (462, 4239, NULL, 625);
INSERT INTO 'dancesrecordingsmap' VALUES (3276, 51, NULL, 4149);
INSERT INTO 'dancesrecordingsmap' VALUES (3277, 7139, NULL, 4150);
INSERT INTO 'dancesrecordingsmap' VALUES (3278, 658, NULL, 4151);
INSERT INTO 'dancesrecordingsmap' VALUES (3279, 3980, NULL, 4152);
INSERT INTO 'dancesrecordingsmap' VALUES (3280, 7147, NULL, 4152);
INSERT INTO 'dancesrecordingsmap' VALUES (3281, 353, NULL, 4153);
INSERT INTO 'dancesrecordingsmap' VALUES (3282, 373, NULL, 4154);
INSERT INTO 'dancesrecordingsmap' VALUES (3283, 1838, NULL, 4154);
INSERT INTO 'dancesrecordingsmap' VALUES (3284, 549, NULL, 4155);
INSERT INTO 'dancesrecordingsmap' VALUES (3285, 5308, NULL, 4155);
INSERT INTO 'dancesrecordingsmap' VALUES (3286, 56, NULL, 4156);
INSERT INTO 'dancesrecordingsmap' VALUES (3288, 633, NULL, 4170);
INSERT INTO 'dancesrecordingsmap' VALUES (3289, 4819, NULL, 2358);
INSERT INTO 'dancesrecordingsmap' VALUES (3291, 8168, NULL, 1903);
INSERT INTO 'dancesrecordingsmap' VALUES (3293, 8632, NULL, 1736);
INSERT INTO 'dancesrecordingsmap' VALUES (3294, 8633, NULL, 1995);
INSERT INTO 'dancesrecordingsmap' VALUES (3295, 3562, NULL, 535);
INSERT INTO 'dancesrecordingsmap' VALUES (3296, 3580, NULL, 1956);
INSERT INTO 'dancesrecordingsmap' VALUES (3297, 588, NULL, 1968);
INSERT INTO 'dancesrecordingsmap' VALUES (3298, 4227, NULL, 3707);
INSERT INTO 'dancesrecordingsmap' VALUES (3299, 3084, NULL, 4019);
INSERT INTO 'dancesrecordingsmap' VALUES (3300, 7546, NULL, 4126);
INSERT INTO 'dancesrecordingsmap' VALUES (3301, 6915, NULL, 4161);
INSERT INTO 'dancesrecordingsmap' VALUES (3302, 6915, NULL, 4167);
INSERT INTO 'dancesrecordingsmap' VALUES (3303, 992, NULL, 3078);
INSERT INTO 'dancesrecordingsmap' VALUES (3317, 1288, NULL, 4182);
INSERT INTO 'dancesrecordingsmap' VALUES (3318, 7036, NULL, 4187);
INSERT INTO 'dancesrecordingsmap' VALUES (8050, 6152, NULL, 8851);
INSERT INTO 'dancesrecordingsmap' VALUES (8069, 4555, NULL, 8889);
INSERT INTO 'dancesrecordingsmap' VALUES (463, 7139, NULL, 626);
INSERT INTO 'dancesrecordingsmap' VALUES (464, 4491, NULL, 627);
INSERT INTO 'dancesrecordingsmap' VALUES (465, 5455, NULL, 628);
INSERT INTO 'dancesrecordingsmap' VALUES (466, 1280, NULL, 629);
INSERT INTO 'dancesrecordingsmap' VALUES (467, 4500, NULL, 630);
INSERT INTO 'dancesrecordingsmap' VALUES (468, 15, NULL, 631);
INSERT INTO 'dancesrecordingsmap' VALUES (469, 778, NULL, 632);
INSERT INTO 'dancesrecordingsmap' VALUES (470, 1793, NULL, 633);
INSERT INTO 'dancesrecordingsmap' VALUES (471, 3595, NULL, 634);
INSERT INTO 'dancesrecordingsmap' VALUES (472, 3607, NULL, 635);
INSERT INTO 'dancesrecordingsmap' VALUES (473, 7124, NULL, 636);
INSERT INTO 'dancesrecordingsmap' VALUES (474, 159, NULL, 637);
INSERT INTO 'dancesrecordingsmap' VALUES (475, 1492, NULL, 638);
INSERT INTO 'dancesrecordingsmap' VALUES (476, 2237, NULL, 639);
INSERT INTO 'dancesrecordingsmap' VALUES (477, 4618, NULL, 640);
INSERT INTO 'dancesrecordingsmap' VALUES (478, 4273, NULL, 642);
INSERT INTO 'dancesrecordingsmap' VALUES (479, 5911, NULL, 643);
INSERT INTO 'dancesrecordingsmap' VALUES (480, 3317, NULL, 644);
INSERT INTO 'dancesrecordingsmap' VALUES (481, 2333, NULL, 645);
INSERT INTO 'dancesrecordingsmap' VALUES (482, 2153, NULL, 647);
INSERT INTO 'dancesrecordingsmap' VALUES (483, 3608, NULL, 648);
INSERT INTO 'dancesrecordingsmap' VALUES (484, 936, NULL, 649);
INSERT INTO 'dancesrecordingsmap' VALUES (485, 6634, NULL, 650);
INSERT INTO 'dancesrecordingsmap' VALUES (486, 6362, NULL, 651);
INSERT INTO 'dancesrecordingsmap' VALUES (487, 2593, NULL, 652);
INSERT INTO 'dancesrecordingsmap' VALUES (488, 3934, NULL, 653);
INSERT INTO 'dancesrecordingsmap' VALUES (489, 7219, NULL, 654);
INSERT INTO 'dancesrecordingsmap' VALUES (490, 5555, NULL, 655);
INSERT INTO 'dancesrecordingsmap' VALUES (491, 4629, NULL, 656);
INSERT INTO 'dancesrecordingsmap' VALUES (492, 2616, NULL, 657);
INSERT INTO 'dancesrecordingsmap' VALUES (493, 7204, NULL, 658);
INSERT INTO 'dancesrecordingsmap' VALUES (494, 5808, NULL, 659);
INSERT INTO 'dancesrecordingsmap' VALUES (495, 652, NULL, 660);
INSERT INTO 'dancesrecordingsmap' VALUES (496, 5006, NULL, 661);
INSERT INTO 'dancesrecordingsmap' VALUES (497, 5412, NULL, 662);
INSERT INTO 'dancesrecordingsmap' VALUES (498, 6712, NULL, 663);
INSERT INTO 'dancesrecordingsmap' VALUES (499, 3057, NULL, 664);
INSERT INTO 'dancesrecordingsmap' VALUES (500, 7180, NULL, 665);
INSERT INTO 'dancesrecordingsmap' VALUES (501, 5308, NULL, 666);
INSERT INTO 'dancesrecordingsmap' VALUES (502, 445, NULL, 667);
INSERT INTO 'dancesrecordingsmap' VALUES (503, 5915, NULL, 668);
INSERT INTO 'dancesrecordingsmap' VALUES (504, 1998, NULL, 669);
INSERT INTO 'dancesrecordingsmap' VALUES (505, 1891, NULL, 670);
INSERT INTO 'dancesrecordingsmap' VALUES (506, 5713, NULL, 671);
INSERT INTO 'dancesrecordingsmap' VALUES (507, 6972, NULL, 672);
INSERT INTO 'dancesrecordingsmap' VALUES (508, 314, NULL, 673);
INSERT INTO 'dancesrecordingsmap' VALUES (509, 1884, NULL, 674);
INSERT INTO 'dancesrecordingsmap' VALUES (510, 4046, NULL, 675);
INSERT INTO 'dancesrecordingsmap' VALUES (511, 3336, NULL, 676);
INSERT INTO 'dancesrecordingsmap' VALUES (3305, 3672, NULL, 1706);
INSERT INTO 'dancesrecordingsmap' VALUES (3306, 6048, NULL, 1708);
INSERT INTO 'dancesrecordingsmap' VALUES (3307, 8146, NULL, 1709);
INSERT INTO 'dancesrecordingsmap' VALUES (3308, 1774, NULL, 1710);
INSERT INTO 'dancesrecordingsmap' VALUES (3309, 2024, NULL, 1711);
INSERT INTO 'dancesrecordingsmap' VALUES (3310, 7546, NULL, 1712);
INSERT INTO 'dancesrecordingsmap' VALUES (3311, 5525, NULL, 1713);
INSERT INTO 'dancesrecordingsmap' VALUES (3313, 5915, NULL, 3618);
INSERT INTO 'dancesrecordingsmap' VALUES (3314, 8142, NULL, 3619);
INSERT INTO 'dancesrecordingsmap' VALUES (3315, 3691, NULL, 4168);
INSERT INTO 'dancesrecordingsmap' VALUES (3316, 5802, NULL, 4169);
INSERT INTO 'dancesrecordingsmap' VALUES (376, 1965, NULL, 510);
INSERT INTO 'dancesrecordingsmap' VALUES (8056, 14433, NULL, 8875);
INSERT INTO 'dancesrecordingsmap' VALUES (513, 3800, NULL, 678);
INSERT INTO 'dancesrecordingsmap' VALUES (514, 6829, NULL, 679);
INSERT INTO 'dancesrecordingsmap' VALUES (516, 5027, NULL, 681);
INSERT INTO 'dancesrecordingsmap' VALUES (518, 3918, NULL, 683);
INSERT INTO 'dancesrecordingsmap' VALUES (519, 6661, NULL, 684);
INSERT INTO 'dancesrecordingsmap' VALUES (415, 7180, NULL, 566);
INSERT INTO 'dancesrecordingsmap' VALUES (396, 5441, NULL, 529);
INSERT INTO 'dancesrecordingsmap' VALUES (3292, 8169, NULL, 1819);
INSERT INTO 'dancesrecordingsmap' VALUES (3290, 8167, NULL, 2141);
INSERT INTO 'dancesrecordingsmap' VALUES (423, 3054, NULL, 578);
INSERT INTO 'dancesrecordingsmap' VALUES (517, 7193, NULL, 682);
INSERT INTO 'dancesrecordingsmap' VALUES (385, 2602, NULL, 521);
INSERT INTO 'dancesrecordingsmap' VALUES (515, 4953, NULL, 680);
INSERT INTO 'dancesrecordingsmap' VALUES (520, 5654, NULL, 685);
INSERT INTO 'dancesrecordingsmap' VALUES (521, 6161, NULL, 686);
INSERT INTO 'dancesrecordingsmap' VALUES (522, 4654, NULL, 687);
INSERT INTO 'dancesrecordingsmap' VALUES (523, 349, NULL, 688);
INSERT INTO 'dancesrecordingsmap' VALUES (524, 2101, NULL, 689);
INSERT INTO 'dancesrecordingsmap' VALUES (525, 549, NULL, 690);
INSERT INTO 'dancesrecordingsmap' VALUES (526, 6995, NULL, 691);
INSERT INTO 'dancesrecordingsmap' VALUES (527, 1777, NULL, 692);
INSERT INTO 'dancesrecordingsmap' VALUES (528, 4441, NULL, 693);
INSERT INTO 'dancesrecordingsmap' VALUES (529, 2984, NULL, 694);
INSERT INTO 'dancesrecordingsmap' VALUES (530, 4968, NULL, 695);
INSERT INTO 'dancesrecordingsmap' VALUES (531, 3336, NULL, 696);
INSERT INTO 'dancesrecordingsmap' VALUES (532, 223, NULL, 697);
INSERT INTO 'dancesrecordingsmap' VALUES (533, 6349, NULL, 698);
INSERT INTO 'dancesrecordingsmap' VALUES (534, 6237, NULL, 699);
INSERT INTO 'dancesrecordingsmap' VALUES (535, 5330, NULL, 700);
INSERT INTO 'dancesrecordingsmap' VALUES (536, 4830, NULL, 702);
INSERT INTO 'dancesrecordingsmap' VALUES (537, 2631, NULL, 703);
INSERT INTO 'dancesrecordingsmap' VALUES (538, 6061, NULL, 704);
INSERT INTO 'dancesrecordingsmap' VALUES (539, 2934, NULL, 705);
INSERT INTO 'dancesrecordingsmap' VALUES (541, 3723, NULL, 707);
INSERT INTO 'dancesrecordingsmap' VALUES (542, 5326, NULL, 708);
INSERT INTO 'dancesrecordingsmap' VALUES (543, 5612, NULL, 709);
INSERT INTO 'dancesrecordingsmap' VALUES (544, 5407, NULL, 710);
INSERT INTO 'dancesrecordingsmap' VALUES (545, 2394, NULL, 711);
INSERT INTO 'dancesrecordingsmap' VALUES (547, 219, NULL, 713);
INSERT INTO 'dancesrecordingsmap' VALUES (548, 183, NULL, 714);
INSERT INTO 'dancesrecordingsmap' VALUES (549, 2469, NULL, 715);
INSERT INTO 'dancesrecordingsmap' VALUES (550, 3108, NULL, 717);
INSERT INTO 'dancesrecordingsmap' VALUES (551, 221, NULL, 718);
INSERT INTO 'dancesrecordingsmap' VALUES (552, 6756, NULL, 719);
INSERT INTO 'dancesrecordingsmap' VALUES (553, 5804, NULL, 720);
INSERT INTO 'dancesrecordingsmap' VALUES (555, 2432, NULL, 723);
INSERT INTO 'dancesrecordingsmap' VALUES (557, 2084, NULL, 725);
INSERT INTO 'dancesrecordingsmap' VALUES (610, 5624, NULL, 716);
INSERT INTO 'dancesrecordingsmap' VALUES (559, 4561, NULL, 727);
INSERT INTO 'dancesrecordingsmap' VALUES (560, 3045, NULL, 729);
INSERT INTO 'dancesrecordingsmap' VALUES (561, 7068, NULL, 730);
INSERT INTO 'dancesrecordingsmap' VALUES (562, 3887, NULL, 731);
INSERT INTO 'dancesrecordingsmap' VALUES (563, 972, NULL, 732);
INSERT INTO 'dancesrecordingsmap' VALUES (564, 3953, NULL, 733);
INSERT INTO 'dancesrecordingsmap' VALUES (565, 6518, NULL, 734);
INSERT INTO 'dancesrecordingsmap' VALUES (566, 4864, NULL, 606);
INSERT INTO 'dancesrecordingsmap' VALUES (568, 222, NULL, 735);
INSERT INTO 'dancesrecordingsmap' VALUES (569, 980, NULL, 736);
INSERT INTO 'dancesrecordingsmap' VALUES (570, 2925, NULL, 737);
INSERT INTO 'dancesrecordingsmap' VALUES (571, 4442, NULL, 738);
INSERT INTO 'dancesrecordingsmap' VALUES (572, 4806, NULL, 739);
INSERT INTO 'dancesrecordingsmap' VALUES (3319, 4798, NULL, 4188);
INSERT INTO 'dancesrecordingsmap' VALUES (3320, 7069, NULL, 4189);
INSERT INTO 'dancesrecordingsmap' VALUES (3321, 905, NULL, 4190);
INSERT INTO 'dancesrecordingsmap' VALUES (3322, 3834, NULL, 4191);
INSERT INTO 'dancesrecordingsmap' VALUES (3323, 61, NULL, 4192);
INSERT INTO 'dancesrecordingsmap' VALUES (3324, 4353, NULL, 4193);
INSERT INTO 'dancesrecordingsmap' VALUES (3325, 5650, NULL, 4194);
INSERT INTO 'dancesrecordingsmap' VALUES (3326, 5860, NULL, 4195);
INSERT INTO 'dancesrecordingsmap' VALUES (3327, 1544, NULL, 4196);
INSERT INTO 'dancesrecordingsmap' VALUES (3328, 1544, NULL, 4197);
INSERT INTO 'dancesrecordingsmap' VALUES (3329, 6419, NULL, 4198);
INSERT INTO 'dancesrecordingsmap' VALUES (3330, 183, NULL, 4199);
INSERT INTO 'dancesrecordingsmap' VALUES (3331, 183, NULL, 4200);
INSERT INTO 'dancesrecordingsmap' VALUES (3332, 2263, NULL, 4201);
INSERT INTO 'dancesrecordingsmap' VALUES (3333, 462, NULL, 4202);
INSERT INTO 'dancesrecordingsmap' VALUES (3334, 5296, NULL, 4203);
INSERT INTO 'dancesrecordingsmap' VALUES (3335, 6972, NULL, 4204);
INSERT INTO 'dancesrecordingsmap' VALUES (3336, 6972, NULL, 4205);
INSERT INTO 'dancesrecordingsmap' VALUES (3337, 340, NULL, 4206);
INSERT INTO 'dancesrecordingsmap' VALUES (3338, 964, NULL, 4207);
INSERT INTO 'dancesrecordingsmap' VALUES (3339, 5407, NULL, 4208);
INSERT INTO 'dancesrecordingsmap' VALUES (3340, 2242, NULL, 4209);
INSERT INTO 'dancesrecordingsmap' VALUES (3341, 8709, NULL, 4210);
INSERT INTO 'dancesrecordingsmap' VALUES (3342, 3636, NULL, 4211);
INSERT INTO 'dancesrecordingsmap' VALUES (3343, 3636, NULL, 4212);
INSERT INTO 'dancesrecordingsmap' VALUES (3344, 5956, NULL, 4177);
INSERT INTO 'dancesrecordingsmap' VALUES (3345, 7336, NULL, 4213);
INSERT INTO 'dancesrecordingsmap' VALUES (3346, 2450, NULL, 4214);
INSERT INTO 'dancesrecordingsmap' VALUES (3347, 7462, NULL, 4215);
INSERT INTO 'dancesrecordingsmap' VALUES (3348, 7380, NULL, 4216);
INSERT INTO 'dancesrecordingsmap' VALUES (3349, 5453, NULL, 4217);
INSERT INTO 'dancesrecordingsmap' VALUES (3350, 7541, NULL, 4218);
INSERT INTO 'dancesrecordingsmap' VALUES (8057, 14434, NULL, 8876);
INSERT INTO 'dancesrecordingsmap' VALUES (8070, 14241, NULL, 8890);
INSERT INTO 'dancesrecordingsmap' VALUES (573, 410, NULL, 740);
INSERT INTO 'dancesrecordingsmap' VALUES (574, 1864, NULL, 741);
INSERT INTO 'dancesrecordingsmap' VALUES (575, 3526, NULL, 742);
INSERT INTO 'dancesrecordingsmap' VALUES (576, 6349, NULL, 743);
INSERT INTO 'dancesrecordingsmap' VALUES (577, 2257, NULL, 744);
INSERT INTO 'dancesrecordingsmap' VALUES (578, 3309, NULL, 745);
INSERT INTO 'dancesrecordingsmap' VALUES (579, 1654, NULL, 746);
INSERT INTO 'dancesrecordingsmap' VALUES (581, 1573, NULL, 748);
INSERT INTO 'dancesrecordingsmap' VALUES (582, 6229, NULL, 749);
INSERT INTO 'dancesrecordingsmap' VALUES (583, 4355, NULL, 750);
INSERT INTO 'dancesrecordingsmap' VALUES (584, 710, NULL, 751);
INSERT INTO 'dancesrecordingsmap' VALUES (585, 4809, NULL, 752);
INSERT INTO 'dancesrecordingsmap' VALUES (586, 7262, NULL, 753);
INSERT INTO 'dancesrecordingsmap' VALUES (587, 3114, NULL, 754);
INSERT INTO 'dancesrecordingsmap' VALUES (588, 711, NULL, 755);
INSERT INTO 'dancesrecordingsmap' VALUES (589, 1074, NULL, 756);
INSERT INTO 'dancesrecordingsmap' VALUES (591, 535, NULL, 758);
INSERT INTO 'dancesrecordingsmap' VALUES (592, 5243, NULL, 759);
INSERT INTO 'dancesrecordingsmap' VALUES (593, 6532, NULL, 760);
INSERT INTO 'dancesrecordingsmap' VALUES (594, 3231, NULL, 762);
INSERT INTO 'dancesrecordingsmap' VALUES (595, 6419, NULL, 763);
INSERT INTO 'dancesrecordingsmap' VALUES (596, 7049, NULL, 764);
INSERT INTO 'dancesrecordingsmap' VALUES (597, 2431, NULL, 765);
INSERT INTO 'dancesrecordingsmap' VALUES (598, 1838, NULL, 766);
INSERT INTO 'dancesrecordingsmap' VALUES (599, 4862, NULL, 768);
INSERT INTO 'dancesrecordingsmap' VALUES (600, 1501, NULL, 769);
INSERT INTO 'dancesrecordingsmap' VALUES (601, 4928, NULL, 770);
INSERT INTO 'dancesrecordingsmap' VALUES (603, 745, NULL, 772);
INSERT INTO 'dancesrecordingsmap' VALUES (604, 4450, NULL, 773);
INSERT INTO 'dancesrecordingsmap' VALUES (605, 4755, NULL, 774);
INSERT INTO 'dancesrecordingsmap' VALUES (606, 3284, NULL, 775);
INSERT INTO 'dancesrecordingsmap' VALUES (608, 1773, NULL, 778);
INSERT INTO 'dancesrecordingsmap' VALUES (609, 3953, NULL, 613);
INSERT INTO 'dancesrecordingsmap' VALUES (611, 83, NULL, 785);
INSERT INTO 'dancesrecordingsmap' VALUES (612, 7282, NULL, 786);
INSERT INTO 'dancesrecordingsmap' VALUES (613, 7283, NULL, 787);
INSERT INTO 'dancesrecordingsmap' VALUES (614, 4933, NULL, 788);
INSERT INTO 'dancesrecordingsmap' VALUES (615, 7284, NULL, 789);
INSERT INTO 'dancesrecordingsmap' VALUES (616, 7285, NULL, 790);
INSERT INTO 'dancesrecordingsmap' VALUES (617, 7286, NULL, 791);
INSERT INTO 'dancesrecordingsmap' VALUES (618, 1782, NULL, 792);
INSERT INTO 'dancesrecordingsmap' VALUES (619, 5637, NULL, 793);
INSERT INTO 'dancesrecordingsmap' VALUES (620, 5354, NULL, 794);
INSERT INTO 'dancesrecordingsmap' VALUES (621, 1348, NULL, 795);
INSERT INTO 'dancesrecordingsmap' VALUES (622, 3672, NULL, 796);
INSERT INTO 'dancesrecordingsmap' VALUES (623, 5462, NULL, 797);
INSERT INTO 'dancesrecordingsmap' VALUES (624, 5802, NULL, 798);
INSERT INTO 'dancesrecordingsmap' VALUES (625, 895, NULL, 799);
INSERT INTO 'dancesrecordingsmap' VALUES (626, 5734, NULL, 800);
INSERT INTO 'dancesrecordingsmap' VALUES (627, 2501, NULL, 801);
INSERT INTO 'dancesrecordingsmap' VALUES (628, 4894, NULL, 802);
INSERT INTO 'dancesrecordingsmap' VALUES (629, 5136, NULL, 803);
INSERT INTO 'dancesrecordingsmap' VALUES (630, 4929, NULL, 804);
INSERT INTO 'dancesrecordingsmap' VALUES (631, 1376, NULL, 805);
INSERT INTO 'dancesrecordingsmap' VALUES (632, 5099, NULL, 806);
INSERT INTO 'dancesrecordingsmap' VALUES (633, 1799, NULL, 807);
INSERT INTO 'dancesrecordingsmap' VALUES (634, 1790, NULL, 808);
INSERT INTO 'dancesrecordingsmap' VALUES (636, 1476, NULL, 810);
INSERT INTO 'dancesrecordingsmap' VALUES (637, 1274, NULL, 811);
INSERT INTO 'dancesrecordingsmap' VALUES (638, 7109, NULL, 812);
INSERT INTO 'dancesrecordingsmap' VALUES (639, 3236, NULL, 813);
INSERT INTO 'dancesrecordingsmap' VALUES (640, 5963, NULL, 814);
INSERT INTO 'dancesrecordingsmap' VALUES (641, 5708, NULL, 815);
INSERT INTO 'dancesrecordingsmap' VALUES (642, 7563, NULL, 816);
INSERT INTO 'dancesrecordingsmap' VALUES (643, 6051, NULL, 817);
INSERT INTO 'dancesrecordingsmap' VALUES (644, 886, NULL, 818);
INSERT INTO 'dancesrecordingsmap' VALUES (645, 3463, NULL, 819);
INSERT INTO 'dancesrecordingsmap' VALUES (646, 7564, NULL, 820);
INSERT INTO 'dancesrecordingsmap' VALUES (647, 3645, NULL, 821);
INSERT INTO 'dancesrecordingsmap' VALUES (648, 6492, NULL, 822);
INSERT INTO 'dancesrecordingsmap' VALUES (650, 7565, NULL, 824);
INSERT INTO 'dancesrecordingsmap' VALUES (651, 7566, NULL, 825);
INSERT INTO 'dancesrecordingsmap' VALUES (653, 7568, NULL, 827);
INSERT INTO 'dancesrecordingsmap' VALUES (657, 6712, NULL, 832);
INSERT INTO 'dancesrecordingsmap' VALUES (658, 1758, NULL, 833);
INSERT INTO 'dancesrecordingsmap' VALUES (659, 4365, NULL, 834);
INSERT INTO 'dancesrecordingsmap' VALUES (660, 3119, NULL, 835);
INSERT INTO 'dancesrecordingsmap' VALUES (661, 6091, NULL, 836);
INSERT INTO 'dancesrecordingsmap' VALUES (662, 7031, NULL, 837);
INSERT INTO 'dancesrecordingsmap' VALUES (512, 5552, NULL, 677);
INSERT INTO 'dancesrecordingsmap' VALUES (567, 2415, NULL, 721);
INSERT INTO 'dancesrecordingsmap' VALUES (590, 4662, NULL, 757);
INSERT INTO 'dancesrecordingsmap' VALUES (635, 723, NULL, 809);
INSERT INTO 'dancesrecordingsmap' VALUES (546, 7105, NULL, 712);
INSERT INTO 'dancesrecordingsmap' VALUES (652, 7567, NULL, 826);
INSERT INTO 'dancesrecordingsmap' VALUES (663, 154, NULL, 838);
INSERT INTO 'dancesrecordingsmap' VALUES (664, 4015, NULL, 839);
INSERT INTO 'dancesrecordingsmap' VALUES (3352, 5045, NULL, 4220);
INSERT INTO 'dancesrecordingsmap' VALUES (3353, 5448, NULL, 4221);
INSERT INTO 'dancesrecordingsmap' VALUES (3355, 7338, NULL, 4223);
INSERT INTO 'dancesrecordingsmap' VALUES (3356, 7459, NULL, 4224);
INSERT INTO 'dancesrecordingsmap' VALUES (3357, 4044, NULL, 4226);
INSERT INTO 'dancesrecordingsmap' VALUES (3358, 633, NULL, 3198);
INSERT INTO 'dancesrecordingsmap' VALUES (540, 1909, NULL, 706);
INSERT INTO 'dancesrecordingsmap' VALUES (556, 6736, NULL, 724);
INSERT INTO 'dancesrecordingsmap' VALUES (607, 521, NULL, 777);
INSERT INTO 'dancesrecordingsmap' VALUES (3359, 5707, NULL, 4227);
INSERT INTO 'dancesrecordingsmap' VALUES (3360, 5128, NULL, 4228);
INSERT INTO 'dancesrecordingsmap' VALUES (3361, 4282, NULL, 4229);
INSERT INTO 'dancesrecordingsmap' VALUES (3362, 5802, NULL, 4231);
INSERT INTO 'dancesrecordingsmap' VALUES (3363, 6798, NULL, 4232);
INSERT INTO 'dancesrecordingsmap' VALUES (3364, 7204, NULL, 4233);
INSERT INTO 'dancesrecordingsmap' VALUES (3365, 5407, NULL, 4234);
INSERT INTO 'dancesrecordingsmap' VALUES (580, 3381, NULL, 747);
INSERT INTO 'dancesrecordingsmap' VALUES (655, 2344, NULL, 829);
INSERT INTO 'dancesrecordingsmap' VALUES (649, 3765, NULL, 823);
INSERT INTO 'dancesrecordingsmap' VALUES (654, 7104, NULL, 828);
INSERT INTO 'dancesrecordingsmap' VALUES (656, 7569, NULL, 830);
INSERT INTO 'dancesrecordingsmap' VALUES (3366, 584, NULL, 4235);
INSERT INTO 'dancesrecordingsmap' VALUES (3367, 4336, NULL, 4236);
INSERT INTO 'dancesrecordingsmap' VALUES (3368, 183, NULL, 4237);
INSERT INTO 'dancesrecordingsmap' VALUES (3369, 3659, NULL, 4238);
INSERT INTO 'dancesrecordingsmap' VALUES (3370, 888, NULL, 4239);
INSERT INTO 'dancesrecordingsmap' VALUES (3371, 4484, NULL, 4240);
INSERT INTO 'dancesrecordingsmap' VALUES (3372, 1582, NULL, 4241);
INSERT INTO 'dancesrecordingsmap' VALUES (3373, 2166, NULL, 1432);
INSERT INTO 'dancesrecordingsmap' VALUES (3374, 6748, NULL, 1433);
INSERT INTO 'dancesrecordingsmap' VALUES (3375, 1562, NULL, 4242);
INSERT INTO 'dancesrecordingsmap' VALUES (3376, 5707, NULL, 1408);
INSERT INTO 'dancesrecordingsmap' VALUES (3377, 1792, NULL, 4243);
INSERT INTO 'dancesrecordingsmap' VALUES (3378, 633, NULL, 4244);
INSERT INTO 'dancesrecordingsmap' VALUES (3379, 4064, NULL, 4245);
INSERT INTO 'dancesrecordingsmap' VALUES (3380, 4239, NULL, 4246);
INSERT INTO 'dancesrecordingsmap' VALUES (3381, 7546, NULL, 4247);
INSERT INTO 'dancesrecordingsmap' VALUES (3382, 7548, NULL, 4249);
INSERT INTO 'dancesrecordingsmap' VALUES (3383, 6915, NULL, 4250);
INSERT INTO 'dancesrecordingsmap' VALUES (3384, 1762, NULL, 4251);
INSERT INTO 'dancesrecordingsmap' VALUES (3385, 3834, NULL, 4252);
INSERT INTO 'dancesrecordingsmap' VALUES (3386, 7546, NULL, 4255);
INSERT INTO 'dancesrecordingsmap' VALUES (3387, 1864, NULL, 4256);
INSERT INTO 'dancesrecordingsmap' VALUES (3388, 6915, NULL, 3629);
INSERT INTO 'dancesrecordingsmap' VALUES (3389, 743, NULL, 2474);
INSERT INTO 'dancesrecordingsmap' VALUES (3390, 6657, NULL, 278);
INSERT INTO 'dancesrecordingsmap' VALUES (3391, 3197, NULL, 56);
INSERT INTO 'dancesrecordingsmap' VALUES (8058, 13210, NULL, 8877);
INSERT INTO 'dancesrecordingsmap' VALUES (8071, 7283, NULL, 8891);
INSERT INTO 'dancesrecordingsmap' VALUES (665, 7180, NULL, 841);
INSERT INTO 'dancesrecordingsmap' VALUES (666, 6451, NULL, 844);
INSERT INTO 'dancesrecordingsmap' VALUES (667, 154, NULL, 417);
INSERT INTO 'dancesrecordingsmap' VALUES (668, 327, NULL, 600);
INSERT INTO 'dancesrecordingsmap' VALUES (671, 4196, NULL, 846);
INSERT INTO 'dancesrecordingsmap' VALUES (672, 1034, NULL, 847);
INSERT INTO 'dancesrecordingsmap' VALUES (673, 410, NULL, 849);
INSERT INTO 'dancesrecordingsmap' VALUES (674, 4102, NULL, 851);
INSERT INTO 'dancesrecordingsmap' VALUES (675, 3323, NULL, 852);
INSERT INTO 'dancesrecordingsmap' VALUES (677, 7553, NULL, 856);
INSERT INTO 'dancesrecordingsmap' VALUES (678, 3172, NULL, 857);
INSERT INTO 'dancesrecordingsmap' VALUES (679, 5407, NULL, 858);
INSERT INTO 'dancesrecordingsmap' VALUES (680, 5794, NULL, 860);
INSERT INTO 'dancesrecordingsmap' VALUES (681, 905, NULL, 863);
INSERT INTO 'dancesrecordingsmap' VALUES (682, 7180, NULL, 865);
INSERT INTO 'dancesrecordingsmap' VALUES (683, 5503, NULL, 866);
INSERT INTO 'dancesrecordingsmap' VALUES (684, 1719, NULL, 867);
INSERT INTO 'dancesrecordingsmap' VALUES (686, 2034, NULL, 12);
INSERT INTO 'dancesrecordingsmap' VALUES (687, 1615, NULL, 71);
INSERT INTO 'dancesrecordingsmap' VALUES (690, 6957, NULL, 249);
INSERT INTO 'dancesrecordingsmap' VALUES (691, 3172, NULL, 274);
INSERT INTO 'dancesrecordingsmap' VALUES (693, 4487, NULL, 367);
INSERT INTO 'dancesrecordingsmap' VALUES (694, 4646, NULL, 372);
INSERT INTO 'dancesrecordingsmap' VALUES (695, 5547, NULL, 456);
INSERT INTO 'dancesrecordingsmap' VALUES (696, 6233, NULL, 129);
INSERT INTO 'dancesrecordingsmap' VALUES (697, 7574, NULL, 23);
INSERT INTO 'dancesrecordingsmap' VALUES (698, 7574, NULL, 561);
INSERT INTO 'dancesrecordingsmap' VALUES (699, 4144, NULL, 459);
INSERT INTO 'dancesrecordingsmap' VALUES (700, 4865, NULL, 461);
INSERT INTO 'dancesrecordingsmap' VALUES (701, 3862, NULL, 466);
INSERT INTO 'dancesrecordingsmap' VALUES (702, 132, NULL, 871);
INSERT INTO 'dancesrecordingsmap' VALUES (703, 3759, NULL, 872);
INSERT INTO 'dancesrecordingsmap' VALUES (704, 3506, NULL, 873);
INSERT INTO 'dancesrecordingsmap' VALUES (705, 743, NULL, 874);
INSERT INTO 'dancesrecordingsmap' VALUES (706, 848, NULL, 875);
INSERT INTO 'dancesrecordingsmap' VALUES (707, 4827, NULL, 876);
INSERT INTO 'dancesrecordingsmap' VALUES (708, 7210, NULL, 877);
INSERT INTO 'dancesrecordingsmap' VALUES (709, 4086, NULL, 878);
INSERT INTO 'dancesrecordingsmap' VALUES (710, 6323, NULL, 879);
INSERT INTO 'dancesrecordingsmap' VALUES (711, 5522, NULL, 880);
INSERT INTO 'dancesrecordingsmap' VALUES (712, 2747, NULL, 881);
INSERT INTO 'dancesrecordingsmap' VALUES (713, 373, NULL, 882);
INSERT INTO 'dancesrecordingsmap' VALUES (714, 2962, NULL, 883);
INSERT INTO 'dancesrecordingsmap' VALUES (715, 3743, NULL, 884);
INSERT INTO 'dancesrecordingsmap' VALUES (716, 4358, NULL, 885);
INSERT INTO 'dancesrecordingsmap' VALUES (717, 5208, NULL, 886);
INSERT INTO 'dancesrecordingsmap' VALUES (718, 4407, NULL, 887);
INSERT INTO 'dancesrecordingsmap' VALUES (719, 4890, NULL, 888);
INSERT INTO 'dancesrecordingsmap' VALUES (721, 3659, NULL, 890);
INSERT INTO 'dancesrecordingsmap' VALUES (722, 4511, NULL, 891);
INSERT INTO 'dancesrecordingsmap' VALUES (723, 116, NULL, 892);
INSERT INTO 'dancesrecordingsmap' VALUES (724, 6380, NULL, 831);
INSERT INTO 'dancesrecordingsmap' VALUES (726, 5808, NULL, 896);
INSERT INTO 'dancesrecordingsmap' VALUES (728, 4548, NULL, 898);
INSERT INTO 'dancesrecordingsmap' VALUES (729, 3759, 309, 899);
INSERT INTO 'dancesrecordingsmap' VALUES (730, 6995, NULL, 901);
INSERT INTO 'dancesrecordingsmap' VALUES (676, 7182, NULL, 855);
INSERT INTO 'dancesrecordingsmap' VALUES (732, 2820, NULL, 904);
INSERT INTO 'dancesrecordingsmap' VALUES (734, 608, NULL, 907);
INSERT INTO 'dancesrecordingsmap' VALUES (735, 5376, NULL, 908);
INSERT INTO 'dancesrecordingsmap' VALUES (737, 6233, NULL, 910);
INSERT INTO 'dancesrecordingsmap' VALUES (738, 5222, NULL, 911);
INSERT INTO 'dancesrecordingsmap' VALUES (739, 862, NULL, 912);
INSERT INTO 'dancesrecordingsmap' VALUES (740, 1615, NULL, 913);
INSERT INTO 'dancesrecordingsmap' VALUES (741, 2044, NULL, 915);
INSERT INTO 'dancesrecordingsmap' VALUES (742, 588, NULL, 916);
INSERT INTO 'dancesrecordingsmap' VALUES (743, 1927, NULL, 917);
INSERT INTO 'dancesrecordingsmap' VALUES (744, 5641, NULL, 918);
INSERT INTO 'dancesrecordingsmap' VALUES (745, 5847, NULL, 920);
INSERT INTO 'dancesrecordingsmap' VALUES (747, 5450, NULL, 925);
INSERT INTO 'dancesrecordingsmap' VALUES (748, 2317, NULL, 926);
INSERT INTO 'dancesrecordingsmap' VALUES (749, 6658, NULL, 927);
INSERT INTO 'dancesrecordingsmap' VALUES (751, 5436, NULL, 929);
INSERT INTO 'dancesrecordingsmap' VALUES (752, 3437, NULL, 930);
INSERT INTO 'dancesrecordingsmap' VALUES (753, 2916, NULL, 931);
INSERT INTO 'dancesrecordingsmap' VALUES (754, 4195, NULL, 932);
INSERT INTO 'dancesrecordingsmap' VALUES (755, 2053, NULL, 933);
INSERT INTO 'dancesrecordingsmap' VALUES (756, 1647, NULL, 392);
INSERT INTO 'dancesrecordingsmap' VALUES (757, 5200, NULL, 248);
INSERT INTO 'dancesrecordingsmap' VALUES (3394, 1044, NULL, 3151);
INSERT INTO 'dancesrecordingsmap' VALUES (3395, 962, NULL, 512);
INSERT INTO 'dancesrecordingsmap' VALUES (3396, 6556, NULL, 415);
INSERT INTO 'dancesrecordingsmap' VALUES (3397, 5998, NULL, 1023);
INSERT INTO 'dancesrecordingsmap' VALUES (3398, 3367, NULL, 513);
INSERT INTO 'dancesrecordingsmap' VALUES (3399, 6666, NULL, 2291);
INSERT INTO 'dancesrecordingsmap' VALUES (3400, 2975, NULL, 250);
INSERT INTO 'dancesrecordingsmap' VALUES (3401, 7552, NULL, 4274);
INSERT INTO 'dancesrecordingsmap' VALUES (3402, 7546, NULL, 4275);
INSERT INTO 'dancesrecordingsmap' VALUES (3403, 1792, NULL, 4276);
INSERT INTO 'dancesrecordingsmap' VALUES (3404, 8160, NULL, 4278);
INSERT INTO 'dancesrecordingsmap' VALUES (3405, 8146, NULL, 4279);
INSERT INTO 'dancesrecordingsmap' VALUES (3406, 8159, NULL, 4280);
INSERT INTO 'dancesrecordingsmap' VALUES (3407, 6915, NULL, 4282);
INSERT INTO 'dancesrecordingsmap' VALUES (3408, 7554, NULL, 4283);
INSERT INTO 'dancesrecordingsmap' VALUES (3409, 8152, NULL, 4284);
INSERT INTO 'dancesrecordingsmap' VALUES (3410, 7574, NULL, 4288);
INSERT INTO 'dancesrecordingsmap' VALUES (3411, 7552, NULL, 4289);
INSERT INTO 'dancesrecordingsmap' VALUES (3412, 8154, NULL, 4290);
INSERT INTO 'dancesrecordingsmap' VALUES (3413, 7546, NULL, 4296);
INSERT INTO 'dancesrecordingsmap' VALUES (3414, 8092, NULL, 1056);
INSERT INTO 'dancesrecordingsmap' VALUES (3415, 5239, NULL, 4304);
INSERT INTO 'dancesrecordingsmap' VALUES (3416, 7548, NULL, 4305);
INSERT INTO 'dancesrecordingsmap' VALUES (3417, 7546, NULL, 4306);
INSERT INTO 'dancesrecordingsmap' VALUES (3418, 2972, NULL, 4309);
INSERT INTO 'dancesrecordingsmap' VALUES (3419, 7552, NULL, 4310);
INSERT INTO 'dancesrecordingsmap' VALUES (3420, 7546, NULL, 4311);
INSERT INTO 'dancesrecordingsmap' VALUES (3421, 5525, NULL, 4312);
INSERT INTO 'dancesrecordingsmap' VALUES (3422, 3743, NULL, 4313);
INSERT INTO 'dancesrecordingsmap' VALUES (3423, 2747, NULL, 4314);
INSERT INTO 'dancesrecordingsmap' VALUES (3425, 8154, NULL, 4320);
INSERT INTO 'dancesrecordingsmap' VALUES (3427, 7552, NULL, 4323);
INSERT INTO 'dancesrecordingsmap' VALUES (3428, 7546, NULL, 4332);
INSERT INTO 'dancesrecordingsmap' VALUES (3429, 8153, NULL, 4333);
INSERT INTO 'dancesrecordingsmap' VALUES (3430, 2298, NULL, 4336);
INSERT INTO 'dancesrecordingsmap' VALUES (3431, 442, NULL, 4340);
INSERT INTO 'dancesrecordingsmap' VALUES (3432, 6915, NULL, 4341);
INSERT INTO 'dancesrecordingsmap' VALUES (3433, 4015, NULL, 4342);
INSERT INTO 'dancesrecordingsmap' VALUES (3434, 1891, NULL, 4343);
INSERT INTO 'dancesrecordingsmap' VALUES (3435, 4641, NULL, 4347);
INSERT INTO 'dancesrecordingsmap' VALUES (8059, 14435, NULL, 8878);
INSERT INTO 'dancesrecordingsmap' VALUES (8072, 7517, NULL, 8892);
INSERT INTO 'dancesrecordingsmap' VALUES (758, 1544, NULL, 934);
INSERT INTO 'dancesrecordingsmap' VALUES (689, 674, NULL, 242);
INSERT INTO 'dancesrecordingsmap' VALUES (688, 3637, NULL, 89);
INSERT INTO 'dancesrecordingsmap' VALUES (727, 5808, NULL, 897);
INSERT INTO 'dancesrecordingsmap' VALUES (685, 1405, NULL, 870);
INSERT INTO 'dancesrecordingsmap' VALUES (750, 2302, NULL, 928);
INSERT INTO 'dancesrecordingsmap' VALUES (3354, 7353, NULL, 4222);
INSERT INTO 'dancesrecordingsmap' VALUES (669, 280, NULL, 408);
INSERT INTO 'dancesrecordingsmap' VALUES (3392, 2244, NULL, 1970);
INSERT INTO 'dancesrecordingsmap' VALUES (736, 2682, NULL, 909);
INSERT INTO 'dancesrecordingsmap' VALUES (759, 4209, NULL, 935);
INSERT INTO 'dancesrecordingsmap' VALUES (760, 1816, NULL, 936);
INSERT INTO 'dancesrecordingsmap' VALUES (762, 159, NULL, 938);
INSERT INTO 'dancesrecordingsmap' VALUES (763, 535, NULL, 939);
INSERT INTO 'dancesrecordingsmap' VALUES (765, 6136, NULL, 942);
INSERT INTO 'dancesrecordingsmap' VALUES (766, 5366, NULL, 943);
INSERT INTO 'dancesrecordingsmap' VALUES (767, 6080, NULL, 944);
INSERT INTO 'dancesrecordingsmap' VALUES (768, 893, NULL, 945);
INSERT INTO 'dancesrecordingsmap' VALUES (761, 68, NULL, 937);
INSERT INTO 'dancesrecordingsmap' VALUES (692, 4565, NULL, 352);
INSERT INTO 'dancesrecordingsmap' VALUES (733, 6182, NULL, 906);
INSERT INTO 'dancesrecordingsmap' VALUES (3424, 2755, NULL, 3242);
INSERT INTO 'dancesrecordingsmap' VALUES (764, 5443, NULL, 940);
INSERT INTO 'dancesrecordingsmap' VALUES (769, 250, NULL, 946);
INSERT INTO 'dancesrecordingsmap' VALUES (770, 2242, NULL, 903);
INSERT INTO 'dancesrecordingsmap' VALUES (771, 2822, NULL, 905);
INSERT INTO 'dancesrecordingsmap' VALUES (781, 551, NULL, 953);
INSERT INTO 'dancesrecordingsmap' VALUES (795, 4111, NULL, 965);
INSERT INTO 'dancesrecordingsmap' VALUES (783, 6410, NULL, 580);
INSERT INTO 'dancesrecordingsmap' VALUES (784, 8072, NULL, 854);
INSERT INTO 'dancesrecordingsmap' VALUES (786, 8067, NULL, 515);
INSERT INTO 'dancesrecordingsmap' VALUES (746, 3617, NULL, 923);
INSERT INTO 'dancesrecordingsmap' VALUES (3426, 7147, NULL, 4321);
INSERT INTO 'dancesrecordingsmap' VALUES (3393, 4497, NULL, 623);
INSERT INTO 'dancesrecordingsmap' VALUES (720, 4890, NULL, 889);
INSERT INTO 'dancesrecordingsmap' VALUES (788, 7782, NULL, 487);
INSERT INTO 'dancesrecordingsmap' VALUES (789, 7903, NULL, 956);
INSERT INTO 'dancesrecordingsmap' VALUES (790, 7814, NULL, 957);
INSERT INTO 'dancesrecordingsmap' VALUES (791, 8024, NULL, 958);
INSERT INTO 'dancesrecordingsmap' VALUES (792, 8029, NULL, 959);
INSERT INTO 'dancesrecordingsmap' VALUES (793, 5444, NULL, 380);
INSERT INTO 'dancesrecordingsmap' VALUES (794, 3033, NULL, 964);
INSERT INTO 'dancesrecordingsmap' VALUES (796, 8088, NULL, 966);
INSERT INTO 'dancesrecordingsmap' VALUES (797, 6682, NULL, 967);
INSERT INTO 'dancesrecordingsmap' VALUES (798, 4015, NULL, 968);
INSERT INTO 'dancesrecordingsmap' VALUES (799, 413, NULL, 969);
INSERT INTO 'dancesrecordingsmap' VALUES (800, 7285, NULL, 970);
INSERT INTO 'dancesrecordingsmap' VALUES (801, 5808, NULL, 971);
INSERT INTO 'dancesrecordingsmap' VALUES (802, 887, NULL, 972);
INSERT INTO 'dancesrecordingsmap' VALUES (803, 1207, NULL, 973);
INSERT INTO 'dancesrecordingsmap' VALUES (804, 4894, NULL, 974);
INSERT INTO 'dancesrecordingsmap' VALUES (805, 5671, NULL, 975);
INSERT INTO 'dancesrecordingsmap' VALUES (806, 6431, NULL, 976);
INSERT INTO 'dancesrecordingsmap' VALUES (808, 6336, NULL, 978);
INSERT INTO 'dancesrecordingsmap' VALUES (809, 4048, NULL, 979);
INSERT INTO 'dancesrecordingsmap' VALUES (810, 6273, NULL, 980);
INSERT INTO 'dancesrecordingsmap' VALUES (812, 7546, NULL, 982);
INSERT INTO 'dancesrecordingsmap' VALUES (813, 2020, NULL, 985);
INSERT INTO 'dancesrecordingsmap' VALUES (816, 3616, NULL, 589);
INSERT INTO 'dancesrecordingsmap' VALUES (817, 4239, NULL, 996);
INSERT INTO 'dancesrecordingsmap' VALUES (818, 6797, NULL, 999);
INSERT INTO 'dancesrecordingsmap' VALUES (819, 8142, NULL, 29);
INSERT INTO 'dancesrecordingsmap' VALUES (820, 8143, NULL, 403);
INSERT INTO 'dancesrecordingsmap' VALUES (821, 8144, NULL, 51);
INSERT INTO 'dancesrecordingsmap' VALUES (822, 8146, NULL, 541);
INSERT INTO 'dancesrecordingsmap' VALUES (823, 8149, NULL, 558);
INSERT INTO 'dancesrecordingsmap' VALUES (824, 8151, NULL, 416);
INSERT INTO 'dancesrecordingsmap' VALUES (825, 8153, NULL, 245);
INSERT INTO 'dancesrecordingsmap' VALUES (826, 5581, NULL, 1005);
INSERT INTO 'dancesrecordingsmap' VALUES (827, 769, NULL, 1006);
INSERT INTO 'dancesrecordingsmap' VALUES (828, 4217, NULL, 1007);
INSERT INTO 'dancesrecordingsmap' VALUES (829, 5525, NULL, 1008);
INSERT INTO 'dancesrecordingsmap' VALUES (830, 7546, NULL, 1009);
INSERT INTO 'dancesrecordingsmap' VALUES (832, 3474, NULL, 1011);
INSERT INTO 'dancesrecordingsmap' VALUES (833, 2745, NULL, 1012);
INSERT INTO 'dancesrecordingsmap' VALUES (834, 2270, NULL, 1013);
INSERT INTO 'dancesrecordingsmap' VALUES (835, 8164, NULL, 1014);
INSERT INTO 'dancesrecordingsmap' VALUES (836, 3310, NULL, 1015);
INSERT INTO 'dancesrecordingsmap' VALUES (837, 6915, NULL, 1016);
INSERT INTO 'dancesrecordingsmap' VALUES (838, 905, NULL, 1017);
INSERT INTO 'dancesrecordingsmap' VALUES (839, 1473, NULL, 1018);
INSERT INTO 'dancesrecordingsmap' VALUES (840, 7553, NULL, 1019);
INSERT INTO 'dancesrecordingsmap' VALUES (841, 1210, NULL, 1020);
INSERT INTO 'dancesrecordingsmap' VALUES (842, 6701, NULL, 1021);
INSERT INTO 'dancesrecordingsmap' VALUES (843, 6048, NULL, 1022);
INSERT INTO 'dancesrecordingsmap' VALUES (844, 5915, NULL, 1023);
INSERT INTO 'dancesrecordingsmap' VALUES (845, 445, NULL, 1024);
INSERT INTO 'dancesrecordingsmap' VALUES (846, 1777, NULL, 1025);
INSERT INTO 'dancesrecordingsmap' VALUES (847, 3231, NULL, 1026);
INSERT INTO 'dancesrecordingsmap' VALUES (848, 1274, NULL, 1027);
INSERT INTO 'dancesrecordingsmap' VALUES (849, 3338, NULL, 1029);
INSERT INTO 'dancesrecordingsmap' VALUES (3436, 6236, NULL, 4356);
INSERT INTO 'dancesrecordingsmap' VALUES (3437, 89, NULL, 4358);
INSERT INTO 'dancesrecordingsmap' VALUES (3438, 8556, NULL, 701);
INSERT INTO 'dancesrecordingsmap' VALUES (3439, 8554, NULL, 955);
INSERT INTO 'dancesrecordingsmap' VALUES (3440, 8557, NULL, 960);
INSERT INTO 'dancesrecordingsmap' VALUES (3441, 8558, NULL, 961);
INSERT INTO 'dancesrecordingsmap' VALUES (3442, 8555, NULL, 962);
INSERT INTO 'dancesrecordingsmap' VALUES (3443, 7911, NULL, 963);
INSERT INTO 'dancesrecordingsmap' VALUES (3444, 4827, NULL, 4360);
INSERT INTO 'dancesrecordingsmap' VALUES (3445, 8860, NULL, 2170);
INSERT INTO 'dancesrecordingsmap' VALUES (3446, 6962, NULL, 4363);
INSERT INTO 'dancesrecordingsmap' VALUES (3447, 2254, NULL, 4364);
INSERT INTO 'dancesrecordingsmap' VALUES (3448, 1023, NULL, 4365);
INSERT INTO 'dancesrecordingsmap' VALUES (3449, 1727, NULL, 4366);
INSERT INTO 'dancesrecordingsmap' VALUES (3450, 4220, NULL, 4367);
INSERT INTO 'dancesrecordingsmap' VALUES (3451, 2039, NULL, 4368);
INSERT INTO 'dancesrecordingsmap' VALUES (3452, 2507, NULL, 4371);
INSERT INTO 'dancesrecordingsmap' VALUES (3453, 5972, NULL, 4372);
INSERT INTO 'dancesrecordingsmap' VALUES (3454, 8266, NULL, 1495);
INSERT INTO 'dancesrecordingsmap' VALUES (3455, 6915, NULL, 4373);
INSERT INTO 'dancesrecordingsmap' VALUES (3456, 6711, NULL, 4374);
INSERT INTO 'dancesrecordingsmap' VALUES (3457, 3561, NULL, 4375);
INSERT INTO 'dancesrecordingsmap' VALUES (3458, 7555, NULL, 4376);
INSERT INTO 'dancesrecordingsmap' VALUES (3459, 1792, NULL, 4377);
INSERT INTO 'dancesrecordingsmap' VALUES (3460, 3225, NULL, 4378);
INSERT INTO 'dancesrecordingsmap' VALUES (3461, 6915, NULL, 4379);
INSERT INTO 'dancesrecordingsmap' VALUES (3462, 1792, NULL, 4380);
INSERT INTO 'dancesrecordingsmap' VALUES (3463, 3561, NULL, 4381);
INSERT INTO 'dancesrecordingsmap' VALUES (3464, 5964, NULL, 4383);
INSERT INTO 'dancesrecordingsmap' VALUES (3465, 6915, NULL, 4385);
INSERT INTO 'dancesrecordingsmap' VALUES (3466, 7554, NULL, 4386);
INSERT INTO 'dancesrecordingsmap' VALUES (3467, 2745, NULL, 4389);
INSERT INTO 'dancesrecordingsmap' VALUES (3468, 7553, NULL, 4390);
INSERT INTO 'dancesrecordingsmap' VALUES (3469, 7546, NULL, 4391);
INSERT INTO 'dancesrecordingsmap' VALUES (3470, 3834, NULL, 4393);
INSERT INTO 'dancesrecordingsmap' VALUES (3471, 7546, NULL, 4396);
INSERT INTO 'dancesrecordingsmap' VALUES (3472, 8160, NULL, 4397);
INSERT INTO 'dancesrecordingsmap' VALUES (3473, 1210, NULL, 4400);
INSERT INTO 'dancesrecordingsmap' VALUES (3474, 8146, NULL, 4402);
INSERT INTO 'dancesrecordingsmap' VALUES (3475, 7554, NULL, 4403);
INSERT INTO 'dancesrecordingsmap' VALUES (3476, 7552, NULL, 4404);
INSERT INTO 'dancesrecordingsmap' VALUES (3477, 6915, NULL, 4406);
INSERT INTO 'dancesrecordingsmap' VALUES (8073, 5794, NULL, 8893);
INSERT INTO 'dancesrecordingsmap' VALUES (850, 373, NULL, 1030);
INSERT INTO 'dancesrecordingsmap' VALUES (854, 6915, NULL, 1037);
INSERT INTO 'dancesrecordingsmap' VALUES (858, 3454, NULL, 1042);
INSERT INTO 'dancesrecordingsmap' VALUES (859, 8161, NULL, 1044);
INSERT INTO 'dancesrecordingsmap' VALUES (860, 2506, NULL, 1046);
INSERT INTO 'dancesrecordingsmap' VALUES (861, 6712, NULL, 1051);
INSERT INTO 'dancesrecordingsmap' VALUES (862, 7906, NULL, 1055);
INSERT INTO 'dancesrecordingsmap' VALUES (863, 8152, NULL, 1061);
INSERT INTO 'dancesrecordingsmap' VALUES (864, 999, NULL, 1062);
INSERT INTO 'dancesrecordingsmap' VALUES (865, 154, NULL, 1063);
INSERT INTO 'dancesrecordingsmap' VALUES (867, 6532, NULL, 1065);
INSERT INTO 'dancesrecordingsmap' VALUES (868, 8154, NULL, 1066);
INSERT INTO 'dancesrecordingsmap' VALUES (869, 5641, NULL, 1072);
INSERT INTO 'dancesrecordingsmap' VALUES (870, 3774, NULL, 1073);
INSERT INTO 'dancesrecordingsmap' VALUES (871, 373, NULL, 1076);
INSERT INTO 'dancesrecordingsmap' VALUES (872, 153, NULL, 1077);
INSERT INTO 'dancesrecordingsmap' VALUES (873, 1210, NULL, 1079);
INSERT INTO 'dancesrecordingsmap' VALUES (874, 1244, NULL, 1082);
INSERT INTO 'dancesrecordingsmap' VALUES (875, 2616, NULL, 1083);
INSERT INTO 'dancesrecordingsmap' VALUES (876, 5168, NULL, 1084);
INSERT INTO 'dancesrecordingsmap' VALUES (877, 7055, NULL, 1085);
INSERT INTO 'dancesrecordingsmap' VALUES (878, 985, NULL, 1086);
INSERT INTO 'dancesrecordingsmap' VALUES (879, 373, NULL, 1087);
INSERT INTO 'dancesrecordingsmap' VALUES (880, 5936, NULL, 1088);
INSERT INTO 'dancesrecordingsmap' VALUES (881, 6420, NULL, 1089);
INSERT INTO 'dancesrecordingsmap' VALUES (882, 7139, NULL, 1091);
INSERT INTO 'dancesrecordingsmap' VALUES (883, 6915, NULL, 1092);
INSERT INTO 'dancesrecordingsmap' VALUES (884, 353, NULL, 1093);
INSERT INTO 'dancesrecordingsmap' VALUES (885, 4663, NULL, 1094);
INSERT INTO 'dancesrecordingsmap' VALUES (886, 6091, NULL, 1095);
INSERT INTO 'dancesrecordingsmap' VALUES (888, 3129, NULL, 1098);
INSERT INTO 'dancesrecordingsmap' VALUES (889, 584, NULL, 1099);
INSERT INTO 'dancesrecordingsmap' VALUES (890, 3281, NULL, 1100);
INSERT INTO 'dancesrecordingsmap' VALUES (891, 7019, NULL, 1101);
INSERT INTO 'dancesrecordingsmap' VALUES (892, 549, NULL, 1102);
INSERT INTO 'dancesrecordingsmap' VALUES (893, 2812, NULL, 1103);
INSERT INTO 'dancesrecordingsmap' VALUES (894, 5658, NULL, 1104);
INSERT INTO 'dancesrecordingsmap' VALUES (895, 5731, NULL, 1105);
INSERT INTO 'dancesrecordingsmap' VALUES (896, 8154, NULL, 1106);
INSERT INTO 'dancesrecordingsmap' VALUES (897, 8142, NULL, 1108);
INSERT INTO 'dancesrecordingsmap' VALUES (898, 7546, NULL, 1110);
INSERT INTO 'dancesrecordingsmap' VALUES (899, 3672, NULL, 1111);
INSERT INTO 'dancesrecordingsmap' VALUES (779, 6640, NULL, 951);
INSERT INTO 'dancesrecordingsmap' VALUES (785, 8065, NULL, 89);
INSERT INTO 'dancesrecordingsmap' VALUES (777, 2722, NULL, 949);
INSERT INTO 'dancesrecordingsmap' VALUES (772, 7135, NULL, 914);
INSERT INTO 'dancesrecordingsmap' VALUES (773, 1473, NULL, 919);
INSERT INTO 'dancesrecordingsmap' VALUES (775, 6862, NULL, 947);
INSERT INTO 'dancesrecordingsmap' VALUES (778, 6035, NULL, 950);
INSERT INTO 'dancesrecordingsmap' VALUES (780, 5217, NULL, 952);
INSERT INTO 'dancesrecordingsmap' VALUES (782, 629, NULL, 954);
INSERT INTO 'dancesrecordingsmap' VALUES (900, 1927, NULL, 1112);
INSERT INTO 'dancesrecordingsmap' VALUES (901, 6712, NULL, 1113);
INSERT INTO 'dancesrecordingsmap' VALUES (902, 1758, NULL, 1114);
INSERT INTO 'dancesrecordingsmap' VALUES (903, 8146, NULL, 1116);
INSERT INTO 'dancesrecordingsmap' VALUES (904, 8143, NULL, 1118);
INSERT INTO 'dancesrecordingsmap' VALUES (905, 1786, NULL, 1120);
INSERT INTO 'dancesrecordingsmap' VALUES (906, 3142, NULL, 1121);
INSERT INTO 'dancesrecordingsmap' VALUES (907, 1501, NULL, 1122);
INSERT INTO 'dancesrecordingsmap' VALUES (908, 2777, NULL, 1123);
INSERT INTO 'dancesrecordingsmap' VALUES (909, 521, NULL, 1124);
INSERT INTO 'dancesrecordingsmap' VALUES (910, 2807, NULL, 1125);
INSERT INTO 'dancesrecordingsmap' VALUES (911, 4209, NULL, 1126);
INSERT INTO 'dancesrecordingsmap' VALUES (787, 5635, NULL, 726);
INSERT INTO 'dancesrecordingsmap' VALUES (815, 2100, NULL, 987);
INSERT INTO 'dancesrecordingsmap' VALUES (887, 3074, NULL, 1096);
INSERT INTO 'dancesrecordingsmap' VALUES (912, 353, NULL, 1127);
INSERT INTO 'dancesrecordingsmap' VALUES (913, 4991, NULL, 1128);
INSERT INTO 'dancesrecordingsmap' VALUES (914, 3129, NULL, 1129);
INSERT INTO 'dancesrecordingsmap' VALUES (916, 6112, NULL, 1131);
INSERT INTO 'dancesrecordingsmap' VALUES (917, 6981, NULL, 1132);
INSERT INTO 'dancesrecordingsmap' VALUES (918, 721, NULL, 1133);
INSERT INTO 'dancesrecordingsmap' VALUES (919, 6407, NULL, 1134);
INSERT INTO 'dancesrecordingsmap' VALUES (920, 6885, NULL, 1135);
INSERT INTO 'dancesrecordingsmap' VALUES (921, 3027, NULL, 1136);
INSERT INTO 'dancesrecordingsmap' VALUES (807, 7031, NULL, 977);
INSERT INTO 'dancesrecordingsmap' VALUES (856, 2498, NULL, 1039);
INSERT INTO 'dancesrecordingsmap' VALUES (866, 3246, NULL, 1064);
INSERT INTO 'dancesrecordingsmap' VALUES (857, 2745, NULL, 1041);
INSERT INTO 'dancesrecordingsmap' VALUES (811, 822, NULL, 981);
INSERT INTO 'dancesrecordingsmap' VALUES (852, 5964, NULL, 1035);
INSERT INTO 'dancesrecordingsmap' VALUES (853, 3152, NULL, 1036);
INSERT INTO 'dancesrecordingsmap' VALUES (814, 170, NULL, 986);
INSERT INTO 'dancesrecordingsmap' VALUES (831, 5807, NULL, 1010);
INSERT INTO 'dancesrecordingsmap' VALUES (922, 6791, NULL, 1137);
INSERT INTO 'dancesrecordingsmap' VALUES (923, 6471, NULL, 1138);
INSERT INTO 'dancesrecordingsmap' VALUES (924, 1773, NULL, 1139);
INSERT INTO 'dancesrecordingsmap' VALUES (925, 2052, NULL, 1140);
INSERT INTO 'dancesrecordingsmap' VALUES (926, 2494, NULL, 1141);
INSERT INTO 'dancesrecordingsmap' VALUES (927, 6523, NULL, 1142);
INSERT INTO 'dancesrecordingsmap' VALUES (928, 1799, NULL, 1143);
INSERT INTO 'dancesrecordingsmap' VALUES (929, 5937, NULL, 1144);
INSERT INTO 'dancesrecordingsmap' VALUES (5405, 11993, NULL, 5955);
INSERT INTO 'dancesrecordingsmap' VALUES (931, 1562, NULL, 1146);
INSERT INTO 'dancesrecordingsmap' VALUES (932, 1931, NULL, 1147);
INSERT INTO 'dancesrecordingsmap' VALUES (933, 2745, NULL, 1148);
INSERT INTO 'dancesrecordingsmap' VALUES (934, 1792, NULL, 1149);
INSERT INTO 'dancesrecordingsmap' VALUES (935, 1792, NULL, 1150);
INSERT INTO 'dancesrecordingsmap' VALUES (936, 1782, NULL, 1151);
INSERT INTO 'dancesrecordingsmap' VALUES (937, 1782, NULL, 1152);
INSERT INTO 'dancesrecordingsmap' VALUES (938, 6233, NULL, 1153);
INSERT INTO 'dancesrecordingsmap' VALUES (939, 6233, NULL, 1154);
INSERT INTO 'dancesrecordingsmap' VALUES (940, 5525, NULL, 1155);
INSERT INTO 'dancesrecordingsmap' VALUES (941, 5525, NULL, 1156);
INSERT INTO 'dancesrecordingsmap' VALUES (942, 5964, NULL, 1157);
INSERT INTO 'dancesrecordingsmap' VALUES (3478, 7546, NULL, 4408);
INSERT INTO 'dancesrecordingsmap' VALUES (3479, 1884, NULL, 4411);
INSERT INTO 'dancesrecordingsmap' VALUES (3480, 5006, NULL, 4415);
INSERT INTO 'dancesrecordingsmap' VALUES (3481, 7284, NULL, 4416);
INSERT INTO 'dancesrecordingsmap' VALUES (3482, 5497, NULL, 4419);
INSERT INTO 'dancesrecordingsmap' VALUES (3483, 1473, NULL, 4421);
INSERT INTO 'dancesrecordingsmap' VALUES (3484, 7548, NULL, 4425);
INSERT INTO 'dancesrecordingsmap' VALUES (3485, 2267, NULL, 4426);
INSERT INTO 'dancesrecordingsmap' VALUES (3486, 1478, NULL, 1212);
INSERT INTO 'dancesrecordingsmap' VALUES (3487, 8144, NULL, 2168);
INSERT INTO 'dancesrecordingsmap' VALUES (3488, 4862, NULL, 4427);
INSERT INTO 'dancesrecordingsmap' VALUES (3490, 8153, NULL, 4436);
INSERT INTO 'dancesrecordingsmap' VALUES (3491, 905, NULL, 4437);
INSERT INTO 'dancesrecordingsmap' VALUES (3492, 7552, NULL, 4438);
INSERT INTO 'dancesrecordingsmap' VALUES (3493, 7546, NULL, 4440);
INSERT INTO 'dancesrecordingsmap' VALUES (3494, 8150, NULL, 4444);
INSERT INTO 'dancesrecordingsmap' VALUES (995, 4356, NULL, 1253);
INSERT INTO 'dancesrecordingsmap' VALUES (3501, 656, NULL, 4470);
INSERT INTO 'dancesrecordingsmap' VALUES (3502, 8146, NULL, 4471);
INSERT INTO 'dancesrecordingsmap' VALUES (3503, 5497, NULL, 4476);
INSERT INTO 'dancesrecordingsmap' VALUES (3504, 1562, NULL, 4478);
INSERT INTO 'dancesrecordingsmap' VALUES (3505, 7553, NULL, 4480);
INSERT INTO 'dancesrecordingsmap' VALUES (3506, 6233, NULL, 4481);
INSERT INTO 'dancesrecordingsmap' VALUES (3507, 980, NULL, 4483);
INSERT INTO 'dancesrecordingsmap' VALUES (3508, 5731, NULL, 4484);
INSERT INTO 'dancesrecordingsmap' VALUES (3509, 7546, NULL, 4485);
INSERT INTO 'dancesrecordingsmap' VALUES (3510, 3725, NULL, 4487);
INSERT INTO 'dancesrecordingsmap' VALUES (3511, 1473, NULL, 4488);
INSERT INTO 'dancesrecordingsmap' VALUES (3512, 89, NULL, 4488);
INSERT INTO 'dancesrecordingsmap' VALUES (3513, 4008, NULL, 4489);
INSERT INTO 'dancesrecordingsmap' VALUES (3514, 8154, NULL, 4490);
INSERT INTO 'dancesrecordingsmap' VALUES (3516, 6104, NULL, 4492);
INSERT INTO 'dancesrecordingsmap' VALUES (3517, 4998, NULL, 4493);
INSERT INTO 'dancesrecordingsmap' VALUES (3518, 8033, NULL, 4494);
INSERT INTO 'dancesrecordingsmap' VALUES (3519, 7501, NULL, 4495);
INSERT INTO 'dancesrecordingsmap' VALUES (3520, 7552, NULL, 4496);
INSERT INTO 'dancesrecordingsmap' VALUES (3521, 2203, NULL, 4497);
INSERT INTO 'dancesrecordingsmap' VALUES (3522, 8146, NULL, 4498);
INSERT INTO 'dancesrecordingsmap' VALUES (3523, 7546, NULL, 4498);
INSERT INTO 'dancesrecordingsmap' VALUES (3524, 5703, NULL, 4499);
INSERT INTO 'dancesrecordingsmap' VALUES (3526, 7546, NULL, 4502);
INSERT INTO 'dancesrecordingsmap' VALUES (3527, 3953, NULL, 4503);
INSERT INTO 'dancesrecordingsmap' VALUES (3528, 8154, NULL, 4504);
INSERT INTO 'dancesrecordingsmap' VALUES (3529, 5207, NULL, 4506);
INSERT INTO 'dancesrecordingsmap' VALUES (3530, 76, NULL, 4507);
INSERT INTO 'dancesrecordingsmap' VALUES (8061, 13627, NULL, 8880);
INSERT INTO 'dancesrecordingsmap' VALUES (943, 8154, NULL, 1166);
INSERT INTO 'dancesrecordingsmap' VALUES (944, 2956, NULL, 1169);
INSERT INTO 'dancesrecordingsmap' VALUES (945, 7574, NULL, 1171);
INSERT INTO 'dancesrecordingsmap' VALUES (946, 8142, NULL, 1173);
INSERT INTO 'dancesrecordingsmap' VALUES (947, 1210, NULL, 1175);
INSERT INTO 'dancesrecordingsmap' VALUES (948, 1931, NULL, 1176);
INSERT INTO 'dancesrecordingsmap' VALUES (949, 4239, NULL, 1178);
INSERT INTO 'dancesrecordingsmap' VALUES (950, 7555, NULL, 1180);
INSERT INTO 'dancesrecordingsmap' VALUES (951, 2745, NULL, 1181);
INSERT INTO 'dancesrecordingsmap' VALUES (952, 1792, NULL, 1184);
INSERT INTO 'dancesrecordingsmap' VALUES (953, 5964, NULL, 1186);
INSERT INTO 'dancesrecordingsmap' VALUES (954, 2916, NULL, 1189);
INSERT INTO 'dancesrecordingsmap' VALUES (955, 3759, NULL, 1190);
INSERT INTO 'dancesrecordingsmap' VALUES (956, 8148, NULL, 1191);
INSERT INTO 'dancesrecordingsmap' VALUES (957, 3152, NULL, 1192);
INSERT INTO 'dancesrecordingsmap' VALUES (958, 3057, NULL, 1193);
INSERT INTO 'dancesrecordingsmap' VALUES (959, 7546, NULL, 1195);
INSERT INTO 'dancesrecordingsmap' VALUES (960, 2916, NULL, 1196);
INSERT INTO 'dancesrecordingsmap' VALUES (961, 588, NULL, 1197);
INSERT INTO 'dancesrecordingsmap' VALUES (962, 6236, NULL, 1198);
INSERT INTO 'dancesrecordingsmap' VALUES (963, 7555, NULL, 1200);
INSERT INTO 'dancesrecordingsmap' VALUES (964, 5963, NULL, 1201);
INSERT INTO 'dancesrecordingsmap' VALUES (965, 6712, NULL, 1202);
INSERT INTO 'dancesrecordingsmap' VALUES (966, 8146, NULL, 1203);
INSERT INTO 'dancesrecordingsmap' VALUES (967, 1838, NULL, 1204);
INSERT INTO 'dancesrecordingsmap' VALUES (968, 6817, NULL, 1206);
INSERT INTO 'dancesrecordingsmap' VALUES (969, 4911, NULL, 1208);
INSERT INTO 'dancesrecordingsmap' VALUES (970, 1927, NULL, 1213);
INSERT INTO 'dancesrecordingsmap' VALUES (971, 2140, NULL, 1214);
INSERT INTO 'dancesrecordingsmap' VALUES (972, 7546, NULL, 1219);
INSERT INTO 'dancesrecordingsmap' VALUES (973, 1881, NULL, 1224);
INSERT INTO 'dancesrecordingsmap' VALUES (974, 2250, NULL, 1225);
INSERT INTO 'dancesrecordingsmap' VALUES (975, 2979, NULL, 1226);
INSERT INTO 'dancesrecordingsmap' VALUES (976, 5525, NULL, 1227);
INSERT INTO 'dancesrecordingsmap' VALUES (977, 8143, NULL, 1228);
INSERT INTO 'dancesrecordingsmap' VALUES (978, 4106, NULL, 1233);
INSERT INTO 'dancesrecordingsmap' VALUES (979, 7546, NULL, 1235);
INSERT INTO 'dancesrecordingsmap' VALUES (980, 610, NULL, 1237);
INSERT INTO 'dancesrecordingsmap' VALUES (981, 5362, NULL, 1238);
INSERT INTO 'dancesrecordingsmap' VALUES (982, 1916, NULL, 1239);
INSERT INTO 'dancesrecordingsmap' VALUES (983, 3940, NULL, 1240);
INSERT INTO 'dancesrecordingsmap' VALUES (984, 6585, NULL, 1241);
INSERT INTO 'dancesrecordingsmap' VALUES (985, 6130, NULL, 1242);
INSERT INTO 'dancesrecordingsmap' VALUES (987, 5731, NULL, 1244);
INSERT INTO 'dancesrecordingsmap' VALUES (988, 3775, NULL, 1245);
INSERT INTO 'dancesrecordingsmap' VALUES (989, 3046, NULL, 1246);
INSERT INTO 'dancesrecordingsmap' VALUES (990, 4782, NULL, 1247);
INSERT INTO 'dancesrecordingsmap' VALUES (991, 5141, NULL, 1248);
INSERT INTO 'dancesrecordingsmap' VALUES (992, 3623, NULL, 1249);
INSERT INTO 'dancesrecordingsmap' VALUES (993, 4309, NULL, 1251);
INSERT INTO 'dancesrecordingsmap' VALUES (994, 6477, NULL, 1252);
INSERT INTO 'dancesrecordingsmap' VALUES (996, 7245, NULL, 1254);
INSERT INTO 'dancesrecordingsmap' VALUES (997, 7242, NULL, 1256);
INSERT INTO 'dancesrecordingsmap' VALUES (998, 1296, NULL, 1257);
INSERT INTO 'dancesrecordingsmap' VALUES (999, 5351, NULL, 1258);
INSERT INTO 'dancesrecordingsmap' VALUES (1000, 754, NULL, 1259);
INSERT INTO 'dancesrecordingsmap' VALUES (1001, 1018, NULL, 1260);
INSERT INTO 'dancesrecordingsmap' VALUES (1002, 3722, NULL, 1261);
INSERT INTO 'dancesrecordingsmap' VALUES (1003, 6763, NULL, 1262);
INSERT INTO 'dancesrecordingsmap' VALUES (1004, 5591, NULL, 1263);
INSERT INTO 'dancesrecordingsmap' VALUES (1005, 3972, NULL, 1264);
INSERT INTO 'dancesrecordingsmap' VALUES (1006, 571, NULL, 1265);
INSERT INTO 'dancesrecordingsmap' VALUES (1007, 6599, NULL, 1266);
INSERT INTO 'dancesrecordingsmap' VALUES (1008, 3246, NULL, 1267);
INSERT INTO 'dancesrecordingsmap' VALUES (1009, 958, NULL, 1269);
INSERT INTO 'dancesrecordingsmap' VALUES (1010, 5032, NULL, 1270);
INSERT INTO 'dancesrecordingsmap' VALUES (1011, 738, NULL, 1271);
INSERT INTO 'dancesrecordingsmap' VALUES (1012, 3730, NULL, 1272);
INSERT INTO 'dancesrecordingsmap' VALUES (1013, 3611, NULL, 1273);
INSERT INTO 'dancesrecordingsmap' VALUES (1014, 1415, NULL, 1274);
INSERT INTO 'dancesrecordingsmap' VALUES (1015, 3091, NULL, 1275);
INSERT INTO 'dancesrecordingsmap' VALUES (1016, 5937, NULL, 1276);
INSERT INTO 'dancesrecordingsmap' VALUES (1017, 4068, NULL, 1277);
INSERT INTO 'dancesrecordingsmap' VALUES (1018, 3152, NULL, 1278);
INSERT INTO 'dancesrecordingsmap' VALUES (1019, 3642, NULL, 1279);
INSERT INTO 'dancesrecordingsmap' VALUES (1020, 6036, NULL, 1280);
INSERT INTO 'dancesrecordingsmap' VALUES (1021, 2428, NULL, 1281);
INSERT INTO 'dancesrecordingsmap' VALUES (1022, 3541, NULL, 1282);
INSERT INTO 'dancesrecordingsmap' VALUES (1023, 4646, NULL, 1283);
INSERT INTO 'dancesrecordingsmap' VALUES (1024, 3342, NULL, 1284);
INSERT INTO 'dancesrecordingsmap' VALUES (1025, 3084, NULL, 1285);
INSERT INTO 'dancesrecordingsmap' VALUES (1026, 6152, NULL, 1286);
INSERT INTO 'dancesrecordingsmap' VALUES (1027, 2495, NULL, 1287);
INSERT INTO 'dancesrecordingsmap' VALUES (1028, 1496, NULL, 1288);
INSERT INTO 'dancesrecordingsmap' VALUES (1029, 4679, NULL, 1289);
INSERT INTO 'dancesrecordingsmap' VALUES (1030, 3912, NULL, 1290);
INSERT INTO 'dancesrecordingsmap' VALUES (3497, 8749, NULL, 4463);
INSERT INTO 'dancesrecordingsmap' VALUES (3496, 2239, NULL, 4462);
INSERT INTO 'dancesrecordingsmap' VALUES (3498, 462, NULL, 4466);
INSERT INTO 'dancesrecordingsmap' VALUES (3499, 3672, NULL, 4467);
INSERT INTO 'dancesrecordingsmap' VALUES (3500, 6748, NULL, 4468);
INSERT INTO 'dancesrecordingsmap' VALUES (3489, 3129, NULL, 4433);
INSERT INTO 'dancesrecordingsmap' VALUES (915, 4086, NULL, 1130);
INSERT INTO 'dancesrecordingsmap' VALUES (1031, 3105, NULL, 1291);
INSERT INTO 'dancesrecordingsmap' VALUES (1032, 4559, NULL, 1292);
INSERT INTO 'dancesrecordingsmap' VALUES (1033, 2644, NULL, 1293);
INSERT INTO 'dancesrecordingsmap' VALUES (1034, 2661, NULL, 1294);
INSERT INTO 'dancesrecordingsmap' VALUES (1035, 3235, NULL, 1295);
INSERT INTO 'dancesrecordingsmap' VALUES (1036, 3656, NULL, 1296);
INSERT INTO 'dancesrecordingsmap' VALUES (1037, 2140, NULL, 1297);
INSERT INTO 'dancesrecordingsmap' VALUES (1038, 7247, NULL, 1298);
INSERT INTO 'dancesrecordingsmap' VALUES (1039, 5520, NULL, 1299);
INSERT INTO 'dancesrecordingsmap' VALUES (1040, 6178, NULL, 1300);
INSERT INTO 'dancesrecordingsmap' VALUES (1041, 541, NULL, 1301);
INSERT INTO 'dancesrecordingsmap' VALUES (1042, 1883, NULL, 1302);
INSERT INTO 'dancesrecordingsmap' VALUES (1043, 3528, NULL, 1303);
INSERT INTO 'dancesrecordingsmap' VALUES (1044, 6029, NULL, 1304);
INSERT INTO 'dancesrecordingsmap' VALUES (1045, 3412, NULL, 1305);
INSERT INTO 'dancesrecordingsmap' VALUES (1046, 1437, NULL, 1306);
INSERT INTO 'dancesrecordingsmap' VALUES (1047, 3888, NULL, 1307);
INSERT INTO 'dancesrecordingsmap' VALUES (1048, 76, NULL, 1308);
INSERT INTO 'dancesrecordingsmap' VALUES (1049, 5463, NULL, 1309);
INSERT INTO 'dancesrecordingsmap' VALUES (1050, 7143, NULL, 1310);
INSERT INTO 'dancesrecordingsmap' VALUES (1051, 43, NULL, 1311);
INSERT INTO 'dancesrecordingsmap' VALUES (1052, 6721, NULL, 1312);
INSERT INTO 'dancesrecordingsmap' VALUES (1053, 5878, NULL, 1313);
INSERT INTO 'dancesrecordingsmap' VALUES (3515, 1244, NULL, 4491);
INSERT INTO 'dancesrecordingsmap' VALUES (1054, 1020, NULL, 1314);
INSERT INTO 'dancesrecordingsmap' VALUES (1055, 6848, NULL, 1315);
INSERT INTO 'dancesrecordingsmap' VALUES (1056, 4431, NULL, 1316);
INSERT INTO 'dancesrecordingsmap' VALUES (1057, 6885, NULL, 1317);
INSERT INTO 'dancesrecordingsmap' VALUES (1058, 4440, NULL, 1318);
INSERT INTO 'dancesrecordingsmap' VALUES (1059, 4455, NULL, 1319);
INSERT INTO 'dancesrecordingsmap' VALUES (1060, 1762, NULL, 1320);
INSERT INTO 'dancesrecordingsmap' VALUES (1061, 4565, NULL, 1321);
INSERT INTO 'dancesrecordingsmap' VALUES (3531, 3672, NULL, 4509);
INSERT INTO 'dancesrecordingsmap' VALUES (3532, 1244, NULL, 4512);
INSERT INTO 'dancesrecordingsmap' VALUES (3533, 7546, NULL, 4515);
INSERT INTO 'dancesrecordingsmap' VALUES (3534, 3165, NULL, 4516);
INSERT INTO 'dancesrecordingsmap' VALUES (3535, 4927, NULL, 4519);
INSERT INTO 'dancesrecordingsmap' VALUES (3536, 3834, NULL, 4520);
INSERT INTO 'dancesrecordingsmap' VALUES (3537, 7553, NULL, 4521);
INSERT INTO 'dancesrecordingsmap' VALUES (3538, 8910, NULL, 3184);
INSERT INTO 'dancesrecordingsmap' VALUES (3539, 8911, NULL, 1231);
INSERT INTO 'dancesrecordingsmap' VALUES (3540, 8912, NULL, 768);
INSERT INTO 'dancesrecordingsmap' VALUES (3542, 8914, NULL, 4193);
INSERT INTO 'dancesrecordingsmap' VALUES (3543, 8915, NULL, 1091);
INSERT INTO 'dancesrecordingsmap' VALUES (3545, 8917, NULL, 1234);
INSERT INTO 'dancesrecordingsmap' VALUES (3546, 8918, NULL, 2044);
INSERT INTO 'dancesrecordingsmap' VALUES (3547, 8919, NULL, 723);
INSERT INTO 'dancesrecordingsmap' VALUES (3548, 7034, NULL, 1643);
INSERT INTO 'dancesrecordingsmap' VALUES (3549, 632, NULL, 2217);
INSERT INTO 'dancesrecordingsmap' VALUES (3551, 2758, NULL, 169);
INSERT INTO 'dancesrecordingsmap' VALUES (3552, 2908, NULL, 2273);
INSERT INTO 'dancesrecordingsmap' VALUES (3553, 3254, NULL, 469);
INSERT INTO 'dancesrecordingsmap' VALUES (3554, 3260, NULL, 661);
INSERT INTO 'dancesrecordingsmap' VALUES (3555, 3288, NULL, 1231);
INSERT INTO 'dancesrecordingsmap' VALUES (3556, 6246, NULL, 228);
INSERT INTO 'dancesrecordingsmap' VALUES (8062, 14437, NULL, 8881);
INSERT INTO 'dancesrecordingsmap' VALUES (1062, 4518, NULL, 1322);
INSERT INTO 'dancesrecordingsmap' VALUES (1063, 5441, NULL, 1323);
INSERT INTO 'dancesrecordingsmap' VALUES (1064, 2024, NULL, 1324);
INSERT INTO 'dancesrecordingsmap' VALUES (1065, 1280, NULL, 1325);
INSERT INTO 'dancesrecordingsmap' VALUES (1066, 4558, NULL, 1326);
INSERT INTO 'dancesrecordingsmap' VALUES (1068, 1776, NULL, 1328);
INSERT INTO 'dancesrecordingsmap' VALUES (1069, 877, NULL, 1329);
INSERT INTO 'dancesrecordingsmap' VALUES (1070, 5519, NULL, 1330);
INSERT INTO 'dancesrecordingsmap' VALUES (1071, 5858, NULL, 1331);
INSERT INTO 'dancesrecordingsmap' VALUES (1073, 4563, NULL, 1333);
INSERT INTO 'dancesrecordingsmap' VALUES (1074, 301, NULL, 1334);
INSERT INTO 'dancesrecordingsmap' VALUES (1075, 6710, NULL, 1335);
INSERT INTO 'dancesrecordingsmap' VALUES (1076, 5347, NULL, 1336);
INSERT INTO 'dancesrecordingsmap' VALUES (1077, 656, NULL, 1337);
INSERT INTO 'dancesrecordingsmap' VALUES (1078, 6285, NULL, 1338);
INSERT INTO 'dancesrecordingsmap' VALUES (1079, 4100, NULL, 1339);
INSERT INTO 'dancesrecordingsmap' VALUES (1080, 4767, NULL, 1340);
INSERT INTO 'dancesrecordingsmap' VALUES (1081, 2010, NULL, 1341);
INSERT INTO 'dancesrecordingsmap' VALUES (1082, 4579, NULL, 1342);
INSERT INTO 'dancesrecordingsmap' VALUES (1083, 6824, NULL, 1343);
INSERT INTO 'dancesrecordingsmap' VALUES (1084, 4995, NULL, 1344);
INSERT INTO 'dancesrecordingsmap' VALUES (1085, 3685, NULL, 453);
INSERT INTO 'dancesrecordingsmap' VALUES (1086, 3938, NULL, 1250);
INSERT INTO 'dancesrecordingsmap' VALUES (1091, 5691, NULL, 1347);
INSERT INTO 'dancesrecordingsmap' VALUES (1092, 1283, NULL, 1348);
INSERT INTO 'dancesrecordingsmap' VALUES (1094, 2918, NULL, 1350);
INSERT INTO 'dancesrecordingsmap' VALUES (1095, 430, NULL, 1351);
INSERT INTO 'dancesrecordingsmap' VALUES (1096, 6359, NULL, 1352);
INSERT INTO 'dancesrecordingsmap' VALUES (1097, 4126, NULL, 1353);
INSERT INTO 'dancesrecordingsmap' VALUES (1098, 910, NULL, 1354);
INSERT INTO 'dancesrecordingsmap' VALUES (1099, 6058, NULL, 1355);
INSERT INTO 'dancesrecordingsmap' VALUES (1100, 5934, NULL, 1356);
INSERT INTO 'dancesrecordingsmap' VALUES (1101, 6116, NULL, 1357);
INSERT INTO 'dancesrecordingsmap' VALUES (1102, 1428, NULL, 1358);
INSERT INTO 'dancesrecordingsmap' VALUES (1103, 4844, NULL, 1359);
INSERT INTO 'dancesrecordingsmap' VALUES (1104, 6368, NULL, 1360);
INSERT INTO 'dancesrecordingsmap' VALUES (1105, 3165, NULL, 1361);
INSERT INTO 'dancesrecordingsmap' VALUES (1106, 442, NULL, 1362);
INSERT INTO 'dancesrecordingsmap' VALUES (1107, 3763, NULL, 1363);
INSERT INTO 'dancesrecordingsmap' VALUES (1108, 1579, NULL, 1364);
INSERT INTO 'dancesrecordingsmap' VALUES (1109, 2910, NULL, 1365);
INSERT INTO 'dancesrecordingsmap' VALUES (1110, 2389, NULL, 1366);
INSERT INTO 'dancesrecordingsmap' VALUES (1111, 480, NULL, 1367);
INSERT INTO 'dancesrecordingsmap' VALUES (1112, 4476, NULL, 1368);
INSERT INTO 'dancesrecordingsmap' VALUES (1113, 4336, NULL, 1369);
INSERT INTO 'dancesrecordingsmap' VALUES (1114, 6981, NULL, 1370);
INSERT INTO 'dancesrecordingsmap' VALUES (1116, 5539, NULL, 1372);
INSERT INTO 'dancesrecordingsmap' VALUES (1118, 223, NULL, 1374);
INSERT INTO 'dancesrecordingsmap' VALUES (1119, 6391, NULL, 1375);
INSERT INTO 'dancesrecordingsmap' VALUES (1121, 5755, NULL, 1377);
INSERT INTO 'dancesrecordingsmap' VALUES (1122, 3575, NULL, 1378);
INSERT INTO 'dancesrecordingsmap' VALUES (1123, 655, NULL, 1380);
INSERT INTO 'dancesrecordingsmap' VALUES (1124, 2725, NULL, 1381);
INSERT INTO 'dancesrecordingsmap' VALUES (1125, 5529, NULL, 1382);
INSERT INTO 'dancesrecordingsmap' VALUES (1126, 2332, NULL, 1384);
INSERT INTO 'dancesrecordingsmap' VALUES (1127, 2353, NULL, 1385);
INSERT INTO 'dancesrecordingsmap' VALUES (1128, 3365, NULL, 1388);
INSERT INTO 'dancesrecordingsmap' VALUES (1129, 1768, NULL, 1389);
INSERT INTO 'dancesrecordingsmap' VALUES (1130, 5422, NULL, 1390);
INSERT INTO 'dancesrecordingsmap' VALUES (1131, 6701, NULL, 1392);
INSERT INTO 'dancesrecordingsmap' VALUES (1132, 2323, NULL, 1393);
INSERT INTO 'dancesrecordingsmap' VALUES (1133, 4256, NULL, 1395);
INSERT INTO 'dancesrecordingsmap' VALUES (1134, 4424, NULL, 1396);
INSERT INTO 'dancesrecordingsmap' VALUES (1135, 4444, NULL, 1397);
INSERT INTO 'dancesrecordingsmap' VALUES (1137, 5904, NULL, 1399);
INSERT INTO 'dancesrecordingsmap' VALUES (1138, 2158, NULL, 1400);
INSERT INTO 'dancesrecordingsmap' VALUES (1139, 6271, NULL, 1401);
INSERT INTO 'dancesrecordingsmap' VALUES (1140, 7055, NULL, 1402);
INSERT INTO 'dancesrecordingsmap' VALUES (3544, 8916, NULL, 383);
INSERT INTO 'dancesrecordingsmap' VALUES (1143, 6748, NULL, 1409);
INSERT INTO 'dancesrecordingsmap' VALUES (1144, 8146, NULL, 1228);
INSERT INTO 'dancesrecordingsmap' VALUES (1145, 2391, NULL, 107);
INSERT INTO 'dancesrecordingsmap' VALUES (1146, 6449, NULL, 24);
INSERT INTO 'dancesrecordingsmap' VALUES (1147, 105, NULL, 123);
INSERT INTO 'dancesrecordingsmap' VALUES (1148, 7011, NULL, 170);
INSERT INTO 'dancesrecordingsmap' VALUES (1149, 7208, NULL, 235);
INSERT INTO 'dancesrecordingsmap' VALUES (1150, 1479, NULL, 240);
INSERT INTO 'dancesrecordingsmap' VALUES (1151, 236, NULL, 922);
INSERT INTO 'dancesrecordingsmap' VALUES (1153, 4344, NULL, 1383);
INSERT INTO 'dancesrecordingsmap' VALUES (3557, 6766, NULL, 854);
INSERT INTO 'dancesrecordingsmap' VALUES (3558, 7546, NULL, 4522);
INSERT INTO 'dancesrecordingsmap' VALUES (3559, 723, NULL, 4523);
INSERT INTO 'dancesrecordingsmap' VALUES (3560, 7554, NULL, 4524);
INSERT INTO 'dancesrecordingsmap' VALUES (3561, 7552, NULL, 4525);
INSERT INTO 'dancesrecordingsmap' VALUES (3562, 1280, NULL, 4527);
INSERT INTO 'dancesrecordingsmap' VALUES (3563, 2807, NULL, 4529);
INSERT INTO 'dancesrecordingsmap' VALUES (3564, 8154, NULL, 4531);
INSERT INTO 'dancesrecordingsmap' VALUES (3565, 2024, NULL, 4533);
INSERT INTO 'dancesrecordingsmap' VALUES (3566, 7553, NULL, 4535);
INSERT INTO 'dancesrecordingsmap' VALUES (3567, 1562, NULL, 4536);
INSERT INTO 'dancesrecordingsmap' VALUES (3569, 8161, NULL, 2862);
INSERT INTO 'dancesrecordingsmap' VALUES (3570, 109, NULL, 2624);
INSERT INTO 'dancesrecordingsmap' VALUES (3571, 1480, NULL, 2622);
INSERT INTO 'dancesrecordingsmap' VALUES (3572, 2593, NULL, 2617);
INSERT INTO 'dancesrecordingsmap' VALUES (3573, 4491, NULL, 2620);
INSERT INTO 'dancesrecordingsmap' VALUES (3574, 4484, NULL, 2625);
INSERT INTO 'dancesrecordingsmap' VALUES (3575, 2250, NULL, 4405);
INSERT INTO 'dancesrecordingsmap' VALUES (3577, 3619, NULL, 2950);
INSERT INTO 'dancesrecordingsmap' VALUES (3578, 75, NULL, 2950);
INSERT INTO 'dancesrecordingsmap' VALUES (3579, 88, NULL, 2953);
INSERT INTO 'dancesrecordingsmap' VALUES (3580, 8140, NULL, 2953);
INSERT INTO 'dancesrecordingsmap' VALUES (3581, 62, NULL, 2951);
INSERT INTO 'dancesrecordingsmap' VALUES (3582, 474, NULL, 2951);
INSERT INTO 'dancesrecordingsmap' VALUES (3583, 1672, NULL, 2954);
INSERT INTO 'dancesrecordingsmap' VALUES (3584, 6014, NULL, 2954);
INSERT INTO 'dancesrecordingsmap' VALUES (3585, 78, NULL, 2955);
INSERT INTO 'dancesrecordingsmap' VALUES (3586, 1904, NULL, 2955);
INSERT INTO 'dancesrecordingsmap' VALUES (3587, 2983, NULL, 2955);
INSERT INTO 'dancesrecordingsmap' VALUES (3588, 3245, NULL, 2955);
INSERT INTO 'dancesrecordingsmap' VALUES (3589, 3361, NULL, 2955);
INSERT INTO 'dancesrecordingsmap' VALUES (3590, 3401, NULL, 2955);
INSERT INTO 'dancesrecordingsmap' VALUES (3591, 6613, NULL, 2955);
INSERT INTO 'dancesrecordingsmap' VALUES (3576, 5964, NULL, 2949);
INSERT INTO 'dancesrecordingsmap' VALUES (1115, 3537, NULL, 1371);
INSERT INTO 'dancesrecordingsmap' VALUES (1152, 5575, NULL, 1379);
INSERT INTO 'dancesrecordingsmap' VALUES (1072, 6489, NULL, 1332);
INSERT INTO 'dancesrecordingsmap' VALUES (3592, 8010, NULL, 2955);
INSERT INTO 'dancesrecordingsmap' VALUES (3593, 8161, NULL, 1172);
INSERT INTO 'dancesrecordingsmap' VALUES (3594, 1677, NULL, 3666);
INSERT INTO 'dancesrecordingsmap' VALUES (3596, 7542, NULL, 3316);
INSERT INTO 'dancesrecordingsmap' VALUES (3597, 8942, NULL, 4552);
INSERT INTO 'dancesrecordingsmap' VALUES (3598, 8943, NULL, 4553);
INSERT INTO 'dancesrecordingsmap' VALUES (3599, 8944, NULL, 4554);
INSERT INTO 'dancesrecordingsmap' VALUES (8063, 14438, NULL, 8882);
INSERT INTO 'dancesrecordingsmap' VALUES (8074, 2260, NULL, 8894);
INSERT INTO 'dancesrecordingsmap' VALUES (1154, 7012, NULL, 1386);
INSERT INTO 'dancesrecordingsmap' VALUES (1155, 291, NULL, 1387);
INSERT INTO 'dancesrecordingsmap' VALUES (1156, 4295, NULL, 1391);
INSERT INTO 'dancesrecordingsmap' VALUES (1157, 1506, NULL, 1394);
INSERT INTO 'dancesrecordingsmap' VALUES (1158, 37, NULL, 1405);
INSERT INTO 'dancesrecordingsmap' VALUES (1093, 2742, NULL, 1349);
INSERT INTO 'dancesrecordingsmap' VALUES (1090, 773, NULL, 1346);
INSERT INTO 'dancesrecordingsmap' VALUES (1142, 1469, NULL, 1404);
INSERT INTO 'dancesrecordingsmap' VALUES (1136, 4871, NULL, 1398);
INSERT INTO 'dancesrecordingsmap' VALUES (1117, 3594, NULL, 1373);
INSERT INTO 'dancesrecordingsmap' VALUES (1089, 1446, NULL, 1345);
INSERT INTO 'dancesrecordingsmap' VALUES (1159, 1528, NULL, 1406);
INSERT INTO 'dancesrecordingsmap' VALUES (1160, 3975, NULL, 1407);
INSERT INTO 'dancesrecordingsmap' VALUES (1162, 5065, NULL, 1411);
INSERT INTO 'dancesrecordingsmap' VALUES (1163, 2935, NULL, 1412);
INSERT INTO 'dancesrecordingsmap' VALUES (1164, 5872, NULL, 1413);
INSERT INTO 'dancesrecordingsmap' VALUES (1166, 1864, NULL, 1415);
INSERT INTO 'dancesrecordingsmap' VALUES (9101, 18257, NULL, 6365);
INSERT INTO 'dancesrecordingsmap' VALUES (1168, 640, NULL, 1417);
INSERT INTO 'dancesrecordingsmap' VALUES (1169, 674, NULL, 1418);
INSERT INTO 'dancesrecordingsmap' VALUES (1228, 2883, NULL, 1512);
INSERT INTO 'dancesrecordingsmap' VALUES (1171, 4928, NULL, 1420);
INSERT INTO 'dancesrecordingsmap' VALUES (1088, 1163, NULL, 1268);
INSERT INTO 'dancesrecordingsmap' VALUES (3550, 2513, NULL, 1763);
INSERT INTO 'dancesrecordingsmap' VALUES (3595, 1478, NULL, 298);
INSERT INTO 'dancesrecordingsmap' VALUES (1120, 3310, NULL, 1376);
INSERT INTO 'dancesrecordingsmap' VALUES (1067, 4959, NULL, 1327);
INSERT INTO 'dancesrecordingsmap' VALUES (1172, 633, NULL, 1421);
INSERT INTO 'dancesrecordingsmap' VALUES (1174, 2415, NULL, 1423);
INSERT INTO 'dancesrecordingsmap' VALUES (1175, 1782, NULL, 1424);
INSERT INTO 'dancesrecordingsmap' VALUES (1176, 909, NULL, 1425);
INSERT INTO 'dancesrecordingsmap' VALUES (1177, 1501, NULL, 1426);
INSERT INTO 'dancesrecordingsmap' VALUES (1178, 1578, NULL, 1427);
INSERT INTO 'dancesrecordingsmap' VALUES (1179, 6505, NULL, 1428);
INSERT INTO 'dancesrecordingsmap' VALUES (1180, 2436, NULL, 1429);
INSERT INTO 'dancesrecordingsmap' VALUES (1181, 3659, NULL, 1430);
INSERT INTO 'dancesrecordingsmap' VALUES (1182, 4562, NULL, 1431);
INSERT INTO 'dancesrecordingsmap' VALUES (1183, 794, NULL, 1434);
INSERT INTO 'dancesrecordingsmap' VALUES (1184, 4646, NULL, 1435);
INSERT INTO 'dancesrecordingsmap' VALUES (1185, 7546, NULL, 1436);
INSERT INTO 'dancesrecordingsmap' VALUES (1186, 1786, NULL, 1437);
INSERT INTO 'dancesrecordingsmap' VALUES (1187, 3672, NULL, 1438);
INSERT INTO 'dancesrecordingsmap' VALUES (1188, 1562, NULL, 1439);
INSERT INTO 'dancesrecordingsmap' VALUES (1189, 1792, NULL, 1440);
INSERT INTO 'dancesrecordingsmap' VALUES (1190, 3246, NULL, 1441);
INSERT INTO 'dancesrecordingsmap' VALUES (1191, 1931, NULL, 1442);
INSERT INTO 'dancesrecordingsmap' VALUES (1192, 327, NULL, 1443);
INSERT INTO 'dancesrecordingsmap' VALUES (1193, 3365, NULL, 1445);
INSERT INTO 'dancesrecordingsmap' VALUES (1195, 6957, NULL, 1447);
INSERT INTO 'dancesrecordingsmap' VALUES (1197, 2332, NULL, 1449);
INSERT INTO 'dancesrecordingsmap' VALUES (1198, 5868, NULL, 1450);
INSERT INTO 'dancesrecordingsmap' VALUES (1199, 6091, NULL, 1452);
INSERT INTO 'dancesrecordingsmap' VALUES (1200, 6539, NULL, 1465);
INSERT INTO 'dancesrecordingsmap' VALUES (1201, 3057, NULL, 1466);
INSERT INTO 'dancesrecordingsmap' VALUES (1202, 5703, NULL, 1467);
INSERT INTO 'dancesrecordingsmap' VALUES (1204, 584, NULL, 1470);
INSERT INTO 'dancesrecordingsmap' VALUES (1206, 7055, NULL, 1472);
INSERT INTO 'dancesrecordingsmap' VALUES (1208, 4927, NULL, 1474);
INSERT INTO 'dancesrecordingsmap' VALUES (1210, 6349, NULL, 1476);
INSERT INTO 'dancesrecordingsmap' VALUES (1212, 2250, NULL, 1490);
INSERT INTO 'dancesrecordingsmap' VALUES (1213, 3339, NULL, 1491);
INSERT INTO 'dancesrecordingsmap' VALUES (1214, 5497, NULL, 1492);
INSERT INTO 'dancesrecordingsmap' VALUES (1215, 972, NULL, 1493);
INSERT INTO 'dancesrecordingsmap' VALUES (1216, 4646, NULL, 1494);
INSERT INTO 'dancesrecordingsmap' VALUES (1217, 6167, NULL, 1495);
INSERT INTO 'dancesrecordingsmap' VALUES (1218, 4633, NULL, 1496);
INSERT INTO 'dancesrecordingsmap' VALUES (1219, 1210, NULL, 1497);
INSERT INTO 'dancesrecordingsmap' VALUES (1220, 7552, NULL, 1498);
INSERT INTO 'dancesrecordingsmap' VALUES (1221, 8154, NULL, 1500);
INSERT INTO 'dancesrecordingsmap' VALUES (1222, 8146, NULL, 1501);
INSERT INTO 'dancesrecordingsmap' VALUES (1223, 1792, NULL, 1502);
INSERT INTO 'dancesrecordingsmap' VALUES (1224, 7546, NULL, 1505);
INSERT INTO 'dancesrecordingsmap' VALUES (1225, 5964, NULL, 1507);
INSERT INTO 'dancesrecordingsmap' VALUES (1226, 7548, NULL, 1508);
INSERT INTO 'dancesrecordingsmap' VALUES (1229, 8146, NULL, 1513);
INSERT INTO 'dancesrecordingsmap' VALUES (1230, 2379, NULL, 1515);
INSERT INTO 'dancesrecordingsmap' VALUES (1232, 5009, NULL, 1517);
INSERT INTO 'dancesrecordingsmap' VALUES (1233, 8154, NULL, 1519);
INSERT INTO 'dancesrecordingsmap' VALUES (1235, 3659, NULL, 1524);
INSERT INTO 'dancesrecordingsmap' VALUES (1236, 1280, NULL, 1526);
INSERT INTO 'dancesrecordingsmap' VALUES (1237, 1792, NULL, 1527);
INSERT INTO 'dancesrecordingsmap' VALUES (1238, 1782, NULL, 1528);
INSERT INTO 'dancesrecordingsmap' VALUES (1239, 1931, NULL, 1529);
INSERT INTO 'dancesrecordingsmap' VALUES (1240, 373, NULL, 1530);
INSERT INTO 'dancesrecordingsmap' VALUES (1241, 5330, NULL, 1532);
INSERT INTO 'dancesrecordingsmap' VALUES (1242, 1834, NULL, 1533);
INSERT INTO 'dancesrecordingsmap' VALUES (1243, 5915, NULL, 1535);
INSERT INTO 'dancesrecordingsmap' VALUES (1245, 1792, NULL, 1537);
INSERT INTO 'dancesrecordingsmap' VALUES (1246, 4641, NULL, 1538);
INSERT INTO 'dancesrecordingsmap' VALUES (3600, 8945, NULL, 4555);
INSERT INTO 'dancesrecordingsmap' VALUES (3601, 8946, NULL, 4556);
INSERT INTO 'dancesrecordingsmap' VALUES (3602, 8947, NULL, 4557);
INSERT INTO 'dancesrecordingsmap' VALUES (3603, 8948, NULL, 4558);
INSERT INTO 'dancesrecordingsmap' VALUES (3604, 8949, NULL, 4559);
INSERT INTO 'dancesrecordingsmap' VALUES (3605, 8950, NULL, 4560);
INSERT INTO 'dancesrecordingsmap' VALUES (3606, 8951, NULL, 4561);
INSERT INTO 'dancesrecordingsmap' VALUES (3607, 8952, NULL, 4562);
INSERT INTO 'dancesrecordingsmap' VALUES (3608, 8953, NULL, 4563);
INSERT INTO 'dancesrecordingsmap' VALUES (3609, 8954, NULL, 4564);
INSERT INTO 'dancesrecordingsmap' VALUES (3610, 8955, NULL, 4565);
INSERT INTO 'dancesrecordingsmap' VALUES (3611, 2203, NULL, 4566);
INSERT INTO 'dancesrecordingsmap' VALUES (3612, 2263, NULL, 4567);
INSERT INTO 'dancesrecordingsmap' VALUES (3613, 5927, NULL, 4568);
INSERT INTO 'dancesrecordingsmap' VALUES (3615, 981, NULL, 4572);
INSERT INTO 'dancesrecordingsmap' VALUES (3616, 7283, NULL, 4573);
INSERT INTO 'dancesrecordingsmap' VALUES (3617, 4796, NULL, 4574);
INSERT INTO 'dancesrecordingsmap' VALUES (3618, 4407, NULL, 4575);
INSERT INTO 'dancesrecordingsmap' VALUES (3619, 2349, NULL, 4576);
INSERT INTO 'dancesrecordingsmap' VALUES (3620, 5122, NULL, 4577);
INSERT INTO 'dancesrecordingsmap' VALUES (3621, 4318, NULL, 4578);
INSERT INTO 'dancesrecordingsmap' VALUES (3622, 153, NULL, 4579);
INSERT INTO 'dancesrecordingsmap' VALUES (3623, 3422, NULL, 4580);
INSERT INTO 'dancesrecordingsmap' VALUES (3624, 2260, NULL, 4581);
INSERT INTO 'dancesrecordingsmap' VALUES (3625, 4752, NULL, 4582);
INSERT INTO 'dancesrecordingsmap' VALUES (3626, 4784, NULL, 4583);
INSERT INTO 'dancesrecordingsmap' VALUES (3629, 3526, NULL, 4587);
INSERT INTO 'dancesrecordingsmap' VALUES (3630, 7284, NULL, 4588);
INSERT INTO 'dancesrecordingsmap' VALUES (3631, 5065, NULL, 4589);
INSERT INTO 'dancesrecordingsmap' VALUES (3632, 753, NULL, 4590);
INSERT INTO 'dancesrecordingsmap' VALUES (3633, 4692, NULL, 4591);
INSERT INTO 'dancesrecordingsmap' VALUES (3634, 5362, NULL, 4592);
INSERT INTO 'dancesrecordingsmap' VALUES (3635, 723, NULL, 4593);
INSERT INTO 'dancesrecordingsmap' VALUES (3636, 822, NULL, 4624);
INSERT INTO 'dancesrecordingsmap' VALUES (3637, 6919, NULL, 4570);
INSERT INTO 'dancesrecordingsmap' VALUES (3639, 8970, NULL, 434);
INSERT INTO 'dancesrecordingsmap' VALUES (3640, 8971, NULL, 659);
INSERT INTO 'dancesrecordingsmap' VALUES (3641, 7282, NULL, 4569);
INSERT INTO 'dancesrecordingsmap' VALUES (8064, 14439, NULL, 8883);
INSERT INTO 'dancesrecordingsmap' VALUES (8075, 2394, NULL, 8895);
INSERT INTO 'dancesrecordingsmap' VALUES (8080, 3580, NULL, 8918);
INSERT INTO 'dancesrecordingsmap' VALUES (8092, 5209, NULL, 5910);
INSERT INTO 'dancesrecordingsmap' VALUES (8094, 6734, NULL, 8933);
INSERT INTO 'dancesrecordingsmap' VALUES (1247, 4102, NULL, 1539);
INSERT INTO 'dancesrecordingsmap' VALUES (1248, 4646, NULL, 1541);
INSERT INTO 'dancesrecordingsmap' VALUES (1250, 4951, NULL, 1543);
INSERT INTO 'dancesrecordingsmap' VALUES (1251, 6287, NULL, 1544);
INSERT INTO 'dancesrecordingsmap' VALUES (1252, 2745, NULL, 1545);
INSERT INTO 'dancesrecordingsmap' VALUES (1253, 1405, NULL, 1546);
INSERT INTO 'dancesrecordingsmap' VALUES (1254, 2332, NULL, 1547);
INSERT INTO 'dancesrecordingsmap' VALUES (1255, 4784, NULL, 1548);
INSERT INTO 'dancesrecordingsmap' VALUES (1256, 4890, NULL, 1549);
INSERT INTO 'dancesrecordingsmap' VALUES (1257, 1990, NULL, 1550);
INSERT INTO 'dancesrecordingsmap' VALUES (1258, 6153, NULL, 1551);
INSERT INTO 'dancesrecordingsmap' VALUES (1259, 6637, NULL, 1552);
INSERT INTO 'dancesrecordingsmap' VALUES (1260, 5578, NULL, 1553);
INSERT INTO 'dancesrecordingsmap' VALUES (1261, 4358, NULL, 1554);
INSERT INTO 'dancesrecordingsmap' VALUES (1262, 902, NULL, 1555);
INSERT INTO 'dancesrecordingsmap' VALUES (1265, 328, NULL, 1559);
INSERT INTO 'dancesrecordingsmap' VALUES (1266, 4103, NULL, 1560);
INSERT INTO 'dancesrecordingsmap' VALUES (1267, 1544, NULL, 1561);
INSERT INTO 'dancesrecordingsmap' VALUES (1268, 594, NULL, 1562);
INSERT INTO 'dancesrecordingsmap' VALUES (1270, 5330, NULL, 1568);
INSERT INTO 'dancesrecordingsmap' VALUES (1271, 7574, NULL, 1570);
INSERT INTO 'dancesrecordingsmap' VALUES (1272, 5296, NULL, 1572);
INSERT INTO 'dancesrecordingsmap' VALUES (1273, 3129, NULL, 1573);
INSERT INTO 'dancesrecordingsmap' VALUES (1274, 5925, NULL, 1574);
INSERT INTO 'dancesrecordingsmap' VALUES (1275, 1478, NULL, 1587);
INSERT INTO 'dancesrecordingsmap' VALUES (1277, 2024, NULL, 1589);
INSERT INTO 'dancesrecordingsmap' VALUES (1278, 1799, NULL, 1590);
INSERT INTO 'dancesrecordingsmap' VALUES (1279, 2250, NULL, 1591);
INSERT INTO 'dancesrecordingsmap' VALUES (1280, 4782, NULL, 1592);
INSERT INTO 'dancesrecordingsmap' VALUES (1281, 5223, NULL, 1593);
INSERT INTO 'dancesrecordingsmap' VALUES (1234, 7247, NULL, 1522);
INSERT INTO 'dancesrecordingsmap' VALUES (1196, 2743, NULL, 1448);
INSERT INTO 'dancesrecordingsmap' VALUES (1231, 358, NULL, 1516);
INSERT INTO 'dancesrecordingsmap' VALUES (1211, 4336, NULL, 1489);
INSERT INTO 'dancesrecordingsmap' VALUES (3614, 5671, NULL, 4571);
INSERT INTO 'dancesrecordingsmap' VALUES (3628, 43, NULL, 4586);
INSERT INTO 'dancesrecordingsmap' VALUES (1263, 5040, NULL, 1557);
INSERT INTO 'dancesrecordingsmap' VALUES (1282, 3246, NULL, 1594);
INSERT INTO 'dancesrecordingsmap' VALUES (1283, 2024, NULL, 1595);
INSERT INTO 'dancesrecordingsmap' VALUES (1284, 6957, NULL, 1596);
INSERT INTO 'dancesrecordingsmap' VALUES (1285, 7109, NULL, 1598);
INSERT INTO 'dancesrecordingsmap' VALUES (1286, 1782, NULL, 1599);
INSERT INTO 'dancesrecordingsmap' VALUES (1287, 3562, NULL, 1600);
INSERT INTO 'dancesrecordingsmap' VALUES (1288, 1677, NULL, 1601);
INSERT INTO 'dancesrecordingsmap' VALUES (1289, 3281, NULL, 1602);
INSERT INTO 'dancesrecordingsmap' VALUES (1290, 480, NULL, 1603);
INSERT INTO 'dancesrecordingsmap' VALUES (1291, 760, NULL, 1488);
INSERT INTO 'dancesrecordingsmap' VALUES (1292, 2956, NULL, 1579);
INSERT INTO 'dancesrecordingsmap' VALUES (1293, 5794, NULL, 1580);
INSERT INTO 'dancesrecordingsmap' VALUES (1294, 7147, NULL, 1581);
INSERT INTO 'dancesrecordingsmap' VALUES (1295, 4461, NULL, 1582);
INSERT INTO 'dancesrecordingsmap' VALUES (1296, 3506, NULL, 1583);
INSERT INTO 'dancesrecordingsmap' VALUES (1297, 753, NULL, 1584);
INSERT INTO 'dancesrecordingsmap' VALUES (1298, 6566, NULL, 1586);
INSERT INTO 'dancesrecordingsmap' VALUES (1161, 3735, NULL, 1410);
INSERT INTO 'dancesrecordingsmap' VALUES (1173, 335, NULL, 1422);
INSERT INTO 'dancesrecordingsmap' VALUES (1244, 1774, NULL, 1536);
INSERT INTO 'dancesrecordingsmap' VALUES (1249, 3365, NULL, 1542);
INSERT INTO 'dancesrecordingsmap' VALUES (1269, 1891, NULL, 1563);
INSERT INTO 'dancesrecordingsmap' VALUES (1165, 428, NULL, 1414);
INSERT INTO 'dancesrecordingsmap' VALUES (1299, 5794, NULL, 1604);
INSERT INTO 'dancesrecordingsmap' VALUES (1300, 2436, NULL, 1605);
INSERT INTO 'dancesrecordingsmap' VALUES (1301, 3046, NULL, 1606);
INSERT INTO 'dancesrecordingsmap' VALUES (1302, 7172, NULL, 1607);
INSERT INTO 'dancesrecordingsmap' VALUES (1304, 5239, NULL, 1609);
INSERT INTO 'dancesrecordingsmap' VALUES (1305, 6739, NULL, 1610);
INSERT INTO 'dancesrecordingsmap' VALUES (1306, 5462, NULL, 1611);
INSERT INTO 'dancesrecordingsmap' VALUES (1307, 2711, NULL, 1612);
INSERT INTO 'dancesrecordingsmap' VALUES (1310, 7220, NULL, 1615);
INSERT INTO 'dancesrecordingsmap' VALUES (1311, 2604, NULL, 1616);
INSERT INTO 'dancesrecordingsmap' VALUES (1313, 3529, NULL, 1619);
INSERT INTO 'dancesrecordingsmap' VALUES (1315, 2846, NULL, 1623);
INSERT INTO 'dancesrecordingsmap' VALUES (1205, 3786, NULL, 1471);
INSERT INTO 'dancesrecordingsmap' VALUES (1207, 5552, NULL, 1473);
INSERT INTO 'dancesrecordingsmap' VALUES (1203, 4827, NULL, 1469);
INSERT INTO 'dancesrecordingsmap' VALUES (1276, 4827, NULL, 1588);
INSERT INTO 'dancesrecordingsmap' VALUES (1264, 1643, NULL, 1558);
INSERT INTO 'dancesrecordingsmap' VALUES (1227, 2745, NULL, 1509);
INSERT INTO 'dancesrecordingsmap' VALUES (3627, 4008, NULL, 4584);
INSERT INTO 'dancesrecordingsmap' VALUES (1316, 445, NULL, 1624);
INSERT INTO 'dancesrecordingsmap' VALUES (1317, 56, NULL, 1625);
INSERT INTO 'dancesrecordingsmap' VALUES (1318, 4928, NULL, 1626);
INSERT INTO 'dancesrecordingsmap' VALUES (1319, 3129, NULL, 1628);
INSERT INTO 'dancesrecordingsmap' VALUES (1321, 5525, NULL, 1630);
INSERT INTO 'dancesrecordingsmap' VALUES (1322, 4102, NULL, 1631);
INSERT INTO 'dancesrecordingsmap' VALUES (1323, 3829, NULL, 1632);
INSERT INTO 'dancesrecordingsmap' VALUES (1324, 1857, NULL, 1633);
INSERT INTO 'dancesrecordingsmap' VALUES (1325, 7189, NULL, 1634);
INSERT INTO 'dancesrecordingsmap' VALUES (1326, 980, NULL, 1636);
INSERT INTO 'dancesrecordingsmap' VALUES (1327, 1348, NULL, 1637);
INSERT INTO 'dancesrecordingsmap' VALUES (1328, 1316, NULL, 1638);
INSERT INTO 'dancesrecordingsmap' VALUES (1329, 1424, NULL, 1639);
INSERT INTO 'dancesrecordingsmap' VALUES (1330, 3027, NULL, 1640);
INSERT INTO 'dancesrecordingsmap' VALUES (1331, 2887, NULL, 1641);
INSERT INTO 'dancesrecordingsmap' VALUES (1332, 5713, NULL, 1642);
INSERT INTO 'dancesrecordingsmap' VALUES (1333, 5413, NULL, 1644);
INSERT INTO 'dancesrecordingsmap' VALUES (1334, 5717, NULL, 1646);
INSERT INTO 'dancesrecordingsmap' VALUES (1335, 2214, NULL, 1647);
INSERT INTO 'dancesrecordingsmap' VALUES (1336, 6163, NULL, 1648);
INSERT INTO 'dancesrecordingsmap' VALUES (1337, 1951, NULL, 1649);
INSERT INTO 'dancesrecordingsmap' VALUES (1338, 6265, NULL, 1650);
INSERT INTO 'dancesrecordingsmap' VALUES (3642, 3743, NULL, 4613);
INSERT INTO 'dancesrecordingsmap' VALUES (3643, 40, NULL, 4614);
INSERT INTO 'dancesrecordingsmap' VALUES (3644, 588, NULL, 4615);
INSERT INTO 'dancesrecordingsmap' VALUES (3645, 1582, NULL, 4616);
INSERT INTO 'dancesrecordingsmap' VALUES (3646, 2189, NULL, 4618);
INSERT INTO 'dancesrecordingsmap' VALUES (3647, 2236, NULL, 4619);
INSERT INTO 'dancesrecordingsmap' VALUES (3648, 5794, NULL, 4620);
INSERT INTO 'dancesrecordingsmap' VALUES (3649, 4484, NULL, 4621);
INSERT INTO 'dancesrecordingsmap' VALUES (3650, 4805, NULL, 4622);
INSERT INTO 'dancesrecordingsmap' VALUES (3651, 4641, NULL, 4623);
INSERT INTO 'dancesrecordingsmap' VALUES (3652, 8977, NULL, 4623);
INSERT INTO 'dancesrecordingsmap' VALUES (3653, 7546, NULL, 4627);
INSERT INTO 'dancesrecordingsmap' VALUES (3654, 7111, NULL, 4629);
INSERT INTO 'dancesrecordingsmap' VALUES (3655, 106, NULL, 4630);
INSERT INTO 'dancesrecordingsmap' VALUES (3656, 7553, NULL, 4631);
INSERT INTO 'dancesrecordingsmap' VALUES (3657, 6915, NULL, 4632);
INSERT INTO 'dancesrecordingsmap' VALUES (3658, 8146, NULL, 4635);
INSERT INTO 'dancesrecordingsmap' VALUES (3659, 373, NULL, 4637);
INSERT INTO 'dancesrecordingsmap' VALUES (3660, 7555, NULL, 4638);
INSERT INTO 'dancesrecordingsmap' VALUES (3661, 5864, NULL, 4641);
INSERT INTO 'dancesrecordingsmap' VALUES (3662, 4782, NULL, 4642);
INSERT INTO 'dancesrecordingsmap' VALUES (3663, 1473, NULL, 4643);
INSERT INTO 'dancesrecordingsmap' VALUES (3664, 3231, NULL, 4644);
INSERT INTO 'dancesrecordingsmap' VALUES (3665, 1966, NULL, 4645);
INSERT INTO 'dancesrecordingsmap' VALUES (3666, 4662, NULL, 4646);
INSERT INTO 'dancesrecordingsmap' VALUES (3667, 980, NULL, 4647);
INSERT INTO 'dancesrecordingsmap' VALUES (3668, 1182, NULL, 4648);
INSERT INTO 'dancesrecordingsmap' VALUES (3669, 3672, NULL, 4649);
INSERT INTO 'dancesrecordingsmap' VALUES (3670, 5623, NULL, 4650);
INSERT INTO 'dancesrecordingsmap' VALUES (3671, 4629, NULL, 4651);
INSERT INTO 'dancesrecordingsmap' VALUES (3672, 559, NULL, 4652);
INSERT INTO 'dancesrecordingsmap' VALUES (3673, 4592, NULL, 4653);
INSERT INTO 'dancesrecordingsmap' VALUES (3674, 5033, NULL, 4654);
INSERT INTO 'dancesrecordingsmap' VALUES (3675, 625, NULL, 4655);
INSERT INTO 'dancesrecordingsmap' VALUES (3676, 5658, NULL, 4656);
INSERT INTO 'dancesrecordingsmap' VALUES (3677, 1521, NULL, 4658);
INSERT INTO 'dancesrecordingsmap' VALUES (3678, 2084, NULL, 4659);
INSERT INTO 'dancesrecordingsmap' VALUES (3679, 2323, NULL, 4661);
INSERT INTO 'dancesrecordingsmap' VALUES (3680, 648, NULL, 4662);
INSERT INTO 'dancesrecordingsmap' VALUES (3681, 2709, NULL, 4663);
INSERT INTO 'dancesrecordingsmap' VALUES (3682, 4291, NULL, 4664);
INSERT INTO 'dancesrecordingsmap' VALUES (3683, 5702, NULL, 4665);
INSERT INTO 'dancesrecordingsmap' VALUES (8076, 3108, NULL, 8896);
INSERT INTO 'dancesrecordingsmap' VALUES (8081, 7282, NULL, 8919);
INSERT INTO 'dancesrecordingsmap' VALUES (8095, 2428, NULL, 8934);
INSERT INTO 'dancesrecordingsmap' VALUES (1340, 2453, NULL, 1652);
INSERT INTO 'dancesrecordingsmap' VALUES (1341, 3300, NULL, 1653);
INSERT INTO 'dancesrecordingsmap' VALUES (1342, 3246, NULL, 1654);
INSERT INTO 'dancesrecordingsmap' VALUES (1343, 4411, NULL, 1655);
INSERT INTO 'dancesrecordingsmap' VALUES (1344, 3435, NULL, 1656);
INSERT INTO 'dancesrecordingsmap' VALUES (1345, 5136, NULL, 1656);
INSERT INTO 'dancesrecordingsmap' VALUES (1346, 909, NULL, 1657);
INSERT INTO 'dancesrecordingsmap' VALUES (1347, 3759, NULL, 1658);
INSERT INTO 'dancesrecordingsmap' VALUES (1349, 439, NULL, 1661);
INSERT INTO 'dancesrecordingsmap' VALUES (1350, 3177, NULL, 1661);
INSERT INTO 'dancesrecordingsmap' VALUES (1351, 5624, NULL, 1661);
INSERT INTO 'dancesrecordingsmap' VALUES (1352, 4444, NULL, 1661);
INSERT INTO 'dancesrecordingsmap' VALUES (1353, 6077, NULL, 1661);
INSERT INTO 'dancesrecordingsmap' VALUES (1354, 8250, NULL, 1662);
INSERT INTO 'dancesrecordingsmap' VALUES (1355, 2809, NULL, 1663);
INSERT INTO 'dancesrecordingsmap' VALUES (1356, 7147, NULL, 1669);
INSERT INTO 'dancesrecordingsmap' VALUES (1357, 6044, NULL, 1670);
INSERT INTO 'dancesrecordingsmap' VALUES (1358, 4641, NULL, 1671);
INSERT INTO 'dancesrecordingsmap' VALUES (1359, 7245, NULL, 1672);
INSERT INTO 'dancesrecordingsmap' VALUES (1360, 4968, NULL, 1673);
INSERT INTO 'dancesrecordingsmap' VALUES (1363, 1792, NULL, 1677);
INSERT INTO 'dancesrecordingsmap' VALUES (1364, 5963, NULL, 1678);
INSERT INTO 'dancesrecordingsmap' VALUES (1365, 7552, NULL, 1668);
INSERT INTO 'dancesrecordingsmap' VALUES (1366, 7546, NULL, 1680);
INSERT INTO 'dancesrecordingsmap' VALUES (1367, 2250, NULL, 1681);
INSERT INTO 'dancesrecordingsmap' VALUES (1368, 1562, NULL, 1682);
INSERT INTO 'dancesrecordingsmap' VALUES (1369, 2745, NULL, 1683);
INSERT INTO 'dancesrecordingsmap' VALUES (1370, 4239, NULL, 1685);
INSERT INTO 'dancesrecordingsmap' VALUES (1371, 7548, NULL, 1686);
INSERT INTO 'dancesrecordingsmap' VALUES (1372, 1786, NULL, 1688);
INSERT INTO 'dancesrecordingsmap' VALUES (1373, 1100, NULL, 1689);
INSERT INTO 'dancesrecordingsmap' VALUES (1374, 5525, NULL, 1692);
INSERT INTO 'dancesrecordingsmap' VALUES (1375, 4641, NULL, 1693);
INSERT INTO 'dancesrecordingsmap' VALUES (1376, 1931, NULL, 1694);
INSERT INTO 'dancesrecordingsmap' VALUES (1377, 4646, NULL, 1695);
INSERT INTO 'dancesrecordingsmap' VALUES (1378, 2924, NULL, 1696);
INSERT INTO 'dancesrecordingsmap' VALUES (1379, 5671, NULL, 1697);
INSERT INTO 'dancesrecordingsmap' VALUES (1381, 3864, NULL, 1699);
INSERT INTO 'dancesrecordingsmap' VALUES (1382, 4145, NULL, 1700);
INSERT INTO 'dancesrecordingsmap' VALUES (1383, 6972, NULL, 1701);
INSERT INTO 'dancesrecordingsmap' VALUES (1384, 7053, NULL, 1702);
INSERT INTO 'dancesrecordingsmap' VALUES (1385, 6632, NULL, 1703);
INSERT INTO 'dancesrecordingsmap' VALUES (1386, 4190, NULL, 1704);
INSERT INTO 'dancesrecordingsmap' VALUES (1387, 5321, NULL, 1705);
INSERT INTO 'dancesrecordingsmap' VALUES (1388, 1966, NULL, 1717);
INSERT INTO 'dancesrecordingsmap' VALUES (1389, 8146, NULL, 1718);
INSERT INTO 'dancesrecordingsmap' VALUES (1390, 7546, NULL, 1719);
INSERT INTO 'dancesrecordingsmap' VALUES (1391, 2956, NULL, 1722);
INSERT INTO 'dancesrecordingsmap' VALUES (1392, 4014, NULL, 1723);
INSERT INTO 'dancesrecordingsmap' VALUES (1393, 5731, NULL, 1725);
INSERT INTO 'dancesrecordingsmap' VALUES (1394, 6523, NULL, 1726);
INSERT INTO 'dancesrecordingsmap' VALUES (1395, 7548, NULL, 1728);
INSERT INTO 'dancesrecordingsmap' VALUES (1397, 1100, NULL, 1731);
INSERT INTO 'dancesrecordingsmap' VALUES (1398, 6585, NULL, 1732);
INSERT INTO 'dancesrecordingsmap' VALUES (1399, 2389, NULL, 1733);
INSERT INTO 'dancesrecordingsmap' VALUES (1400, 5543, NULL, 1734);
INSERT INTO 'dancesrecordingsmap' VALUES (1401, 5832, NULL, 1735);
INSERT INTO 'dancesrecordingsmap' VALUES (1402, 4103, NULL, 1736);
INSERT INTO 'dancesrecordingsmap' VALUES (1403, 3562, NULL, 1737);
INSERT INTO 'dancesrecordingsmap' VALUES (1404, 1758, NULL, 1738);
INSERT INTO 'dancesrecordingsmap' VALUES (1405, 1020, NULL, 1742);
INSERT INTO 'dancesrecordingsmap' VALUES (1407, 2506, NULL, 1744);
INSERT INTO 'dancesrecordingsmap' VALUES (1408, 4324, NULL, 1745);
INSERT INTO 'dancesrecordingsmap' VALUES (1409, 541, NULL, 1746);
INSERT INTO 'dancesrecordingsmap' VALUES (1410, 3541, NULL, 1747);
INSERT INTO 'dancesrecordingsmap' VALUES (1411, 6349, NULL, 1748);
INSERT INTO 'dancesrecordingsmap' VALUES (1412, 6523, NULL, 1749);
INSERT INTO 'dancesrecordingsmap' VALUES (1413, 4337, NULL, 1750);
INSERT INTO 'dancesrecordingsmap' VALUES (1414, 1478, NULL, 1751);
INSERT INTO 'dancesrecordingsmap' VALUES (1415, 5330, NULL, 1752);
INSERT INTO 'dancesrecordingsmap' VALUES (1416, 2956, NULL, 1753);
INSERT INTO 'dancesrecordingsmap' VALUES (1417, 3246, NULL, 1754);
INSERT INTO 'dancesrecordingsmap' VALUES (1418, 5964, NULL, 1755);
INSERT INTO 'dancesrecordingsmap' VALUES (1419, 498, NULL, 1756);
INSERT INTO 'dancesrecordingsmap' VALUES (1420, 6748, NULL, 1757);
INSERT INTO 'dancesrecordingsmap' VALUES (8093, 442, NULL, 5908);
INSERT INTO 'dancesrecordingsmap' VALUES (1303, 5376, NULL, 1608);
INSERT INTO 'dancesrecordingsmap' VALUES (1348, 1544, NULL, 1659);
INSERT INTO 'dancesrecordingsmap' VALUES (1312, 7267, NULL, 1618);
INSERT INTO 'dancesrecordingsmap' VALUES (1361, 40, NULL, 1674);
INSERT INTO 'dancesrecordingsmap' VALUES (1421, 2260, NULL, 1758);
INSERT INTO 'dancesrecordingsmap' VALUES (1422, 819, NULL, 1759);
INSERT INTO 'dancesrecordingsmap' VALUES (1423, 1431, NULL, 1760);
INSERT INTO 'dancesrecordingsmap' VALUES (1424, 4725, NULL, 1761);
INSERT INTO 'dancesrecordingsmap' VALUES (3684, 6182, NULL, 4666);
INSERT INTO 'dancesrecordingsmap' VALUES (3685, 7282, NULL, 4668);
INSERT INTO 'dancesrecordingsmap' VALUES (3686, 1625, NULL, 4669);
INSERT INTO 'dancesrecordingsmap' VALUES (3687, 964, NULL, 4672);
INSERT INTO 'dancesrecordingsmap' VALUES (3688, 6768, NULL, 4673);
INSERT INTO 'dancesrecordingsmap' VALUES (3689, 8344, NULL, 4675);
INSERT INTO 'dancesrecordingsmap' VALUES (3690, 1847, NULL, 4676);
INSERT INTO 'dancesrecordingsmap' VALUES (1309, 231, NULL, 1614);
INSERT INTO 'dancesrecordingsmap' VALUES (1308, 5581, NULL, 1613);
INSERT INTO 'dancesrecordingsmap' VALUES (3691, 8709, NULL, 4677);
INSERT INTO 'dancesrecordingsmap' VALUES (3692, 3485, NULL, 4678);
INSERT INTO 'dancesrecordingsmap' VALUES (3693, 3441, NULL, 4679);
INSERT INTO 'dancesrecordingsmap' VALUES (3694, 2077, NULL, 4680);
INSERT INTO 'dancesrecordingsmap' VALUES (3695, 5755, NULL, 4681);
INSERT INTO 'dancesrecordingsmap' VALUES (3696, 1998, NULL, 4683);
INSERT INTO 'dancesrecordingsmap' VALUES (3697, 4032, NULL, 4684);
INSERT INTO 'dancesrecordingsmap' VALUES (3698, 5860, NULL, 4685);
INSERT INTO 'dancesrecordingsmap' VALUES (3699, 743, NULL, 4686);
INSERT INTO 'dancesrecordingsmap' VALUES (3700, 4844, NULL, 4687);
INSERT INTO 'dancesrecordingsmap' VALUES (3701, 4086, NULL, 4688);
INSERT INTO 'dancesrecordingsmap' VALUES (3704, 3729, NULL, 4691);
INSERT INTO 'dancesrecordingsmap' VALUES (1362, 649, NULL, 1675);
INSERT INTO 'dancesrecordingsmap' VALUES (1429, 4728, NULL, 1766);
INSERT INTO 'dancesrecordingsmap' VALUES (1425, 3580, NULL, 1762);
INSERT INTO 'dancesrecordingsmap' VALUES (1430, 3608, NULL, 1767);
INSERT INTO 'dancesrecordingsmap' VALUES (1428, 2189, NULL, 1765);
INSERT INTO 'dancesrecordingsmap' VALUES (1426, 5591, NULL, 1763);
INSERT INTO 'dancesrecordingsmap' VALUES (1431, 1773, NULL, 1768);
INSERT INTO 'dancesrecordingsmap' VALUES (1396, 1478, NULL, 1729);
INSERT INTO 'dancesrecordingsmap' VALUES (1320, 3129, NULL, 1629);
INSERT INTO 'dancesrecordingsmap' VALUES (1406, 4336, NULL, 1743);
INSERT INTO 'dancesrecordingsmap' VALUES (1380, 6682, NULL, 1698);
INSERT INTO 'dancesrecordingsmap' VALUES (3706, 6386, NULL, 4693);
INSERT INTO 'dancesrecordingsmap' VALUES (3707, 109, NULL, 4694);
INSERT INTO 'dancesrecordingsmap' VALUES (3708, 4106, NULL, 4695);
INSERT INTO 'dancesrecordingsmap' VALUES (3709, 3577, NULL, 4696);
INSERT INTO 'dancesrecordingsmap' VALUES (3710, 153, NULL, 4697);
INSERT INTO 'dancesrecordingsmap' VALUES (3712, 6048, NULL, 4700);
INSERT INTO 'dancesrecordingsmap' VALUES (3713, 4431, NULL, 4701);
INSERT INTO 'dancesrecordingsmap' VALUES (3714, 4931, NULL, 4702);
INSERT INTO 'dancesrecordingsmap' VALUES (3715, 3798, NULL, 4703);
INSERT INTO 'dancesrecordingsmap' VALUES (3716, 445, NULL, 4704);
INSERT INTO 'dancesrecordingsmap' VALUES (3717, 2409, NULL, 4705);
INSERT INTO 'dancesrecordingsmap' VALUES (3718, 2267, NULL, 4709);
INSERT INTO 'dancesrecordingsmap' VALUES (3719, 3129, NULL, 4710);
INSERT INTO 'dancesrecordingsmap' VALUES (3720, 7109, NULL, 4713);
INSERT INTO 'dancesrecordingsmap' VALUES (3721, 1931, NULL, 4715);
INSERT INTO 'dancesrecordingsmap' VALUES (3722, 7546, NULL, 4717);
INSERT INTO 'dancesrecordingsmap' VALUES (3723, 7546, NULL, 4719);
INSERT INTO 'dancesrecordingsmap' VALUES (3724, 1280, NULL, 4720);
INSERT INTO 'dancesrecordingsmap' VALUES (3725, 7546, NULL, 4723);
INSERT INTO 'dancesrecordingsmap' VALUES (8077, 2267, NULL, 8897);
INSERT INTO 'dancesrecordingsmap' VALUES (8082, 2498, NULL, 8920);
INSERT INTO 'dancesrecordingsmap' VALUES (8096, 9106, NULL, 8935);
INSERT INTO 'dancesrecordingsmap' VALUES (1433, 3567, NULL, 1770);
INSERT INTO 'dancesrecordingsmap' VALUES (1434, 1780, NULL, 1771);
INSERT INTO 'dancesrecordingsmap' VALUES (1435, 3737, NULL, 1772);
INSERT INTO 'dancesrecordingsmap' VALUES (1436, 5731, NULL, 1773);
INSERT INTO 'dancesrecordingsmap' VALUES (1437, 6860, NULL, 1774);
INSERT INTO 'dancesrecordingsmap' VALUES (1438, 6233, NULL, 1775);
INSERT INTO 'dancesrecordingsmap' VALUES (1439, 924, NULL, 1776);
INSERT INTO 'dancesrecordingsmap' VALUES (1440, 3485, NULL, 1777);
INSERT INTO 'dancesrecordingsmap' VALUES (1441, 5330, NULL, 1778);
INSERT INTO 'dancesrecordingsmap' VALUES (1442, 633, NULL, 1779);
INSERT INTO 'dancesrecordingsmap' VALUES (1443, 6712, NULL, 1780);
INSERT INTO 'dancesrecordingsmap' VALUES (1444, 4935, NULL, 1781);
INSERT INTO 'dancesrecordingsmap' VALUES (1445, 4765, NULL, 1782);
INSERT INTO 'dancesrecordingsmap' VALUES (1446, 153, NULL, 1783);
INSERT INTO 'dancesrecordingsmap' VALUES (1447, 4015, NULL, 1784);
INSERT INTO 'dancesrecordingsmap' VALUES (1448, 89, NULL, 1785);
INSERT INTO 'dancesrecordingsmap' VALUES (1450, 5345, NULL, 1787);
INSERT INTO 'dancesrecordingsmap' VALUES (1451, 2593, NULL, 1788);
INSERT INTO 'dancesrecordingsmap' VALUES (1452, 353, NULL, 1790);
INSERT INTO 'dancesrecordingsmap' VALUES (1453, 877, NULL, 1791);
INSERT INTO 'dancesrecordingsmap' VALUES (1454, 3528, NULL, 1792);
INSERT INTO 'dancesrecordingsmap' VALUES (1455, 4558, NULL, 1793);
INSERT INTO 'dancesrecordingsmap' VALUES (1456, 4555, NULL, 1794);
INSERT INTO 'dancesrecordingsmap' VALUES (1457, 4931, NULL, 1795);
INSERT INTO 'dancesrecordingsmap' VALUES (1458, 3727, NULL, 1796);
INSERT INTO 'dancesrecordingsmap' VALUES (1459, 4562, NULL, 1797);
INSERT INTO 'dancesrecordingsmap' VALUES (1460, 6748, NULL, 1798);
INSERT INTO 'dancesrecordingsmap' VALUES (1461, 4205, NULL, 1799);
INSERT INTO 'dancesrecordingsmap' VALUES (1462, 2166, NULL, 1800);
INSERT INTO 'dancesrecordingsmap' VALUES (1463, 4444, NULL, 1802);
INSERT INTO 'dancesrecordingsmap' VALUES (1464, 5904, NULL, 1803);
INSERT INTO 'dancesrecordingsmap' VALUES (1465, 6337, NULL, 1804);
INSERT INTO 'dancesrecordingsmap' VALUES (1474, 3435, NULL, 1813);
INSERT INTO 'dancesrecordingsmap' VALUES (1475, 6010, NULL, 1814);
INSERT INTO 'dancesrecordingsmap' VALUES (1477, 3129, NULL, 1816);
INSERT INTO 'dancesrecordingsmap' VALUES (1478, 2063, NULL, 1817);
INSERT INTO 'dancesrecordingsmap' VALUES (1479, 4803, NULL, 1818);
INSERT INTO 'dancesrecordingsmap' VALUES (1482, 4565, NULL, 1821);
INSERT INTO 'dancesrecordingsmap' VALUES (1483, 6091, NULL, 1822);
INSERT INTO 'dancesrecordingsmap' VALUES (1484, 8173, NULL, 1824);
INSERT INTO 'dancesrecordingsmap' VALUES (1485, 6336, NULL, 1825);
INSERT INTO 'dancesrecordingsmap' VALUES (1486, 8174, NULL, 1826);
INSERT INTO 'dancesrecordingsmap' VALUES (1487, 8175, NULL, 1827);
INSERT INTO 'dancesrecordingsmap' VALUES (1488, 1930, NULL, 1828);
INSERT INTO 'dancesrecordingsmap' VALUES (1489, 1854, NULL, 1829);
INSERT INTO 'dancesrecordingsmap' VALUES (1490, 976, NULL, 1830);
INSERT INTO 'dancesrecordingsmap' VALUES (1492, 8176, NULL, 1832);
INSERT INTO 'dancesrecordingsmap' VALUES (1493, 8177, NULL, 1833);
INSERT INTO 'dancesrecordingsmap' VALUES (1494, 5824, NULL, 1834);
INSERT INTO 'dancesrecordingsmap' VALUES (1495, 4398, NULL, 1835);
INSERT INTO 'dancesrecordingsmap' VALUES (1496, 696, NULL, 1836);
INSERT INTO 'dancesrecordingsmap' VALUES (1497, 5939, NULL, 1837);
INSERT INTO 'dancesrecordingsmap' VALUES (1498, 7553, NULL, 1838);
INSERT INTO 'dancesrecordingsmap' VALUES (1499, 7546, NULL, 1839);
INSERT INTO 'dancesrecordingsmap' VALUES (1500, 7548, NULL, 1840);
INSERT INTO 'dancesrecordingsmap' VALUES (1501, 7552, NULL, 1841);
INSERT INTO 'dancesrecordingsmap' VALUES (1502, 6978, NULL, 1842);
INSERT INTO 'dancesrecordingsmap' VALUES (1503, 4014, NULL, 1843);
INSERT INTO 'dancesrecordingsmap' VALUES (1504, 5424, NULL, 1844);
INSERT INTO 'dancesrecordingsmap' VALUES (1505, 224, NULL, 1845);
INSERT INTO 'dancesrecordingsmap' VALUES (1506, 3635, NULL, 1846);
INSERT INTO 'dancesrecordingsmap' VALUES (1507, 4044, NULL, 1847);
INSERT INTO 'dancesrecordingsmap' VALUES (1508, 373, NULL, 1848);
INSERT INTO 'dancesrecordingsmap' VALUES (1509, 1908, NULL, 1850);
INSERT INTO 'dancesrecordingsmap' VALUES (1510, 5621, NULL, 1851);
INSERT INTO 'dancesrecordingsmap' VALUES (1511, 3323, NULL, 1852);
INSERT INTO 'dancesrecordingsmap' VALUES (1512, 3172, NULL, 1853);
INSERT INTO 'dancesrecordingsmap' VALUES (1513, 6287, NULL, 1854);
INSERT INTO 'dancesrecordingsmap' VALUES (1515, 3980, NULL, 1856);
INSERT INTO 'dancesrecordingsmap' VALUES (1517, 312, NULL, 1858);
INSERT INTO 'dancesrecordingsmap' VALUES (1525, 3953, NULL, 1867);
INSERT INTO 'dancesrecordingsmap' VALUES (1526, 7111, NULL, 1868);
INSERT INTO 'dancesrecordingsmap' VALUES (1527, 3129, NULL, 1870);
INSERT INTO 'dancesrecordingsmap' VALUES (1528, 3941, NULL, 1871);
INSERT INTO 'dancesrecordingsmap' VALUES (1529, 5497, NULL, 1872);
INSERT INTO 'dancesrecordingsmap' VALUES (1531, 3789, NULL, 1874);
INSERT INTO 'dancesrecordingsmap' VALUES (1532, 5637, NULL, 1875);
INSERT INTO 'dancesrecordingsmap' VALUES (1533, 6915, NULL, 1876);
INSERT INTO 'dancesrecordingsmap' VALUES (1534, 2349, NULL, 1877);
INSERT INTO 'dancesrecordingsmap' VALUES (1535, 3774, NULL, 1878);
INSERT INTO 'dancesrecordingsmap' VALUES (1536, 4032, NULL, 1879);
INSERT INTO 'dancesrecordingsmap' VALUES (1537, 2250, NULL, 1880);
INSERT INTO 'dancesrecordingsmap' VALUES (1538, 2428, NULL, 1881);
INSERT INTO 'dancesrecordingsmap' VALUES (1539, 4641, NULL, 1882);
INSERT INTO 'dancesrecordingsmap' VALUES (1540, 2747, NULL, 1883);
INSERT INTO 'dancesrecordingsmap' VALUES (1541, 3888, NULL, 1884);
INSERT INTO 'dancesrecordingsmap' VALUES (1542, 6848, NULL, 1885);
INSERT INTO 'dancesrecordingsmap' VALUES (1543, 1786, NULL, 1887);
INSERT INTO 'dancesrecordingsmap' VALUES (1544, 3154, NULL, 1888);
INSERT INTO 'dancesrecordingsmap' VALUES (1545, 1348, NULL, 1889);
INSERT INTO 'dancesrecordingsmap' VALUES (1546, 4782, NULL, 1890);
INSERT INTO 'dancesrecordingsmap' VALUES (1547, 5525, NULL, 1891);
INSERT INTO 'dancesrecordingsmap' VALUES (1548, 7109, NULL, 1892);
INSERT INTO 'dancesrecordingsmap' VALUES (1549, 754, NULL, 1893);
INSERT INTO 'dancesrecordingsmap' VALUES (1550, 4068, NULL, 1894);
INSERT INTO 'dancesrecordingsmap' VALUES (1551, 7546, NULL, 1895);
INSERT INTO 'dancesrecordingsmap' VALUES (1552, 7553, NULL, 1896);
INSERT INTO 'dancesrecordingsmap' VALUES (1553, 7548, NULL, 1897);
INSERT INTO 'dancesrecordingsmap' VALUES (1554, 8146, NULL, 1898);
INSERT INTO 'dancesrecordingsmap' VALUES (3726, 7548, NULL, 4727);
INSERT INTO 'dancesrecordingsmap' VALUES (3727, 8146, NULL, 4729);
INSERT INTO 'dancesrecordingsmap' VALUES (3728, 6712, NULL, 4730);
INSERT INTO 'dancesrecordingsmap' VALUES (3729, 7546, NULL, 4732);
INSERT INTO 'dancesrecordingsmap' VALUES (3730, 4646, NULL, 4733);
INSERT INTO 'dancesrecordingsmap' VALUES (3731, 1792, NULL, 4736);
INSERT INTO 'dancesrecordingsmap' VALUES (3732, 5964, NULL, 4738);
INSERT INTO 'dancesrecordingsmap' VALUES (3733, 2250, NULL, 4739);
INSERT INTO 'dancesrecordingsmap' VALUES (3734, 7548, NULL, 4740);
INSERT INTO 'dancesrecordingsmap' VALUES (3735, 8146, NULL, 4741);
INSERT INTO 'dancesrecordingsmap' VALUES (1609, 810, NULL, 1970);
INSERT INTO 'dancesrecordingsmap' VALUES (3737, 1792, NULL, 3704);
INSERT INTO 'dancesrecordingsmap' VALUES (3738, 2846, NULL, 4743);
INSERT INTO 'dancesrecordingsmap' VALUES (3739, 2846, NULL, 4746);
INSERT INTO 'dancesrecordingsmap' VALUES (3740, 9041, NULL, 2459);
INSERT INTO 'dancesrecordingsmap' VALUES (3742, 9045, NULL, 804);
INSERT INTO 'dancesrecordingsmap' VALUES (3743, 1562, NULL, 4603);
INSERT INTO 'dancesrecordingsmap' VALUES (3744, 633, NULL, 4604);
INSERT INTO 'dancesrecordingsmap' VALUES (3745, 4862, NULL, 4610);
INSERT INTO 'dancesrecordingsmap' VALUES (3746, 522, NULL, 4611);
INSERT INTO 'dancesrecordingsmap' VALUES (3747, 8154, NULL, 4751);
INSERT INTO 'dancesrecordingsmap' VALUES (1556, 2506, NULL, 1900);
INSERT INTO 'dancesrecordingsmap' VALUES (1557, 5463, NULL, 1901);
INSERT INTO 'dancesrecordingsmap' VALUES (3702, 6380, NULL, 4689);
INSERT INTO 'dancesrecordingsmap' VALUES (1516, 2354, NULL, 1857);
INSERT INTO 'dancesrecordingsmap' VALUES (1480, 7093, NULL, 1819);
INSERT INTO 'dancesrecordingsmap' VALUES (3711, 2777, NULL, 4698);
INSERT INTO 'dancesrecordingsmap' VALUES (1514, 189, NULL, 1855);
INSERT INTO 'dancesrecordingsmap' VALUES (1476, 6086, NULL, 1815);
INSERT INTO 'dancesrecordingsmap' VALUES (1555, 8142, NULL, 1899);
INSERT INTO 'dancesrecordingsmap' VALUES (1558, 1280, NULL, 1903);
INSERT INTO 'dancesrecordingsmap' VALUES (1559, 1562, NULL, 1904);
INSERT INTO 'dancesrecordingsmap' VALUES (1560, 2389, NULL, 1905);
INSERT INTO 'dancesrecordingsmap' VALUES (1561, 5198, NULL, 1909);
INSERT INTO 'dancesrecordingsmap' VALUES (1562, 354, NULL, 1910);
INSERT INTO 'dancesrecordingsmap' VALUES (1563, 5355, NULL, 1911);
INSERT INTO 'dancesrecordingsmap' VALUES (1564, 535, NULL, 1912);
INSERT INTO 'dancesrecordingsmap' VALUES (1565, 6081, NULL, 1913);
INSERT INTO 'dancesrecordingsmap' VALUES (1567, 5308, NULL, 1915);
INSERT INTO 'dancesrecordingsmap' VALUES (1568, 129, NULL, 1916);
INSERT INTO 'dancesrecordingsmap' VALUES (1569, 1235, NULL, 1917);
INSERT INTO 'dancesrecordingsmap' VALUES (1570, 2525, NULL, 1918);
INSERT INTO 'dancesrecordingsmap' VALUES (1572, 1314, NULL, 1920);
INSERT INTO 'dancesrecordingsmap' VALUES (1573, 1625, NULL, 1921);
INSERT INTO 'dancesrecordingsmap' VALUES (1574, 8142, NULL, 1922);
INSERT INTO 'dancesrecordingsmap' VALUES (1469, 958, NULL, 1808);
INSERT INTO 'dancesrecordingsmap' VALUES (1468, 5208, NULL, 1807);
INSERT INTO 'dancesrecordingsmap' VALUES (1473, 654, NULL, 1812);
INSERT INTO 'dancesrecordingsmap' VALUES (1471, 1762, NULL, 1810);
INSERT INTO 'dancesrecordingsmap' VALUES (1467, 611, NULL, 1806);
INSERT INTO 'dancesrecordingsmap' VALUES (1472, 6310, NULL, 1811);
INSERT INTO 'dancesrecordingsmap' VALUES (1470, 2389, NULL, 1809);
INSERT INTO 'dancesrecordingsmap' VALUES (1522, 4133, NULL, 1864);
INSERT INTO 'dancesrecordingsmap' VALUES (1523, 754, NULL, 1865);
INSERT INTO 'dancesrecordingsmap' VALUES (1518, 6609, NULL, 1860);
INSERT INTO 'dancesrecordingsmap' VALUES (1521, 3722, NULL, 1863);
INSERT INTO 'dancesrecordingsmap' VALUES (1520, 902, NULL, 1862);
INSERT INTO 'dancesrecordingsmap' VALUES (1524, 4755, NULL, 1866);
INSERT INTO 'dancesrecordingsmap' VALUES (1519, 1624, NULL, 1861);
INSERT INTO 'dancesrecordingsmap' VALUES (3741, 9044, NULL, 1028);
INSERT INTO 'dancesrecordingsmap' VALUES (3703, 4720, NULL, 4690);
INSERT INTO 'dancesrecordingsmap' VALUES (1575, 7546, NULL, 1923);
INSERT INTO 'dancesrecordingsmap' VALUES (1576, 7548, NULL, 1924);
INSERT INTO 'dancesrecordingsmap' VALUES (1577, 8146, NULL, 1925);
INSERT INTO 'dancesrecordingsmap' VALUES (1578, 3743, NULL, 1926);
INSERT INTO 'dancesrecordingsmap' VALUES (1579, 3057, NULL, 1927);
INSERT INTO 'dancesrecordingsmap' VALUES (1580, 2189, NULL, 1929);
INSERT INTO 'dancesrecordingsmap' VALUES (1581, 1562, NULL, 1930);
INSERT INTO 'dancesrecordingsmap' VALUES (1582, 4015, NULL, 1933);
INSERT INTO 'dancesrecordingsmap' VALUES (1583, 8144, NULL, 1934);
INSERT INTO 'dancesrecordingsmap' VALUES (1584, 7554, NULL, 1935);
INSERT INTO 'dancesrecordingsmap' VALUES (1585, 3299, NULL, 1939);
INSERT INTO 'dancesrecordingsmap' VALUES (1586, 6471, NULL, 1940);
INSERT INTO 'dancesrecordingsmap' VALUES (1587, 223, NULL, 1941);
INSERT INTO 'dancesrecordingsmap' VALUES (1588, 6048, NULL, 1942);
INSERT INTO 'dancesrecordingsmap' VALUES (1589, 1745, NULL, 1943);
INSERT INTO 'dancesrecordingsmap' VALUES (1590, 1562, NULL, 1944);
INSERT INTO 'dancesrecordingsmap' VALUES (1591, 2250, NULL, 1945);
INSERT INTO 'dancesrecordingsmap' VALUES (1592, 7554, NULL, 1947);
INSERT INTO 'dancesrecordingsmap' VALUES (1593, 4548, NULL, 1948);
INSERT INTO 'dancesrecordingsmap' VALUES (1594, 1020, NULL, 1949);
INSERT INTO 'dancesrecordingsmap' VALUES (1595, 3862, NULL, 1950);
INSERT INTO 'dancesrecordingsmap' VALUES (1596, 3506, NULL, 1951);
INSERT INTO 'dancesrecordingsmap' VALUES (1597, 743, NULL, 1952);
INSERT INTO 'dancesrecordingsmap' VALUES (1598, 3759, NULL, 1953);
INSERT INTO 'dancesrecordingsmap' VALUES (1599, 7546, NULL, 1954);
INSERT INTO 'dancesrecordingsmap' VALUES (1600, 1786, NULL, 1955);
INSERT INTO 'dancesrecordingsmap' VALUES (1601, 2962, NULL, 1957);
INSERT INTO 'dancesrecordingsmap' VALUES (1602, 4014, NULL, 1959);
INSERT INTO 'dancesrecordingsmap' VALUES (1603, 5915, NULL, 1960);
INSERT INTO 'dancesrecordingsmap' VALUES (1604, 1562, NULL, 1962);
INSERT INTO 'dancesrecordingsmap' VALUES (1605, 1582, NULL, 1963);
INSERT INTO 'dancesrecordingsmap' VALUES (1606, 1782, NULL, 1965);
INSERT INTO 'dancesrecordingsmap' VALUES (1607, 4102, NULL, 1966);
INSERT INTO 'dancesrecordingsmap' VALUES (1610, 6051, NULL, 1971);
INSERT INTO 'dancesrecordingsmap' VALUES (1611, 5865, NULL, 1972);
INSERT INTO 'dancesrecordingsmap' VALUES (1612, 5927, NULL, 1973);
INSERT INTO 'dancesrecordingsmap' VALUES (1613, 153, NULL, 1974);
INSERT INTO 'dancesrecordingsmap' VALUES (1614, 54, NULL, 1976);
INSERT INTO 'dancesrecordingsmap' VALUES (1615, 5308, NULL, 1977);
INSERT INTO 'dancesrecordingsmap' VALUES (1616, 462, NULL, 1978);
INSERT INTO 'dancesrecordingsmap' VALUES (1617, 1998, NULL, 1979);
INSERT INTO 'dancesrecordingsmap' VALUES (1619, 6972, NULL, 1981);
INSERT INTO 'dancesrecordingsmap' VALUES (1620, 6703, NULL, 1982);
INSERT INTO 'dancesrecordingsmap' VALUES (1621, 5040, NULL, 1994);
INSERT INTO 'dancesrecordingsmap' VALUES (1622, 6816, NULL, 1995);
INSERT INTO 'dancesrecordingsmap' VALUES (1623, 3594, NULL, 1996);
INSERT INTO 'dancesrecordingsmap' VALUES (1624, 4359, NULL, 1997);
INSERT INTO 'dancesrecordingsmap' VALUES (1626, 2562, NULL, 1999);
INSERT INTO 'dancesrecordingsmap' VALUES (1627, 4407, NULL, 2000);
INSERT INTO 'dancesrecordingsmap' VALUES (1629, 2353, NULL, 2002);
INSERT INTO 'dancesrecordingsmap' VALUES (1631, 5591, NULL, 2006);
INSERT INTO 'dancesrecordingsmap' VALUES (1632, 5208, NULL, 2008);
INSERT INTO 'dancesrecordingsmap' VALUES (1633, 2024, NULL, 2009);
INSERT INTO 'dancesrecordingsmap' VALUES (1634, 633, NULL, 2010);
INSERT INTO 'dancesrecordingsmap' VALUES (1635, 743, NULL, 2014);
INSERT INTO 'dancesrecordingsmap' VALUES (1636, 3057, NULL, 2020);
INSERT INTO 'dancesrecordingsmap' VALUES (1638, 1792, NULL, 2023);
INSERT INTO 'dancesrecordingsmap' VALUES (1642, 5832, NULL, 2030);
INSERT INTO 'dancesrecordingsmap' VALUES (1643, 2409, NULL, 2032);
INSERT INTO 'dancesrecordingsmap' VALUES (1644, 3743, NULL, 2033);
INSERT INTO 'dancesrecordingsmap' VALUES (1645, 658, NULL, 2035);
INSERT INTO 'dancesrecordingsmap' VALUES (1646, 3231, NULL, 2043);
INSERT INTO 'dancesrecordingsmap' VALUES (1647, 3980, NULL, 2044);
INSERT INTO 'dancesrecordingsmap' VALUES (3748, 6505, NULL, 4752);
INSERT INTO 'dancesrecordingsmap' VALUES (3749, 1582, NULL, 4753);
INSERT INTO 'dancesrecordingsmap' VALUES (3750, 3934, NULL, 4754);
INSERT INTO 'dancesrecordingsmap' VALUES (3751, 1478, NULL, 4756);
INSERT INTO 'dancesrecordingsmap' VALUES (3752, 7546, NULL, 4760);
INSERT INTO 'dancesrecordingsmap' VALUES (3753, 1834, NULL, 4762);
INSERT INTO 'dancesrecordingsmap' VALUES (3754, 5525, NULL, 4765);
INSERT INTO 'dancesrecordingsmap' VALUES (3755, 1931, NULL, 4767);
INSERT INTO 'dancesrecordingsmap' VALUES (3756, 3672, NULL, 4770);
INSERT INTO 'dancesrecordingsmap' VALUES (3757, 7546, NULL, 4771);
INSERT INTO 'dancesrecordingsmap' VALUES (3758, 1562, NULL, 4773);
INSERT INTO 'dancesrecordingsmap' VALUES (3759, 754, NULL, 4775);
INSERT INTO 'dancesrecordingsmap' VALUES (3760, 2745, NULL, 4776);
INSERT INTO 'dancesrecordingsmap' VALUES (3761, 7554, NULL, 4778);
INSERT INTO 'dancesrecordingsmap' VALUES (3762, 5525, NULL, 4782);
INSERT INTO 'dancesrecordingsmap' VALUES (3763, 8146, NULL, 4784);
INSERT INTO 'dancesrecordingsmap' VALUES (3764, 7574, NULL, 4787);
INSERT INTO 'dancesrecordingsmap' VALUES (3765, 7546, NULL, 4789);
INSERT INTO 'dancesrecordingsmap' VALUES (3766, 116, NULL, 4794);
INSERT INTO 'dancesrecordingsmap' VALUES (3767, 2562, NULL, 4795);
INSERT INTO 'dancesrecordingsmap' VALUES (3768, 7546, NULL, 4799);
INSERT INTO 'dancesrecordingsmap' VALUES (3769, 7546, NULL, 4802);
INSERT INTO 'dancesrecordingsmap' VALUES (3770, 8154, NULL, 4803);
INSERT INTO 'dancesrecordingsmap' VALUES (3771, 2136, NULL, 4809);
INSERT INTO 'dancesrecordingsmap' VALUES (3772, 1154, NULL, 4810);
INSERT INTO 'dancesrecordingsmap' VALUES (3773, 760, NULL, 4811);
INSERT INTO 'dancesrecordingsmap' VALUES (3774, 1586, NULL, 4812);
INSERT INTO 'dancesrecordingsmap' VALUES (3775, 4438, NULL, 4813);
INSERT INTO 'dancesrecordingsmap' VALUES (3776, 2807, NULL, 4814);
INSERT INTO 'dancesrecordingsmap' VALUES (3777, 4506, NULL, 4815);
INSERT INTO 'dancesrecordingsmap' VALUES (3778, 3631, NULL, 4816);
INSERT INTO 'dancesrecordingsmap' VALUES (3779, 5906, NULL, 4817);
INSERT INTO 'dancesrecordingsmap' VALUES (3780, 6566, NULL, 4818);
INSERT INTO 'dancesrecordingsmap' VALUES (3781, 4461, NULL, 4819);
INSERT INTO 'dancesrecordingsmap' VALUES (3782, 753, NULL, 4820);
INSERT INTO 'dancesrecordingsmap' VALUES (3783, 3897, NULL, 1739);
INSERT INTO 'dancesrecordingsmap' VALUES (3784, 1562, NULL, 4821);
INSERT INTO 'dancesrecordingsmap' VALUES (3785, 7574, NULL, 4822);
INSERT INTO 'dancesrecordingsmap' VALUES (3786, 7546, NULL, 4823);
INSERT INTO 'dancesrecordingsmap' VALUES (3787, 7546, NULL, 4824);
INSERT INTO 'dancesrecordingsmap' VALUES (3788, 745, NULL, 4827);
INSERT INTO 'dancesrecordingsmap' VALUES (3789, 4043, NULL, 4828);
INSERT INTO 'dancesrecordingsmap' VALUES (8078, 11188, NULL, 8898);
INSERT INTO 'dancesrecordingsmap' VALUES (8083, 10920, NULL, 8921);
INSERT INTO 'dancesrecordingsmap' VALUES (8097, 4491, NULL, 8936);
INSERT INTO 'dancesrecordingsmap' VALUES (1648, 3783, NULL, 2045);
INSERT INTO 'dancesrecordingsmap' VALUES (1649, 7139, NULL, 2046);
INSERT INTO 'dancesrecordingsmap' VALUES (1650, 2428, NULL, 2047);
INSERT INTO 'dancesrecordingsmap' VALUES (1652, 909, NULL, 2049);
INSERT INTO 'dancesrecordingsmap' VALUES (1653, 894, NULL, 2050);
INSERT INTO 'dancesrecordingsmap' VALUES (1655, 6373, NULL, 2052);
INSERT INTO 'dancesrecordingsmap' VALUES (1657, 7546, NULL, 2056);
INSERT INTO 'dancesrecordingsmap' VALUES (1658, 2415, NULL, 2057);
INSERT INTO 'dancesrecordingsmap' VALUES (1659, 7548, NULL, 2058);
INSERT INTO 'dancesrecordingsmap' VALUES (1660, 5404, NULL, 2059);
INSERT INTO 'dancesrecordingsmap' VALUES (1661, 1927, NULL, 2065);
INSERT INTO 'dancesrecordingsmap' VALUES (1662, 7548, NULL, 2071);
INSERT INTO 'dancesrecordingsmap' VALUES (1663, 361, NULL, 2073);
INSERT INTO 'dancesrecordingsmap' VALUES (1664, 7546, NULL, 2075);
INSERT INTO 'dancesrecordingsmap' VALUES (1665, 1478, NULL, 2076);
INSERT INTO 'dancesrecordingsmap' VALUES (1666, 1562, NULL, 2080);
INSERT INTO 'dancesrecordingsmap' VALUES (1667, 2250, NULL, 2081);
INSERT INTO 'dancesrecordingsmap' VALUES (1668, 352, NULL, 2084);
INSERT INTO 'dancesrecordingsmap' VALUES (1670, 1280, NULL, 2086);
INSERT INTO 'dancesrecordingsmap' VALUES (1671, 1792, NULL, 2087);
INSERT INTO 'dancesrecordingsmap' VALUES (1672, 848, NULL, 2088);
INSERT INTO 'dancesrecordingsmap' VALUES (1673, 909, NULL, 2089);
INSERT INTO 'dancesrecordingsmap' VALUES (1674, 743, NULL, 2090);
INSERT INTO 'dancesrecordingsmap' VALUES (1675, 3759, NULL, 2091);
INSERT INTO 'dancesrecordingsmap' VALUES (1676, 7546, NULL, 2092);
INSERT INTO 'dancesrecordingsmap' VALUES (1677, 7548, NULL, 2093);
INSERT INTO 'dancesrecordingsmap' VALUES (1678, 2979, NULL, 2094);
INSERT INTO 'dancesrecordingsmap' VALUES (1637, 4358, NULL, 2021);
INSERT INTO 'dancesrecordingsmap' VALUES (1641, 743, NULL, 2027);
INSERT INTO 'dancesrecordingsmap' VALUES (1640, 3058, NULL, 2025);
INSERT INTO 'dancesrecordingsmap' VALUES (1679, 2956, NULL, 2096);
INSERT INTO 'dancesrecordingsmap' VALUES (1680, 2916, NULL, 2098);
INSERT INTO 'dancesrecordingsmap' VALUES (1681, 4239, NULL, 2099);
INSERT INTO 'dancesrecordingsmap' VALUES (1682, 4491, NULL, 2100);
INSERT INTO 'dancesrecordingsmap' VALUES (1683, 5731, NULL, 2101);
INSERT INTO 'dancesrecordingsmap' VALUES (1684, 4103, NULL, 2102);
INSERT INTO 'dancesrecordingsmap' VALUES (1685, 3281, NULL, 2104);
INSERT INTO 'dancesrecordingsmap' VALUES (1686, 7129, NULL, 2107);
INSERT INTO 'dancesrecordingsmap' VALUES (1687, 3651, NULL, 2108);
INSERT INTO 'dancesrecordingsmap' VALUES (1688, 633, NULL, 2109);
INSERT INTO 'dancesrecordingsmap' VALUES (1689, 4014, NULL, 2110);
INSERT INTO 'dancesrecordingsmap' VALUES (1690, 4282, NULL, 2111);
INSERT INTO 'dancesrecordingsmap' VALUES (1691, 642, NULL, 2112);
INSERT INTO 'dancesrecordingsmap' VALUES (1693, 1686, NULL, 2114);
INSERT INTO 'dancesrecordingsmap' VALUES (1694, 5713, NULL, 2115);
INSERT INTO 'dancesrecordingsmap' VALUES (1695, 3680, NULL, 2116);
INSERT INTO 'dancesrecordingsmap' VALUES (1696, 7188, NULL, 2117);
INSERT INTO 'dancesrecordingsmap' VALUES (1697, 6037, NULL, 2118);
INSERT INTO 'dancesrecordingsmap' VALUES (1698, 5707, NULL, 2119);
INSERT INTO 'dancesrecordingsmap' VALUES (1608, 769, NULL, 1969);
INSERT INTO 'dancesrecordingsmap' VALUES (1639, 5262, NULL, 2024);
INSERT INTO 'dancesrecordingsmap' VALUES (1566, 2043, NULL, 1914);
INSERT INTO 'dancesrecordingsmap' VALUES (1651, 6629, NULL, 2048);
INSERT INTO 'dancesrecordingsmap' VALUES (1630, 3726, NULL, 2003);
INSERT INTO 'dancesrecordingsmap' VALUES (1618, 6847, NULL, 1980);
INSERT INTO 'dancesrecordingsmap' VALUES (1654, 6813, NULL, 2051);
INSERT INTO 'dancesrecordingsmap' VALUES (1571, 3876, NULL, 1919);
INSERT INTO 'dancesrecordingsmap' VALUES (1628, 917, NULL, 2001);
INSERT INTO 'dancesrecordingsmap' VALUES (1699, 5033, NULL, 2121);
INSERT INTO 'dancesrecordingsmap' VALUES (1700, 3672, NULL, 2122);
INSERT INTO 'dancesrecordingsmap' VALUES (1701, 3225, NULL, 2123);
INSERT INTO 'dancesrecordingsmap' VALUES (1702, 3921, NULL, 2124);
INSERT INTO 'dancesrecordingsmap' VALUES (1703, 5239, NULL, 2125);
INSERT INTO 'dancesrecordingsmap' VALUES (1704, 2153, NULL, 2126);
INSERT INTO 'dancesrecordingsmap' VALUES (1705, 6349, NULL, 2127);
INSERT INTO 'dancesrecordingsmap' VALUES (1706, 3589, NULL, 2128);
INSERT INTO 'dancesrecordingsmap' VALUES (1707, 4782, NULL, 2129);
INSERT INTO 'dancesrecordingsmap' VALUES (1708, 6407, NULL, 2130);
INSERT INTO 'dancesrecordingsmap' VALUES (1709, 3561, NULL, 2131);
INSERT INTO 'dancesrecordingsmap' VALUES (1710, 5462, NULL, 2132);
INSERT INTO 'dancesrecordingsmap' VALUES (1711, 3588, NULL, 2133);
INSERT INTO 'dancesrecordingsmap' VALUES (1712, 3934, NULL, 2134);
INSERT INTO 'dancesrecordingsmap' VALUES (1713, 2421, NULL, 2135);
INSERT INTO 'dancesrecordingsmap' VALUES (1714, 2992, NULL, 2136);
INSERT INTO 'dancesrecordingsmap' VALUES (1715, 6104, NULL, 2137);
INSERT INTO 'dancesrecordingsmap' VALUES (1692, 6186, NULL, 2113);
INSERT INTO 'dancesrecordingsmap' VALUES (1716, 3636, NULL, 2138);
INSERT INTO 'dancesrecordingsmap' VALUES (1717, 218, NULL, 2139);
INSERT INTO 'dancesrecordingsmap' VALUES (1718, 7180, NULL, 2140);
INSERT INTO 'dancesrecordingsmap' VALUES (1721, 5529, NULL, 2142);
INSERT INTO 'dancesrecordingsmap' VALUES (1722, 5243, NULL, 2143);
INSERT INTO 'dancesrecordingsmap' VALUES (1723, 887, NULL, 2144);
INSERT INTO 'dancesrecordingsmap' VALUES (1725, 7152, NULL, 2146);
INSERT INTO 'dancesrecordingsmap' VALUES (1727, 6448, NULL, 2148);
INSERT INTO 'dancesrecordingsmap' VALUES (1728, 2349, NULL, 2152);
INSERT INTO 'dancesrecordingsmap' VALUES (1729, 153, NULL, 2153);
INSERT INTO 'dancesrecordingsmap' VALUES (1731, 549, NULL, 2155);
INSERT INTO 'dancesrecordingsmap' VALUES (1732, 1280, NULL, 2156);
INSERT INTO 'dancesrecordingsmap' VALUES (1733, 3129, NULL, 2157);
INSERT INTO 'dancesrecordingsmap' VALUES (1734, 4935, NULL, 2158);
INSERT INTO 'dancesrecordingsmap' VALUES (1735, 4064, NULL, 2159);
INSERT INTO 'dancesrecordingsmap' VALUES (1737, 7546, NULL, 2162);
INSERT INTO 'dancesrecordingsmap' VALUES (1738, 2846, NULL, 2163);
INSERT INTO 'dancesrecordingsmap' VALUES (1739, 3743, NULL, 2164);
INSERT INTO 'dancesrecordingsmap' VALUES (1740, 373, NULL, 2165);
INSERT INTO 'dancesrecordingsmap' VALUES (3790, 3225, NULL, 4829);
INSERT INTO 'dancesrecordingsmap' VALUES (3791, 4407, NULL, 4830);
INSERT INTO 'dancesrecordingsmap' VALUES (3792, 4763, NULL, 4831);
INSERT INTO 'dancesrecordingsmap' VALUES (3793, 289, NULL, 4832);
INSERT INTO 'dancesrecordingsmap' VALUES (3794, 704, NULL, 4833);
INSERT INTO 'dancesrecordingsmap' VALUES (3795, 4491, NULL, 4834);
INSERT INTO 'dancesrecordingsmap' VALUES (3798, 7555, NULL, 4847);
INSERT INTO 'dancesrecordingsmap' VALUES (3799, 7546, NULL, 4854);
INSERT INTO 'dancesrecordingsmap' VALUES (3800, 3659, NULL, 4857);
INSERT INTO 'dancesrecordingsmap' VALUES (3801, 3129, NULL, 4864);
INSERT INTO 'dancesrecordingsmap' VALUES (3810, 9091, NULL, 1468);
INSERT INTO 'dancesrecordingsmap' VALUES (3811, 9092, NULL, 2149);
INSERT INTO 'dancesrecordingsmap' VALUES (3812, 9093, NULL, 2150);
INSERT INTO 'dancesrecordingsmap' VALUES (3814, 9095, NULL, 2763);
INSERT INTO 'dancesrecordingsmap' VALUES (3816, 9054, NULL, 2765);
INSERT INTO 'dancesrecordingsmap' VALUES (3817, 9097, NULL, 4594);
INSERT INTO 'dancesrecordingsmap' VALUES (3818, 9098, NULL, 4595);
INSERT INTO 'dancesrecordingsmap' VALUES (3819, 9099, NULL, 4596);
INSERT INTO 'dancesrecordingsmap' VALUES (3820, 9100, NULL, 4597);
INSERT INTO 'dancesrecordingsmap' VALUES (3821, 9101, NULL, 4598);
INSERT INTO 'dancesrecordingsmap' VALUES (3822, 4641, NULL, 4882);
INSERT INTO 'dancesrecordingsmap' VALUES (3823, 2436, NULL, 4883);
INSERT INTO 'dancesrecordingsmap' VALUES (3824, 743, NULL, 4884);
INSERT INTO 'dancesrecordingsmap' VALUES (3825, 5555, NULL, 4885);
INSERT INTO 'dancesrecordingsmap' VALUES (3826, 3165, NULL, 4886);
INSERT INTO 'dancesrecordingsmap' VALUES (3827, 5707, NULL, 4887);
INSERT INTO 'dancesrecordingsmap' VALUES (3828, 6233, NULL, 4888);
INSERT INTO 'dancesrecordingsmap' VALUES (3829, 2317, NULL, 4889);
INSERT INTO 'dancesrecordingsmap' VALUES (3830, 5525, NULL, 4890);
INSERT INTO 'dancesrecordingsmap' VALUES (3831, 2745, NULL, 4891);
INSERT INTO 'dancesrecordingsmap' VALUES (8079, 3326, NULL, 8899);
INSERT INTO 'dancesrecordingsmap' VALUES (8084, 4641, NULL, 8924);
INSERT INTO 'dancesrecordingsmap' VALUES (8098, 3637, NULL, 8937);
INSERT INTO 'dancesrecordingsmap' VALUES (1741, 5529, NULL, 2166);
INSERT INTO 'dancesrecordingsmap' VALUES (1742, 7546, NULL, 2172);
INSERT INTO 'dancesrecordingsmap' VALUES (1743, 7553, NULL, 2175);
INSERT INTO 'dancesrecordingsmap' VALUES (1744, 8154, NULL, 2177);
INSERT INTO 'dancesrecordingsmap' VALUES (1745, 8146, NULL, 2178);
INSERT INTO 'dancesrecordingsmap' VALUES (1746, 5239, NULL, 2179);
INSERT INTO 'dancesrecordingsmap' VALUES (1747, 7548, NULL, 2181);
INSERT INTO 'dancesrecordingsmap' VALUES (1748, 4239, NULL, 2185);
INSERT INTO 'dancesrecordingsmap' VALUES (1749, 56, NULL, 2187);
INSERT INTO 'dancesrecordingsmap' VALUES (1750, 6634, NULL, 2188);
INSERT INTO 'dancesrecordingsmap' VALUES (1751, 5463, NULL, 2189);
INSERT INTO 'dancesrecordingsmap' VALUES (1752, 1891, NULL, 2190);
INSERT INTO 'dancesrecordingsmap' VALUES (1753, 76, NULL, 2191);
INSERT INTO 'dancesrecordingsmap' VALUES (1755, 43, NULL, 2193);
INSERT INTO 'dancesrecordingsmap' VALUES (1756, 899, NULL, 2194);
INSERT INTO 'dancesrecordingsmap' VALUES (1757, 6029, NULL, 2195);
INSERT INTO 'dancesrecordingsmap' VALUES (1758, 4334, NULL, 2196);
INSERT INTO 'dancesrecordingsmap' VALUES (1759, 1838, NULL, 2197);
INSERT INTO 'dancesrecordingsmap' VALUES (1760, 5637, NULL, 2199);
INSERT INTO 'dancesrecordingsmap' VALUES (1761, 3923, NULL, 2201);
INSERT INTO 'dancesrecordingsmap' VALUES (1762, 5999, NULL, 2202);
INSERT INTO 'dancesrecordingsmap' VALUES (1763, 2353, NULL, 2203);
INSERT INTO 'dancesrecordingsmap' VALUES (1764, 540, NULL, 2204);
INSERT INTO 'dancesrecordingsmap' VALUES (1765, 1025, NULL, 2206);
INSERT INTO 'dancesrecordingsmap' VALUES (1767, 5522, NULL, 2208);
INSERT INTO 'dancesrecordingsmap' VALUES (1768, 1100, NULL, 2209);
INSERT INTO 'dancesrecordingsmap' VALUES (1769, 2415, NULL, 2210);
INSERT INTO 'dancesrecordingsmap' VALUES (1770, 3246, NULL, 2211);
INSERT INTO 'dancesrecordingsmap' VALUES (1771, 3506, NULL, 2212);
INSERT INTO 'dancesrecordingsmap' VALUES (1772, 4102, NULL, 2213);
INSERT INTO 'dancesrecordingsmap' VALUES (1773, 4051, NULL, 2214);
INSERT INTO 'dancesrecordingsmap' VALUES (1774, 5794, NULL, 2215);
INSERT INTO 'dancesrecordingsmap' VALUES (1775, 2716, NULL, 2216);
INSERT INTO 'dancesrecordingsmap' VALUES (1776, 2956, NULL, 2217);
INSERT INTO 'dancesrecordingsmap' VALUES (1777, 7147, NULL, 2218);
INSERT INTO 'dancesrecordingsmap' VALUES (1778, 4548, NULL, 2219);
INSERT INTO 'dancesrecordingsmap' VALUES (1779, 4239, NULL, 2220);
INSERT INTO 'dancesrecordingsmap' VALUES (1780, 5829, NULL, 2221);
INSERT INTO 'dancesrecordingsmap' VALUES (1782, 7546, NULL, 2223);
INSERT INTO 'dancesrecordingsmap' VALUES (1783, 7552, NULL, 2226);
INSERT INTO 'dancesrecordingsmap' VALUES (1784, 7553, NULL, 2227);
INSERT INTO 'dancesrecordingsmap' VALUES (1785, 5964, NULL, 2229);
INSERT INTO 'dancesrecordingsmap' VALUES (1786, 1478, NULL, 2230);
INSERT INTO 'dancesrecordingsmap' VALUES (1787, 5543, NULL, 2232);
INSERT INTO 'dancesrecordingsmap' VALUES (1788, 2916, NULL, 2233);
INSERT INTO 'dancesrecordingsmap' VALUES (1789, 4303, NULL, 2235);
INSERT INTO 'dancesrecordingsmap' VALUES (1790, 6505, NULL, 2236);
INSERT INTO 'dancesrecordingsmap' VALUES (1791, 5033, NULL, 2237);
INSERT INTO 'dancesrecordingsmap' VALUES (1792, 6701, NULL, 2238);
INSERT INTO 'dancesrecordingsmap' VALUES (1793, 5519, NULL, 2239);
INSERT INTO 'dancesrecordingsmap' VALUES (1794, 1966, NULL, 2240);
INSERT INTO 'dancesrecordingsmap' VALUES (1795, 4239, NULL, 2241);
INSERT INTO 'dancesrecordingsmap' VALUES (1796, 2409, NULL, 2242);
INSERT INTO 'dancesrecordingsmap' VALUES (1797, 5982, NULL, 2243);
INSERT INTO 'dancesrecordingsmap' VALUES (1799, 6915, NULL, 2245);
INSERT INTO 'dancesrecordingsmap' VALUES (1800, 2727, NULL, 2246);
INSERT INTO 'dancesrecordingsmap' VALUES (1801, 3580, NULL, 2247);
INSERT INTO 'dancesrecordingsmap' VALUES (1802, 3594, NULL, 2248);
INSERT INTO 'dancesrecordingsmap' VALUES (1803, 6748, NULL, 2249);
INSERT INTO 'dancesrecordingsmap' VALUES (1804, 5376, NULL, 2250);
INSERT INTO 'dancesrecordingsmap' VALUES (1805, 312, NULL, 2251);
INSERT INTO 'dancesrecordingsmap' VALUES (1806, 3722, NULL, 2252);
INSERT INTO 'dancesrecordingsmap' VALUES (1807, 899, NULL, 2253);
INSERT INTO 'dancesrecordingsmap' VALUES (1808, 2631, NULL, 2254);
INSERT INTO 'dancesrecordingsmap' VALUES (1809, 7546, NULL, 2255);
INSERT INTO 'dancesrecordingsmap' VALUES (1810, 7548, NULL, 2256);
INSERT INTO 'dancesrecordingsmap' VALUES (1811, 2970, NULL, 2257);
INSERT INTO 'dancesrecordingsmap' VALUES (1812, 1786, NULL, 2258);
INSERT INTO 'dancesrecordingsmap' VALUES (1813, 1638, NULL, 2259);
INSERT INTO 'dancesrecordingsmap' VALUES (1814, 3219, NULL, 2260);
INSERT INTO 'dancesrecordingsmap' VALUES (1815, 3424, NULL, 2261);
INSERT INTO 'dancesrecordingsmap' VALUES (1816, 4064, NULL, 2262);
INSERT INTO 'dancesrecordingsmap' VALUES (1817, 5624, NULL, 2263);
INSERT INTO 'dancesrecordingsmap' VALUES (1818, 4663, NULL, 2267);
INSERT INTO 'dancesrecordingsmap' VALUES (3802, 3526, NULL, 4868);
INSERT INTO 'dancesrecordingsmap' VALUES (3803, 7546, NULL, 4870);
INSERT INTO 'dancesrecordingsmap' VALUES (3804, 8154, NULL, 4871);
INSERT INTO 'dancesrecordingsmap' VALUES (3805, 1927, NULL, 4872);
INSERT INTO 'dancesrecordingsmap' VALUES (3806, 3152, NULL, 4875);
INSERT INTO 'dancesrecordingsmap' VALUES (1730, 6712, NULL, 2154);
INSERT INTO 'dancesrecordingsmap' VALUES (3808, 7552, NULL, 4879);
INSERT INTO 'dancesrecordingsmap' VALUES (3807, 4431, NULL, 4877);
INSERT INTO 'dancesrecordingsmap' VALUES (1821, 5033, NULL, 2270);
INSERT INTO 'dancesrecordingsmap' VALUES (1822, 1543, NULL, 2271);
INSERT INTO 'dancesrecordingsmap' VALUES (1823, 2498, NULL, 2272);
INSERT INTO 'dancesrecordingsmap' VALUES (1824, 6634, NULL, 2273);
INSERT INTO 'dancesrecordingsmap' VALUES (1825, 4318, NULL, 2276);
INSERT INTO 'dancesrecordingsmap' VALUES (1826, 5207, NULL, 2277);
INSERT INTO 'dancesrecordingsmap' VALUES (1827, 3672, NULL, 2278);
INSERT INTO 'dancesrecordingsmap' VALUES (1828, 7182, NULL, 2279);
INSERT INTO 'dancesrecordingsmap' VALUES (1829, 7111, NULL, 2280);
INSERT INTO 'dancesrecordingsmap' VALUES (1830, 2428, NULL, 2281);
INSERT INTO 'dancesrecordingsmap' VALUES (1831, 392, NULL, 2282);
INSERT INTO 'dancesrecordingsmap' VALUES (1832, 820, NULL, 2283);
INSERT INTO 'dancesrecordingsmap' VALUES (3832, 1792, NULL, 4892);
INSERT INTO 'dancesrecordingsmap' VALUES (3834, 6957, NULL, 4894);
INSERT INTO 'dancesrecordingsmap' VALUES (3835, 6748, NULL, 4895);
INSERT INTO 'dancesrecordingsmap' VALUES (3836, 6748, NULL, 4896);
INSERT INTO 'dancesrecordingsmap' VALUES (3837, 373, NULL, 4897);
INSERT INTO 'dancesrecordingsmap' VALUES (3838, 1782, NULL, 4899);
INSERT INTO 'dancesrecordingsmap' VALUES (3839, 588, NULL, 4660);
INSERT INTO 'dancesrecordingsmap' VALUES (3840, 4126, NULL, 4657);
INSERT INTO 'dancesrecordingsmap' VALUES (1781, 377, NULL, 2222);
INSERT INTO 'dancesrecordingsmap' VALUES (3815, 9096, NULL, 2764);
INSERT INTO 'dancesrecordingsmap' VALUES (1819, 522, NULL, 2268);
INSERT INTO 'dancesrecordingsmap' VALUES (1754, 7182, NULL, 2192);
INSERT INTO 'dancesrecordingsmap' VALUES (1724, 4998, NULL, 2145);
INSERT INTO 'dancesrecordingsmap' VALUES (1719, 1634, NULL, 2141);
INSERT INTO 'dancesrecordingsmap' VALUES (3841, 4127, NULL, 4657);
INSERT INTO 'dancesrecordingsmap' VALUES (3842, 6311, NULL, 4667);
INSERT INTO 'dancesrecordingsmap' VALUES (3843, 55, NULL, 4900);
INSERT INTO 'dancesrecordingsmap' VALUES (3844, 4374, NULL, 4901);
INSERT INTO 'dancesrecordingsmap' VALUES (3845, 2042, NULL, 4902);
INSERT INTO 'dancesrecordingsmap' VALUES (3846, 3620, NULL, 4903);
INSERT INTO 'dancesrecordingsmap' VALUES (3847, 3932, NULL, 4904);
INSERT INTO 'dancesrecordingsmap' VALUES (3848, 5065, NULL, 4905);
INSERT INTO 'dancesrecordingsmap' VALUES (3849, 5624, NULL, 4906);
INSERT INTO 'dancesrecordingsmap' VALUES (3851, 6373, NULL, 4908);
INSERT INTO 'dancesrecordingsmap' VALUES (3853, 3577, NULL, 4910);
INSERT INTO 'dancesrecordingsmap' VALUES (3854, 4935, NULL, 4911);
INSERT INTO 'dancesrecordingsmap' VALUES (3857, 9104, NULL, 4914);
INSERT INTO 'dancesrecordingsmap' VALUES (3858, 9105, NULL, 4915);
INSERT INTO 'dancesrecordingsmap' VALUES (3859, 9106, NULL, 4916);
INSERT INTO 'dancesrecordingsmap' VALUES (3860, 9107, NULL, 4917);
INSERT INTO 'dancesrecordingsmap' VALUES (3862, 9109, NULL, 4919);
INSERT INTO 'dancesrecordingsmap' VALUES (3863, 9110, NULL, 4920);
INSERT INTO 'dancesrecordingsmap' VALUES (3797, 7546, NULL, 4840);
INSERT INTO 'dancesrecordingsmap' VALUES (1820, 4291, NULL, 2269);
INSERT INTO 'dancesrecordingsmap' VALUES (1766, 2979, NULL, 2207);
INSERT INTO 'dancesrecordingsmap' VALUES (3856, 9103, NULL, 4913);
INSERT INTO 'dancesrecordingsmap' VALUES (1736, 6091, NULL, 2160);
INSERT INTO 'dancesrecordingsmap' VALUES (1726, 1559, NULL, 2147);
INSERT INTO 'dancesrecordingsmap' VALUES (3864, 9111, NULL, 4921);
INSERT INTO 'dancesrecordingsmap' VALUES (3865, 1641, NULL, 4922);
INSERT INTO 'dancesrecordingsmap' VALUES (3866, 5160, NULL, 4923);
INSERT INTO 'dancesrecordingsmap' VALUES (3867, 3267, NULL, 4924);
INSERT INTO 'dancesrecordingsmap' VALUES (3868, 4601, NULL, 4925);
INSERT INTO 'dancesrecordingsmap' VALUES (3869, 4471, NULL, 4926);
INSERT INTO 'dancesrecordingsmap' VALUES (3870, 5062, NULL, 4927);
INSERT INTO 'dancesrecordingsmap' VALUES (3871, 4092, NULL, 4928);
INSERT INTO 'dancesrecordingsmap' VALUES (3872, 1908, NULL, 4929);
INSERT INTO 'dancesrecordingsmap' VALUES (3873, 739, NULL, 4930);
INSERT INTO 'dancesrecordingsmap' VALUES (3874, 1304, NULL, 4931);
INSERT INTO 'dancesrecordingsmap' VALUES (8085, 4032, NULL, 8923);
INSERT INTO 'dancesrecordingsmap' VALUES (8099, 4484, NULL, 8938);
INSERT INTO 'dancesrecordingsmap' VALUES (1833, 3743, NULL, 2285);
INSERT INTO 'dancesrecordingsmap' VALUES (1836, 3700, NULL, 2289);
INSERT INTO 'dancesrecordingsmap' VALUES (1837, 6205, NULL, 2290);
INSERT INTO 'dancesrecordingsmap' VALUES (1838, 56, NULL, 2291);
INSERT INTO 'dancesrecordingsmap' VALUES (1839, 314, NULL, 2292);
INSERT INTO 'dancesrecordingsmap' VALUES (1840, 1884, NULL, 2293);
INSERT INTO 'dancesrecordingsmap' VALUES (1841, 4641, NULL, 2295);
INSERT INTO 'dancesrecordingsmap' VALUES (1842, 964, NULL, 2296);
INSERT INTO 'dancesrecordingsmap' VALUES (1843, 5236, NULL, 2297);
INSERT INTO 'dancesrecordingsmap' VALUES (1844, 7650, NULL, 2298);
INSERT INTO 'dancesrecordingsmap' VALUES (1845, 223, NULL, 2300);
INSERT INTO 'dancesrecordingsmap' VALUES (1846, 6701, NULL, 1034);
INSERT INTO 'dancesrecordingsmap' VALUES (1847, 2745, NULL, 1478);
INSERT INTO 'dancesrecordingsmap' VALUES (1848, 4014, NULL, 1479);
INSERT INTO 'dancesrecordingsmap' VALUES (1849, 335, NULL, 1483);
INSERT INTO 'dancesrecordingsmap' VALUES (1850, 1792, NULL, 1484);
INSERT INTO 'dancesrecordingsmap' VALUES (1851, 5239, NULL, 1485);
INSERT INTO 'dancesrecordingsmap' VALUES (1852, 1782, NULL, 1487);
INSERT INTO 'dancesrecordingsmap' VALUES (1853, 5128, NULL, 1585);
INSERT INTO 'dancesrecordingsmap' VALUES (1854, 5462, NULL, 2266);
INSERT INTO 'dancesrecordingsmap' VALUES (1855, 7548, NULL, 2301);
INSERT INTO 'dancesrecordingsmap' VALUES (1856, 2956, NULL, 2302);
INSERT INTO 'dancesrecordingsmap' VALUES (1859, 55, NULL, 2305);
INSERT INTO 'dancesrecordingsmap' VALUES (1860, 4014, NULL, 2306);
INSERT INTO 'dancesrecordingsmap' VALUES (1861, 4935, NULL, 2307);
INSERT INTO 'dancesrecordingsmap' VALUES (1862, 7109, NULL, 2308);
INSERT INTO 'dancesrecordingsmap' VALUES (1863, 3577, NULL, 2309);
INSERT INTO 'dancesrecordingsmap' VALUES (1864, 3932, NULL, 2310);
INSERT INTO 'dancesrecordingsmap' VALUES (1865, 1786, NULL, 2311);
INSERT INTO 'dancesrecordingsmap' VALUES (1866, 2807, NULL, 2312);
INSERT INTO 'dancesrecordingsmap' VALUES (1867, 2947, NULL, 2313);
INSERT INTO 'dancesrecordingsmap' VALUES (1868, 769, NULL, 2314);
INSERT INTO 'dancesrecordingsmap' VALUES (1869, 6938, NULL, 2315);
INSERT INTO 'dancesrecordingsmap' VALUES (1870, 5198, NULL, 2316);
INSERT INTO 'dancesrecordingsmap' VALUES (1871, 1838, NULL, 2317);
INSERT INTO 'dancesrecordingsmap' VALUES (1872, 5703, NULL, 2319);
INSERT INTO 'dancesrecordingsmap' VALUES (1873, 6792, NULL, 2320);
INSERT INTO 'dancesrecordingsmap' VALUES (1874, 4858, NULL, 2321);
INSERT INTO 'dancesrecordingsmap' VALUES (1875, 5915, NULL, 2322);
INSERT INTO 'dancesrecordingsmap' VALUES (1876, 353, NULL, 2323);
INSERT INTO 'dancesrecordingsmap' VALUES (1877, 981, NULL, 2324);
INSERT INTO 'dancesrecordingsmap' VALUES (1878, 240, NULL, 2325);
INSERT INTO 'dancesrecordingsmap' VALUES (1879, 2747, NULL, 2326);
INSERT INTO 'dancesrecordingsmap' VALUES (1881, 6382, NULL, 2328);
INSERT INTO 'dancesrecordingsmap' VALUES (1882, 6037, NULL, 2329);
INSERT INTO 'dancesrecordingsmap' VALUES (1883, 6915, NULL, 2330);
INSERT INTO 'dancesrecordingsmap' VALUES (1884, 4548, NULL, 2331);
INSERT INTO 'dancesrecordingsmap' VALUES (1885, 2250, NULL, 2333);
INSERT INTO 'dancesrecordingsmap' VALUES (1886, 3528, NULL, 2335);
INSERT INTO 'dancesrecordingsmap' VALUES (1887, 7552, NULL, 2337);
INSERT INTO 'dancesrecordingsmap' VALUES (1889, 7546, NULL, 2340);
INSERT INTO 'dancesrecordingsmap' VALUES (1890, 3615, NULL, 2341);
INSERT INTO 'dancesrecordingsmap' VALUES (1891, 3267, NULL, 2343);
INSERT INTO 'dancesrecordingsmap' VALUES (1892, 5160, NULL, 2344);
INSERT INTO 'dancesrecordingsmap' VALUES (1893, 4601, NULL, 2345);
INSERT INTO 'dancesrecordingsmap' VALUES (1894, 1641, NULL, 2346);
INSERT INTO 'dancesrecordingsmap' VALUES (1895, 739, NULL, 2347);
INSERT INTO 'dancesrecordingsmap' VALUES (1896, 1304, NULL, 2348);
INSERT INTO 'dancesrecordingsmap' VALUES (1897, 1908, NULL, 2349);
INSERT INTO 'dancesrecordingsmap' VALUES (1898, 4092, NULL, 2350);
INSERT INTO 'dancesrecordingsmap' VALUES (1899, 4471, NULL, 2351);
INSERT INTO 'dancesrecordingsmap' VALUES (1900, 5062, NULL, 2352);
INSERT INTO 'dancesrecordingsmap' VALUES (1902, 8568, NULL, 2354);
INSERT INTO 'dancesrecordingsmap' VALUES (1903, 8571, NULL, 2355);
INSERT INTO 'dancesrecordingsmap' VALUES (1904, 8574, NULL, 2356);
INSERT INTO 'dancesrecordingsmap' VALUES (1905, 8569, NULL, 2357);
INSERT INTO 'dancesrecordingsmap' VALUES (1906, 3791, NULL, 2358);
INSERT INTO 'dancesrecordingsmap' VALUES (1907, 8570, NULL, 2359);
INSERT INTO 'dancesrecordingsmap' VALUES (1908, 8578, NULL, 2360);
INSERT INTO 'dancesrecordingsmap' VALUES (1909, 3252, NULL, 2361);
INSERT INTO 'dancesrecordingsmap' VALUES (1910, 8576, NULL, 2362);
INSERT INTO 'dancesrecordingsmap' VALUES (1911, 8575, NULL, 2363);
INSERT INTO 'dancesrecordingsmap' VALUES (1912, 7793, NULL, 2364);
INSERT INTO 'dancesrecordingsmap' VALUES (1913, 8573, NULL, 2365);
INSERT INTO 'dancesrecordingsmap' VALUES (1914, 2716, NULL, 2367);
INSERT INTO 'dancesrecordingsmap' VALUES (1915, 3735, NULL, 2368);
INSERT INTO 'dancesrecordingsmap' VALUES (1916, 4928, NULL, 2369);
INSERT INTO 'dancesrecordingsmap' VALUES (1917, 5522, NULL, 2370);
INSERT INTO 'dancesrecordingsmap' VALUES (1918, 1562, NULL, 2371);
INSERT INTO 'dancesrecordingsmap' VALUES (1919, 2916, NULL, 2372);
INSERT INTO 'dancesrecordingsmap' VALUES (1920, 3528, NULL, 2373);
INSERT INTO 'dancesrecordingsmap' VALUES (1921, 1773, NULL, 2374);
INSERT INTO 'dancesrecordingsmap' VALUES (1922, 6817, NULL, 2375);
INSERT INTO 'dancesrecordingsmap' VALUES (1923, 1624, NULL, 2376);
INSERT INTO 'dancesrecordingsmap' VALUES (1924, 5208, NULL, 2377);
INSERT INTO 'dancesrecordingsmap' VALUES (1925, 633, NULL, 2378);
INSERT INTO 'dancesrecordingsmap' VALUES (3875, 7555, NULL, 4932);
INSERT INTO 'dancesrecordingsmap' VALUES (3876, 6037, NULL, 3199);
INSERT INTO 'dancesrecordingsmap' VALUES (3878, 2415, NULL, 2513);
INSERT INTO 'dancesrecordingsmap' VALUES (3879, 5198, NULL, 4300);
INSERT INTO 'dancesrecordingsmap' VALUES (3894, 9161, NULL, 909);
INSERT INTO 'dancesrecordingsmap' VALUES (3881, 3834, NULL, 3745);
INSERT INTO 'dancesrecordingsmap' VALUES (3882, 9113, NULL, 1795);
INSERT INTO 'dancesrecordingsmap' VALUES (3883, 9125, NULL, 2419);
INSERT INTO 'dancesrecordingsmap' VALUES (3886, 2922, NULL, 996);
INSERT INTO 'dancesrecordingsmap' VALUES (3887, 183, NULL, 4682);
INSERT INTO 'dancesrecordingsmap' VALUES (3889, 9138, NULL, 4671);
INSERT INTO 'dancesrecordingsmap' VALUES (3890, 9158, NULL, 2564);
INSERT INTO 'dancesrecordingsmap' VALUES (3893, 6490, NULL, 255);
INSERT INTO 'dancesrecordingsmap' VALUES (3895, 9162, NULL, 48);
INSERT INTO 'dancesrecordingsmap' VALUES (3897, 9164, NULL, 4621);
INSERT INTO 'dancesrecordingsmap' VALUES (3899, 9150, NULL, 3031);
INSERT INTO 'dancesrecordingsmap' VALUES (3900, 9151, NULL, 2417);
INSERT INTO 'dancesrecordingsmap' VALUES (3902, 9153, NULL, 136);
INSERT INTO 'dancesrecordingsmap' VALUES (3904, 9155, NULL, 3111);
INSERT INTO 'dancesrecordingsmap' VALUES (3905, 9156, NULL, 1135);
INSERT INTO 'dancesrecordingsmap' VALUES (3906, 8709, NULL, 4934);
INSERT INTO 'dancesrecordingsmap' VALUES (3907, 3198, NULL, 4935);
INSERT INTO 'dancesrecordingsmap' VALUES (3884, 9128, NULL, 1453);
INSERT INTO 'dancesrecordingsmap' VALUES (3885, 9136, NULL, 1454);
INSERT INTO 'dancesrecordingsmap' VALUES (3833, 4796, NULL, 4893);
INSERT INTO 'dancesrecordingsmap' VALUES (3892, 6490, NULL, 40);
INSERT INTO 'dancesrecordingsmap' VALUES (3861, 9108, NULL, 4918);
INSERT INTO 'dancesrecordingsmap' VALUES (3888, 8165, NULL, 4670);
INSERT INTO 'dancesrecordingsmap' VALUES (3908, 6995, NULL, 4937);
INSERT INTO 'dancesrecordingsmap' VALUES (3909, 5497, NULL, 4938);
INSERT INTO 'dancesrecordingsmap' VALUES (3910, 916, NULL, 4940);
INSERT INTO 'dancesrecordingsmap' VALUES (3911, 3244, NULL, 4942);
INSERT INTO 'dancesrecordingsmap' VALUES (3912, 9168, NULL, 4941);
INSERT INTO 'dancesrecordingsmap' VALUES (3913, 6680, NULL, 4943);
INSERT INTO 'dancesrecordingsmap' VALUES (3915, 2388, NULL, 1080);
INSERT INTO 'dancesrecordingsmap' VALUES (3916, 7546, NULL, 4946);
INSERT INTO 'dancesrecordingsmap' VALUES (8086, 9286, NULL, 8925);
INSERT INTO 'dancesrecordingsmap' VALUES (8100, 7283, NULL, 8939);
INSERT INTO 'dancesrecordingsmap' VALUES (1927, 1582, NULL, 2380);
INSERT INTO 'dancesrecordingsmap' VALUES (1928, 153, NULL, 2381);
INSERT INTO 'dancesrecordingsmap' VALUES (1929, 1501, NULL, 2382);
INSERT INTO 'dancesrecordingsmap' VALUES (1930, 3888, NULL, 2383);
INSERT INTO 'dancesrecordingsmap' VALUES (1931, 6915, NULL, 2384);
INSERT INTO 'dancesrecordingsmap' VALUES (1932, 5525, NULL, 2385);
INSERT INTO 'dancesrecordingsmap' VALUES (1933, 3834, NULL, 2386);
INSERT INTO 'dancesrecordingsmap' VALUES (1935, 1562, NULL, 2389);
INSERT INTO 'dancesrecordingsmap' VALUES (1936, 1792, NULL, 2390);
INSERT INTO 'dancesrecordingsmap' VALUES (1937, 7546, NULL, 2392);
INSERT INTO 'dancesrecordingsmap' VALUES (1938, 5239, NULL, 2393);
INSERT INTO 'dancesrecordingsmap' VALUES (1926, 335, NULL, 2379);
INSERT INTO 'dancesrecordingsmap' VALUES (3903, 9154, NULL, 2515);
INSERT INTO 'dancesrecordingsmap' VALUES (3852, 2349, NULL, 4909);
INSERT INTO 'dancesrecordingsmap' VALUES (3914, 5107, NULL, 337);
INSERT INTO 'dancesrecordingsmap' VALUES (3855, 9102, NULL, 4912);
INSERT INTO 'dancesrecordingsmap' VALUES (1888, 6094, NULL, 2338);
INSERT INTO 'dancesrecordingsmap' VALUES (1835, 2604, NULL, 2288);
INSERT INTO 'dancesrecordingsmap' VALUES (1939, 7548, NULL, 2394);
INSERT INTO 'dancesrecordingsmap' VALUES (1940, 1210, NULL, 2395);
INSERT INTO 'dancesrecordingsmap' VALUES (1941, 7045, NULL, 2396);
INSERT INTO 'dancesrecordingsmap' VALUES (1942, 4318, NULL, 2397);
INSERT INTO 'dancesrecordingsmap' VALUES (1943, 5744, NULL, 2398);
INSERT INTO 'dancesrecordingsmap' VALUES (1944, 1881, NULL, 2399);
INSERT INTO 'dancesrecordingsmap' VALUES (1946, 722, NULL, 2401);
INSERT INTO 'dancesrecordingsmap' VALUES (1947, 801, NULL, 2402);
INSERT INTO 'dancesrecordingsmap' VALUES (1948, 3959, NULL, 2403);
INSERT INTO 'dancesrecordingsmap' VALUES (1949, 4503, NULL, 2404);
INSERT INTO 'dancesrecordingsmap' VALUES (1951, 916, NULL, 2406);
INSERT INTO 'dancesrecordingsmap' VALUES (1953, 540, NULL, 2409);
INSERT INTO 'dancesrecordingsmap' VALUES (1956, 3323, NULL, 2412);
INSERT INTO 'dancesrecordingsmap' VALUES (1957, 1348, NULL, 2414);
INSERT INTO 'dancesrecordingsmap' VALUES (1958, 743, NULL, 2415);
INSERT INTO 'dancesrecordingsmap' VALUES (1960, 3862, NULL, 2419);
INSERT INTO 'dancesrecordingsmap' VALUES (1961, 7548, NULL, 2421);
INSERT INTO 'dancesrecordingsmap' VALUES (1962, 2956, NULL, 2422);
INSERT INTO 'dancesrecordingsmap' VALUES (1963, 7147, NULL, 2425);
INSERT INTO 'dancesrecordingsmap' VALUES (1964, 1864, NULL, 2427);
INSERT INTO 'dancesrecordingsmap' VALUES (1965, 2916, NULL, 2428);
INSERT INTO 'dancesrecordingsmap' VALUES (1858, 3225, NULL, 2304);
INSERT INTO 'dancesrecordingsmap' VALUES (3877, 5955, NULL, 1859);
INSERT INTO 'dancesrecordingsmap' VALUES (3898, 9149, NULL, 1866);
INSERT INTO 'dancesrecordingsmap' VALUES (3901, 9152, NULL, 2519);
INSERT INTO 'dancesrecordingsmap' VALUES (1934, 2745, NULL, 2388);
INSERT INTO 'dancesrecordingsmap' VALUES (1857, 2349, NULL, 2303);
INSERT INTO 'dancesrecordingsmap' VALUES (1901, 8577, NULL, 2353);
INSERT INTO 'dancesrecordingsmap' VALUES (1966, 3528, NULL, 2429);
INSERT INTO 'dancesrecordingsmap' VALUES (1967, 936, NULL, 2431);
INSERT INTO 'dancesrecordingsmap' VALUES (1968, 1148, NULL, 2433);
INSERT INTO 'dancesrecordingsmap' VALUES (1969, 4634, NULL, 2434);
INSERT INTO 'dancesrecordingsmap' VALUES (1970, 569, NULL, 2435);
INSERT INTO 'dancesrecordingsmap' VALUES (1971, 5619, NULL, 2436);
INSERT INTO 'dancesrecordingsmap' VALUES (1972, 6371, NULL, 2437);
INSERT INTO 'dancesrecordingsmap' VALUES (1973, 3010, NULL, 2438);
INSERT INTO 'dancesrecordingsmap' VALUES (1974, 2411, NULL, 2440);
INSERT INTO 'dancesrecordingsmap' VALUES (1975, 1643, NULL, 2441);
INSERT INTO 'dancesrecordingsmap' VALUES (1976, 5309, NULL, 2442);
INSERT INTO 'dancesrecordingsmap' VALUES (1977, 5451, NULL, 2443);
INSERT INTO 'dancesrecordingsmap' VALUES (1979, 1549, NULL, 2445);
INSERT INTO 'dancesrecordingsmap' VALUES (1980, 4411, NULL, 2446);
INSERT INTO 'dancesrecordingsmap' VALUES (1981, 1207, NULL, 2447);
INSERT INTO 'dancesrecordingsmap' VALUES (1982, 1029, NULL, 2448);
INSERT INTO 'dancesrecordingsmap' VALUES (1983, 292, NULL, 2449);
INSERT INTO 'dancesrecordingsmap' VALUES (1984, 3504, NULL, 2450);
INSERT INTO 'dancesrecordingsmap' VALUES (1985, 6210, NULL, 2451);
INSERT INTO 'dancesrecordingsmap' VALUES (1986, 6913, NULL, 2452);
INSERT INTO 'dancesrecordingsmap' VALUES (1987, 1535, NULL, 2453);
INSERT INTO 'dancesrecordingsmap' VALUES (1990, 3705, NULL, 2456);
INSERT INTO 'dancesrecordingsmap' VALUES (1992, 4215, NULL, 2458);
INSERT INTO 'dancesrecordingsmap' VALUES (1993, 6205, NULL, 2459);
INSERT INTO 'dancesrecordingsmap' VALUES (1994, 1372, NULL, 2460);
INSERT INTO 'dancesrecordingsmap' VALUES (1995, 522, NULL, 2462);
INSERT INTO 'dancesrecordingsmap' VALUES (1997, 605, NULL, 2464);
INSERT INTO 'dancesrecordingsmap' VALUES (1999, 4014, NULL, 2466);
INSERT INTO 'dancesrecordingsmap' VALUES (2000, 3057, NULL, 2467);
INSERT INTO 'dancesrecordingsmap' VALUES (2001, 1792, NULL, 2468);
INSERT INTO 'dancesrecordingsmap' VALUES (2002, 5794, NULL, 2470);
INSERT INTO 'dancesrecordingsmap' VALUES (2003, 3129, NULL, 2472);
INSERT INTO 'dancesrecordingsmap' VALUES (2004, 4765, NULL, 2473);
INSERT INTO 'dancesrecordingsmap' VALUES (2005, 1777, NULL, 2475);
INSERT INTO 'dancesrecordingsmap' VALUES (2006, 2777, NULL, 2477);
INSERT INTO 'dancesrecordingsmap' VALUES (2007, 3435, NULL, 2478);
INSERT INTO 'dancesrecordingsmap' VALUES (2008, 4548, NULL, 2479);
INSERT INTO 'dancesrecordingsmap' VALUES (2009, 2494, NULL, 2480);
INSERT INTO 'dancesrecordingsmap' VALUES (2010, 2415, NULL, 2481);
INSERT INTO 'dancesrecordingsmap' VALUES (2011, 2428, NULL, 2482);
INSERT INTO 'dancesrecordingsmap' VALUES (2012, 3506, NULL, 2483);
INSERT INTO 'dancesrecordingsmap' VALUES (2013, 2498, NULL, 2484);
INSERT INTO 'dancesrecordingsmap' VALUES (2014, 4555, NULL, 2485);
INSERT INTO 'dancesrecordingsmap' VALUES (2015, 5207, NULL, 2486);
INSERT INTO 'dancesrecordingsmap' VALUES (2016, 6885, NULL, 2488);
INSERT INTO 'dancesrecordingsmap' VALUES (2062, 2887, NULL, 2560);
INSERT INTO 'dancesrecordingsmap' VALUES (2028, 6420, NULL, 2514);
INSERT INTO 'dancesrecordingsmap' VALUES (2029, 753, NULL, 2517);
INSERT INTO 'dancesrecordingsmap' VALUES (2030, 816, NULL, 2522);
INSERT INTO 'dancesrecordingsmap' VALUES (2031, 3802, NULL, 2524);
INSERT INTO 'dancesrecordingsmap' VALUES (2067, 4816, NULL, 2566);
INSERT INTO 'dancesrecordingsmap' VALUES (2033, 2189, NULL, 2526);
INSERT INTO 'dancesrecordingsmap' VALUES (2034, 2934, NULL, 2527);
INSERT INTO 'dancesrecordingsmap' VALUES (2035, 3105, NULL, 2529);
INSERT INTO 'dancesrecordingsmap' VALUES (2036, 6539, NULL, 2530);
INSERT INTO 'dancesrecordingsmap' VALUES (2037, 985, NULL, 2532);
INSERT INTO 'dancesrecordingsmap' VALUES (2038, 83, NULL, 2533);
INSERT INTO 'dancesrecordingsmap' VALUES (2039, 5260, NULL, 2534);
INSERT INTO 'dancesrecordingsmap' VALUES (2040, 4641, NULL, 2536);
INSERT INTO 'dancesrecordingsmap' VALUES (2041, 5262, NULL, 2537);
INSERT INTO 'dancesrecordingsmap' VALUES (2042, 3637, NULL, 2538);
INSERT INTO 'dancesrecordingsmap' VALUES (2043, 1862, NULL, 2539);
INSERT INTO 'dancesrecordingsmap' VALUES (2044, 5713, NULL, 2540);
INSERT INTO 'dancesrecordingsmap' VALUES (2045, 4209, NULL, 2541);
INSERT INTO 'dancesrecordingsmap' VALUES (2046, 1857, NULL, 2542);
INSERT INTO 'dancesrecordingsmap' VALUES (2047, 4827, NULL, 2544);
INSERT INTO 'dancesrecordingsmap' VALUES (2048, 3580, NULL, 2545);
INSERT INTO 'dancesrecordingsmap' VALUES (2049, 4442, NULL, 2546);
INSERT INTO 'dancesrecordingsmap' VALUES (2050, 3748, NULL, 2548);
INSERT INTO 'dancesrecordingsmap' VALUES (2051, 4239, NULL, 2549);
INSERT INTO 'dancesrecordingsmap' VALUES (3917, 7552, NULL, 4947);
INSERT INTO 'dancesrecordingsmap' VALUES (3918, 9294, NULL, 4948);
INSERT INTO 'dancesrecordingsmap' VALUES (3919, 9286, NULL, 4950);
INSERT INTO 'dancesrecordingsmap' VALUES (3920, 9297, NULL, 4951);
INSERT INTO 'dancesrecordingsmap' VALUES (3921, 8146, NULL, 4953);
INSERT INTO 'dancesrecordingsmap' VALUES (3922, 9287, NULL, 4955);
INSERT INTO 'dancesrecordingsmap' VALUES (3923, 9288, NULL, 4956);
INSERT INTO 'dancesrecordingsmap' VALUES (3924, 7553, NULL, 4957);
INSERT INTO 'dancesrecordingsmap' VALUES (3925, 9291, NULL, 4959);
INSERT INTO 'dancesrecordingsmap' VALUES (3926, 8088, NULL, 4960);
INSERT INTO 'dancesrecordingsmap' VALUES (3928, 3616, NULL, 4962);
INSERT INTO 'dancesrecordingsmap' VALUES (3929, 6048, NULL, 4964);
INSERT INTO 'dancesrecordingsmap' VALUES (3930, 7055, NULL, 4966);
INSERT INTO 'dancesrecordingsmap' VALUES (3931, 4805, NULL, 4968);
INSERT INTO 'dancesrecordingsmap' VALUES (3932, 6748, NULL, 4969);
INSERT INTO 'dancesrecordingsmap' VALUES (3933, 2394, NULL, 4970);
INSERT INTO 'dancesrecordingsmap' VALUES (3934, 4995, NULL, 4973);
INSERT INTO 'dancesrecordingsmap' VALUES (8087, 3637, NULL, 8926);
INSERT INTO 'dancesrecordingsmap' VALUES (2052, 4728, NULL, 2550);
INSERT INTO 'dancesrecordingsmap' VALUES (2053, 5497, NULL, 2551);
INSERT INTO 'dancesrecordingsmap' VALUES (2054, 1758, NULL, 2552);
INSERT INTO 'dancesrecordingsmap' VALUES (2055, 3281, NULL, 2553);
INSERT INTO 'dancesrecordingsmap' VALUES (2056, 5637, NULL, 2554);
INSERT INTO 'dancesrecordingsmap' VALUES (2057, 1218, NULL, 2555);
INSERT INTO 'dancesrecordingsmap' VALUES (2058, 4585, NULL, 2556);
INSERT INTO 'dancesrecordingsmap' VALUES (2059, 6609, NULL, 2557);
INSERT INTO 'dancesrecordingsmap' VALUES (2061, 1891, NULL, 2559);
INSERT INTO 'dancesrecordingsmap' VALUES (2065, 715, NULL, 2564);
INSERT INTO 'dancesrecordingsmap' VALUES (2066, 6328, NULL, 2565);
INSERT INTO 'dancesrecordingsmap' VALUES (2068, 717, NULL, 2567);
INSERT INTO 'dancesrecordingsmap' VALUES (2069, 5262, NULL, 2569);
INSERT INTO 'dancesrecordingsmap' VALUES (2070, 5330, NULL, 2571);
INSERT INTO 'dancesrecordingsmap' VALUES (2071, 2979, NULL, 2573);
INSERT INTO 'dancesrecordingsmap' VALUES (2072, 584, NULL, 2574);
INSERT INTO 'dancesrecordingsmap' VALUES (2074, 5308, NULL, 2577);
INSERT INTO 'dancesrecordingsmap' VALUES (2075, 3172, NULL, 2579);
INSERT INTO 'dancesrecordingsmap' VALUES (2076, 4784, NULL, 2580);
INSERT INTO 'dancesrecordingsmap' VALUES (2077, 4291, NULL, 2581);
INSERT INTO 'dancesrecordingsmap' VALUES (2078, 4015, NULL, 2582);
INSERT INTO 'dancesrecordingsmap' VALUES (2079, 5927, NULL, 2583);
INSERT INTO 'dancesrecordingsmap' VALUES (2018, 6897, NULL, 2490);
INSERT INTO 'dancesrecordingsmap' VALUES (2022, 584, NULL, 2494);
INSERT INTO 'dancesrecordingsmap' VALUES (2027, 5637, NULL, 2499);
INSERT INTO 'dancesrecordingsmap' VALUES (2025, 5898, NULL, 2497);
INSERT INTO 'dancesrecordingsmap' VALUES (2020, 633, NULL, 2492);
INSERT INTO 'dancesrecordingsmap' VALUES (2021, 6532, NULL, 2493);
INSERT INTO 'dancesrecordingsmap' VALUES (2026, 1965, NULL, 2498);
INSERT INTO 'dancesrecordingsmap' VALUES (2019, 2531, NULL, 2491);
INSERT INTO 'dancesrecordingsmap' VALUES (2024, 4641, NULL, 2496);
INSERT INTO 'dancesrecordingsmap' VALUES (1950, 5558, NULL, 2405);
INSERT INTO 'dancesrecordingsmap' VALUES (3935, 3774, NULL, 4974);
INSERT INTO 'dancesrecordingsmap' VALUES (1955, 1485, NULL, 2411);
INSERT INTO 'dancesrecordingsmap' VALUES (1952, 1025, NULL, 2407);
INSERT INTO 'dancesrecordingsmap' VALUES (1954, 4920, NULL, 2410);
INSERT INTO 'dancesrecordingsmap' VALUES (1978, 413, NULL, 2444);
INSERT INTO 'dancesrecordingsmap' VALUES (2060, 5623, NULL, 2558);
INSERT INTO 'dancesrecordingsmap' VALUES (2080, 5637, NULL, 2584);
INSERT INTO 'dancesrecordingsmap' VALUES (2081, 7546, NULL, 2587);
INSERT INTO 'dancesrecordingsmap' VALUES (2082, 1280, NULL, 2588);
INSERT INTO 'dancesrecordingsmap' VALUES (2083, 6420, NULL, 2589);
INSERT INTO 'dancesrecordingsmap' VALUES (2084, 980, NULL, 2590);
INSERT INTO 'dancesrecordingsmap' VALUES (2085, 7147, NULL, 2591);
INSERT INTO 'dancesrecordingsmap' VALUES (2087, 4102, NULL, 2595);
INSERT INTO 'dancesrecordingsmap' VALUES (2088, 743, NULL, 2596);
INSERT INTO 'dancesrecordingsmap' VALUES (2089, 445, NULL, 2598);
INSERT INTO 'dancesrecordingsmap' VALUES (2090, 5376, NULL, 2601);
INSERT INTO 'dancesrecordingsmap' VALUES (2091, 5308, NULL, 2602);
INSERT INTO 'dancesrecordingsmap' VALUES (2092, 769, NULL, 2603);
INSERT INTO 'dancesrecordingsmap' VALUES (2093, 4890, NULL, 2604);
INSERT INTO 'dancesrecordingsmap' VALUES (2094, 462, NULL, 2605);
INSERT INTO 'dancesrecordingsmap' VALUES (2095, 5927, NULL, 2606);
INSERT INTO 'dancesrecordingsmap' VALUES (2096, 56, NULL, 2608);
INSERT INTO 'dancesrecordingsmap' VALUES (2097, 5621, NULL, 2609);
INSERT INTO 'dancesrecordingsmap' VALUES (2098, 6995, NULL, 2610);
INSERT INTO 'dancesrecordingsmap' VALUES (2099, 5308, NULL, 2611);
INSERT INTO 'dancesrecordingsmap' VALUES (2100, 3172, NULL, 2612);
INSERT INTO 'dancesrecordingsmap' VALUES (2101, 950, NULL, 2613);
INSERT INTO 'dancesrecordingsmap' VALUES (2102, 164, NULL, 2614);
INSERT INTO 'dancesrecordingsmap' VALUES (2103, 3436, NULL, 2615);
INSERT INTO 'dancesrecordingsmap' VALUES (2104, 2494, NULL, 2618);
INSERT INTO 'dancesrecordingsmap' VALUES (2105, 2415, NULL, 2619);
INSERT INTO 'dancesrecordingsmap' VALUES (2106, 2428, NULL, 2621);
INSERT INTO 'dancesrecordingsmap' VALUES (2107, 6848, NULL, 2626);
INSERT INTO 'dancesrecordingsmap' VALUES (2064, 3137, NULL, 2562);
INSERT INTO 'dancesrecordingsmap' VALUES (1991, 1521, NULL, 2457);
INSERT INTO 'dancesrecordingsmap' VALUES (1945, 5389, NULL, 2400);
INSERT INTO 'dancesrecordingsmap' VALUES (1989, 2263, NULL, 2455);
INSERT INTO 'dancesrecordingsmap' VALUES (1988, 904, NULL, 2454);
INSERT INTO 'dancesrecordingsmap' VALUES (1996, 4931, NULL, 2463);
INSERT INTO 'dancesrecordingsmap' VALUES (2108, 6885, NULL, 2627);
INSERT INTO 'dancesrecordingsmap' VALUES (2109, 633, NULL, 1158);
INSERT INTO 'dancesrecordingsmap' VALUES (2110, 7111, NULL, 1160);
INSERT INTO 'dancesrecordingsmap' VALUES (2111, 658, NULL, 1162);
INSERT INTO 'dancesrecordingsmap' VALUES (2112, 4102, NULL, 1163);
INSERT INTO 'dancesrecordingsmap' VALUES (2113, 4968, NULL, 1164);
INSERT INTO 'dancesrecordingsmap' VALUES (2114, 4998, NULL, 1165);
INSERT INTO 'dancesrecordingsmap' VALUES (2115, 6048, NULL, 1167);
INSERT INTO 'dancesrecordingsmap' VALUES (2116, 7180, NULL, 2332);
INSERT INTO 'dancesrecordingsmap' VALUES (2117, 6010, NULL, 2339);
INSERT INTO 'dancesrecordingsmap' VALUES (2118, 2344, NULL, 2628);
INSERT INTO 'dancesrecordingsmap' VALUES (2119, 629, NULL, 2629);
INSERT INTO 'dancesrecordingsmap' VALUES (2120, 7104, NULL, 2630);
INSERT INTO 'dancesrecordingsmap' VALUES (2121, 6995, NULL, 2631);
INSERT INTO 'dancesrecordingsmap' VALUES (2122, 6052, NULL, 2632);
INSERT INTO 'dancesrecordingsmap' VALUES (2123, 5198, NULL, 2633);
INSERT INTO 'dancesrecordingsmap' VALUES (2124, 4046, NULL, 2634);
INSERT INTO 'dancesrecordingsmap' VALUES (2126, 4784, NULL, 2636);
INSERT INTO 'dancesrecordingsmap' VALUES (2127, 4015, NULL, 2637);
INSERT INTO 'dancesrecordingsmap' VALUES (2128, 576, NULL, 2639);
INSERT INTO 'dancesrecordingsmap' VALUES (2129, 2353, NULL, 2640);
INSERT INTO 'dancesrecordingsmap' VALUES (2130, 3314, NULL, 2641);
INSERT INTO 'dancesrecordingsmap' VALUES (3927, 4716, NULL, 4961);
INSERT INTO 'dancesrecordingsmap' VALUES (1998, 559, NULL, 2465);
INSERT INTO 'dancesrecordingsmap' VALUES (2017, 4120, NULL, 2489);
INSERT INTO 'dancesrecordingsmap' VALUES (2131, 2707, NULL, 2642);
INSERT INTO 'dancesrecordingsmap' VALUES (2133, 4225, NULL, 2644);
INSERT INTO 'dancesrecordingsmap' VALUES (2135, 986, NULL, 2646);
INSERT INTO 'dancesrecordingsmap' VALUES (2136, 5576, NULL, 2647);
INSERT INTO 'dancesrecordingsmap' VALUES (2137, 2492, NULL, 2648);
INSERT INTO 'dancesrecordingsmap' VALUES (2138, 2431, NULL, 2649);
INSERT INTO 'dancesrecordingsmap' VALUES (2139, 3828, NULL, 2650);
INSERT INTO 'dancesrecordingsmap' VALUES (2140, 7458, NULL, 2652);
INSERT INTO 'dancesrecordingsmap' VALUES (2141, 7344, NULL, 2653);
INSERT INTO 'dancesrecordingsmap' VALUES (2142, 7423, NULL, 2655);
INSERT INTO 'dancesrecordingsmap' VALUES (2143, 7485, NULL, 2656);
INSERT INTO 'dancesrecordingsmap' VALUES (2144, 7409, NULL, 2657);
INSERT INTO 'dancesrecordingsmap' VALUES (3936, 3176, NULL, 4976);
INSERT INTO 'dancesrecordingsmap' VALUES (3937, 153, NULL, 4977);
INSERT INTO 'dancesrecordingsmap' VALUES (3938, 6739, NULL, 4978);
INSERT INTO 'dancesrecordingsmap' VALUES (3939, 5007, NULL, 4979);
INSERT INTO 'dancesrecordingsmap' VALUES (3940, 6915, NULL, 4980);
INSERT INTO 'dancesrecordingsmap' VALUES (3941, 686, NULL, 4981);
INSERT INTO 'dancesrecordingsmap' VALUES (3942, 3172, NULL, 4981);
INSERT INTO 'dancesrecordingsmap' VALUES (3943, 7055, NULL, 4983);
INSERT INTO 'dancesrecordingsmap' VALUES (3944, 8749, NULL, 4984);
INSERT INTO 'dancesrecordingsmap' VALUES (3945, 2367, NULL, 4986);
INSERT INTO 'dancesrecordingsmap' VALUES (3954, 9104, NULL, 4997);
INSERT INTO 'dancesrecordingsmap' VALUES (3955, 7285, NULL, 4998);
INSERT INTO 'dancesrecordingsmap' VALUES (3956, 7560, NULL, 4999);
INSERT INTO 'dancesrecordingsmap' VALUES (3957, 2222, NULL, 5000);
INSERT INTO 'dancesrecordingsmap' VALUES (3958, 54, NULL, 5002);
INSERT INTO 'dancesrecordingsmap' VALUES (3959, 594, NULL, 5003);
INSERT INTO 'dancesrecordingsmap' VALUES (3960, 4365, NULL, 5004);
INSERT INTO 'dancesrecordingsmap' VALUES (3962, 6153, NULL, 5006);
INSERT INTO 'dancesrecordingsmap' VALUES (3963, 7019, NULL, 5007);
INSERT INTO 'dancesrecordingsmap' VALUES (3964, 905, NULL, 5008);
INSERT INTO 'dancesrecordingsmap' VALUES (3965, 445, NULL, 5009);
INSERT INTO 'dancesrecordingsmap' VALUES (3966, 658, NULL, 5010);
INSERT INTO 'dancesrecordingsmap' VALUES (3967, 7111, NULL, 5011);
INSERT INTO 'dancesrecordingsmap' VALUES (3968, 9365, NULL, 3334);
INSERT INTO 'dancesrecordingsmap' VALUES (3969, 5093, NULL, 5012);
INSERT INTO 'dancesrecordingsmap' VALUES (3970, 2604, NULL, 5013);
INSERT INTO 'dancesrecordingsmap' VALUES (3971, 604, NULL, 5014);
INSERT INTO 'dancesrecordingsmap' VALUES (3972, 8178, NULL, 5015);
INSERT INTO 'dancesrecordingsmap' VALUES (3973, 2616, NULL, 5016);
INSERT INTO 'dancesrecordingsmap' VALUES (3974, 1621, NULL, 5017);
INSERT INTO 'dancesrecordingsmap' VALUES (3975, 1578, NULL, 5018);
INSERT INTO 'dancesrecordingsmap' VALUES (3976, 4679, NULL, 5019);
INSERT INTO 'dancesrecordingsmap' VALUES (3977, 2571, NULL, 5020);
INSERT INTO 'dancesrecordingsmap' VALUES (8088, 743, NULL, 8927);
INSERT INTO 'dancesrecordingsmap' VALUES (2170, 2820, NULL, 2697);
INSERT INTO 'dancesrecordingsmap' VALUES (2145, 7524, NULL, 2658);
INSERT INTO 'dancesrecordingsmap' VALUES (2147, 7373, NULL, 2660);
INSERT INTO 'dancesrecordingsmap' VALUES (2148, 7349, NULL, 2661);
INSERT INTO 'dancesrecordingsmap' VALUES (2149, 7488, NULL, 2662);
INSERT INTO 'dancesrecordingsmap' VALUES (2150, 7490, NULL, 2663);
INSERT INTO 'dancesrecordingsmap' VALUES (2151, 5525, NULL, 2664);
INSERT INTO 'dancesrecordingsmap' VALUES (2152, 8146, NULL, 2665);
INSERT INTO 'dancesrecordingsmap' VALUES (2159, 3232, NULL, 382);
INSERT INTO 'dancesrecordingsmap' VALUES (2160, 2747, NULL, 2681);
INSERT INTO 'dancesrecordingsmap' VALUES (2161, 2820, NULL, 2682);
INSERT INTO 'dancesrecordingsmap' VALUES (2162, 4102, NULL, 2683);
INSERT INTO 'dancesrecordingsmap' VALUES (2163, 1792, NULL, 2684);
INSERT INTO 'dancesrecordingsmap' VALUES (2164, 4032, NULL, 2688);
INSERT INTO 'dancesrecordingsmap' VALUES (2165, 5239, NULL, 2691);
INSERT INTO 'dancesrecordingsmap' VALUES (2166, 5525, NULL, 2692);
INSERT INTO 'dancesrecordingsmap' VALUES (2167, 1210, NULL, 2693);
INSERT INTO 'dancesrecordingsmap' VALUES (2168, 1792, NULL, 2695);
INSERT INTO 'dancesrecordingsmap' VALUES (2169, 2260, NULL, 2696);
INSERT INTO 'dancesrecordingsmap' VALUES (2171, 1562, NULL, 2700);
INSERT INTO 'dancesrecordingsmap' VALUES (2172, 1931, NULL, 2701);
INSERT INTO 'dancesrecordingsmap' VALUES (2173, 2260, NULL, 2702);
INSERT INTO 'dancesrecordingsmap' VALUES (2174, 1562, NULL, 2707);
INSERT INTO 'dancesrecordingsmap' VALUES (2175, 1931, NULL, 2708);
INSERT INTO 'dancesrecordingsmap' VALUES (2176, 6915, NULL, 2711);
INSERT INTO 'dancesrecordingsmap' VALUES (2177, 1562, NULL, 2712);
INSERT INTO 'dancesrecordingsmap' VALUES (2179, 1782, NULL, 2714);
INSERT INTO 'dancesrecordingsmap' VALUES (2180, 1782, NULL, 2715);
INSERT INTO 'dancesrecordingsmap' VALUES (2181, 1792, NULL, 2716);
INSERT INTO 'dancesrecordingsmap' VALUES (2182, 1792, NULL, 2717);
INSERT INTO 'dancesrecordingsmap' VALUES (2183, 1931, NULL, 2718);
INSERT INTO 'dancesrecordingsmap' VALUES (2184, 2745, NULL, 2720);
INSERT INTO 'dancesrecordingsmap' VALUES (2185, 2745, NULL, 2721);
INSERT INTO 'dancesrecordingsmap' VALUES (2186, 5525, NULL, 2722);
INSERT INTO 'dancesrecordingsmap' VALUES (2187, 5525, NULL, 2723);
INSERT INTO 'dancesrecordingsmap' VALUES (2188, 5964, NULL, 2724);
INSERT INTO 'dancesrecordingsmap' VALUES (2189, 2170, NULL, 135);
INSERT INTO 'dancesrecordingsmap' VALUES (2190, 5525, NULL, 2502);
INSERT INTO 'dancesrecordingsmap' VALUES (2191, 7548, NULL, 2504);
INSERT INTO 'dancesrecordingsmap' VALUES (2192, 4102, NULL, 2506);
INSERT INTO 'dancesrecordingsmap' VALUES (2193, 7552, NULL, 2508);
INSERT INTO 'dancesrecordingsmap' VALUES (2194, 6915, NULL, 2509);
INSERT INTO 'dancesrecordingsmap' VALUES (2195, 3672, NULL, 2510);
INSERT INTO 'dancesrecordingsmap' VALUES (2196, 7546, NULL, 2511);
INSERT INTO 'dancesrecordingsmap' VALUES (2197, 2745, NULL, 2731);
INSERT INTO 'dancesrecordingsmap' VALUES (2198, 972, NULL, 2732);
INSERT INTO 'dancesrecordingsmap' VALUES (2199, 4102, NULL, 2733);
INSERT INTO 'dancesrecordingsmap' VALUES (2200, 6915, NULL, 2734);
INSERT INTO 'dancesrecordingsmap' VALUES (2201, 1792, NULL, 2735);
INSERT INTO 'dancesrecordingsmap' VALUES (2202, 2916, NULL, 2737);
INSERT INTO 'dancesrecordingsmap' VALUES (2203, 2745, NULL, 2738);
INSERT INTO 'dancesrecordingsmap' VALUES (2204, 3561, NULL, 2739);
INSERT INTO 'dancesrecordingsmap' VALUES (2205, 1927, NULL, 2740);
INSERT INTO 'dancesrecordingsmap' VALUES (2206, 6915, NULL, 2741);
INSERT INTO 'dancesrecordingsmap' VALUES (2207, 1210, NULL, 2742);
INSERT INTO 'dancesrecordingsmap' VALUES (2208, 7109, NULL, 2743);
INSERT INTO 'dancesrecordingsmap' VALUES (2209, 2317, NULL, 2744);
INSERT INTO 'dancesrecordingsmap' VALUES (2210, 5658, NULL, 2746);
INSERT INTO 'dancesrecordingsmap' VALUES (2211, 4728, NULL, 2747);
INSERT INTO 'dancesrecordingsmap' VALUES (2212, 2024, NULL, 2748);
INSERT INTO 'dancesrecordingsmap' VALUES (2213, 3888, NULL, 2749);
INSERT INTO 'dancesrecordingsmap' VALUES (2214, 4064, NULL, 2750);
INSERT INTO 'dancesrecordingsmap' VALUES (2215, 6712, NULL, 2751);
INSERT INTO 'dancesrecordingsmap' VALUES (2216, 1576, NULL, 2752);
INSERT INTO 'dancesrecordingsmap' VALUES (2217, 743, NULL, 2753);
INSERT INTO 'dancesrecordingsmap' VALUES (2218, 769, NULL, 2756);
INSERT INTO 'dancesrecordingsmap' VALUES (2219, 2713, NULL, 1132);
INSERT INTO 'dancesrecordingsmap' VALUES (2220, 2777, NULL, 2779);
INSERT INTO 'dancesrecordingsmap' VALUES (2146, 7528, NULL, 2659);
INSERT INTO 'dancesrecordingsmap' VALUES (2125, 3463, NULL, 2635);
INSERT INTO 'dancesrecordingsmap' VALUES (2086, 541, NULL, 2594);
INSERT INTO 'dancesrecordingsmap' VALUES (2221, 6712, NULL, 2780);
INSERT INTO 'dancesrecordingsmap' VALUES (2222, 2409, NULL, 2781);
INSERT INTO 'dancesrecordingsmap' VALUES (2223, 5330, NULL, 2782);
INSERT INTO 'dancesrecordingsmap' VALUES (2224, 1966, NULL, 2783);
INSERT INTO 'dancesrecordingsmap' VALUES (2225, 5802, NULL, 2784);
INSERT INTO 'dancesrecordingsmap' VALUES (2226, 4102, NULL, 2785);
INSERT INTO 'dancesrecordingsmap' VALUES (2227, 3980, NULL, 2786);
INSERT INTO 'dancesrecordingsmap' VALUES (2228, 7189, NULL, 2787);
INSERT INTO 'dancesrecordingsmap' VALUES (2229, 5713, NULL, 2788);
INSERT INTO 'dancesrecordingsmap' VALUES (2230, 633, NULL, 2789);
INSERT INTO 'dancesrecordingsmap' VALUES (2231, 3129, NULL, 2790);
INSERT INTO 'dancesrecordingsmap' VALUES (2232, 353, NULL, 2791);
INSERT INTO 'dancesrecordingsmap' VALUES (2233, 3339, NULL, 2792);
INSERT INTO 'dancesrecordingsmap' VALUES (2234, 6420, NULL, 2793);
INSERT INTO 'dancesrecordingsmap' VALUES (2235, 7553, NULL, 2795);
INSERT INTO 'dancesrecordingsmap' VALUES (2236, 7552, NULL, 2796);
INSERT INTO 'dancesrecordingsmap' VALUES (3979, 1934, NULL, 5022);
INSERT INTO 'dancesrecordingsmap' VALUES (3980, 3461, NULL, 5023);
INSERT INTO 'dancesrecordingsmap' VALUES (3981, 6897, NULL, 5024);
INSERT INTO 'dancesrecordingsmap' VALUES (3982, 3108, NULL, 5025);
INSERT INTO 'dancesrecordingsmap' VALUES (3983, 9380, NULL, 5026);
INSERT INTO 'dancesrecordingsmap' VALUES (3984, 9381, NULL, 5027);
INSERT INTO 'dancesrecordingsmap' VALUES (3986, 2387, NULL, 5029);
INSERT INTO 'dancesrecordingsmap' VALUES (2307, 6382, NULL, 2893);
INSERT INTO 'dancesrecordingsmap' VALUES (3989, 9384, NULL, 5032);
INSERT INTO 'dancesrecordingsmap' VALUES (3990, 7548, NULL, 5033);
INSERT INTO 'dancesrecordingsmap' VALUES (2153, 4106, NULL, 2668);
INSERT INTO 'dancesrecordingsmap' VALUES (2154, 8142, NULL, 2672);
INSERT INTO 'dancesrecordingsmap' VALUES (2156, 7546, NULL, 2676);
INSERT INTO 'dancesrecordingsmap' VALUES (2157, 7553, NULL, 2679);
INSERT INTO 'dancesrecordingsmap' VALUES (2158, 1280, NULL, 2680);
INSERT INTO 'dancesrecordingsmap' VALUES (3988, 7849, NULL, 5031);
INSERT INTO 'dancesrecordingsmap' VALUES (2134, 4521, NULL, 2645);
INSERT INTO 'dancesrecordingsmap' VALUES (3992, 9385, NULL, 5035);
INSERT INTO 'dancesrecordingsmap' VALUES (3993, 9386, NULL, 5036);
INSERT INTO 'dancesrecordingsmap' VALUES (3994, 9387, NULL, 5037);
INSERT INTO 'dancesrecordingsmap' VALUES (3999, 1884, NULL, 5042);
INSERT INTO 'dancesrecordingsmap' VALUES (4000, 2437, NULL, 5043);
INSERT INTO 'dancesrecordingsmap' VALUES (4001, 2616, NULL, 5044);
INSERT INTO 'dancesrecordingsmap' VALUES (4002, 5296, NULL, 5045);
INSERT INTO 'dancesrecordingsmap' VALUES (4003, 7243, NULL, 5046);
INSERT INTO 'dancesrecordingsmap' VALUES (4004, 822, NULL, 5047);
INSERT INTO 'dancesrecordingsmap' VALUES (4005, 5915, NULL, 5048);
INSERT INTO 'dancesrecordingsmap' VALUES (4006, 4928, NULL, 5049);
INSERT INTO 'dancesrecordingsmap' VALUES (4007, 4641, NULL, 5050);
INSERT INTO 'dancesrecordingsmap' VALUES (4008, 6995, NULL, 5051);
INSERT INTO 'dancesrecordingsmap' VALUES (4009, 4662, NULL, 5052);
INSERT INTO 'dancesrecordingsmap' VALUES (4010, 3485, NULL, 5054);
INSERT INTO 'dancesrecordingsmap' VALUES (4011, 8165, NULL, 4706);
INSERT INTO 'dancesrecordingsmap' VALUES (4012, 9483, NULL, 384);
INSERT INTO 'dancesrecordingsmap' VALUES (4013, 9484, NULL, 2360);
INSERT INTO 'dancesrecordingsmap' VALUES (4014, 9485, NULL, 2298);
INSERT INTO 'dancesrecordingsmap' VALUES (4015, 9488, NULL, 17);
INSERT INTO 'dancesrecordingsmap' VALUES (4016, 9490, NULL, 385);
INSERT INTO 'dancesrecordingsmap' VALUES (4017, 9492, NULL, 2359);
INSERT INTO 'dancesrecordingsmap' VALUES (3947, 5860, NULL, 4989);
INSERT INTO 'dancesrecordingsmap' VALUES (3948, 1501, NULL, 4990);
INSERT INTO 'dancesrecordingsmap' VALUES (3949, 4805, NULL, 4991);
INSERT INTO 'dancesrecordingsmap' VALUES (3950, 6712, NULL, 4992);
INSERT INTO 'dancesrecordingsmap' VALUES (3951, 6182, NULL, 4993);
INSERT INTO 'dancesrecordingsmap' VALUES (3952, 2267, NULL, 4994);
INSERT INTO 'dancesrecordingsmap' VALUES (3953, 1792, NULL, 4995);
INSERT INTO 'dancesrecordingsmap' VALUES (3997, 9390, NULL, 5040);
INSERT INTO 'dancesrecordingsmap' VALUES (3995, 9388, NULL, 5038);
INSERT INTO 'dancesrecordingsmap' VALUES (3961, 3941, NULL, 5005);
INSERT INTO 'dancesrecordingsmap' VALUES (3991, 9169, NULL, 5034);
INSERT INTO 'dancesrecordingsmap' VALUES (4019, 9494, NULL, 1141);
INSERT INTO 'dancesrecordingsmap' VALUES (4021, 9496, NULL, 5029);
INSERT INTO 'dancesrecordingsmap' VALUES (4022, 9332, NULL, 4423);
INSERT INTO 'dancesrecordingsmap' VALUES (4023, 6701, NULL, 5055);
INSERT INTO 'dancesrecordingsmap' VALUES (4024, 6712, NULL, 5056);
INSERT INTO 'dancesrecordingsmap' VALUES (4025, 314, NULL, 5057);
INSERT INTO 'dancesrecordingsmap' VALUES (4026, 5330, NULL, 5058);
INSERT INTO 'dancesrecordingsmap' VALUES (4027, 5525, NULL, 5059);
INSERT INTO 'dancesrecordingsmap' VALUES (4028, 6010, NULL, 5060);
INSERT INTO 'dancesrecordingsmap' VALUES (4029, 816, NULL, 5061);
INSERT INTO 'dancesrecordingsmap' VALUES (4030, 7180, NULL, 5062);
INSERT INTO 'dancesrecordingsmap' VALUES (8102, 7284, NULL, 8941);
INSERT INTO 'dancesrecordingsmap' VALUES (2237, 4407, NULL, 2797);
INSERT INTO 'dancesrecordingsmap' VALUES (2238, 7546, NULL, 2798);
INSERT INTO 'dancesrecordingsmap' VALUES (2239, 6711, NULL, 2799);
INSERT INTO 'dancesrecordingsmap' VALUES (2240, 7548, NULL, 2800);
INSERT INTO 'dancesrecordingsmap' VALUES (2241, 6287, NULL, 2801);
INSERT INTO 'dancesrecordingsmap' VALUES (2242, 3921, NULL, 2803);
INSERT INTO 'dancesrecordingsmap' VALUES (2243, 7546, NULL, 2804);
INSERT INTO 'dancesrecordingsmap' VALUES (2244, 2916, NULL, 2805);
INSERT INTO 'dancesrecordingsmap' VALUES (2245, 7546, NULL, 2806);
INSERT INTO 'dancesrecordingsmap' VALUES (2246, 5983, NULL, 2807);
INSERT INTO 'dancesrecordingsmap' VALUES (2247, 6106, NULL, 2808);
INSERT INTO 'dancesrecordingsmap' VALUES (2248, 4877, NULL, 2809);
INSERT INTO 'dancesrecordingsmap' VALUES (2249, 6333, NULL, 2810);
INSERT INTO 'dancesrecordingsmap' VALUES (2250, 437, NULL, 2811);
INSERT INTO 'dancesrecordingsmap' VALUES (2251, 6375, NULL, 2812);
INSERT INTO 'dancesrecordingsmap' VALUES (2252, 5063, NULL, 2813);
INSERT INTO 'dancesrecordingsmap' VALUES (2253, 4063, NULL, 2814);
INSERT INTO 'dancesrecordingsmap' VALUES (2254, 4815, NULL, 2815);
INSERT INTO 'dancesrecordingsmap' VALUES (2255, 5539, NULL, 2817);
INSERT INTO 'dancesrecordingsmap' VALUES (2256, 2044, NULL, 2818);
INSERT INTO 'dancesrecordingsmap' VALUES (2257, 1834, NULL, 2819);
INSERT INTO 'dancesrecordingsmap' VALUES (2258, 5755, NULL, 2825);
INSERT INTO 'dancesrecordingsmap' VALUES (2259, 8142, NULL, 2828);
INSERT INTO 'dancesrecordingsmap' VALUES (2261, 7546, NULL, 2831);
INSERT INTO 'dancesrecordingsmap' VALUES (2262, 2042, NULL, 2832);
INSERT INTO 'dancesrecordingsmap' VALUES (2263, 2781, NULL, 2834);
INSERT INTO 'dancesrecordingsmap' VALUES (2264, 1780, NULL, 2835);
INSERT INTO 'dancesrecordingsmap' VALUES (2265, 4728, NULL, 2840);
INSERT INTO 'dancesrecordingsmap' VALUES (2266, 3759, NULL, 2841);
INSERT INTO 'dancesrecordingsmap' VALUES (2267, 5463, NULL, 2842);
INSERT INTO 'dancesrecordingsmap' VALUES (2268, 6585, NULL, 2843);
INSERT INTO 'dancesrecordingsmap' VALUES (2269, 5128, NULL, 2844);
INSERT INTO 'dancesrecordingsmap' VALUES (2270, 2979, NULL, 2845);
INSERT INTO 'dancesrecordingsmap' VALUES (2271, 109, NULL, 2846);
INSERT INTO 'dancesrecordingsmap' VALUES (2272, 3635, NULL, 2847);
INSERT INTO 'dancesrecordingsmap' VALUES (2273, 848, NULL, 2848);
INSERT INTO 'dancesrecordingsmap' VALUES (2284, 743, NULL, 2864);
INSERT INTO 'dancesrecordingsmap' VALUES (2285, 1562, NULL, 2865);
INSERT INTO 'dancesrecordingsmap' VALUES (2286, 5741, NULL, 2866);
INSERT INTO 'dancesrecordingsmap' VALUES (2287, 2747, NULL, 2868);
INSERT INTO 'dancesrecordingsmap' VALUES (2289, 7111, NULL, 1451);
INSERT INTO 'dancesrecordingsmap' VALUES (2290, 4407, NULL, 2758);
INSERT INTO 'dancesrecordingsmap' VALUES (2291, 5982, NULL, 2759);
INSERT INTO 'dancesrecordingsmap' VALUES (2292, 1782, NULL, 2760);
INSERT INTO 'dancesrecordingsmap' VALUES (2293, 4336, NULL, 2761);
INSERT INTO 'dancesrecordingsmap' VALUES (2294, 4102, NULL, 2879);
INSERT INTO 'dancesrecordingsmap' VALUES (2295, 2498, NULL, 2880);
INSERT INTO 'dancesrecordingsmap' VALUES (2296, 4959, NULL, 2881);
INSERT INTO 'dancesrecordingsmap' VALUES (2297, 6915, NULL, 2882);
INSERT INTO 'dancesrecordingsmap' VALUES (2298, 584, NULL, 2883);
INSERT INTO 'dancesrecordingsmap' VALUES (2299, 2389, NULL, 2884);
INSERT INTO 'dancesrecordingsmap' VALUES (2300, 3365, NULL, 2885);
INSERT INTO 'dancesrecordingsmap' VALUES (2301, 2250, NULL, 2886);
INSERT INTO 'dancesrecordingsmap' VALUES (2302, 2956, NULL, 2887);
INSERT INTO 'dancesrecordingsmap' VALUES (2303, 7055, NULL, 2888);
INSERT INTO 'dancesrecordingsmap' VALUES (2304, 2409, NULL, 2889);
INSERT INTO 'dancesrecordingsmap' VALUES (2305, 2349, NULL, 2890);
INSERT INTO 'dancesrecordingsmap' VALUES (2306, 3759, NULL, 2891);
INSERT INTO 'dancesrecordingsmap' VALUES (2319, 4782, NULL, 2905);
INSERT INTO 'dancesrecordingsmap' VALUES (2320, 3774, NULL, 2906);
INSERT INTO 'dancesrecordingsmap' VALUES (2321, 6532, NULL, 2907);
INSERT INTO 'dancesrecordingsmap' VALUES (2322, 2166, NULL, 2909);
INSERT INTO 'dancesrecordingsmap' VALUES (2323, 1966, NULL, 2910);
INSERT INTO 'dancesrecordingsmap' VALUES (2324, 5658, NULL, 2911);
INSERT INTO 'dancesrecordingsmap' VALUES (2325, 4911, NULL, 2228);
INSERT INTO 'dancesrecordingsmap' VALUES (2326, 8301, NULL, 2917);
INSERT INTO 'dancesrecordingsmap' VALUES (2327, 7552, NULL, 2918);
INSERT INTO 'dancesrecordingsmap' VALUES (2328, 8143, NULL, 2921);
INSERT INTO 'dancesrecordingsmap' VALUES (2329, 2521, NULL, 2924);
INSERT INTO 'dancesrecordingsmap' VALUES (4031, 1884, NULL, 5063);
INSERT INTO 'dancesrecordingsmap' VALUES (4032, 4106, NULL, 5064);
INSERT INTO 'dancesrecordingsmap' VALUES (4033, 3336, NULL, 5065);
INSERT INTO 'dancesrecordingsmap' VALUES (4034, 6048, NULL, 5066);
INSERT INTO 'dancesrecordingsmap' VALUES (4035, 4304, NULL, 2090);
INSERT INTO 'dancesrecordingsmap' VALUES (4037, 1204, NULL, 3841);
INSERT INTO 'dancesrecordingsmap' VALUES (4038, 9567, NULL, 456);
INSERT INTO 'dancesrecordingsmap' VALUES (4040, 7111, NULL, 5067);
INSERT INTO 'dancesrecordingsmap' VALUES (4042, 3057, NULL, 5069);
INSERT INTO 'dancesrecordingsmap' VALUES (4043, 4646, NULL, 5070);
INSERT INTO 'dancesrecordingsmap' VALUES (4044, 3129, NULL, 5071);
INSERT INTO 'dancesrecordingsmap' VALUES (4045, 6712, NULL, 5072);
INSERT INTO 'dancesrecordingsmap' VALUES (4046, 3203, NULL, 5073);
INSERT INTO 'dancesrecordingsmap' VALUES (4047, 5170, NULL, 5074);
INSERT INTO 'dancesrecordingsmap' VALUES (4048, 4291, NULL, 5075);
INSERT INTO 'dancesrecordingsmap' VALUES (4049, 4271, NULL, 5076);
INSERT INTO 'dancesrecordingsmap' VALUES (4050, 2494, NULL, 5077);
INSERT INTO 'dancesrecordingsmap' VALUES (4051, 633, NULL, 5078);
INSERT INTO 'dancesrecordingsmap' VALUES (4036, 5679, NULL, 1989);
INSERT INTO 'dancesrecordingsmap' VALUES (3978, 6707, NULL, 5021);
INSERT INTO 'dancesrecordingsmap' VALUES (2309, 992, NULL, 2895);
INSERT INTO 'dancesrecordingsmap' VALUES (2260, 7555, NULL, 2829);
INSERT INTO 'dancesrecordingsmap' VALUES (2308, 400, NULL, 2894);
INSERT INTO 'dancesrecordingsmap' VALUES (2310, 5703, NULL, 2896);
INSERT INTO 'dancesrecordingsmap' VALUES (2311, 5686, NULL, 2897);
INSERT INTO 'dancesrecordingsmap' VALUES (2313, 6819, NULL, 2899);
INSERT INTO 'dancesrecordingsmap' VALUES (2314, 2556, NULL, 2900);
INSERT INTO 'dancesrecordingsmap' VALUES (2315, 981, NULL, 2901);
INSERT INTO 'dancesrecordingsmap' VALUES (2316, 51, NULL, 2902);
INSERT INTO 'dancesrecordingsmap' VALUES (2317, 3569, NULL, 2903);
INSERT INTO 'dancesrecordingsmap' VALUES (2318, 974, NULL, 2904);
INSERT INTO 'dancesrecordingsmap' VALUES (4052, 859, NULL, 5079);
INSERT INTO 'dancesrecordingsmap' VALUES (4053, 9611, NULL, 4449);
INSERT INTO 'dancesrecordingsmap' VALUES (4054, 5860, NULL, 5081);
INSERT INTO 'dancesrecordingsmap' VALUES (4055, 4106, NULL, 5082);
INSERT INTO 'dancesrecordingsmap' VALUES (4056, 9645, NULL, 5083);
INSERT INTO 'dancesrecordingsmap' VALUES (4057, 7548, NULL, 5084);
INSERT INTO 'dancesrecordingsmap' VALUES (4058, 274, NULL, 5086);
INSERT INTO 'dancesrecordingsmap' VALUES (4059, 3310, NULL, 5087);
INSERT INTO 'dancesrecordingsmap' VALUES (4060, 1773, NULL, 5088);
INSERT INTO 'dancesrecordingsmap' VALUES (4061, 8753, NULL, 5089);
INSERT INTO 'dancesrecordingsmap' VALUES (4062, 5529, NULL, 5090);
INSERT INTO 'dancesrecordingsmap' VALUES (4063, 1884, NULL, 5093);
INSERT INTO 'dancesrecordingsmap' VALUES (4064, 7652, NULL, 5094);
INSERT INTO 'dancesrecordingsmap' VALUES (4065, 1931, NULL, 5095);
INSERT INTO 'dancesrecordingsmap' VALUES (4067, 3529, NULL, 5098);
INSERT INTO 'dancesrecordingsmap' VALUES (4069, 9001, NULL, 5099);
INSERT INTO 'dancesrecordingsmap' VALUES (4070, 9003, NULL, 5100);
INSERT INTO 'dancesrecordingsmap' VALUES (4071, 9006, NULL, 5100);
INSERT INTO 'dancesrecordingsmap' VALUES (4072, 9009, NULL, 5101);
INSERT INTO 'dancesrecordingsmap' VALUES (8090, 10787, NULL, 8930);
INSERT INTO 'dancesrecordingsmap' VALUES (8103, 5921, NULL, 8943);
INSERT INTO 'dancesrecordingsmap' VALUES (8105, 909, NULL, 8945);
INSERT INTO 'dancesrecordingsmap' VALUES (8108, 3637, NULL, 8948);
INSERT INTO 'dancesrecordingsmap' VALUES (8109, 7245, NULL, 8950);
INSERT INTO 'dancesrecordingsmap' VALUES (8112, 5198, NULL, 8953);
INSERT INTO 'dancesrecordingsmap' VALUES (8113, 2034, NULL, 8955);
INSERT INTO 'dancesrecordingsmap' VALUES (8118, 4032, NULL, 8961);
INSERT INTO 'dancesrecordingsmap' VALUES (2288, 2228, NULL, 2873);
INSERT INTO 'dancesrecordingsmap' VALUES (4018, 9493, NULL, 337);
INSERT INTO 'dancesrecordingsmap' VALUES (4068, 5279, NULL, 3196);
INSERT INTO 'dancesrecordingsmap' VALUES (3998, 5588, NULL, 1617);
INSERT INTO 'dancesrecordingsmap' VALUES (4066, 9631, NULL, 3193);
INSERT INTO 'dancesrecordingsmap' VALUES (4020, 9495, NULL, 1232);
INSERT INTO 'dancesrecordingsmap' VALUES (8130, 5330, NULL, 8992);
INSERT INTO 'dancesrecordingsmap' VALUES (8131, 2250, NULL, 8995);
INSERT INTO 'dancesrecordingsmap' VALUES (8132, 6010, NULL, 8997);
INSERT INTO 'dancesrecordingsmap' VALUES (8133, 769, NULL, 9004);
INSERT INTO 'dancesrecordingsmap' VALUES (8134, 3582, NULL, 9007);
INSERT INTO 'dancesrecordingsmap' VALUES (8135, 8744, NULL, 9016);
INSERT INTO 'dancesrecordingsmap' VALUES (8139, 14532, NULL, 9020);
INSERT INTO 'dancesrecordingsmap' VALUES (8141, 14535, NULL, 9023);
INSERT INTO 'dancesrecordingsmap' VALUES (8144, 14634, NULL, 9026);
INSERT INTO 'dancesrecordingsmap' VALUES (8146, 14636, NULL, 9029);
INSERT INTO 'dancesrecordingsmap' VALUES (8147, 14241, NULL, 9030);
INSERT INTO 'dancesrecordingsmap' VALUES (8148, 2267, NULL, 9055);
INSERT INTO 'dancesrecordingsmap' VALUES (8149, 6037, NULL, 9057);
INSERT INTO 'dancesrecordingsmap' VALUES (2330, 7546, NULL, 2927);
INSERT INTO 'dancesrecordingsmap' VALUES (2331, 7552, NULL, 2928);
INSERT INTO 'dancesrecordingsmap' VALUES (2332, 8154, NULL, 2929);
INSERT INTO 'dancesrecordingsmap' VALUES (2333, 7548, NULL, 2930);
INSERT INTO 'dancesrecordingsmap' VALUES (2334, 5641, NULL, 2934);
INSERT INTO 'dancesrecordingsmap' VALUES (2335, 5658, NULL, 2936);
INSERT INTO 'dancesrecordingsmap' VALUES (2336, 1210, NULL, 2937);
INSERT INTO 'dancesrecordingsmap' VALUES (2337, 4032, NULL, 2938);
INSERT INTO 'dancesrecordingsmap' VALUES (2338, 899, NULL, 2939);
INSERT INTO 'dancesrecordingsmap' VALUES (2339, 5982, NULL, 2940);
INSERT INTO 'dancesrecordingsmap' VALUES (2340, 1792, NULL, 2941);
INSERT INTO 'dancesrecordingsmap' VALUES (2341, 3594, NULL, 2942);
INSERT INTO 'dancesrecordingsmap' VALUES (3985, 9382, NULL, 5028);
INSERT INTO 'dancesrecordingsmap' VALUES (2274, 1562, NULL, 2849);
INSERT INTO 'dancesrecordingsmap' VALUES (2275, 6638, NULL, 2850);
INSERT INTO 'dancesrecordingsmap' VALUES (2276, 6091, NULL, 2851);
INSERT INTO 'dancesrecordingsmap' VALUES (2277, 5794, NULL, 2852);
INSERT INTO 'dancesrecordingsmap' VALUES (2278, 642, NULL, 2853);
INSERT INTO 'dancesrecordingsmap' VALUES (2279, 5239, NULL, 2855);
INSERT INTO 'dancesrecordingsmap' VALUES (2281, 7189, NULL, 2857);
INSERT INTO 'dancesrecordingsmap' VALUES (2282, 153, NULL, 2858);
INSERT INTO 'dancesrecordingsmap' VALUES (2283, 7546, NULL, 2859);
INSERT INTO 'dancesrecordingsmap' VALUES (4039, 9568, NULL, 5040);
INSERT INTO 'dancesrecordingsmap' VALUES (8119, 6373, NULL, 8962);
INSERT INTO 'dancesrecordingsmap' VALUES (3996, 9389, NULL, 5039);
INSERT INTO 'dancesrecordingsmap' VALUES (2342, 794, NULL, 2943);
INSERT INTO 'dancesrecordingsmap' VALUES (2343, 1501, NULL, 2944);
INSERT INTO 'dancesrecordingsmap' VALUES (2344, 4646, NULL, 2945);
INSERT INTO 'dancesrecordingsmap' VALUES (2345, 6373, NULL, 2946);
INSERT INTO 'dancesrecordingsmap' VALUES (2346, 2153, NULL, 2947);
INSERT INTO 'dancesrecordingsmap' VALUES (2347, 3154, NULL, 2948);
INSERT INTO 'dancesrecordingsmap' VALUES (2349, 7546, NULL, 2956);
INSERT INTO 'dancesrecordingsmap' VALUES (2350, 1799, NULL, 2957);
INSERT INTO 'dancesrecordingsmap' VALUES (2351, 2498, NULL, 2959);
INSERT INTO 'dancesrecordingsmap' VALUES (2352, 7546, NULL, 2960);
INSERT INTO 'dancesrecordingsmap' VALUES (2353, 4782, NULL, 2961);
INSERT INTO 'dancesrecordingsmap' VALUES (2355, 2745, NULL, 2963);
INSERT INTO 'dancesrecordingsmap' VALUES (2356, 2250, NULL, 2964);
INSERT INTO 'dancesrecordingsmap' VALUES (2357, 1348, NULL, 2965);
INSERT INTO 'dancesrecordingsmap' VALUES (2358, 5239, NULL, 2967);
INSERT INTO 'dancesrecordingsmap' VALUES (2359, 2349, NULL, 2968);
INSERT INTO 'dancesrecordingsmap' VALUES (2360, 6848, NULL, 2969);
INSERT INTO 'dancesrecordingsmap' VALUES (2361, 4928, NULL, 2970);
INSERT INTO 'dancesrecordingsmap' VALUES (2362, 4968, NULL, 2971);
INSERT INTO 'dancesrecordingsmap' VALUES (2363, 4491, NULL, 2972);
INSERT INTO 'dancesrecordingsmap' VALUES (2364, 55, NULL, 2973);
INSERT INTO 'dancesrecordingsmap' VALUES (2365, 8146, NULL, 2975);
INSERT INTO 'dancesrecordingsmap' VALUES (2366, 7147, NULL, 2976);
INSERT INTO 'dancesrecordingsmap' VALUES (2367, 5308, NULL, 2980);
INSERT INTO 'dancesrecordingsmap' VALUES (2368, 3129, NULL, 2981);
INSERT INTO 'dancesrecordingsmap' VALUES (2369, 6897, NULL, 2982);
INSERT INTO 'dancesrecordingsmap' VALUES (2370, 89, NULL, 2983);
INSERT INTO 'dancesrecordingsmap' VALUES (2371, 445, NULL, 2984);
INSERT INTO 'dancesrecordingsmap' VALUES (2373, 584, NULL, 2986);
INSERT INTO 'dancesrecordingsmap' VALUES (2374, 56, NULL, 2987);
INSERT INTO 'dancesrecordingsmap' VALUES (2375, 4555, NULL, 2988);
INSERT INTO 'dancesrecordingsmap' VALUES (2376, 3231, NULL, 2989);
INSERT INTO 'dancesrecordingsmap' VALUES (2377, 5915, NULL, 2990);
INSERT INTO 'dancesrecordingsmap' VALUES (2378, 5552, NULL, 2991);
INSERT INTO 'dancesrecordingsmap' VALUES (2379, 4324, NULL, 2992);
INSERT INTO 'dancesrecordingsmap' VALUES (2380, 5207, NULL, 2993);
INSERT INTO 'dancesrecordingsmap' VALUES (2381, 2153, NULL, 2994);
INSERT INTO 'dancesrecordingsmap' VALUES (2382, 6349, NULL, 2995);
INSERT INTO 'dancesrecordingsmap' VALUES (2383, 4968, NULL, 2996);
INSERT INTO 'dancesrecordingsmap' VALUES (2384, 6599, NULL, 2997);
INSERT INTO 'dancesrecordingsmap' VALUES (2385, 4562, NULL, 2998);
INSERT INTO 'dancesrecordingsmap' VALUES (2386, 1883, NULL, 2999);
INSERT INTO 'dancesrecordingsmap' VALUES (2387, 3246, NULL, 3000);
INSERT INTO 'dancesrecordingsmap' VALUES (2388, 2745, NULL, 3001);
INSERT INTO 'dancesrecordingsmap' VALUES (2389, 5637, NULL, 3002);
INSERT INTO 'dancesrecordingsmap' VALUES (2390, 153, NULL, 3003);
INSERT INTO 'dancesrecordingsmap' VALUES (2391, 1007, NULL, 3004);
INSERT INTO 'dancesrecordingsmap' VALUES (2392, 6915, NULL, 3006);
INSERT INTO 'dancesrecordingsmap' VALUES (2393, 3837, NULL, 3007);
INSERT INTO 'dancesrecordingsmap' VALUES (2394, 7220, NULL, 3008);
INSERT INTO 'dancesrecordingsmap' VALUES (2395, 4014, NULL, 3009);
INSERT INTO 'dancesrecordingsmap' VALUES (2396, 3906, NULL, 3010);
INSERT INTO 'dancesrecordingsmap' VALUES (2397, 223, NULL, 1534);
INSERT INTO 'dancesrecordingsmap' VALUES (2398, 1348, NULL, 3011);
INSERT INTO 'dancesrecordingsmap' VALUES (2399, 753, NULL, 3012);
INSERT INTO 'dancesrecordingsmap' VALUES (2400, 223, NULL, 3013);
INSERT INTO 'dancesrecordingsmap' VALUES (2401, 1578, NULL, 3014);
INSERT INTO 'dancesrecordingsmap' VALUES (2402, 3862, NULL, 3015);
INSERT INTO 'dancesrecordingsmap' VALUES (2403, 3281, NULL, 3016);
INSERT INTO 'dancesrecordingsmap' VALUES (2404, 5621, NULL, 3017);
INSERT INTO 'dancesrecordingsmap' VALUES (2405, 152, NULL, 3018);
INSERT INTO 'dancesrecordingsmap' VALUES (2406, 3246, NULL, 3019);
INSERT INTO 'dancesrecordingsmap' VALUES (2407, 743, NULL, 3020);
INSERT INTO 'dancesrecordingsmap' VALUES (2408, 6420, NULL, 3021);
INSERT INTO 'dancesrecordingsmap' VALUES (2409, 2367, NULL, 3023);
INSERT INTO 'dancesrecordingsmap' VALUES (2410, 7189, NULL, 3024);
INSERT INTO 'dancesrecordingsmap' VALUES (2411, 3172, NULL, 3026);
INSERT INTO 'dancesrecordingsmap' VALUES (2412, 3743, NULL, 3027);
INSERT INTO 'dancesrecordingsmap' VALUES (2413, 1562, NULL, 3040);
INSERT INTO 'dancesrecordingsmap' VALUES (2414, 1582, NULL, 3042);
INSERT INTO 'dancesrecordingsmap' VALUES (2415, 8146, NULL, 3043);
INSERT INTO 'dancesrecordingsmap' VALUES (2416, 7548, NULL, 3045);
INSERT INTO 'dancesrecordingsmap' VALUES (2418, 980, NULL, 3047);
INSERT INTO 'dancesrecordingsmap' VALUES (2419, 6310, NULL, 3048);
INSERT INTO 'dancesrecordingsmap' VALUES (2420, 848, NULL, 3050);
INSERT INTO 'dancesrecordingsmap' VALUES (2421, 3953, NULL, 3051);
INSERT INTO 'dancesrecordingsmap' VALUES (4073, 9007, NULL, 5102);
INSERT INTO 'dancesrecordingsmap' VALUES (4075, 9010, NULL, 5104);
INSERT INTO 'dancesrecordingsmap' VALUES (4077, 9005, NULL, 5106);
INSERT INTO 'dancesrecordingsmap' VALUES (4078, 9011, NULL, 5107);
INSERT INTO 'dancesrecordingsmap' VALUES (4079, 9012, NULL, 5108);
INSERT INTO 'dancesrecordingsmap' VALUES (9103, 7039, NULL, 716);
INSERT INTO 'dancesrecordingsmap' VALUES (8975, 5755, NULL, 10042);
INSERT INTO 'dancesrecordingsmap' VALUES (4082, 9008, NULL, 5110);
INSERT INTO 'dancesrecordingsmap' VALUES (4083, 9014, NULL, 5111);
INSERT INTO 'dancesrecordingsmap' VALUES (4084, 9015, NULL, 5112);
INSERT INTO 'dancesrecordingsmap' VALUES (4086, 9543, NULL, 5114);
INSERT INTO 'dancesrecordingsmap' VALUES (4087, 1114, NULL, 5115);
INSERT INTO 'dancesrecordingsmap' VALUES (4088, 699, NULL, 5115);
INSERT INTO 'dancesrecordingsmap' VALUES (4090, 5209, NULL, 5116);
INSERT INTO 'dancesrecordingsmap' VALUES (4091, 1473, NULL, 5117);
INSERT INTO 'dancesrecordingsmap' VALUES (4092, 9559, NULL, 5118);
INSERT INTO 'dancesrecordingsmap' VALUES (4093, 7654, NULL, 5119);
INSERT INTO 'dancesrecordingsmap' VALUES (4094, 9074, NULL, 5120);
INSERT INTO 'dancesrecordingsmap' VALUES (4095, 9560, NULL, 5121);
INSERT INTO 'dancesrecordingsmap' VALUES (4096, 7543, NULL, 5122);
INSERT INTO 'dancesrecordingsmap' VALUES (4097, 9561, NULL, 5123);
INSERT INTO 'dancesrecordingsmap' VALUES (4098, 9562, NULL, 5124);
INSERT INTO 'dancesrecordingsmap' VALUES (4099, 9563, NULL, 5125);
INSERT INTO 'dancesrecordingsmap' VALUES (4100, 9705, NULL, 273);
INSERT INTO 'dancesrecordingsmap' VALUES (4101, 9707, NULL, 842);
INSERT INTO 'dancesrecordingsmap' VALUES (4102, 7570, NULL, 840);
INSERT INTO 'dancesrecordingsmap' VALUES (4103, 9728, NULL, 2747);
INSERT INTO 'dancesrecordingsmap' VALUES (4105, 6942, NULL, 2487);
INSERT INTO 'dancesrecordingsmap' VALUES (4106, 6943, NULL, 2531);
INSERT INTO 'dancesrecordingsmap' VALUES (4107, 6944, NULL, 4384);
INSERT INTO 'dancesrecordingsmap' VALUES (4108, 9016, NULL, 4388);
INSERT INTO 'dancesrecordingsmap' VALUES (4109, 9017, NULL, 5097);
INSERT INTO 'dancesrecordingsmap' VALUES (4110, 9018, NULL, 5126);
INSERT INTO 'dancesrecordingsmap' VALUES (4111, 9019, NULL, 5127);
INSERT INTO 'dancesrecordingsmap' VALUES (4112, 9019, NULL, 5128);
INSERT INTO 'dancesrecordingsmap' VALUES (4113, 9020, NULL, 5129);
INSERT INTO 'dancesrecordingsmap' VALUES (4114, 9021, NULL, 5130);
INSERT INTO 'dancesrecordingsmap' VALUES (4115, 4351, NULL, 2214);
INSERT INTO 'dancesrecordingsmap' VALUES (8091, 1582, NULL, 8931);
INSERT INTO 'dancesrecordingsmap' VALUES (8104, 2979, NULL, 8944);
INSERT INTO 'dancesrecordingsmap' VALUES (8106, 3365, NULL, 8946);
INSERT INTO 'dancesrecordingsmap' VALUES (8110, 377, NULL, 8951);
INSERT INTO 'dancesrecordingsmap' VALUES (8114, 5637, NULL, 8956);
INSERT INTO 'dancesrecordingsmap' VALUES (8120, 4273, NULL, 8963);
INSERT INTO 'dancesrecordingsmap' VALUES (8136, 8744, NULL, 9017);
INSERT INTO 'dancesrecordingsmap' VALUES (4104, 9728, NULL, 426);
INSERT INTO 'dancesrecordingsmap' VALUES (4076, 9004, NULL, 5105);
INSERT INTO 'dancesrecordingsmap' VALUES (4089, 6497, NULL, 952);
INSERT INTO 'dancesrecordingsmap' VALUES (8140, 14533, NULL, 9021);
INSERT INTO 'dancesrecordingsmap' VALUES (8150, 3021, NULL, 9058);
INSERT INTO 'dancesrecordingsmap' VALUES (8153, 4858, NULL, 9061);
INSERT INTO 'dancesrecordingsmap' VALUES (2422, 3506, NULL, 3052);
INSERT INTO 'dancesrecordingsmap' VALUES (2423, 3789, NULL, 3053);
INSERT INTO 'dancesrecordingsmap' VALUES (2424, 5741, NULL, 3055);
INSERT INTO 'dancesrecordingsmap' VALUES (2425, 4102, NULL, 3056);
INSERT INTO 'dancesrecordingsmap' VALUES (2426, 3236, NULL, 3057);
INSERT INTO 'dancesrecordingsmap' VALUES (2427, 6915, NULL, 3058);
INSERT INTO 'dancesrecordingsmap' VALUES (2428, 4548, NULL, 3059);
INSERT INTO 'dancesrecordingsmap' VALUES (2429, 1792, NULL, 3060);
INSERT INTO 'dancesrecordingsmap' VALUES (2430, 5964, NULL, 3061);
INSERT INTO 'dancesrecordingsmap' VALUES (2431, 754, NULL, 3062);
INSERT INTO 'dancesrecordingsmap' VALUES (2432, 4239, NULL, 3063);
INSERT INTO 'dancesrecordingsmap' VALUES (2433, 5616, NULL, 3064);
INSERT INTO 'dancesrecordingsmap' VALUES (2434, 4032, NULL, 3065);
INSERT INTO 'dancesrecordingsmap' VALUES (2435, 1562, NULL, 3066);
INSERT INTO 'dancesrecordingsmap' VALUES (2436, 1931, NULL, 3067);
INSERT INTO 'dancesrecordingsmap' VALUES (2437, 2317, NULL, 3068);
INSERT INTO 'dancesrecordingsmap' VALUES (2438, 4646, NULL, 3069);
INSERT INTO 'dancesrecordingsmap' VALUES (2439, 4102, NULL, 3070);
INSERT INTO 'dancesrecordingsmap' VALUES (2440, 5525, NULL, 3071);
INSERT INTO 'dancesrecordingsmap' VALUES (2441, 1792, NULL, 3072);
INSERT INTO 'dancesrecordingsmap' VALUES (2442, 5330, NULL, 3073);
INSERT INTO 'dancesrecordingsmap' VALUES (2443, 5330, NULL, 3074);
INSERT INTO 'dancesrecordingsmap' VALUES (2444, 1782, NULL, 3075);
INSERT INTO 'dancesrecordingsmap' VALUES (2446, 6253, NULL, 3077);
INSERT INTO 'dancesrecordingsmap' VALUES (2447, 5915, NULL, 2600);
INSERT INTO 'dancesrecordingsmap' VALUES (2417, 5426, NULL, 3046);
INSERT INTO 'dancesrecordingsmap' VALUES (8142, 14536, NULL, 9024);
INSERT INTO 'dancesrecordingsmap' VALUES (2348, 7555, NULL, 2952);
INSERT INTO 'dancesrecordingsmap' VALUES (2354, 909, NULL, 2962);
INSERT INTO 'dancesrecordingsmap' VALUES (2448, 3580, NULL, 3079);
INSERT INTO 'dancesrecordingsmap' VALUES (2449, 4927, NULL, 3080);
INSERT INTO 'dancesrecordingsmap' VALUES (2450, 5982, NULL, 3081);
INSERT INTO 'dancesrecordingsmap' VALUES (2451, 1834, NULL, 3082);
INSERT INTO 'dancesrecordingsmap' VALUES (2452, 3561, NULL, 3083);
INSERT INTO 'dancesrecordingsmap' VALUES (2453, 3152, NULL, 3085);
INSERT INTO 'dancesrecordingsmap' VALUES (2454, 4641, NULL, 3086);
INSERT INTO 'dancesrecordingsmap' VALUES (2455, 4064, NULL, 3088);
INSERT INTO 'dancesrecordingsmap' VALUES (2456, 2250, NULL, 3089);
INSERT INTO 'dancesrecordingsmap' VALUES (2457, 4227, NULL, 3090);
INSERT INTO 'dancesrecordingsmap' VALUES (2458, 5033, NULL, 3091);
INSERT INTO 'dancesrecordingsmap' VALUES (2459, 5520, NULL, 3092);
INSERT INTO 'dancesrecordingsmap' VALUES (2460, 5749, NULL, 3093);
INSERT INTO 'dancesrecordingsmap' VALUES (2461, 3279, NULL, 3094);
INSERT INTO 'dancesrecordingsmap' VALUES (2462, 2838, NULL, 3095);
INSERT INTO 'dancesrecordingsmap' VALUES (2463, 723, NULL, 3096);
INSERT INTO 'dancesrecordingsmap' VALUES (2464, 223, NULL, 3097);
INSERT INTO 'dancesrecordingsmap' VALUES (2466, 3435, NULL, 3099);
INSERT INTO 'dancesrecordingsmap' VALUES (2467, 1966, NULL, 3100);
INSERT INTO 'dancesrecordingsmap' VALUES (2468, 4431, NULL, 2366);
INSERT INTO 'dancesrecordingsmap' VALUES (2469, 6915, NULL, 3029);
INSERT INTO 'dancesrecordingsmap' VALUES (2470, 5426, NULL, 3031);
INSERT INTO 'dancesrecordingsmap' VALUES (2471, 3802, NULL, 3034);
INSERT INTO 'dancesrecordingsmap' VALUES (2472, 1962, NULL, 3035);
INSERT INTO 'dancesrecordingsmap' VALUES (2473, 2838, NULL, 3037);
INSERT INTO 'dancesrecordingsmap' VALUES (2474, 5658, NULL, 3101);
INSERT INTO 'dancesrecordingsmap' VALUES (2445, 2745, NULL, 3076);
INSERT INTO 'dancesrecordingsmap' VALUES (4074, 9002, NULL, 5103);
INSERT INTO 'dancesrecordingsmap' VALUES (2475, 1758, NULL, 3102);
INSERT INTO 'dancesrecordingsmap' VALUES (2476, 3057, NULL, 3103);
INSERT INTO 'dancesrecordingsmap' VALUES (2477, 2956, NULL, 3104);
INSERT INTO 'dancesrecordingsmap' VALUES (2478, 5641, NULL, 3106);
INSERT INTO 'dancesrecordingsmap' VALUES (2479, 658, NULL, 3107);
INSERT INTO 'dancesrecordingsmap' VALUES (2480, 4911, NULL, 3108);
INSERT INTO 'dancesrecordingsmap' VALUES (2481, 2838, NULL, 3111);
INSERT INTO 'dancesrecordingsmap' VALUES (2482, 522, NULL, 3116);
INSERT INTO 'dancesrecordingsmap' VALUES (2483, 8154, NULL, 3117);
INSERT INTO 'dancesrecordingsmap' VALUES (2484, 6505, NULL, 3118);
INSERT INTO 'dancesrecordingsmap' VALUES (2485, 1582, NULL, 3119);
INSERT INTO 'dancesrecordingsmap' VALUES (2486, 1478, NULL, 3122);
INSERT INTO 'dancesrecordingsmap' VALUES (2487, 1792, NULL, 3123);
INSERT INTO 'dancesrecordingsmap' VALUES (2488, 2498, NULL, 3124);
INSERT INTO 'dancesrecordingsmap' VALUES (2489, 4318, NULL, 3126);
INSERT INTO 'dancesrecordingsmap' VALUES (2490, 1786, NULL, 3128);
INSERT INTO 'dancesrecordingsmap' VALUES (2491, 2498, NULL, 3129);
INSERT INTO 'dancesrecordingsmap' VALUES (2492, 5525, NULL, 3130);
INSERT INTO 'dancesrecordingsmap' VALUES (2493, 2745, NULL, 3131);
INSERT INTO 'dancesrecordingsmap' VALUES (2494, 6915, NULL, 3134);
INSERT INTO 'dancesrecordingsmap' VALUES (2495, 1931, NULL, 3135);
INSERT INTO 'dancesrecordingsmap' VALUES (2496, 541, NULL, 3136);
INSERT INTO 'dancesrecordingsmap' VALUES (2497, 3526, NULL, 3137);
INSERT INTO 'dancesrecordingsmap' VALUES (2498, 3528, NULL, 3138);
INSERT INTO 'dancesrecordingsmap' VALUES (2499, 5591, NULL, 3139);
INSERT INTO 'dancesrecordingsmap' VALUES (2500, 1210, NULL, 3140);
INSERT INTO 'dancesrecordingsmap' VALUES (2501, 4862, NULL, 3141);
INSERT INTO 'dancesrecordingsmap' VALUES (2502, 7242, NULL, 3142);
INSERT INTO 'dancesrecordingsmap' VALUES (2504, 5373, NULL, 3144);
INSERT INTO 'dancesrecordingsmap' VALUES (2505, 3988, NULL, 3145);
INSERT INTO 'dancesrecordingsmap' VALUES (2506, 1817, NULL, 3146);
INSERT INTO 'dancesrecordingsmap' VALUES (2509, 2305, NULL, 3149);
INSERT INTO 'dancesrecordingsmap' VALUES (2510, 4707, NULL, 3150);
INSERT INTO 'dancesrecordingsmap' VALUES (2511, 5354, NULL, 3151);
INSERT INTO 'dancesrecordingsmap' VALUES (2512, 8142, NULL, 1511);
INSERT INTO 'dancesrecordingsmap' VALUES (2513, 5523, NULL, 3152);
INSERT INTO 'dancesrecordingsmap' VALUES (2514, 2389, NULL, 3155);
INSERT INTO 'dancesrecordingsmap' VALUES (2515, 3759, NULL, 3156);
INSERT INTO 'dancesrecordingsmap' VALUES (2516, 5731, NULL, 3157);
INSERT INTO 'dancesrecordingsmap' VALUES (2517, 6233, NULL, 530);
INSERT INTO 'dancesrecordingsmap' VALUES (2518, 5239, NULL, 532);
INSERT INTO 'dancesrecordingsmap' VALUES (2519, 6359, NULL, 3028);
INSERT INTO 'dancesrecordingsmap' VALUES (2520, 3672, NULL, 3105);
INSERT INTO 'dancesrecordingsmap' VALUES (2521, 2156, NULL, 3167);
INSERT INTO 'dancesrecordingsmap' VALUES (2522, 2918, NULL, 3168);
INSERT INTO 'dancesrecordingsmap' VALUES (2523, 5802, NULL, 3169);
INSERT INTO 'dancesrecordingsmap' VALUES (2524, 4646, NULL, 3170);
INSERT INTO 'dancesrecordingsmap' VALUES (2525, 353, NULL, 3171);
INSERT INTO 'dancesrecordingsmap' VALUES (2526, 3435, NULL, 3172);
INSERT INTO 'dancesrecordingsmap' VALUES (2527, 4890, NULL, 74);
INSERT INTO 'dancesrecordingsmap' VALUES (2528, 7147, NULL, 1159);
INSERT INTO 'dancesrecordingsmap' VALUES (2529, 5713, NULL, 1161);
INSERT INTO 'dancesrecordingsmap' VALUES (2530, 6091, NULL, 1168);
INSERT INTO 'dancesrecordingsmap' VALUES (2531, 7111, NULL, 2430);
INSERT INTO 'dancesrecordingsmap' VALUES (2532, 5239, NULL, 2476);
INSERT INTO 'dancesrecordingsmap' VALUES (2533, 7109, NULL, 2861);
INSERT INTO 'dancesrecordingsmap' VALUES (2534, 4032, NULL, 3036);
INSERT INTO 'dancesrecordingsmap' VALUES (2535, 6214, NULL, 3158);
INSERT INTO 'dancesrecordingsmap' VALUES (2536, 5525, NULL, 3173);
INSERT INTO 'dancesrecordingsmap' VALUES (2537, 2979, NULL, 3174);
INSERT INTO 'dancesrecordingsmap' VALUES (2538, 3154, NULL, 3175);
INSERT INTO 'dancesrecordingsmap' VALUES (2539, 4725, NULL, 3176);
INSERT INTO 'dancesrecordingsmap' VALUES (2540, 743, NULL, 3177);
INSERT INTO 'dancesrecordingsmap' VALUES (2541, 3246, NULL, 3178);
INSERT INTO 'dancesrecordingsmap' VALUES (2542, 2250, NULL, 3179);
INSERT INTO 'dancesrecordingsmap' VALUES (2543, 3558, NULL, 3180);
INSERT INTO 'dancesrecordingsmap' VALUES (2544, 373, NULL, 3181);
INSERT INTO 'dancesrecordingsmap' VALUES (2545, 1647, NULL, 3182);
INSERT INTO 'dancesrecordingsmap' VALUES (2546, 7546, NULL, 3183);
INSERT INTO 'dancesrecordingsmap' VALUES (2547, 5637, NULL, 3184);
INSERT INTO 'dancesrecordingsmap' VALUES (2548, 2956, NULL, 3185);
INSERT INTO 'dancesrecordingsmap' VALUES (2549, 2353, NULL, 3186);
INSERT INTO 'dancesrecordingsmap' VALUES (4117, 5135, NULL, 2526);
INSERT INTO 'dancesrecordingsmap' VALUES (4119, 9745, NULL, 1413);
INSERT INTO 'dancesrecordingsmap' VALUES (4120, 9755, NULL, 2812);
INSERT INTO 'dancesrecordingsmap' VALUES (4122, 9189, NULL, 1308);
INSERT INTO 'dancesrecordingsmap' VALUES (4123, 9773, NULL, 288);
INSERT INTO 'dancesrecordingsmap' VALUES (4124, 9774, NULL, 5046);
INSERT INTO 'dancesrecordingsmap' VALUES (4125, 8709, NULL, 5131);
INSERT INTO 'dancesrecordingsmap' VALUES (4126, 9565, NULL, 5132);
INSERT INTO 'dancesrecordingsmap' VALUES (4127, 9084, NULL, 5133);
INSERT INTO 'dancesrecordingsmap' VALUES (4128, 2222, NULL, 5134);
INSERT INTO 'dancesrecordingsmap' VALUES (4129, 1383, NULL, 5135);
INSERT INTO 'dancesrecordingsmap' VALUES (4130, 2918, NULL, 5136);
INSERT INTO 'dancesrecordingsmap' VALUES (4131, 6387, NULL, 5137);
INSERT INTO 'dancesrecordingsmap' VALUES (4132, 7436, NULL, 5138);
INSERT INTO 'dancesrecordingsmap' VALUES (4133, 9004, NULL, 5139);
INSERT INTO 'dancesrecordingsmap' VALUES (2550, 4641, NULL, 3187);
INSERT INTO 'dancesrecordingsmap' VALUES (2551, 2349, NULL, 3188);
INSERT INTO 'dancesrecordingsmap' VALUES (2552, 7542, NULL, 3189);
INSERT INTO 'dancesrecordingsmap' VALUES (2553, 7542, NULL, 1081);
INSERT INTO 'dancesrecordingsmap' VALUES (2554, 7542, NULL, 1690);
INSERT INTO 'dancesrecordingsmap' VALUES (2555, 5525, NULL, 3190);
INSERT INTO 'dancesrecordingsmap' VALUES (2556, 1931, NULL, 3192);
INSERT INTO 'dancesrecordingsmap' VALUES (2559, 2781, NULL, 3195);
INSERT INTO 'dancesrecordingsmap' VALUES (2561, 4014, NULL, 3197);
INSERT INTO 'dancesrecordingsmap' VALUES (2562, 7553, NULL, 3212);
INSERT INTO 'dancesrecordingsmap' VALUES (2563, 4227, NULL, 3213);
INSERT INTO 'dancesrecordingsmap' VALUES (2564, 7546, NULL, 3215);
INSERT INTO 'dancesrecordingsmap' VALUES (2565, 934, NULL, 3218);
INSERT INTO 'dancesrecordingsmap' VALUES (2566, 3246, NULL, 3219);
INSERT INTO 'dancesrecordingsmap' VALUES (2567, 950, NULL, 3228);
INSERT INTO 'dancesrecordingsmap' VALUES (2569, 5117, NULL, 3230);
INSERT INTO 'dancesrecordingsmap' VALUES (2570, 1715, NULL, 3231);
INSERT INTO 'dancesrecordingsmap' VALUES (2571, 4908, NULL, 3232);
INSERT INTO 'dancesrecordingsmap' VALUES (2572, 7065, NULL, 3233);
INSERT INTO 'dancesrecordingsmap' VALUES (2573, 7921, NULL, 3236);
INSERT INTO 'dancesrecordingsmap' VALUES (2574, 4585, NULL, 3237);
INSERT INTO 'dancesrecordingsmap' VALUES (2575, 1647, NULL, 1097);
INSERT INTO 'dancesrecordingsmap' VALUES (2581, 2093, NULL, 3248);
INSERT INTO 'dancesrecordingsmap' VALUES (2582, 2093, NULL, 3249);
INSERT INTO 'dancesrecordingsmap' VALUES (2583, 6867, NULL, 3250);
INSERT INTO 'dancesrecordingsmap' VALUES (2578, 3336, NULL, 3245);
INSERT INTO 'dancesrecordingsmap' VALUES (2576, 3506, NULL, 3243);
INSERT INTO 'dancesrecordingsmap' VALUES (2577, 1304, NULL, 3244);
INSERT INTO 'dancesrecordingsmap' VALUES (2579, 6420, NULL, 3246);
INSERT INTO 'dancesrecordingsmap' VALUES (2580, 4782, NULL, 3247);
INSERT INTO 'dancesrecordingsmap' VALUES (2503, 2408, NULL, 3143);
INSERT INTO 'dancesrecordingsmap' VALUES (2508, 1876, NULL, 3148);
INSERT INTO 'dancesrecordingsmap' VALUES (2585, 3172, NULL, 3252);
INSERT INTO 'dancesrecordingsmap' VALUES (2588, 7147, NULL, 3255);
INSERT INTO 'dancesrecordingsmap' VALUES (2589, 5637, NULL, 3256);
INSERT INTO 'dancesrecordingsmap' VALUES (2590, 3057, NULL, 3257);
INSERT INTO 'dancesrecordingsmap' VALUES (2591, 2786, NULL, 1730);
INSERT INTO 'dancesrecordingsmap' VALUES (2592, 6915, NULL, 3224);
INSERT INTO 'dancesrecordingsmap' VALUES (2593, 3672, NULL, 3226);
INSERT INTO 'dancesrecordingsmap' VALUES (2595, 153, NULL, 3032);
INSERT INTO 'dancesrecordingsmap' VALUES (2596, 4318, NULL, 3223);
INSERT INTO 'dancesrecordingsmap' VALUES (2597, 3097, NULL, 3259);
INSERT INTO 'dancesrecordingsmap' VALUES (2598, 1774, NULL, 3261);
INSERT INTO 'dancesrecordingsmap' VALUES (2600, 4641, NULL, 3263);
INSERT INTO 'dancesrecordingsmap' VALUES (2601, 6550, NULL, 120);
INSERT INTO 'dancesrecordingsmap' VALUES (2602, 3987, NULL, 146);
INSERT INTO 'dancesrecordingsmap' VALUES (2603, 855, NULL, 2423);
INSERT INTO 'dancesrecordingsmap' VALUES (2604, 4835, NULL, 2426);
INSERT INTO 'dancesrecordingsmap' VALUES (2605, 4280, NULL, 3264);
INSERT INTO 'dancesrecordingsmap' VALUES (2606, 6845, NULL, 3265);
INSERT INTO 'dancesrecordingsmap' VALUES (2607, 5768, NULL, 3266);
INSERT INTO 'dancesrecordingsmap' VALUES (2608, 4988, NULL, 3267);
INSERT INTO 'dancesrecordingsmap' VALUES (2609, 472, NULL, 3268);
INSERT INTO 'dancesrecordingsmap' VALUES (2610, 5618, NULL, 3269);
INSERT INTO 'dancesrecordingsmap' VALUES (2611, 1928, NULL, 3270);
INSERT INTO 'dancesrecordingsmap' VALUES (2613, 1927, NULL, 3272);
INSERT INTO 'dancesrecordingsmap' VALUES (2614, 314, NULL, 3273);
INSERT INTO 'dancesrecordingsmap' VALUES (2615, 5860, NULL, 3274);
INSERT INTO 'dancesrecordingsmap' VALUES (2616, 3562, NULL, 3275);
INSERT INTO 'dancesrecordingsmap' VALUES (2617, 3336, NULL, 3276);
INSERT INTO 'dancesrecordingsmap' VALUES (2558, 3529, NULL, 3194);
INSERT INTO 'dancesrecordingsmap' VALUES (2557, 650, NULL, 3193);
INSERT INTO 'dancesrecordingsmap' VALUES (2560, 3595, NULL, 3196);
INSERT INTO 'dancesrecordingsmap' VALUES (2618, 584, NULL, 3277);
INSERT INTO 'dancesrecordingsmap' VALUES (2619, 4106, NULL, 3278);
INSERT INTO 'dancesrecordingsmap' VALUES (2620, 3561, NULL, 3279);
INSERT INTO 'dancesrecordingsmap' VALUES (2621, 2409, NULL, 3280);
INSERT INTO 'dancesrecordingsmap' VALUES (2622, 4927, NULL, 3281);
INSERT INTO 'dancesrecordingsmap' VALUES (2623, 2777, NULL, 3282);
INSERT INTO 'dancesrecordingsmap' VALUES (2624, 4369, NULL, 3283);
INSERT INTO 'dancesrecordingsmap' VALUES (2625, 10, NULL, 3284);
INSERT INTO 'dancesrecordingsmap' VALUES (2626, 4224, NULL, 3285);
INSERT INTO 'dancesrecordingsmap' VALUES (2627, 5696, NULL, 3286);
INSERT INTO 'dancesrecordingsmap' VALUES (2628, 3346, NULL, 3287);
INSERT INTO 'dancesrecordingsmap' VALUES (2629, 2627, NULL, 3288);
INSERT INTO 'dancesrecordingsmap' VALUES (2630, 6037, NULL, 1937);
INSERT INTO 'dancesrecordingsmap' VALUES (2631, 6712, NULL, 3289);
INSERT INTO 'dancesrecordingsmap' VALUES (2633, 1838, NULL, 3291);
INSERT INTO 'dancesrecordingsmap' VALUES (2634, 5794, NULL, 3292);
INSERT INTO 'dancesrecordingsmap' VALUES (2635, 1786, NULL, 3293);
INSERT INTO 'dancesrecordingsmap' VALUES (2636, 7180, NULL, 3294);
INSERT INTO 'dancesrecordingsmap' VALUES (2637, 5330, NULL, 3296);
INSERT INTO 'dancesrecordingsmap' VALUES (2638, 3980, NULL, 3297);
INSERT INTO 'dancesrecordingsmap' VALUES (2639, 314, NULL, 3298);
INSERT INTO 'dancesrecordingsmap' VALUES (2640, 1280, NULL, 3299);
INSERT INTO 'dancesrecordingsmap' VALUES (2641, 887, NULL, 3300);
INSERT INTO 'dancesrecordingsmap' VALUES (2642, 584, NULL, 3301);
INSERT INTO 'dancesrecordingsmap' VALUES (4134, 8757, NULL, 5140);
INSERT INTO 'dancesrecordingsmap' VALUES (4135, 1128, NULL, 5141);
INSERT INTO 'dancesrecordingsmap' VALUES (4116, 5165, NULL, 1866);
INSERT INTO 'dancesrecordingsmap' VALUES (2632, 32, NULL, 3290);
INSERT INTO 'dancesrecordingsmap' VALUES (2587, 3906, NULL, 3254);
INSERT INTO 'dancesrecordingsmap' VALUES (4121, 9756, NULL, 336);
INSERT INTO 'dancesrecordingsmap' VALUES (2507, 4553, NULL, 3147);
INSERT INTO 'dancesrecordingsmap' VALUES (2594, 1927, NULL, 3227);
INSERT INTO 'dancesrecordingsmap' VALUES (2599, 7546, NULL, 3262);
INSERT INTO 'dancesrecordingsmap' VALUES (4136, 1469, NULL, 5142);
INSERT INTO 'dancesrecordingsmap' VALUES (4137, 6484, NULL, 5143);
INSERT INTO 'dancesrecordingsmap' VALUES (4141, 1143, NULL, 5147);
INSERT INTO 'dancesrecordingsmap' VALUES (4142, 3780, NULL, 5148);
INSERT INTO 'dancesrecordingsmap' VALUES (4143, 4120, NULL, 5149);
INSERT INTO 'dancesrecordingsmap' VALUES (4144, 3994, NULL, 5150);
INSERT INTO 'dancesrecordingsmap' VALUES (4146, 5291, NULL, 5152);
INSERT INTO 'dancesrecordingsmap' VALUES (4147, 5646, NULL, 5153);
INSERT INTO 'dancesrecordingsmap' VALUES (4148, 2158, NULL, 5157);
INSERT INTO 'dancesrecordingsmap' VALUES (4149, 9804, NULL, 5155);
INSERT INTO 'dancesrecordingsmap' VALUES (4150, 9805, NULL, 5154);
INSERT INTO 'dancesrecordingsmap' VALUES (4151, 9806, NULL, 5156);
INSERT INTO 'dancesrecordingsmap' VALUES (4152, 313, NULL, 5159);
INSERT INTO 'dancesrecordingsmap' VALUES (4153, 2267, NULL, 5160);
INSERT INTO 'dancesrecordingsmap' VALUES (4154, 1796, NULL, 5161);
INSERT INTO 'dancesrecordingsmap' VALUES (4155, 1796, NULL, 5162);
INSERT INTO 'dancesrecordingsmap' VALUES (4156, 4796, NULL, 5163);
INSERT INTO 'dancesrecordingsmap' VALUES (4157, 2222, NULL, 5164);
INSERT INTO 'dancesrecordingsmap' VALUES (4158, 5529, NULL, 5165);
INSERT INTO 'dancesrecordingsmap' VALUES (4159, 5529, NULL, 5166);
INSERT INTO 'dancesrecordingsmap' VALUES (4160, 6091, NULL, 5167);
INSERT INTO 'dancesrecordingsmap' VALUES (4161, 2063, NULL, 5168);
INSERT INTO 'dancesrecordingsmap' VALUES (4162, 2063, NULL, 5169);
INSERT INTO 'dancesrecordingsmap' VALUES (4164, 9760, NULL, 5171);
INSERT INTO 'dancesrecordingsmap' VALUES (4166, 9762, NULL, 5173);
INSERT INTO 'dancesrecordingsmap' VALUES (4167, 7570, NULL, 5174);
INSERT INTO 'dancesrecordingsmap' VALUES (4168, 9061, NULL, 5175);
INSERT INTO 'dancesrecordingsmap' VALUES (4169, 9764, NULL, 5176);
INSERT INTO 'dancesrecordingsmap' VALUES (4171, 9766, NULL, 5178);
INSERT INTO 'dancesrecordingsmap' VALUES (4173, 9768, NULL, 5180);
INSERT INTO 'dancesrecordingsmap' VALUES (4175, 9770, NULL, 5182);
INSERT INTO 'dancesrecordingsmap' VALUES (8111, 5006, NULL, 8952);
INSERT INTO 'dancesrecordingsmap' VALUES (8115, 7139, NULL, 8957);
INSERT INTO 'dancesrecordingsmap' VALUES (8121, 3980, NULL, 8964);
INSERT INTO 'dancesrecordingsmap' VALUES (8137, 8744, NULL, 9018);
INSERT INTO 'dancesrecordingsmap' VALUES (8143, 14537, NULL, 9025);
INSERT INTO 'dancesrecordingsmap' VALUES (8151, 11146, NULL, 9059);
INSERT INTO 'dancesrecordingsmap' VALUES (8154, 805, NULL, 9063);
INSERT INTO 'dancesrecordingsmap' VALUES (8156, 4102, NULL, 9065);
INSERT INTO 'dancesrecordingsmap' VALUES (8158, 14638, NULL, 9067);
INSERT INTO 'dancesrecordingsmap' VALUES (8161, 14598, NULL, 9070);
INSERT INTO 'dancesrecordingsmap' VALUES (8162, 7546, NULL, 9071);
INSERT INTO 'dancesrecordingsmap' VALUES (8163, 7553, NULL, 9073);
INSERT INTO 'dancesrecordingsmap' VALUES (8166, 7552, NULL, 9076);
INSERT INTO 'dancesrecordingsmap' VALUES (8167, 8146, NULL, 9081);
INSERT INTO 'dancesrecordingsmap' VALUES (8168, 8143, NULL, 9081);
INSERT INTO 'dancesrecordingsmap' VALUES (8169, 7548, NULL, 9084);
INSERT INTO 'dancesrecordingsmap' VALUES (8170, 7554, NULL, 9086);
INSERT INTO 'dancesrecordingsmap' VALUES (8172, 1582, NULL, 9089);
INSERT INTO 'dancesrecordingsmap' VALUES (8174, 4102, NULL, 9094);
INSERT INTO 'dancesrecordingsmap' VALUES (8178, 14640, NULL, 9102);
INSERT INTO 'dancesrecordingsmap' VALUES (8179, 40, NULL, 9105);
INSERT INTO 'dancesrecordingsmap' VALUES (2643, 894, NULL, 3302);
INSERT INTO 'dancesrecordingsmap' VALUES (2644, 1792, NULL, 3303);
INSERT INTO 'dancesrecordingsmap' VALUES (2645, 1792, NULL, 3304);
INSERT INTO 'dancesrecordingsmap' VALUES (2646, 5462, NULL, 3305);
INSERT INTO 'dancesrecordingsmap' VALUES (2647, 4014, NULL, 3306);
INSERT INTO 'dancesrecordingsmap' VALUES (2649, 909, NULL, 3308);
INSERT INTO 'dancesrecordingsmap' VALUES (2650, 2593, NULL, 3309);
INSERT INTO 'dancesrecordingsmap' VALUES (2651, 1478, NULL, 3310);
INSERT INTO 'dancesrecordingsmap' VALUES (2652, 522, NULL, 3311);
INSERT INTO 'dancesrecordingsmap' VALUES (2653, 1786, NULL, 3312);
INSERT INTO 'dancesrecordingsmap' VALUES (2654, 5964, NULL, 3313);
INSERT INTO 'dancesrecordingsmap' VALUES (2655, 2153, NULL, 3314);
INSERT INTO 'dancesrecordingsmap' VALUES (2656, 3608, NULL, 3315);
INSERT INTO 'dancesrecordingsmap' VALUES (2657, 1927, NULL, 3317);
INSERT INTO 'dancesrecordingsmap' VALUES (2658, 2250, NULL, 3318);
INSERT INTO 'dancesrecordingsmap' VALUES (2659, 5621, NULL, 3319);
INSERT INTO 'dancesrecordingsmap' VALUES (2660, 2250, NULL, 3320);
INSERT INTO 'dancesrecordingsmap' VALUES (2661, 5904, NULL, 3321);
INSERT INTO 'dancesrecordingsmap' VALUES (2662, 5262, NULL, 3322);
INSERT INTO 'dancesrecordingsmap' VALUES (2663, 4805, NULL, 3323);
INSERT INTO 'dancesrecordingsmap' VALUES (2664, 4890, NULL, 3324);
INSERT INTO 'dancesrecordingsmap' VALUES (2665, 909, NULL, 3325);
INSERT INTO 'dancesrecordingsmap' VALUES (2666, 2267, NULL, 3326);
INSERT INTO 'dancesrecordingsmap' VALUES (2668, 1582, NULL, 3328);
INSERT INTO 'dancesrecordingsmap' VALUES (2669, 3231, NULL, 3329);
INSERT INTO 'dancesrecordingsmap' VALUES (2670, 3323, NULL, 3330);
INSERT INTO 'dancesrecordingsmap' VALUES (2671, 4782, NULL, 3331);
INSERT INTO 'dancesrecordingsmap' VALUES (2672, 5982, NULL, 3332);
INSERT INTO 'dancesrecordingsmap' VALUES (2674, 7612, NULL, 1386);
INSERT INTO 'dancesrecordingsmap' VALUES (2675, 8728, NULL, 109);
INSERT INTO 'dancesrecordingsmap' VALUES (2676, 4783, NULL, 1730);
INSERT INTO 'dancesrecordingsmap' VALUES (2677, 7554, NULL, 3335);
INSERT INTO 'dancesrecordingsmap' VALUES (2678, 905, NULL, 3337);
INSERT INTO 'dancesrecordingsmap' VALUES (2679, 7552, NULL, 3339);
INSERT INTO 'dancesrecordingsmap' VALUES (2680, 7553, NULL, 3340);
INSERT INTO 'dancesrecordingsmap' VALUES (2681, 2203, NULL, 3341);
INSERT INTO 'dancesrecordingsmap' VALUES (2682, 3980, NULL, 3342);
INSERT INTO 'dancesrecordingsmap' VALUES (2683, 4015, NULL, 3343);
INSERT INTO 'dancesrecordingsmap' VALUES (2684, 7546, NULL, 3344);
INSERT INTO 'dancesrecordingsmap' VALUES (2685, 7546, NULL, 3346);
INSERT INTO 'dancesrecordingsmap' VALUES (2686, 8161, NULL, 3347);
INSERT INTO 'dancesrecordingsmap' VALUES (2687, 5713, NULL, 3348);
INSERT INTO 'dancesrecordingsmap' VALUES (2688, 4633, NULL, 3349);
INSERT INTO 'dancesrecordingsmap' VALUES (2689, 8142, NULL, 3350);
INSERT INTO 'dancesrecordingsmap' VALUES (2690, 2317, NULL, 3360);
INSERT INTO 'dancesrecordingsmap' VALUES (2692, 6037, NULL, 3363);
INSERT INTO 'dancesrecordingsmap' VALUES (2693, 1966, NULL, 3364);
INSERT INTO 'dancesrecordingsmap' VALUES (2694, 1834, NULL, 3365);
INSERT INTO 'dancesrecordingsmap' VALUES (2695, 5945, NULL, 3367);
INSERT INTO 'dancesrecordingsmap' VALUES (2696, 4014, NULL, 3368);
INSERT INTO 'dancesrecordingsmap' VALUES (2697, 1582, NULL, 3370);
INSERT INTO 'dancesrecordingsmap' VALUES (2698, 355, NULL, 3372);
INSERT INTO 'dancesrecordingsmap' VALUES (2699, 8569, NULL, 3373);
INSERT INTO 'dancesrecordingsmap' VALUES (2700, 7574, NULL, 3374);
INSERT INTO 'dancesrecordingsmap' VALUES (2701, 7967, NULL, 3377);
INSERT INTO 'dancesrecordingsmap' VALUES (2702, 7966, NULL, 3378);
INSERT INTO 'dancesrecordingsmap' VALUES (2703, 1210, NULL, 3379);
INSERT INTO 'dancesrecordingsmap' VALUES (2704, 7968, NULL, 3380);
INSERT INTO 'dancesrecordingsmap' VALUES (2705, 6915, NULL, 3381);
INSERT INTO 'dancesrecordingsmap' VALUES (2612, 633, NULL, 3271);
INSERT INTO 'dancesrecordingsmap' VALUES (4140, 1124, NULL, 5146);
INSERT INTO 'dancesrecordingsmap' VALUES (4139, 859, NULL, 5145);
INSERT INTO 'dancesrecordingsmap' VALUES (4174, 9769, NULL, 5181);
INSERT INTO 'dancesrecordingsmap' VALUES (4163, 9759, NULL, 5170);
INSERT INTO 'dancesrecordingsmap' VALUES (4165, 9761, NULL, 5172);
INSERT INTO 'dancesrecordingsmap' VALUES (2667, 652, NULL, 3327);
INSERT INTO 'dancesrecordingsmap' VALUES (2706, 7552, NULL, 1511);
INSERT INTO 'dancesrecordingsmap' VALUES (2707, 7546, NULL, 1518);
INSERT INTO 'dancesrecordingsmap' VALUES (2708, 3203, NULL, 1514);
INSERT INTO 'dancesrecordingsmap' VALUES (2709, 353, NULL, 3382);
INSERT INTO 'dancesrecordingsmap' VALUES (2710, 2353, NULL, 3383);
INSERT INTO 'dancesrecordingsmap' VALUES (2711, 5208, NULL, 3384);
INSERT INTO 'dancesrecordingsmap' VALUES (2712, 4407, NULL, 3385);
INSERT INTO 'dancesrecordingsmap' VALUES (2713, 5591, NULL, 3386);
INSERT INTO 'dancesrecordingsmap' VALUES (2714, 7546, NULL, 3388);
INSERT INTO 'dancesrecordingsmap' VALUES (2715, 1017, NULL, 3389);
INSERT INTO 'dancesrecordingsmap' VALUES (2716, 7552, NULL, 3391);
INSERT INTO 'dancesrecordingsmap' VALUES (2717, 7529, NULL, 3392);
INSERT INTO 'dancesrecordingsmap' VALUES (2718, 7055, NULL, 3393);
INSERT INTO 'dancesrecordingsmap' VALUES (2719, 1060, NULL, 3394);
INSERT INTO 'dancesrecordingsmap' VALUES (2720, 3231, NULL, 3395);
INSERT INTO 'dancesrecordingsmap' VALUES (2721, 5308, NULL, 3396);
INSERT INTO 'dancesrecordingsmap' VALUES (2722, 2879, NULL, 3397);
INSERT INTO 'dancesrecordingsmap' VALUES (2723, 584, NULL, 3398);
INSERT INTO 'dancesrecordingsmap' VALUES (2724, 4931, NULL, 3399);
INSERT INTO 'dancesrecordingsmap' VALUES (2725, 4014, NULL, 3400);
INSERT INTO 'dancesrecordingsmap' VALUES (2726, 2203, NULL, 3401);
INSERT INTO 'dancesrecordingsmap' VALUES (2727, 3980, NULL, 3402);
INSERT INTO 'dancesrecordingsmap' VALUES (2728, 4102, NULL, 3403);
INSERT INTO 'dancesrecordingsmap' VALUES (2729, 2317, NULL, 3404);
INSERT INTO 'dancesrecordingsmap' VALUES (2730, 1931, NULL, 3405);
INSERT INTO 'dancesrecordingsmap' VALUES (2731, 5525, NULL, 3406);
INSERT INTO 'dancesrecordingsmap' VALUES (2732, 1792, NULL, 3407);
INSERT INTO 'dancesrecordingsmap' VALUES (2733, 2745, NULL, 3408);
INSERT INTO 'dancesrecordingsmap' VALUES (2734, 6915, NULL, 3409);
INSERT INTO 'dancesrecordingsmap' VALUES (4176, 7245, NULL, 5183);
INSERT INTO 'dancesrecordingsmap' VALUES (4177, 3558, NULL, 5184);
INSERT INTO 'dancesrecordingsmap' VALUES (4178, 5904, NULL, 5185);
INSERT INTO 'dancesrecordingsmap' VALUES (4179, 140, NULL, 5186);
INSERT INTO 'dancesrecordingsmap' VALUES (2691, 1100, NULL, 3362);
INSERT INTO 'dancesrecordingsmap' VALUES (2648, 3246, NULL, 3307);
INSERT INTO 'dancesrecordingsmap' VALUES (4138, 358, NULL, 5144);
INSERT INTO 'dancesrecordingsmap' VALUES (2673, 1501, NULL, 3333);
INSERT INTO 'dancesrecordingsmap' VALUES (4180, 1961, NULL, 5187);
INSERT INTO 'dancesrecordingsmap' VALUES (4181, 4209, NULL, 5188);
INSERT INTO 'dancesrecordingsmap' VALUES (4182, 1578, NULL, 5189);
INSERT INTO 'dancesrecordingsmap' VALUES (4183, 1283, NULL, 5190);
INSERT INTO 'dancesrecordingsmap' VALUES (4184, 3172, NULL, 5191);
INSERT INTO 'dancesrecordingsmap' VALUES (4185, 6373, NULL, 5192);
INSERT INTO 'dancesrecordingsmap' VALUES (4186, 1582, NULL, 5193);
INSERT INTO 'dancesrecordingsmap' VALUES (4187, 9833, NULL, 847);
INSERT INTO 'dancesrecordingsmap' VALUES (4188, 9041, NULL, 3554);
INSERT INTO 'dancesrecordingsmap' VALUES (4189, 2168, NULL, 639);
INSERT INTO 'dancesrecordingsmap' VALUES (4190, 1931, NULL, 5195);
INSERT INTO 'dancesrecordingsmap' VALUES (4191, 2317, NULL, 5196);
INSERT INTO 'dancesrecordingsmap' VALUES (4192, 5525, NULL, 5197);
INSERT INTO 'dancesrecordingsmap' VALUES (4193, 4032, NULL, 5198);
INSERT INTO 'dancesrecordingsmap' VALUES (4194, 4102, NULL, 5199);
INSERT INTO 'dancesrecordingsmap' VALUES (4195, 1782, NULL, 5200);
INSERT INTO 'dancesrecordingsmap' VALUES (4196, 7546, NULL, 5201);
INSERT INTO 'dancesrecordingsmap' VALUES (4197, 2745, NULL, 5202);
INSERT INTO 'dancesrecordingsmap' VALUES (4198, 1792, NULL, 5203);
INSERT INTO 'dancesrecordingsmap' VALUES (4199, 8154, NULL, 5204);
INSERT INTO 'dancesrecordingsmap' VALUES (4200, 5239, NULL, 5205);
INSERT INTO 'dancesrecordingsmap' VALUES (4201, 1562, NULL, 5207);
INSERT INTO 'dancesrecordingsmap' VALUES (4202, 7546, NULL, 5208);
INSERT INTO 'dancesrecordingsmap' VALUES (4203, 8489, NULL, 56);
INSERT INTO 'dancesrecordingsmap' VALUES (4204, 8490, NULL, 4189);
INSERT INTO 'dancesrecordingsmap' VALUES (4205, 8562, NULL, 649);
INSERT INTO 'dancesrecordingsmap' VALUES (4207, 8493, NULL, 273);
INSERT INTO 'dancesrecordingsmap' VALUES (4172, 9767, NULL, 5179);
INSERT INTO 'dancesrecordingsmap' VALUES (4170, 9765, NULL, 5177);
INSERT INTO 'dancesrecordingsmap' VALUES (4208, 8494, NULL, 2630);
INSERT INTO 'dancesrecordingsmap' VALUES (4209, 8495, NULL, 419);
INSERT INTO 'dancesrecordingsmap' VALUES (4210, 8496, NULL, 720);
INSERT INTO 'dancesrecordingsmap' VALUES (4211, 8497, NULL, 1973);
INSERT INTO 'dancesrecordingsmap' VALUES (4213, 7742, NULL, 2107);
INSERT INTO 'dancesrecordingsmap' VALUES (4215, 6493, NULL, 1126);
INSERT INTO 'dancesrecordingsmap' VALUES (4216, 3571, NULL, 234);
INSERT INTO 'dancesrecordingsmap' VALUES (8116, 1786, NULL, 8958);
INSERT INTO 'dancesrecordingsmap' VALUES (8122, 4646, NULL, 8965);
INSERT INTO 'dancesrecordingsmap' VALUES (8138, 8744, NULL, 9019);
INSERT INTO 'dancesrecordingsmap' VALUES (8152, 11128, NULL, 9060);
INSERT INTO 'dancesrecordingsmap' VALUES (8155, 3418, NULL, 9064);
INSERT INTO 'dancesrecordingsmap' VALUES (8157, 11131, NULL, 9066);
INSERT INTO 'dancesrecordingsmap' VALUES (8159, 3165, NULL, 9068);
INSERT INTO 'dancesrecordingsmap' VALUES (8164, 8154, NULL, 9074);
INSERT INTO 'dancesrecordingsmap' VALUES (8171, 7553, NULL, 9087);
INSERT INTO 'dancesrecordingsmap' VALUES (8173, 1786, NULL, 9090);
INSERT INTO 'dancesrecordingsmap' VALUES (8175, 7147, NULL, 9095);
INSERT INTO 'dancesrecordingsmap' VALUES (8180, 2018, NULL, 9107);
INSERT INTO 'dancesrecordingsmap' VALUES (2735, 4102, NULL, 3410);
INSERT INTO 'dancesrecordingsmap' VALUES (2736, 5330, NULL, 3411);
INSERT INTO 'dancesrecordingsmap' VALUES (2737, 5330, NULL, 3412);
INSERT INTO 'dancesrecordingsmap' VALUES (2738, 4032, NULL, 3413);
INSERT INTO 'dancesrecordingsmap' VALUES (2739, 5239, NULL, 3414);
INSERT INTO 'dancesrecordingsmap' VALUES (2740, 7546, NULL, 3415);
INSERT INTO 'dancesrecordingsmap' VALUES (2741, 7546, NULL, 3416);
INSERT INTO 'dancesrecordingsmap' VALUES (2742, 1782, NULL, 3419);
INSERT INTO 'dancesrecordingsmap' VALUES (2743, 93, NULL, 783);
INSERT INTO 'dancesrecordingsmap' VALUES (2744, 7527, NULL, 783);
INSERT INTO 'dancesrecordingsmap' VALUES (2745, 7350, NULL, 783);
INSERT INTO 'dancesrecordingsmap' VALUES (2746, 7529, NULL, 2528);
INSERT INTO 'dancesrecordingsmap' VALUES (2747, 7406, NULL, 2528);
INSERT INTO 'dancesrecordingsmap' VALUES (2748, 1843, NULL, 3422);
INSERT INTO 'dancesrecordingsmap' VALUES (2749, 1543, NULL, 3423);
INSERT INTO 'dancesrecordingsmap' VALUES (2750, 5721, NULL, 3424);
INSERT INTO 'dancesrecordingsmap' VALUES (2751, 5034, NULL, 3424);
INSERT INTO 'dancesrecordingsmap' VALUES (2752, 2126, NULL, 3424);
INSERT INTO 'dancesrecordingsmap' VALUES (2753, 7531, NULL, 3425);
INSERT INTO 'dancesrecordingsmap' VALUES (2754, 7420, NULL, 3426);
INSERT INTO 'dancesrecordingsmap' VALUES (2755, 7517, NULL, 3426);
INSERT INTO 'dancesrecordingsmap' VALUES (2757, 4610, NULL, 3428);
INSERT INTO 'dancesrecordingsmap' VALUES (2758, 7042, NULL, 3428);
INSERT INTO 'dancesrecordingsmap' VALUES (2759, 904, NULL, 3428);
INSERT INTO 'dancesrecordingsmap' VALUES (2760, 3678, NULL, 3428);
INSERT INTO 'dancesrecordingsmap' VALUES (2761, 6177, NULL, 3429);
INSERT INTO 'dancesrecordingsmap' VALUES (2762, 192, NULL, 3429);
INSERT INTO 'dancesrecordingsmap' VALUES (2763, 2157, NULL, 3429);
INSERT INTO 'dancesrecordingsmap' VALUES (2764, 6217, NULL, 3429);
INSERT INTO 'dancesrecordingsmap' VALUES (2765, 6431, NULL, 3430);
INSERT INTO 'dancesrecordingsmap' VALUES (2766, 7339, NULL, 3430);
INSERT INTO 'dancesrecordingsmap' VALUES (2767, 1250, NULL, 3430);
INSERT INTO 'dancesrecordingsmap' VALUES (2768, 7474, NULL, 3431);
INSERT INTO 'dancesrecordingsmap' VALUES (2769, 7534, NULL, 3431);
INSERT INTO 'dancesrecordingsmap' VALUES (2772, 7980, NULL, 3433);
INSERT INTO 'dancesrecordingsmap' VALUES (2773, 2770, NULL, 3434);
INSERT INTO 'dancesrecordingsmap' VALUES (2774, 2941, NULL, 3434);
INSERT INTO 'dancesrecordingsmap' VALUES (2775, 7539, NULL, 3435);
INSERT INTO 'dancesrecordingsmap' VALUES (2776, 2809, NULL, 3435);
INSERT INTO 'dancesrecordingsmap' VALUES (2777, 4239, NULL, 3436);
INSERT INTO 'dancesrecordingsmap' VALUES (2779, 4555, NULL, 3438);
INSERT INTO 'dancesrecordingsmap' VALUES (2780, 2428, NULL, 3439);
INSERT INTO 'dancesrecordingsmap' VALUES (2781, 2267, NULL, 3440);
INSERT INTO 'dancesrecordingsmap' VALUES (2783, 6748, NULL, 3442);
INSERT INTO 'dancesrecordingsmap' VALUES (2784, 1931, NULL, 3443);
INSERT INTO 'dancesrecordingsmap' VALUES (2785, 5713, NULL, 3444);
INSERT INTO 'dancesrecordingsmap' VALUES (2786, 4046, NULL, 3445);
INSERT INTO 'dancesrecordingsmap' VALUES (2787, 4646, NULL, 3446);
INSERT INTO 'dancesrecordingsmap' VALUES (2788, 4803, NULL, 3447);
INSERT INTO 'dancesrecordingsmap' VALUES (2790, 373, NULL, 3449);
INSERT INTO 'dancesrecordingsmap' VALUES (2791, 4641, NULL, 3450);
INSERT INTO 'dancesrecordingsmap' VALUES (2792, 289, NULL, 3451);
INSERT INTO 'dancesrecordingsmap' VALUES (2793, 109, NULL, 3452);
INSERT INTO 'dancesrecordingsmap' VALUES (2794, 2562, NULL, 3453);
INSERT INTO 'dancesrecordingsmap' VALUES (2795, 1588, NULL, 3454);
INSERT INTO 'dancesrecordingsmap' VALUES (2796, 4491, NULL, 3455);
INSERT INTO 'dancesrecordingsmap' VALUES (2797, 2494, NULL, 3456);
INSERT INTO 'dancesrecordingsmap' VALUES (2798, 5543, NULL, 3457);
INSERT INTO 'dancesrecordingsmap' VALUES (2799, 6420, NULL, 3458);
INSERT INTO 'dancesrecordingsmap' VALUES (2800, 4759, NULL, 3459);
INSERT INTO 'dancesrecordingsmap' VALUES (2801, 5765, NULL, 3460);
INSERT INTO 'dancesrecordingsmap' VALUES (2802, 6287, NULL, 3461);
INSERT INTO 'dancesrecordingsmap' VALUES (2804, 5921, NULL, 3463);
INSERT INTO 'dancesrecordingsmap' VALUES (2805, 377, NULL, 3464);
INSERT INTO 'dancesrecordingsmap' VALUES (2806, 7147, NULL, 3465);
INSERT INTO 'dancesrecordingsmap' VALUES (2807, 5794, NULL, 3466);
INSERT INTO 'dancesrecordingsmap' VALUES (2803, 3788, NULL, 3462);
INSERT INTO 'dancesrecordingsmap' VALUES (2809, 5040, NULL, 3468);
INSERT INTO 'dancesrecordingsmap' VALUES (2810, 3038, NULL, 3469);
INSERT INTO 'dancesrecordingsmap' VALUES (2811, 2956, NULL, 3470);
INSERT INTO 'dancesrecordingsmap' VALUES (2813, 984, NULL, 3472);
INSERT INTO 'dancesrecordingsmap' VALUES (2814, 40, NULL, 3473);
INSERT INTO 'dancesrecordingsmap' VALUES (2815, 4103, NULL, 3474);
INSERT INTO 'dancesrecordingsmap' VALUES (2816, 7613, NULL, 3475);
INSERT INTO 'dancesrecordingsmap' VALUES (2817, 8729, NULL, 3476);
INSERT INTO 'dancesrecordingsmap' VALUES (2818, 8730, NULL, 3477);
INSERT INTO 'dancesrecordingsmap' VALUES (2819, 5219, NULL, 3478);
INSERT INTO 'dancesrecordingsmap' VALUES (2820, 8732, NULL, 3479);
INSERT INTO 'dancesrecordingsmap' VALUES (2821, 3418, NULL, 3480);
INSERT INTO 'dancesrecordingsmap' VALUES (2822, 4796, NULL, 3481);
INSERT INTO 'dancesrecordingsmap' VALUES (2823, 822, NULL, 3482);
INSERT INTO 'dancesrecordingsmap' VALUES (2826, 4752, NULL, 3485);
INSERT INTO 'dancesrecordingsmap' VALUES (2827, 7055, NULL, 3486);
INSERT INTO 'dancesrecordingsmap' VALUES (4218, 9994, NULL, 1095);
INSERT INTO 'dancesrecordingsmap' VALUES (4219, 9995, NULL, 615);
INSERT INTO 'dancesrecordingsmap' VALUES (4220, 9742, NULL, 3168);
INSERT INTO 'dancesrecordingsmap' VALUES (4221, 7546, NULL, 5209);
INSERT INTO 'dancesrecordingsmap' VALUES (4222, 8148, NULL, 5210);
INSERT INTO 'dancesrecordingsmap' VALUES (4223, 10048, NULL, 1121);
INSERT INTO 'dancesrecordingsmap' VALUES (4225, 1330, NULL, 3558);
INSERT INTO 'dancesrecordingsmap' VALUES (4226, 1330, NULL, 2631);
INSERT INTO 'dancesrecordingsmap' VALUES (4217, 9989, NULL, 1984);
INSERT INTO 'dancesrecordingsmap' VALUES (2782, 1473, NULL, 3441);
INSERT INTO 'dancesrecordingsmap' VALUES (4214, 6493, NULL, 2497);
INSERT INTO 'dancesrecordingsmap' VALUES (2789, 6701, NULL, 3448);
INSERT INTO 'dancesrecordingsmap' VALUES (2778, 4805, NULL, 3437);
INSERT INTO 'dancesrecordingsmap' VALUES (4224, 10049, NULL, 307);
INSERT INTO 'dancesrecordingsmap' VALUES (2824, 2453, NULL, 3483);
INSERT INTO 'dancesrecordingsmap' VALUES (4227, 1330, NULL, 2610);
INSERT INTO 'dancesrecordingsmap' VALUES (4228, 1330, NULL, 4937);
INSERT INTO 'dancesrecordingsmap' VALUES (4229, 1330, NULL, 3754);
INSERT INTO 'dancesrecordingsmap' VALUES (4230, 10115, NULL, 420);
INSERT INTO 'dancesrecordingsmap' VALUES (4231, 10116, NULL, 202);
INSERT INTO 'dancesrecordingsmap' VALUES (4232, 2717, NULL, 5213);
INSERT INTO 'dancesrecordingsmap' VALUES (4233, 9814, NULL, 5214);
INSERT INTO 'dancesrecordingsmap' VALUES (4234, 9815, NULL, 5215);
INSERT INTO 'dancesrecordingsmap' VALUES (4273, 10252, NULL, 855);
INSERT INTO 'dancesrecordingsmap' VALUES (4238, 9818, NULL, 5219);
INSERT INTO 'dancesrecordingsmap' VALUES (4239, 9022, NULL, 5220);
INSERT INTO 'dancesrecordingsmap' VALUES (4240, 9819, NULL, 5221);
INSERT INTO 'dancesrecordingsmap' VALUES (4241, 7028, NULL, 5222);
INSERT INTO 'dancesrecordingsmap' VALUES (4242, 584, NULL, 5223);
INSERT INTO 'dancesrecordingsmap' VALUES (4243, 635, NULL, 5224);
INSERT INTO 'dancesrecordingsmap' VALUES (4244, 10193, NULL, 4973);
INSERT INTO 'dancesrecordingsmap' VALUES (4245, 9564, NULL, 5231);
INSERT INTO 'dancesrecordingsmap' VALUES (4247, 10231, NULL, 5245);
INSERT INTO 'dancesrecordingsmap' VALUES (4248, 154, NULL, 5248);
INSERT INTO 'dancesrecordingsmap' VALUES (4249, 7554, NULL, 5249);
INSERT INTO 'dancesrecordingsmap' VALUES (4250, 7546, NULL, 5250);
INSERT INTO 'dancesrecordingsmap' VALUES (4251, 6943, NULL, 5252);
INSERT INTO 'dancesrecordingsmap' VALUES (4252, 8146, NULL, 5253);
INSERT INTO 'dancesrecordingsmap' VALUES (4253, 7546, NULL, 5256);
INSERT INTO 'dancesrecordingsmap' VALUES (4254, 6701, NULL, 5258);
INSERT INTO 'dancesrecordingsmap' VALUES (4255, 5731, NULL, 5263);
INSERT INTO 'dancesrecordingsmap' VALUES (4257, 10236, NULL, 2526);
INSERT INTO 'dancesrecordingsmap' VALUES (4258, 10237, NULL, 1664);
INSERT INTO 'dancesrecordingsmap' VALUES (4259, 10239, NULL, 294);
INSERT INTO 'dancesrecordingsmap' VALUES (8123, 633, NULL, 8966);
INSERT INTO 'dancesrecordingsmap' VALUES (4212, 8498, NULL, 151);
INSERT INTO 'dancesrecordingsmap' VALUES (4237, 7696, NULL, 5218);
INSERT INTO 'dancesrecordingsmap' VALUES (2812, 1783, NULL, 3471);
INSERT INTO 'dancesrecordingsmap' VALUES (4246, 2679, NULL, 5235);
INSERT INTO 'dancesrecordingsmap' VALUES (2825, 2821, NULL, 3484);
INSERT INTO 'dancesrecordingsmap' VALUES (8160, 2924, NULL, 9069);
INSERT INTO 'dancesrecordingsmap' VALUES (8165, 14639, NULL, 9075);
INSERT INTO 'dancesrecordingsmap' VALUES (8176, 6048, NULL, 9100);
INSERT INTO 'dancesrecordingsmap' VALUES (8181, 12490, NULL, 9109);
INSERT INTO 'dancesrecordingsmap' VALUES (8182, 14641, NULL, 9111);
INSERT INTO 'dancesrecordingsmap' VALUES (8184, 8154, NULL, 9116);
INSERT INTO 'dancesrecordingsmap' VALUES (8185, 8153, NULL, 9118);
INSERT INTO 'dancesrecordingsmap' VALUES (8187, 549, NULL, 9126);
INSERT INTO 'dancesrecordingsmap' VALUES (8190, 7546, NULL, 9131);
INSERT INTO 'dancesrecordingsmap' VALUES (8191, 8142, NULL, 9134);
INSERT INTO 'dancesrecordingsmap' VALUES (8192, 1792, NULL, 9137);
INSERT INTO 'dancesrecordingsmap' VALUES (8197, 3672, NULL, 9144);
INSERT INTO 'dancesrecordingsmap' VALUES (8198, 6915, NULL, 9149);
INSERT INTO 'dancesrecordingsmap' VALUES (8200, 7553, NULL, 9195);
INSERT INTO 'dancesrecordingsmap' VALUES (8205, 8143, NULL, 9202);
INSERT INTO 'dancesrecordingsmap' VALUES (8212, 2521, NULL, 9216);
INSERT INTO 'dancesrecordingsmap' VALUES (8213, 7553, NULL, 9218);
INSERT INTO 'dancesrecordingsmap' VALUES (8214, 2260, NULL, 9226);
INSERT INTO 'dancesrecordingsmap' VALUES (8217, 7552, NULL, 9231);
INSERT INTO 'dancesrecordingsmap' VALUES (8220, 8749, NULL, 9236);
INSERT INTO 'dancesrecordingsmap' VALUES (8221, 7548, NULL, 9239);
INSERT INTO 'dancesrecordingsmap' VALUES (2828, 2367, NULL, 3487);
INSERT INTO 'dancesrecordingsmap' VALUES (2829, 6224, NULL, 3488);
INSERT INTO 'dancesrecordingsmap' VALUES (2830, 7574, NULL, 3505);
INSERT INTO 'dancesrecordingsmap' VALUES (2831, 8142, NULL, 3506);
INSERT INTO 'dancesrecordingsmap' VALUES (2832, 8143, NULL, 3507);
INSERT INTO 'dancesrecordingsmap' VALUES (2833, 7553, NULL, 3508);
INSERT INTO 'dancesrecordingsmap' VALUES (2834, 8144, NULL, 3509);
INSERT INTO 'dancesrecordingsmap' VALUES (2835, 8145, NULL, 3510);
INSERT INTO 'dancesrecordingsmap' VALUES (2836, 8146, NULL, 3511);
INSERT INTO 'dancesrecordingsmap' VALUES (8117, 1501, NULL, 8959);
INSERT INTO 'dancesrecordingsmap' VALUES (2756, 1499, NULL, 3427);
INSERT INTO 'dancesrecordingsmap' VALUES (2837, 8147, NULL, 3512);
INSERT INTO 'dancesrecordingsmap' VALUES (2838, 7546, NULL, 3513);
INSERT INTO 'dancesrecordingsmap' VALUES (2839, 8148, NULL, 3514);
INSERT INTO 'dancesrecordingsmap' VALUES (2840, 7548, NULL, 3515);
INSERT INTO 'dancesrecordingsmap' VALUES (2841, 8149, NULL, 3516);
INSERT INTO 'dancesrecordingsmap' VALUES (2842, 8150, NULL, 3517);
INSERT INTO 'dancesrecordingsmap' VALUES (2843, 8151, NULL, 3518);
INSERT INTO 'dancesrecordingsmap' VALUES (2844, 7552, NULL, 3519);
INSERT INTO 'dancesrecordingsmap' VALUES (2845, 8152, NULL, 3520);
INSERT INTO 'dancesrecordingsmap' VALUES (2846, 8153, NULL, 3521);
INSERT INTO 'dancesrecordingsmap' VALUES (2847, 7554, NULL, 3522);
INSERT INTO 'dancesrecordingsmap' VALUES (2848, 8154, NULL, 3523);
INSERT INTO 'dancesrecordingsmap' VALUES (2849, 8155, NULL, 3524);
INSERT INTO 'dancesrecordingsmap' VALUES (2850, 8156, NULL, 3524);
INSERT INTO 'dancesrecordingsmap' VALUES (2851, 8157, NULL, 3525);
INSERT INTO 'dancesrecordingsmap' VALUES (2852, 8158, NULL, 3526);
INSERT INTO 'dancesrecordingsmap' VALUES (2853, 8159, NULL, 3527);
INSERT INTO 'dancesrecordingsmap' VALUES (2854, 8160, NULL, 3528);
INSERT INTO 'dancesrecordingsmap' VALUES (2855, 8162, NULL, 3529);
INSERT INTO 'dancesrecordingsmap' VALUES (2856, 5693, NULL, 3530);
INSERT INTO 'dancesrecordingsmap' VALUES (2857, 1562, NULL, 3532);
INSERT INTO 'dancesrecordingsmap' VALUES (2858, 1931, NULL, 3533);
INSERT INTO 'dancesrecordingsmap' VALUES (2859, 2317, NULL, 3534);
INSERT INTO 'dancesrecordingsmap' VALUES (2860, 2745, NULL, 3535);
INSERT INTO 'dancesrecordingsmap' VALUES (2861, 6233, NULL, 3536);
INSERT INTO 'dancesrecordingsmap' VALUES (2862, 1782, NULL, 3537);
INSERT INTO 'dancesrecordingsmap' VALUES (2863, 4032, NULL, 3538);
INSERT INTO 'dancesrecordingsmap' VALUES (2864, 5525, NULL, 3539);
INSERT INTO 'dancesrecordingsmap' VALUES (2865, 1792, NULL, 3540);
INSERT INTO 'dancesrecordingsmap' VALUES (2866, 5964, NULL, 3541);
INSERT INTO 'dancesrecordingsmap' VALUES (2867, 6915, NULL, 3542);
INSERT INTO 'dancesrecordingsmap' VALUES (2868, 4102, NULL, 3543);
INSERT INTO 'dancesrecordingsmap' VALUES (2869, 5330, NULL, 3544);
INSERT INTO 'dancesrecordingsmap' VALUES (2870, 5239, NULL, 3545);
INSERT INTO 'dancesrecordingsmap' VALUES (2871, 1841, NULL, 3546);
INSERT INTO 'dancesrecordingsmap' VALUES (2873, 2979, NULL, 3548);
INSERT INTO 'dancesrecordingsmap' VALUES (2874, 1625, NULL, 3549);
INSERT INTO 'dancesrecordingsmap' VALUES (2875, 7204, NULL, 3550);
INSERT INTO 'dancesrecordingsmap' VALUES (2876, 7282, NULL, 3552);
INSERT INTO 'dancesrecordingsmap' VALUES (2877, 314, NULL, 3553);
INSERT INTO 'dancesrecordingsmap' VALUES (2878, 6205, NULL, 3554);
INSERT INTO 'dancesrecordingsmap' VALUES (2879, 3783, NULL, 3555);
INSERT INTO 'dancesrecordingsmap' VALUES (2880, 6995, NULL, 3558);
INSERT INTO 'dancesrecordingsmap' VALUES (2881, 5109, NULL, 3559);
INSERT INTO 'dancesrecordingsmap' VALUES (2882, 7188, NULL, 3560);
INSERT INTO 'dancesrecordingsmap' VALUES (2883, 312, NULL, 3561);
INSERT INTO 'dancesrecordingsmap' VALUES (2884, 1927, NULL, 2004);
INSERT INTO 'dancesrecordingsmap' VALUES (2885, 8737, NULL, 3556);
INSERT INTO 'dancesrecordingsmap' VALUES (2886, 183, NULL, 3557);
INSERT INTO 'dancesrecordingsmap' VALUES (2887, 950, NULL, 3562);
INSERT INTO 'dancesrecordingsmap' VALUES (2888, 4726, NULL, 3563);
INSERT INTO 'dancesrecordingsmap' VALUES (2889, 3323, NULL, 3564);
INSERT INTO 'dancesrecordingsmap' VALUES (2890, 2189, NULL, 3565);
INSERT INTO 'dancesrecordingsmap' VALUES (2891, 1777, NULL, 3566);
INSERT INTO 'dancesrecordingsmap' VALUES (2892, 1274, NULL, 3567);
INSERT INTO 'dancesrecordingsmap' VALUES (2893, 610, NULL, 3568);
INSERT INTO 'dancesrecordingsmap' VALUES (2894, 2428, NULL, 3569);
INSERT INTO 'dancesrecordingsmap' VALUES (2895, 6957, NULL, 3570);
INSERT INTO 'dancesrecordingsmap' VALUES (2896, 2593, NULL, 3571);
INSERT INTO 'dancesrecordingsmap' VALUES (2897, 4086, NULL, 3572);
INSERT INTO 'dancesrecordingsmap' VALUES (2898, 6748, NULL, 3573);
INSERT INTO 'dancesrecordingsmap' VALUES (2899, 4293, NULL, 3574);
INSERT INTO 'dancesrecordingsmap' VALUES (2900, 5362, NULL, 3575);
INSERT INTO 'dancesrecordingsmap' VALUES (2901, 3342, NULL, 3576);
INSERT INTO 'dancesrecordingsmap' VALUES (2902, 5462, NULL, 3577);
INSERT INTO 'dancesrecordingsmap' VALUES (2903, 654, NULL, 3578);
INSERT INTO 'dancesrecordingsmap' VALUES (2904, 5713, NULL, 3579);
INSERT INTO 'dancesrecordingsmap' VALUES (2905, 5982, NULL, 3580);
INSERT INTO 'dancesrecordingsmap' VALUES (2906, 3558, NULL, 3581);
INSERT INTO 'dancesrecordingsmap' VALUES (2907, 5741, NULL, 3582);
INSERT INTO 'dancesrecordingsmap' VALUES (2908, 445, NULL, 3583);
INSERT INTO 'dancesrecordingsmap' VALUES (2909, 584, NULL, 3584);
INSERT INTO 'dancesrecordingsmap' VALUES (2910, 902, NULL, 3585);
INSERT INTO 'dancesrecordingsmap' VALUES (2911, 5528, NULL, 3586);
INSERT INTO 'dancesrecordingsmap' VALUES (2912, 55, NULL, 3587);
INSERT INTO 'dancesrecordingsmap' VALUES (2913, 4374, NULL, 3588);
INSERT INTO 'dancesrecordingsmap' VALUES (2914, 2042, NULL, 3589);
INSERT INTO 'dancesrecordingsmap' VALUES (2915, 5065, NULL, 3590);
INSERT INTO 'dancesrecordingsmap' VALUES (2917, 3625, NULL, 3592);
INSERT INTO 'dancesrecordingsmap' VALUES (2918, 6373, NULL, 3593);
INSERT INTO 'dancesrecordingsmap' VALUES (2919, 2349, NULL, 3594);
INSERT INTO 'dancesrecordingsmap' VALUES (4260, 10239, NULL, 4965);
INSERT INTO 'dancesrecordingsmap' VALUES (4261, 10238, NULL, 2974);
INSERT INTO 'dancesrecordingsmap' VALUES (4262, 10240, NULL, 1126);
INSERT INTO 'dancesrecordingsmap' VALUES (4263, 10241, NULL, 4962);
INSERT INTO 'dancesrecordingsmap' VALUES (4264, 10242, NULL, 2529);
INSERT INTO 'dancesrecordingsmap' VALUES (4265, 10243, NULL, 4963);
INSERT INTO 'dancesrecordingsmap' VALUES (4266, 10244, NULL, 4960);
INSERT INTO 'dancesrecordingsmap' VALUES (4267, 10245, NULL, 1231);
INSERT INTO 'dancesrecordingsmap' VALUES (4268, 10246, NULL, 2655);
INSERT INTO 'dancesrecordingsmap' VALUES (4269, 10247, NULL, 819);
INSERT INTO 'dancesrecordingsmap' VALUES (4272, 10251, NULL, 846);
INSERT INTO 'dancesrecordingsmap' VALUES (4275, 10254, NULL, 853);
INSERT INTO 'dancesrecordingsmap' VALUES (4276, 10255, NULL, 2170);
INSERT INTO 'dancesrecordingsmap' VALUES (4277, 10255, NULL, 1011);
INSERT INTO 'dancesrecordingsmap' VALUES (4278, 10256, NULL, 4618);
INSERT INTO 'dancesrecordingsmap' VALUES (4279, 10257, NULL, 1138);
INSERT INTO 'dancesrecordingsmap' VALUES (4280, 10258, NULL, 71);
INSERT INTO 'dancesrecordingsmap' VALUES (4281, 10259, NULL, 5192);
INSERT INTO 'dancesrecordingsmap' VALUES (4283, 10261, NULL, 1813);
INSERT INTO 'dancesrecordingsmap' VALUES (4285, 10263, NULL, 4970);
INSERT INTO 'dancesrecordingsmap' VALUES (4287, 10265, NULL, 4960);
INSERT INTO 'dancesrecordingsmap' VALUES (4289, 10269, NULL, 3473);
INSERT INTO 'dancesrecordingsmap' VALUES (4290, 10270, NULL, 5029);
INSERT INTO 'dancesrecordingsmap' VALUES (4292, 10272, NULL, 4694);
INSERT INTO 'dancesrecordingsmap' VALUES (4294, 10279, NULL, 2363);
INSERT INTO 'dancesrecordingsmap' VALUES (4295, 10278, NULL, 1413);
INSERT INTO 'dancesrecordingsmap' VALUES (4296, 10281, NULL, 1007);
INSERT INTO 'dancesrecordingsmap' VALUES (4297, 1647, NULL, 5264);
INSERT INTO 'dancesrecordingsmap' VALUES (4293, 10276, NULL, 1489);
INSERT INTO 'dancesrecordingsmap' VALUES (2916, 3577, NULL, 3591);
INSERT INTO 'dancesrecordingsmap' VALUES (4256, 10233, NULL, 307);
INSERT INTO 'dancesrecordingsmap' VALUES (4298, 4561, NULL, 5265);
INSERT INTO 'dancesrecordingsmap' VALUES (4299, 3979, NULL, 5266);
INSERT INTO 'dancesrecordingsmap' VALUES (4300, 56, NULL, 5267);
INSERT INTO 'dancesrecordingsmap' VALUES (4302, 9855, NULL, 5269);
INSERT INTO 'dancesrecordingsmap' VALUES (8124, 743, NULL, 8967);
INSERT INTO 'dancesrecordingsmap' VALUES (8177, 6048, NULL, 9101);
INSERT INTO 'dancesrecordingsmap' VALUES (8183, 3637, NULL, 9113);
INSERT INTO 'dancesrecordingsmap' VALUES (8186, 8146, NULL, 9121);
INSERT INTO 'dancesrecordingsmap' VALUES (8188, 8143, NULL, 9127);
INSERT INTO 'dancesrecordingsmap' VALUES (8193, 7548, NULL, 9138);
INSERT INTO 'dancesrecordingsmap' VALUES (8199, 7548, NULL, 9150);
INSERT INTO 'dancesrecordingsmap' VALUES (8201, 7546, NULL, 9196);
INSERT INTO 'dancesrecordingsmap' VALUES (8206, 5239, NULL, 9203);
INSERT INTO 'dancesrecordingsmap' VALUES (8215, 1792, NULL, 9227);
INSERT INTO 'dancesrecordingsmap' VALUES (8218, 5926, NULL, 9232);
INSERT INTO 'dancesrecordingsmap' VALUES (8222, 8146, NULL, 9241);
INSERT INTO 'dancesrecordingsmap' VALUES (8225, 7546, NULL, 9248);
INSERT INTO 'dancesrecordingsmap' VALUES (2920, 4935, NULL, 3595);
INSERT INTO 'dancesrecordingsmap' VALUES (2921, 7217, NULL, 3596);
INSERT INTO 'dancesrecordingsmap' VALUES (2922, 7548, NULL, 3599);
INSERT INTO 'dancesrecordingsmap' VALUES (2923, 8146, NULL, 3601);
INSERT INTO 'dancesrecordingsmap' VALUES (2924, 713, NULL, 3546);
INSERT INTO 'dancesrecordingsmap' VALUES (2925, 1382, NULL, 941);
INSERT INTO 'dancesrecordingsmap' VALUES (2926, 2242, NULL, 621);
INSERT INTO 'dancesrecordingsmap' VALUES (2928, 2934, NULL, 3235);
INSERT INTO 'dancesrecordingsmap' VALUES (2929, 8087, NULL, 3235);
INSERT INTO 'dancesrecordingsmap' VALUES (2930, 5065, NULL, 3611);
INSERT INTO 'dancesrecordingsmap' VALUES (2931, 2153, NULL, 3612);
INSERT INTO 'dancesrecordingsmap' VALUES (2932, 1323, NULL, 3613);
INSERT INTO 'dancesrecordingsmap' VALUES (2933, 410, NULL, 3614);
INSERT INTO 'dancesrecordingsmap' VALUES (2934, 1864, NULL, 3615);
INSERT INTO 'dancesrecordingsmap' VALUES (2936, 4864, NULL, 3617);
INSERT INTO 'dancesrecordingsmap' VALUES (4286, 10264, NULL, 845);
INSERT INTO 'dancesrecordingsmap' VALUES (2935, 5701, NULL, 3616);
INSERT INTO 'dancesrecordingsmap' VALUES (2927, 8154, NULL, 2678);
INSERT INTO 'dancesrecordingsmap' VALUES (4282, 10260, NULL, 1819);
INSERT INTO 'dancesrecordingsmap' VALUES (4284, 10262, NULL, 1820);
INSERT INTO 'dancesrecordingsmap' VALUES (2937, 7055, NULL, 3620);
INSERT INTO 'dancesrecordingsmap' VALUES (2938, 2801, NULL, 728);
INSERT INTO 'dancesrecordingsmap' VALUES (2939, 591, NULL, 728);
INSERT INTO 'dancesrecordingsmap' VALUES (2940, 2981, NULL, 1574);
INSERT INTO 'dancesrecordingsmap' VALUES (2942, 8025, NULL, 2284);
INSERT INTO 'dancesrecordingsmap' VALUES (2943, 2601, NULL, 2284);
INSERT INTO 'dancesrecordingsmap' VALUES (2944, 2236, NULL, 1730);
INSERT INTO 'dancesrecordingsmap' VALUES (9104, 17320, NULL, 10165);
INSERT INTO 'dancesrecordingsmap' VALUES (9105, 6318, NULL, 10159);
INSERT INTO 'dancesrecordingsmap' VALUES (8219, 3561, NULL, 9233);
INSERT INTO 'dancesrecordingsmap' VALUES (2956, 4198, NULL, 1531);
INSERT INTO 'dancesrecordingsmap' VALUES (2957, 6175, NULL, 1531);
INSERT INTO 'dancesrecordingsmap' VALUES (2958, 6385, NULL, 1531);
INSERT INTO 'dancesrecordingsmap' VALUES (2959, 6331, NULL, 1525);
INSERT INTO 'dancesrecordingsmap' VALUES (2960, 7546, NULL, 3623);
INSERT INTO 'dancesrecordingsmap' VALUES (2961, 7546, NULL, 3624);
INSERT INTO 'dancesrecordingsmap' VALUES (2962, 3129, NULL, 1931);
INSERT INTO 'dancesrecordingsmap' VALUES (2963, 2242, NULL, 2461);
INSERT INTO 'dancesrecordingsmap' VALUES (2964, 4102, NULL, 3627);
INSERT INTO 'dancesrecordingsmap' VALUES (2965, 8146, NULL, 3630);
INSERT INTO 'dancesrecordingsmap' VALUES (2966, 5239, NULL, 3631);
INSERT INTO 'dancesrecordingsmap' VALUES (2967, 3834, NULL, 3632);
INSERT INTO 'dancesrecordingsmap' VALUES (2968, 5963, NULL, 3633);
INSERT INTO 'dancesrecordingsmap' VALUES (2969, 7546, NULL, 3636);
INSERT INTO 'dancesrecordingsmap' VALUES (2970, 6712, NULL, 3639);
INSERT INTO 'dancesrecordingsmap' VALUES (2971, 8142, NULL, 3640);
INSERT INTO 'dancesrecordingsmap' VALUES (2972, 7546, NULL, 3643);
INSERT INTO 'dancesrecordingsmap' VALUES (2973, 4227, NULL, 3646);
INSERT INTO 'dancesrecordingsmap' VALUES (2975, 1562, NULL, 3657);
INSERT INTO 'dancesrecordingsmap' VALUES (2976, 8144, NULL, 3659);
INSERT INTO 'dancesrecordingsmap' VALUES (2977, 7546, NULL, 3660);
INSERT INTO 'dancesrecordingsmap' VALUES (2978, 7553, NULL, 3662);
INSERT INTO 'dancesrecordingsmap' VALUES (4301, 5222, NULL, 5268);
INSERT INTO 'dancesrecordingsmap' VALUES (4270, 10248, NULL, 829);
INSERT INTO 'dancesrecordingsmap' VALUES (4291, 10271, NULL, 4961);
INSERT INTO 'dancesrecordingsmap' VALUES (2979, 5525, NULL, 3663);
INSERT INTO 'dancesrecordingsmap' VALUES (2980, 2367, NULL, 3664);
INSERT INTO 'dancesrecordingsmap' VALUES (2981, 1792, NULL, 3665);
INSERT INTO 'dancesrecordingsmap' VALUES (2982, 1792, NULL, 3680);
INSERT INTO 'dancesrecordingsmap' VALUES (2983, 2747, NULL, 3685);
INSERT INTO 'dancesrecordingsmap' VALUES (2984, 7546, NULL, 3686);
INSERT INTO 'dancesrecordingsmap' VALUES (2985, 1834, NULL, 3690);
INSERT INTO 'dancesrecordingsmap' VALUES (2986, 8161, NULL, 3692);
INSERT INTO 'dancesrecordingsmap' VALUES (2987, 353, NULL, 3693);
INSERT INTO 'dancesrecordingsmap' VALUES (2988, 6915, NULL, 3695);
INSERT INTO 'dancesrecordingsmap' VALUES (2989, 1562, NULL, 3696);
INSERT INTO 'dancesrecordingsmap' VALUES (2990, 8148, NULL, 3697);
INSERT INTO 'dancesrecordingsmap' VALUES (2991, 5741, NULL, 3698);
INSERT INTO 'dancesrecordingsmap' VALUES (2992, 7546, NULL, 3700);
INSERT INTO 'dancesrecordingsmap' VALUES (2993, 2747, NULL, 3702);
INSERT INTO 'dancesrecordingsmap' VALUES (2994, 743, NULL, 2287);
INSERT INTO 'dancesrecordingsmap' VALUES (2997, 4633, NULL, 3705);
INSERT INTO 'dancesrecordingsmap' VALUES (2998, 7552, NULL, 3721);
INSERT INTO 'dancesrecordingsmap' VALUES (2999, 7555, NULL, 3723);
INSERT INTO 'dancesrecordingsmap' VALUES (3000, 7546, NULL, 3724);
INSERT INTO 'dancesrecordingsmap' VALUES (3001, 8144, NULL, 3725);
INSERT INTO 'dancesrecordingsmap' VALUES (3002, 7552, NULL, 3738);
INSERT INTO 'dancesrecordingsmap' VALUES (3003, 2812, NULL, 3740);
INSERT INTO 'dancesrecordingsmap' VALUES (3004, 2068, NULL, 3741);
INSERT INTO 'dancesrecordingsmap' VALUES (3005, 8154, NULL, 3746);
INSERT INTO 'dancesrecordingsmap' VALUES (3006, 3743, NULL, 2567);
INSERT INTO 'dancesrecordingsmap' VALUES (3007, 4325, NULL, 3749);
INSERT INTO 'dancesrecordingsmap' VALUES (3008, 4646, NULL, 3750);
INSERT INTO 'dancesrecordingsmap' VALUES (3009, 5208, NULL, 3751);
INSERT INTO 'dancesrecordingsmap' VALUES (3010, 2745, NULL, 3753);
INSERT INTO 'dancesrecordingsmap' VALUES (3011, 6995, NULL, 3754);
INSERT INTO 'dancesrecordingsmap' VALUES (3012, 5207, NULL, 3755);
INSERT INTO 'dancesrecordingsmap' VALUES (3013, 2925, NULL, 3756);
INSERT INTO 'dancesrecordingsmap' VALUES (3014, 5591, NULL, 3757);
INSERT INTO 'dancesrecordingsmap' VALUES (3015, 4827, NULL, 3759);
INSERT INTO 'dancesrecordingsmap' VALUES (3016, 3537, NULL, 3760);
INSERT INTO 'dancesrecordingsmap' VALUES (3017, 2495, NULL, 3761);
INSERT INTO 'dancesrecordingsmap' VALUES (3018, 7546, NULL, 3762);
INSERT INTO 'dancesrecordingsmap' VALUES (3027, 2389, NULL, 3780);
INSERT INTO 'dancesrecordingsmap' VALUES (3028, 2661, NULL, 3781);
INSERT INTO 'dancesrecordingsmap' VALUES (3029, 1799, NULL, 3783);
INSERT INTO 'dancesrecordingsmap' VALUES (3030, 7553, NULL, 3784);
INSERT INTO 'dancesrecordingsmap' VALUES (3031, 8146, NULL, 3785);
INSERT INTO 'dancesrecordingsmap' VALUES (3032, 7546, NULL, 3787);
INSERT INTO 'dancesrecordingsmap' VALUES (3033, 43, NULL, 3789);
INSERT INTO 'dancesrecordingsmap' VALUES (3034, 8160, NULL, 3791);
INSERT INTO 'dancesrecordingsmap' VALUES (3035, 4032, NULL, 3792);
INSERT INTO 'dancesrecordingsmap' VALUES (3036, 5963, NULL, 3795);
INSERT INTO 'dancesrecordingsmap' VALUES (3037, 5239, NULL, 3798);
INSERT INTO 'dancesrecordingsmap' VALUES (3038, 4641, NULL, 3799);
INSERT INTO 'dancesrecordingsmap' VALUES (3039, 5591, NULL, 3802);
INSERT INTO 'dancesrecordingsmap' VALUES (3040, 5239, NULL, 3803);
INSERT INTO 'dancesrecordingsmap' VALUES (3041, 7546, NULL, 3804);
INSERT INTO 'dancesrecordingsmap' VALUES (3042, 7574, NULL, 3805);
INSERT INTO 'dancesrecordingsmap' VALUES (3043, 3834, NULL, 3806);
INSERT INTO 'dancesrecordingsmap' VALUES (3044, 588, NULL, 3809);
INSERT INTO 'dancesrecordingsmap' VALUES (3045, 3152, NULL, 3811);
INSERT INTO 'dancesrecordingsmap' VALUES (3046, 7548, NULL, 3813);
INSERT INTO 'dancesrecordingsmap' VALUES (3047, 2747, NULL, 3814);
INSERT INTO 'dancesrecordingsmap' VALUES (3048, 743, NULL, 3815);
INSERT INTO 'dancesrecordingsmap' VALUES (3049, 3246, NULL, 3816);
INSERT INTO 'dancesrecordingsmap' VALUES (8125, 3172, NULL, 8968);
INSERT INTO 'dancesrecordingsmap' VALUES (8189, 5330, NULL, 9130);
INSERT INTO 'dancesrecordingsmap' VALUES (8194, 1786, NULL, 9140);
INSERT INTO 'dancesrecordingsmap' VALUES (8202, 11890, NULL, 9197);
INSERT INTO 'dancesrecordingsmap' VALUES (8216, 7553, NULL, 9228);
INSERT INTO 'dancesrecordingsmap' VALUES (8223, 1931, NULL, 9242);
INSERT INTO 'dancesrecordingsmap' VALUES (8226, 2956, NULL, 9252);
INSERT INTO 'dancesrecordingsmap' VALUES (8227, 3526, NULL, 9256);
INSERT INTO 'dancesrecordingsmap' VALUES (8231, 8747, NULL, 9262);
INSERT INTO 'dancesrecordingsmap' VALUES (8233, 8747, NULL, 9264);
INSERT INTO 'dancesrecordingsmap' VALUES (8234, 8748, NULL, 9265);
INSERT INTO 'dancesrecordingsmap' VALUES (8235, 8748, NULL, 9266);
INSERT INTO 'dancesrecordingsmap' VALUES (8246, 14305, NULL, 9279);
INSERT INTO 'dancesrecordingsmap' VALUES (8252, 3526, NULL, 9289);
INSERT INTO 'dancesrecordingsmap' VALUES (8253, 3528, NULL, 9292);
INSERT INTO 'dancesrecordingsmap' VALUES (8254, 5591, NULL, 9295);
INSERT INTO 'dancesrecordingsmap' VALUES (8255, 14679, NULL, 9298);
INSERT INTO 'dancesrecordingsmap' VALUES (8257, 6048, NULL, 9308);
INSERT INTO 'dancesrecordingsmap' VALUES (3050, 4633, NULL, 3817);
INSERT INTO 'dancesrecordingsmap' VALUES (3051, 1210, NULL, 3818);
INSERT INTO 'dancesrecordingsmap' VALUES (3052, 1478, NULL, 3819);
INSERT INTO 'dancesrecordingsmap' VALUES (3053, 1562, NULL, 3820);
INSERT INTO 'dancesrecordingsmap' VALUES (3054, 1931, NULL, 3821);
INSERT INTO 'dancesrecordingsmap' VALUES (3055, 5497, NULL, 3822);
INSERT INTO 'dancesrecordingsmap' VALUES (3056, 654, NULL, 3823);
INSERT INTO 'dancesrecordingsmap' VALUES (3057, 723, NULL, 3824);
INSERT INTO 'dancesrecordingsmap' VALUES (3058, 1348, NULL, 2548);
INSERT INTO 'dancesrecordingsmap' VALUES (3059, 4103, NULL, 3825);
INSERT INTO 'dancesrecordingsmap' VALUES (3060, 2250, NULL, 3826);
INSERT INTO 'dancesrecordingsmap' VALUES (3061, 4431, NULL, 3828);
INSERT INTO 'dancesrecordingsmap' VALUES (3062, 2956, NULL, 3830);
INSERT INTO 'dancesrecordingsmap' VALUES (3063, 522, NULL, 3831);
INSERT INTO 'dancesrecordingsmap' VALUES (3064, 7147, NULL, 3832);
INSERT INTO 'dancesrecordingsmap' VALUES (3065, 3588, NULL, 3833);
INSERT INTO 'dancesrecordingsmap' VALUES (3066, 5921, NULL, 3834);
INSERT INTO 'dancesrecordingsmap' VALUES (2948, 233, NULL, 1985);
INSERT INTO 'dancesrecordingsmap' VALUES (2949, 4623, NULL, 1985);
INSERT INTO 'dancesrecordingsmap' VALUES (2950, 2465, NULL, 1988);
INSERT INTO 'dancesrecordingsmap' VALUES (2951, 2089, NULL, 1989);
INSERT INTO 'dancesrecordingsmap' VALUES (2952, 3885, NULL, 1989);
INSERT INTO 'dancesrecordingsmap' VALUES (2953, 6213, NULL, 1989);
INSERT INTO 'dancesrecordingsmap' VALUES (2954, 3251, NULL, 1991);
INSERT INTO 'dancesrecordingsmap' VALUES (2955, 3501, NULL, 1991);
INSERT INTO 'dancesrecordingsmap' VALUES (3067, 1786, NULL, 3835);
INSERT INTO 'dancesrecordingsmap' VALUES (3068, 743, NULL, 3836);
INSERT INTO 'dancesrecordingsmap' VALUES (3069, 4239, NULL, 3837);
INSERT INTO 'dancesrecordingsmap' VALUES (3070, 2349, NULL, 3838);
INSERT INTO 'dancesrecordingsmap' VALUES (3071, 7546, NULL, 3842);
INSERT INTO 'dancesrecordingsmap' VALUES (3072, 7546, NULL, 3843);
INSERT INTO 'dancesrecordingsmap' VALUES (3073, 3834, NULL, 3847);
INSERT INTO 'dancesrecordingsmap' VALUES (3074, 3701, NULL, 3848);
INSERT INTO 'dancesrecordingsmap' VALUES (3075, 6711, NULL, 3850);
INSERT INTO 'dancesrecordingsmap' VALUES (3076, 5641, NULL, 3851);
INSERT INTO 'dancesrecordingsmap' VALUES (3077, 3735, NULL, 3852);
INSERT INTO 'dancesrecordingsmap' VALUES (3078, 3528, NULL, 3853);
INSERT INTO 'dancesrecordingsmap' VALUES (3079, 7791, NULL, 3855);
INSERT INTO 'dancesrecordingsmap' VALUES (3080, 4051, NULL, 3856);
INSERT INTO 'dancesrecordingsmap' VALUES (3081, 4633, NULL, 3861);
INSERT INTO 'dancesrecordingsmap' VALUES (3082, 6915, NULL, 3862);
INSERT INTO 'dancesrecordingsmap' VALUES (3083, 7546, NULL, 3867);
INSERT INTO 'dancesrecordingsmap' VALUES (3084, 4641, NULL, 3868);
INSERT INTO 'dancesrecordingsmap' VALUES (3085, 7548, NULL, 3869);
INSERT INTO 'dancesrecordingsmap' VALUES (3086, 1562, NULL, 3870);
INSERT INTO 'dancesrecordingsmap' VALUES (3087, 3672, NULL, 3871);
INSERT INTO 'dancesrecordingsmap' VALUES (3088, 7548, NULL, 3874);
INSERT INTO 'dancesrecordingsmap' VALUES (3089, 2250, NULL, 3875);
INSERT INTO 'dancesrecordingsmap' VALUES (3090, 5157, NULL, 3877);
INSERT INTO 'dancesrecordingsmap' VALUES (3091, 5920, NULL, 3877);
INSERT INTO 'dancesrecordingsmap' VALUES (3092, 2147, NULL, 3879);
INSERT INTO 'dancesrecordingsmap' VALUES (3093, 3537, NULL, 3879);
INSERT INTO 'dancesrecordingsmap' VALUES (3094, 7546, NULL, 3880);
INSERT INTO 'dancesrecordingsmap' VALUES (3096, 769, NULL, 3884);
INSERT INTO 'dancesrecordingsmap' VALUES (3097, 4015, NULL, 3885);
INSERT INTO 'dancesrecordingsmap' VALUES (3098, 848, NULL, 3886);
INSERT INTO 'dancesrecordingsmap' VALUES (3099, 6037, NULL, 3887);
INSERT INTO 'dancesrecordingsmap' VALUES (3100, 3941, NULL, 3892);
INSERT INTO 'dancesrecordingsmap' VALUES (3101, 8146, NULL, 3893);
INSERT INTO 'dancesrecordingsmap' VALUES (3102, 1799, NULL, 3897);
INSERT INTO 'dancesrecordingsmap' VALUES (3103, 6712, NULL, 3899);
INSERT INTO 'dancesrecordingsmap' VALUES (3104, 541, NULL, 3908);
INSERT INTO 'dancesrecordingsmap' VALUES (3105, 7546, NULL, 3084);
INSERT INTO 'dancesrecordingsmap' VALUES (3106, 1931, NULL, 3087);
INSERT INTO 'dancesrecordingsmap' VALUES (3107, 2317, NULL, 3793);
INSERT INTO 'dancesrecordingsmap' VALUES (3108, 4032, NULL, 3796);
INSERT INTO 'dancesrecordingsmap' VALUES (3109, 4585, NULL, 3797);
INSERT INTO 'dancesrecordingsmap' VALUES (3110, 4584, NULL, 3797);
INSERT INTO 'dancesrecordingsmap' VALUES (3111, 2434, NULL, 3797);
INSERT INTO 'dancesrecordingsmap' VALUES (3112, 7553, NULL, 3858);
INSERT INTO 'dancesrecordingsmap' VALUES (3113, 1792, NULL, 3860);
INSERT INTO 'dancesrecordingsmap' VALUES (3114, 1792, NULL, 3864);
INSERT INTO 'dancesrecordingsmap' VALUES (3115, 6233, NULL, 3866);
INSERT INTO 'dancesrecordingsmap' VALUES (3116, 6233, NULL, 3883);
INSERT INTO 'dancesrecordingsmap' VALUES (3117, 4102, NULL, 3912);
INSERT INTO 'dancesrecordingsmap' VALUES (3118, 7546, NULL, 3913);
INSERT INTO 'dancesrecordingsmap' VALUES (3119, 5525, NULL, 3914);
INSERT INTO 'dancesrecordingsmap' VALUES (3120, 3365, NULL, 3916);
INSERT INTO 'dancesrecordingsmap' VALUES (3121, 7130, NULL, 3917);
INSERT INTO 'dancesrecordingsmap' VALUES (3122, 3601, NULL, 3918);
INSERT INTO 'dancesrecordingsmap' VALUES (3123, 2585, NULL, 3920);
INSERT INTO 'dancesrecordingsmap' VALUES (3124, 2631, NULL, 3921);
INSERT INTO 'dancesrecordingsmap' VALUES (3125, 4102, NULL, 3922);
INSERT INTO 'dancesrecordingsmap' VALUES (3126, 7546, NULL, 3923);
INSERT INTO 'dancesrecordingsmap' VALUES (3127, 3529, NULL, 3924);
INSERT INTO 'dancesrecordingsmap' VALUES (3128, 7999, NULL, 3925);
INSERT INTO 'dancesrecordingsmap' VALUES (3129, 5525, NULL, 3926);
INSERT INTO 'dancesrecordingsmap' VALUES (3130, 1331, NULL, 3928);
INSERT INTO 'dancesrecordingsmap' VALUES (3131, 5713, NULL, 3929);
INSERT INTO 'dancesrecordingsmap' VALUES (3132, 5330, NULL, 3931);
INSERT INTO 'dancesrecordingsmap' VALUES (3133, 4633, NULL, 3932);
INSERT INTO 'dancesrecordingsmap' VALUES (3134, 7546, NULL, 3934);
INSERT INTO 'dancesrecordingsmap' VALUES (3135, 2419, NULL, 2966);
INSERT INTO 'dancesrecordingsmap' VALUES (3136, 5641, NULL, 1687);
INSERT INTO 'dancesrecordingsmap' VALUES (3019, 4491, NULL, 3767);
INSERT INTO 'dancesrecordingsmap' VALUES (3020, 7546, NULL, 3768);
INSERT INTO 'dancesrecordingsmap' VALUES (3022, 1799, NULL, 3772);
INSERT INTO 'dancesrecordingsmap' VALUES (3023, 7552, NULL, 3773);
INSERT INTO 'dancesrecordingsmap' VALUES (3024, 980, NULL, 3774);
INSERT INTO 'dancesrecordingsmap' VALUES (3025, 7548, NULL, 3775);
INSERT INTO 'dancesrecordingsmap' VALUES (3026, 6420, NULL, 3777);
INSERT INTO 'dancesrecordingsmap' VALUES (3021, 5731, NULL, 3770);
INSERT INTO 'dancesrecordingsmap' VALUES (8207, 7554, NULL, 9206);
INSERT INTO 'dancesrecordingsmap' VALUES (3095, 1931, NULL, 3881);
INSERT INTO 'dancesrecordingsmap' VALUES (3137, 7546, NULL, 3649);
INSERT INTO 'dancesrecordingsmap' VALUES (3138, 3129, NULL, 3938);
INSERT INTO 'dancesrecordingsmap' VALUES (3139, 8738, NULL, 3946);
INSERT INTO 'dancesrecordingsmap' VALUES (3140, 8738, NULL, 1033);
INSERT INTO 'dancesrecordingsmap' VALUES (3141, 8744, NULL, 3947);
INSERT INTO 'dancesrecordingsmap' VALUES (3142, 8745, NULL, 3948);
INSERT INTO 'dancesrecordingsmap' VALUES (8126, 3743, NULL, 8969);
INSERT INTO 'dancesrecordingsmap' VALUES (8195, 7546, NULL, 9141);
INSERT INTO 'dancesrecordingsmap' VALUES (8203, 8154, NULL, 9198);
INSERT INTO 'dancesrecordingsmap' VALUES (8208, 4030, NULL, 9207);
INSERT INTO 'dancesrecordingsmap' VALUES (8224, 8745, NULL, 9243);
INSERT INTO 'dancesrecordingsmap' VALUES (8228, 5525, NULL, 9257);
INSERT INTO 'dancesrecordingsmap' VALUES (8232, 8747, NULL, 9263);
INSERT INTO 'dancesrecordingsmap' VALUES (8236, 8748, NULL, 9267);
INSERT INTO 'dancesrecordingsmap' VALUES (8247, 14305, NULL, 9280);
INSERT INTO 'dancesrecordingsmap' VALUES (8258, 4998, NULL, 9310);
INSERT INTO 'dancesrecordingsmap' VALUES (4341, 1777, NULL, 5311);
INSERT INTO 'dancesrecordingsmap' VALUES (4342, 10367, NULL, 5312);
INSERT INTO 'dancesrecordingsmap' VALUES (4343, 2992, NULL, 5313);
INSERT INTO 'dancesrecordingsmap' VALUES (4344, 6104, NULL, 5314);
INSERT INTO 'dancesrecordingsmap' VALUES (4345, 3891, NULL, 5315);
INSERT INTO 'dancesrecordingsmap' VALUES (4346, 3027, NULL, 5316);
INSERT INTO 'dancesrecordingsmap' VALUES (4347, 5296, NULL, 5317);
INSERT INTO 'dancesrecordingsmap' VALUES (4349, 10382, NULL, 4445);
INSERT INTO 'dancesrecordingsmap' VALUES (4350, 10383, NULL, 4614);
INSERT INTO 'dancesrecordingsmap' VALUES (4351, 10385, NULL, 844);
INSERT INTO 'dancesrecordingsmap' VALUES (4352, 6484, NULL, 5310);
INSERT INTO 'dancesrecordingsmap' VALUES (4419, 10588, NULL, 4605);
INSERT INTO 'dancesrecordingsmap' VALUES (4354, 8774, NULL, 5319);
INSERT INTO 'dancesrecordingsmap' VALUES (4355, 8775, NULL, 5320);
INSERT INTO 'dancesrecordingsmap' VALUES (4356, 8776, NULL, 5321);
INSERT INTO 'dancesrecordingsmap' VALUES (4357, 5170, NULL, 5322);
INSERT INTO 'dancesrecordingsmap' VALUES (4358, 8778, NULL, 5323);
INSERT INTO 'dancesrecordingsmap' VALUES (4359, 8779, NULL, 5324);
INSERT INTO 'dancesrecordingsmap' VALUES (4360, 1708, NULL, 5325);
INSERT INTO 'dancesrecordingsmap' VALUES (4361, 8781, NULL, 5326);
INSERT INTO 'dancesrecordingsmap' VALUES (4362, 4217, NULL, 5327);
INSERT INTO 'dancesrecordingsmap' VALUES (4363, 8782, NULL, 5328);
INSERT INTO 'dancesrecordingsmap' VALUES (4364, 8783, NULL, 5329);
INSERT INTO 'dancesrecordingsmap' VALUES (4366, 10399, NULL, 5332);
INSERT INTO 'dancesrecordingsmap' VALUES (4367, 10400, NULL, 5333);
INSERT INTO 'dancesrecordingsmap' VALUES (4368, 10401, NULL, 5334);
INSERT INTO 'dancesrecordingsmap' VALUES (4369, 1774, NULL, 5305);
INSERT INTO 'dancesrecordingsmap' VALUES (4370, 4998, NULL, 5308);
INSERT INTO 'dancesrecordingsmap' VALUES (4371, 4142, NULL, 5335);
INSERT INTO 'dancesrecordingsmap' VALUES (4372, 9107, NULL, 5336);
INSERT INTO 'dancesrecordingsmap' VALUES (4373, 7351, NULL, 5337);
INSERT INTO 'dancesrecordingsmap' VALUES (4374, 7090, NULL, 5338);
INSERT INTO 'dancesrecordingsmap' VALUES (4375, 9800, NULL, 5339);
INSERT INTO 'dancesrecordingsmap' VALUES (4376, 2935, NULL, 5340);
INSERT INTO 'dancesrecordingsmap' VALUES (4377, 5755, NULL, 5341);
INSERT INTO 'dancesrecordingsmap' VALUES (4378, 5198, NULL, 5342);
INSERT INTO 'dancesrecordingsmap' VALUES (4379, 5013, NULL, 5343);
INSERT INTO 'dancesrecordingsmap' VALUES (4380, 1758, NULL, 5344);
INSERT INTO 'dancesrecordingsmap' VALUES (4381, 5525, NULL, 5345);
INSERT INTO 'dancesrecordingsmap' VALUES (4382, 9208, NULL, 5346);
INSERT INTO 'dancesrecordingsmap' VALUES (4383, 10460, NULL, 3496);
INSERT INTO 'dancesrecordingsmap' VALUES (4384, 10316, NULL, 1621);
INSERT INTO 'dancesrecordingsmap' VALUES (4386, 10476, NULL, 2100);
INSERT INTO 'dancesrecordingsmap' VALUES (4387, 10476, NULL, 213);
INSERT INTO 'dancesrecordingsmap' VALUES (4388, 10476, NULL, 627);
INSERT INTO 'dancesrecordingsmap' VALUES (4389, 10476, NULL, 3455);
INSERT INTO 'dancesrecordingsmap' VALUES (4391, 10476, NULL, 2972);
INSERT INTO 'dancesrecordingsmap' VALUES (4392, 10476, NULL, 528);
INSERT INTO 'dancesrecordingsmap' VALUES (4393, 10476, NULL, 4106);
INSERT INTO 'dancesrecordingsmap' VALUES (4394, 10476, NULL, 4146);
INSERT INTO 'dancesrecordingsmap' VALUES (4395, 10476, NULL, 2620);
INSERT INTO 'dancesrecordingsmap' VALUES (4396, 10476, NULL, 5291);
INSERT INTO 'dancesrecordingsmap' VALUES (4397, 10476, NULL, 4059);
INSERT INTO 'dancesrecordingsmap' VALUES (4398, 10476, NULL, 4834);
INSERT INTO 'dancesrecordingsmap' VALUES (4399, 693, NULL, 4618);
INSERT INTO 'dancesrecordingsmap' VALUES (4402, 10256, NULL, 1929);
INSERT INTO 'dancesrecordingsmap' VALUES (4403, 10256, NULL, 3565);
INSERT INTO 'dancesrecordingsmap' VALUES (4404, 10256, NULL, 2526);
INSERT INTO 'dancesrecordingsmap' VALUES (4405, 693, NULL, 2526);
INSERT INTO 'dancesrecordingsmap' VALUES (4406, 10479, NULL, 848);
INSERT INTO 'dancesrecordingsmap' VALUES (4407, 10481, NULL, 1661);
INSERT INTO 'dancesrecordingsmap' VALUES (4408, 10481, NULL, 846);
INSERT INTO 'dancesrecordingsmap' VALUES (4409, 10482, NULL, 1354);
INSERT INTO 'dancesrecordingsmap' VALUES (4410, 10486, NULL, 4217);
INSERT INTO 'dancesrecordingsmap' VALUES (4411, 9444, NULL, 469);
INSERT INTO 'dancesrecordingsmap' VALUES (4412, 7671, NULL, 361);
INSERT INTO 'dancesrecordingsmap' VALUES (4413, 7671, NULL, 853);
INSERT INTO 'dancesrecordingsmap' VALUES (4414, 6720, NULL, 5347);
INSERT INTO 'dancesrecordingsmap' VALUES (4415, 1884, NULL, 5348);
INSERT INTO 'dancesrecordingsmap' VALUES (4416, 2357, NULL, 5349);
INSERT INTO 'dancesrecordingsmap' VALUES (4417, 9812, NULL, 2150);
INSERT INTO 'dancesrecordingsmap' VALUES (4418, 10587, NULL, 784);
INSERT INTO 'dancesrecordingsmap' VALUES (4420, 10589, NULL, 4612);
INSERT INTO 'dancesrecordingsmap' VALUES (4421, 10590, NULL, 5350);
INSERT INTO 'dancesrecordingsmap' VALUES (4422, 10591, NULL, 5351);
INSERT INTO 'dancesrecordingsmap' VALUES (4423, 10592, NULL, 5352);
INSERT INTO 'dancesrecordingsmap' VALUES (4424, 9774, NULL, 5353);
INSERT INTO 'dancesrecordingsmap' VALUES (4427, 10595, NULL, 5356);
INSERT INTO 'dancesrecordingsmap' VALUES (4428, 7532, NULL, 5357);
INSERT INTO 'dancesrecordingsmap' VALUES (4429, 6055, NULL, 5358);
INSERT INTO 'dancesrecordingsmap' VALUES (4430, 10597, NULL, 5359);
INSERT INTO 'dancesrecordingsmap' VALUES (4431, 10598, NULL, 5360);
INSERT INTO 'dancesrecordingsmap' VALUES (4432, 7470, NULL, 5361);
INSERT INTO 'dancesrecordingsmap' VALUES (4433, 10599, NULL, 5362);
INSERT INTO 'dancesrecordingsmap' VALUES (8127, 4641, NULL, 8970);
INSERT INTO 'dancesrecordingsmap' VALUES (8196, 5616, NULL, 9142);
INSERT INTO 'dancesrecordingsmap' VALUES (8204, 8142, NULL, 9199);
INSERT INTO 'dancesrecordingsmap' VALUES (8209, 8148, NULL, 9209);
INSERT INTO 'dancesrecordingsmap' VALUES (8229, 7546, NULL, 9259);
INSERT INTO 'dancesrecordingsmap' VALUES (8256, 11308, NULL, 9300);
INSERT INTO 'dancesrecordingsmap' VALUES (8237, 8748, NULL, 9268);
INSERT INTO 'dancesrecordingsmap' VALUES (8248, 5459, NULL, 9281);
INSERT INTO 'dancesrecordingsmap' VALUES (4434, 10544, NULL, 5363);
INSERT INTO 'dancesrecordingsmap' VALUES (4435, 10545, NULL, 5364);
INSERT INTO 'dancesrecordingsmap' VALUES (4436, 10306, NULL, 5365);
INSERT INTO 'dancesrecordingsmap' VALUES (4437, 10546, NULL, 5366);
INSERT INTO 'dancesrecordingsmap' VALUES (4438, 10547, NULL, 5367);
INSERT INTO 'dancesrecordingsmap' VALUES (4439, 10428, NULL, 5368);
INSERT INTO 'dancesrecordingsmap' VALUES (4440, 10548, NULL, 5369);
INSERT INTO 'dancesrecordingsmap' VALUES (4441, 10549, NULL, 5370);
INSERT INTO 'dancesrecordingsmap' VALUES (4442, 9854, NULL, 5374);
INSERT INTO 'dancesrecordingsmap' VALUES (4443, 10052, NULL, 5375);
INSERT INTO 'dancesrecordingsmap' VALUES (4446, 3980, NULL, 5383);
INSERT INTO 'dancesrecordingsmap' VALUES (4448, 1786, NULL, 2616);
INSERT INTO 'dancesrecordingsmap' VALUES (4449, 3762, NULL, 5388);
INSERT INTO 'dancesrecordingsmap' VALUES (4450, 2323, NULL, 5389);
INSERT INTO 'dancesrecordingsmap' VALUES (4451, 4424, NULL, 5390);
INSERT INTO 'dancesrecordingsmap' VALUES (4452, 5904, NULL, 5391);
INSERT INTO 'dancesrecordingsmap' VALUES (4453, 5529, NULL, 5392);
INSERT INTO 'dancesrecordingsmap' VALUES (4454, 4484, NULL, 5393);
INSERT INTO 'dancesrecordingsmap' VALUES (4456, 10601, NULL, 2358);
INSERT INTO 'dancesrecordingsmap' VALUES (4457, 1296, NULL, 5001);
INSERT INTO 'dancesrecordingsmap' VALUES (4458, 4633, NULL, 5395);
INSERT INTO 'dancesrecordingsmap' VALUES (4459, 1931, NULL, 5396);
INSERT INTO 'dancesrecordingsmap' VALUES (4460, 5964, NULL, 5397);
INSERT INTO 'dancesrecordingsmap' VALUES (4461, 6915, NULL, 5398);
INSERT INTO 'dancesrecordingsmap' VALUES (4462, 1210, NULL, 5399);
INSERT INTO 'dancesrecordingsmap' VALUES (4463, 2745, NULL, 5400);
INSERT INTO 'dancesrecordingsmap' VALUES (4464, 2498, NULL, 5401);
INSERT INTO 'dancesrecordingsmap' VALUES (4465, 1562, NULL, 5402);
INSERT INTO 'dancesrecordingsmap' VALUES (4466, 7546, NULL, 5403);
INSERT INTO 'dancesrecordingsmap' VALUES (4467, 5239, NULL, 5405);
INSERT INTO 'dancesrecordingsmap' VALUES (4468, 3672, NULL, 5406);
INSERT INTO 'dancesrecordingsmap' VALUES (4469, 1782, NULL, 5407);
INSERT INTO 'dancesrecordingsmap' VALUES (4470, 7546, NULL, 5409);
INSERT INTO 'dancesrecordingsmap' VALUES (4471, 1210, NULL, 5410);
INSERT INTO 'dancesrecordingsmap' VALUES (4472, 8154, NULL, 5411);
INSERT INTO 'dancesrecordingsmap' VALUES (4447, 9352, NULL, 5385);
INSERT INTO 'dancesrecordingsmap' VALUES (4348, 10378, NULL, 722);
INSERT INTO 'dancesrecordingsmap' VALUES (4365, 10398, NULL, 5331);
INSERT INTO 'dancesrecordingsmap' VALUES (4473, 8143, NULL, 5412);
INSERT INTO 'dancesrecordingsmap' VALUES (4474, 1562, NULL, 5413);
INSERT INTO 'dancesrecordingsmap' VALUES (4475, 7554, NULL, 5414);
INSERT INTO 'dancesrecordingsmap' VALUES (4476, 7553, NULL, 5417);
INSERT INTO 'dancesrecordingsmap' VALUES (4477, 8159, NULL, 5422);
INSERT INTO 'dancesrecordingsmap' VALUES (4478, 8146, NULL, 5427);
INSERT INTO 'dancesrecordingsmap' VALUES (4479, 9505, NULL, 5053);
INSERT INTO 'dancesrecordingsmap' VALUES (4480, 10672, NULL, 4973);
INSERT INTO 'dancesrecordingsmap' VALUES (4481, 8103, NULL, 5431);
INSERT INTO 'dancesrecordingsmap' VALUES (4482, 2016, NULL, 5432);
INSERT INTO 'dancesrecordingsmap' VALUES (4483, 8102, NULL, 5436);
INSERT INTO 'dancesrecordingsmap' VALUES (9106, 17564, NULL, 10160);
INSERT INTO 'dancesrecordingsmap' VALUES (4485, 9083, NULL, 5439);
INSERT INTO 'dancesrecordingsmap' VALUES (4486, 7530, NULL, 5443);
INSERT INTO 'dancesrecordingsmap' VALUES (4487, 3996, NULL, 5444);
INSERT INTO 'dancesrecordingsmap' VALUES (4488, 10459, NULL, 5446);
INSERT INTO 'dancesrecordingsmap' VALUES (4489, 548, NULL, 5447);
INSERT INTO 'dancesrecordingsmap' VALUES (4492, 10785, NULL, 3501);
INSERT INTO 'dancesrecordingsmap' VALUES (4493, 742, NULL, 30);
INSERT INTO 'dancesrecordingsmap' VALUES (4494, 4032, NULL, 5453);
INSERT INTO 'dancesrecordingsmap' VALUES (4495, 1562, NULL, 5454);
INSERT INTO 'dancesrecordingsmap' VALUES (4496, 8154, NULL, 5455);
INSERT INTO 'dancesrecordingsmap' VALUES (4497, 4641, NULL, 5456);
INSERT INTO 'dancesrecordingsmap' VALUES (4498, 8142, NULL, 5457);
INSERT INTO 'dancesrecordingsmap' VALUES (4499, 2250, NULL, 5458);
INSERT INTO 'dancesrecordingsmap' VALUES (4500, 4102, NULL, 5459);
INSERT INTO 'dancesrecordingsmap' VALUES (4501, 5964, NULL, 5461);
INSERT INTO 'dancesrecordingsmap' VALUES (4502, 7574, NULL, 5462);
INSERT INTO 'dancesrecordingsmap' VALUES (4503, 4890, NULL, 5463);
INSERT INTO 'dancesrecordingsmap' VALUES (4505, 10797, NULL, 5445);
INSERT INTO 'dancesrecordingsmap' VALUES (4507, 10798, NULL, 5449);
INSERT INTO 'dancesrecordingsmap' VALUES (4509, 9740, NULL, 1555);
INSERT INTO 'dancesrecordingsmap' VALUES (4510, 10802, NULL, 4045);
INSERT INTO 'dancesrecordingsmap' VALUES (4535, 10900, NULL, 5028);
INSERT INTO 'dancesrecordingsmap' VALUES (4390, 10476, NULL, 3767);
INSERT INTO 'dancesrecordingsmap' VALUES (4400, 693, NULL, 1765);
INSERT INTO 'dancesrecordingsmap' VALUES (4425, 10593, NULL, 5354);
INSERT INTO 'dancesrecordingsmap' VALUES (4511, 10803, NULL, 348);
INSERT INTO 'dancesrecordingsmap' VALUES (4513, 10820, NULL, 1413);
INSERT INTO 'dancesrecordingsmap' VALUES (4515, 10842, NULL, 2137);
INSERT INTO 'dancesrecordingsmap' VALUES (4516, 10844, NULL, 4202);
INSERT INTO 'dancesrecordingsmap' VALUES (4517, 10849, NULL, 4570);
INSERT INTO 'dancesrecordingsmap' VALUES (4518, 10850, NULL, 1257);
INSERT INTO 'dancesrecordingsmap' VALUES (4519, 10861, NULL, 5371);
INSERT INTO 'dancesrecordingsmap' VALUES (4520, 10862, NULL, 5372);
INSERT INTO 'dancesrecordingsmap' VALUES (4521, 10863, NULL, 5373);
INSERT INTO 'dancesrecordingsmap' VALUES (4522, 10864, NULL, 5377);
INSERT INTO 'dancesrecordingsmap' VALUES (4523, 10865, NULL, 5378);
INSERT INTO 'dancesrecordingsmap' VALUES (4524, 10866, NULL, 5380);
INSERT INTO 'dancesrecordingsmap' VALUES (4525, 10778, NULL, 5381);
INSERT INTO 'dancesrecordingsmap' VALUES (4526, 10867, NULL, 5382);
INSERT INTO 'dancesrecordingsmap' VALUES (4527, 10797, NULL, 5384);
INSERT INTO 'dancesrecordingsmap' VALUES (4528, 10535, NULL, 4688);
INSERT INTO 'dancesrecordingsmap' VALUES (4536, 10903, NULL, 174);
INSERT INTO 'dancesrecordingsmap' VALUES (4537, 10904, NULL, 4127);
INSERT INTO 'dancesrecordingsmap' VALUES (4538, 10905, NULL, 2317);
INSERT INTO 'dancesrecordingsmap' VALUES (4539, 10906, NULL, 1084);
INSERT INTO 'dancesrecordingsmap' VALUES (4540, 10908, NULL, 1415);
INSERT INTO 'dancesrecordingsmap' VALUES (4541, 10907, NULL, 807);
INSERT INTO 'dancesrecordingsmap' VALUES (4542, 10909, NULL, 1133);
INSERT INTO 'dancesrecordingsmap' VALUES (4543, 10910, NULL, 2969);
INSERT INTO 'dancesrecordingsmap' VALUES (4544, 10653, NULL, 485);
INSERT INTO 'dancesrecordingsmap' VALUES (4545, 159, NULL, 486);
INSERT INTO 'dancesrecordingsmap' VALUES (4546, 10787, NULL, 488);
INSERT INTO 'dancesrecordingsmap' VALUES (4547, 10788, NULL, 489);
INSERT INTO 'dancesrecordingsmap' VALUES (4548, 10789, NULL, 490);
INSERT INTO 'dancesrecordingsmap' VALUES (4549, 10790, NULL, 491);
INSERT INTO 'dancesrecordingsmap' VALUES (4550, 10791, NULL, 492);
INSERT INTO 'dancesrecordingsmap' VALUES (4551, 10792, NULL, 493);
INSERT INTO 'dancesrecordingsmap' VALUES (4552, 10793, NULL, 494);
INSERT INTO 'dancesrecordingsmap' VALUES (4553, 10794, NULL, 495);
INSERT INTO 'dancesrecordingsmap' VALUES (4554, 9083, NULL, 1714);
INSERT INTO 'dancesrecordingsmap' VALUES (4555, 9474, NULL, 2908);
INSERT INTO 'dancesrecordingsmap' VALUES (8128, 4890, NULL, 8971);
INSERT INTO 'dancesrecordingsmap' VALUES (8210, 8146, NULL, 9210);
INSERT INTO 'dancesrecordingsmap' VALUES (8230, 2925, NULL, 9260);
INSERT INTO 'dancesrecordingsmap' VALUES (8238, 8748, NULL, 9269);
INSERT INTO 'dancesrecordingsmap' VALUES (8249, 14314, NULL, 9282);
INSERT INTO 'dancesrecordingsmap' VALUES (4560, 387, NULL, 5467);
INSERT INTO 'dancesrecordingsmap' VALUES (4562, 10519, NULL, 5469);
INSERT INTO 'dancesrecordingsmap' VALUES (4563, 4068, NULL, 5470);
INSERT INTO 'dancesrecordingsmap' VALUES (4564, 2063, NULL, 5473);
INSERT INTO 'dancesrecordingsmap' VALUES (4566, 10935, NULL, 5471);
INSERT INTO 'dancesrecordingsmap' VALUES (4567, 10936, NULL, 5472);
INSERT INTO 'dancesrecordingsmap' VALUES (4568, 10937, NULL, 5474);
INSERT INTO 'dancesrecordingsmap' VALUES (4569, 10977, NULL, 2951);
INSERT INTO 'dancesrecordingsmap' VALUES (4570, 10977, NULL, 5099);
INSERT INTO 'dancesrecordingsmap' VALUES (4571, 10716, NULL, 766);
INSERT INTO 'dancesrecordingsmap' VALUES (4572, 10716, NULL, 2317);
INSERT INTO 'dancesrecordingsmap' VALUES (4573, 10716, NULL, 432);
INSERT INTO 'dancesrecordingsmap' VALUES (4574, 10716, NULL, 2197);
INSERT INTO 'dancesrecordingsmap' VALUES (4575, 10716, NULL, 1204);
INSERT INTO 'dancesrecordingsmap' VALUES (4576, 10716, NULL, 4136);
INSERT INTO 'dancesrecordingsmap' VALUES (4577, 10716, NULL, 414);
INSERT INTO 'dancesrecordingsmap' VALUES (4578, 10905, NULL, 432);
INSERT INTO 'dancesrecordingsmap' VALUES (4579, 10905, NULL, 2197);
INSERT INTO 'dancesrecordingsmap' VALUES (4580, 10905, NULL, 1204);
INSERT INTO 'dancesrecordingsmap' VALUES (4581, 10905, NULL, 4136);
INSERT INTO 'dancesrecordingsmap' VALUES (4582, 10905, NULL, 414);
INSERT INTO 'dancesrecordingsmap' VALUES (4583, 10905, NULL, 766);
INSERT INTO 'dancesrecordingsmap' VALUES (4584, 10805, NULL, 1360);
INSERT INTO 'dancesrecordingsmap' VALUES (4585, 10806, NULL, 1467);
INSERT INTO 'dancesrecordingsmap' VALUES (4586, 10807, NULL, 5100);
INSERT INTO 'dancesrecordingsmap' VALUES (4587, 10808, NULL, 248);
INSERT INTO 'dancesrecordingsmap' VALUES (4589, 10810, NULL, 2589);
INSERT INTO 'dancesrecordingsmap' VALUES (4590, 10810, NULL, 1089);
INSERT INTO 'dancesrecordingsmap' VALUES (4592, 10810, NULL, 436);
INSERT INTO 'dancesrecordingsmap' VALUES (4593, 10810, NULL, 3458);
INSERT INTO 'dancesrecordingsmap' VALUES (4595, 10810, NULL, 335);
INSERT INTO 'dancesrecordingsmap' VALUES (4596, 10810, NULL, 334);
INSERT INTO 'dancesrecordingsmap' VALUES (4597, 10810, NULL, 2793);
INSERT INTO 'dancesrecordingsmap' VALUES (4598, 10810, NULL, 3021);
INSERT INTO 'dancesrecordingsmap' VALUES (4599, 10810, NULL, 4048);
INSERT INTO 'dancesrecordingsmap' VALUES (4600, 10810, NULL, 2514);
INSERT INTO 'dancesrecordingsmap' VALUES (4601, 10811, NULL, 4019);
INSERT INTO 'dancesrecordingsmap' VALUES (4602, 10811, NULL, 1285);
INSERT INTO 'dancesrecordingsmap' VALUES (4603, 10812, NULL, 673);
INSERT INTO 'dancesrecordingsmap' VALUES (4604, 10812, NULL, 2292);
INSERT INTO 'dancesrecordingsmap' VALUES (4605, 10812, NULL, 3553);
INSERT INTO 'dancesrecordingsmap' VALUES (4606, 10812, NULL, 3273);
INSERT INTO 'dancesrecordingsmap' VALUES (4607, 10812, NULL, 3298);
INSERT INTO 'dancesrecordingsmap' VALUES (4608, 10812, NULL, 5057);
INSERT INTO 'dancesrecordingsmap' VALUES (4609, 10812, NULL, 9);
INSERT INTO 'dancesrecordingsmap' VALUES (4611, 10815, NULL, 1943);
INSERT INTO 'dancesrecordingsmap' VALUES (4591, 10810, NULL, 3246);
INSERT INTO 'dancesrecordingsmap' VALUES (4530, 10880, NULL, 480);
INSERT INTO 'dancesrecordingsmap' VALUES (4529, 10879, NULL, 479);
INSERT INTO 'dancesrecordingsmap' VALUES (4531, 10881, NULL, 481);
INSERT INTO 'dancesrecordingsmap' VALUES (4532, 10882, NULL, 482);
INSERT INTO 'dancesrecordingsmap' VALUES (4533, 10883, NULL, 483);
INSERT INTO 'dancesrecordingsmap' VALUES (4534, 10884, NULL, 484);
INSERT INTO 'dancesrecordingsmap' VALUES (4514, 10007, NULL, 897);
INSERT INTO 'dancesrecordingsmap' VALUES (4512, 3934, NULL, 3120);
INSERT INTO 'dancesrecordingsmap' VALUES (4445, 9986, NULL, 5379);
INSERT INTO 'dancesrecordingsmap' VALUES (4444, 9353, NULL, 5376);
INSERT INTO 'dancesrecordingsmap' VALUES (4455, 6701, NULL, 5394);
INSERT INTO 'dancesrecordingsmap' VALUES (4612, 10816, NULL, 4417);
INSERT INTO 'dancesrecordingsmap' VALUES (4613, 10768, NULL, 3449);
INSERT INTO 'dancesrecordingsmap' VALUES (4614, 11029, NULL, 238);
INSERT INTO 'dancesrecordingsmap' VALUES (4615, 11030, NULL, 3034);
INSERT INTO 'dancesrecordingsmap' VALUES (4616, 11030, NULL, 167);
INSERT INTO 'dancesrecordingsmap' VALUES (4617, 11030, NULL, 166);
INSERT INTO 'dancesrecordingsmap' VALUES (4618, 11030, NULL, 2524);
INSERT INTO 'dancesrecordingsmap' VALUES (4619, 11034, NULL, 831);
INSERT INTO 'dancesrecordingsmap' VALUES (4620, 11034, NULL, 333);
INSERT INTO 'dancesrecordingsmap' VALUES (4622, 11034, NULL, 3425);
INSERT INTO 'dancesrecordingsmap' VALUES (4623, 11035, NULL, 5071);
INSERT INTO 'dancesrecordingsmap' VALUES (4624, 11035, NULL, 1816);
INSERT INTO 'dancesrecordingsmap' VALUES (4625, 11037, NULL, 2282);
INSERT INTO 'dancesrecordingsmap' VALUES (4626, 11037, NULL, 14);
INSERT INTO 'dancesrecordingsmap' VALUES (4627, 10457, NULL, 3447);
INSERT INTO 'dancesrecordingsmap' VALUES (4628, 11040, NULL, 4941);
INSERT INTO 'dancesrecordingsmap' VALUES (4629, 11041, NULL, 613);
INSERT INTO 'dancesrecordingsmap' VALUES (4630, 11041, NULL, 733);
INSERT INTO 'dancesrecordingsmap' VALUES (4631, 11041, NULL, 3051);
INSERT INTO 'dancesrecordingsmap' VALUES (4632, 11041, NULL, 4503);
INSERT INTO 'dancesrecordingsmap' VALUES (4633, 11041, NULL, 1867);
INSERT INTO 'dancesrecordingsmap' VALUES (4635, 11045, NULL, 4939);
INSERT INTO 'dancesrecordingsmap' VALUES (4636, 11046, NULL, 1311);
INSERT INTO 'dancesrecordingsmap' VALUES (4639, 11057, NULL, 4818);
INSERT INTO 'dancesrecordingsmap' VALUES (4640, 11057, NULL, 1586);
INSERT INTO 'dancesrecordingsmap' VALUES (4641, 11058, NULL, 2650);
INSERT INTO 'dancesrecordingsmap' VALUES (4643, 11060, NULL, 1126);
INSERT INTO 'dancesrecordingsmap' VALUES (4644, 11061, NULL, 56);
INSERT INTO 'dancesrecordingsmap' VALUES (4645, 11064, NULL, 366);
INSERT INTO 'dancesrecordingsmap' VALUES (4646, 11069, NULL, 526);
INSERT INTO 'dancesrecordingsmap' VALUES (4647, 11073, NULL, 1621);
INSERT INTO 'dancesrecordingsmap' VALUES (4648, 11082, NULL, 1638);
INSERT INTO 'dancesrecordingsmap' VALUES (4649, 11082, NULL, 1829);
INSERT INTO 'dancesrecordingsmap' VALUES (8129, 2428, NULL, 8972);
INSERT INTO 'dancesrecordingsmap' VALUES (8211, 5787, NULL, 9211);
INSERT INTO 'dancesrecordingsmap' VALUES (8239, 8748, NULL, 9270);
INSERT INTO 'dancesrecordingsmap' VALUES (8250, 5459, NULL, 9283);
INSERT INTO 'dancesrecordingsmap' VALUES (4650, 11082, NULL, 476);
INSERT INTO 'dancesrecordingsmap' VALUES (4558, 4355, NULL, 5465);
INSERT INTO 'dancesrecordingsmap' VALUES (4642, 11059, NULL, 3098);
INSERT INTO 'dancesrecordingsmap' VALUES (4621, 11034, NULL, 4689);
INSERT INTO 'dancesrecordingsmap' VALUES (4565, 10934, NULL, 2037);
INSERT INTO 'dancesrecordingsmap' VALUES (4610, 10813, NULL, 1614);
INSERT INTO 'dancesrecordingsmap' VALUES (4588, 10809, NULL, 1345);
INSERT INTO 'dancesrecordingsmap' VALUES (4556, 8837, NULL, 3915);
INSERT INTO 'dancesrecordingsmap' VALUES (4490, 5952, NULL, 5450);
INSERT INTO 'dancesrecordingsmap' VALUES (4508, 10799, NULL, 5452);
INSERT INTO 'dancesrecordingsmap' VALUES (4651, 11111, NULL, 5437);
INSERT INTO 'dancesrecordingsmap' VALUES (4652, 11108, NULL, 5429);
INSERT INTO 'dancesrecordingsmap' VALUES (4653, 11109, NULL, 5430);
INSERT INTO 'dancesrecordingsmap' VALUES (4654, 1113, NULL, 5433);
INSERT INTO 'dancesrecordingsmap' VALUES (4655, 11110, NULL, 5434);
INSERT INTO 'dancesrecordingsmap' VALUES (4656, 9043, NULL, 5435);
INSERT INTO 'dancesrecordingsmap' VALUES (4657, 11112, NULL, 5440);
INSERT INTO 'dancesrecordingsmap' VALUES (4658, 6287, NULL, 5475);
INSERT INTO 'dancesrecordingsmap' VALUES (4659, 7282, NULL, 5476);
INSERT INTO 'dancesrecordingsmap' VALUES (4662, 5296, NULL, 5483);
INSERT INTO 'dancesrecordingsmap' VALUES (4664, 1223, NULL, 5487);
INSERT INTO 'dancesrecordingsmap' VALUES (4665, 2428, NULL, 5489);
INSERT INTO 'dancesrecordingsmap' VALUES (4666, 11159, NULL, 1521);
INSERT INTO 'dancesrecordingsmap' VALUES (4667, 6425, NULL, 1874);
INSERT INTO 'dancesrecordingsmap' VALUES (4669, 4950, NULL, 294);
INSERT INTO 'dancesrecordingsmap' VALUES (4670, 4123, NULL, 3698);
INSERT INTO 'dancesrecordingsmap' VALUES (4671, 4050, NULL, 3116);
INSERT INTO 'dancesrecordingsmap' VALUES (4672, 5280, NULL, 1343);
INSERT INTO 'dancesrecordingsmap' VALUES (4673, 2642, NULL, 592);
INSERT INTO 'dancesrecordingsmap' VALUES (4674, 184, NULL, 802);
INSERT INTO 'dancesrecordingsmap' VALUES (4675, 1597, NULL, 2840);
INSERT INTO 'dancesrecordingsmap' VALUES (4676, 2816, NULL, 2602);
INSERT INTO 'dancesrecordingsmap' VALUES (4677, 6753, NULL, 2315);
INSERT INTO 'dancesrecordingsmap' VALUES (4678, 1987, NULL, 1126);
INSERT INTO 'dancesrecordingsmap' VALUES (4679, 3534, NULL, 1867);
INSERT INTO 'dancesrecordingsmap' VALUES (4680, 6483, NULL, 2409);
INSERT INTO 'dancesrecordingsmap' VALUES (4681, 2689, NULL, 1250);
INSERT INTO 'dancesrecordingsmap' VALUES (4682, 3394, NULL, 3083);
INSERT INTO 'dancesrecordingsmap' VALUES (4683, 2729, NULL, 2313);
INSERT INTO 'dancesrecordingsmap' VALUES (4684, 3599, NULL, 1347);
INSERT INTO 'dancesrecordingsmap' VALUES (4685, 3005, NULL, 1337);
INSERT INTO 'dancesrecordingsmap' VALUES (4688, 4387, NULL, 1874);
INSERT INTO 'dancesrecordingsmap' VALUES (4689, 1241, NULL, 3014);
INSERT INTO 'dancesrecordingsmap' VALUES (4690, 7216, NULL, 1370);
INSERT INTO 'dancesrecordingsmap' VALUES (4691, 1166, NULL, 1133);
INSERT INTO 'dancesrecordingsmap' VALUES (4594, 10810, NULL, 3777);
INSERT INTO 'dancesrecordingsmap' VALUES (4561, 2716, NULL, 5468);
INSERT INTO 'dancesrecordingsmap' VALUES (4559, 7227, NULL, 5466);
INSERT INTO 'dancesrecordingsmap' VALUES (4692, 4076, NULL, 2917);
INSERT INTO 'dancesrecordingsmap' VALUES (4693, 2065, NULL, 1250);
INSERT INTO 'dancesrecordingsmap' VALUES (4694, 2230, NULL, 2404);
INSERT INTO 'dancesrecordingsmap' VALUES (4695, 6831, NULL, 1129);
INSERT INTO 'dancesrecordingsmap' VALUES (4696, 6724, NULL, 1428);
INSERT INTO 'dancesrecordingsmap' VALUES (4697, 4879, NULL, 1121);
INSERT INTO 'dancesrecordingsmap' VALUES (4698, 2954, NULL, 3016);
INSERT INTO 'dancesrecordingsmap' VALUES (4699, 459, NULL, 1141);
INSERT INTO 'dancesrecordingsmap' VALUES (4700, 3120, NULL, 1781);
INSERT INTO 'dancesrecordingsmap' VALUES (4701, 5125, NULL, 1131);
INSERT INTO 'dancesrecordingsmap' VALUES (4702, 6525, NULL, 355);
INSERT INTO 'dancesrecordingsmap' VALUES (4703, 5639, NULL, 1133);
INSERT INTO 'dancesrecordingsmap' VALUES (4704, 5877, NULL, 2398);
INSERT INTO 'dancesrecordingsmap' VALUES (4706, 6934, NULL, 3625);
INSERT INTO 'dancesrecordingsmap' VALUES (4707, 1920, NULL, 1611);
INSERT INTO 'dancesrecordingsmap' VALUES (4708, 6184, NULL, 1672);
INSERT INTO 'dancesrecordingsmap' VALUES (4709, 4054, NULL, 2917);
INSERT INTO 'dancesrecordingsmap' VALUES (4710, 2417, NULL, 1339);
INSERT INTO 'dancesrecordingsmap' VALUES (4711, 2680, NULL, 1747);
INSERT INTO 'dancesrecordingsmap' VALUES (4712, 5052, NULL, 1795);
INSERT INTO 'dancesrecordingsmap' VALUES (4713, 4687, NULL, 1606);
INSERT INTO 'dancesrecordingsmap' VALUES (4714, 6608, NULL, 2312);
INSERT INTO 'dancesrecordingsmap' VALUES (4715, 6925, NULL, 2404);
INSERT INTO 'dancesrecordingsmap' VALUES (4716, 4089, NULL, 2107);
INSERT INTO 'dancesrecordingsmap' VALUES (4717, 6411, NULL, 1131);
INSERT INTO 'dancesrecordingsmap' VALUES (4718, 1381, NULL, 3083);
INSERT INTO 'dancesrecordingsmap' VALUES (4719, 6132, NULL, 2046);
INSERT INTO 'dancesrecordingsmap' VALUES (4720, 1462, NULL, 907);
INSERT INTO 'dancesrecordingsmap' VALUES (4721, 4801, NULL, 1336);
INSERT INTO 'dancesrecordingsmap' VALUES (4722, 4056, NULL, 3126);
INSERT INTO 'dancesrecordingsmap' VALUES (4723, 36, NULL, 1400);
INSERT INTO 'dancesrecordingsmap' VALUES (4724, 1737, NULL, 1874);
INSERT INTO 'dancesrecordingsmap' VALUES (4725, 1890, NULL, 1357);
INSERT INTO 'dancesrecordingsmap' VALUES (4726, 1526, NULL, 1342);
INSERT INTO 'dancesrecordingsmap' VALUES (4727, 2693, NULL, 164);
INSERT INTO 'dancesrecordingsmap' VALUES (4728, 3535, NULL, 1344);
INSERT INTO 'dancesrecordingsmap' VALUES (4729, 3415, NULL, 1547);
INSERT INTO 'dancesrecordingsmap' VALUES (4730, 1529, NULL, 1351);
INSERT INTO 'dancesrecordingsmap' VALUES (4731, 4168, NULL, 1339);
INSERT INTO 'dancesrecordingsmap' VALUES (4732, 3087, NULL, 1546);
INSERT INTO 'dancesrecordingsmap' VALUES (4733, 3904, NULL, 1550);
INSERT INTO 'dancesrecordingsmap' VALUES (4735, 1174, NULL, 913);
INSERT INTO 'dancesrecordingsmap' VALUES (4736, 7481, NULL, 1999);
INSERT INTO 'dancesrecordingsmap' VALUES (4737, 5069, NULL, 927);
INSERT INTO 'dancesrecordingsmap' VALUES (4738, 8226, NULL, 1543);
INSERT INTO 'dancesrecordingsmap' VALUES (4739, 8218, NULL, 227);
INSERT INTO 'dancesrecordingsmap' VALUES (4740, 909, NULL, 5491);
INSERT INTO 'dancesrecordingsmap' VALUES (8240, 8751, NULL, 9271);
INSERT INTO 'dancesrecordingsmap' VALUES (4742, 7019, NULL, 5493);
INSERT INTO 'dancesrecordingsmap' VALUES (4743, 3108, NULL, 5494);
INSERT INTO 'dancesrecordingsmap' VALUES (4744, 1473, NULL, 5495);
INSERT INTO 'dancesrecordingsmap' VALUES (4745, 10008, NULL, 5496);
INSERT INTO 'dancesrecordingsmap' VALUES (4747, 3129, NULL, 5499);
INSERT INTO 'dancesrecordingsmap' VALUES (4748, 9107, NULL, 5500);
INSERT INTO 'dancesrecordingsmap' VALUES (4750, 8088, NULL, 5502);
INSERT INTO 'dancesrecordingsmap' VALUES (4751, 5209, NULL, 5503);
INSERT INTO 'dancesrecordingsmap' VALUES (4752, 5326, NULL, 5504);
INSERT INTO 'dancesrecordingsmap' VALUES (4753, 5612, NULL, 5505);
INSERT INTO 'dancesrecordingsmap' VALUES (4755, 2394, NULL, 5507);
INSERT INTO 'dancesrecordingsmap' VALUES (4756, 7105, NULL, 5508);
INSERT INTO 'dancesrecordingsmap' VALUES (4757, 219, NULL, 5509);
INSERT INTO 'dancesrecordingsmap' VALUES (4758, 183, NULL, 5510);
INSERT INTO 'dancesrecordingsmap' VALUES (4759, 2469, NULL, 5511);
INSERT INTO 'dancesrecordingsmap' VALUES (4760, 5555, NULL, 5512);
INSERT INTO 'dancesrecordingsmap' VALUES (4761, 4629, NULL, 5513);
INSERT INTO 'dancesrecordingsmap' VALUES (4762, 2616, NULL, 5514);
INSERT INTO 'dancesrecordingsmap' VALUES (4763, 7204, NULL, 5515);
INSERT INTO 'dancesrecordingsmap' VALUES (4764, 5808, NULL, 5516);
INSERT INTO 'dancesrecordingsmap' VALUES (4765, 652, NULL, 5517);
INSERT INTO 'dancesrecordingsmap' VALUES (4766, 5006, NULL, 5518);
INSERT INTO 'dancesrecordingsmap' VALUES (4767, 5412, NULL, 5519);
INSERT INTO 'dancesrecordingsmap' VALUES (4768, 11190, NULL, 5526);
INSERT INTO 'dancesrecordingsmap' VALUES (4769, 11184, NULL, 5520);
INSERT INTO 'dancesrecordingsmap' VALUES (4771, 11186, NULL, 5522);
INSERT INTO 'dancesrecordingsmap' VALUES (4772, 11187, NULL, 5523);
INSERT INTO 'dancesrecordingsmap' VALUES (4773, 11188, NULL, 5524);
INSERT INTO 'dancesrecordingsmap' VALUES (4774, 11189, NULL, 5525);
INSERT INTO 'dancesrecordingsmap' VALUES (4775, 5209, NULL, 5530);
INSERT INTO 'dancesrecordingsmap' VALUES (4776, 7520, NULL, 5531);
INSERT INTO 'dancesrecordingsmap' VALUES (4777, 11193, NULL, 5532);
INSERT INTO 'dancesrecordingsmap' VALUES (4778, 223, NULL, 5533);
INSERT INTO 'dancesrecordingsmap' VALUES (4779, 5610, NULL, 5534);
INSERT INTO 'dancesrecordingsmap' VALUES (4780, 5794, NULL, 5535);
INSERT INTO 'dancesrecordingsmap' VALUES (4781, 6952, NULL, 5536);
INSERT INTO 'dancesrecordingsmap' VALUES (4782, 3635, NULL, 5537);
INSERT INTO 'dancesrecordingsmap' VALUES (4783, 1758, NULL, 5538);
INSERT INTO 'dancesrecordingsmap' VALUES (4784, 168, NULL, 5539);
INSERT INTO 'dancesrecordingsmap' VALUES (4785, 3528, NULL, 5540);
INSERT INTO 'dancesrecordingsmap' VALUES (4786, 4662, NULL, 5541);
INSERT INTO 'dancesrecordingsmap' VALUES (4787, 2084, NULL, 5542);
INSERT INTO 'dancesrecordingsmap' VALUES (4788, 1891, NULL, 5543);
INSERT INTO 'dancesrecordingsmap' VALUES (4789, 1782, NULL, 5548);
INSERT INTO 'dancesrecordingsmap' VALUES (4790, 8146, NULL, 5549);
INSERT INTO 'dancesrecordingsmap' VALUES (4791, 3152, NULL, 5552);
INSERT INTO 'dancesrecordingsmap' VALUES (4746, 56, NULL, 5497);
INSERT INTO 'dancesrecordingsmap' VALUES (4668, 1334, NULL, 266);
INSERT INTO 'dancesrecordingsmap' VALUES (4637, 11048, NULL, 21);
INSERT INTO 'dancesrecordingsmap' VALUES (4661, 1020, NULL, 5481);
INSERT INTO 'dancesrecordingsmap' VALUES (4634, 11043, NULL, 2561);
INSERT INTO 'dancesrecordingsmap' VALUES (4792, 5354, NULL, 5555);
INSERT INTO 'dancesrecordingsmap' VALUES (4793, 9067, NULL, 1667);
INSERT INTO 'dancesrecordingsmap' VALUES (4794, 11164, NULL, 1136);
INSERT INTO 'dancesrecordingsmap' VALUES (4795, 11170, NULL, 2159);
INSERT INTO 'dancesrecordingsmap' VALUES (4796, 11216, NULL, 56);
INSERT INTO 'dancesrecordingsmap' VALUES (4797, 11217, NULL, 109);
INSERT INTO 'dancesrecordingsmap' VALUES (4798, 9862, NULL, 17);
INSERT INTO 'dancesrecordingsmap' VALUES (4799, 11220, NULL, 212);
INSERT INTO 'dancesrecordingsmap' VALUES (4800, 10554, NULL, 911);
INSERT INTO 'dancesrecordingsmap' VALUES (4801, 10557, NULL, 1428);
INSERT INTO 'dancesrecordingsmap' VALUES (4802, 11218, NULL, 4675);
INSERT INTO 'dancesrecordingsmap' VALUES (4803, 11219, NULL, 3429);
INSERT INTO 'dancesrecordingsmap' VALUES (4812, 1829, NULL, 3700);
INSERT INTO 'dancesrecordingsmap' VALUES (4813, 9812, NULL, 489);
INSERT INTO 'dancesrecordingsmap' VALUES (4814, 11289, NULL, 639);
INSERT INTO 'dancesrecordingsmap' VALUES (4815, 11363, NULL, 2637);
INSERT INTO 'dancesrecordingsmap' VALUES (4816, 11351, NULL, 1615);
INSERT INTO 'dancesrecordingsmap' VALUES (4818, 11353, NULL, 584);
INSERT INTO 'dancesrecordingsmap' VALUES (4819, 11354, NULL, 2150);
INSERT INTO 'dancesrecordingsmap' VALUES (4820, 11356, NULL, 3434);
INSERT INTO 'dancesrecordingsmap' VALUES (4821, 11357, NULL, 213);
INSERT INTO 'dancesrecordingsmap' VALUES (4822, 11358, NULL, 5336);
INSERT INTO 'dancesrecordingsmap' VALUES (4823, 11359, NULL, 1468);
INSERT INTO 'dancesrecordingsmap' VALUES (4826, 11362, NULL, 903);
INSERT INTO 'dancesrecordingsmap' VALUES (4827, 11364, NULL, 891);
INSERT INTO 'dancesrecordingsmap' VALUES (4829, 3365, NULL, 5568);
INSERT INTO 'dancesrecordingsmap' VALUES (4830, 3791, NULL, 5569);
INSERT INTO 'dancesrecordingsmap' VALUES (4831, 1786, NULL, 5570);
INSERT INTO 'dancesrecordingsmap' VALUES (4832, 9110, NULL, 5572);
INSERT INTO 'dancesrecordingsmap' VALUES (4833, 6957, NULL, 5574);
INSERT INTO 'dancesrecordingsmap' VALUES (4834, 5713, NULL, 5575);
INSERT INTO 'dancesrecordingsmap' VALUES (8241, 8751, NULL, 9272);
INSERT INTO 'dancesrecordingsmap' VALUES (4770, 11185, NULL, 5521);
INSERT INTO 'dancesrecordingsmap' VALUES (4660, 3594, NULL, 5480);
INSERT INTO 'dancesrecordingsmap' VALUES (4687, 621, NULL, 1346);
INSERT INTO 'dancesrecordingsmap' VALUES (4749, 9090, NULL, 5501);
INSERT INTO 'dancesrecordingsmap' VALUES (4836, 9107, NULL, 5577);
INSERT INTO 'dancesrecordingsmap' VALUES (4837, 377, NULL, 5578);
INSERT INTO 'dancesrecordingsmap' VALUES (4838, 4227, NULL, 5579);
INSERT INTO 'dancesrecordingsmap' VALUES (4839, 11401, NULL, 838);
INSERT INTO 'dancesrecordingsmap' VALUES (4840, 8709, NULL, 2464);
INSERT INTO 'dancesrecordingsmap' VALUES (4841, 9946, NULL, 5591);
INSERT INTO 'dancesrecordingsmap' VALUES (4842, 9947, NULL, 5592);
INSERT INTO 'dancesrecordingsmap' VALUES (4843, 9945, NULL, 5593);
INSERT INTO 'dancesrecordingsmap' VALUES (4844, 9948, NULL, 5594);
INSERT INTO 'dancesrecordingsmap' VALUES (4845, 9949, NULL, 5595);
INSERT INTO 'dancesrecordingsmap' VALUES (4848, 11429, NULL, 2656);
INSERT INTO 'dancesrecordingsmap' VALUES (4849, 11430, NULL, 5558);
INSERT INTO 'dancesrecordingsmap' VALUES (4850, 11431, NULL, 1100);
INSERT INTO 'dancesrecordingsmap' VALUES (4851, 11431, NULL, 3016);
INSERT INTO 'dancesrecordingsmap' VALUES (4852, 11431, NULL, 2104);
INSERT INTO 'dancesrecordingsmap' VALUES (4853, 11431, NULL, 136);
INSERT INTO 'dancesrecordingsmap' VALUES (4854, 11431, NULL, 1602);
INSERT INTO 'dancesrecordingsmap' VALUES (4855, 11431, NULL, 2553);
INSERT INTO 'dancesrecordingsmap' VALUES (4857, 9121, NULL, 5565);
INSERT INTO 'dancesrecordingsmap' VALUES (4858, 11435, NULL, 4960);
INSERT INTO 'dancesrecordingsmap' VALUES (4859, 5904, NULL, 5597);
INSERT INTO 'dancesrecordingsmap' VALUES (4860, 3323, NULL, 5600);
INSERT INTO 'dancesrecordingsmap' VALUES (4861, 5525, NULL, 5605);
INSERT INTO 'dancesrecordingsmap' VALUES (4862, 11436, NULL, 4435);
INSERT INTO 'dancesrecordingsmap' VALUES (4863, 11440, NULL, 5475);
INSERT INTO 'dancesrecordingsmap' VALUES (4864, 11439, NULL, 5475);
INSERT INTO 'dancesrecordingsmap' VALUES (4865, 11442, NULL, 4215);
INSERT INTO 'dancesrecordingsmap' VALUES (4867, 11443, NULL, 5565);
INSERT INTO 'dancesrecordingsmap' VALUES (4868, 11444, NULL, 5475);
INSERT INTO 'dancesrecordingsmap' VALUES (4870, 11446, NULL, 4970);
INSERT INTO 'dancesrecordingsmap' VALUES (4871, 11447, NULL, 4962);
INSERT INTO 'dancesrecordingsmap' VALUES (4872, 11449, NULL, 382);
INSERT INTO 'dancesrecordingsmap' VALUES (4873, 11448, NULL, 853);
INSERT INTO 'dancesrecordingsmap' VALUES (4874, 11450, NULL, 2165);
INSERT INTO 'dancesrecordingsmap' VALUES (4878, 11454, NULL, 4960);
INSERT INTO 'dancesrecordingsmap' VALUES (4734, 2304, NULL, 1471);
INSERT INTO 'dancesrecordingsmap' VALUES (4847, 11429, NULL, 110);
INSERT INTO 'dancesrecordingsmap' VALUES (4804, 9456, NULL, 4114);
INSERT INTO 'dancesrecordingsmap' VALUES (4811, 9802, NULL, 5560);
INSERT INTO 'dancesrecordingsmap' VALUES (4741, 9565, NULL, 5492);
INSERT INTO 'dancesrecordingsmap' VALUES (4754, 5407, NULL, 5506);
INSERT INTO 'dancesrecordingsmap' VALUES (4835, 9165, NULL, 5576);
INSERT INTO 'dancesrecordingsmap' VALUES (4879, 7666, NULL, 2267);
INSERT INTO 'dancesrecordingsmap' VALUES (4880, 11455, NULL, 4960);
INSERT INTO 'dancesrecordingsmap' VALUES (4881, 11456, NULL, 4966);
INSERT INTO 'dancesrecordingsmap' VALUES (4884, 11460, NULL, 4684);
INSERT INTO 'dancesrecordingsmap' VALUES (4885, 11462, NULL, 848);
INSERT INTO 'dancesrecordingsmap' VALUES (4886, 11463, NULL, 5037);
INSERT INTO 'dancesrecordingsmap' VALUES (4887, 11464, NULL, 4693);
INSERT INTO 'dancesrecordingsmap' VALUES (4889, 10266, NULL, 848);
INSERT INTO 'dancesrecordingsmap' VALUES (4890, 11466, NULL, 4568);
INSERT INTO 'dancesrecordingsmap' VALUES (4891, 11467, NULL, 381);
INSERT INTO 'dancesrecordingsmap' VALUES (4892, 11468, NULL, 5178);
INSERT INTO 'dancesrecordingsmap' VALUES (4893, 11469, NULL, 5182);
INSERT INTO 'dancesrecordingsmap' VALUES (4895, 11471, NULL, 5099);
INSERT INTO 'dancesrecordingsmap' VALUES (4896, 11472, NULL, 3439);
INSERT INTO 'dancesrecordingsmap' VALUES (4897, 11473, NULL, 645);
INSERT INTO 'dancesrecordingsmap' VALUES (4898, 11474, NULL, 5178);
INSERT INTO 'dancesrecordingsmap' VALUES (4899, 11475, NULL, 848);
INSERT INTO 'dancesrecordingsmap' VALUES (4900, 11476, NULL, 3436);
INSERT INTO 'dancesrecordingsmap' VALUES (9107, 10048, NULL, 10166);
INSERT INTO 'dancesrecordingsmap' VALUES (4902, 11479, NULL, 5581);
INSERT INTO 'dancesrecordingsmap' VALUES (4905, 11482, NULL, 5584);
INSERT INTO 'dancesrecordingsmap' VALUES (4906, 11483, NULL, 5585);
INSERT INTO 'dancesrecordingsmap' VALUES (4907, 11484, NULL, 5586);
INSERT INTO 'dancesrecordingsmap' VALUES (4910, 11487, NULL, 5590);
INSERT INTO 'dancesrecordingsmap' VALUES (4913, 11490, NULL, 4960);
INSERT INTO 'dancesrecordingsmap' VALUES (4914, 11492, NULL, 846);
INSERT INTO 'dancesrecordingsmap' VALUES (4915, 11493, NULL, 853);
INSERT INTO 'dancesrecordingsmap' VALUES (4917, 11495, NULL, 5449);
INSERT INTO 'dancesrecordingsmap' VALUES (4919, 11497, NULL, 5340);
INSERT INTO 'dancesrecordingsmap' VALUES (4920, 11498, NULL, 5558);
INSERT INTO 'dancesrecordingsmap' VALUES (4921, 11499, NULL, 2354);
INSERT INTO 'dancesrecordingsmap' VALUES (4922, 11501, NULL, 2655);
INSERT INTO 'dancesrecordingsmap' VALUES (4923, 11502, NULL, 2657);
INSERT INTO 'dancesrecordingsmap' VALUES (4926, 11505, NULL, 3468);
INSERT INTO 'dancesrecordingsmap' VALUES (8242, 8753, NULL, 9273);
INSERT INTO 'dancesrecordingsmap' VALUES (4927, 11506, NULL, 854);
INSERT INTO 'dancesrecordingsmap' VALUES (4928, 11507, NULL, 853);
INSERT INTO 'dancesrecordingsmap' VALUES (4932, 9571, NULL, 4435);
INSERT INTO 'dancesrecordingsmap' VALUES (4933, 9572, NULL, 4437);
INSERT INTO 'dancesrecordingsmap' VALUES (4934, 9573, NULL, 4439);
INSERT INTO 'dancesrecordingsmap' VALUES (4936, 9575, NULL, 4443);
INSERT INTO 'dancesrecordingsmap' VALUES (4937, 9576, NULL, 4445);
INSERT INTO 'dancesrecordingsmap' VALUES (4938, 9577, NULL, 4447);
INSERT INTO 'dancesrecordingsmap' VALUES (4939, 9578, NULL, 4449);
INSERT INTO 'dancesrecordingsmap' VALUES (4940, 9579, NULL, 4450);
INSERT INTO 'dancesrecordingsmap' VALUES (4941, 9580, NULL, 4452);
INSERT INTO 'dancesrecordingsmap' VALUES (4944, 9584, NULL, 2143);
INSERT INTO 'dancesrecordingsmap' VALUES (4945, 4487, NULL, 5596);
INSERT INTO 'dancesrecordingsmap' VALUES (4946, 902, NULL, 5598);
INSERT INTO 'dancesrecordingsmap' VALUES (4947, 11438, NULL, 5602);
INSERT INTO 'dancesrecordingsmap' VALUES (4948, 4192, NULL, 5603);
INSERT INTO 'dancesrecordingsmap' VALUES (4949, 11538, NULL, 2094);
INSERT INTO 'dancesrecordingsmap' VALUES (4950, 9787, NULL, 4688);
INSERT INTO 'dancesrecordingsmap' VALUES (4952, 11573, NULL, 4654);
INSERT INTO 'dancesrecordingsmap' VALUES (4953, 11577, NULL, 35);
INSERT INTO 'dancesrecordingsmap' VALUES (4954, 11579, NULL, 4655);
INSERT INTO 'dancesrecordingsmap' VALUES (4955, 11575, NULL, 434);
INSERT INTO 'dancesrecordingsmap' VALUES (4956, 11581, NULL, 420);
INSERT INTO 'dancesrecordingsmap' VALUES (4957, 9104, NULL, 5609);
INSERT INTO 'dancesrecordingsmap' VALUES (4958, 10787, NULL, 5610);
INSERT INTO 'dancesrecordingsmap' VALUES (4959, 9561, NULL, 5611);
INSERT INTO 'dancesrecordingsmap' VALUES (4960, 7350, NULL, 5612);
INSERT INTO 'dancesrecordingsmap' VALUES (4961, 5209, NULL, 5613);
INSERT INTO 'dancesrecordingsmap' VALUES (4962, 159, NULL, 5614);
INSERT INTO 'dancesrecordingsmap' VALUES (4963, 6915, NULL, 5615);
INSERT INTO 'dancesrecordingsmap' VALUES (4964, 10791, NULL, 5616);
INSERT INTO 'dancesrecordingsmap' VALUES (4966, 2924, NULL, 5619);
INSERT INTO 'dancesrecordingsmap' VALUES (4967, 894, NULL, 5620);
INSERT INTO 'dancesrecordingsmap' VALUES (4968, 4805, NULL, 5621);
INSERT INTO 'dancesrecordingsmap' VALUES (4969, 153, NULL, 5622);
INSERT INTO 'dancesrecordingsmap' VALUES (4970, 11367, NULL, 5623);
INSERT INTO 'dancesrecordingsmap' VALUES (4971, 11367, NULL, 5624);
INSERT INTO 'dancesrecordingsmap' VALUES (4929, 11508, NULL, 855);
INSERT INTO 'dancesrecordingsmap' VALUES (4974, 11370, NULL, 5627);
INSERT INTO 'dancesrecordingsmap' VALUES (4877, 11453, NULL, 387);
INSERT INTO 'dancesrecordingsmap' VALUES (4909, 11486, NULL, 5589);
INSERT INTO 'dancesrecordingsmap' VALUES (4817, 11352, NULL, 3467);
INSERT INTO 'dancesrecordingsmap' VALUES (4869, 11445, NULL, 5563);
INSERT INTO 'dancesrecordingsmap' VALUES (4856, 11433, NULL, 2525);
INSERT INTO 'dancesrecordingsmap' VALUES (4828, 1087, NULL, 5567);
INSERT INTO 'dancesrecordingsmap' VALUES (4942, 9581, NULL, 4454);
INSERT INTO 'dancesrecordingsmap' VALUES (4911, 11488, NULL, 5172);
INSERT INTO 'dancesrecordingsmap' VALUES (4918, 11496, NULL, 4222);
INSERT INTO 'dancesrecordingsmap' VALUES (4908, 11485, NULL, 5587);
INSERT INTO 'dancesrecordingsmap' VALUES (4916, 11494, NULL, 383);
INSERT INTO 'dancesrecordingsmap' VALUES (4883, 11458, NULL, 1379);
INSERT INTO 'dancesrecordingsmap' VALUES (4924, 11503, NULL, 1379);
INSERT INTO 'dancesrecordingsmap' VALUES (4825, 11361, NULL, 4699);
INSERT INTO 'dancesrecordingsmap' VALUES (4904, 11481, NULL, 5583);
INSERT INTO 'dancesrecordingsmap' VALUES (4975, 11370, NULL, 5628);
INSERT INTO 'dancesrecordingsmap' VALUES (4977, 11371, NULL, 5630);
INSERT INTO 'dancesrecordingsmap' VALUES (4978, 11372, NULL, 5631);
INSERT INTO 'dancesrecordingsmap' VALUES (4979, 11373, NULL, 5632);
INSERT INTO 'dancesrecordingsmap' VALUES (4980, 11374, NULL, 5633);
INSERT INTO 'dancesrecordingsmap' VALUES (4981, 11374, NULL, 5634);
INSERT INTO 'dancesrecordingsmap' VALUES (4982, 11375, NULL, 5635);
INSERT INTO 'dancesrecordingsmap' VALUES (4983, 11376, NULL, 5636);
INSERT INTO 'dancesrecordingsmap' VALUES (4984, 11376, NULL, 5637);
INSERT INTO 'dancesrecordingsmap' VALUES (4985, 1624, NULL, 5638);
INSERT INTO 'dancesrecordingsmap' VALUES (4987, 658, NULL, 5642);
INSERT INTO 'dancesrecordingsmap' VALUES (4988, 633, NULL, 5643);
INSERT INTO 'dancesrecordingsmap' VALUES (4989, 633, NULL, 5644);
INSERT INTO 'dancesrecordingsmap' VALUES (4990, 769, NULL, 5645);
INSERT INTO 'dancesrecordingsmap' VALUES (4991, 1836, NULL, 5647);
INSERT INTO 'dancesrecordingsmap' VALUES (4992, 3179, NULL, 5648);
INSERT INTO 'dancesrecordingsmap' VALUES (4993, 5449, NULL, 5648);
INSERT INTO 'dancesrecordingsmap' VALUES (4994, 11169, NULL, 5648);
INSERT INTO 'dancesrecordingsmap' VALUES (4995, 9093, NULL, 5648);
INSERT INTO 'dancesrecordingsmap' VALUES (4996, 9812, NULL, 5648);
INSERT INTO 'dancesrecordingsmap' VALUES (4997, 9812, NULL, 5649);
INSERT INTO 'dancesrecordingsmap' VALUES (4998, 3179, NULL, 5649);
INSERT INTO 'dancesrecordingsmap' VALUES (4999, 11169, NULL, 5649);
INSERT INTO 'dancesrecordingsmap' VALUES (5000, 5449, NULL, 5649);
INSERT INTO 'dancesrecordingsmap' VALUES (5001, 9093, NULL, 5649);
INSERT INTO 'dancesrecordingsmap' VALUES (5002, 3789, NULL, 5650);
INSERT INTO 'dancesrecordingsmap' VALUES (5003, 3172, NULL, 5651);
INSERT INTO 'dancesrecordingsmap' VALUES (5004, 3172, NULL, 5652);
INSERT INTO 'dancesrecordingsmap' VALUES (5006, 10647, NULL, 5654);
INSERT INTO 'dancesrecordingsmap' VALUES (5011, 10677, NULL, 5658);
INSERT INTO 'dancesrecordingsmap' VALUES (5012, 10665, NULL, 5660);
INSERT INTO 'dancesrecordingsmap' VALUES (5015, 10669, NULL, 5663);
INSERT INTO 'dancesrecordingsmap' VALUES (5017, 128, NULL, 2317);
INSERT INTO 'dancesrecordingsmap' VALUES (5018, 390, NULL, 1397);
INSERT INTO 'dancesrecordingsmap' VALUES (5021, 1518, NULL, 2137);
INSERT INTO 'dancesrecordingsmap' VALUES (5022, 11589, NULL, 5100);
INSERT INTO 'dancesrecordingsmap' VALUES (5023, 11590, NULL, 4703);
INSERT INTO 'dancesrecordingsmap' VALUES (5024, 11591, NULL, 3315);
INSERT INTO 'dancesrecordingsmap' VALUES (5019, 11588, NULL, 5488);
INSERT INTO 'dancesrecordingsmap' VALUES (4931, 11510, NULL, 360);
INSERT INTO 'dancesrecordingsmap' VALUES (4866, 11441, NULL, 5480);
INSERT INTO 'dancesrecordingsmap' VALUES (5010, 10580, NULL, 5659);
INSERT INTO 'dancesrecordingsmap' VALUES (4876, 11452, NULL, 5031);
INSERT INTO 'dancesrecordingsmap' VALUES (4935, 9574, NULL, 4441);
INSERT INTO 'dancesrecordingsmap' VALUES (4951, 7395, NULL, 2003);
INSERT INTO 'dancesrecordingsmap' VALUES (4925, 11504, NULL, 3471);
INSERT INTO 'dancesrecordingsmap' VALUES (5020, 1225, NULL, 2457);
INSERT INTO 'dancesrecordingsmap' VALUES (5025, 11591, NULL, 4997);
INSERT INTO 'dancesrecordingsmap' VALUES (5026, 11592, NULL, 2456);
INSERT INTO 'dancesrecordingsmap' VALUES (5028, 5797, NULL, 5111);
INSERT INTO 'dancesrecordingsmap' VALUES (5029, 11595, NULL, 2045);
INSERT INTO 'dancesrecordingsmap' VALUES (5030, 11596, NULL, 868);
INSERT INTO 'dancesrecordingsmap' VALUES (5031, 11604, NULL, 202);
INSERT INTO 'dancesrecordingsmap' VALUES (5032, 11605, NULL, 18);
INSERT INTO 'dancesrecordingsmap' VALUES (5033, 11606, NULL, 4934);
INSERT INTO 'dancesrecordingsmap' VALUES (5034, 11609, NULL, 635);
INSERT INTO 'dancesrecordingsmap' VALUES (5036, 11613, NULL, 1775);
INSERT INTO 'dancesrecordingsmap' VALUES (5037, 11614, NULL, 907);
INSERT INTO 'dancesrecordingsmap' VALUES (5038, 11615, NULL, 1124);
INSERT INTO 'dancesrecordingsmap' VALUES (5039, 11620, NULL, 1294);
INSERT INTO 'dancesrecordingsmap' VALUES (5040, 11622, NULL, 1254);
INSERT INTO 'dancesrecordingsmap' VALUES (5041, 11622, NULL, 1672);
INSERT INTO 'dancesrecordingsmap' VALUES (5042, 2882, NULL, 2324);
INSERT INTO 'dancesrecordingsmap' VALUES (5043, 3016, NULL, 4819);
INSERT INTO 'dancesrecordingsmap' VALUES (5044, 3016, NULL, 1582);
INSERT INTO 'dancesrecordingsmap' VALUES (8243, 8753, NULL, 9274);
INSERT INTO 'dancesrecordingsmap' VALUES (5058, 7546, NULL, 5673);
INSERT INTO 'dancesrecordingsmap' VALUES (5059, 1799, NULL, 5674);
INSERT INTO 'dancesrecordingsmap' VALUES (5060, 7554, NULL, 5675);
INSERT INTO 'dancesrecordingsmap' VALUES (5061, 7553, NULL, 5676);
INSERT INTO 'dancesrecordingsmap' VALUES (5062, 8146, NULL, 5678);
INSERT INTO 'dancesrecordingsmap' VALUES (5063, 7147, NULL, 5679);
INSERT INTO 'dancesrecordingsmap' VALUES (5064, 7552, NULL, 5680);
INSERT INTO 'dancesrecordingsmap' VALUES (5065, 7548, NULL, 5682);
INSERT INTO 'dancesrecordingsmap' VALUES (5066, 8144, NULL, 5683);
INSERT INTO 'dancesrecordingsmap' VALUES (5067, 1562, NULL, 5686);
INSERT INTO 'dancesrecordingsmap' VALUES (5068, 9646, NULL, 5098);
INSERT INTO 'dancesrecordingsmap' VALUES (5016, 10460, NULL, 5664);
INSERT INTO 'dancesrecordingsmap' VALUES (5049, 245, NULL, 781);
INSERT INTO 'dancesrecordingsmap' VALUES (5050, 11629, NULL, 782);
INSERT INTO 'dancesrecordingsmap' VALUES (5053, 5403, NULL, 5667);
INSERT INTO 'dancesrecordingsmap' VALUES (5051, 5829, NULL, 4505);
INSERT INTO 'dancesrecordingsmap' VALUES (5052, 902, NULL, 5666);
INSERT INTO 'dancesrecordingsmap' VALUES (5009, 10695, NULL, 5657);
INSERT INTO 'dancesrecordingsmap' VALUES (4943, 9582, NULL, 4455);
INSERT INTO 'dancesrecordingsmap' VALUES (4903, 11480, NULL, 5582);
INSERT INTO 'dancesrecordingsmap' VALUES (4965, 1066, NULL, 5618);
INSERT INTO 'dancesrecordingsmap' VALUES (4930, 11509, NULL, 172);
INSERT INTO 'dancesrecordingsmap' VALUES (5054, 2716, NULL, 5668);
INSERT INTO 'dancesrecordingsmap' VALUES (5008, 10233, NULL, 5656);
INSERT INTO 'dancesrecordingsmap' VALUES (5013, 10195, NULL, 5661);
INSERT INTO 'dancesrecordingsmap' VALUES (5047, 5079, NULL, 776);
INSERT INTO 'dancesrecordingsmap' VALUES (4875, 11451, NULL, 5039);
INSERT INTO 'dancesrecordingsmap' VALUES (4972, 11368, NULL, 5625);
INSERT INTO 'dancesrecordingsmap' VALUES (5070, 8624, NULL, 945);
INSERT INTO 'dancesrecordingsmap' VALUES (5071, 11633, NULL, 261);
INSERT INTO 'dancesrecordingsmap' VALUES (5072, 11633, NULL, 1787);
INSERT INTO 'dancesrecordingsmap' VALUES (5073, 11634, NULL, 827);
INSERT INTO 'dancesrecordingsmap' VALUES (5075, 11638, NULL, 4708);
INSERT INTO 'dancesrecordingsmap' VALUES (5076, 11640, NULL, 3491);
INSERT INTO 'dancesrecordingsmap' VALUES (5080, 11684, NULL, 124);
INSERT INTO 'dancesrecordingsmap' VALUES (5081, 11688, NULL, 1234);
INSERT INTO 'dancesrecordingsmap' VALUES (5082, 11690, NULL, 3474);
INSERT INTO 'dancesrecordingsmap' VALUES (5083, 11694, NULL, 4449);
INSERT INTO 'dancesrecordingsmap' VALUES (5084, 11695, NULL, 1521);
INSERT INTO 'dancesrecordingsmap' VALUES (5087, 4857, NULL, 5702);
INSERT INTO 'dancesrecordingsmap' VALUES (5088, 340, NULL, 5703);
INSERT INTO 'dancesrecordingsmap' VALUES (5089, 4720, NULL, 5704);
INSERT INTO 'dancesrecordingsmap' VALUES (5091, 6734, NULL, 5706);
INSERT INTO 'dancesrecordingsmap' VALUES (5092, 11392, NULL, 5707);
INSERT INTO 'dancesrecordingsmap' VALUES (5093, 11398, NULL, 5708);
INSERT INTO 'dancesrecordingsmap' VALUES (5094, 9127, NULL, 5708);
INSERT INTO 'dancesrecordingsmap' VALUES (5095, 11400, NULL, 5709);
INSERT INTO 'dancesrecordingsmap' VALUES (5096, 11391, NULL, 5709);
INSERT INTO 'dancesrecordingsmap' VALUES (5097, 10105, NULL, 5710);
INSERT INTO 'dancesrecordingsmap' VALUES (5098, 9643, NULL, 5711);
INSERT INTO 'dancesrecordingsmap' VALUES (5099, 9636, NULL, 5712);
INSERT INTO 'dancesrecordingsmap' VALUES (5104, 9638, NULL, 5716);
INSERT INTO 'dancesrecordingsmap' VALUES (5107, 9634, NULL, 5718);
INSERT INTO 'dancesrecordingsmap' VALUES (5035, 11611, NULL, 2560);
INSERT INTO 'dancesrecordingsmap' VALUES (5114, 11397, NULL, 5723);
INSERT INTO 'dancesrecordingsmap' VALUES (5115, 7941, NULL, 5724);
INSERT INTO 'dancesrecordingsmap' VALUES (5116, 11390, NULL, 5724);
INSERT INTO 'dancesrecordingsmap' VALUES (5117, 1492, NULL, 5725);
INSERT INTO 'dancesrecordingsmap' VALUES (5119, 3672, NULL, 5727);
INSERT INTO 'dancesrecordingsmap' VALUES (5121, 2437, NULL, 5729);
INSERT INTO 'dancesrecordingsmap' VALUES (5122, 2979, NULL, 5730);
INSERT INTO 'dancesrecordingsmap' VALUES (5124, 3759, NULL, 5732);
INSERT INTO 'dancesrecordingsmap' VALUES (5125, 4424, NULL, 5733);
INSERT INTO 'dancesrecordingsmap' VALUES (5127, 2267, NULL, 5735);
INSERT INTO 'dancesrecordingsmap' VALUES (5128, 4784, NULL, 5736);
INSERT INTO 'dancesrecordingsmap' VALUES (5129, 11752, NULL, 4669);
INSERT INTO 'dancesrecordingsmap' VALUES (5130, 11753, NULL, 4916);
INSERT INTO 'dancesrecordingsmap' VALUES (5131, 11757, NULL, 123);
INSERT INTO 'dancesrecordingsmap' VALUES (5132, 9787, NULL, 5738);
INSERT INTO 'dancesrecordingsmap' VALUES (5133, 11543, NULL, 5745);
INSERT INTO 'dancesrecordingsmap' VALUES (5134, 11759, NULL, 4970);
INSERT INTO 'dancesrecordingsmap' VALUES (5136, 11768, NULL, 5338);
INSERT INTO 'dancesrecordingsmap' VALUES (5137, 11763, NULL, 5744);
INSERT INTO 'dancesrecordingsmap' VALUES (5138, 6964, NULL, 5739);
INSERT INTO 'dancesrecordingsmap' VALUES (5139, 6150, NULL, 5135);
INSERT INTO 'dancesrecordingsmap' VALUES (5142, 11771, NULL, 5741);
INSERT INTO 'dancesrecordingsmap' VALUES (5145, 1578, NULL, 5749);
INSERT INTO 'dancesrecordingsmap' VALUES (8244, 8749, NULL, 9275);
INSERT INTO 'dancesrecordingsmap' VALUES (5146, 2427, NULL, 5750);
INSERT INTO 'dancesrecordingsmap' VALUES (5147, 1595, NULL, 5751);
INSERT INTO 'dancesrecordingsmap' VALUES (5150, 4642, NULL, 5753);
INSERT INTO 'dancesrecordingsmap' VALUES (5151, 3786, NULL, 5756);
INSERT INTO 'dancesrecordingsmap' VALUES (5154, 312, NULL, 5759);
INSERT INTO 'dancesrecordingsmap' VALUES (5155, 3980, NULL, 5760);
INSERT INTO 'dancesrecordingsmap' VALUES (5156, 9940, NULL, 5761);
INSERT INTO 'dancesrecordingsmap' VALUES (5157, 7180, NULL, 5762);
INSERT INTO 'dancesrecordingsmap' VALUES (5118, 6349, NULL, 5726);
INSERT INTO 'dancesrecordingsmap' VALUES (5005, 10703, NULL, 5653);
INSERT INTO 'dancesrecordingsmap' VALUES (5112, 11393, NULL, 5722);
INSERT INTO 'dancesrecordingsmap' VALUES (5152, 6679, NULL, 5757);
INSERT INTO 'dancesrecordingsmap' VALUES (9108, 358, NULL, 10161);
INSERT INTO 'dancesrecordingsmap' VALUES (5090, 6386, NULL, 5705);
INSERT INTO 'dancesrecordingsmap' VALUES (5027, 11594, NULL, 5181);
INSERT INTO 'dancesrecordingsmap' VALUES (4976, 11371, NULL, 5629);
INSERT INTO 'dancesrecordingsmap' VALUES (5158, 1145, NULL, 5763);
INSERT INTO 'dancesrecordingsmap' VALUES (5159, 1352, NULL, 5764);
INSERT INTO 'dancesrecordingsmap' VALUES (5160, 5256, NULL, 5765);
INSERT INTO 'dancesrecordingsmap' VALUES (5161, 5437, NULL, 5766);
INSERT INTO 'dancesrecordingsmap' VALUES (5162, 5262, NULL, 5767);
INSERT INTO 'dancesrecordingsmap' VALUES (5163, 4173, NULL, 5768);
INSERT INTO 'dancesrecordingsmap' VALUES (5164, 4147, NULL, 5769);
INSERT INTO 'dancesrecordingsmap' VALUES (5165, 1505, NULL, 5770);
INSERT INTO 'dancesrecordingsmap' VALUES (5166, 1195, NULL, 5771);
INSERT INTO 'dancesrecordingsmap' VALUES (5167, 1467, NULL, 5772);
INSERT INTO 'dancesrecordingsmap' VALUES (5168, 428, NULL, 5773);
INSERT INTO 'dancesrecordingsmap' VALUES (5169, 2709, NULL, 5774);
INSERT INTO 'dancesrecordingsmap' VALUES (5170, 399, NULL, 5775);
INSERT INTO 'dancesrecordingsmap' VALUES (5171, 8956, NULL, 5776);
INSERT INTO 'dancesrecordingsmap' VALUES (5172, 1647, NULL, 5777);
INSERT INTO 'dancesrecordingsmap' VALUES (5173, 1647, NULL, 5778);
INSERT INTO 'dancesrecordingsmap' VALUES (5174, 1244, NULL, 5779);
INSERT INTO 'dancesrecordingsmap' VALUES (5175, 4155, NULL, 5780);
INSERT INTO 'dancesrecordingsmap' VALUES (5176, 5310, NULL, 5781);
INSERT INTO 'dancesrecordingsmap' VALUES (5178, 314, NULL, 5783);
INSERT INTO 'dancesrecordingsmap' VALUES (5179, 5934, NULL, 5784);
INSERT INTO 'dancesrecordingsmap' VALUES (5180, 6116, NULL, 5785);
INSERT INTO 'dancesrecordingsmap' VALUES (5181, 1428, NULL, 5786);
INSERT INTO 'dancesrecordingsmap' VALUES (5182, 3338, NULL, 5787);
INSERT INTO 'dancesrecordingsmap' VALUES (5184, 2644, NULL, 5790);
INSERT INTO 'dancesrecordingsmap' VALUES (5185, 2661, NULL, 5791);
INSERT INTO 'dancesrecordingsmap' VALUES (5186, 3235, NULL, 5792);
INSERT INTO 'dancesrecordingsmap' VALUES (5187, 3656, NULL, 5793);
INSERT INTO 'dancesrecordingsmap' VALUES (5188, 2140, NULL, 5794);
INSERT INTO 'dancesrecordingsmap' VALUES (5189, 3528, NULL, 5795);
INSERT INTO 'dancesrecordingsmap' VALUES (5190, 7247, NULL, 5796);
INSERT INTO 'dancesrecordingsmap' VALUES (5191, 5520, NULL, 5797);
INSERT INTO 'dancesrecordingsmap' VALUES (5192, 6178, NULL, 5798);
INSERT INTO 'dancesrecordingsmap' VALUES (5193, 541, NULL, 5799);
INSERT INTO 'dancesrecordingsmap' VALUES (5194, 1883, NULL, 5800);
INSERT INTO 'dancesrecordingsmap' VALUES (5195, 4032, NULL, 5801);
INSERT INTO 'dancesrecordingsmap' VALUES (5197, 10526, NULL, 5802);
INSERT INTO 'dancesrecordingsmap' VALUES (5198, 3373, NULL, 5803);
INSERT INTO 'dancesrecordingsmap' VALUES (5199, 2459, NULL, 5804);
INSERT INTO 'dancesrecordingsmap' VALUES (5200, 627, NULL, 5805);
INSERT INTO 'dancesrecordingsmap' VALUES (5201, 11762, NULL, 5806);
INSERT INTO 'dancesrecordingsmap' VALUES (5203, 11764, NULL, 5808);
INSERT INTO 'dancesrecordingsmap' VALUES (5204, 3486, NULL, 5809);
INSERT INTO 'dancesrecordingsmap' VALUES (5205, 3244, NULL, 5810);
INSERT INTO 'dancesrecordingsmap' VALUES (5177, 314, NULL, 5782);
INSERT INTO 'dancesrecordingsmap' VALUES (5208, 11765, NULL, 5813);
INSERT INTO 'dancesrecordingsmap' VALUES (5101, 11396, NULL, 5714);
INSERT INTO 'dancesrecordingsmap' VALUES (5148, 6043, NULL, 5752);
INSERT INTO 'dancesrecordingsmap' VALUES (5149, 6044, NULL, 5752);
INSERT INTO 'dancesrecordingsmap' VALUES (5074, 11636, NULL, 937);
INSERT INTO 'dancesrecordingsmap' VALUES (5103, 9640, NULL, 5715);
INSERT INTO 'dancesrecordingsmap' VALUES (5085, 11698, NULL, 893);
INSERT INTO 'dancesrecordingsmap' VALUES (5110, 11389, NULL, 5721);
INSERT INTO 'dancesrecordingsmap' VALUES (5109, 9642, NULL, 5720);
INSERT INTO 'dancesrecordingsmap' VALUES (5120, 1087, NULL, 5728);
INSERT INTO 'dancesrecordingsmap' VALUES (5108, 11395, NULL, 5719);
INSERT INTO 'dancesrecordingsmap' VALUES (5183, 3695, NULL, 5788);
INSERT INTO 'dancesrecordingsmap' VALUES (5123, 877, NULL, 5731);
INSERT INTO 'dancesrecordingsmap' VALUES (5206, 8258, NULL, 5811);
INSERT INTO 'dancesrecordingsmap' VALUES (5045, 7211, NULL, 1617);
INSERT INTO 'dancesrecordingsmap' VALUES (5153, 394, NULL, 5758);
INSERT INTO 'dancesrecordingsmap' VALUES (5069, 9646, NULL, 3194);
INSERT INTO 'dancesrecordingsmap' VALUES (5126, 373, NULL, 5734);
INSERT INTO 'dancesrecordingsmap' VALUES (5046, 1560, NULL, 2001);
INSERT INTO 'dancesrecordingsmap' VALUES (5209, 11766, NULL, 5814);
INSERT INTO 'dancesrecordingsmap' VALUES (5211, 11767, NULL, 5816);
INSERT INTO 'dancesrecordingsmap' VALUES (5212, 11195, NULL, 5817);
INSERT INTO 'dancesrecordingsmap' VALUES (5213, 11196, NULL, 5818);
INSERT INTO 'dancesrecordingsmap' VALUES (5214, 11197, NULL, 5819);
INSERT INTO 'dancesrecordingsmap' VALUES (5215, 11198, NULL, 5820);
INSERT INTO 'dancesrecordingsmap' VALUES (5216, 8529, NULL, 5821);
INSERT INTO 'dancesrecordingsmap' VALUES (5217, 11199, NULL, 5822);
INSERT INTO 'dancesrecordingsmap' VALUES (5218, 11199, NULL, 5823);
INSERT INTO 'dancesrecordingsmap' VALUES (5219, 11200, NULL, 5824);
INSERT INTO 'dancesrecordingsmap' VALUES (5220, 11201, NULL, 5825);
INSERT INTO 'dancesrecordingsmap' VALUES (5221, 11202, NULL, 5826);
INSERT INTO 'dancesrecordingsmap' VALUES (5223, 11203, NULL, 5828);
INSERT INTO 'dancesrecordingsmap' VALUES (5224, 9534, NULL, 5829);
INSERT INTO 'dancesrecordingsmap' VALUES (5225, 9406, NULL, 5830);
INSERT INTO 'dancesrecordingsmap' VALUES (5226, 1075, NULL, 5831);
INSERT INTO 'dancesrecordingsmap' VALUES (5227, 1937, NULL, 5832);
INSERT INTO 'dancesrecordingsmap' VALUES (5229, 1358, NULL, 5834);
INSERT INTO 'dancesrecordingsmap' VALUES (5230, 5667, NULL, 5835);
INSERT INTO 'dancesrecordingsmap' VALUES (5232, 5430, NULL, 5837);
INSERT INTO 'dancesrecordingsmap' VALUES (5233, 9234, NULL, 5838);
INSERT INTO 'dancesrecordingsmap' VALUES (5234, 9202, NULL, 5839);
INSERT INTO 'dancesrecordingsmap' VALUES (5235, 1907, NULL, 5840);
INSERT INTO 'dancesrecordingsmap' VALUES (5236, 9241, NULL, 5841);
INSERT INTO 'dancesrecordingsmap' VALUES (5237, 9207, NULL, 5842);
INSERT INTO 'dancesrecordingsmap' VALUES (8245, 8749, NULL, 9276);
INSERT INTO 'dancesrecordingsmap' VALUES (5239, 11877, NULL, 5844);
INSERT INTO 'dancesrecordingsmap' VALUES (5240, 6952, NULL, 5845);
INSERT INTO 'dancesrecordingsmap' VALUES (5241, 2972, NULL, 5846);
INSERT INTO 'dancesrecordingsmap' VALUES (5242, 4663, NULL, 5847);
INSERT INTO 'dancesrecordingsmap' VALUES (5243, 4804, NULL, 5848);
INSERT INTO 'dancesrecordingsmap' VALUES (5245, 4595, NULL, 5850);
INSERT INTO 'dancesrecordingsmap' VALUES (5246, 3154, NULL, 5851);
INSERT INTO 'dancesrecordingsmap' VALUES (5247, 4744, NULL, 5852);
INSERT INTO 'dancesrecordingsmap' VALUES (5248, 1780, NULL, 5853);
INSERT INTO 'dancesrecordingsmap' VALUES (5249, 6471, NULL, 5854);
INSERT INTO 'dancesrecordingsmap' VALUES (5250, 4433, NULL, 5855);
INSERT INTO 'dancesrecordingsmap' VALUES (5251, 3435, NULL, 5856);
INSERT INTO 'dancesrecordingsmap' VALUES (5252, 11890, NULL, 580);
INSERT INTO 'dancesrecordingsmap' VALUES (5253, 2498, NULL, 4387);
INSERT INTO 'dancesrecordingsmap' VALUES (5255, 353, NULL, 5857);
INSERT INTO 'dancesrecordingsmap' VALUES (5048, 4136, NULL, 779);
INSERT INTO 'dancesrecordingsmap' VALUES (5143, 11798, NULL, 781);
INSERT INTO 'dancesrecordingsmap' VALUES (5079, 462, NULL, 4505);
INSERT INTO 'dancesrecordingsmap' VALUES (5140, 1128, NULL, 95);
INSERT INTO 'dancesrecordingsmap' VALUES (5014, 10678, NULL, 5662);
INSERT INTO 'dancesrecordingsmap' VALUES (5141, 8143, NULL, 259);
INSERT INTO 'dancesrecordingsmap' VALUES (5196, 7365, NULL, 3777);
INSERT INTO 'dancesrecordingsmap' VALUES (5100, 9639, NULL, 5713);
INSERT INTO 'dancesrecordingsmap' VALUES (5231, 9407, NULL, 5836);
INSERT INTO 'dancesrecordingsmap' VALUES (5055, 4262, NULL, 5669);
INSERT INTO 'dancesrecordingsmap' VALUES (5135, 11760, NULL, 5039);
INSERT INTO 'dancesrecordingsmap' VALUES (5144, 2021, NULL, 5748);
INSERT INTO 'dancesrecordingsmap' VALUES (5256, 5006, NULL, 5858);
INSERT INTO 'dancesrecordingsmap' VALUES (5257, 1176, NULL, 5859);
INSERT INTO 'dancesrecordingsmap' VALUES (5258, 11599, NULL, 5861);
INSERT INTO 'dancesrecordingsmap' VALUES (5259, 3463, NULL, 5862);
INSERT INTO 'dancesrecordingsmap' VALUES (5260, 7111, NULL, 5863);
INSERT INTO 'dancesrecordingsmap' VALUES (5261, 4784, NULL, 5864);
INSERT INTO 'dancesrecordingsmap' VALUES (5262, 7547, NULL, 5865);
INSERT INTO 'dancesrecordingsmap' VALUES (5264, 9561, NULL, 5867);
INSERT INTO 'dancesrecordingsmap' VALUES (5265, 3338, NULL, 5868);
INSERT INTO 'dancesrecordingsmap' VALUES (5266, 3631, NULL, 5870);
INSERT INTO 'dancesrecordingsmap' VALUES (5267, 6010, NULL, 5871);
INSERT INTO 'dancesrecordingsmap' VALUES (5269, 312, NULL, 5872);
INSERT INTO 'dancesrecordingsmap' VALUES (5270, 3057, NULL, 5873);
INSERT INTO 'dancesrecordingsmap' VALUES (5271, 3057, NULL, 5874);
INSERT INTO 'dancesrecordingsmap' VALUES (5273, 10787, NULL, 5876);
INSERT INTO 'dancesrecordingsmap' VALUES (5274, 11189, NULL, 5877);
INSERT INTO 'dancesrecordingsmap' VALUES (5275, 11189, NULL, 5878);
INSERT INTO 'dancesrecordingsmap' VALUES (5276, 633, NULL, 5879);
INSERT INTO 'dancesrecordingsmap' VALUES (5277, 633, NULL, 5880);
INSERT INTO 'dancesrecordingsmap' VALUES (5278, 5525, NULL, 5881);
INSERT INTO 'dancesrecordingsmap' VALUES (5279, 462, NULL, 5882);
INSERT INTO 'dancesrecordingsmap' VALUES (5280, 2222, NULL, 5883);
INSERT INTO 'dancesrecordingsmap' VALUES (5281, 8832, NULL, 5885);
INSERT INTO 'dancesrecordingsmap' VALUES (5282, 5243, NULL, 5886);
INSERT INTO 'dancesrecordingsmap' VALUES (5283, 674, NULL, 5887);
INSERT INTO 'dancesrecordingsmap' VALUES (5284, 5552, NULL, 5888);
INSERT INTO 'dancesrecordingsmap' VALUES (5285, 8146, NULL, 5889);
INSERT INTO 'dancesrecordingsmap' VALUES (5286, 1864, NULL, 5890);
INSERT INTO 'dancesrecordingsmap' VALUES (5287, 8154, NULL, 5891);
INSERT INTO 'dancesrecordingsmap' VALUES (5288, 5591, NULL, 5892);
INSERT INTO 'dancesrecordingsmap' VALUES (5289, 7553, NULL, 5893);
INSERT INTO 'dancesrecordingsmap' VALUES (5290, 7546, NULL, 5895);
INSERT INTO 'dancesrecordingsmap' VALUES (5291, 7552, NULL, 5896);
INSERT INTO 'dancesrecordingsmap' VALUES (5292, 8143, NULL, 5903);
INSERT INTO 'dancesrecordingsmap' VALUES (5293, 11919, NULL, 5884);
INSERT INTO 'dancesrecordingsmap' VALUES (5294, 11921, NULL, 530);
INSERT INTO 'dancesrecordingsmap' VALUES (5295, 7441, NULL, 5905);
INSERT INTO 'dancesrecordingsmap' VALUES (5296, 1473, NULL, 5906);
INSERT INTO 'dancesrecordingsmap' VALUES (5297, 152, NULL, 5907);
INSERT INTO 'dancesrecordingsmap' VALUES (5298, 6048, NULL, 5909);
INSERT INTO 'dancesrecordingsmap' VALUES (5299, 5623, NULL, 5911);
INSERT INTO 'dancesrecordingsmap' VALUES (5301, 3980, NULL, 5913);
INSERT INTO 'dancesrecordingsmap' VALUES (5302, 6763, NULL, 5915);
INSERT INTO 'dancesrecordingsmap' VALUES (5303, 2267, NULL, 5916);
INSERT INTO 'dancesrecordingsmap' VALUES (5304, 2428, NULL, 5917);
INSERT INTO 'dancesrecordingsmap' VALUES (5305, 11946, NULL, 48);
INSERT INTO 'dancesrecordingsmap' VALUES (5306, 11947, NULL, 859);
INSERT INTO 'dancesrecordingsmap' VALUES (5307, 11948, NULL, 5123);
INSERT INTO 'dancesrecordingsmap' VALUES (5309, 11950, NULL, 35);
INSERT INTO 'dancesrecordingsmap' VALUES (5311, 11953, NULL, 4651);
INSERT INTO 'dancesrecordingsmap' VALUES (5312, 11954, NULL, 4941);
INSERT INTO 'dancesrecordingsmap' VALUES (5313, 11955, NULL, 5117);
INSERT INTO 'dancesrecordingsmap' VALUES (5314, 11956, NULL, 286);
INSERT INTO 'dancesrecordingsmap' VALUES (5315, 11959, NULL, 4976);
INSERT INTO 'dancesrecordingsmap' VALUES (5316, 11960, NULL, 638);
INSERT INTO 'dancesrecordingsmap' VALUES (5317, 11961, NULL, 1495);
INSERT INTO 'dancesrecordingsmap' VALUES (5318, 11962, NULL, 1142);
INSERT INTO 'dancesrecordingsmap' VALUES (5319, 11963, NULL, 3487);
INSERT INTO 'dancesrecordingsmap' VALUES (5320, 11964, NULL, 227);
INSERT INTO 'dancesrecordingsmap' VALUES (5321, 11965, NULL, 443);
INSERT INTO 'dancesrecordingsmap' VALUES (5322, 11966, NULL, 876);
INSERT INTO 'dancesrecordingsmap' VALUES (5323, 612, NULL, 5919);
INSERT INTO 'dancesrecordingsmap' VALUES (5324, 5063, NULL, 5919);
INSERT INTO 'dancesrecordingsmap' VALUES (5325, 4532, NULL, 5923);
INSERT INTO 'dancesrecordingsmap' VALUES (5326, 10870, NULL, 5923);
INSERT INTO 'dancesrecordingsmap' VALUES (5327, 3499, NULL, 5923);
INSERT INTO 'dancesrecordingsmap' VALUES (5328, 6366, NULL, 5924);
INSERT INTO 'dancesrecordingsmap' VALUES (5329, 4112, NULL, 5934);
INSERT INTO 'dancesrecordingsmap' VALUES (5330, 4262, NULL, 5934);
INSERT INTO 'dancesrecordingsmap' VALUES (5331, 5984, NULL, 5934);
INSERT INTO 'dancesrecordingsmap' VALUES (5332, 11957, NULL, 864);
INSERT INTO 'dancesrecordingsmap' VALUES (5334, 5564, NULL, 4164);
INSERT INTO 'dancesrecordingsmap' VALUES (5335, 8845, NULL, 4164);
INSERT INTO 'dancesrecordingsmap' VALUES (5336, 7182, NULL, 4164);
INSERT INTO 'dancesrecordingsmap' VALUES (5337, 2930, NULL, 4166);
INSERT INTO 'dancesrecordingsmap' VALUES (5338, 5520, NULL, 4160);
INSERT INTO 'dancesrecordingsmap' VALUES (5339, 5731, NULL, 4162);
INSERT INTO 'dancesrecordingsmap' VALUES (5340, 469, NULL, 4163);
INSERT INTO 'dancesrecordingsmap' VALUES (5341, 965, NULL, 4163);
INSERT INTO 'dancesrecordingsmap' VALUES (5342, 1497, NULL, 4163);
INSERT INTO 'dancesrecordingsmap' VALUES (5308, 11949, NULL, 3143);
INSERT INTO 'dancesrecordingsmap' VALUES (5222, 11204, NULL, 5827);
INSERT INTO 'dancesrecordingsmap' VALUES (5228, 9408, NULL, 5833);
INSERT INTO 'dancesrecordingsmap' VALUES (5263, 10794, NULL, 5866);
INSERT INTO 'dancesrecordingsmap' VALUES (5333, 11958, NULL, 3039);
INSERT INTO 'dancesrecordingsmap' VALUES (5268, 3058, NULL, 5869);
INSERT INTO 'dancesrecordingsmap' VALUES (5210, 9533, NULL, 5815);
INSERT INTO 'dancesrecordingsmap' VALUES (5343, 2603, NULL, 4163);
INSERT INTO 'dancesrecordingsmap' VALUES (5344, 5591, NULL, 4163);
INSERT INTO 'dancesrecordingsmap' VALUES (5345, 6848, NULL, 5936);
INSERT INTO 'dancesrecordingsmap' VALUES (5346, 3326, NULL, 5937);
INSERT INTO 'dancesrecordingsmap' VALUES (5347, 3580, NULL, 5938);
INSERT INTO 'dancesrecordingsmap' VALUES (5348, 2415, NULL, 5939);
INSERT INTO 'dancesrecordingsmap' VALUES (5349, 2437, NULL, 5940);
INSERT INTO 'dancesrecordingsmap' VALUES (5350, 3609, NULL, 5941);
INSERT INTO 'dancesrecordingsmap' VALUES (5353, 29, NULL, 1700);
INSERT INTO 'dancesrecordingsmap' VALUES (5354, 7213, NULL, 1821);
INSERT INTO 'dancesrecordingsmap' VALUES (5355, 7213, NULL, 193);
INSERT INTO 'dancesrecordingsmap' VALUES (5356, 5589, NULL, 1672);
INSERT INTO 'dancesrecordingsmap' VALUES (5357, 5589, NULL, 1254);
INSERT INTO 'dancesrecordingsmap' VALUES (5358, 6861, NULL, 3780);
INSERT INTO 'dancesrecordingsmap' VALUES (5359, 5569, NULL, 2309);
INSERT INTO 'dancesrecordingsmap' VALUES (5361, 5569, NULL, 4696);
INSERT INTO 'dancesrecordingsmap' VALUES (5363, 5569, NULL, 4910);
INSERT INTO 'dancesrecordingsmap' VALUES (5364, 2571, NULL, 1141);
INSERT INTO 'dancesrecordingsmap' VALUES (5365, 3957, NULL, 2279);
INSERT INTO 'dancesrecordingsmap' VALUES (5367, 7078, NULL, 2310);
INSERT INTO 'dancesrecordingsmap' VALUES (5368, 264, NULL, 4239);
INSERT INTO 'dancesrecordingsmap' VALUES (5369, 1982, NULL, 2870);
INSERT INTO 'dancesrecordingsmap' VALUES (5370, 6317, NULL, 627);
INSERT INTO 'dancesrecordingsmap' VALUES (5371, 6317, NULL, 2972);
INSERT INTO 'dancesrecordingsmap' VALUES (5372, 6317, NULL, 528);
INSERT INTO 'dancesrecordingsmap' VALUES (5373, 6317, NULL, 213);
INSERT INTO 'dancesrecordingsmap' VALUES (5374, 6317, NULL, 4059);
INSERT INTO 'dancesrecordingsmap' VALUES (5376, 6317, NULL, 5291);
INSERT INTO 'dancesrecordingsmap' VALUES (5377, 6317, NULL, 3455);
INSERT INTO 'dancesrecordingsmap' VALUES (5378, 6317, NULL, 4106);
INSERT INTO 'dancesrecordingsmap' VALUES (5379, 6317, NULL, 4146);
INSERT INTO 'dancesrecordingsmap' VALUES (5380, 6317, NULL, 4834);
INSERT INTO 'dancesrecordingsmap' VALUES (5383, 2558, NULL, 2240);
INSERT INTO 'dancesrecordingsmap' VALUES (5384, 2558, NULL, 4038);
INSERT INTO 'dancesrecordingsmap' VALUES (5385, 6833, NULL, 1236);
INSERT INTO 'dancesrecordingsmap' VALUES (5386, 262, NULL, 1804);
INSERT INTO 'dancesrecordingsmap' VALUES (5387, 5079, NULL, 5110);
INSERT INTO 'dancesrecordingsmap' VALUES (5389, 7709, NULL, 5136);
INSERT INTO 'dancesrecordingsmap' VALUES (5390, 7709, NULL, 1350);
INSERT INTO 'dancesrecordingsmap' VALUES (5391, 8199, NULL, 2628);
INSERT INTO 'dancesrecordingsmap' VALUES (5392, 2891, NULL, 5534);
INSERT INTO 'dancesrecordingsmap' VALUES (5393, 5913, NULL, 1979);
INSERT INTO 'dancesrecordingsmap' VALUES (5394, 7154, NULL, 1418);
INSERT INTO 'dancesrecordingsmap' VALUES (5410, 12004, NULL, 5960);
INSERT INTO 'dancesrecordingsmap' VALUES (5411, 12005, NULL, 5961);
INSERT INTO 'dancesrecordingsmap' VALUES (5412, 12006, NULL, 5962);
INSERT INTO 'dancesrecordingsmap' VALUES (5272, 743, NULL, 5875);
INSERT INTO 'dancesrecordingsmap' VALUES (5300, 5976, NULL, 5912);
INSERT INTO 'dancesrecordingsmap' VALUES (5362, 5569, NULL, 151);
INSERT INTO 'dancesrecordingsmap' VALUES (5244, 4725, NULL, 5849);
INSERT INTO 'dancesrecordingsmap' VALUES (5352, 2687, NULL, 614);
INSERT INTO 'dancesrecordingsmap' VALUES (5238, 4300, NULL, 5843);
INSERT INTO 'dancesrecordingsmap' VALUES (5413, 12007, NULL, 5963);
INSERT INTO 'dancesrecordingsmap' VALUES (5418, 11769, NULL, 5737);
INSERT INTO 'dancesrecordingsmap' VALUES (5419, 11770, NULL, 5740);
INSERT INTO 'dancesrecordingsmap' VALUES (5420, 11772, NULL, 5742);
INSERT INTO 'dancesrecordingsmap' VALUES (5422, 9093, NULL, 5746);
INSERT INTO 'dancesrecordingsmap' VALUES (5395, 9867, NULL, 142);
INSERT INTO 'dancesrecordingsmap' VALUES (5425, 12024, NULL, 2717);
INSERT INTO 'dancesrecordingsmap' VALUES (5426, 12025, NULL, 1943);
INSERT INTO 'dancesrecordingsmap' VALUES (5427, 10368, NULL, 1284);
INSERT INTO 'dancesrecordingsmap' VALUES (5428, 12026, NULL, 2641);
INSERT INTO 'dancesrecordingsmap' VALUES (5429, 12027, NULL, 2155);
INSERT INTO 'dancesrecordingsmap' VALUES (5430, 12028, NULL, 1329);
INSERT INTO 'dancesrecordingsmap' VALUES (5431, 12030, NULL, 1616);
INSERT INTO 'dancesrecordingsmap' VALUES (5432, 12031, NULL, 355);
INSERT INTO 'dancesrecordingsmap' VALUES (5433, 7546, NULL, 5968);
INSERT INTO 'dancesrecordingsmap' VALUES (5434, 6351, NULL, 5970);
INSERT INTO 'dancesrecordingsmap' VALUES (5435, 4102, NULL, 5971);
INSERT INTO 'dancesrecordingsmap' VALUES (5437, 4008, NULL, 5975);
INSERT INTO 'dancesrecordingsmap' VALUES (5438, 5525, NULL, 5976);
INSERT INTO 'dancesrecordingsmap' VALUES (5439, 8154, NULL, 5977);
INSERT INTO 'dancesrecordingsmap' VALUES (5440, 4239, NULL, 5980);
INSERT INTO 'dancesrecordingsmap' VALUES (5441, 12053, NULL, 5022);
INSERT INTO 'dancesrecordingsmap' VALUES (5442, 12056, NULL, 5559);
INSERT INTO 'dancesrecordingsmap' VALUES (5443, 12058, NULL, 5339);
INSERT INTO 'dancesrecordingsmap' VALUES (5444, 12059, NULL, 846);
INSERT INTO 'dancesrecordingsmap' VALUES (5445, 9741, NULL, 1141);
INSERT INTO 'dancesrecordingsmap' VALUES (5447, 11828, NULL, 5969);
INSERT INTO 'dancesrecordingsmap' VALUES (5448, 12069, NULL, 5981);
INSERT INTO 'dancesrecordingsmap' VALUES (5449, 12070, NULL, 5972);
INSERT INTO 'dancesrecordingsmap' VALUES (5450, 7345, NULL, 1133);
INSERT INTO 'dancesrecordingsmap' VALUES (5451, 7502, NULL, 1357);
INSERT INTO 'dancesrecordingsmap' VALUES (5452, 7502, NULL, 5785);
INSERT INTO 'dancesrecordingsmap' VALUES (5453, 7483, NULL, 907);
INSERT INTO 'dancesrecordingsmap' VALUES (5455, 7405, NULL, 773);
INSERT INTO 'dancesrecordingsmap' VALUES (5456, 7398, NULL, 1550);
INSERT INTO 'dancesrecordingsmap' VALUES (5460, 7491, NULL, 355);
INSERT INTO 'dancesrecordingsmap' VALUES (5463, 7493, NULL, 105);
INSERT INTO 'dancesrecordingsmap' VALUES (5465, 7410, NULL, 2270);
INSERT INTO 'dancesrecordingsmap' VALUES (5466, 7445, NULL, 723);
INSERT INTO 'dancesrecordingsmap' VALUES (5467, 7512, NULL, 1912);
INSERT INTO 'dancesrecordingsmap' VALUES (5375, 6317, NULL, 3767);
INSERT INTO 'dancesrecordingsmap' VALUES (5446, 12067, NULL, 4114);
INSERT INTO 'dancesrecordingsmap' VALUES (5381, 2966, NULL, 830);
INSERT INTO 'dancesrecordingsmap' VALUES (5382, 2965, NULL, 830);
INSERT INTO 'dancesrecordingsmap' VALUES (5469, 7354, NULL, 105);
INSERT INTO 'dancesrecordingsmap' VALUES (5470, 7248, NULL, 910);
INSERT INTO 'dancesrecordingsmap' VALUES (5471, 4237, NULL, 2402);
INSERT INTO 'dancesrecordingsmap' VALUES (5472, 6547, NULL, 1672);
INSERT INTO 'dancesrecordingsmap' VALUES (5473, 253, NULL, 1874);
INSERT INTO 'dancesrecordingsmap' VALUES (5474, 1487, NULL, 2542);
INSERT INTO 'dancesrecordingsmap' VALUES (5475, 4377, NULL, 1343);
INSERT INTO 'dancesrecordingsmap' VALUES (5476, 123, NULL, 2846);
INSERT INTO 'dancesrecordingsmap' VALUES (5477, 406, NULL, 2312);
INSERT INTO 'dancesrecordingsmap' VALUES (5479, 2898, NULL, 1127);
INSERT INTO 'dancesrecordingsmap' VALUES (5481, 9084, NULL, 5985);
INSERT INTO 'dancesrecordingsmap' VALUES (5482, 2469, NULL, 5986);
INSERT INTO 'dancesrecordingsmap' VALUES (5483, 7180, NULL, 5987);
INSERT INTO 'dancesrecordingsmap' VALUES (5484, 11369, NULL, 5988);
INSERT INTO 'dancesrecordingsmap' VALUES (5485, 1469, NULL, 5989);
INSERT INTO 'dancesrecordingsmap' VALUES (5486, 329, NULL, 5990);
INSERT INTO 'dancesrecordingsmap' VALUES (5487, 12108, NULL, 5991);
INSERT INTO 'dancesrecordingsmap' VALUES (5488, 7520, NULL, 5992);
INSERT INTO 'dancesrecordingsmap' VALUES (5489, 3108, NULL, 5994);
INSERT INTO 'dancesrecordingsmap' VALUES (5490, 674, NULL, 5995);
INSERT INTO 'dancesrecordingsmap' VALUES (5491, 2084, NULL, 5996);
INSERT INTO 'dancesrecordingsmap' VALUES (5492, 5326, NULL, 5997);
INSERT INTO 'dancesrecordingsmap' VALUES (5493, 11372, NULL, 5993);
INSERT INTO 'dancesrecordingsmap' VALUES (5494, 1244, NULL, 5998);
INSERT INTO 'dancesrecordingsmap' VALUES (5496, 5402, NULL, 6000);
INSERT INTO 'dancesrecordingsmap' VALUES (5497, 11370, NULL, 6001);
INSERT INTO 'dancesrecordingsmap' VALUES (5498, 9869, NULL, 6002);
INSERT INTO 'dancesrecordingsmap' VALUES (5499, 1791, NULL, 6003);
INSERT INTO 'dancesrecordingsmap' VALUES (5500, 1870, NULL, 2036);
INSERT INTO 'dancesrecordingsmap' VALUES (5502, 3440, NULL, 2601);
INSERT INTO 'dancesrecordingsmap' VALUES (5503, 1995, NULL, 1550);
INSERT INTO 'dancesrecordingsmap' VALUES (5504, 1042, NULL, 1348);
INSERT INTO 'dancesrecordingsmap' VALUES (5505, 6935, NULL, 1339);
INSERT INTO 'dancesrecordingsmap' VALUES (5506, 1984, NULL, 3151);
INSERT INTO 'dancesrecordingsmap' VALUES (5396, 9838, NULL, 243);
INSERT INTO 'dancesrecordingsmap' VALUES (5508, 1540, NULL, 1418);
INSERT INTO 'dancesrecordingsmap' VALUES (5509, 2403, NULL, 1141);
INSERT INTO 'dancesrecordingsmap' VALUES (5510, 2609, NULL, 915);
INSERT INTO 'dancesrecordingsmap' VALUES (5511, 5971, NULL, 1128);
INSERT INTO 'dancesrecordingsmap' VALUES (5513, 5601, NULL, 1356);
INSERT INTO 'dancesrecordingsmap' VALUES (5514, 1534, NULL, 2993);
INSERT INTO 'dancesrecordingsmap' VALUES (5515, 6004, NULL, 1490);
INSERT INTO 'dancesrecordingsmap' VALUES (5516, 6353, NULL, 2431);
INSERT INTO 'dancesrecordingsmap' VALUES (5518, 2029, NULL, 1362);
INSERT INTO 'dancesrecordingsmap' VALUES (5520, 3540, NULL, 193);
INSERT INTO 'dancesrecordingsmap' VALUES (5522, 2917, NULL, 52);
INSERT INTO 'dancesrecordingsmap' VALUES (5523, 2461, NULL, 1355);
INSERT INTO 'dancesrecordingsmap' VALUES (5524, 676, NULL, 1397);
INSERT INTO 'dancesrecordingsmap' VALUES (5527, 172, NULL, 1133);
INSERT INTO 'dancesrecordingsmap' VALUES (5454, 7535, NULL, 2497);
INSERT INTO 'dancesrecordingsmap' VALUES (5388, 7709, NULL, 2495);
INSERT INTO 'dancesrecordingsmap' VALUES (5414, 10904, NULL, 5964);
INSERT INTO 'dancesrecordingsmap' VALUES (5415, 10903, NULL, 5965);
INSERT INTO 'dancesrecordingsmap' VALUES (5416, 10905, NULL, 5966);
INSERT INTO 'dancesrecordingsmap' VALUES (5417, 10906, NULL, 5967);
INSERT INTO 'dancesrecordingsmap' VALUES (5424, 12023, NULL, 5567);
INSERT INTO 'dancesrecordingsmap' VALUES (5517, 6696, NULL, 1145);
INSERT INTO 'dancesrecordingsmap' VALUES (5398, 11997, NULL, 3115);
INSERT INTO 'dancesrecordingsmap' VALUES (5399, 11998, NULL, 4272);
INSERT INTO 'dancesrecordingsmap' VALUES (5400, 11999, NULL, 5949);
INSERT INTO 'dancesrecordingsmap' VALUES (5401, 11994, NULL, 5950);
INSERT INTO 'dancesrecordingsmap' VALUES (5397, 10501, NULL, 5951);
INSERT INTO 'dancesrecordingsmap' VALUES (5402, 12000, NULL, 5952);
INSERT INTO 'dancesrecordingsmap' VALUES (5403, 12001, NULL, 5953);
INSERT INTO 'dancesrecordingsmap' VALUES (5404, 11992, NULL, 5954);
INSERT INTO 'dancesrecordingsmap' VALUES (5406, 11991, NULL, 5956);
INSERT INTO 'dancesrecordingsmap' VALUES (5407, 11995, NULL, 5957);
INSERT INTO 'dancesrecordingsmap' VALUES (5408, 11996, NULL, 5958);
INSERT INTO 'dancesrecordingsmap' VALUES (5409, 12002, NULL, 5959);
INSERT INTO 'dancesrecordingsmap' VALUES (5351, 4726, NULL, 5943);
INSERT INTO 'dancesrecordingsmap' VALUES (5366, 1795, NULL, 809);
INSERT INTO 'dancesrecordingsmap' VALUES (5360, 5569, NULL, 3591);
INSERT INTO 'dancesrecordingsmap' VALUES (5521, 538, NULL, 1332);
INSERT INTO 'dancesrecordingsmap' VALUES (5478, 884, NULL, 909);
INSERT INTO 'dancesrecordingsmap' VALUES (5529, 2027, NULL, 2402);
INSERT INTO 'dancesrecordingsmap' VALUES (5530, 4889, NULL, 2524);
INSERT INTO 'dancesrecordingsmap' VALUES (5531, 883, NULL, 1360);
INSERT INTO 'dancesrecordingsmap' VALUES (5532, 6261, NULL, 2397);
INSERT INTO 'dancesrecordingsmap' VALUES (5533, 2165, NULL, 2403);
INSERT INTO 'dancesrecordingsmap' VALUES (5534, 4963, NULL, 725);
INSERT INTO 'dancesrecordingsmap' VALUES (5535, 3807, NULL, 1418);
INSERT INTO 'dancesrecordingsmap' VALUES (5536, 3822, NULL, 727);
INSERT INTO 'dancesrecordingsmap' VALUES (5537, 3015, NULL, 1619);
INSERT INTO 'dancesrecordingsmap' VALUES (5538, 6688, NULL, 910);
INSERT INTO 'dancesrecordingsmap' VALUES (5539, 1935, NULL, 294);
INSERT INTO 'dancesrecordingsmap' VALUES (5541, 2912, NULL, 1393);
INSERT INTO 'dancesrecordingsmap' VALUES (5542, 5078, NULL, 1795);
INSERT INTO 'dancesrecordingsmap' VALUES (5543, 539, NULL, 453);
INSERT INTO 'dancesrecordingsmap' VALUES (9110, 8653, NULL, 10163);
INSERT INTO 'dancesrecordingsmap' VALUES (5550, 561, NULL, 1543);
INSERT INTO 'dancesrecordingsmap' VALUES (5551, 269, NULL, 3119);
INSERT INTO 'dancesrecordingsmap' VALUES (5552, 4402, NULL, 64);
INSERT INTO 'dancesrecordingsmap' VALUES (5553, 5706, NULL, 1546);
INSERT INTO 'dancesrecordingsmap' VALUES (5554, 3163, NULL, 1260);
INSERT INTO 'dancesrecordingsmap' VALUES (5555, 817, NULL, 1495);
INSERT INTO 'dancesrecordingsmap' VALUES (5556, 124, NULL, 1795);
INSERT INTO 'dancesrecordingsmap' VALUES (5557, 6564, NULL, 727);
INSERT INTO 'dancesrecordingsmap' VALUES (5558, 4254, NULL, 1790);
INSERT INTO 'dancesrecordingsmap' VALUES (5559, 3674, NULL, 2144);
INSERT INTO 'dancesrecordingsmap' VALUES (5560, 3801, NULL, 1133);
INSERT INTO 'dancesrecordingsmap' VALUES (5561, 4860, NULL, 52);
INSERT INTO 'dancesrecordingsmap' VALUES (5562, 574, NULL, 184);
INSERT INTO 'dancesrecordingsmap' VALUES (5563, 3960, NULL, 1131);
INSERT INTO 'dancesrecordingsmap' VALUES (5566, 3187, NULL, 3083);
INSERT INTO 'dancesrecordingsmap' VALUES (5567, 3439, NULL, 1418);
INSERT INTO 'dancesrecordingsmap' VALUES (5569, 4719, NULL, 1417);
INSERT INTO 'dancesrecordingsmap' VALUES (5571, 7072, NULL, 1430);
INSERT INTO 'dancesrecordingsmap' VALUES (5572, 871, NULL, 6008);
INSERT INTO 'dancesrecordingsmap' VALUES (5573, 6633, NULL, 6009);
INSERT INTO 'dancesrecordingsmap' VALUES (5575, 1696, NULL, 6011);
INSERT INTO 'dancesrecordingsmap' VALUES (5576, 3388, NULL, 6012);
INSERT INTO 'dancesrecordingsmap' VALUES (5577, 7552, NULL, 374);
INSERT INTO 'dancesrecordingsmap' VALUES (5578, 537, NULL, 2151);
INSERT INTO 'dancesrecordingsmap' VALUES (5579, 1770, NULL, 2151);
INSERT INTO 'dancesrecordingsmap' VALUES (5580, 4936, NULL, 2151);
INSERT INTO 'dancesrecordingsmap' VALUES (5581, 2667, NULL, 2151);
INSERT INTO 'dancesrecordingsmap' VALUES (5582, 3287, NULL, 2151);
INSERT INTO 'dancesrecordingsmap' VALUES (5583, 4257, NULL, 2151);
INSERT INTO 'dancesrecordingsmap' VALUES (5584, 5729, NULL, 2151);
INSERT INTO 'dancesrecordingsmap' VALUES (5585, 6528, NULL, 3022);
INSERT INTO 'dancesrecordingsmap' VALUES (5586, 5961, NULL, 3025);
INSERT INTO 'dancesrecordingsmap' VALUES (5546, 3086, NULL, 5788);
INSERT INTO 'dancesrecordingsmap' VALUES (5525, 417, NULL, 1542);
INSERT INTO 'dancesrecordingsmap' VALUES (5461, 7492, NULL, 1857);
INSERT INTO 'dancesrecordingsmap' VALUES (5458, 7403, NULL, 2400);
INSERT INTO 'dancesrecordingsmap' VALUES (5464, 7425, NULL, 2003);
INSERT INTO 'dancesrecordingsmap' VALUES (5568, 5268, NULL, 1414);
INSERT INTO 'dancesrecordingsmap' VALUES (5457, 7497, NULL, 1613);
INSERT INTO 'dancesrecordingsmap' VALUES (5564, 4780, NULL, 1819);
INSERT INTO 'dancesrecordingsmap' VALUES (5519, 1732, NULL, 1404);
INSERT INTO 'dancesrecordingsmap' VALUES (5548, 6855, NULL, 1345);
INSERT INTO 'dancesrecordingsmap' VALUES (5544, 7066, NULL, 724);
INSERT INTO 'dancesrecordingsmap' VALUES (5587, 1209, NULL, 2870);
INSERT INTO 'dancesrecordingsmap' VALUES (5588, 4795, NULL, 2870);
INSERT INTO 'dancesrecordingsmap' VALUES (5589, 2785, NULL, 2871);
INSERT INTO 'dancesrecordingsmap' VALUES (5590, 5836, NULL, 2871);
INSERT INTO 'dancesrecordingsmap' VALUES (5592, 2513, NULL, 2874);
INSERT INTO 'dancesrecordingsmap' VALUES (5593, 6171, NULL, 2874);
INSERT INTO 'dancesrecordingsmap' VALUES (5594, 2857, NULL, 2875);
INSERT INTO 'dancesrecordingsmap' VALUES (5595, 3756, NULL, 2875);
INSERT INTO 'dancesrecordingsmap' VALUES (5596, 3994, NULL, 2875);
INSERT INTO 'dancesrecordingsmap' VALUES (5597, 4266, NULL, 2875);
INSERT INTO 'dancesrecordingsmap' VALUES (5598, 1060, NULL, 2877);
INSERT INTO 'dancesrecordingsmap' VALUES (5599, 5004, NULL, 2839);
INSERT INTO 'dancesrecordingsmap' VALUES (5600, 5688, NULL, 2839);
INSERT INTO 'dancesrecordingsmap' VALUES (5601, 2250, NULL, 2578);
INSERT INTO 'dancesrecordingsmap' VALUES (5602, 174, NULL, 3078);
INSERT INTO 'dancesrecordingsmap' VALUES (5603, 7940, NULL, 3078);
INSERT INTO 'dancesrecordingsmap' VALUES (5604, 2703, NULL, 2469);
INSERT INTO 'dancesrecordingsmap' VALUES (5606, 2409, NULL, 6016);
INSERT INTO 'dancesrecordingsmap' VALUES (5607, 1210, NULL, 6017);
INSERT INTO 'dancesrecordingsmap' VALUES (5608, 6711, NULL, 6018);
INSERT INTO 'dancesrecordingsmap' VALUES (5609, 1125, NULL, 2408);
INSERT INTO 'dancesrecordingsmap' VALUES (5611, 4004, NULL, 1547);
INSERT INTO 'dancesrecordingsmap' VALUES (5612, 1912, NULL, 184);
INSERT INTO 'dancesrecordingsmap' VALUES (5613, 2455, NULL, 1348);
INSERT INTO 'dancesrecordingsmap' VALUES (5614, 5633, NULL, 52);
INSERT INTO 'dancesrecordingsmap' VALUES (5615, 832, NULL, 1351);
INSERT INTO 'dancesrecordingsmap' VALUES (5616, 6869, NULL, 1418);
INSERT INTO 'dancesrecordingsmap' VALUES (5617, 423, NULL, 690);
INSERT INTO 'dancesrecordingsmap' VALUES (5618, 3930, NULL, 1782);
INSERT INTO 'dancesrecordingsmap' VALUES (5620, 5353, NULL, 1418);
INSERT INTO 'dancesrecordingsmap' VALUES (5621, 1993, NULL, 1343);
INSERT INTO 'dancesrecordingsmap' VALUES (5622, 5294, NULL, 727);
INSERT INTO 'dancesrecordingsmap' VALUES (5623, 3078, NULL, 1913);
INSERT INTO 'dancesrecordingsmap' VALUES (5624, 2031, NULL, 2969);
INSERT INTO 'dancesrecordingsmap' VALUES (5625, 374, NULL, 1358);
INSERT INTO 'dancesrecordingsmap' VALUES (5627, 5112, NULL, 1393);
INSERT INTO 'dancesrecordingsmap' VALUES (5628, 6480, NULL, 2530);
INSERT INTO 'dancesrecordingsmap' VALUES (5629, 2704, NULL, 1546);
INSERT INTO 'dancesrecordingsmap' VALUES (5630, 6932, NULL, 2146);
INSERT INTO 'dancesrecordingsmap' VALUES (5631, 2393, NULL, 2530);
INSERT INTO 'dancesrecordingsmap' VALUES (5633, 3090, NULL, 2422);
INSERT INTO 'dancesrecordingsmap' VALUES (5634, 5050, NULL, 717);
INSERT INTO 'dancesrecordingsmap' VALUES (5636, 133, NULL, 2462);
INSERT INTO 'dancesrecordingsmap' VALUES (5637, 2672, NULL, 1612);
INSERT INTO 'dancesrecordingsmap' VALUES (5565, 6070, NULL, 110);
INSERT INTO 'dancesrecordingsmap' VALUES (5512, 3011, NULL, 1811);
INSERT INTO 'dancesrecordingsmap' VALUES (5501, 176, NULL, 1812);
INSERT INTO 'dancesrecordingsmap' VALUES (5605, 1311, NULL, 2471);
INSERT INTO 'dancesrecordingsmap' VALUES (5526, 6120, NULL, 207);
INSERT INTO 'dancesrecordingsmap' VALUES (5480, 2414, NULL, 1327);
INSERT INTO 'dancesrecordingsmap' VALUES (5468, 7363, NULL, 2147);
INSERT INTO 'dancesrecordingsmap' VALUES (5639, 6905, NULL, 1495);
INSERT INTO 'dancesrecordingsmap' VALUES (5641, 5815, NULL, 1852);
INSERT INTO 'dancesrecordingsmap' VALUES (5642, 1583, NULL, 1877);
INSERT INTO 'dancesrecordingsmap' VALUES (5643, 2633, NULL, 718);
INSERT INTO 'dancesrecordingsmap' VALUES (5644, 6538, NULL, 2396);
INSERT INTO 'dancesrecordingsmap' VALUES (5645, 260, NULL, 1026);
INSERT INTO 'dancesrecordingsmap' VALUES (5646, 6100, NULL, 1548);
INSERT INTO 'dancesrecordingsmap' VALUES (5647, 3192, NULL, 2530);
INSERT INTO 'dancesrecordingsmap' VALUES (5648, 6154, NULL, 1133);
INSERT INTO 'dancesrecordingsmap' VALUES (5649, 6307, NULL, 188);
INSERT INTO 'dancesrecordingsmap' VALUES (5651, 7546, NULL, 6020);
INSERT INTO 'dancesrecordingsmap' VALUES (5652, 2979, NULL, 6021);
INSERT INTO 'dancesrecordingsmap' VALUES (5653, 8143, NULL, 6024);
INSERT INTO 'dancesrecordingsmap' VALUES (5654, 8146, NULL, 6026);
INSERT INTO 'dancesrecordingsmap' VALUES (5655, 3172, NULL, 6027);
INSERT INTO 'dancesrecordingsmap' VALUES (5656, 4827, NULL, 6031);
INSERT INTO 'dancesrecordingsmap' VALUES (5657, 7548, NULL, 6035);
INSERT INTO 'dancesrecordingsmap' VALUES (5658, 769, NULL, 6037);
INSERT INTO 'dancesrecordingsmap' VALUES (5659, 12426, NULL, 5935);
INSERT INTO 'dancesrecordingsmap' VALUES (5660, 12403, NULL, 2433);
INSERT INTO 'dancesrecordingsmap' VALUES (5661, 4297, NULL, 1913);
INSERT INTO 'dancesrecordingsmap' VALUES (5662, 2285, NULL, 1544);
INSERT INTO 'dancesrecordingsmap' VALUES (5663, 6504, NULL, 2431);
INSERT INTO 'dancesrecordingsmap' VALUES (5664, 4971, NULL, 2404);
INSERT INTO 'dancesrecordingsmap' VALUES (5665, 7092, NULL, 725);
INSERT INTO 'dancesrecordingsmap' VALUES (5666, 528, NULL, 1133);
INSERT INTO 'dancesrecordingsmap' VALUES (5668, 1667, NULL, 1781);
INSERT INTO 'dancesrecordingsmap' VALUES (5669, 5251, NULL, 1913);
INSERT INTO 'dancesrecordingsmap' VALUES (5670, 6049, NULL, 2404);
INSERT INTO 'dancesrecordingsmap' VALUES (5671, 5068, NULL, 5799);
INSERT INTO 'dancesrecordingsmap' VALUES (5672, 5753, NULL, 3018);
INSERT INTO 'dancesrecordingsmap' VALUES (5676, 1536, NULL, 720);
INSERT INTO 'dancesrecordingsmap' VALUES (5678, 4077, NULL, 2917);
INSERT INTO 'dancesrecordingsmap' VALUES (5679, 6806, NULL, 184);
INSERT INTO 'dancesrecordingsmap' VALUES (5680, 244, NULL, 1851);
INSERT INTO 'dancesrecordingsmap' VALUES (5681, 12432, NULL, 5555);
INSERT INTO 'dancesrecordingsmap' VALUES (5682, 12432, NULL, 794);
INSERT INTO 'dancesrecordingsmap' VALUES (5683, 12432, NULL, 3151);
INSERT INTO 'dancesrecordingsmap' VALUES (5685, 12437, NULL, 5792);
INSERT INTO 'dancesrecordingsmap' VALUES (5686, 12438, NULL, 3195);
INSERT INTO 'dancesrecordingsmap' VALUES (5687, 12439, NULL, 3578);
INSERT INTO 'dancesrecordingsmap' VALUES (5688, 12440, NULL, 1543);
INSERT INTO 'dancesrecordingsmap' VALUES (5689, 12442, NULL, 1128);
INSERT INTO 'dancesrecordingsmap' VALUES (5690, 12455, NULL, 674);
INSERT INTO 'dancesrecordingsmap' VALUES (5691, 12456, NULL, 868);
INSERT INTO 'dancesrecordingsmap' VALUES (5692, 12457, NULL, 663);
INSERT INTO 'dancesrecordingsmap' VALUES (5695, 12461, NULL, 4667);
INSERT INTO 'dancesrecordingsmap' VALUES (5696, 12462, NULL, 4668);
INSERT INTO 'dancesrecordingsmap' VALUES (5697, 12463, NULL, 4658);
INSERT INTO 'dancesrecordingsmap' VALUES (5698, 12464, NULL, 972);
INSERT INTO 'dancesrecordingsmap' VALUES (5699, 12465, NULL, 4668);
INSERT INTO 'dancesrecordingsmap' VALUES (5700, 12467, NULL, 4659);
INSERT INTO 'dancesrecordingsmap' VALUES (5701, 12468, NULL, 4667);
INSERT INTO 'dancesrecordingsmap' VALUES (5702, 12469, NULL, 4668);
INSERT INTO 'dancesrecordingsmap' VALUES (5703, 12472, NULL, 4659);
INSERT INTO 'dancesrecordingsmap' VALUES (5704, 12466, NULL, 3451);
INSERT INTO 'dancesrecordingsmap' VALUES (5705, 12470, NULL, 868);
INSERT INTO 'dancesrecordingsmap' VALUES (5706, 12471, NULL, 813);
INSERT INTO 'dancesrecordingsmap' VALUES (5707, 12473, NULL, 788);
INSERT INTO 'dancesrecordingsmap' VALUES (5708, 12474, NULL, 445);
INSERT INTO 'dancesrecordingsmap' VALUES (5709, 7061, NULL, 4429);
INSERT INTO 'dancesrecordingsmap' VALUES (5710, 11512, NULL, 6019);
INSERT INTO 'dancesrecordingsmap' VALUES (5712, 10381, NULL, 6039);
INSERT INTO 'dancesrecordingsmap' VALUES (5528, 5242, NULL, 2525);
INSERT INTO 'dancesrecordingsmap' VALUES (9112, 17271, NULL, 10168);
INSERT INTO 'dancesrecordingsmap' VALUES (5693, 12458, NULL, 677);
INSERT INTO 'dancesrecordingsmap' VALUES (5547, 4905, NULL, 266);
INSERT INTO 'dancesrecordingsmap' VALUES (5713, 1087, NULL, 6040);
INSERT INTO 'dancesrecordingsmap' VALUES (5714, 5885, NULL, 6041);
INSERT INTO 'dancesrecordingsmap' VALUES (5715, 12454, NULL, 6042);
INSERT INTO 'dancesrecordingsmap' VALUES (5716, 10535, NULL, 6043);
INSERT INTO 'dancesrecordingsmap' VALUES (5718, 2039, NULL, 6045);
INSERT INTO 'dancesrecordingsmap' VALUES (5719, 12454, NULL, 6046);
INSERT INTO 'dancesrecordingsmap' VALUES (5720, 10433, NULL, 6047);
INSERT INTO 'dancesrecordingsmap' VALUES (5721, 2039, NULL, 6048);
INSERT INTO 'dancesrecordingsmap' VALUES (5724, 12480, NULL, 848);
INSERT INTO 'dancesrecordingsmap' VALUES (5725, 12481, NULL, 853);
INSERT INTO 'dancesrecordingsmap' VALUES (5726, 12484, NULL, 2354);
INSERT INTO 'dancesrecordingsmap' VALUES (5727, 12483, NULL, 5049);
INSERT INTO 'dancesrecordingsmap' VALUES (5728, 12485, NULL, 4962);
INSERT INTO 'dancesrecordingsmap' VALUES (5730, 12489, NULL, 5558);
INSERT INTO 'dancesrecordingsmap' VALUES (5731, 12488, NULL, 847);
INSERT INTO 'dancesrecordingsmap' VALUES (5732, 12490, NULL, 318);
INSERT INTO 'dancesrecordingsmap' VALUES (5733, 12491, NULL, 3321);
INSERT INTO 'dancesrecordingsmap' VALUES (5734, 12492, NULL, 846);
INSERT INTO 'dancesrecordingsmap' VALUES (5735, 12493, NULL, 4975);
INSERT INTO 'dancesrecordingsmap' VALUES (5737, 12495, NULL, 1431);
INSERT INTO 'dancesrecordingsmap' VALUES (5738, 12487, NULL, 2117);
INSERT INTO 'dancesrecordingsmap' VALUES (5739, 12120, NULL, 1368);
INSERT INTO 'dancesrecordingsmap' VALUES (5741, 12497, NULL, 4487);
INSERT INTO 'dancesrecordingsmap' VALUES (5743, 12500, NULL, 847);
INSERT INTO 'dancesrecordingsmap' VALUES (5744, 12501, NULL, 853);
INSERT INTO 'dancesrecordingsmap' VALUES (5745, 12499, NULL, 166);
INSERT INTO 'dancesrecordingsmap' VALUES (5746, 5222, NULL, 6049);
INSERT INTO 'dancesrecordingsmap' VALUES (5747, 1615, NULL, 6050);
INSERT INTO 'dancesrecordingsmap' VALUES (5748, 608, NULL, 6051);
INSERT INTO 'dancesrecordingsmap' VALUES (5750, 12505, NULL, 1642);
INSERT INTO 'dancesrecordingsmap' VALUES (5751, 12509, NULL, 1921);
INSERT INTO 'dancesrecordingsmap' VALUES (5752, 2935, NULL, 6053);
INSERT INTO 'dancesrecordingsmap' VALUES (5753, 3504, NULL, 6054);
INSERT INTO 'dancesrecordingsmap' VALUES (5754, 5889, NULL, 6055);
INSERT INTO 'dancesrecordingsmap' VALUES (5755, 3424, NULL, 6056);
INSERT INTO 'dancesrecordingsmap' VALUES (5756, 3310, NULL, 6057);
INSERT INTO 'dancesrecordingsmap' VALUES (5757, 7560, NULL, 6058);
INSERT INTO 'dancesrecordingsmap' VALUES (5758, 1578, NULL, 6059);
INSERT INTO 'dancesrecordingsmap' VALUES (5759, 1207, NULL, 6060);
INSERT INTO 'dancesrecordingsmap' VALUES (5760, 413, NULL, 6062);
INSERT INTO 'dancesrecordingsmap' VALUES (5761, 4491, NULL, 6063);
INSERT INTO 'dancesrecordingsmap' VALUES (5762, 5330, NULL, 6064);
INSERT INTO 'dancesrecordingsmap' VALUES (5763, 10774, NULL, 6065);
INSERT INTO 'dancesrecordingsmap' VALUES (5764, 1535, NULL, 6066);
INSERT INTO 'dancesrecordingsmap' VALUES (5765, 6152, NULL, 6067);
INSERT INTO 'dancesrecordingsmap' VALUES (5766, 223, NULL, 6068);
INSERT INTO 'dancesrecordingsmap' VALUES (5768, 12566, NULL, 3431);
INSERT INTO 'dancesrecordingsmap' VALUES (5769, 12567, NULL, 2526);
INSERT INTO 'dancesrecordingsmap' VALUES (5770, 12567, NULL, 3565);
INSERT INTO 'dancesrecordingsmap' VALUES (5772, 12567, NULL, 4618);
INSERT INTO 'dancesrecordingsmap' VALUES (5773, 12572, NULL, 2458);
INSERT INTO 'dancesrecordingsmap' VALUES (5722, 12478, NULL, 845);
INSERT INTO 'dancesrecordingsmap' VALUES (5591, 1087, NULL, 2873);
INSERT INTO 'dancesrecordingsmap' VALUES (5749, 4195, NULL, 6052);
INSERT INTO 'dancesrecordingsmap' VALUES (5736, 12173, NULL, 5331);
INSERT INTO 'dancesrecordingsmap' VALUES (5640, 2738, NULL, 2003);
INSERT INTO 'dancesrecordingsmap' VALUES (5619, 6194, NULL, 1414);
INSERT INTO 'dancesrecordingsmap' VALUES (5667, 6293, NULL, 1614);
INSERT INTO 'dancesrecordingsmap' VALUES (5626, 125, NULL, 1857);
INSERT INTO 'dancesrecordingsmap' VALUES (5610, 3167, NULL, 1398);
INSERT INTO 'dancesrecordingsmap' VALUES (5675, 5505, NULL, 2457);
INSERT INTO 'dancesrecordingsmap' VALUES (5635, 5587, NULL, 724);
INSERT INTO 'dancesrecordingsmap' VALUES (5673, 3673, NULL, 2001);
INSERT INTO 'dancesrecordingsmap' VALUES (5774, 12603, NULL, 4825);
INSERT INTO 'dancesrecordingsmap' VALUES (5775, 12605, NULL, 297);
INSERT INTO 'dancesrecordingsmap' VALUES (5776, 12373, NULL, 1612);
INSERT INTO 'dancesrecordingsmap' VALUES (5777, 12640, NULL, 4681);
INSERT INTO 'dancesrecordingsmap' VALUES (5778, 1544, NULL, 6069);
INSERT INTO 'dancesrecordingsmap' VALUES (5779, 4995, NULL, 6070);
INSERT INTO 'dancesrecordingsmap' VALUES (5780, 4662, NULL, 6071);
INSERT INTO 'dancesrecordingsmap' VALUES (5781, 3231, NULL, 6072);
INSERT INTO 'dancesrecordingsmap' VALUES (5782, 5794, NULL, 6073);
INSERT INTO 'dancesrecordingsmap' VALUES (5783, 377, NULL, 6074);
INSERT INTO 'dancesrecordingsmap' VALUES (5784, 6817, NULL, 6076);
INSERT INTO 'dancesrecordingsmap' VALUES (5786, 2807, NULL, 6078);
INSERT INTO 'dancesrecordingsmap' VALUES (5787, 1280, NULL, 6079);
INSERT INTO 'dancesrecordingsmap' VALUES (5788, 109, NULL, 6081);
INSERT INTO 'dancesrecordingsmap' VALUES (5789, 4103, NULL, 6082);
INSERT INTO 'dancesrecordingsmap' VALUES (5790, 12643, NULL, 861);
INSERT INTO 'dancesrecordingsmap' VALUES (5791, 12645, NULL, 868);
INSERT INTO 'dancesrecordingsmap' VALUES (5793, 12644, NULL, 512);
INSERT INTO 'dancesrecordingsmap' VALUES (5794, 12646, NULL, 946);
INSERT INTO 'dancesrecordingsmap' VALUES (5795, 12648, NULL, 900);
INSERT INTO 'dancesrecordingsmap' VALUES (5797, 12651, NULL, 5139);
INSERT INTO 'dancesrecordingsmap' VALUES (5798, 12652, NULL, 5232);
INSERT INTO 'dancesrecordingsmap' VALUES (5799, 12653, NULL, 3426);
INSERT INTO 'dancesrecordingsmap' VALUES (5800, 12654, NULL, 639);
INSERT INTO 'dancesrecordingsmap' VALUES (5801, 12655, NULL, 842);
INSERT INTO 'dancesrecordingsmap' VALUES (5802, 12656, NULL, 5232);
INSERT INTO 'dancesrecordingsmap' VALUES (5803, 12658, NULL, 5237);
INSERT INTO 'dancesrecordingsmap' VALUES (5804, 12659, NULL, 5234);
INSERT INTO 'dancesrecordingsmap' VALUES (5805, 9841, NULL, 5236);
INSERT INTO 'dancesrecordingsmap' VALUES (5806, 10930, NULL, 5233);
INSERT INTO 'dancesrecordingsmap' VALUES (5807, 12657, NULL, 3556);
INSERT INTO 'dancesrecordingsmap' VALUES (5808, 12275, NULL, 5271);
INSERT INTO 'dancesrecordingsmap' VALUES (5836, 3326, NULL, 6107);
INSERT INTO 'dancesrecordingsmap' VALUES (5811, 11230, NULL, 1007);
INSERT INTO 'dancesrecordingsmap' VALUES (5812, 12582, NULL, 5472);
INSERT INTO 'dancesrecordingsmap' VALUES (5813, 12660, NULL, 3587);
INSERT INTO 'dancesrecordingsmap' VALUES (5814, 3786, NULL, 6084);
INSERT INTO 'dancesrecordingsmap' VALUES (5815, 7111, NULL, 6085);
INSERT INTO 'dancesrecordingsmap' VALUES (5816, 109, NULL, 6086);
INSERT INTO 'dancesrecordingsmap' VALUES (5817, 909, NULL, 6087);
INSERT INTO 'dancesrecordingsmap' VALUES (5818, 2409, NULL, 6088);
INSERT INTO 'dancesrecordingsmap' VALUES (5819, 312, NULL, 6089);
INSERT INTO 'dancesrecordingsmap' VALUES (5820, 5829, NULL, 6091);
INSERT INTO 'dancesrecordingsmap' VALUES (5821, 12085, NULL, 6092);
INSERT INTO 'dancesrecordingsmap' VALUES (5823, 6915, NULL, 6093);
INSERT INTO 'dancesrecordingsmap' VALUES (5824, 3799, NULL, 6094);
INSERT INTO 'dancesrecordingsmap' VALUES (5825, 5403, NULL, 6095);
INSERT INTO 'dancesrecordingsmap' VALUES (5677, 6050, NULL, 1811);
INSERT INTO 'dancesrecordingsmap' VALUES (5771, 12567, NULL, 1765);
INSERT INTO 'dancesrecordingsmap' VALUES (5729, 12486, NULL, 172);
INSERT INTO 'dancesrecordingsmap' VALUES (5711, 10663, NULL, 6038);
INSERT INTO 'dancesrecordingsmap' VALUES (5684, 12433, NULL, 3109);
INSERT INTO 'dancesrecordingsmap' VALUES (5632, 5781, NULL, 2489);
INSERT INTO 'dancesrecordingsmap' VALUES (5826, 223, NULL, 6096);
INSERT INTO 'dancesrecordingsmap' VALUES (5827, 1931, NULL, 6097);
INSERT INTO 'dancesrecordingsmap' VALUES (5828, 5497, NULL, 6098);
INSERT INTO 'dancesrecordingsmap' VALUES (5829, 3834, NULL, 6099);
INSERT INTO 'dancesrecordingsmap' VALUES (5831, 3561, NULL, 6102);
INSERT INTO 'dancesrecordingsmap' VALUES (5832, 4155, NULL, 6103);
INSERT INTO 'dancesrecordingsmap' VALUES (5833, 3941, NULL, 6104);
INSERT INTO 'dancesrecordingsmap' VALUES (5834, 894, NULL, 6105);
INSERT INTO 'dancesrecordingsmap' VALUES (5835, 2813, NULL, 6106);
INSERT INTO 'dancesrecordingsmap' VALUES (5837, 1388, NULL, 6109);
INSERT INTO 'dancesrecordingsmap' VALUES (5838, 6629, NULL, 6111);
INSERT INTO 'dancesrecordingsmap' VALUES (5839, 2962, NULL, 6112);
INSERT INTO 'dancesrecordingsmap' VALUES (5840, 8839, NULL, 6110);
INSERT INTO 'dancesrecordingsmap' VALUES (9111, 17558, NULL, 10164);
INSERT INTO 'dancesrecordingsmap' VALUES (5842, 12669, NULL, 4943);
INSERT INTO 'dancesrecordingsmap' VALUES (5843, 12670, NULL, 859);
INSERT INTO 'dancesrecordingsmap' VALUES (5844, 1786, NULL, 6113);
INSERT INTO 'dancesrecordingsmap' VALUES (5845, 541, NULL, 6114);
INSERT INTO 'dancesrecordingsmap' VALUES (5847, 5713, NULL, 6116);
INSERT INTO 'dancesrecordingsmap' VALUES (5849, 5426, NULL, 6118);
INSERT INTO 'dancesrecordingsmap' VALUES (5850, 354, NULL, 6119);
INSERT INTO 'dancesrecordingsmap' VALUES (5851, 5463, NULL, 6120);
INSERT INTO 'dancesrecordingsmap' VALUES (5852, 6393, NULL, 6121);
INSERT INTO 'dancesrecordingsmap' VALUES (5854, 12124, NULL, 6123);
INSERT INTO 'dancesrecordingsmap' VALUES (5855, 3921, NULL, 6124);
INSERT INTO 'dancesrecordingsmap' VALUES (5856, 2947, NULL, 6125);
INSERT INTO 'dancesrecordingsmap' VALUES (5857, 6271, NULL, 6126);
INSERT INTO 'dancesrecordingsmap' VALUES (5858, 2110, NULL, 6127);
INSERT INTO 'dancesrecordingsmap' VALUES (5859, 4227, NULL, 6128);
INSERT INTO 'dancesrecordingsmap' VALUES (5860, 4864, NULL, 6129);
INSERT INTO 'dancesrecordingsmap' VALUES (5861, 3045, NULL, 6130);
INSERT INTO 'dancesrecordingsmap' VALUES (5862, 980, NULL, 6131);
INSERT INTO 'dancesrecordingsmap' VALUES (5863, 972, NULL, 6132);
INSERT INTO 'dancesrecordingsmap' VALUES (5864, 2415, NULL, 6133);
INSERT INTO 'dancesrecordingsmap' VALUES (5865, 3953, NULL, 6134);
INSERT INTO 'dancesrecordingsmap' VALUES (5866, 3887, NULL, 6135);
INSERT INTO 'dancesrecordingsmap' VALUES (5867, 4359, NULL, 6136);
INSERT INTO 'dancesrecordingsmap' VALUES (5868, 6539, NULL, 6137);
INSERT INTO 'dancesrecordingsmap' VALUES (5869, 222, NULL, 6138);
INSERT INTO 'dancesrecordingsmap' VALUES (5870, 6518, NULL, 6139);
INSERT INTO 'dancesrecordingsmap' VALUES (5871, 6957, NULL, 6140);
INSERT INTO 'dancesrecordingsmap' VALUES (5872, 4716, NULL, 6080);
INSERT INTO 'dancesrecordingsmap' VALUES (5873, 5480, NULL, 6083);
INSERT INTO 'dancesrecordingsmap' VALUES (5875, 9102, NULL, 6141);
INSERT INTO 'dancesrecordingsmap' VALUES (5876, 1478, NULL, 6142);
INSERT INTO 'dancesrecordingsmap' VALUES (5877, 1641, NULL, 6143);
INSERT INTO 'dancesrecordingsmap' VALUES (5878, 2260, NULL, 6144);
INSERT INTO 'dancesrecordingsmap' VALUES (5879, 2260, NULL, 6145);
INSERT INTO 'dancesrecordingsmap' VALUES (5880, 3267, NULL, 6146);
INSERT INTO 'dancesrecordingsmap' VALUES (5881, 2972, NULL, 6147);
INSERT INTO 'dancesrecordingsmap' VALUES (5883, 5160, NULL, 6149);
INSERT INTO 'dancesrecordingsmap' VALUES (5884, 2389, NULL, 6150);
INSERT INTO 'dancesrecordingsmap' VALUES (5885, 3435, NULL, 6151);
INSERT INTO 'dancesrecordingsmap' VALUES (5886, 4805, NULL, 6152);
INSERT INTO 'dancesrecordingsmap' VALUES (5887, 10791, NULL, 6153);
INSERT INTO 'dancesrecordingsmap' VALUES (5888, 1582, NULL, 6154);
INSERT INTO 'dancesrecordingsmap' VALUES (5889, 3593, NULL, 6155);
INSERT INTO 'dancesrecordingsmap' VALUES (5890, 2004, NULL, 6156);
INSERT INTO 'dancesrecordingsmap' VALUES (5891, 1792, NULL, 6157);
INSERT INTO 'dancesrecordingsmap' VALUES (5892, 4782, NULL, 6158);
INSERT INTO 'dancesrecordingsmap' VALUES (5895, 4092, NULL, 6161);
INSERT INTO 'dancesrecordingsmap' VALUES (5896, 3580, NULL, 6162);
INSERT INTO 'dancesrecordingsmap' VALUES (5897, 4239, NULL, 6163);
INSERT INTO 'dancesrecordingsmap' VALUES (5767, 4365, NULL, 5860);
INSERT INTO 'dancesrecordingsmap' VALUES (5853, 5389, NULL, 6122);
INSERT INTO 'dancesrecordingsmap' VALUES (5846, 12106, NULL, 6115);
INSERT INTO 'dancesrecordingsmap' VALUES (5723, 12479, NULL, 855);
INSERT INTO 'dancesrecordingsmap' VALUES (5717, 10433, NULL, 6044);
INSERT INTO 'dancesrecordingsmap' VALUES (5882, 3310, NULL, 6148);
INSERT INTO 'dancesrecordingsmap' VALUES (5796, 12650, NULL, 965);
INSERT INTO 'dancesrecordingsmap' VALUES (5792, 12647, NULL, 4699);
INSERT INTO 'dancesrecordingsmap' VALUES (5898, 2024, NULL, 6164);
INSERT INTO 'dancesrecordingsmap' VALUES (5899, 3558, NULL, 6165);
INSERT INTO 'dancesrecordingsmap' VALUES (5900, 3953, NULL, 6166);
INSERT INTO 'dancesrecordingsmap' VALUES (5901, 1480, NULL, 6167);
INSERT INTO 'dancesrecordingsmap' VALUES (5902, 778, NULL, 6168);
INSERT INTO 'dancesrecordingsmap' VALUES (5903, 11892, NULL, 6169);
INSERT INTO 'dancesrecordingsmap' VALUES (5904, 1784, NULL, 6170);
INSERT INTO 'dancesrecordingsmap' VALUES (5906, 7274, NULL, 6172);
INSERT INTO 'dancesrecordingsmap' VALUES (5907, 7289, NULL, 6174);
INSERT INTO 'dancesrecordingsmap' VALUES (5908, 7293, NULL, 6175);
INSERT INTO 'dancesrecordingsmap' VALUES (5909, 11897, NULL, 6176);
INSERT INTO 'dancesrecordingsmap' VALUES (5911, 6204, NULL, 6178);
INSERT INTO 'dancesrecordingsmap' VALUES (5912, 12665, NULL, 6179);
INSERT INTO 'dancesrecordingsmap' VALUES (5913, 9420, NULL, 6180);
INSERT INTO 'dancesrecordingsmap' VALUES (5914, 9528, NULL, 6181);
INSERT INTO 'dancesrecordingsmap' VALUES (5915, 9422, NULL, 6182);
INSERT INTO 'dancesrecordingsmap' VALUES (5916, 7296, NULL, 6183);
INSERT INTO 'dancesrecordingsmap' VALUES (5918, 6821, NULL, 1141);
INSERT INTO 'dancesrecordingsmap' VALUES (5919, 961, NULL, 61);
INSERT INTO 'dancesrecordingsmap' VALUES (5920, 2634, NULL, 1913);
INSERT INTO 'dancesrecordingsmap' VALUES (5921, 6148, NULL, 6185);
INSERT INTO 'dancesrecordingsmap' VALUES (5922, 12723, NULL, 4595);
INSERT INTO 'dancesrecordingsmap' VALUES (5923, 12725, NULL, 5012);
INSERT INTO 'dancesrecordingsmap' VALUES (5924, 3154, NULL, 6202);
INSERT INTO 'dancesrecordingsmap' VALUES (5925, 1786, NULL, 6205);
INSERT INTO 'dancesrecordingsmap' VALUES (5926, 3834, NULL, 6207);
INSERT INTO 'dancesrecordingsmap' VALUES (5927, 5982, NULL, 6208);
INSERT INTO 'dancesrecordingsmap' VALUES (5928, 4641, NULL, 6212);
INSERT INTO 'dancesrecordingsmap' VALUES (5929, 1582, NULL, 6214);
INSERT INTO 'dancesrecordingsmap' VALUES (5931, 7109, NULL, 6220);
INSERT INTO 'dancesrecordingsmap' VALUES (5932, 2388, NULL, 6221);
INSERT INTO 'dancesrecordingsmap' VALUES (5934, 12729, NULL, 6215);
INSERT INTO 'dancesrecordingsmap' VALUES (5935, 12728, NULL, 6211);
INSERT INTO 'dancesrecordingsmap' VALUES (5936, 9893, NULL, 371);
INSERT INTO 'dancesrecordingsmap' VALUES (5938, 12730, NULL, 964);
INSERT INTO 'dancesrecordingsmap' VALUES (5939, 11704, NULL, 5771);
INSERT INTO 'dancesrecordingsmap' VALUES (5940, 11704, NULL, 4583);
INSERT INTO 'dancesrecordingsmap' VALUES (5941, 11704, NULL, 5864);
INSERT INTO 'dancesrecordingsmap' VALUES (5942, 11704, NULL, 2636);
INSERT INTO 'dancesrecordingsmap' VALUES (5943, 11704, NULL, 2580);
INSERT INTO 'dancesrecordingsmap' VALUES (5944, 11704, NULL, 5736);
INSERT INTO 'dancesrecordingsmap' VALUES (5946, 413, NULL, 6235);
INSERT INTO 'dancesrecordingsmap' VALUES (5947, 349, NULL, 6238);
INSERT INTO 'dancesrecordingsmap' VALUES (5948, 7111, NULL, 6241);
INSERT INTO 'dancesrecordingsmap' VALUES (5949, 4784, NULL, 5771);
INSERT INTO 'dancesrecordingsmap' VALUES (5950, 12747, NULL, 6243);
INSERT INTO 'dancesrecordingsmap' VALUES (5951, 12748, NULL, 6244);
INSERT INTO 'dancesrecordingsmap' VALUES (5953, 12750, NULL, 6246);
INSERT INTO 'dancesrecordingsmap' VALUES (5954, 12751, NULL, 6247);
INSERT INTO 'dancesrecordingsmap' VALUES (5955, 11703, NULL, 6248);
INSERT INTO 'dancesrecordingsmap' VALUES (5956, 12752, NULL, 6249);
INSERT INTO 'dancesrecordingsmap' VALUES (5957, 12753, NULL, 6250);
INSERT INTO 'dancesrecordingsmap' VALUES (5958, 12754, NULL, 6251);
INSERT INTO 'dancesrecordingsmap' VALUES (5959, 12755, NULL, 6252);
INSERT INTO 'dancesrecordingsmap' VALUES (5960, 12756, NULL, 6253);
INSERT INTO 'dancesrecordingsmap' VALUES (5961, 12757, NULL, 6254);
INSERT INTO 'dancesrecordingsmap' VALUES (5933, 5216, NULL, 6209);
INSERT INTO 'dancesrecordingsmap' VALUES (9113, 9205, NULL, 10169);
INSERT INTO 'dancesrecordingsmap' VALUES (5822, 5964, NULL, 6090);
INSERT INTO 'dancesrecordingsmap' VALUES (5945, 3759, NULL, 6233);
INSERT INTO 'dancesrecordingsmap' VALUES (5848, 4911, NULL, 6117);
INSERT INTO 'dancesrecordingsmap' VALUES (5874, 6474, NULL, 2141);
INSERT INTO 'dancesrecordingsmap' VALUES (5894, 5525, NULL, 6160);
INSERT INTO 'dancesrecordingsmap' VALUES (5962, 12758, NULL, 6255);
INSERT INTO 'dancesrecordingsmap' VALUES (5963, 9381, NULL, 6260);
INSERT INTO 'dancesrecordingsmap' VALUES (5964, 2756, NULL, 6261);
INSERT INTO 'dancesrecordingsmap' VALUES (5965, 3136, NULL, 6261);
INSERT INTO 'dancesrecordingsmap' VALUES (5966, 4252, NULL, 6261);
INSERT INTO 'dancesrecordingsmap' VALUES (5967, 5198, NULL, 6261);
INSERT INTO 'dancesrecordingsmap' VALUES (5968, 5296, NULL, 6262);
INSERT INTO 'dancesrecordingsmap' VALUES (5969, 8090, NULL, 6262);
INSERT INTO 'dancesrecordingsmap' VALUES (5970, 6645, NULL, 6264);
INSERT INTO 'dancesrecordingsmap' VALUES (5971, 648, NULL, 6265);
INSERT INTO 'dancesrecordingsmap' VALUES (5972, 1303, NULL, 6265);
INSERT INTO 'dancesrecordingsmap' VALUES (5973, 1616, NULL, 6265);
INSERT INTO 'dancesrecordingsmap' VALUES (5974, 1830, NULL, 6265);
INSERT INTO 'dancesrecordingsmap' VALUES (5975, 3154, NULL, 6265);
INSERT INTO 'dancesrecordingsmap' VALUES (5976, 11485, NULL, 6265);
INSERT INTO 'dancesrecordingsmap' VALUES (5977, 3369, NULL, 6265);
INSERT INTO 'dancesrecordingsmap' VALUES (5978, 6064, NULL, 6265);
INSERT INTO 'dancesrecordingsmap' VALUES (5979, 12759, NULL, 6267);
INSERT INTO 'dancesrecordingsmap' VALUES (5980, 12760, NULL, 6268);
INSERT INTO 'dancesrecordingsmap' VALUES (5981, 12761, NULL, 6269);
INSERT INTO 'dancesrecordingsmap' VALUES (5982, 12762, NULL, 6270);
INSERT INTO 'dancesrecordingsmap' VALUES (5983, 12763, NULL, 6271);
INSERT INTO 'dancesrecordingsmap' VALUES (5984, 12764, NULL, 6272);
INSERT INTO 'dancesrecordingsmap' VALUES (5985, 12765, NULL, 6273);
INSERT INTO 'dancesrecordingsmap' VALUES (5987, 12767, NULL, 6275);
INSERT INTO 'dancesrecordingsmap' VALUES (5988, 12768, NULL, 6276);
INSERT INTO 'dancesrecordingsmap' VALUES (5989, 11704, NULL, 1548);
INSERT INTO 'dancesrecordingsmap' VALUES (5990, 1318, NULL, 894);
INSERT INTO 'dancesrecordingsmap' VALUES (5991, 10145, NULL, 894);
INSERT INTO 'dancesrecordingsmap' VALUES (5993, 3237, NULL, 924);
INSERT INTO 'dancesrecordingsmap' VALUES (5994, 3418, NULL, 6277);
INSERT INTO 'dancesrecordingsmap' VALUES (5995, 4796, NULL, 6278);
INSERT INTO 'dancesrecordingsmap' VALUES (5996, 822, NULL, 6279);
INSERT INTO 'dancesrecordingsmap' VALUES (5997, 2453, NULL, 6280);
INSERT INTO 'dancesrecordingsmap' VALUES (5998, 6995, NULL, 6281);
INSERT INTO 'dancesrecordingsmap' VALUES (5999, 4759, NULL, 2623);
INSERT INTO 'dancesrecordingsmap' VALUES (6000, 12769, NULL, 6173);
INSERT INTO 'dancesrecordingsmap' VALUES (6002, 12783, NULL, 5135);
INSERT INTO 'dancesrecordingsmap' VALUES (6004, 12785, NULL, 1667);
INSERT INTO 'dancesrecordingsmap' VALUES (6005, 12787, NULL, 5559);
INSERT INTO 'dancesrecordingsmap' VALUES (6006, 8081, NULL, 1121);
INSERT INTO 'dancesrecordingsmap' VALUES (6007, 8057, NULL, 1467);
INSERT INTO 'dancesrecordingsmap' VALUES (6008, 8058, NULL, 3030);
INSERT INTO 'dancesrecordingsmap' VALUES (6009, 8064, NULL, 2646);
INSERT INTO 'dancesrecordingsmap' VALUES (6010, 8066, NULL, 2140);
INSERT INTO 'dancesrecordingsmap' VALUES (6011, 8069, NULL, 3681);
INSERT INTO 'dancesrecordingsmap' VALUES (6012, 3834, NULL, 3681);
INSERT INTO 'dancesrecordingsmap' VALUES (5986, 12766, NULL, 6274);
INSERT INTO 'dancesrecordingsmap' VALUES (5742, 12498, NULL, 5039);
INSERT INTO 'dancesrecordingsmap' VALUES (5740, 12496, NULL, 4690);
INSERT INTO 'dancesrecordingsmap' VALUES (6013, 3834, NULL, 4797);
INSERT INTO 'dancesrecordingsmap' VALUES (6014, 8069, NULL, 4797);
INSERT INTO 'dancesrecordingsmap' VALUES (6015, 8069, NULL, 4191);
INSERT INTO 'dancesrecordingsmap' VALUES (6016, 8069, NULL, 3806);
INSERT INTO 'dancesrecordingsmap' VALUES (6017, 8069, NULL, 4520);
INSERT INTO 'dancesrecordingsmap' VALUES (6018, 8069, NULL, 3632);
INSERT INTO 'dancesrecordingsmap' VALUES (6019, 8069, NULL, 3847);
INSERT INTO 'dancesrecordingsmap' VALUES (6020, 8069, NULL, 4252);
INSERT INTO 'dancesrecordingsmap' VALUES (6021, 8069, NULL, 168);
INSERT INTO 'dancesrecordingsmap' VALUES (6022, 8069, NULL, 169);
INSERT INTO 'dancesrecordingsmap' VALUES (6023, 8069, NULL, 6099);
INSERT INTO 'dancesrecordingsmap' VALUES (6024, 8069, NULL, 6207);
INSERT INTO 'dancesrecordingsmap' VALUES (6025, 8069, NULL, 2386);
INSERT INTO 'dancesrecordingsmap' VALUES (6026, 8069, NULL, 4393);
INSERT INTO 'dancesrecordingsmap' VALUES (6027, 8069, NULL, 3981);
INSERT INTO 'dancesrecordingsmap' VALUES (6028, 3834, NULL, 3981);
INSERT INTO 'dancesrecordingsmap' VALUES (6029, 3834, NULL, 4285);
INSERT INTO 'dancesrecordingsmap' VALUES (6030, 8069, NULL, 4285);
INSERT INTO 'dancesrecordingsmap' VALUES (6031, 8069, NULL, 2725);
INSERT INTO 'dancesrecordingsmap' VALUES (6032, 3834, NULL, 2725);
INSERT INTO 'dancesrecordingsmap' VALUES (6033, 3834, NULL, 3166);
INSERT INTO 'dancesrecordingsmap' VALUES (6034, 8069, NULL, 3166);
INSERT INTO 'dancesrecordingsmap' VALUES (6036, 8077, NULL, 2202);
INSERT INTO 'dancesrecordingsmap' VALUES (6038, 8083, NULL, 2449);
INSERT INTO 'dancesrecordingsmap' VALUES (6039, 12219, NULL, 6282);
INSERT INTO 'dancesrecordingsmap' VALUES (6040, 12630, NULL, 6283);
INSERT INTO 'dancesrecordingsmap' VALUES (6041, 11600, NULL, 6284);
INSERT INTO 'dancesrecordingsmap' VALUES (6042, 12631, NULL, 6285);
INSERT INTO 'dancesrecordingsmap' VALUES (6043, 12632, NULL, 6286);
INSERT INTO 'dancesrecordingsmap' VALUES (6044, 12633, NULL, 6287);
INSERT INTO 'dancesrecordingsmap' VALUES (6045, 12634, NULL, 6288);
INSERT INTO 'dancesrecordingsmap' VALUES (6046, 12633, NULL, 6289);
INSERT INTO 'dancesrecordingsmap' VALUES (6049, 12636, NULL, 6292);
INSERT INTO 'dancesrecordingsmap' VALUES (6050, 12637, NULL, 6293);
INSERT INTO 'dancesrecordingsmap' VALUES (6051, 11523, NULL, 6294);
INSERT INTO 'dancesrecordingsmap' VALUES (6052, 11523, NULL, 6295);
INSERT INTO 'dancesrecordingsmap' VALUES (6053, 8832, NULL, 6297);
INSERT INTO 'dancesrecordingsmap' VALUES (6054, 12790, NULL, 6281);
INSERT INTO 'dancesrecordingsmap' VALUES (6055, 12790, NULL, 3754);
INSERT INTO 'dancesrecordingsmap' VALUES (6056, 12790, NULL, 5051);
INSERT INTO 'dancesrecordingsmap' VALUES (6057, 12790, NULL, 901);
INSERT INTO 'dancesrecordingsmap' VALUES (6058, 12790, NULL, 3558);
INSERT INTO 'dancesrecordingsmap' VALUES (6059, 12790, NULL, 2631);
INSERT INTO 'dancesrecordingsmap' VALUES (6060, 12790, NULL, 691);
INSERT INTO 'dancesrecordingsmap' VALUES (6061, 12790, NULL, 2610);
INSERT INTO 'dancesrecordingsmap' VALUES (6063, 12790, NULL, 4937);
INSERT INTO 'dancesrecordingsmap' VALUES (6064, 1330, NULL, 6281);
INSERT INTO 'dancesrecordingsmap' VALUES (6065, 1330, NULL, 5051);
INSERT INTO 'dancesrecordingsmap' VALUES (6066, 1330, NULL, 901);
INSERT INTO 'dancesrecordingsmap' VALUES (6067, 1330, NULL, 691);
INSERT INTO 'dancesrecordingsmap' VALUES (9114, 17266, NULL, 10170);
INSERT INTO 'dancesrecordingsmap' VALUES (6062, 12790, NULL, 548);
INSERT INTO 'dancesrecordingsmap' VALUES (6082, 5860, NULL, 6312);
INSERT INTO 'dancesrecordingsmap' VALUES (5992, 4691, NULL, 897);
INSERT INTO 'dancesrecordingsmap' VALUES (5930, 8672, NULL, 6219);
INSERT INTO 'dancesrecordingsmap' VALUES (6047, 11908, NULL, 6290);
INSERT INTO 'dancesrecordingsmap' VALUES (5905, 12662, NULL, 6171);
INSERT INTO 'dancesrecordingsmap' VALUES (5917, 12302, NULL, 6184);
INSERT INTO 'dancesrecordingsmap' VALUES (5937, 9893, NULL, 5379);
INSERT INTO 'dancesrecordingsmap' VALUES (5952, 12749, NULL, 6245);
INSERT INTO 'dancesrecordingsmap' VALUES (6035, 8071, NULL, 1523);
INSERT INTO 'dancesrecordingsmap' VALUES (6103, 5794, NULL, 6334);
INSERT INTO 'dancesrecordingsmap' VALUES (6095, 4102, NULL, 6326);
INSERT INTO 'dancesrecordingsmap' VALUES (6096, 2777, NULL, 6327);
INSERT INTO 'dancesrecordingsmap' VALUES (6097, 909, NULL, 6328);
INSERT INTO 'dancesrecordingsmap' VALUES (6098, 56, NULL, 6329);
INSERT INTO 'dancesrecordingsmap' VALUES (6099, 5936, NULL, 6330);
INSERT INTO 'dancesrecordingsmap' VALUES (6100, 5637, NULL, 6331);
INSERT INTO 'dancesrecordingsmap' VALUES (6101, 584, NULL, 6332);
INSERT INTO 'dancesrecordingsmap' VALUES (6102, 3057, NULL, 6333);
INSERT INTO 'dancesrecordingsmap' VALUES (6104, 3365, NULL, 6335);
INSERT INTO 'dancesrecordingsmap' VALUES (6105, 3129, NULL, 6336);
INSERT INTO 'dancesrecordingsmap' VALUES (6106, 6380, NULL, 6338);
INSERT INTO 'dancesrecordingsmap' VALUES (6108, 3980, NULL, 6339);
INSERT INTO 'dancesrecordingsmap' VALUES (6110, 4646, NULL, 6341);
INSERT INTO 'dancesrecordingsmap' VALUES (6111, 4805, NULL, 6342);
INSERT INTO 'dancesrecordingsmap' VALUES (6112, 4411, NULL, 6343);
INSERT INTO 'dancesrecordingsmap' VALUES (6113, 1792, NULL, 6345);
INSERT INTO 'dancesrecordingsmap' VALUES (6114, 5209, NULL, 6347);
INSERT INTO 'dancesrecordingsmap' VALUES (6116, 4641, NULL, 6349);
INSERT INTO 'dancesrecordingsmap' VALUES (6117, 413, NULL, 6351);
INSERT INTO 'dancesrecordingsmap' VALUES (6118, 7546, NULL, 6353);
INSERT INTO 'dancesrecordingsmap' VALUES (6119, 12831, NULL, 6354);
INSERT INTO 'dancesrecordingsmap' VALUES (6120, 10356, NULL, 6355);
INSERT INTO 'dancesrecordingsmap' VALUES (6121, 12827, NULL, 6356);
INSERT INTO 'dancesrecordingsmap' VALUES (6123, 9811, NULL, 6359);
INSERT INTO 'dancesrecordingsmap' VALUES (6124, 12829, NULL, 6360);
INSERT INTO 'dancesrecordingsmap' VALUES (6125, 9562, NULL, 6361);
INSERT INTO 'dancesrecordingsmap' VALUES (6126, 10014, NULL, 6362);
INSERT INTO 'dancesrecordingsmap' VALUES (6127, 1697, NULL, 6363);
INSERT INTO 'dancesrecordingsmap' VALUES (6129, 12830, NULL, 6364);
INSERT INTO 'dancesrecordingsmap' VALUES (6130, 12318, NULL, 4449);
INSERT INTO 'dancesrecordingsmap' VALUES (6131, 1087, NULL, 6366);
INSERT INTO 'dancesrecordingsmap' VALUES (6132, 2910, NULL, 6367);
INSERT INTO 'dancesrecordingsmap' VALUES (6133, 5829, NULL, 6368);
INSERT INTO 'dancesrecordingsmap' VALUES (6134, 1829, NULL, 6369);
INSERT INTO 'dancesrecordingsmap' VALUES (6135, 2030, NULL, 6370);
INSERT INTO 'dancesrecordingsmap' VALUES (6136, 11189, NULL, 6371);
INSERT INTO 'dancesrecordingsmap' VALUES (6137, 5637, NULL, 6372);
INSERT INTO 'dancesrecordingsmap' VALUES (6138, 7111, NULL, 6373);
INSERT INTO 'dancesrecordingsmap' VALUES (6140, 2254, NULL, 6387);
INSERT INTO 'dancesrecordingsmap' VALUES (6141, 12795, NULL, 6389);
INSERT INTO 'dancesrecordingsmap' VALUES (6142, 12796, NULL, 6390);
INSERT INTO 'dancesrecordingsmap' VALUES (6143, 7629, NULL, 6391);
INSERT INTO 'dancesrecordingsmap' VALUES (6144, 12797, NULL, 6392);
INSERT INTO 'dancesrecordingsmap' VALUES (6146, 2364, NULL, 6394);
INSERT INTO 'dancesrecordingsmap' VALUES (6147, 12799, NULL, 6395);
INSERT INTO 'dancesrecordingsmap' VALUES (6148, 12800, NULL, 6396);
INSERT INTO 'dancesrecordingsmap' VALUES (6149, 12801, NULL, 6397);
INSERT INTO 'dancesrecordingsmap' VALUES (6150, 12802, NULL, 6398);
INSERT INTO 'dancesrecordingsmap' VALUES (6151, 12803, NULL, 6399);
INSERT INTO 'dancesrecordingsmap' VALUES (6152, 12804, NULL, 6400);
INSERT INTO 'dancesrecordingsmap' VALUES (6153, 12805, NULL, 6401);
INSERT INTO 'dancesrecordingsmap' VALUES (6154, 12806, NULL, 6402);
INSERT INTO 'dancesrecordingsmap' VALUES (6155, 12807, NULL, 6403);
INSERT INTO 'dancesrecordingsmap' VALUES (6156, 12938, NULL, 4004);
INSERT INTO 'dancesrecordingsmap' VALUES (6157, 12937, NULL, 4437);
INSERT INTO 'dancesrecordingsmap' VALUES (6159, 12429, NULL, 5237);
INSERT INTO 'dancesrecordingsmap' VALUES (6160, 12941, NULL, 5708);
INSERT INTO 'dancesrecordingsmap' VALUES (6161, 9748, NULL, 420);
INSERT INTO 'dancesrecordingsmap' VALUES (6073, 1415, NULL, 6303);
INSERT INTO 'dancesrecordingsmap' VALUES (6037, 8078, NULL, 1613);
INSERT INTO 'dancesrecordingsmap' VALUES (6080, 3642, NULL, 6310);
INSERT INTO 'dancesrecordingsmap' VALUES (6079, 4548, NULL, 6309);
INSERT INTO 'dancesrecordingsmap' VALUES (6078, 6523, NULL, 6308);
INSERT INTO 'dancesrecordingsmap' VALUES (6077, 5937, NULL, 6307);
INSERT INTO 'dancesrecordingsmap' VALUES (6076, 4068, NULL, 6306);
INSERT INTO 'dancesrecordingsmap' VALUES (6072, 3611, NULL, 6302);
INSERT INTO 'dancesrecordingsmap' VALUES (6071, 2428, NULL, 6301);
INSERT INTO 'dancesrecordingsmap' VALUES (6070, 3091, NULL, 6300);
INSERT INTO 'dancesrecordingsmap' VALUES (6069, 4641, NULL, 6299);
INSERT INTO 'dancesrecordingsmap' VALUES (6075, 3152, NULL, 6305);
INSERT INTO 'dancesrecordingsmap' VALUES (6162, 12942, NULL, 824);
INSERT INTO 'dancesrecordingsmap' VALUES (6163, 12943, NULL, 5972);
INSERT INTO 'dancesrecordingsmap' VALUES (6128, 12832, NULL, 6365);
INSERT INTO 'dancesrecordingsmap' VALUES (6167, 12946, NULL, 5083);
INSERT INTO 'dancesrecordingsmap' VALUES (6168, 12019, NULL, 5100);
INSERT INTO 'dancesrecordingsmap' VALUES (6169, 12431, NULL, 5232);
INSERT INTO 'dancesrecordingsmap' VALUES (6170, 12947, NULL, 2355);
INSERT INTO 'dancesrecordingsmap' VALUES (6171, 12956, NULL, 6404);
INSERT INTO 'dancesrecordingsmap' VALUES (6172, 12948, NULL, 6405);
INSERT INTO 'dancesrecordingsmap' VALUES (6173, 12953, NULL, 6406);
INSERT INTO 'dancesrecordingsmap' VALUES (6174, 12952, NULL, 6407);
INSERT INTO 'dancesrecordingsmap' VALUES (6175, 12957, NULL, 6408);
INSERT INTO 'dancesrecordingsmap' VALUES (6176, 12951, NULL, 6409);
INSERT INTO 'dancesrecordingsmap' VALUES (6177, 12950, NULL, 6410);
INSERT INTO 'dancesrecordingsmap' VALUES (6178, 12954, NULL, 6411);
INSERT INTO 'dancesrecordingsmap' VALUES (6179, 12949, NULL, 6412);
INSERT INTO 'dancesrecordingsmap' VALUES (6180, 12955, NULL, 6413);
INSERT INTO 'dancesrecordingsmap' VALUES (6181, 12959, NULL, 6414);
INSERT INTO 'dancesrecordingsmap' VALUES (6183, 12961, NULL, 6416);
INSERT INTO 'dancesrecordingsmap' VALUES (6184, 12971, NULL, 6417);
INSERT INTO 'dancesrecordingsmap' VALUES (6214, 13060, NULL, 116);
INSERT INTO 'dancesrecordingsmap' VALUES (6188, 9157, NULL, 2151);
INSERT INTO 'dancesrecordingsmap' VALUES (6190, 13047, NULL, 4676);
INSERT INTO 'dancesrecordingsmap' VALUES (6192, 13049, NULL, 4659);
INSERT INTO 'dancesrecordingsmap' VALUES (6193, 13050, NULL, 4681);
INSERT INTO 'dancesrecordingsmap' VALUES (6194, 13051, NULL, 4668);
INSERT INTO 'dancesrecordingsmap' VALUES (6195, 13052, NULL, 4658);
INSERT INTO 'dancesrecordingsmap' VALUES (6196, 13053, NULL, 4657);
INSERT INTO 'dancesrecordingsmap' VALUES (6197, 13054, NULL, 4679);
INSERT INTO 'dancesrecordingsmap' VALUES (6199, 5497, NULL, 6404);
INSERT INTO 'dancesrecordingsmap' VALUES (6200, 3152, NULL, 6410);
INSERT INTO 'dancesrecordingsmap' VALUES (6201, 5102, NULL, 6410);
INSERT INTO 'dancesrecordingsmap' VALUES (6202, 899, NULL, 6414);
INSERT INTO 'dancesrecordingsmap' VALUES (6203, 1687, NULL, 6416);
INSERT INTO 'dancesrecordingsmap' VALUES (6204, 11593, NULL, 6416);
INSERT INTO 'dancesrecordingsmap' VALUES (6205, 3247, NULL, 6416);
INSERT INTO 'dancesrecordingsmap' VALUES (6206, 6665, NULL, 6416);
INSERT INTO 'dancesrecordingsmap' VALUES (6207, 1864, NULL, 6417);
INSERT INTO 'dancesrecordingsmap' VALUES (6208, 3709, NULL, 6417);
INSERT INTO 'dancesrecordingsmap' VALUES (6209, 13056, NULL, 966);
INSERT INTO 'dancesrecordingsmap' VALUES (6210, 13057, NULL, 976);
INSERT INTO 'dancesrecordingsmap' VALUES (6212, 13059, NULL, 972);
INSERT INTO 'dancesrecordingsmap' VALUES (6213, 13061, NULL, 970);
INSERT INTO 'dancesrecordingsmap' VALUES (6215, 13063, NULL, 380);
INSERT INTO 'dancesrecordingsmap' VALUES (6216, 13062, NULL, 453);
INSERT INTO 'dancesrecordingsmap' VALUES (6217, 13064, NULL, 114);
INSERT INTO 'dancesrecordingsmap' VALUES (6218, 13065, NULL, 971);
INSERT INTO 'dancesrecordingsmap' VALUES (6219, 13070, NULL, 6375);
INSERT INTO 'dancesrecordingsmap' VALUES (6221, 13075, NULL, 6377);
INSERT INTO 'dancesrecordingsmap' VALUES (6223, 13077, NULL, 6379);
INSERT INTO 'dancesrecordingsmap' VALUES (6224, 13078, NULL, 6380);
INSERT INTO 'dancesrecordingsmap' VALUES (6115, 442, NULL, 6348);
INSERT INTO 'dancesrecordingsmap' VALUES (6225, 13079, NULL, 6382);
INSERT INTO 'dancesrecordingsmap' VALUES (6227, 13080, NULL, 6384);
INSERT INTO 'dancesrecordingsmap' VALUES (6229, 13082, NULL, 6386);
INSERT INTO 'dancesrecordingsmap' VALUES (6230, 13083, NULL, 6388);
INSERT INTO 'dancesrecordingsmap' VALUES (6232, 13114, NULL, 443);
INSERT INTO 'dancesrecordingsmap' VALUES (6233, 4827, NULL, 6367);
INSERT INTO 'dancesrecordingsmap' VALUES (6234, 12867, NULL, 6425);
INSERT INTO 'dancesrecordingsmap' VALUES (6235, 1533, NULL, 6426);
INSERT INTO 'dancesrecordingsmap' VALUES (6238, 13128, NULL, 6424);
INSERT INTO 'dancesrecordingsmap' VALUES (6239, 13129, NULL, 6428);
INSERT INTO 'dancesrecordingsmap' VALUES (6240, 13130, NULL, 6429);
INSERT INTO 'dancesrecordingsmap' VALUES (6241, 13131, NULL, 6431);
INSERT INTO 'dancesrecordingsmap' VALUES (6242, 13132, NULL, 6432);
INSERT INTO 'dancesrecordingsmap' VALUES (6243, 13133, NULL, 6433);
INSERT INTO 'dancesrecordingsmap' VALUES (6245, 13135, NULL, 6435);
INSERT INTO 'dancesrecordingsmap' VALUES (6246, 13136, NULL, 6436);
INSERT INTO 'dancesrecordingsmap' VALUES (6247, 13137, NULL, 6437);
INSERT INTO 'dancesrecordingsmap' VALUES (6248, 13138, NULL, 6438);
INSERT INTO 'dancesrecordingsmap' VALUES (6249, 13139, NULL, 6439);
INSERT INTO 'dancesrecordingsmap' VALUES (6250, 13140, NULL, 2359);
INSERT INTO 'dancesrecordingsmap' VALUES (6251, 13150, NULL, 846);
INSERT INTO 'dancesrecordingsmap' VALUES (6252, 13149, NULL, 4962);
INSERT INTO 'dancesrecordingsmap' VALUES (6254, 13152, NULL, 2356);
INSERT INTO 'dancesrecordingsmap' VALUES (6257, 13155, NULL, 3331);
INSERT INTO 'dancesrecordingsmap' VALUES (6258, 13157, NULL, 4962);
INSERT INTO 'dancesrecordingsmap' VALUES (6259, 13158, NULL, 4975);
INSERT INTO 'dancesrecordingsmap' VALUES (6261, 13160, NULL, 5449);
INSERT INTO 'dancesrecordingsmap' VALUES (6265, 13165, NULL, 4960);
INSERT INTO 'dancesrecordingsmap' VALUES (6267, 13167, NULL, 5476);
INSERT INTO 'dancesrecordingsmap' VALUES (6268, 13168, NULL, 5569);
INSERT INTO 'dancesrecordingsmap' VALUES (6122, 12828, NULL, 6358);
INSERT INTO 'dancesrecordingsmap' VALUES (6094, 1647, NULL, 6325);
INSERT INTO 'dancesrecordingsmap' VALUES (6084, 633, NULL, 6314);
INSERT INTO 'dancesrecordingsmap' VALUES (6083, 5904, NULL, 6313);
INSERT INTO 'dancesrecordingsmap' VALUES (6085, 3172, NULL, 6315);
INSERT INTO 'dancesrecordingsmap' VALUES (6086, 2563, NULL, 6316);
INSERT INTO 'dancesrecordingsmap' VALUES (6087, 5407, NULL, 6317);
INSERT INTO 'dancesrecordingsmap' VALUES (6091, 3129, NULL, 6321);
INSERT INTO 'dancesrecordingsmap' VALUES (6089, 769, NULL, 6319);
INSERT INTO 'dancesrecordingsmap' VALUES (6090, 2353, NULL, 6320);
INSERT INTO 'dancesrecordingsmap' VALUES (6092, 3129, NULL, 6322);
INSERT INTO 'dancesrecordingsmap' VALUES (6093, 6010, NULL, 6323);
INSERT INTO 'dancesrecordingsmap' VALUES (6263, 13163, NULL, 387);
INSERT INTO 'dancesrecordingsmap' VALUES (6244, 13134, NULL, 6434);
INSERT INTO 'dancesrecordingsmap' VALUES (6107, 12810, NULL, 5563);
INSERT INTO 'dancesrecordingsmap' VALUES (6189, 12884, NULL, 1659);
INSERT INTO 'dancesrecordingsmap' VALUES (6139, 12248, NULL, 6381);
INSERT INTO 'dancesrecordingsmap' VALUES (6186, 8726, NULL, 1660);
INSERT INTO 'dancesrecordingsmap' VALUES (6198, 13055, NULL, 426);
INSERT INTO 'dancesrecordingsmap' VALUES (6231, 13114, NULL, 2635);
INSERT INTO 'dancesrecordingsmap' VALUES (6211, 13058, NULL, 677);
INSERT INTO 'dancesrecordingsmap' VALUES (6145, 12798, NULL, 6393);
INSERT INTO 'dancesrecordingsmap' VALUES (6187, 12983, NULL, 6374);
INSERT INTO 'dancesrecordingsmap' VALUES (6237, 11814, NULL, 6430);
INSERT INTO 'dancesrecordingsmap' VALUES (6256, 13154, NULL, 3327);
INSERT INTO 'dancesrecordingsmap' VALUES (6158, 9751, NULL, 1523);
INSERT INTO 'dancesrecordingsmap' VALUES (6271, 13171, NULL, 4975);
INSERT INTO 'dancesrecordingsmap' VALUES (6272, 13172, NULL, 71);
INSERT INTO 'dancesrecordingsmap' VALUES (6274, 13177, NULL, 5026);
INSERT INTO 'dancesrecordingsmap' VALUES (6275, 13178, NULL, 4569);
INSERT INTO 'dancesrecordingsmap' VALUES (6277, 13181, NULL, 3472);
INSERT INTO 'dancesrecordingsmap' VALUES (6278, 13182, NULL, 848);
INSERT INTO 'dancesrecordingsmap' VALUES (6282, 13186, NULL, 5751);
INSERT INTO 'dancesrecordingsmap' VALUES (6286, 13190, NULL, 4975);
INSERT INTO 'dancesrecordingsmap' VALUES (6287, 13191, NULL, 71);
INSERT INTO 'dancesrecordingsmap' VALUES (6290, 13193, NULL, 4694);
INSERT INTO 'dancesrecordingsmap' VALUES (6294, 13198, NULL, 4960);
INSERT INTO 'dancesrecordingsmap' VALUES (6296, 13200, NULL, 1672);
INSERT INTO 'dancesrecordingsmap' VALUES (6298, 13202, NULL, 3321);
INSERT INTO 'dancesrecordingsmap' VALUES (6301, 13205, NULL, 2170);
INSERT INTO 'dancesrecordingsmap' VALUES (6302, 218, NULL, 6440);
INSERT INTO 'dancesrecordingsmap' VALUES (6303, 1533, NULL, 6441);
INSERT INTO 'dancesrecordingsmap' VALUES (6304, 7120, NULL, 6442);
INSERT INTO 'dancesrecordingsmap' VALUES (6305, 4878, NULL, 6443);
INSERT INTO 'dancesrecordingsmap' VALUES (6306, 1544, NULL, 6444);
INSERT INTO 'dancesrecordingsmap' VALUES (6307, 7980, NULL, 6445);
INSERT INTO 'dancesrecordingsmap' VALUES (6308, 4337, NULL, 6446);
INSERT INTO 'dancesrecordingsmap' VALUES (6309, 2588, NULL, 6447);
INSERT INTO 'dancesrecordingsmap' VALUES (6310, 93, NULL, 6448);
INSERT INTO 'dancesrecordingsmap' VALUES (6311, 893, NULL, 6449);
INSERT INTO 'dancesrecordingsmap' VALUES (6312, 3366, NULL, 6450);
INSERT INTO 'dancesrecordingsmap' VALUES (6315, 5723, NULL, 6458);
INSERT INTO 'dancesrecordingsmap' VALUES (6316, 5885, NULL, 6459);
INSERT INTO 'dancesrecordingsmap' VALUES (6317, 12243, NULL, 6461);
INSERT INTO 'dancesrecordingsmap' VALUES (6318, 10787, NULL, 6463);
INSERT INTO 'dancesrecordingsmap' VALUES (6320, 13230, NULL, 5238);
INSERT INTO 'dancesrecordingsmap' VALUES (6321, 13231, NULL, 4675);
INSERT INTO 'dancesrecordingsmap' VALUES (6323, 13244, NULL, 2201);
INSERT INTO 'dancesrecordingsmap' VALUES (6324, 13245, NULL, 1571);
INSERT INTO 'dancesrecordingsmap' VALUES (6325, 13246, NULL, 157);
INSERT INTO 'dancesrecordingsmap' VALUES (6326, 13248, NULL, 5124);
INSERT INTO 'dancesrecordingsmap' VALUES (6329, 13253, NULL, 1785);
INSERT INTO 'dancesrecordingsmap' VALUES (6330, 13254, NULL, 3399);
INSERT INTO 'dancesrecordingsmap' VALUES (6332, 13256, NULL, 5111);
INSERT INTO 'dancesrecordingsmap' VALUES (6333, 13257, NULL, 5100);
INSERT INTO 'dancesrecordingsmap' VALUES (6334, 13258, NULL, 6106);
INSERT INTO 'dancesrecordingsmap' VALUES (6335, 13259, NULL, 1665);
INSERT INTO 'dancesrecordingsmap' VALUES (6336, 13269, NULL, 1428);
INSERT INTO 'dancesrecordingsmap' VALUES (6339, 13269, NULL, 4752);
INSERT INTO 'dancesrecordingsmap' VALUES (6340, 13269, NULL, 3118);
INSERT INTO 'dancesrecordingsmap' VALUES (6341, 13269, NULL, 2236);
INSERT INTO 'dancesrecordingsmap' VALUES (6342, 13278, NULL, 5598);
INSERT INTO 'dancesrecordingsmap' VALUES (6343, 13310, NULL, 4214);
INSERT INTO 'dancesrecordingsmap' VALUES (6344, 11681, NULL, 6470);
INSERT INTO 'dancesrecordingsmap' VALUES (6236, 12696, NULL, 6427);
INSERT INTO 'dancesrecordingsmap' VALUES (6295, 13199, NULL, 5488);
INSERT INTO 'dancesrecordingsmap' VALUES (6164, 9749, NULL, 1031);
INSERT INTO 'dancesrecordingsmap' VALUES (6291, 13195, NULL, 937);
INSERT INTO 'dancesrecordingsmap' VALUES (6220, 13071, NULL, 6376);
INSERT INTO 'dancesrecordingsmap' VALUES (6262, 13161, NULL, 437);
INSERT INTO 'dancesrecordingsmap' VALUES (6166, 12945, NULL, 5229);
INSERT INTO 'dancesrecordingsmap' VALUES (6337, 13269, NULL, 337);
INSERT INTO 'dancesrecordingsmap' VALUES (6222, 13076, NULL, 6378);
INSERT INTO 'dancesrecordingsmap' VALUES (6354, 13343, NULL, 4004);
INSERT INTO 'dancesrecordingsmap' VALUES (6356, 7239, NULL, 6488);
INSERT INTO 'dancesrecordingsmap' VALUES (6357, 10463, NULL, 6489);
INSERT INTO 'dancesrecordingsmap' VALUES (6358, 10774, NULL, 6490);
INSERT INTO 'dancesrecordingsmap' VALUES (6359, 9084, NULL, 6491);
INSERT INTO 'dancesrecordingsmap' VALUES (6361, 9083, NULL, 6493);
INSERT INTO 'dancesrecordingsmap' VALUES (6362, 8154, NULL, 6495);
INSERT INTO 'dancesrecordingsmap' VALUES (6363, 6915, NULL, 6499);
INSERT INTO 'dancesrecordingsmap' VALUES (6364, 8142, NULL, 6501);
INSERT INTO 'dancesrecordingsmap' VALUES (6365, 7546, NULL, 6503);
INSERT INTO 'dancesrecordingsmap' VALUES (6366, 13355, NULL, 6508);
INSERT INTO 'dancesrecordingsmap' VALUES (6367, 4844, NULL, 6509);
INSERT INTO 'dancesrecordingsmap' VALUES (6368, 6763, NULL, 6510);
INSERT INTO 'dancesrecordingsmap' VALUES (6369, 3172, NULL, 6511);
INSERT INTO 'dancesrecordingsmap' VALUES (6370, 4015, NULL, 6512);
INSERT INTO 'dancesrecordingsmap' VALUES (6371, 2747, NULL, 6513);
INSERT INTO 'dancesrecordingsmap' VALUES (6372, 7111, NULL, 6515);
INSERT INTO 'dancesrecordingsmap' VALUES (6373, 5927, NULL, 6516);
INSERT INTO 'dancesrecordingsmap' VALUES (6374, 13356, NULL, 6517);
INSERT INTO 'dancesrecordingsmap' VALUES (9136, 4919, NULL, 10203);
INSERT INTO 'dancesrecordingsmap' VALUES (6376, 3791, NULL, 6519);
INSERT INTO 'dancesrecordingsmap' VALUES (6377, 5529, NULL, 6520);
INSERT INTO 'dancesrecordingsmap' VALUES (6378, 13358, NULL, 6521);
INSERT INTO 'dancesrecordingsmap' VALUES (6379, 4015, NULL, 6522);
INSERT INTO 'dancesrecordingsmap' VALUES (6381, 13360, NULL, 6524);
INSERT INTO 'dancesrecordingsmap' VALUES (6382, 13361, NULL, 6525);
INSERT INTO 'dancesrecordingsmap' VALUES (6383, 13362, NULL, 6526);
INSERT INTO 'dancesrecordingsmap' VALUES (6384, 13363, NULL, 6527);
INSERT INTO 'dancesrecordingsmap' VALUES (6385, 13364, NULL, 6528);
INSERT INTO 'dancesrecordingsmap' VALUES (6386, 13365, NULL, 6529);
INSERT INTO 'dancesrecordingsmap' VALUES (6387, 13366, NULL, 6530);
INSERT INTO 'dancesrecordingsmap' VALUES (6388, 1582, NULL, 6532);
INSERT INTO 'dancesrecordingsmap' VALUES (6390, 1624, NULL, 6534);
INSERT INTO 'dancesrecordingsmap' VALUES (6391, 3326, NULL, 6535);
INSERT INTO 'dancesrecordingsmap' VALUES (6392, 5904, NULL, 6536);
INSERT INTO 'dancesrecordingsmap' VALUES (6393, 3580, NULL, 6537);
INSERT INTO 'dancesrecordingsmap' VALUES (6394, 4968, NULL, 6538);
INSERT INTO 'dancesrecordingsmap' VALUES (6395, 4565, NULL, 6539);
INSERT INTO 'dancesrecordingsmap' VALUES (6396, 2962, NULL, 6540);
INSERT INTO 'dancesrecordingsmap' VALUES (6397, 223, NULL, 6540);
INSERT INTO 'dancesrecordingsmap' VALUES (6398, 1549, NULL, 6541);
INSERT INTO 'dancesrecordingsmap' VALUES (6399, 12542, NULL, 6542);
INSERT INTO 'dancesrecordingsmap' VALUES (6400, 5529, NULL, 6543);
INSERT INTO 'dancesrecordingsmap' VALUES (6401, 6634, NULL, 6544);
INSERT INTO 'dancesrecordingsmap' VALUES (6402, 6373, NULL, 6545);
INSERT INTO 'dancesrecordingsmap' VALUES (6403, 1535, NULL, 6546);
INSERT INTO 'dancesrecordingsmap' VALUES (6404, 7465, NULL, 6546);
INSERT INTO 'dancesrecordingsmap' VALUES (6405, 3802, NULL, 6547);
INSERT INTO 'dancesrecordingsmap' VALUES (6283, 13187, NULL, 5667);
INSERT INTO 'dancesrecordingsmap' VALUES (6253, 13151, NULL, 4692);
INSERT INTO 'dancesrecordingsmap' VALUES (6228, 13081, NULL, 6385);
INSERT INTO 'dancesrecordingsmap' VALUES (6345, 3786, NULL, 6472);
INSERT INTO 'dancesrecordingsmap' VALUES (6347, 5330, NULL, 6474);
INSERT INTO 'dancesrecordingsmap' VALUES (6349, 1838, NULL, 6476);
INSERT INTO 'dancesrecordingsmap' VALUES (6352, 6010, NULL, 6480);
INSERT INTO 'dancesrecordingsmap' VALUES (6350, 313, NULL, 6477);
INSERT INTO 'dancesrecordingsmap' VALUES (6346, 4102, NULL, 6473);
INSERT INTO 'dancesrecordingsmap' VALUES (6353, 7189, NULL, 6481);
INSERT INTO 'dancesrecordingsmap' VALUES (6348, 3129, NULL, 6475);
INSERT INTO 'dancesrecordingsmap' VALUES (6255, 13153, NULL, 5477);
INSERT INTO 'dancesrecordingsmap' VALUES (6314, 3909, NULL, 6452);
INSERT INTO 'dancesrecordingsmap' VALUES (6264, 13164, NULL, 4961);
INSERT INTO 'dancesrecordingsmap' VALUES (6260, 13159, NULL, 5039);
INSERT INTO 'dancesrecordingsmap' VALUES (6292, 13196, NULL, 4961);
INSERT INTO 'dancesrecordingsmap' VALUES (6338, 13269, NULL, 338);
INSERT INTO 'dancesrecordingsmap' VALUES (6226, 13079, NULL, 6383);
INSERT INTO 'dancesrecordingsmap' VALUES (6355, 4236, NULL, 6487);
INSERT INTO 'dancesrecordingsmap' VALUES (6389, 6091, NULL, 6533);
INSERT INTO 'dancesrecordingsmap' VALUES (6406, 12694, NULL, 6548);
INSERT INTO 'dancesrecordingsmap' VALUES (6407, 5497, NULL, 6549);
INSERT INTO 'dancesrecordingsmap' VALUES (6408, 7204, NULL, 6550);
INSERT INTO 'dancesrecordingsmap' VALUES (6410, 588, NULL, 6552);
INSERT INTO 'dancesrecordingsmap' VALUES (6411, 413, NULL, 6553);
INSERT INTO 'dancesrecordingsmap' VALUES (6412, 4411, NULL, 6554);
INSERT INTO 'dancesrecordingsmap' VALUES (6414, 3541, NULL, 6556);
INSERT INTO 'dancesrecordingsmap' VALUES (6415, 4646, NULL, 6557);
INSERT INTO 'dancesrecordingsmap' VALUES (6416, 3342, NULL, 6558);
INSERT INTO 'dancesrecordingsmap' VALUES (6417, 3084, NULL, 6559);
INSERT INTO 'dancesrecordingsmap' VALUES (6418, 6152, NULL, 6560);
INSERT INTO 'dancesrecordingsmap' VALUES (6419, 1496, NULL, 6561);
INSERT INTO 'dancesrecordingsmap' VALUES (6420, 4679, NULL, 6562);
INSERT INTO 'dancesrecordingsmap' VALUES (6421, 3912, NULL, 6563);
INSERT INTO 'dancesrecordingsmap' VALUES (6422, 2495, NULL, 6564);
INSERT INTO 'dancesrecordingsmap' VALUES (6423, 3105, NULL, 6565);
INSERT INTO 'dancesrecordingsmap' VALUES (6425, 4559, NULL, 6567);
INSERT INTO 'dancesrecordingsmap' VALUES (6426, 3390, NULL, 6568);
INSERT INTO 'dancesrecordingsmap' VALUES (6427, 10790, NULL, 6569);
INSERT INTO 'dancesrecordingsmap' VALUES (6428, 2501, NULL, 6570);
INSERT INTO 'dancesrecordingsmap' VALUES (6429, 7531, NULL, 6571);
INSERT INTO 'dancesrecordingsmap' VALUES (6430, 2024, NULL, 6572);
INSERT INTO 'dancesrecordingsmap' VALUES (6431, 4796, NULL, 6573);
INSERT INTO 'dancesrecordingsmap' VALUES (6432, 13368, NULL, 6574);
INSERT INTO 'dancesrecordingsmap' VALUES (6433, 55, NULL, 6575);
INSERT INTO 'dancesrecordingsmap' VALUES (6434, 10788, NULL, 6576);
INSERT INTO 'dancesrecordingsmap' VALUES (6436, 10306, NULL, 6578);
INSERT INTO 'dancesrecordingsmap' VALUES (6438, 4106, NULL, 6580);
INSERT INTO 'dancesrecordingsmap' VALUES (6439, 289, NULL, 6581);
INSERT INTO 'dancesrecordingsmap' VALUES (6441, 5734, NULL, 6583);
INSERT INTO 'dancesrecordingsmap' VALUES (6442, 2501, NULL, 6584);
INSERT INTO 'dancesrecordingsmap' VALUES (6443, 4894, NULL, 6585);
INSERT INTO 'dancesrecordingsmap' VALUES (6444, 5136, NULL, 6586);
INSERT INTO 'dancesrecordingsmap' VALUES (6445, 4929, NULL, 6587);
INSERT INTO 'dancesrecordingsmap' VALUES (6446, 1376, NULL, 6588);
INSERT INTO 'dancesrecordingsmap' VALUES (6447, 5099, NULL, 6589);
INSERT INTO 'dancesrecordingsmap' VALUES (6448, 4929, NULL, 6590);
INSERT INTO 'dancesrecordingsmap' VALUES (6450, 12542, NULL, 6592);
INSERT INTO 'dancesrecordingsmap' VALUES (6451, 9836, NULL, 6593);
INSERT INTO 'dancesrecordingsmap' VALUES (6452, 7282, NULL, 6594);
INSERT INTO 'dancesrecordingsmap' VALUES (6453, 3172, NULL, 6596);
INSERT INTO 'dancesrecordingsmap' VALUES (6331, 13255, NULL, 242);
INSERT INTO 'dancesrecordingsmap' VALUES (6270, 13170, NULL, 1674);
INSERT INTO 'dancesrecordingsmap' VALUES (6280, 13184, NULL, 1660);
INSERT INTO 'dancesrecordingsmap' VALUES (6409, 13367, NULL, 6551);
INSERT INTO 'dancesrecordingsmap' VALUES (6297, 13201, NULL, 2659);
INSERT INTO 'dancesrecordingsmap' VALUES (6437, 7560, NULL, 6579);
INSERT INTO 'dancesrecordingsmap' VALUES (6313, 4552, NULL, 6451);
INSERT INTO 'dancesrecordingsmap' VALUES (6288, 13192, NULL, 4971);
INSERT INTO 'dancesrecordingsmap' VALUES (6454, 4487, NULL, 6599);
INSERT INTO 'dancesrecordingsmap' VALUES (6269, 13169, NULL, 1379);
INSERT INTO 'dancesrecordingsmap' VALUES (6048, 12635, NULL, 6291);
INSERT INTO 'dancesrecordingsmap' VALUES (9116, 18278, NULL, 6291);
INSERT INTO 'dancesrecordingsmap' VALUES (6322, 13232, NULL, 5181);
INSERT INTO 'dancesrecordingsmap' VALUES (6413, 2166, NULL, 6555);
INSERT INTO 'dancesrecordingsmap' VALUES (6455, 3383, NULL, 6602);
INSERT INTO 'dancesrecordingsmap' VALUES (6456, 2030, NULL, 6604);
INSERT INTO 'dancesrecordingsmap' VALUES (6457, 441, NULL, 6609);
INSERT INTO 'dancesrecordingsmap' VALUES (6459, 1881, NULL, 6611);
INSERT INTO 'dancesrecordingsmap' VALUES (6460, 2846, NULL, 6612);
INSERT INTO 'dancesrecordingsmap' VALUES (6461, 3428, NULL, 6613);
INSERT INTO 'dancesrecordingsmap' VALUES (6462, 3680, NULL, 6614);
INSERT INTO 'dancesrecordingsmap' VALUES (6463, 4014, NULL, 6615);
INSERT INTO 'dancesrecordingsmap' VALUES (6464, 4271, NULL, 6616);
INSERT INTO 'dancesrecordingsmap' VALUES (6465, 4044, NULL, 6617);
INSERT INTO 'dancesrecordingsmap' VALUES (6466, 4283, NULL, 6618);
INSERT INTO 'dancesrecordingsmap' VALUES (6467, 4474, NULL, 6619);
INSERT INTO 'dancesrecordingsmap' VALUES (6468, 6037, NULL, 6620);
INSERT INTO 'dancesrecordingsmap' VALUES (6469, 5807, NULL, 6621);
INSERT INTO 'dancesrecordingsmap' VALUES (6470, 1881, NULL, 6622);
INSERT INTO 'dancesrecordingsmap' VALUES (6471, 633, NULL, 6623);
INSERT INTO 'dancesrecordingsmap' VALUES (6472, 805, NULL, 6624);
INSERT INTO 'dancesrecordingsmap' VALUES (6473, 3225, NULL, 6625);
INSERT INTO 'dancesrecordingsmap' VALUES (6476, 3777, NULL, 6628);
INSERT INTO 'dancesrecordingsmap' VALUES (6477, 3883, NULL, 6629);
INSERT INTO 'dancesrecordingsmap' VALUES (6478, 4043, NULL, 6630);
INSERT INTO 'dancesrecordingsmap' VALUES (6479, 4680, NULL, 6631);
INSERT INTO 'dancesrecordingsmap' VALUES (6480, 4282, NULL, 6632);
INSERT INTO 'dancesrecordingsmap' VALUES (6481, 5128, NULL, 6633);
INSERT INTO 'dancesrecordingsmap' VALUES (6482, 5699, NULL, 6634);
INSERT INTO 'dancesrecordingsmap' VALUES (6483, 5749, NULL, 6635);
INSERT INTO 'dancesrecordingsmap' VALUES (6484, 5707, NULL, 6636);
INSERT INTO 'dancesrecordingsmap' VALUES (6486, 1789, NULL, 6638);
INSERT INTO 'dancesrecordingsmap' VALUES (6487, 9638, NULL, 6639);
INSERT INTO 'dancesrecordingsmap' VALUES (6490, 2822, NULL, 6642);
INSERT INTO 'dancesrecordingsmap' VALUES (6503, 4046, NULL, 6655);
INSERT INTO 'dancesrecordingsmap' VALUES (6493, 2110, NULL, 6645);
INSERT INTO 'dancesrecordingsmap' VALUES (6494, 13260, NULL, 6646);
INSERT INTO 'dancesrecordingsmap' VALUES (6496, 5885, NULL, 6648);
INSERT INTO 'dancesrecordingsmap' VALUES (6497, 3422, NULL, 6649);
INSERT INTO 'dancesrecordingsmap' VALUES (6500, 10433, NULL, 6652);
INSERT INTO 'dancesrecordingsmap' VALUES (6501, 9110, NULL, 6653);
INSERT INTO 'dancesrecordingsmap' VALUES (6504, 9836, NULL, 6656);
INSERT INTO 'dancesrecordingsmap' VALUES (6505, 9107, NULL, 6657);
INSERT INTO 'dancesrecordingsmap' VALUES (6506, 5080, NULL, 6658);
INSERT INTO 'dancesrecordingsmap' VALUES (6507, 4411, NULL, 6659);
INSERT INTO 'dancesrecordingsmap' VALUES (6508, 4106, NULL, 6660);
INSERT INTO 'dancesrecordingsmap' VALUES (6509, 12793, NULL, 6661);
INSERT INTO 'dancesrecordingsmap' VALUES (6510, 12793, NULL, 6662);
INSERT INTO 'dancesrecordingsmap' VALUES (6512, 4365, NULL, 6664);
INSERT INTO 'dancesrecordingsmap' VALUES (6513, 5868, NULL, 6665);
INSERT INTO 'dancesrecordingsmap' VALUES (6514, 6848, NULL, 6666);
INSERT INTO 'dancesrecordingsmap' VALUES (6515, 5555, NULL, 6667);
INSERT INTO 'dancesrecordingsmap' VALUES (6516, 5555, NULL, 6668);
INSERT INTO 'dancesrecordingsmap' VALUES (6517, 1588, NULL, 6669);
INSERT INTO 'dancesrecordingsmap' VALUES (6518, 5802, NULL, 6670);
INSERT INTO 'dancesrecordingsmap' VALUES (6520, 822, NULL, 6672);
INSERT INTO 'dancesrecordingsmap' VALUES (6521, 4805, NULL, 6673);
INSERT INTO 'dancesrecordingsmap' VALUES (6522, 3108, NULL, 6674);
INSERT INTO 'dancesrecordingsmap' VALUES (6523, 221, NULL, 6675);
INSERT INTO 'dancesrecordingsmap' VALUES (6524, 4106, NULL, 6676);
INSERT INTO 'dancesrecordingsmap' VALUES (6525, 2437, NULL, 6677);
INSERT INTO 'dancesrecordingsmap' VALUES (6526, 6756, NULL, 6678);
INSERT INTO 'dancesrecordingsmap' VALUES (6527, 5804, NULL, 6679);
INSERT INTO 'dancesrecordingsmap' VALUES (6328, 13251, NULL, 1446);
INSERT INTO 'dancesrecordingsmap' VALUES (6498, 6915, NULL, 6650);
INSERT INTO 'dancesrecordingsmap' VALUES (6440, 895, NULL, 6582);
INSERT INTO 'dancesrecordingsmap' VALUES (6499, 816, NULL, 6651);
INSERT INTO 'dancesrecordingsmap' VALUES (6424, 5462, NULL, 6566);
INSERT INTO 'dancesrecordingsmap' VALUES (6528, 6380, NULL, 6680);
INSERT INTO 'dancesrecordingsmap' VALUES (6529, 6380, NULL, 6681);
INSERT INTO 'dancesrecordingsmap' VALUES (6530, 7172, NULL, 6682);
INSERT INTO 'dancesrecordingsmap' VALUES (6531, 2645, NULL, 6683);
INSERT INTO 'dancesrecordingsmap' VALUES (6532, 5398, NULL, 6684);
INSERT INTO 'dancesrecordingsmap' VALUES (6533, 1437, NULL, 6685);
INSERT INTO 'dancesrecordingsmap' VALUES (6534, 4562, NULL, 6686);
INSERT INTO 'dancesrecordingsmap' VALUES (6535, 3412, NULL, 6687);
INSERT INTO 'dancesrecordingsmap' VALUES (6536, 1582, NULL, 6688);
INSERT INTO 'dancesrecordingsmap' VALUES (6537, 6029, NULL, 6689);
INSERT INTO 'dancesrecordingsmap' VALUES (6538, 7068, NULL, 6690);
INSERT INTO 'dancesrecordingsmap' VALUES (6539, 682, NULL, 6691);
INSERT INTO 'dancesrecordingsmap' VALUES (6542, 1087, NULL, 6694);
INSERT INTO 'dancesrecordingsmap' VALUES (6543, 4827, NULL, 6695);
INSERT INTO 'dancesrecordingsmap' VALUES (6545, 5529, NULL, 6697);
INSERT INTO 'dancesrecordingsmap' VALUES (6546, 9636, NULL, 6698);
INSERT INTO 'dancesrecordingsmap' VALUES (6547, 12542, NULL, 6699);
INSERT INTO 'dancesrecordingsmap' VALUES (6548, 1884, NULL, 6700);
INSERT INTO 'dancesrecordingsmap' VALUES (6549, 8743, NULL, 6701);
INSERT INTO 'dancesrecordingsmap' VALUES (6550, 4484, NULL, 6702);
INSERT INTO 'dancesrecordingsmap' VALUES (6551, 4805, NULL, 6703);
INSERT INTO 'dancesrecordingsmap' VALUES (6553, 2437, NULL, 6705);
INSERT INTO 'dancesrecordingsmap' VALUES (6554, 5326, NULL, 6706);
INSERT INTO 'dancesrecordingsmap' VALUES (6555, 900, NULL, 6707);
INSERT INTO 'dancesrecordingsmap' VALUES (6556, 11371, NULL, 6708);
INSERT INTO 'dancesrecordingsmap' VALUES (6557, 5525, NULL, 6709);
INSERT INTO 'dancesrecordingsmap' VALUES (6558, 1864, NULL, 6710);
INSERT INTO 'dancesrecordingsmap' VALUES (6559, 4442, NULL, 6711);
INSERT INTO 'dancesrecordingsmap' VALUES (6560, 4806, NULL, 6712);
INSERT INTO 'dancesrecordingsmap' VALUES (6561, 410, NULL, 6713);
INSERT INTO 'dancesrecordingsmap' VALUES (6562, 2925, NULL, 6714);
INSERT INTO 'dancesrecordingsmap' VALUES (6563, 3526, NULL, 6715);
INSERT INTO 'dancesrecordingsmap' VALUES (6564, 4907, NULL, 6716);
INSERT INTO 'dancesrecordingsmap' VALUES (6565, 2257, NULL, 6717);
INSERT INTO 'dancesrecordingsmap' VALUES (6566, 6349, NULL, 6718);
INSERT INTO 'dancesrecordingsmap' VALUES (6568, 794, NULL, 6720);
INSERT INTO 'dancesrecordingsmap' VALUES (6569, 3580, NULL, 6721);
INSERT INTO 'dancesrecordingsmap' VALUES (6570, 7109, NULL, 6722);
INSERT INTO 'dancesrecordingsmap' VALUES (6571, 10535, NULL, 6723);
INSERT INTO 'dancesrecordingsmap' VALUES (6572, 3700, NULL, 6724);
INSERT INTO 'dancesrecordingsmap' VALUES (6573, 5794, NULL, 6725);
INSERT INTO 'dancesrecordingsmap' VALUES (6574, 3802, NULL, 6726);
INSERT INTO 'dancesrecordingsmap' VALUES (6575, 6091, NULL, 6727);
INSERT INTO 'dancesrecordingsmap' VALUES (6576, 6287, NULL, 6728);
INSERT INTO 'dancesrecordingsmap' VALUES (6577, 4844, NULL, 6729);
INSERT INTO 'dancesrecordingsmap' VALUES (6578, 4844, NULL, 6730);
INSERT INTO 'dancesrecordingsmap' VALUES (6579, 1100, NULL, 6731);
INSERT INTO 'dancesrecordingsmap' VALUES (6580, 5308, NULL, 6732);
INSERT INTO 'dancesrecordingsmap' VALUES (6581, 754, NULL, 6733);
INSERT INTO 'dancesrecordingsmap' VALUES (6582, 13372, NULL, 6734);
INSERT INTO 'dancesrecordingsmap' VALUES (6583, 615, NULL, 6735);
INSERT INTO 'dancesrecordingsmap' VALUES (6584, 4890, NULL, 6736);
INSERT INTO 'dancesrecordingsmap' VALUES (6519, 2600, NULL, 6671);
INSERT INTO 'dancesrecordingsmap' VALUES (6281, 13185, NULL, 5478);
INSERT INTO 'dancesrecordingsmap' VALUES (6449, 9083, NULL, 6591);
INSERT INTO 'dancesrecordingsmap' VALUES (6380, 13359, NULL, 6523);
INSERT INTO 'dancesrecordingsmap' VALUES (6474, 3651, NULL, 6626);
INSERT INTO 'dancesrecordingsmap' VALUES (6273, 13173, NULL, 5039);
INSERT INTO 'dancesrecordingsmap' VALUES (6541, 3672, NULL, 6693);
INSERT INTO 'dancesrecordingsmap' VALUES (6475, 3651, NULL, 6627);
INSERT INTO 'dancesrecordingsmap' VALUES (6276, 13179, NULL, 5028);
INSERT INTO 'dancesrecordingsmap' VALUES (6552, 9638, NULL, 6704);
INSERT INTO 'dancesrecordingsmap' VALUES (6488, 5006, NULL, 6640);
INSERT INTO 'dancesrecordingsmap' VALUES (6585, 4805, NULL, 6737);
INSERT INTO 'dancesrecordingsmap' VALUES (6586, 4102, NULL, 6738);
INSERT INTO 'dancesrecordingsmap' VALUES (6587, 4102, NULL, 6739);
INSERT INTO 'dancesrecordingsmap' VALUES (6588, 13374, NULL, 6741);
INSERT INTO 'dancesrecordingsmap' VALUES (6590, 13376, NULL, 6743);
INSERT INTO 'dancesrecordingsmap' VALUES (6591, 13373, NULL, 6744);
INSERT INTO 'dancesrecordingsmap' VALUES (6592, 1173, NULL, 6745);
INSERT INTO 'dancesrecordingsmap' VALUES (6593, 1204, NULL, 6746);
INSERT INTO 'dancesrecordingsmap' VALUES (6594, 13377, NULL, 6747);
INSERT INTO 'dancesrecordingsmap' VALUES (6595, 13378, NULL, 6748);
INSERT INTO 'dancesrecordingsmap' VALUES (6596, 9261, NULL, 6749);
INSERT INTO 'dancesrecordingsmap' VALUES (6597, 13379, NULL, 6750);
INSERT INTO 'dancesrecordingsmap' VALUES (6598, 13380, NULL, 6751);
INSERT INTO 'dancesrecordingsmap' VALUES (6599, 12290, NULL, 6752);
INSERT INTO 'dancesrecordingsmap' VALUES (6600, 11874, NULL, 6753);
INSERT INTO 'dancesrecordingsmap' VALUES (6601, 11873, NULL, 6754);
INSERT INTO 'dancesrecordingsmap' VALUES (6602, 13381, NULL, 6755);
INSERT INTO 'dancesrecordingsmap' VALUES (6603, 13382, NULL, 6756);
INSERT INTO 'dancesrecordingsmap' VALUES (6604, 1641, NULL, 6757);
INSERT INTO 'dancesrecordingsmap' VALUES (6511, 314, NULL, 6663);
INSERT INTO 'dancesrecordingsmap' VALUES (6606, 6196, NULL, 6759);
INSERT INTO 'dancesrecordingsmap' VALUES (6607, 1296, NULL, 6760);
INSERT INTO 'dancesrecordingsmap' VALUES (6608, 2360, NULL, 6761);
INSERT INTO 'dancesrecordingsmap' VALUES (6609, 11587, NULL, 6762);
INSERT INTO 'dancesrecordingsmap' VALUES (6610, 2203, NULL, 6763);
INSERT INTO 'dancesrecordingsmap' VALUES (6611, 5794, NULL, 6764);
INSERT INTO 'dancesrecordingsmap' VALUES (6613, 13248, NULL, 6766);
INSERT INTO 'dancesrecordingsmap' VALUES (6614, 1473, NULL, 6767);
INSERT INTO 'dancesrecordingsmap' VALUES (6615, 5209, NULL, 6768);
INSERT INTO 'dancesrecordingsmap' VALUES (6616, 6052, NULL, 6769);
INSERT INTO 'dancesrecordingsmap' VALUES (6617, 13383, NULL, 6770);
INSERT INTO 'dancesrecordingsmap' VALUES (6618, 4102, NULL, 6771);
INSERT INTO 'dancesrecordingsmap' VALUES (6619, 1283, NULL, 6772);
INSERT INTO 'dancesrecordingsmap' VALUES (6620, 2742, NULL, 6773);
INSERT INTO 'dancesrecordingsmap' VALUES (6621, 2918, NULL, 6774);
INSERT INTO 'dancesrecordingsmap' VALUES (6622, 430, NULL, 6775);
INSERT INTO 'dancesrecordingsmap' VALUES (6623, 4126, NULL, 6776);
INSERT INTO 'dancesrecordingsmap' VALUES (6624, 2700, NULL, 6777);
INSERT INTO 'dancesrecordingsmap' VALUES (6625, 910, NULL, 6778);
INSERT INTO 'dancesrecordingsmap' VALUES (6626, 6058, NULL, 6779);
INSERT INTO 'dancesrecordingsmap' VALUES (6627, 2360, NULL, 6780);
INSERT INTO 'dancesrecordingsmap' VALUES (6628, 3323, NULL, 6781);
INSERT INTO 'dancesrecordingsmap' VALUES (6629, 5308, NULL, 6782);
INSERT INTO 'dancesrecordingsmap' VALUES (6630, 4558, NULL, 6783);
INSERT INTO 'dancesrecordingsmap' VALUES (6631, 4959, NULL, 6784);
INSERT INTO 'dancesrecordingsmap' VALUES (6632, 1776, NULL, 6785);
INSERT INTO 'dancesrecordingsmap' VALUES (6633, 877, NULL, 6786);
INSERT INTO 'dancesrecordingsmap' VALUES (6634, 6489, NULL, 6787);
INSERT INTO 'dancesrecordingsmap' VALUES (6635, 5858, NULL, 6788);
INSERT INTO 'dancesrecordingsmap' VALUES (6636, 5713, NULL, 6789);
INSERT INTO 'dancesrecordingsmap' VALUES (6637, 5519, NULL, 6790);
INSERT INTO 'dancesrecordingsmap' VALUES (6638, 5982, NULL, 6791);
INSERT INTO 'dancesrecordingsmap' VALUES (6639, 3558, NULL, 6792);
INSERT INTO 'dancesrecordingsmap' VALUES (6641, 301, NULL, 6794);
INSERT INTO 'dancesrecordingsmap' VALUES (6540, 3281, NULL, 6692);
INSERT INTO 'dancesrecordingsmap' VALUES (6489, 314, NULL, 6641);
INSERT INTO 'dancesrecordingsmap' VALUES (6567, 5525, NULL, 6719);
INSERT INTO 'dancesrecordingsmap' VALUES (9117, 16794, NULL, 757);
INSERT INTO 'dancesrecordingsmap' VALUES (9119, 17275, NULL, 10199);
INSERT INTO 'dancesrecordingsmap' VALUES (6640, 4563, NULL, 6793);
INSERT INTO 'dancesrecordingsmap' VALUES (6495, 12538, NULL, 6647);
INSERT INTO 'dancesrecordingsmap' VALUES (6642, 5713, NULL, 6795);
INSERT INTO 'dancesrecordingsmap' VALUES (6643, 5519, NULL, 6796);
INSERT INTO 'dancesrecordingsmap' VALUES (6644, 3541, NULL, 6797);
INSERT INTO 'dancesrecordingsmap' VALUES (6589, 587, NULL, 6742);
INSERT INTO 'dancesrecordingsmap' VALUES (6645, 4646, NULL, 6798);
INSERT INTO 'dancesrecordingsmap' VALUES (6646, 3342, NULL, 6799);
INSERT INTO 'dancesrecordingsmap' VALUES (6647, 3084, NULL, 6800);
INSERT INTO 'dancesrecordingsmap' VALUES (6648, 6152, NULL, 6801);
INSERT INTO 'dancesrecordingsmap' VALUES (6649, 13384, NULL, 6802);
INSERT INTO 'dancesrecordingsmap' VALUES (6650, 4679, NULL, 6803);
INSERT INTO 'dancesrecordingsmap' VALUES (6651, 3912, NULL, 6804);
INSERT INTO 'dancesrecordingsmap' VALUES (6652, 2495, NULL, 6805);
INSERT INTO 'dancesrecordingsmap' VALUES (6653, 3105, NULL, 6806);
INSERT INTO 'dancesrecordingsmap' VALUES (6654, 5462, NULL, 6807);
INSERT INTO 'dancesrecordingsmap' VALUES (6655, 4559, NULL, 6808);
INSERT INTO 'dancesrecordingsmap' VALUES (6657, 6848, NULL, 6810);
INSERT INTO 'dancesrecordingsmap' VALUES (6659, 6885, NULL, 6812);
INSERT INTO 'dancesrecordingsmap' VALUES (6660, 4440, NULL, 6813);
INSERT INTO 'dancesrecordingsmap' VALUES (6662, 1762, NULL, 6815);
INSERT INTO 'dancesrecordingsmap' VALUES (6663, 4565, NULL, 6816);
INSERT INTO 'dancesrecordingsmap' VALUES (6664, 4518, NULL, 6817);
INSERT INTO 'dancesrecordingsmap' VALUES (6666, 2024, NULL, 6819);
INSERT INTO 'dancesrecordingsmap' VALUES (6667, 1280, NULL, 6820);
INSERT INTO 'dancesrecordingsmap' VALUES (6668, 6763, NULL, 6821);
INSERT INTO 'dancesrecordingsmap' VALUES (6669, 5207, NULL, 6822);
INSERT INTO 'dancesrecordingsmap' VALUES (6670, 958, NULL, 6823);
INSERT INTO 'dancesrecordingsmap' VALUES (6671, 3972, NULL, 6824);
INSERT INTO 'dancesrecordingsmap' VALUES (6672, 5591, NULL, 6825);
INSERT INTO 'dancesrecordingsmap' VALUES (6673, 3722, NULL, 6826);
INSERT INTO 'dancesrecordingsmap' VALUES (6674, 738, NULL, 6827);
INSERT INTO 'dancesrecordingsmap' VALUES (6675, 571, NULL, 6828);
INSERT INTO 'dancesrecordingsmap' VALUES (6676, 3246, NULL, 6829);
INSERT INTO 'dancesrecordingsmap' VALUES (6677, 3730, NULL, 6830);
INSERT INTO 'dancesrecordingsmap' VALUES (6678, 6599, NULL, 6831);
INSERT INTO 'dancesrecordingsmap' VALUES (6680, 4928, NULL, 6833);
INSERT INTO 'dancesrecordingsmap' VALUES (6682, 4064, NULL, 6835);
INSERT INTO 'dancesrecordingsmap' VALUES (6683, 909, NULL, 6836);
INSERT INTO 'dancesrecordingsmap' VALUES (6684, 1100, NULL, 6837);
INSERT INTO 'dancesrecordingsmap' VALUES (6707, 3284, NULL, 6860);
INSERT INTO 'dancesrecordingsmap' VALUES (6686, 12793, NULL, 6839);
INSERT INTO 'dancesrecordingsmap' VALUES (6687, 12794, NULL, 6840);
INSERT INTO 'dancesrecordingsmap' VALUES (6688, 13316, NULL, 6841);
INSERT INTO 'dancesrecordingsmap' VALUES (6689, 4450, NULL, 6842);
INSERT INTO 'dancesrecordingsmap' VALUES (6690, 3284, NULL, 6843);
INSERT INTO 'dancesrecordingsmap' VALUES (6691, 1773, NULL, 6844);
INSERT INTO 'dancesrecordingsmap' VALUES (6692, 4862, NULL, 6845);
INSERT INTO 'dancesrecordingsmap' VALUES (6693, 4755, NULL, 6846);
INSERT INTO 'dancesrecordingsmap' VALUES (6694, 1501, NULL, 6847);
INSERT INTO 'dancesrecordingsmap' VALUES (6695, 13385, NULL, 6848);
INSERT INTO 'dancesrecordingsmap' VALUES (6697, 4928, NULL, 6850);
INSERT INTO 'dancesrecordingsmap' VALUES (6699, 4064, NULL, 6852);
INSERT INTO 'dancesrecordingsmap' VALUES (6700, 909, NULL, 6853);
INSERT INTO 'dancesrecordingsmap' VALUES (6701, 1100, NULL, 6854);
INSERT INTO 'dancesrecordingsmap' VALUES (9118, 16794, NULL, 5807);
INSERT INTO 'dancesrecordingsmap' VALUES (6703, 12793, NULL, 6856);
INSERT INTO 'dancesrecordingsmap' VALUES (6704, 12794, NULL, 6857);
INSERT INTO 'dancesrecordingsmap' VALUES (6705, 13316, NULL, 6858);
INSERT INTO 'dancesrecordingsmap' VALUES (6706, 4450, NULL, 6859);
INSERT INTO 'dancesrecordingsmap' VALUES (6708, 1773, NULL, 6861);
INSERT INTO 'dancesrecordingsmap' VALUES (6709, 4862, NULL, 6862);
INSERT INTO 'dancesrecordingsmap' VALUES (6710, 4755, NULL, 6863);
INSERT INTO 'dancesrecordingsmap' VALUES (6711, 1501, NULL, 6864);
INSERT INTO 'dancesrecordingsmap' VALUES (6661, 4455, NULL, 6814);
INSERT INTO 'dancesrecordingsmap' VALUES (6658, 4431, NULL, 6811);
INSERT INTO 'dancesrecordingsmap' VALUES (6544, 13371, NULL, 6696);
INSERT INTO 'dancesrecordingsmap' VALUES (6712, 13385, NULL, 6865);
INSERT INTO 'dancesrecordingsmap' VALUES (6715, 4928, NULL, 6868);
INSERT INTO 'dancesrecordingsmap' VALUES (6717, 4064, NULL, 6870);
INSERT INTO 'dancesrecordingsmap' VALUES (6718, 909, NULL, 6871);
INSERT INTO 'dancesrecordingsmap' VALUES (6720, 521, NULL, 6873);
INSERT INTO 'dancesrecordingsmap' VALUES (6723, 13316, NULL, 6876);
INSERT INTO 'dancesrecordingsmap' VALUES (9137, 5754, NULL, 10204);
INSERT INTO 'dancesrecordingsmap' VALUES (9139, 3607, NULL, 10207);
INSERT INTO 'dancesrecordingsmap' VALUES (9140, 5981, NULL, 10211);
INSERT INTO 'dancesrecordingsmap' VALUES (6729, 13387, NULL, 6882);
INSERT INTO 'dancesrecordingsmap' VALUES (9141, 3638, NULL, 10212);
INSERT INTO 'dancesrecordingsmap' VALUES (5785, 743, NULL, 6077);
INSERT INTO 'dancesrecordingsmap' VALUES (6777, 12963, NULL, 6932);
INSERT INTO 'dancesrecordingsmap' VALUES (6734, 13393, NULL, 6887);
INSERT INTO 'dancesrecordingsmap' VALUES (6735, 13394, NULL, 6888);
INSERT INTO 'dancesrecordingsmap' VALUES (6736, 13395, NULL, 6889);
INSERT INTO 'dancesrecordingsmap' VALUES (6737, 13388, NULL, 6891);
INSERT INTO 'dancesrecordingsmap' VALUES (6739, 13389, NULL, 6893);
INSERT INTO 'dancesrecordingsmap' VALUES (6740, 13286, NULL, 6894);
INSERT INTO 'dancesrecordingsmap' VALUES (6742, 13387, NULL, 6896);
INSERT INTO 'dancesrecordingsmap' VALUES (6744, 13391, NULL, 6898);
INSERT INTO 'dancesrecordingsmap' VALUES (6745, 13392, NULL, 6899);
INSERT INTO 'dancesrecordingsmap' VALUES (6747, 13393, NULL, 6901);
INSERT INTO 'dancesrecordingsmap' VALUES (6748, 13394, NULL, 6902);
INSERT INTO 'dancesrecordingsmap' VALUES (6749, 13395, NULL, 6903);
INSERT INTO 'dancesrecordingsmap' VALUES (6750, 13396, NULL, 6904);
INSERT INTO 'dancesrecordingsmap' VALUES (6751, 2910, NULL, 6905);
INSERT INTO 'dancesrecordingsmap' VALUES (6752, 1210, NULL, 6906);
INSERT INTO 'dancesrecordingsmap' VALUES (6776, 12965, NULL, 6931);
INSERT INTO 'dancesrecordingsmap' VALUES (6754, 4291, NULL, 6908);
INSERT INTO 'dancesrecordingsmap' VALUES (6756, 3580, NULL, 6910);
INSERT INTO 'dancesrecordingsmap' VALUES (6757, 674, NULL, 6911);
INSERT INTO 'dancesrecordingsmap' VALUES (6758, 6010, NULL, 6912);
INSERT INTO 'dancesrecordingsmap' VALUES (6759, 1348, NULL, 6913);
INSERT INTO 'dancesrecordingsmap' VALUES (6760, 6616, NULL, 6914);
INSERT INTO 'dancesrecordingsmap' VALUES (6761, 2024, NULL, 6915);
INSERT INTO 'dancesrecordingsmap' VALUES (6762, 6048, NULL, 6917);
INSERT INTO 'dancesrecordingsmap' VALUES (6763, 1777, NULL, 6918);
INSERT INTO 'dancesrecordingsmap' VALUES (6764, 2349, NULL, 6919);
INSERT INTO 'dancesrecordingsmap' VALUES (6767, 3659, NULL, 6922);
INSERT INTO 'dancesrecordingsmap' VALUES (6768, 6052, NULL, 6923);
INSERT INTO 'dancesrecordingsmap' VALUES (6769, 4102, NULL, 6924);
INSERT INTO 'dancesrecordingsmap' VALUES (6770, 12967, NULL, 6925);
INSERT INTO 'dancesrecordingsmap' VALUES (6771, 12966, NULL, 6926);
INSERT INTO 'dancesrecordingsmap' VALUES (6772, 12960, NULL, 6927);
INSERT INTO 'dancesrecordingsmap' VALUES (6773, 12962, NULL, 6928);
INSERT INTO 'dancesrecordingsmap' VALUES (6774, 12969, NULL, 6929);
INSERT INTO 'dancesrecordingsmap' VALUES (6779, 12970, NULL, 6934);
INSERT INTO 'dancesrecordingsmap' VALUES (6781, 12972, NULL, 6936);
INSERT INTO 'dancesrecordingsmap' VALUES (6782, 9837, NULL, 6937);
INSERT INTO 'dancesrecordingsmap' VALUES (6783, 12979, NULL, 6938);
INSERT INTO 'dancesrecordingsmap' VALUES (6784, 12981, NULL, 6939);
INSERT INTO 'dancesrecordingsmap' VALUES (6612, 2129, NULL, 6765);
INSERT INTO 'dancesrecordingsmap' VALUES (6679, 5032, NULL, 6832);
INSERT INTO 'dancesrecordingsmap' VALUES (6765, 6712, NULL, 6920);
INSERT INTO 'dancesrecordingsmap' VALUES (6766, 3281, NULL, 6921);
INSERT INTO 'dancesrecordingsmap' VALUES (6785, 12978, NULL, 6940);
INSERT INTO 'dancesrecordingsmap' VALUES (6786, 12982, NULL, 6941);
INSERT INTO 'dancesrecordingsmap' VALUES (6787, 12974, NULL, 6942);
INSERT INTO 'dancesrecordingsmap' VALUES (6788, 12976, NULL, 6943);
INSERT INTO 'dancesrecordingsmap' VALUES (6789, 12980, NULL, 6944);
INSERT INTO 'dancesrecordingsmap' VALUES (6790, 12975, NULL, 6945);
INSERT INTO 'dancesrecordingsmap' VALUES (6791, 12977, NULL, 6946);
INSERT INTO 'dancesrecordingsmap' VALUES (6793, 13404, NULL, 6948);
INSERT INTO 'dancesrecordingsmap' VALUES (6794, 13405, NULL, 6949);
INSERT INTO 'dancesrecordingsmap' VALUES (6795, 13406, NULL, 6950);
INSERT INTO 'dancesrecordingsmap' VALUES (6796, 13407, NULL, 6951);
INSERT INTO 'dancesrecordingsmap' VALUES (6798, 13409, NULL, 6953);
INSERT INTO 'dancesrecordingsmap' VALUES (6799, 13410, NULL, 6954);
INSERT INTO 'dancesrecordingsmap' VALUES (6800, 13411, NULL, 6955);
INSERT INTO 'dancesrecordingsmap' VALUES (6801, 13412, NULL, 6956);
INSERT INTO 'dancesrecordingsmap' VALUES (6802, 13413, NULL, 6957);
INSERT INTO 'dancesrecordingsmap' VALUES (6804, 13415, NULL, 6959);
INSERT INTO 'dancesrecordingsmap' VALUES (6805, 13416, NULL, 6960);
INSERT INTO 'dancesrecordingsmap' VALUES (6806, 13417, NULL, 6961);
INSERT INTO 'dancesrecordingsmap' VALUES (6807, 13418, NULL, 6962);
INSERT INTO 'dancesrecordingsmap' VALUES (6808, 13419, NULL, 6963);
INSERT INTO 'dancesrecordingsmap' VALUES (6809, 13420, NULL, 6964);
INSERT INTO 'dancesrecordingsmap' VALUES (6810, 13421, NULL, 6965);
INSERT INTO 'dancesrecordingsmap' VALUES (6811, 13422, NULL, 6966);
INSERT INTO 'dancesrecordingsmap' VALUES (6812, 13423, NULL, 6967);
INSERT INTO 'dancesrecordingsmap' VALUES (6813, 13424, NULL, 6968);
INSERT INTO 'dancesrecordingsmap' VALUES (6814, 13425, NULL, 6969);
INSERT INTO 'dancesrecordingsmap' VALUES (6816, 13439, NULL, 6971);
INSERT INTO 'dancesrecordingsmap' VALUES (6818, 8838, NULL, 6973);
INSERT INTO 'dancesrecordingsmap' VALUES (6819, 13264, NULL, 6974);
INSERT INTO 'dancesrecordingsmap' VALUES (6820, 13429, NULL, 6975);
INSERT INTO 'dancesrecordingsmap' VALUES (6821, 8834, NULL, 6976);
INSERT INTO 'dancesrecordingsmap' VALUES (6824, 13432, NULL, 6979);
INSERT INTO 'dancesrecordingsmap' VALUES (6826, 13434, NULL, 6981);
INSERT INTO 'dancesrecordingsmap' VALUES (6827, 11943, NULL, 6982);
INSERT INTO 'dancesrecordingsmap' VALUES (6828, 11944, NULL, 6983);
INSERT INTO 'dancesrecordingsmap' VALUES (6829, 11533, NULL, 6984);
INSERT INTO 'dancesrecordingsmap' VALUES (6830, 13435, NULL, 6985);
INSERT INTO 'dancesrecordingsmap' VALUES (6831, 13266, NULL, 6986);
INSERT INTO 'dancesrecordingsmap' VALUES (6803, 13414, NULL, 6958);
INSERT INTO 'dancesrecordingsmap' VALUES (6713, 4411, NULL, 6866);
INSERT INTO 'dancesrecordingsmap' VALUES (6780, 12973, NULL, 6935);
INSERT INTO 'dancesrecordingsmap' VALUES (6797, 13408, NULL, 6952);
INSERT INTO 'dancesrecordingsmap' VALUES (6743, 12603, NULL, 6897);
INSERT INTO 'dancesrecordingsmap' VALUES (6753, 3766, NULL, 6907);
INSERT INTO 'dancesrecordingsmap' VALUES (6775, 12965, NULL, 6930);
INSERT INTO 'dancesrecordingsmap' VALUES (6778, 12964, 603, 6933);
INSERT INTO 'dancesrecordingsmap' VALUES (9120, 17568, NULL, 10200);
INSERT INTO 'dancesrecordingsmap' VALUES (6722, 12794, NULL, 6875);
INSERT INTO 'dancesrecordingsmap' VALUES (6656, 1020, NULL, 6809);
INSERT INTO 'dancesrecordingsmap' VALUES (6832, 8837, NULL, 6987);
INSERT INTO 'dancesrecordingsmap' VALUES (6835, 9875, NULL, 6990);
INSERT INTO 'dancesrecordingsmap' VALUES (6836, 13438, NULL, 6991);
INSERT INTO 'dancesrecordingsmap' VALUES (6837, 13439, NULL, 6992);
INSERT INTO 'dancesrecordingsmap' VALUES (6839, 13441, NULL, 6994);
INSERT INTO 'dancesrecordingsmap' VALUES (6840, 13442, NULL, 6995);
INSERT INTO 'dancesrecordingsmap' VALUES (6841, 1474, NULL, 6996);
INSERT INTO 'dancesrecordingsmap' VALUES (6842, 13443, NULL, 6997);
INSERT INTO 'dancesrecordingsmap' VALUES (6843, 13444, NULL, 6998);
INSERT INTO 'dancesrecordingsmap' VALUES (6844, 13445, NULL, 6999);
INSERT INTO 'dancesrecordingsmap' VALUES (6845, 13446, NULL, 7000);
INSERT INTO 'dancesrecordingsmap' VALUES (6846, 13447, NULL, 7001);
INSERT INTO 'dancesrecordingsmap' VALUES (6847, 13448, NULL, 7002);
INSERT INTO 'dancesrecordingsmap' VALUES (6848, 1492, NULL, 7003);
INSERT INTO 'dancesrecordingsmap' VALUES (6850, 11277, NULL, 7005);
INSERT INTO 'dancesrecordingsmap' VALUES (6852, 3105, NULL, 7007);
INSERT INTO 'dancesrecordingsmap' VALUES (6854, 6098, NULL, 7009);
INSERT INTO 'dancesrecordingsmap' VALUES (6857, 11970, NULL, 7012);
INSERT INTO 'dancesrecordingsmap' VALUES (6858, 6860, NULL, 7013);
INSERT INTO 'dancesrecordingsmap' VALUES (6861, 13451, NULL, 7016);
INSERT INTO 'dancesrecordingsmap' VALUES (6862, 10339, NULL, 7017);
INSERT INTO 'dancesrecordingsmap' VALUES (6863, 13453, NULL, 7018);
INSERT INTO 'dancesrecordingsmap' VALUES (6864, 10324, NULL, 7019);
INSERT INTO 'dancesrecordingsmap' VALUES (6865, 7873, NULL, 7020);
INSERT INTO 'dancesrecordingsmap' VALUES (6866, 9699, NULL, 7021);
INSERT INTO 'dancesrecordingsmap' VALUES (6867, 11749, NULL, 7022);
INSERT INTO 'dancesrecordingsmap' VALUES (6868, 4537, NULL, 7023);
INSERT INTO 'dancesrecordingsmap' VALUES (6869, 13455, NULL, 7024);
INSERT INTO 'dancesrecordingsmap' VALUES (6870, 13456, NULL, 7025);
INSERT INTO 'dancesrecordingsmap' VALUES (6874, 13460, NULL, 7029);
INSERT INTO 'dancesrecordingsmap' VALUES (6879, 13464, NULL, 7034);
INSERT INTO 'dancesrecordingsmap' VALUES (6880, 13465, NULL, 7035);
INSERT INTO 'dancesrecordingsmap' VALUES (6881, 13466, NULL, 7036);
INSERT INTO 'dancesrecordingsmap' VALUES (6882, 13467, NULL, 7037);
INSERT INTO 'dancesrecordingsmap' VALUES (6883, 13468, NULL, 7038);
INSERT INTO 'dancesrecordingsmap' VALUES (6884, 13469, NULL, 7039);
INSERT INTO 'dancesrecordingsmap' VALUES (6885, 13470, NULL, 7040);
INSERT INTO 'dancesrecordingsmap' VALUES (6886, 13471, NULL, 7041);
INSERT INTO 'dancesrecordingsmap' VALUES (7009, 6150, NULL, 7213);
INSERT INTO 'dancesrecordingsmap' VALUES (6888, 13472, NULL, 7043);
INSERT INTO 'dancesrecordingsmap' VALUES (6889, 13473, NULL, 7044);
INSERT INTO 'dancesrecordingsmap' VALUES (6890, 9203, NULL, 7045);
INSERT INTO 'dancesrecordingsmap' VALUES (6891, 9206, NULL, 7046);
INSERT INTO 'dancesrecordingsmap' VALUES (6892, 9204, NULL, 7047);
INSERT INTO 'dancesrecordingsmap' VALUES (6893, 9211, NULL, 7048);
INSERT INTO 'dancesrecordingsmap' VALUES (6894, 9217, NULL, 7049);
INSERT INTO 'dancesrecordingsmap' VALUES (6895, 13351, NULL, 7050);
INSERT INTO 'dancesrecordingsmap' VALUES (6896, 10171, NULL, 7051);
INSERT INTO 'dancesrecordingsmap' VALUES (6897, 13475, NULL, 7052);
INSERT INTO 'dancesrecordingsmap' VALUES (6898, 13476, NULL, 7053);
INSERT INTO 'dancesrecordingsmap' VALUES (6899, 13477, NULL, 7054);
INSERT INTO 'dancesrecordingsmap' VALUES (6900, 13478, NULL, 7055);
INSERT INTO 'dancesrecordingsmap' VALUES (6902, 13480, NULL, 7057);
INSERT INTO 'dancesrecordingsmap' VALUES (6903, 13481, NULL, 7058);
INSERT INTO 'dancesrecordingsmap' VALUES (6904, 13482, NULL, 7059);
INSERT INTO 'dancesrecordingsmap' VALUES (6906, 9220, NULL, 7061);
INSERT INTO 'dancesrecordingsmap' VALUES (6908, 13483, NULL, 7063);
INSERT INTO 'dancesrecordingsmap' VALUES (7004, 5480, NULL, 7208);
INSERT INTO 'dancesrecordingsmap' VALUES (6910, 11780, NULL, 7065);
INSERT INTO 'dancesrecordingsmap' VALUES (6911, 13485, NULL, 7066);
INSERT INTO 'dancesrecordingsmap' VALUES (6912, 13486, NULL, 7067);
INSERT INTO 'dancesrecordingsmap' VALUES (6878, 13449, NULL, 7033);
INSERT INTO 'dancesrecordingsmap' VALUES (6823, 13431, NULL, 6978);
INSERT INTO 'dancesrecordingsmap' VALUES (6833, 13436, NULL, 6988);
INSERT INTO 'dancesrecordingsmap' VALUES (6859, 10286, NULL, 7014);
INSERT INTO 'dancesrecordingsmap' VALUES (6875, 13461, NULL, 7030);
INSERT INTO 'dancesrecordingsmap' VALUES (6815, 13426, NULL, 6970);
INSERT INTO 'dancesrecordingsmap' VALUES (6738, 13282, NULL, 6892);
INSERT INTO 'dancesrecordingsmap' VALUES (6871, 6860, NULL, 7026);
INSERT INTO 'dancesrecordingsmap' VALUES (6905, 9214, NULL, 7060);
INSERT INTO 'dancesrecordingsmap' VALUES (6741, 13390, NULL, 6895);
INSERT INTO 'dancesrecordingsmap' VALUES (6721, 12793, NULL, 6874);
INSERT INTO 'dancesrecordingsmap' VALUES (6913, 13487, NULL, 7068);
INSERT INTO 'dancesrecordingsmap' VALUES (6915, 13489, NULL, 7070);
INSERT INTO 'dancesrecordingsmap' VALUES (6917, 13847, NULL, 7072);
INSERT INTO 'dancesrecordingsmap' VALUES (6901, 13479, NULL, 7056);
INSERT INTO 'dancesrecordingsmap' VALUES (6920, 13850, NULL, 7075);
INSERT INTO 'dancesrecordingsmap' VALUES (6922, 13852, NULL, 7077);
INSERT INTO 'dancesrecordingsmap' VALUES (6923, 2563, NULL, 7078);
INSERT INTO 'dancesrecordingsmap' VALUES (6924, 1760, NULL, 7079);
INSERT INTO 'dancesrecordingsmap' VALUES (6926, 13498, NULL, 7083);
INSERT INTO 'dancesrecordingsmap' VALUES (6927, 13499, NULL, 7084);
INSERT INTO 'dancesrecordingsmap' VALUES (6929, 13501, NULL, 7086);
INSERT INTO 'dancesrecordingsmap' VALUES (6931, 13503, NULL, 7088);
INSERT INTO 'dancesrecordingsmap' VALUES (6932, 13504, NULL, 7089);
INSERT INTO 'dancesrecordingsmap' VALUES (6934, 13506, NULL, 7091);
INSERT INTO 'dancesrecordingsmap' VALUES (6935, 13507, NULL, 7092);
INSERT INTO 'dancesrecordingsmap' VALUES (6936, 13508, NULL, 7093);
INSERT INTO 'dancesrecordingsmap' VALUES (6937, 909, NULL, 7095);
INSERT INTO 'dancesrecordingsmap' VALUES (6938, 13509, NULL, 7096);
INSERT INTO 'dancesrecordingsmap' VALUES (6939, 743, NULL, 7097);
INSERT INTO 'dancesrecordingsmap' VALUES (6940, 352, NULL, 7098);
INSERT INTO 'dancesrecordingsmap' VALUES (6941, 1280, NULL, 7102);
INSERT INTO 'dancesrecordingsmap' VALUES (6942, 3759, NULL, 7103);
INSERT INTO 'dancesrecordingsmap' VALUES (6943, 848, NULL, 7106);
INSERT INTO 'dancesrecordingsmap' VALUES (6944, 6471, NULL, 7129);
INSERT INTO 'dancesrecordingsmap' VALUES (6945, 1533, NULL, 7130);
INSERT INTO 'dancesrecordingsmap' VALUES (6946, 11763, NULL, 7131);
INSERT INTO 'dancesrecordingsmap' VALUES (6947, 2453, NULL, 7132);
INSERT INTO 'dancesrecordingsmap' VALUES (6948, 909, NULL, 7133);
INSERT INTO 'dancesrecordingsmap' VALUES (6949, 1473, NULL, 7134);
INSERT INTO 'dancesrecordingsmap' VALUES (6950, 1544, NULL, 7135);
INSERT INTO 'dancesrecordingsmap' VALUES (6951, 2203, NULL, 7136);
INSERT INTO 'dancesrecordingsmap' VALUES (6952, 6373, NULL, 7137);
INSERT INTO 'dancesrecordingsmap' VALUES (6953, 1884, NULL, 7138);
INSERT INTO 'dancesrecordingsmap' VALUES (6954, 3336, NULL, 7139);
INSERT INTO 'dancesrecordingsmap' VALUES (6955, 11373, NULL, 7140);
INSERT INTO 'dancesrecordingsmap' VALUES (6956, 887, NULL, 7141);
INSERT INTO 'dancesrecordingsmap' VALUES (6957, 4928, NULL, 7142);
INSERT INTO 'dancesrecordingsmap' VALUES (9128, 13654, NULL, 10192);
INSERT INTO 'dancesrecordingsmap' VALUES (9122, 17555, NULL, 10186);
INSERT INTO 'dancesrecordingsmap' VALUES (2312, 1470, NULL, 2898);
INSERT INTO 'dancesrecordingsmap' VALUES (9151, 14401, NULL, 10223);
INSERT INTO 'dancesrecordingsmap' VALUES (9154, 16566, NULL, 10220);
INSERT INTO 'dancesrecordingsmap' VALUES (9156, 18409, NULL, 10216);
INSERT INTO 'dancesrecordingsmap' VALUES (9158, 17121, NULL, 10218);
INSERT INTO 'dancesrecordingsmap' VALUES (9123, 8978, NULL, 10187);
INSERT INTO 'dancesrecordingsmap' VALUES (9125, 17559, NULL, 10189);
INSERT INTO 'dancesrecordingsmap' VALUES (9121, 17569, NULL, 10201);
INSERT INTO 'dancesrecordingsmap' VALUES (7011, 10007, NULL, 7215);
INSERT INTO 'dancesrecordingsmap' VALUES (6877, 13463, NULL, 7032);
INSERT INTO 'dancesrecordingsmap' VALUES (6960, 963, NULL, 7162);
INSERT INTO 'dancesrecordingsmap' VALUES (9232, 19140, NULL, 10243);
INSERT INTO 'dancesrecordingsmap' VALUES (6872, 13458, NULL, 7027);
INSERT INTO 'dancesrecordingsmap' VALUES (6925, 13497, NULL, 7082);
INSERT INTO 'dancesrecordingsmap' VALUES (6916, 3549, NULL, 7071);
INSERT INTO 'dancesrecordingsmap' VALUES (6860, 1729, NULL, 7015);
INSERT INTO 'dancesrecordingsmap' VALUES (6817, 13428, NULL, 6972);
INSERT INTO 'dancesrecordingsmap' VALUES (5105, 9632, NULL, 5717);
INSERT INTO 'dancesrecordingsmap' VALUES (6930, 13502, NULL, 7087);
INSERT INTO 'dancesrecordingsmap' VALUES (6907, 9207, NULL, 7062);
INSERT INTO 'dancesrecordingsmap' VALUES (6822, 13430, NULL, 6977);
INSERT INTO 'dancesrecordingsmap' VALUES (9233, 19137, NULL, 10240);
INSERT INTO 'dancesrecordingsmap' VALUES (6998, 7239, NULL, 7202);
INSERT INTO 'dancesrecordingsmap' VALUES (6999, 10463, NULL, 7203);
INSERT INTO 'dancesrecordingsmap' VALUES (7000, 10774, NULL, 7204);
INSERT INTO 'dancesrecordingsmap' VALUES (7001, 9084, NULL, 7205);
INSERT INTO 'dancesrecordingsmap' VALUES (7002, 6484, NULL, 7206);
INSERT INTO 'dancesrecordingsmap' VALUES (7003, 9083, NULL, 7207);
INSERT INTO 'dancesrecordingsmap' VALUES (7005, 1232, NULL, 7209);
INSERT INTO 'dancesrecordingsmap' VALUES (7006, 1128, NULL, 7210);
INSERT INTO 'dancesrecordingsmap' VALUES (7007, 695, NULL, 7211);
INSERT INTO 'dancesrecordingsmap' VALUES (7008, 1223, NULL, 7212);
INSERT INTO 'dancesrecordingsmap' VALUES (7010, 10773, NULL, 7214);
INSERT INTO 'dancesrecordingsmap' VALUES (7012, 13511, NULL, 7216);
INSERT INTO 'dancesrecordingsmap' VALUES (7013, 549, NULL, 7217);
INSERT INTO 'dancesrecordingsmap' VALUES (7014, 3834, NULL, 7218);
INSERT INTO 'dancesrecordingsmap' VALUES (7015, 1881, NULL, 7219);
INSERT INTO 'dancesrecordingsmap' VALUES (7016, 3888, NULL, 7221);
INSERT INTO 'dancesrecordingsmap' VALUES (7017, 7546, NULL, 7222);
INSERT INTO 'dancesrecordingsmap' VALUES (7019, 4431, NULL, 7225);
INSERT INTO 'dancesrecordingsmap' VALUES (6909, 9470, NULL, 7064);
INSERT INTO 'dancesrecordingsmap' VALUES (6968, 769, NULL, 7170);
INSERT INTO 'dancesrecordingsmap' VALUES (6856, 549, NULL, 7011);
INSERT INTO 'dancesrecordingsmap' VALUES (6855, 1647, NULL, 7010);
INSERT INTO 'dancesrecordingsmap' VALUES (6851, 4858, NULL, 7006);
INSERT INTO 'dancesrecordingsmap' VALUES (6834, 13437, NULL, 6989);
INSERT INTO 'dancesrecordingsmap' VALUES (6958, 5308, NULL, 7160);
INSERT INTO 'dancesrecordingsmap' VALUES (6962, 2494, NULL, 7164);
INSERT INTO 'dancesrecordingsmap' VALUES (6963, 3418, NULL, 7165);
INSERT INTO 'dancesrecordingsmap' VALUES (6964, 3436, NULL, 7166);
INSERT INTO 'dancesrecordingsmap' VALUES (6966, 10535, NULL, 7168);
INSERT INTO 'dancesrecordingsmap' VALUES (6967, 1176, NULL, 7169);
INSERT INTO 'dancesrecordingsmap' VALUES (6969, 3281, NULL, 7171);
INSERT INTO 'dancesrecordingsmap' VALUES (6965, 12454, NULL, 7167);
INSERT INTO 'dancesrecordingsmap' VALUES (9235, 9944, NULL, 843);
INSERT INTO 'dancesrecordingsmap' VALUES (8251, 541, NULL, 9286);
INSERT INTO 'dancesrecordingsmap' VALUES (9237, 8211, NULL, 2444);
INSERT INTO 'dancesrecordingsmap' VALUES (6853, 2125, NULL, 7008);
INSERT INTO 'dancesrecordingsmap' VALUES (6876, 13462, NULL, 7031);
INSERT INTO 'dancesrecordingsmap' VALUES (6914, 13488, 455, 7069);
INSERT INTO 'dancesrecordingsmap' VALUES (7020, 7542, NULL, 7227);
INSERT INTO 'dancesrecordingsmap' VALUES (7021, 2428, NULL, 7228);
INSERT INTO 'dancesrecordingsmap' VALUES (7024, 6152, NULL, 7235);
INSERT INTO 'dancesrecordingsmap' VALUES (7025, 905, NULL, 7237);
INSERT INTO 'dancesrecordingsmap' VALUES (7026, 2979, NULL, 7239);
INSERT INTO 'dancesrecordingsmap' VALUES (7027, 7243, NULL, 7241);
INSERT INTO 'dancesrecordingsmap' VALUES (7029, 12735, NULL, 7244);
INSERT INTO 'dancesrecordingsmap' VALUES (7030, 549, NULL, 7248);
INSERT INTO 'dancesrecordingsmap' VALUES (7031, 5330, NULL, 7250);
INSERT INTO 'dancesrecordingsmap' VALUES (7032, 615, NULL, 7252);
INSERT INTO 'dancesrecordingsmap' VALUES (7033, 2267, NULL, 7254);
INSERT INTO 'dancesrecordingsmap' VALUES (7034, 1210, NULL, 7255);
INSERT INTO 'dancesrecordingsmap' VALUES (7035, 8644, NULL, 7256);
INSERT INTO 'dancesrecordingsmap' VALUES (7036, 13512, NULL, 7257);
INSERT INTO 'dancesrecordingsmap' VALUES (7037, 1838, NULL, 7258);
INSERT INTO 'dancesrecordingsmap' VALUES (7038, 5621, NULL, 7259);
INSERT INTO 'dancesrecordingsmap' VALUES (7039, 7553, NULL, 7260);
INSERT INTO 'dancesrecordingsmap' VALUES (7040, 13513, NULL, 7261);
INSERT INTO 'dancesrecordingsmap' VALUES (7041, 13514, NULL, 7262);
INSERT INTO 'dancesrecordingsmap' VALUES (7042, 13515, NULL, 7263);
INSERT INTO 'dancesrecordingsmap' VALUES (7043, 5755, NULL, 7264);
INSERT INTO 'dancesrecordingsmap' VALUES (7044, 1786, NULL, 7265);
INSERT INTO 'dancesrecordingsmap' VALUES (7045, 13516, NULL, 7266);
INSERT INTO 'dancesrecordingsmap' VALUES (7046, 11546, NULL, 7267);
INSERT INTO 'dancesrecordingsmap' VALUES (7047, 3786, NULL, 7268);
INSERT INTO 'dancesrecordingsmap' VALUES (7048, 3172, NULL, 7269);
INSERT INTO 'dancesrecordingsmap' VALUES (7049, 658, NULL, 7270);
INSERT INTO 'dancesrecordingsmap' VALUES (7050, 2979, NULL, 7271);
INSERT INTO 'dancesrecordingsmap' VALUES (7051, 1405, NULL, 7272);
INSERT INTO 'dancesrecordingsmap' VALUES (7053, 3057, NULL, 7274);
INSERT INTO 'dancesrecordingsmap' VALUES (7055, 3726, NULL, 7276);
INSERT INTO 'dancesrecordingsmap' VALUES (7056, 6010, NULL, 7277);
INSERT INTO 'dancesrecordingsmap' VALUES (7057, 1223, NULL, 7278);
INSERT INTO 'dancesrecordingsmap' VALUES (7058, 2349, NULL, 7279);
INSERT INTO 'dancesrecordingsmap' VALUES (7059, 549, NULL, 7280);
INSERT INTO 'dancesrecordingsmap' VALUES (7060, 4359, NULL, 7281);
INSERT INTO 'dancesrecordingsmap' VALUES (7061, 159, NULL, 7282);
INSERT INTO 'dancesrecordingsmap' VALUES (7062, 7282, NULL, 7283);
INSERT INTO 'dancesrecordingsmap' VALUES (7063, 5330, NULL, 7284);
INSERT INTO 'dancesrecordingsmap' VALUES (7064, 1244, NULL, 7285);
INSERT INTO 'dancesrecordingsmap' VALUES (7065, 2604, NULL, 7286);
INSERT INTO 'dancesrecordingsmap' VALUES (7066, 4890, NULL, 7287);
INSERT INTO 'dancesrecordingsmap' VALUES (7067, 11189, NULL, 7288);
INSERT INTO 'dancesrecordingsmap' VALUES (7068, 9107, NULL, 7289);
INSERT INTO 'dancesrecordingsmap' VALUES (7069, 584, NULL, 7290);
INSERT INTO 'dancesrecordingsmap' VALUES (7070, 6373, NULL, 7291);
INSERT INTO 'dancesrecordingsmap' VALUES (7071, 4491, NULL, 7292);
INSERT INTO 'dancesrecordingsmap' VALUES (7072, 723, NULL, 7293);
INSERT INTO 'dancesrecordingsmap' VALUES (7073, 8835, NULL, 7324);
INSERT INTO 'dancesrecordingsmap' VALUES (7074, 11945, NULL, 7325);
INSERT INTO 'dancesrecordingsmap' VALUES (7075, 8832, NULL, 7326);
INSERT INTO 'dancesrecordingsmap' VALUES (7076, 13517, NULL, 7327);
INSERT INTO 'dancesrecordingsmap' VALUES (7077, 8839, NULL, 7328);
INSERT INTO 'dancesrecordingsmap' VALUES (7078, 13518, NULL, 7329);
INSERT INTO 'dancesrecordingsmap' VALUES (7079, 14204, NULL, 7330);
INSERT INTO 'dancesrecordingsmap' VALUES (7080, 13261, NULL, 7331);
INSERT INTO 'dancesrecordingsmap' VALUES (7081, 8833, NULL, 7332);
INSERT INTO 'dancesrecordingsmap' VALUES (7082, 11919, NULL, 7333);
INSERT INTO 'dancesrecordingsmap' VALUES (7083, 13262, NULL, 7334);
INSERT INTO 'dancesrecordingsmap' VALUES (7084, 13267, NULL, 7335);
INSERT INTO 'dancesrecordingsmap' VALUES (7085, 13521, NULL, 7336);
INSERT INTO 'dancesrecordingsmap' VALUES (7086, 13522, NULL, 7337);
INSERT INTO 'dancesrecordingsmap' VALUES (7088, 7243, NULL, 7339);
INSERT INTO 'dancesrecordingsmap' VALUES (7089, 13524, NULL, 7340);
INSERT INTO 'dancesrecordingsmap' VALUES (7090, 13525, NULL, 7341);
INSERT INTO 'dancesrecordingsmap' VALUES (7091, 13526, NULL, 7342);
INSERT INTO 'dancesrecordingsmap' VALUES (7092, 13527, NULL, 7343);
INSERT INTO 'dancesrecordingsmap' VALUES (7093, 11512, NULL, 7344);
INSERT INTO 'dancesrecordingsmap' VALUES (7094, 13528, NULL, 7345);
INSERT INTO 'dancesrecordingsmap' VALUES (7095, 13529, NULL, 7346);
INSERT INTO 'dancesrecordingsmap' VALUES (7054, 1931, NULL, 7275);
INSERT INTO 'dancesrecordingsmap' VALUES (9186, 14458, NULL, 8916);
INSERT INTO 'dancesrecordingsmap' VALUES (9179, 14449, NULL, 8907);
INSERT INTO 'dancesrecordingsmap' VALUES (9177, 14447, NULL, 8905);
INSERT INTO 'dancesrecordingsmap' VALUES (6919, 13849, NULL, 7074);
INSERT INTO 'dancesrecordingsmap' VALUES (9149, 16838, NULL, 10225);
INSERT INTO 'dancesrecordingsmap' VALUES (7018, 4641, NULL, 7223);
INSERT INTO 'dancesrecordingsmap' VALUES (6838, 13440, NULL, 6993);
INSERT INTO 'dancesrecordingsmap' VALUES (7096, 13530, NULL, 7347);
INSERT INTO 'dancesrecordingsmap' VALUES (7097, 13531, NULL, 7348);
INSERT INTO 'dancesrecordingsmap' VALUES (7098, 13532, NULL, 7349);
INSERT INTO 'dancesrecordingsmap' VALUES (7099, 13533, NULL, 7350);
INSERT INTO 'dancesrecordingsmap' VALUES (7100, 13534, NULL, 7351);
INSERT INTO 'dancesrecordingsmap' VALUES (7101, 13535, NULL, 7352);
INSERT INTO 'dancesrecordingsmap' VALUES (7102, 13536, NULL, 7353);
INSERT INTO 'dancesrecordingsmap' VALUES (7103, 13537, NULL, 7354);
INSERT INTO 'dancesrecordingsmap' VALUES (7104, 13538, NULL, 7355);
INSERT INTO 'dancesrecordingsmap' VALUES (7105, 3528, NULL, 7360);
INSERT INTO 'dancesrecordingsmap' VALUES (7106, 8142, NULL, 7361);
INSERT INTO 'dancesrecordingsmap' VALUES (7107, 4808, NULL, 7373);
INSERT INTO 'dancesrecordingsmap' VALUES (7108, 13539, NULL, 7374);
INSERT INTO 'dancesrecordingsmap' VALUES (7110, 12090, NULL, 7376);
INSERT INTO 'dancesrecordingsmap' VALUES (7111, 2716, NULL, 7377);
INSERT INTO 'dancesrecordingsmap' VALUES (7112, 10433, NULL, 7378);
INSERT INTO 'dancesrecordingsmap' VALUES (7113, 10433, NULL, 7379);
INSERT INTO 'dancesrecordingsmap' VALUES (7114, 1087, NULL, 7380);
INSERT INTO 'dancesrecordingsmap' VALUES (7115, 3119, NULL, 7381);
INSERT INTO 'dancesrecordingsmap' VALUES (7109, 12093, NULL, 7375);
INSERT INTO 'dancesrecordingsmap' VALUES (7117, 2110, NULL, 7383);
INSERT INTO 'dancesrecordingsmap' VALUES (7118, 13541, NULL, 7384);
INSERT INTO 'dancesrecordingsmap' VALUES (7119, 8749, NULL, 7385);
INSERT INTO 'dancesrecordingsmap' VALUES (7122, 7061, NULL, 7388);
INSERT INTO 'dancesrecordingsmap' VALUES (7123, 2498, NULL, 7389);
INSERT INTO 'dancesrecordingsmap' VALUES (7124, 1782, NULL, 7390);
INSERT INTO 'dancesrecordingsmap' VALUES (7125, 11800, NULL, 7391);
INSERT INTO 'dancesrecordingsmap' VALUES (7126, 5802, NULL, 7392);
INSERT INTO 'dancesrecordingsmap' VALUES (7127, 1348, NULL, 7393);
INSERT INTO 'dancesrecordingsmap' VALUES (7128, 6763, NULL, 7394);
INSERT INTO 'dancesrecordingsmap' VALUES (7129, 3802, NULL, 7395);
INSERT INTO 'dancesrecordingsmap' VALUES (7130, 7182, NULL, 7396);
INSERT INTO 'dancesrecordingsmap' VALUES (7131, 11376, NULL, 7397);
INSERT INTO 'dancesrecordingsmap' VALUES (7132, 11801, NULL, 7398);
INSERT INTO 'dancesrecordingsmap' VALUES (7133, 2350, NULL, 7399);
INSERT INTO 'dancesrecordingsmap' VALUES (7134, 3129, NULL, 7400);
INSERT INTO 'dancesrecordingsmap' VALUES (7023, 223, NULL, 7233);
INSERT INTO 'dancesrecordingsmap' VALUES (7136, 3594, NULL, 7402);
INSERT INTO 'dancesrecordingsmap' VALUES (7137, 4227, NULL, 7403);
INSERT INTO 'dancesrecordingsmap' VALUES (7138, 4015, NULL, 7404);
INSERT INTO 'dancesrecordingsmap' VALUES (7139, 4928, NULL, 7405);
INSERT INTO 'dancesrecordingsmap' VALUES (7140, 549, NULL, 7406);
INSERT INTO 'dancesrecordingsmap' VALUES (7141, 7546, NULL, 7407);
INSERT INTO 'dancesrecordingsmap' VALUES (7142, 8152, NULL, 7412);
INSERT INTO 'dancesrecordingsmap' VALUES (7143, 9759, NULL, 7417);
INSERT INTO 'dancesrecordingsmap' VALUES (7144, 5296, NULL, 7418);
INSERT INTO 'dancesrecordingsmap' VALUES (7145, 1562, NULL, 7423);
INSERT INTO 'dancesrecordingsmap' VALUES (7147, 7553, NULL, 7425);
INSERT INTO 'dancesrecordingsmap' VALUES (7148, 7546, NULL, 7426);
INSERT INTO 'dancesrecordingsmap' VALUES (7149, 10289, NULL, 7427);
INSERT INTO 'dancesrecordingsmap' VALUES (7150, 3561, NULL, 7428);
INSERT INTO 'dancesrecordingsmap' VALUES (7151, 6359, NULL, 7429);
INSERT INTO 'dancesrecordingsmap' VALUES (7153, 5964, NULL, 7431);
INSERT INTO 'dancesrecordingsmap' VALUES (7154, 7546, NULL, 7432);
INSERT INTO 'dancesrecordingsmap' VALUES (7155, 4562, NULL, 7433);
INSERT INTO 'dancesrecordingsmap' VALUES (7156, 3152, NULL, 7434);
INSERT INTO 'dancesrecordingsmap' VALUES (7157, 6915, NULL, 7435);
INSERT INTO 'dancesrecordingsmap' VALUES (7158, 1834, NULL, 7436);
INSERT INTO 'dancesrecordingsmap' VALUES (6933, 13505, NULL, 7090);
INSERT INTO 'dancesrecordingsmap' VALUES (6959, 7147, NULL, 7161);
INSERT INTO 'dancesrecordingsmap' VALUES (6997, 4236, NULL, 7201);
INSERT INTO 'dancesrecordingsmap' VALUES (7152, 8154, NULL, 7430);
INSERT INTO 'dancesrecordingsmap' VALUES (7022, 3615, NULL, 7232);
INSERT INTO 'dancesrecordingsmap' VALUES (7052, 5637, NULL, 7273);
INSERT INTO 'dancesrecordingsmap' VALUES (6970, 9009, NULL, 7172);
INSERT INTO 'dancesrecordingsmap' VALUES (7159, 7554, NULL, 7437);
INSERT INTO 'dancesrecordingsmap' VALUES (7160, 2498, NULL, 7438);
INSERT INTO 'dancesrecordingsmap' VALUES (7161, 2745, NULL, 7439);
INSERT INTO 'dancesrecordingsmap' VALUES (7162, 3834, NULL, 7440);
INSERT INTO 'dancesrecordingsmap' VALUES (7163, 3672, NULL, 7442);
INSERT INTO 'dancesrecordingsmap' VALUES (7165, 5239, NULL, 7444);
INSERT INTO 'dancesrecordingsmap' VALUES (7166, 5525, NULL, 7445);
INSERT INTO 'dancesrecordingsmap' VALUES (7168, 4032, NULL, 7451);
INSERT INTO 'dancesrecordingsmap' VALUES (7169, 5374, NULL, 7452);
INSERT INTO 'dancesrecordingsmap' VALUES (7171, 3281, NULL, 7455);
INSERT INTO 'dancesrecordingsmap' VALUES (7172, 7546, NULL, 7456);
INSERT INTO 'dancesrecordingsmap' VALUES (7173, 154, NULL, 7457);
INSERT INTO 'dancesrecordingsmap' VALUES (7174, 6349, NULL, 7458);
INSERT INTO 'dancesrecordingsmap' VALUES (7175, 3580, NULL, 7459);
INSERT INTO 'dancesrecordingsmap' VALUES (7176, 7546, NULL, 7460);
INSERT INTO 'dancesrecordingsmap' VALUES (7177, 972, NULL, 7461);
INSERT INTO 'dancesrecordingsmap' VALUES (7178, 1478, NULL, 7462);
INSERT INTO 'dancesrecordingsmap' VALUES (7179, 899, NULL, 7463);
INSERT INTO 'dancesrecordingsmap' VALUES (7180, 7219, NULL, 7464);
INSERT INTO 'dancesrecordingsmap' VALUES (7181, 5963, NULL, 7465);
INSERT INTO 'dancesrecordingsmap' VALUES (7182, 5591, NULL, 7466);
INSERT INTO 'dancesrecordingsmap' VALUES (7183, 6599, NULL, 7467);
INSERT INTO 'dancesrecordingsmap' VALUES (7184, 6634, NULL, 7468);
INSERT INTO 'dancesrecordingsmap' VALUES (7185, 6748, NULL, 7472);
INSERT INTO 'dancesrecordingsmap' VALUES (7186, 8148, NULL, 7473);
INSERT INTO 'dancesrecordingsmap' VALUES (7187, 8142, NULL, 7474);
INSERT INTO 'dancesrecordingsmap' VALUES (7188, 522, NULL, 7475);
INSERT INTO 'dancesrecordingsmap' VALUES (7189, 1215, NULL, 7476);
INSERT INTO 'dancesrecordingsmap' VALUES (7190, 3730, NULL, 7477);
INSERT INTO 'dancesrecordingsmap' VALUES (7191, 4633, NULL, 7478);
INSERT INTO 'dancesrecordingsmap' VALUES (7192, 6701, NULL, 7479);
INSERT INTO 'dancesrecordingsmap' VALUES (7193, 13517, NULL, 7480);
INSERT INTO 'dancesrecordingsmap' VALUES (7194, 1758, NULL, 7481);
INSERT INTO 'dancesrecordingsmap' VALUES (7195, 11516, NULL, 7482);
INSERT INTO 'dancesrecordingsmap' VALUES (7196, 353, NULL, 7483);
INSERT INTO 'dancesrecordingsmap' VALUES (7197, 4662, NULL, 7484);
INSERT INTO 'dancesrecordingsmap' VALUES (7198, 13545, NULL, 7485);
INSERT INTO 'dancesrecordingsmap' VALUES (7199, 9111, NULL, 7486);
INSERT INTO 'dancesrecordingsmap' VALUES (7200, 11943, NULL, 7487);
INSERT INTO 'dancesrecordingsmap' VALUES (7202, 3659, NULL, 7489);
INSERT INTO 'dancesrecordingsmap' VALUES (7203, 462, NULL, 7490);
INSERT INTO 'dancesrecordingsmap' VALUES (7204, 11945, NULL, 7492);
INSERT INTO 'dancesrecordingsmap' VALUES (7205, 2242, NULL, 7493);
INSERT INTO 'dancesrecordingsmap' VALUES (7206, 3172, NULL, 7494);
INSERT INTO 'dancesrecordingsmap' VALUES (7170, 4928, NULL, 7453);
INSERT INTO 'dancesrecordingsmap' VALUES (7135, 15140, NULL, 7401);
INSERT INTO 'dancesrecordingsmap' VALUES (7087, 13523, NULL, 7338);
INSERT INTO 'dancesrecordingsmap' VALUES (7146, 4646, NULL, 7424);
INSERT INTO 'dancesrecordingsmap' VALUES (7207, 1773, NULL, 7495);
INSERT INTO 'dancesrecordingsmap' VALUES (7208, 4032, NULL, 7496);
INSERT INTO 'dancesrecordingsmap' VALUES (7209, 6523, NULL, 7497);
INSERT INTO 'dancesrecordingsmap' VALUES (7210, 5591, NULL, 7498);
INSERT INTO 'dancesrecordingsmap' VALUES (7211, 4755, NULL, 7499);
INSERT INTO 'dancesrecordingsmap' VALUES (7212, 5525, NULL, 7500);
INSERT INTO 'dancesrecordingsmap' VALUES (7213, 5963, NULL, 7501);
INSERT INTO 'dancesrecordingsmap' VALUES (7214, 1582, NULL, 7502);
INSERT INTO 'dancesrecordingsmap' VALUES (7215, 6349, NULL, 7503);
INSERT INTO 'dancesrecordingsmap' VALUES (7216, 2644, NULL, 7504);
INSERT INTO 'dancesrecordingsmap' VALUES (7217, 4646, NULL, 7505);
INSERT INTO 'dancesrecordingsmap' VALUES (7218, 5964, NULL, 7506);
INSERT INTO 'dancesrecordingsmap' VALUES (7219, 754, NULL, 7507);
INSERT INTO 'dancesrecordingsmap' VALUES (7220, 6748, NULL, 7508);
INSERT INTO 'dancesrecordingsmap' VALUES (7221, 4068, NULL, 7509);
INSERT INTO 'dancesrecordingsmap' VALUES (7222, 5239, NULL, 7510);
INSERT INTO 'dancesrecordingsmap' VALUES (7223, 3635, NULL, 7523);
INSERT INTO 'dancesrecordingsmap' VALUES (7224, 1624, NULL, 7524);
INSERT INTO 'dancesrecordingsmap' VALUES (7225, 2250, NULL, 7525);
INSERT INTO 'dancesrecordingsmap' VALUES (7226, 5239, NULL, 7527);
INSERT INTO 'dancesrecordingsmap' VALUES (7228, 3562, NULL, 7529);
INSERT INTO 'dancesrecordingsmap' VALUES (7229, 3834, NULL, 7531);
INSERT INTO 'dancesrecordingsmap' VALUES (7231, 7111, NULL, 7535);
INSERT INTO 'dancesrecordingsmap' VALUES (7233, 1931, NULL, 7539);
INSERT INTO 'dancesrecordingsmap' VALUES (7234, 1792, NULL, 7540);
INSERT INTO 'dancesrecordingsmap' VALUES (7235, 2498, NULL, 7544);
INSERT INTO 'dancesrecordingsmap' VALUES (7236, 5239, NULL, 7546);
INSERT INTO 'dancesrecordingsmap' VALUES (7237, 8142, NULL, 7551);
INSERT INTO 'dancesrecordingsmap' VALUES (7238, 658, NULL, 7552);
INSERT INTO 'dancesrecordingsmap' VALUES (7239, 980, NULL, 7553);
INSERT INTO 'dancesrecordingsmap' VALUES (7240, 2804, NULL, 7554);
INSERT INTO 'dancesrecordingsmap' VALUES (7241, 1931, NULL, 7556);
INSERT INTO 'dancesrecordingsmap' VALUES (7242, 11817, NULL, 7558);
INSERT INTO 'dancesrecordingsmap' VALUES (7243, 920, NULL, 7562);
INSERT INTO 'dancesrecordingsmap' VALUES (7244, 1866, NULL, 7567);
INSERT INTO 'dancesrecordingsmap' VALUES (7246, 8559, NULL, 7572);
INSERT INTO 'dancesrecordingsmap' VALUES (7247, 13554, NULL, 7573);
INSERT INTO 'dancesrecordingsmap' VALUES (7250, 13557, NULL, 7576);
INSERT INTO 'dancesrecordingsmap' VALUES (7378, 1296, NULL, 7779);
INSERT INTO 'dancesrecordingsmap' VALUES (7255, 14039, NULL, 7581);
INSERT INTO 'dancesrecordingsmap' VALUES (7257, 3743, NULL, 7587);
INSERT INTO 'dancesrecordingsmap' VALUES (7258, 4942, NULL, 7590);
INSERT INTO 'dancesrecordingsmap' VALUES (7259, 549, NULL, 7596);
INSERT INTO 'dancesrecordingsmap' VALUES (7260, 7546, NULL, 7606);
INSERT INTO 'dancesrecordingsmap' VALUES (7261, 8146, NULL, 7607);
INSERT INTO 'dancesrecordingsmap' VALUES (7262, 8154, NULL, 7608);
INSERT INTO 'dancesrecordingsmap' VALUES (7263, 7552, NULL, 7610);
INSERT INTO 'dancesrecordingsmap' VALUES (7264, 7553, NULL, 7611);
INSERT INTO 'dancesrecordingsmap' VALUES (7265, 7554, NULL, 7612);
INSERT INTO 'dancesrecordingsmap' VALUES (7266, 8143, NULL, 7613);
INSERT INTO 'dancesrecordingsmap' VALUES (7245, 13553, NULL, 7571);
INSERT INTO 'dancesrecordingsmap' VALUES (7268, 7548, NULL, 7615);
INSERT INTO 'dancesrecordingsmap' VALUES (7269, 8159, NULL, 7616);
INSERT INTO 'dancesrecordingsmap' VALUES (7270, 8162, NULL, 7617);
INSERT INTO 'dancesrecordingsmap' VALUES (7271, 8161, NULL, 7618);
INSERT INTO 'dancesrecordingsmap' VALUES (7272, 1562, NULL, 7620);
INSERT INTO 'dancesrecordingsmap' VALUES (7273, 6359, NULL, 7621);
INSERT INTO 'dancesrecordingsmap' VALUES (7274, 154, NULL, 7622);
INSERT INTO 'dancesrecordingsmap' VALUES (7275, 8154, NULL, 7623);
INSERT INTO 'dancesrecordingsmap' VALUES (7276, 2250, NULL, 7624);
INSERT INTO 'dancesrecordingsmap' VALUES (7277, 3562, NULL, 7625);
INSERT INTO 'dancesrecordingsmap' VALUES (7278, 1792, NULL, 7626);
INSERT INTO 'dancesrecordingsmap' VALUES (7279, 7548, NULL, 7627);
INSERT INTO 'dancesrecordingsmap' VALUES (7280, 1210, NULL, 7628);
INSERT INTO 'dancesrecordingsmap' VALUES (7281, 5239, NULL, 7629);
INSERT INTO 'dancesrecordingsmap' VALUES (7282, 4014, NULL, 7630);
INSERT INTO 'dancesrecordingsmap' VALUES (7283, 2846, NULL, 7631);
INSERT INTO 'dancesrecordingsmap' VALUES (7284, 13730, NULL, 7632);
INSERT INTO 'dancesrecordingsmap' VALUES (7285, 13731, NULL, 7633);
INSERT INTO 'dancesrecordingsmap' VALUES (7286, 12108, NULL, 7634);
INSERT INTO 'dancesrecordingsmap' VALUES (7287, 13567, NULL, 7635);
INSERT INTO 'dancesrecordingsmap' VALUES (7288, 13568, NULL, 7636);
INSERT INTO 'dancesrecordingsmap' VALUES (7289, 13569, NULL, 7637);
INSERT INTO 'dancesrecordingsmap' VALUES (7290, 13570, NULL, 7638);
INSERT INTO 'dancesrecordingsmap' VALUES (7291, 13571, NULL, 7639);
INSERT INTO 'dancesrecordingsmap' VALUES (7292, 13572, NULL, 7640);
INSERT INTO 'dancesrecordingsmap' VALUES (7293, 13573, NULL, 7641);
INSERT INTO 'dancesrecordingsmap' VALUES (7294, 6152, NULL, 7645);
INSERT INTO 'dancesrecordingsmap' VALUES (7295, 6471, NULL, 7647);
INSERT INTO 'dancesrecordingsmap' VALUES (7296, 5596, NULL, 7651);
INSERT INTO 'dancesrecordingsmap' VALUES (7297, 13574, NULL, 7654);
INSERT INTO 'dancesrecordingsmap' VALUES (7298, 7335, NULL, 7655);
INSERT INTO 'dancesrecordingsmap' VALUES (7299, 12071, NULL, 7658);
INSERT INTO 'dancesrecordingsmap' VALUES (7300, 7548, NULL, 7659);
INSERT INTO 'dancesrecordingsmap' VALUES (7301, 2260, NULL, 7660);
INSERT INTO 'dancesrecordingsmap' VALUES (7302, 2745, NULL, 7662);
INSERT INTO 'dancesrecordingsmap' VALUES (7303, 3701, NULL, 7663);
INSERT INTO 'dancesrecordingsmap' VALUES (7304, 7554, NULL, 7666);
INSERT INTO 'dancesrecordingsmap' VALUES (7305, 1348, NULL, 7667);
INSERT INTO 'dancesrecordingsmap' VALUES (7306, 8851, NULL, 7668);
INSERT INTO 'dancesrecordingsmap' VALUES (7307, 3444, NULL, 7669);
INSERT INTO 'dancesrecordingsmap' VALUES (7308, 6407, NULL, 7671);
INSERT INTO 'dancesrecordingsmap' VALUES (7309, 5658, NULL, 7674);
INSERT INTO 'dancesrecordingsmap' VALUES (7310, 313, NULL, 7675);
INSERT INTO 'dancesrecordingsmap' VALUES (7311, 1927, NULL, 7676);
INSERT INTO 'dancesrecordingsmap' VALUES (7312, 654, NULL, 7678);
INSERT INTO 'dancesrecordingsmap' VALUES (7313, 3528, NULL, 7679);
INSERT INTO 'dancesrecordingsmap' VALUES (7314, 4032, NULL, 7680);
INSERT INTO 'dancesrecordingsmap' VALUES (7315, 13575, NULL, 7681);
INSERT INTO 'dancesrecordingsmap' VALUES (7316, 13576, NULL, 7682);
INSERT INTO 'dancesrecordingsmap' VALUES (7317, 4102, NULL, 7683);
INSERT INTO 'dancesrecordingsmap' VALUES (7318, 13577, NULL, 7687);
INSERT INTO 'dancesrecordingsmap' VALUES (7319, 4935, NULL, 7688);
INSERT INTO 'dancesrecordingsmap' VALUES (7320, 89, NULL, 7689);
INSERT INTO 'dancesrecordingsmap' VALUES (7321, 4558, NULL, 7690);
INSERT INTO 'dancesrecordingsmap' VALUES (7322, 3953, NULL, 7691);
INSERT INTO 'dancesrecordingsmap' VALUES (7324, 4765, NULL, 7693);
INSERT INTO 'dancesrecordingsmap' VALUES (7325, 5345, NULL, 7694);
INSERT INTO 'dancesrecordingsmap' VALUES (7326, 2349, NULL, 7695);
INSERT INTO 'dancesrecordingsmap' VALUES (7327, 6712, NULL, 7696);
INSERT INTO 'dancesrecordingsmap' VALUES (7328, 1777, NULL, 7697);
INSERT INTO 'dancesrecordingsmap' VALUES (7329, 3941, NULL, 7698);
INSERT INTO 'dancesrecordingsmap' VALUES (7330, 2593, NULL, 7699);
INSERT INTO 'dancesrecordingsmap' VALUES (7331, 877, NULL, 7700);
INSERT INTO 'dancesrecordingsmap' VALUES (7332, 4555, NULL, 7701);
INSERT INTO 'dancesrecordingsmap' VALUES (7333, 3528, NULL, 7702);
INSERT INTO 'dancesrecordingsmap' VALUES (7334, 985, NULL, 7705);
INSERT INTO 'dancesrecordingsmap' VALUES (7335, 5407, NULL, 7707);
INSERT INTO 'dancesrecordingsmap' VALUES (7336, 8956, NULL, 7709);
INSERT INTO 'dancesrecordingsmap' VALUES (7339, 1544, NULL, 7715);
INSERT INTO 'dancesrecordingsmap' VALUES (7340, 3057, NULL, 7718);
INSERT INTO 'dancesrecordingsmap' VALUES (7341, 683, NULL, 7720);
INSERT INTO 'dancesrecordingsmap' VALUES (7342, 985, NULL, 7723);
INSERT INTO 'dancesrecordingsmap' VALUES (7343, 5407, NULL, 7725);
INSERT INTO 'dancesrecordingsmap' VALUES (7344, 8956, NULL, 7727);
INSERT INTO 'dancesrecordingsmap' VALUES (7345, 9852, NULL, 7729);
INSERT INTO 'dancesrecordingsmap' VALUES (7347, 1544, NULL, 7733);
INSERT INTO 'dancesrecordingsmap' VALUES (7348, 3057, NULL, 7736);
INSERT INTO 'dancesrecordingsmap' VALUES (7349, 683, NULL, 7738);
INSERT INTO 'dancesrecordingsmap' VALUES (7350, 5641, NULL, 7739);
INSERT INTO 'dancesrecordingsmap' VALUES (7351, 4103, NULL, 7741);
INSERT INTO 'dancesrecordingsmap' VALUES (7167, 980, NULL, 7446);
INSERT INTO 'dancesrecordingsmap' VALUES (7256, 14040, NULL, 7582);
INSERT INTO 'dancesrecordingsmap' VALUES (7249, 13556, NULL, 7575);
INSERT INTO 'dancesrecordingsmap' VALUES (7164, 1931, NULL, 7443);
INSERT INTO 'dancesrecordingsmap' VALUES (7323, 594, NULL, 7692);
INSERT INTO 'dancesrecordingsmap' VALUES (7352, 5525, NULL, 7744);
INSERT INTO 'dancesrecordingsmap' VALUES (7353, 7546, NULL, 7748);
INSERT INTO 'dancesrecordingsmap' VALUES (7354, 3743, NULL, 7749);
INSERT INTO 'dancesrecordingsmap' VALUES (7355, 7553, NULL, 7751);
INSERT INTO 'dancesrecordingsmap' VALUES (7356, 2024, NULL, 7753);
INSERT INTO 'dancesrecordingsmap' VALUES (7357, 2389, NULL, 7755);
INSERT INTO 'dancesrecordingsmap' VALUES (7358, 7546, NULL, 7757);
INSERT INTO 'dancesrecordingsmap' VALUES (7359, 1210, NULL, 7758);
INSERT INTO 'dancesrecordingsmap' VALUES (7360, 5731, NULL, 7761);
INSERT INTO 'dancesrecordingsmap' VALUES (7363, 3775, NULL, 7764);
INSERT INTO 'dancesrecordingsmap' VALUES (7364, 5141, NULL, 7765);
INSERT INTO 'dancesrecordingsmap' VALUES (7365, 6585, NULL, 7766);
INSERT INTO 'dancesrecordingsmap' VALUES (7366, 610, NULL, 7767);
INSERT INTO 'dancesrecordingsmap' VALUES (7367, 5362, NULL, 7768);
INSERT INTO 'dancesrecordingsmap' VALUES (7369, 3046, NULL, 7770);
INSERT INTO 'dancesrecordingsmap' VALUES (7370, 4782, NULL, 7771);
INSERT INTO 'dancesrecordingsmap' VALUES (7371, 6130, NULL, 7772);
INSERT INTO 'dancesrecordingsmap' VALUES (7375, 7242, NULL, 7776);
INSERT INTO 'dancesrecordingsmap' VALUES (7376, 3623, NULL, 7777);
INSERT INTO 'dancesrecordingsmap' VALUES (7377, 4309, NULL, 7778);
INSERT INTO 'dancesrecordingsmap' VALUES (7379, 6477, NULL, 7780);
INSERT INTO 'dancesrecordingsmap' VALUES (7380, 1018, NULL, 7781);
INSERT INTO 'dancesrecordingsmap' VALUES (7381, 2745, NULL, 7782);
INSERT INTO 'dancesrecordingsmap' VALUES (7383, 754, NULL, 7784);
INSERT INTO 'dancesrecordingsmap' VALUES (7385, 13580, NULL, 7786);
INSERT INTO 'dancesrecordingsmap' VALUES (7386, 6711, NULL, 7787);
INSERT INTO 'dancesrecordingsmap' VALUES (7387, 3444, NULL, 7788);
INSERT INTO 'dancesrecordingsmap' VALUES (7388, 1017, NULL, 7789);
INSERT INTO 'dancesrecordingsmap' VALUES (7389, 1366, NULL, 7790);
INSERT INTO 'dancesrecordingsmap' VALUES (7390, 2436, NULL, 7791);
INSERT INTO 'dancesrecordingsmap' VALUES (7391, 4499, NULL, 7792);
INSERT INTO 'dancesrecordingsmap' VALUES (7392, 3986, NULL, 7793);
INSERT INTO 'dancesrecordingsmap' VALUES (7393, 654, NULL, 7794);
INSERT INTO 'dancesrecordingsmap' VALUES (7252, 13559, NULL, 7578);
INSERT INTO 'dancesrecordingsmap' VALUES (7248, 13555, NULL, 7574);
INSERT INTO 'dancesrecordingsmap' VALUES (7251, 13558, NULL, 7577);
INSERT INTO 'dancesrecordingsmap' VALUES (7373, 5497, NULL, 7774);
INSERT INTO 'dancesrecordingsmap' VALUES (7267, 1479, NULL, 7614);
INSERT INTO 'dancesrecordingsmap' VALUES (7254, 14038, NULL, 7580);
INSERT INTO 'dancesrecordingsmap' VALUES (7395, 5223, NULL, 7796);
INSERT INTO 'dancesrecordingsmap' VALUES (7396, 6800, NULL, 7797);
INSERT INTO 'dancesrecordingsmap' VALUES (7397, 1677, NULL, 7798);
INSERT INTO 'dancesrecordingsmap' VALUES (7398, 13581, NULL, 7799);
INSERT INTO 'dancesrecordingsmap' VALUES (7399, 13582, NULL, 7800);
INSERT INTO 'dancesrecordingsmap' VALUES (7400, 13583, NULL, 7801);
INSERT INTO 'dancesrecordingsmap' VALUES (7401, 13584, NULL, 7802);
INSERT INTO 'dancesrecordingsmap' VALUES (7402, 13585, NULL, 7803);
INSERT INTO 'dancesrecordingsmap' VALUES (7403, 10920, NULL, 7804);
INSERT INTO 'dancesrecordingsmap' VALUES (7404, 13149, NULL, 7805);
INSERT INTO 'dancesrecordingsmap' VALUES (7405, 10376, NULL, 7806);
INSERT INTO 'dancesrecordingsmap' VALUES (7406, 13586, NULL, 7807);
INSERT INTO 'dancesrecordingsmap' VALUES (7407, 12426, NULL, 7808);
INSERT INTO 'dancesrecordingsmap' VALUES (7408, 13587, NULL, 7809);
INSERT INTO 'dancesrecordingsmap' VALUES (7410, 13588, NULL, 7811);
INSERT INTO 'dancesrecordingsmap' VALUES (7411, 13589, NULL, 7812);
INSERT INTO 'dancesrecordingsmap' VALUES (7412, 13590, NULL, 7813);
INSERT INTO 'dancesrecordingsmap' VALUES (7413, 13591, NULL, 7814);
INSERT INTO 'dancesrecordingsmap' VALUES (7414, 1562, NULL, 7815);
INSERT INTO 'dancesrecordingsmap' VALUES (7415, 980, NULL, 7817);
INSERT INTO 'dancesrecordingsmap' VALUES (7416, 1501, NULL, 7818);
INSERT INTO 'dancesrecordingsmap' VALUES (7417, 4442, NULL, 7820);
INSERT INTO 'dancesrecordingsmap' VALUES (7419, 1348, NULL, 7823);
INSERT INTO 'dancesrecordingsmap' VALUES (7420, 7546, NULL, 7824);
INSERT INTO 'dancesrecordingsmap' VALUES (7421, 794, NULL, 7825);
INSERT INTO 'dancesrecordingsmap' VALUES (7423, 1582, NULL, 7832);
INSERT INTO 'dancesrecordingsmap' VALUES (7424, 4014, NULL, 7835);
INSERT INTO 'dancesrecordingsmap' VALUES (7425, 3152, NULL, 7837);
INSERT INTO 'dancesrecordingsmap' VALUES (7426, 4359, NULL, 7839);
INSERT INTO 'dancesrecordingsmap' VALUES (7427, 5207, NULL, 7840);
INSERT INTO 'dancesrecordingsmap' VALUES (7428, 3580, NULL, 7841);
INSERT INTO 'dancesrecordingsmap' VALUES (7429, 1562, NULL, 7843);
INSERT INTO 'dancesrecordingsmap' VALUES (7430, 2645, NULL, 7844);
INSERT INTO 'dancesrecordingsmap' VALUES (7431, 6349, NULL, 7849);
INSERT INTO 'dancesrecordingsmap' VALUES (7432, 1799, NULL, 7855);
INSERT INTO 'dancesrecordingsmap' VALUES (7433, 7546, NULL, 7857);
INSERT INTO 'dancesrecordingsmap' VALUES (7434, 5731, NULL, 7861);
INSERT INTO 'dancesrecordingsmap' VALUES (7435, 1478, NULL, 7863);
INSERT INTO 'dancesrecordingsmap' VALUES (7436, 3281, NULL, 7866);
INSERT INTO 'dancesrecordingsmap' VALUES (7437, 335, NULL, 7868);
INSERT INTO 'dancesrecordingsmap' VALUES (7438, 1210, NULL, 7869);
INSERT INTO 'dancesrecordingsmap' VALUES (7440, 3561, NULL, 7881);
INSERT INTO 'dancesrecordingsmap' VALUES (7441, 541, NULL, 7883);
INSERT INTO 'dancesrecordingsmap' VALUES (7442, 1829, NULL, 7895);
INSERT INTO 'dancesrecordingsmap' VALUES (7443, 2807, NULL, 7955);
INSERT INTO 'dancesrecordingsmap' VALUES (7444, 1792, NULL, 7956);
INSERT INTO 'dancesrecordingsmap' VALUES (7445, 2389, NULL, 7962);
INSERT INTO 'dancesrecordingsmap' VALUES (7446, 13592, NULL, 7965);
INSERT INTO 'dancesrecordingsmap' VALUES (7447, 4633, NULL, 7967);
INSERT INTO 'dancesrecordingsmap' VALUES (7448, 5525, NULL, 7968);
INSERT INTO 'dancesrecordingsmap' VALUES (7449, 2745, NULL, 7969);
INSERT INTO 'dancesrecordingsmap' VALUES (7450, 7553, NULL, 7970);
INSERT INTO 'dancesrecordingsmap' VALUES (7452, 1931, NULL, 7972);
INSERT INTO 'dancesrecordingsmap' VALUES (7453, 2317, NULL, 7973);
INSERT INTO 'dancesrecordingsmap' VALUES (7454, 8154, NULL, 7974);
INSERT INTO 'dancesrecordingsmap' VALUES (7455, 1562, NULL, 7975);
INSERT INTO 'dancesrecordingsmap' VALUES (7456, 8143, NULL, 7976);
INSERT INTO 'dancesrecordingsmap' VALUES (7457, 1782, NULL, 7977);
INSERT INTO 'dancesrecordingsmap' VALUES (7458, 2498, NULL, 7978);
INSERT INTO 'dancesrecordingsmap' VALUES (7459, 1792, NULL, 7979);
INSERT INTO 'dancesrecordingsmap' VALUES (7460, 5330, NULL, 7980);
INSERT INTO 'dancesrecordingsmap' VALUES (7461, 4102, NULL, 7981);
INSERT INTO 'dancesrecordingsmap' VALUES (7462, 13270, NULL, 7982);
INSERT INTO 'dancesrecordingsmap' VALUES (7463, 9403, NULL, 7983);
INSERT INTO 'dancesrecordingsmap' VALUES (7464, 4931, NULL, 7984);
INSERT INTO 'dancesrecordingsmap' VALUES (7465, 5296, NULL, 7985);
INSERT INTO 'dancesrecordingsmap' VALUES (7466, 5260, NULL, 7986);
INSERT INTO 'dancesrecordingsmap' VALUES (7468, 1787, NULL, 7988);
INSERT INTO 'dancesrecordingsmap' VALUES (7469, 13593, NULL, 7989);
INSERT INTO 'dancesrecordingsmap' VALUES (7470, 250, NULL, 7990);
INSERT INTO 'dancesrecordingsmap' VALUES (7471, 5915, NULL, 7991);
INSERT INTO 'dancesrecordingsmap' VALUES (7451, 8162, NULL, 7971);
INSERT INTO 'dancesrecordingsmap' VALUES (7338, 10428, NULL, 7713);
INSERT INTO 'dancesrecordingsmap' VALUES (7346, 10428, NULL, 7731);
INSERT INTO 'dancesrecordingsmap' VALUES (7368, 3940, NULL, 7769);
INSERT INTO 'dancesrecordingsmap' VALUES (7382, 4356, NULL, 7783);
INSERT INTO 'dancesrecordingsmap' VALUES (7394, 611, NULL, 7795);
INSERT INTO 'dancesrecordingsmap' VALUES (7374, 5351, NULL, 7775);
INSERT INTO 'dancesrecordingsmap' VALUES (7472, 6897, NULL, 7992);
INSERT INTO 'dancesrecordingsmap' VALUES (7473, 13594, NULL, 7993);
INSERT INTO 'dancesrecordingsmap' VALUES (7474, 2110, NULL, 7994);
INSERT INTO 'dancesrecordingsmap' VALUES (7476, 695, NULL, 7996);
INSERT INTO 'dancesrecordingsmap' VALUES (7477, 12539, NULL, 7997);
INSERT INTO 'dancesrecordingsmap' VALUES (7478, 13595, NULL, 7998);
INSERT INTO 'dancesrecordingsmap' VALUES (7479, 549, NULL, 8000);
INSERT INTO 'dancesrecordingsmap' VALUES (7480, 8146, NULL, 8003);
INSERT INTO 'dancesrecordingsmap' VALUES (7481, 6915, NULL, 8005);
INSERT INTO 'dancesrecordingsmap' VALUES (7482, 1210, NULL, 8007);
INSERT INTO 'dancesrecordingsmap' VALUES (7483, 12071, NULL, 8013);
INSERT INTO 'dancesrecordingsmap' VALUES (7484, 2260, NULL, 8014);
INSERT INTO 'dancesrecordingsmap' VALUES (7485, 7553, NULL, 8017);
INSERT INTO 'dancesrecordingsmap' VALUES (7486, 8146, NULL, 8018);
INSERT INTO 'dancesrecordingsmap' VALUES (7488, 13596, NULL, 8031);
INSERT INTO 'dancesrecordingsmap' VALUES (7489, 13272, NULL, 8032);
INSERT INTO 'dancesrecordingsmap' VALUES (7490, 13597, NULL, 8033);
INSERT INTO 'dancesrecordingsmap' VALUES (7491, 13598, NULL, 8034);
INSERT INTO 'dancesrecordingsmap' VALUES (7492, 13599, NULL, 8035);
INSERT INTO 'dancesrecordingsmap' VALUES (7494, 13601, NULL, 8037);
INSERT INTO 'dancesrecordingsmap' VALUES (7495, 13602, NULL, 8038);
INSERT INTO 'dancesrecordingsmap' VALUES (7496, 13603, NULL, 8039);
INSERT INTO 'dancesrecordingsmap' VALUES (7497, 13604, NULL, 8040);
INSERT INTO 'dancesrecordingsmap' VALUES (7498, 13273, NULL, 8041);
INSERT INTO 'dancesrecordingsmap' VALUES (7500, 13606, NULL, 8043);
INSERT INTO 'dancesrecordingsmap' VALUES (7502, 13608, NULL, 8045);
INSERT INTO 'dancesrecordingsmap' VALUES (7504, 54, NULL, 8047);
INSERT INTO 'dancesrecordingsmap' VALUES (7505, 7090, NULL, 8048);
INSERT INTO 'dancesrecordingsmap' VALUES (7506, 594, NULL, 8049);
INSERT INTO 'dancesrecordingsmap' VALUES (7507, 5065, NULL, 8050);
INSERT INTO 'dancesrecordingsmap' VALUES (7508, 6153, NULL, 8051);
INSERT INTO 'dancesrecordingsmap' VALUES (7509, 5703, NULL, 8053);
INSERT INTO 'dancesrecordingsmap' VALUES (7510, 3562, NULL, 8054);
INSERT INTO 'dancesrecordingsmap' VALUES (7513, 10892, NULL, 8057);
INSERT INTO 'dancesrecordingsmap' VALUES (7515, 13614, NULL, 8059);
INSERT INTO 'dancesrecordingsmap' VALUES (7516, 2421, NULL, 8060);
INSERT INTO 'dancesrecordingsmap' VALUES (7517, 522, NULL, 8061);
INSERT INTO 'dancesrecordingsmap' VALUES (7518, 13615, NULL, 8062);
INSERT INTO 'dancesrecordingsmap' VALUES (7520, 8202, NULL, 8064);
INSERT INTO 'dancesrecordingsmap' VALUES (7521, 845, NULL, 8065);
INSERT INTO 'dancesrecordingsmap' VALUES (7522, 8203, NULL, 8066);
INSERT INTO 'dancesrecordingsmap' VALUES (7523, 13617, NULL, 8067);
INSERT INTO 'dancesrecordingsmap' VALUES (7524, 413, NULL, 8068);
INSERT INTO 'dancesrecordingsmap' VALUES (7525, 13618, NULL, 8069);
INSERT INTO 'dancesrecordingsmap' VALUES (7527, 13619, NULL, 8071);
INSERT INTO 'dancesrecordingsmap' VALUES (7528, 5499, NULL, 8072);
INSERT INTO 'dancesrecordingsmap' VALUES (7529, 9084, NULL, 8073);
INSERT INTO 'dancesrecordingsmap' VALUES (7530, 12428, NULL, 8074);
INSERT INTO 'dancesrecordingsmap' VALUES (7531, 9087, NULL, 8075);
INSERT INTO 'dancesrecordingsmap' VALUES (7532, 13620, NULL, 8076);
INSERT INTO 'dancesrecordingsmap' VALUES (7533, 9008, NULL, 8077);
INSERT INTO 'dancesrecordingsmap' VALUES (7534, 6972, NULL, 8078);
INSERT INTO 'dancesrecordingsmap' VALUES (7535, 11001, NULL, 8079);
INSERT INTO 'dancesrecordingsmap' VALUES (7536, 13621, NULL, 8080);
INSERT INTO 'dancesrecordingsmap' VALUES (7537, 5384, NULL, 8081);
INSERT INTO 'dancesrecordingsmap' VALUES (7538, 14339, NULL, 8082);
INSERT INTO 'dancesrecordingsmap' VALUES (7540, 7795, NULL, 8084);
INSERT INTO 'dancesrecordingsmap' VALUES (7384, 13579, NULL, 7785);
INSERT INTO 'dancesrecordingsmap' VALUES (7409, 12941, NULL, 7810);
INSERT INTO 'dancesrecordingsmap' VALUES (7539, 12634, NULL, 8083);
INSERT INTO 'dancesrecordingsmap' VALUES (7503, 13609, NULL, 8046);
INSERT INTO 'dancesrecordingsmap' VALUES (7487, 7554, NULL, 8024);
INSERT INTO 'dancesrecordingsmap' VALUES (7362, 5702, NULL, 7763);
INSERT INTO 'dancesrecordingsmap' VALUES (7512, 4858, NULL, 8056);
INSERT INTO 'dancesrecordingsmap' VALUES (7422, 2717, NULL, 7830);
INSERT INTO 'dancesrecordingsmap' VALUES (7439, 1931, NULL, 7871);
INSERT INTO 'dancesrecordingsmap' VALUES (7542, 1543, NULL, 8086);
INSERT INTO 'dancesrecordingsmap' VALUES (7543, 4808, NULL, 8089);
INSERT INTO 'dancesrecordingsmap' VALUES (7545, 4827, NULL, 8091);
INSERT INTO 'dancesrecordingsmap' VALUES (7546, 13622, NULL, 8092);
INSERT INTO 'dancesrecordingsmap' VALUES (7547, 13623, NULL, 8093);
INSERT INTO 'dancesrecordingsmap' VALUES (7548, 6701, NULL, 8094);
INSERT INTO 'dancesrecordingsmap' VALUES (7549, 4411, NULL, 8095);
INSERT INTO 'dancesrecordingsmap' VALUES (7550, 54, NULL, 8096);
INSERT INTO 'dancesrecordingsmap' VALUES (7551, 13624, NULL, 8097);
INSERT INTO 'dancesrecordingsmap' VALUES (7552, 13625, NULL, 8098);
INSERT INTO 'dancesrecordingsmap' VALUES (7553, 10773, NULL, 8099);
INSERT INTO 'dancesrecordingsmap' VALUES (7554, 12796, NULL, 8100);
INSERT INTO 'dancesrecordingsmap' VALUES (7556, 10306, NULL, 8102);
INSERT INTO 'dancesrecordingsmap' VALUES (7557, 12539, NULL, 8103);
INSERT INTO 'dancesrecordingsmap' VALUES (7558, 9817, NULL, 8105);
INSERT INTO 'dancesrecordingsmap' VALUES (7559, 5354, NULL, 8107);
INSERT INTO 'dancesrecordingsmap' VALUES (7560, 2484, NULL, 8109);
INSERT INTO 'dancesrecordingsmap' VALUES (7561, 2979, NULL, 8111);
INSERT INTO 'dancesrecordingsmap' VALUES (7562, 584, NULL, 8113);
INSERT INTO 'dancesrecordingsmap' VALUES (7563, 12538, NULL, 8115);
INSERT INTO 'dancesrecordingsmap' VALUES (7564, 4046, NULL, 8117);
INSERT INTO 'dancesrecordingsmap' VALUES (7565, 6634, NULL, 8119);
INSERT INTO 'dancesrecordingsmap' VALUES (7566, 2063, NULL, 8121);
INSERT INTO 'dancesrecordingsmap' VALUES (7567, 5239, NULL, 8122);
INSERT INTO 'dancesrecordingsmap' VALUES (7568, 8142, NULL, 8123);
INSERT INTO 'dancesrecordingsmap' VALUES (7569, 5964, NULL, 8124);
INSERT INTO 'dancesrecordingsmap' VALUES (7570, 7554, NULL, 8125);
INSERT INTO 'dancesrecordingsmap' VALUES (7571, 5658, NULL, 8131);
INSERT INTO 'dancesrecordingsmap' VALUES (7572, 2820, NULL, 8134);
INSERT INTO 'dancesrecordingsmap' VALUES (7573, 2317, NULL, 8140);
INSERT INTO 'dancesrecordingsmap' VALUES (7574, 3561, NULL, 8141);
INSERT INTO 'dancesrecordingsmap' VALUES (7575, 3152, NULL, 8142);
INSERT INTO 'dancesrecordingsmap' VALUES (7576, 6599, NULL, 8143);
INSERT INTO 'dancesrecordingsmap' VALUES (7577, 5591, NULL, 8144);
INSERT INTO 'dancesrecordingsmap' VALUES (7578, 633, NULL, 8145);
INSERT INTO 'dancesrecordingsmap' VALUES (7579, 7554, NULL, 8146);
INSERT INTO 'dancesrecordingsmap' VALUES (7580, 1792, NULL, 8147);
INSERT INTO 'dancesrecordingsmap' VALUES (7544, 1777, NULL, 8090);
INSERT INTO 'dancesrecordingsmap' VALUES (7467, 89, NULL, 7987);
INSERT INTO 'dancesrecordingsmap' VALUES (7499, 13605, NULL, 8042);
INSERT INTO 'dancesrecordingsmap' VALUES (7582, 1834, NULL, 8149);
INSERT INTO 'dancesrecordingsmap' VALUES (7583, 7555, NULL, 8150);
INSERT INTO 'dancesrecordingsmap' VALUES (7584, 8154, NULL, 8151);
INSERT INTO 'dancesrecordingsmap' VALUES (7585, 6359, NULL, 8152);
INSERT INTO 'dancesrecordingsmap' VALUES (7586, 6748, NULL, 8153);
INSERT INTO 'dancesrecordingsmap' VALUES (7587, 6915, NULL, 8154);
INSERT INTO 'dancesrecordingsmap' VALUES (7588, 4633, NULL, 8155);
INSERT INTO 'dancesrecordingsmap' VALUES (7589, 7546, NULL, 8156);
INSERT INTO 'dancesrecordingsmap' VALUES (7590, 1210, NULL, 8157);
INSERT INTO 'dancesrecordingsmap' VALUES (7591, 2745, NULL, 8158);
INSERT INTO 'dancesrecordingsmap' VALUES (7592, 1792, NULL, 8159);
INSERT INTO 'dancesrecordingsmap' VALUES (7593, 5330, NULL, 8160);
INSERT INTO 'dancesrecordingsmap' VALUES (7594, 1562, NULL, 8161);
INSERT INTO 'dancesrecordingsmap' VALUES (7595, 1786, NULL, 8162);
INSERT INTO 'dancesrecordingsmap' VALUES (7596, 5525, NULL, 8163);
INSERT INTO 'dancesrecordingsmap' VALUES (7597, 6359, NULL, 8164);
INSERT INTO 'dancesrecordingsmap' VALUES (7598, 7546, NULL, 8166);
INSERT INTO 'dancesrecordingsmap' VALUES (7599, 1210, NULL, 8167);
INSERT INTO 'dancesrecordingsmap' VALUES (7600, 2745, NULL, 8168);
INSERT INTO 'dancesrecordingsmap' VALUES (7601, 1792, NULL, 8169);
INSERT INTO 'dancesrecordingsmap' VALUES (7602, 5330, NULL, 8170);
INSERT INTO 'dancesrecordingsmap' VALUES (7603, 1562, NULL, 8171);
INSERT INTO 'dancesrecordingsmap' VALUES (7604, 1786, NULL, 8172);
INSERT INTO 'dancesrecordingsmap' VALUES (7605, 5525, NULL, 8173);
INSERT INTO 'dancesrecordingsmap' VALUES (7606, 6359, NULL, 8174);
INSERT INTO 'dancesrecordingsmap' VALUES (7607, 1931, NULL, 8175);
INSERT INTO 'dancesrecordingsmap' VALUES (7608, 6048, NULL, 8177);
INSERT INTO 'dancesrecordingsmap' VALUES (7609, 8146, NULL, 8178);
INSERT INTO 'dancesrecordingsmap' VALUES (7610, 3980, NULL, 8180);
INSERT INTO 'dancesrecordingsmap' VALUES (7611, 7553, NULL, 8182);
INSERT INTO 'dancesrecordingsmap' VALUES (7612, 549, NULL, 8183);
INSERT INTO 'dancesrecordingsmap' VALUES (7613, 8142, NULL, 8185);
INSERT INTO 'dancesrecordingsmap' VALUES (7614, 11772, NULL, 8186);
INSERT INTO 'dancesrecordingsmap' VALUES (7615, 5525, NULL, 8188);
INSERT INTO 'dancesrecordingsmap' VALUES (7616, 7546, NULL, 8192);
INSERT INTO 'dancesrecordingsmap' VALUES (7617, 6359, NULL, 8193);
INSERT INTO 'dancesrecordingsmap' VALUES (7618, 8154, NULL, 8194);
INSERT INTO 'dancesrecordingsmap' VALUES (7620, 3834, NULL, 8196);
INSERT INTO 'dancesrecordingsmap' VALUES (7621, 5964, NULL, 8199);
INSERT INTO 'dancesrecordingsmap' VALUES (7622, 1792, NULL, 8204);
INSERT INTO 'dancesrecordingsmap' VALUES (7623, 7553, NULL, 8206);
INSERT INTO 'dancesrecordingsmap' VALUES (7624, 7542, NULL, 8207);
INSERT INTO 'dancesrecordingsmap' VALUES (7625, 8154, NULL, 8208);
INSERT INTO 'dancesrecordingsmap' VALUES (7626, 1210, NULL, 8209);
INSERT INTO 'dancesrecordingsmap' VALUES (7627, 2389, NULL, 8213);
INSERT INTO 'dancesrecordingsmap' VALUES (7628, 633, NULL, 8216);
INSERT INTO 'dancesrecordingsmap' VALUES (7629, 1834, NULL, 8218);
INSERT INTO 'dancesrecordingsmap' VALUES (7630, 7546, NULL, 8220);
INSERT INTO 'dancesrecordingsmap' VALUES (7631, 6915, NULL, 8221);
INSERT INTO 'dancesrecordingsmap' VALUES (7632, 353, NULL, 8222);
INSERT INTO 'dancesrecordingsmap' VALUES (7633, 5741, NULL, 8226);
INSERT INTO 'dancesrecordingsmap' VALUES (7634, 1562, NULL, 8228);
INSERT INTO 'dancesrecordingsmap' VALUES (7635, 8148, NULL, 8229);
INSERT INTO 'dancesrecordingsmap' VALUES (7636, 7546, NULL, 8230);
INSERT INTO 'dancesrecordingsmap' VALUES (7637, 743, NULL, 8232);
INSERT INTO 'dancesrecordingsmap' VALUES (7638, 2747, NULL, 8234);
INSERT INTO 'dancesrecordingsmap' VALUES (7639, 2956, NULL, 8236);
INSERT INTO 'dancesrecordingsmap' VALUES (7641, 5731, NULL, 8240);
INSERT INTO 'dancesrecordingsmap' VALUES (7642, 3437, NULL, 8241);
INSERT INTO 'dancesrecordingsmap' VALUES (7644, 7546, NULL, 8243);
INSERT INTO 'dancesrecordingsmap' VALUES (7645, 4103, NULL, 8244);
INSERT INTO 'dancesrecordingsmap' VALUES (7646, 4491, NULL, 8245);
INSERT INTO 'dancesrecordingsmap' VALUES (7647, 7546, NULL, 8246);
INSERT INTO 'dancesrecordingsmap' VALUES (7648, 4239, NULL, 8248);
INSERT INTO 'dancesrecordingsmap' VALUES (7649, 3281, NULL, 8249);
INSERT INTO 'dancesrecordingsmap' VALUES (7650, 2979, NULL, 8250);
INSERT INTO 'dancesrecordingsmap' VALUES (7652, 445, NULL, 8256);
INSERT INTO 'dancesrecordingsmap' VALUES (7653, 7553, NULL, 8257);
INSERT INTO 'dancesrecordingsmap' VALUES (7655, 6161, NULL, 8263);
INSERT INTO 'dancesrecordingsmap' VALUES (7658, 4931, NULL, 8286);
INSERT INTO 'dancesrecordingsmap' VALUES (7659, 4827, NULL, 8287);
INSERT INTO 'dancesrecordingsmap' VALUES (7660, 742, NULL, 8288);
INSERT INTO 'dancesrecordingsmap' VALUES (7555, 6037, NULL, 8101);
INSERT INTO 'dancesrecordingsmap' VALUES (7514, 13613, NULL, 8058);
INSERT INTO 'dancesrecordingsmap' VALUES (7581, 6037, NULL, 8148);
INSERT INTO 'dancesrecordingsmap' VALUES (7640, 2916, NULL, 8237);
INSERT INTO 'dancesrecordingsmap' VALUES (7493, 13600, NULL, 8036);
INSERT INTO 'dancesrecordingsmap' VALUES (7651, 6048, NULL, 8253);
INSERT INTO 'dancesrecordingsmap' VALUES (7511, 442, NULL, 8055);
INSERT INTO 'dancesrecordingsmap' VALUES (7661, 5497, NULL, 8289);
INSERT INTO 'dancesrecordingsmap' VALUES (7662, 3537, NULL, 8290);
INSERT INTO 'dancesrecordingsmap' VALUES (7663, 3789, NULL, 8291);
INSERT INTO 'dancesrecordingsmap' VALUES (7664, 1864, NULL, 8292);
INSERT INTO 'dancesrecordingsmap' VALUES (7665, 5591, NULL, 8293);
INSERT INTO 'dancesrecordingsmap' VALUES (7666, 5945, NULL, 8294);
INSERT INTO 'dancesrecordingsmap' VALUES (7667, 153, NULL, 8295);
INSERT INTO 'dancesrecordingsmap' VALUES (7668, 1834, NULL, 8296);
INSERT INTO 'dancesrecordingsmap' VALUES (7669, 2925, NULL, 8297);
INSERT INTO 'dancesrecordingsmap' VALUES (7670, 1786, NULL, 8298);
INSERT INTO 'dancesrecordingsmap' VALUES (7671, 2495, NULL, 8299);
INSERT INTO 'dancesrecordingsmap' VALUES (7672, 3129, NULL, 8300);
INSERT INTO 'dancesrecordingsmap' VALUES (7673, 1562, NULL, 8301);
INSERT INTO 'dancesrecordingsmap' VALUES (7675, 1792, NULL, 8303);
INSERT INTO 'dancesrecordingsmap' VALUES (7676, 1792, NULL, 8304);
INSERT INTO 'dancesrecordingsmap' VALUES (7677, 1931, NULL, 8305);
INSERT INTO 'dancesrecordingsmap' VALUES (7678, 2317, NULL, 8306);
INSERT INTO 'dancesrecordingsmap' VALUES (7680, 1782, NULL, 8308);
INSERT INTO 'dancesrecordingsmap' VALUES (7681, 5525, NULL, 8309);
INSERT INTO 'dancesrecordingsmap' VALUES (7682, 5525, NULL, 8310);
INSERT INTO 'dancesrecordingsmap' VALUES (7685, 6233, NULL, 8313);
INSERT INTO 'dancesrecordingsmap' VALUES (7686, 6233, NULL, 8314);
INSERT INTO 'dancesrecordingsmap' VALUES (7689, 13677, NULL, 8318);
INSERT INTO 'dancesrecordingsmap' VALUES (7690, 13522, NULL, 8319);
INSERT INTO 'dancesrecordingsmap' VALUES (7691, 11533, NULL, 8320);
INSERT INTO 'dancesrecordingsmap' VALUES (7692, 13678, NULL, 8321);
INSERT INTO 'dancesrecordingsmap' VALUES (7694, 13688, NULL, 8331);
INSERT INTO 'dancesrecordingsmap' VALUES (7696, 13682, NULL, 8324);
INSERT INTO 'dancesrecordingsmap' VALUES (7697, 13683, NULL, 8325);
INSERT INTO 'dancesrecordingsmap' VALUES (7698, 13328, NULL, 8326);
INSERT INTO 'dancesrecordingsmap' VALUES (7699, 13684, NULL, 8327);
INSERT INTO 'dancesrecordingsmap' VALUES (7700, 13685, NULL, 8328);
INSERT INTO 'dancesrecordingsmap' VALUES (7701, 13686, NULL, 8329);
INSERT INTO 'dancesrecordingsmap' VALUES (7702, 13687, NULL, 8330);
INSERT INTO 'dancesrecordingsmap' VALUES (7703, 13689, NULL, 8332);
INSERT INTO 'dancesrecordingsmap' VALUES (7704, 13690, NULL, 8333);
INSERT INTO 'dancesrecordingsmap' VALUES (7705, 7563, NULL, 8334);
INSERT INTO 'dancesrecordingsmap' VALUES (9124, 17554, NULL, 10188);
INSERT INTO 'dancesrecordingsmap' VALUES (7711, 13733, NULL, 198);
INSERT INTO 'dancesrecordingsmap' VALUES (7714, 13739, NULL, 5124);
INSERT INTO 'dancesrecordingsmap' VALUES (7716, 13811, NULL, 2527);
INSERT INTO 'dancesrecordingsmap' VALUES (7718, 13815, NULL, 4007);
INSERT INTO 'dancesrecordingsmap' VALUES (7719, 13821, NULL, 5237);
INSERT INTO 'dancesrecordingsmap' VALUES (7720, 13821, NULL, 4445);
INSERT INTO 'dancesrecordingsmap' VALUES (7721, 13809, NULL, 5373);
INSERT INTO 'dancesrecordingsmap' VALUES (7724, 7862, NULL, 3372);
INSERT INTO 'dancesrecordingsmap' VALUES (7725, 7862, NULL, 1331);
INSERT INTO 'dancesrecordingsmap' VALUES (7726, 4399, NULL, 2969);
INSERT INTO 'dancesrecordingsmap' VALUES (7728, 1273, NULL, 2014);
INSERT INTO 'dancesrecordingsmap' VALUES (7729, 2553, NULL, 3660);
INSERT INTO 'dancesrecordingsmap' VALUES (7730, 1383, NULL, 2841);
INSERT INTO 'dancesrecordingsmap' VALUES (7731, 5275, NULL, 2555);
INSERT INTO 'dancesrecordingsmap' VALUES (7733, 5469, NULL, 1135);
INSERT INTO 'dancesrecordingsmap' VALUES (7735, 2853, NULL, 1452);
INSERT INTO 'dancesrecordingsmap' VALUES (7736, 5690, NULL, 1286);
INSERT INTO 'dancesrecordingsmap' VALUES (7737, 2503, NULL, 1363);
INSERT INTO 'dancesrecordingsmap' VALUES (7717, 13812, NULL, 6507);
INSERT INTO 'dancesrecordingsmap' VALUES (7740, 595, NULL, 1615);
INSERT INTO 'dancesrecordingsmap' VALUES (7741, 5682, NULL, 1306);
INSERT INTO 'dancesrecordingsmap' VALUES (7742, 445, NULL, 8347);
INSERT INTO 'dancesrecordingsmap' VALUES (7743, 462, NULL, 8348);
INSERT INTO 'dancesrecordingsmap' VALUES (7656, 2203, NULL, 8266);
INSERT INTO 'dancesrecordingsmap' VALUES (7541, 8932, NULL, 8085);
INSERT INTO 'dancesrecordingsmap' VALUES (7679, 1782, NULL, 8307);
INSERT INTO 'dancesrecordingsmap' VALUES (7619, 1792, NULL, 8195);
INSERT INTO 'dancesrecordingsmap' VALUES (7744, 584, NULL, 8349);
INSERT INTO 'dancesrecordingsmap' VALUES (7747, 2604, NULL, 8352);
INSERT INTO 'dancesrecordingsmap' VALUES (7748, 2924, NULL, 8353);
INSERT INTO 'dancesrecordingsmap' VALUES (7693, 14241, NULL, 8322);
INSERT INTO 'dancesrecordingsmap' VALUES (7687, 14241, NULL, 8315);
INSERT INTO 'dancesrecordingsmap' VALUES (7688, 14241, NULL, 8316);
INSERT INTO 'dancesrecordingsmap' VALUES (7750, 3172, NULL, 8355);
INSERT INTO 'dancesrecordingsmap' VALUES (7752, 3941, NULL, 8357);
INSERT INTO 'dancesrecordingsmap' VALUES (7753, 4784, NULL, 8358);
INSERT INTO 'dancesrecordingsmap' VALUES (7754, 4931, NULL, 8359);
INSERT INTO 'dancesrecordingsmap' VALUES (7755, 5703, NULL, 8360);
INSERT INTO 'dancesrecordingsmap' VALUES (7756, 6010, NULL, 8361);
INSERT INTO 'dancesrecordingsmap' VALUES (7757, 6048, NULL, 8362);
INSERT INTO 'dancesrecordingsmap' VALUES (7758, 5829, NULL, 8363);
INSERT INTO 'dancesrecordingsmap' VALUES (7760, 7111, NULL, 8365);
INSERT INTO 'dancesrecordingsmap' VALUES (7761, 873, NULL, 8366);
INSERT INTO 'dancesrecordingsmap' VALUES (7762, 3783, NULL, 8367);
INSERT INTO 'dancesrecordingsmap' VALUES (7763, 2394, NULL, 8368);
INSERT INTO 'dancesrecordingsmap' VALUES (7765, 4175, NULL, 8370);
INSERT INTO 'dancesrecordingsmap' VALUES (7766, 11188, NULL, 8371);
INSERT INTO 'dancesrecordingsmap' VALUES (7683, 2745, NULL, 8311);
INSERT INTO 'dancesrecordingsmap' VALUES (7764, 6386, NULL, 8369);
INSERT INTO 'dancesrecordingsmap' VALUES (7746, 1485, NULL, 8351);
INSERT INTO 'dancesrecordingsmap' VALUES (7745, 1128, NULL, 8350);
INSERT INTO 'dancesrecordingsmap' VALUES (7695, 13681, NULL, 8323);
INSERT INTO 'dancesrecordingsmap' VALUES (7712, 13734, NULL, 947);
INSERT INTO 'dancesrecordingsmap' VALUES (7727, 1273, NULL, 2027);
INSERT INTO 'dancesrecordingsmap' VALUES (7732, 7080, NULL, 2411);
INSERT INTO 'dancesrecordingsmap' VALUES (9126, 17556, NULL, 10190);
INSERT INTO 'dancesrecordingsmap' VALUES (7709, 13732, NULL, 5481);
INSERT INTO 'dancesrecordingsmap' VALUES (7706, 11189, NULL, 7163);
INSERT INTO 'dancesrecordingsmap' VALUES (7768, 4805, NULL, 8373);
INSERT INTO 'dancesrecordingsmap' VALUES (7769, 5982, NULL, 8374);
INSERT INTO 'dancesrecordingsmap' VALUES (7770, 7109, NULL, 8375);
INSERT INTO 'dancesrecordingsmap' VALUES (7771, 9088, NULL, 8376);
INSERT INTO 'dancesrecordingsmap' VALUES (7772, 442, NULL, 8377);
INSERT INTO 'dancesrecordingsmap' VALUES (7774, 8956, NULL, 8379);
INSERT INTO 'dancesrecordingsmap' VALUES (7775, 5552, NULL, 8407);
INSERT INTO 'dancesrecordingsmap' VALUES (7776, 4073, NULL, 8408);
INSERT INTO 'dancesrecordingsmap' VALUES (7777, 977, NULL, 8410);
INSERT INTO 'dancesrecordingsmap' VALUES (7778, 3699, NULL, 8411);
INSERT INTO 'dancesrecordingsmap' VALUES (7779, 4585, NULL, 8413);
INSERT INTO 'dancesrecordingsmap' VALUES (7780, 13753, NULL, 8414);
INSERT INTO 'dancesrecordingsmap' VALUES (7782, 7480, NULL, 8416);
INSERT INTO 'dancesrecordingsmap' VALUES (7783, 14295, NULL, 8417);
INSERT INTO 'dancesrecordingsmap' VALUES (7784, 14294, NULL, 8418);
INSERT INTO 'dancesrecordingsmap' VALUES (7787, 5465, NULL, 8409);
INSERT INTO 'dancesrecordingsmap' VALUES (7788, 1246, NULL, 8412);
INSERT INTO 'dancesrecordingsmap' VALUES (7789, 8086, NULL, 8412);
INSERT INTO 'dancesrecordingsmap' VALUES (7810, 14297, NULL, 8421);
INSERT INTO 'dancesrecordingsmap' VALUES (7811, 14300, NULL, 8422);
INSERT INTO 'dancesrecordingsmap' VALUES (7812, 8753, NULL, 8423);
INSERT INTO 'dancesrecordingsmap' VALUES (7813, 14299, NULL, 8424);
INSERT INTO 'dancesrecordingsmap' VALUES (7814, 14301, NULL, 8425);
INSERT INTO 'dancesrecordingsmap' VALUES (7815, 12177, NULL, 8426);
INSERT INTO 'dancesrecordingsmap' VALUES (7816, 14302, NULL, 8427);
INSERT INTO 'dancesrecordingsmap' VALUES (7817, 1607, NULL, 8428);
INSERT INTO 'dancesrecordingsmap' VALUES (7818, 14298, NULL, 8429);
INSERT INTO 'dancesrecordingsmap' VALUES (7819, 5459, NULL, 8430);
INSERT INTO 'dancesrecordingsmap' VALUES (7820, 2239, NULL, 8431);
INSERT INTO 'dancesrecordingsmap' VALUES (7821, 14303, NULL, 8432);
INSERT INTO 'dancesrecordingsmap' VALUES (7823, 8752, NULL, 8434);
INSERT INTO 'dancesrecordingsmap' VALUES (7824, 14305, NULL, 8435);
INSERT INTO 'dancesrecordingsmap' VALUES (7825, 3487, NULL, 8436);
INSERT INTO 'dancesrecordingsmap' VALUES (7826, 14298, NULL, 8437);
INSERT INTO 'dancesrecordingsmap' VALUES (7827, 14299, NULL, 8438);
INSERT INTO 'dancesrecordingsmap' VALUES (7828, 12177, NULL, 8439);
INSERT INTO 'dancesrecordingsmap' VALUES (7829, 3614, NULL, 8440);
INSERT INTO 'dancesrecordingsmap' VALUES (7831, 14308, NULL, 8442);
INSERT INTO 'dancesrecordingsmap' VALUES (7832, 8750, NULL, 8443);
INSERT INTO 'dancesrecordingsmap' VALUES (7833, 14309, NULL, 8444);
INSERT INTO 'dancesrecordingsmap' VALUES (7834, 14310, NULL, 8445);
INSERT INTO 'dancesrecordingsmap' VALUES (7835, 14311, NULL, 8446);
INSERT INTO 'dancesrecordingsmap' VALUES (7836, 14312, NULL, 8447);
INSERT INTO 'dancesrecordingsmap' VALUES (7837, 14313, NULL, 8448);
INSERT INTO 'dancesrecordingsmap' VALUES (7838, 14296, NULL, 8449);
INSERT INTO 'dancesrecordingsmap' VALUES (7839, 5926, NULL, 8450);
INSERT INTO 'dancesrecordingsmap' VALUES (7840, 8749, NULL, 8451);
INSERT INTO 'dancesrecordingsmap' VALUES (7841, 14314, NULL, 8452);
INSERT INTO 'dancesrecordingsmap' VALUES (7842, 14315, NULL, 8453);
INSERT INTO 'dancesrecordingsmap' VALUES (7843, 14316, NULL, 8454);
INSERT INTO 'dancesrecordingsmap' VALUES (7844, 8749, NULL, 8455);
INSERT INTO 'dancesrecordingsmap' VALUES (7845, 2979, NULL, 8457);
INSERT INTO 'dancesrecordingsmap' VALUES (7847, 5525, NULL, 8459);
INSERT INTO 'dancesrecordingsmap' VALUES (7848, 522, NULL, 8461);
INSERT INTO 'dancesrecordingsmap' VALUES (7849, 11438, NULL, 8462);
INSERT INTO 'dancesrecordingsmap' VALUES (7850, 7042, NULL, 8463);
INSERT INTO 'dancesrecordingsmap' VALUES (7684, 2745, NULL, 8312);
INSERT INTO 'dancesrecordingsmap' VALUES (7749, 2935, NULL, 8354);
INSERT INTO 'dancesrecordingsmap' VALUES (7715, 13810, NULL, 2515);
INSERT INTO 'dancesrecordingsmap' VALUES (7846, 604, NULL, 8458);
INSERT INTO 'dancesrecordingsmap' VALUES (7723, 5232, NULL, 2562);
INSERT INTO 'dancesrecordingsmap' VALUES (7713, 13736, NULL, 3499);
INSERT INTO 'dancesrecordingsmap' VALUES (7739, 75, NULL, 2952);
INSERT INTO 'dancesrecordingsmap' VALUES (7852, 754, NULL, 8465);
INSERT INTO 'dancesrecordingsmap' VALUES (7854, 5802, NULL, 8470);
INSERT INTO 'dancesrecordingsmap' VALUES (7855, 3105, NULL, 8471);
INSERT INTO 'dancesrecordingsmap' VALUES (7856, 2747, NULL, 8472);
INSERT INTO 'dancesrecordingsmap' VALUES (7857, 3580, NULL, 8473);
INSERT INTO 'dancesrecordingsmap' VALUES (7858, 5207, NULL, 8474);
INSERT INTO 'dancesrecordingsmap' VALUES (7859, 8932, NULL, 8475);
INSERT INTO 'dancesrecordingsmap' VALUES (7860, 5621, NULL, 8476);
INSERT INTO 'dancesrecordingsmap' VALUES (7861, 14293, NULL, 8477);
INSERT INTO 'dancesrecordingsmap' VALUES (7862, 743, NULL, 8478);
INSERT INTO 'dancesrecordingsmap' VALUES (7863, 5860, NULL, 8479);
INSERT INTO 'dancesrecordingsmap' VALUES (7864, 5330, NULL, 8482);
INSERT INTO 'dancesrecordingsmap' VALUES (7865, 1562, NULL, 8483);
INSERT INTO 'dancesrecordingsmap' VALUES (7866, 6915, NULL, 8484);
INSERT INTO 'dancesrecordingsmap' VALUES (7867, 1478, NULL, 8485);
INSERT INTO 'dancesrecordingsmap' VALUES (7868, 5525, NULL, 8486);
INSERT INTO 'dancesrecordingsmap' VALUES (7869, 7553, NULL, 8487);
INSERT INTO 'dancesrecordingsmap' VALUES (7870, 1792, NULL, 8488);
INSERT INTO 'dancesrecordingsmap' VALUES (7871, 8142, NULL, 8489);
INSERT INTO 'dancesrecordingsmap' VALUES (7872, 6359, NULL, 8490);
INSERT INTO 'dancesrecordingsmap' VALUES (7873, 3336, NULL, 8491);
INSERT INTO 'dancesrecordingsmap' VALUES (7874, 4102, NULL, 8492);
INSERT INTO 'dancesrecordingsmap' VALUES (7875, 8154, NULL, 8493);
INSERT INTO 'dancesrecordingsmap' VALUES (7876, 5239, NULL, 8494);
INSERT INTO 'dancesrecordingsmap' VALUES (7877, 2745, NULL, 8495);
INSERT INTO 'dancesrecordingsmap' VALUES (7878, 2250, NULL, 8496);
INSERT INTO 'dancesrecordingsmap' VALUES (7879, 5239, NULL, 8498);
INSERT INTO 'dancesrecordingsmap' VALUES (7880, 3310, NULL, 8502);
INSERT INTO 'dancesrecordingsmap' VALUES (7881, 8154, NULL, 8504);
INSERT INTO 'dancesrecordingsmap' VALUES (7882, 7553, NULL, 8505);
INSERT INTO 'dancesrecordingsmap' VALUES (7883, 8146, NULL, 8508);
INSERT INTO 'dancesrecordingsmap' VALUES (7884, 2250, NULL, 8514);
INSERT INTO 'dancesrecordingsmap' VALUES (7885, 2979, NULL, 8517);
INSERT INTO 'dancesrecordingsmap' VALUES (7886, 3980, NULL, 8518);
INSERT INTO 'dancesrecordingsmap' VALUES (7887, 8154, NULL, 8520);
INSERT INTO 'dancesrecordingsmap' VALUES (7888, 6712, NULL, 8521);
INSERT INTO 'dancesrecordingsmap' VALUES (7889, 7553, NULL, 8522);
INSERT INTO 'dancesrecordingsmap' VALUES (7890, 894, NULL, 8524);
INSERT INTO 'dancesrecordingsmap' VALUES (7891, 6915, NULL, 8525);
INSERT INTO 'dancesrecordingsmap' VALUES (7892, 8142, NULL, 8526);
INSERT INTO 'dancesrecordingsmap' VALUES (7893, 2777, NULL, 8528);
INSERT INTO 'dancesrecordingsmap' VALUES (7894, 7546, NULL, 8530);
INSERT INTO 'dancesrecordingsmap' VALUES (7895, 7554, NULL, 8531);
INSERT INTO 'dancesrecordingsmap' VALUES (7896, 1758, NULL, 8532);
INSERT INTO 'dancesrecordingsmap' VALUES (7897, 153, NULL, 8533);
INSERT INTO 'dancesrecordingsmap' VALUES (7898, 8146, NULL, 8534);
INSERT INTO 'dancesrecordingsmap' VALUES (7899, 2947, NULL, 8536);
INSERT INTO 'dancesrecordingsmap' VALUES (7902, 8154, NULL, 8572);
INSERT INTO 'dancesrecordingsmap' VALUES (7903, 4633, NULL, 8574);
INSERT INTO 'dancesrecordingsmap' VALUES (7904, 1210, NULL, 8575);
INSERT INTO 'dancesrecordingsmap' VALUES (7905, 8154, NULL, 8576);
INSERT INTO 'dancesrecordingsmap' VALUES (7906, 8142, NULL, 8577);
INSERT INTO 'dancesrecordingsmap' VALUES (7907, 7553, NULL, 8578);
INSERT INTO 'dancesrecordingsmap' VALUES (7908, 8152, NULL, 8579);
INSERT INTO 'dancesrecordingsmap' VALUES (7909, 8146, NULL, 8587);
INSERT INTO 'dancesrecordingsmap' VALUES (7910, 8153, NULL, 8588);
INSERT INTO 'dancesrecordingsmap' VALUES (7911, 6359, NULL, 8589);
INSERT INTO 'dancesrecordingsmap' VALUES (7912, 7546, NULL, 8590);
INSERT INTO 'dancesrecordingsmap' VALUES (7913, 1562, NULL, 8591);
INSERT INTO 'dancesrecordingsmap' VALUES (7914, 7552, NULL, 8592);
INSERT INTO 'dancesrecordingsmap' VALUES (7915, 8142, NULL, 8594);
INSERT INTO 'dancesrecordingsmap' VALUES (7916, 8143, NULL, 8595);
INSERT INTO 'dancesrecordingsmap' VALUES (7917, 1562, NULL, 8596);
INSERT INTO 'dancesrecordingsmap' VALUES (7918, 8161, NULL, 8597);
INSERT INTO 'dancesrecordingsmap' VALUES (7919, 8146, NULL, 8598);
INSERT INTO 'dancesrecordingsmap' VALUES (7921, 7546, NULL, 8601);
INSERT INTO 'dancesrecordingsmap' VALUES (7922, 8142, NULL, 8604);
INSERT INTO 'dancesrecordingsmap' VALUES (7923, 8154, NULL, 8605);
INSERT INTO 'dancesrecordingsmap' VALUES (7924, 6359, NULL, 8607);
INSERT INTO 'dancesrecordingsmap' VALUES (7925, 7553, NULL, 8608);
INSERT INTO 'dancesrecordingsmap' VALUES (7926, 1210, NULL, 8609);
INSERT INTO 'dancesrecordingsmap' VALUES (7927, 7546, NULL, 8611);
INSERT INTO 'dancesrecordingsmap' VALUES (7928, 1562, NULL, 8614);
INSERT INTO 'dancesrecordingsmap' VALUES (7929, 8142, NULL, 8615);
INSERT INTO 'dancesrecordingsmap' VALUES (7930, 7553, NULL, 8616);
INSERT INTO 'dancesrecordingsmap' VALUES (7932, 8146, NULL, 8619);
INSERT INTO 'dancesrecordingsmap' VALUES (7933, 6359, NULL, 8624);
INSERT INTO 'dancesrecordingsmap' VALUES (7935, 8143, NULL, 8628);
INSERT INTO 'dancesrecordingsmap' VALUES (7938, 3246, NULL, 8633);
INSERT INTO 'dancesrecordingsmap' VALUES (7941, 1562, NULL, 8639);
INSERT INTO 'dancesrecordingsmap' VALUES (7950, 8148, NULL, 8652);
INSERT INTO 'dancesrecordingsmap' VALUES (7781, 14, NULL, 8415);
INSERT INTO 'dancesrecordingsmap' VALUES (7851, 3609, NULL, 8464);
INSERT INTO 'dancesrecordingsmap' VALUES (7734, 6295, NULL, 464);
INSERT INTO 'dancesrecordingsmap' VALUES (7767, 2924, NULL, 8372);
INSERT INTO 'dancesrecordingsmap' VALUES (7773, 3418, NULL, 8378);
INSERT INTO 'dancesrecordingsmap' VALUES (7934, 7554, NULL, 8626);
INSERT INTO 'dancesrecordingsmap' VALUES (7759, 6712, NULL, 8364);
INSERT INTO 'dancesrecordingsmap' VALUES (7951, 3246, NULL, 8653);
INSERT INTO 'dancesrecordingsmap' VALUES (7952, 3561, NULL, 8655);
INSERT INTO 'dancesrecordingsmap' VALUES (7953, 8146, NULL, 8657);
INSERT INTO 'dancesrecordingsmap' VALUES (7954, 1562, NULL, 8659);
INSERT INTO 'dancesrecordingsmap' VALUES (7955, 6915, NULL, 8660);
INSERT INTO 'dancesrecordingsmap' VALUES (7956, 5623, NULL, 8662);
INSERT INTO 'dancesrecordingsmap' VALUES (7957, 7553, NULL, 8663);
INSERT INTO 'dancesrecordingsmap' VALUES (7958, 7548, NULL, 8665);
INSERT INTO 'dancesrecordingsmap' VALUES (7959, 7546, NULL, 8666);
INSERT INTO 'dancesrecordingsmap' VALUES (7960, 3834, NULL, 8667);
INSERT INTO 'dancesrecordingsmap' VALUES (7961, 7554, NULL, 8668);
INSERT INTO 'dancesrecordingsmap' VALUES (7962, 1927, NULL, 8670);
INSERT INTO 'dancesrecordingsmap' VALUES (7964, 7574, NULL, 8672);
INSERT INTO 'dancesrecordingsmap' VALUES (7830, 14307, NULL, 8441);
INSERT INTO 'dancesrecordingsmap' VALUES (7949, 1786, NULL, 8651);
INSERT INTO 'dancesrecordingsmap' VALUES (7965, 4014, NULL, 8674);
INSERT INTO 'dancesrecordingsmap' VALUES (7966, 7147, NULL, 8675);
INSERT INTO 'dancesrecordingsmap' VALUES (7967, 1792, NULL, 8680);
INSERT INTO 'dancesrecordingsmap' VALUES (7968, 1210, NULL, 8683);
INSERT INTO 'dancesrecordingsmap' VALUES (7969, 658, NULL, 8684);
INSERT INTO 'dancesrecordingsmap' VALUES (7970, 6359, NULL, 8685);
INSERT INTO 'dancesrecordingsmap' VALUES (7971, 2250, NULL, 8687);
INSERT INTO 'dancesrecordingsmap' VALUES (7972, 8154, NULL, 8688);
INSERT INTO 'dancesrecordingsmap' VALUES (7974, 445, NULL, 8690);
INSERT INTO 'dancesrecordingsmap' VALUES (7975, 2979, NULL, 8693);
INSERT INTO 'dancesrecordingsmap' VALUES (7976, 769, NULL, 8694);
INSERT INTO 'dancesrecordingsmap' VALUES (7977, 3672, NULL, 8695);
INSERT INTO 'dancesrecordingsmap' VALUES (7978, 1066, NULL, 8696);
INSERT INTO 'dancesrecordingsmap' VALUES (7979, 14211, NULL, 8698);
INSERT INTO 'dancesrecordingsmap' VALUES (7980, 8146, NULL, 8703);
INSERT INTO 'dancesrecordingsmap' VALUES (7981, 1927, NULL, 8704);
INSERT INTO 'dancesrecordingsmap' VALUES (7982, 10394, NULL, 8705);
INSERT INTO 'dancesrecordingsmap' VALUES (7983, 2745, NULL, 8706);
INSERT INTO 'dancesrecordingsmap' VALUES (7984, 4744, NULL, 8710);
INSERT INTO 'dancesrecordingsmap' VALUES (7985, 743, NULL, 8711);
INSERT INTO 'dancesrecordingsmap' VALUES (7986, 1786, NULL, 8712);
INSERT INTO 'dancesrecordingsmap' VALUES (7987, 7546, NULL, 8713);
INSERT INTO 'dancesrecordingsmap' VALUES (7988, 6767, NULL, 8714);
INSERT INTO 'dancesrecordingsmap' VALUES (7989, 8142, NULL, 8715);
INSERT INTO 'dancesrecordingsmap' VALUES (7990, 2189, NULL, 8716);
INSERT INTO 'dancesrecordingsmap' VALUES (7991, 153, NULL, 8737);
INSERT INTO 'dancesrecordingsmap' VALUES (7992, 4782, NULL, 8743);
INSERT INTO 'dancesrecordingsmap' VALUES (7993, 1792, NULL, 8745);
INSERT INTO 'dancesrecordingsmap' VALUES (7994, 648, NULL, 8770);
INSERT INTO 'dancesrecordingsmap' VALUES (7995, 549, NULL, 8771);
INSERT INTO 'dancesrecordingsmap' VALUES (7997, 1792, NULL, 8775);
INSERT INTO 'dancesrecordingsmap' VALUES (7998, 8146, NULL, 8776);
INSERT INTO 'dancesrecordingsmap' VALUES (7999, 1799, NULL, 8777);
INSERT INTO 'dancesrecordingsmap' VALUES (8001, 7554, NULL, 8780);
INSERT INTO 'dancesrecordingsmap' VALUES (8002, 7546, NULL, 8781);
INSERT INTO 'dancesrecordingsmap' VALUES (8003, 2498, NULL, 8782);
INSERT INTO 'dancesrecordingsmap' VALUES (8004, 1348, NULL, 8783);
INSERT INTO 'dancesrecordingsmap' VALUES (8005, 5525, NULL, 8788);
INSERT INTO 'dancesrecordingsmap' VALUES (8007, 7546, NULL, 8795);
INSERT INTO 'dancesrecordingsmap' VALUES (8008, 154, NULL, 8797);
INSERT INTO 'dancesrecordingsmap' VALUES (8009, 1562, NULL, 8801);
INSERT INTO 'dancesrecordingsmap' VALUES (8010, 899, NULL, 8802);
INSERT INTO 'dancesrecordingsmap' VALUES (8288, 14685, NULL, 9367);
INSERT INTO 'dancesrecordingsmap' VALUES (8012, 794, NULL, 8806);
INSERT INTO 'dancesrecordingsmap' VALUES (8013, 723, NULL, 8810);
INSERT INTO 'dancesrecordingsmap' VALUES (8014, 9106, NULL, 8812);
INSERT INTO 'dancesrecordingsmap' VALUES (8015, 13357, NULL, 8815);
INSERT INTO 'dancesrecordingsmap' VALUES (8017, 950, NULL, 8817);
INSERT INTO 'dancesrecordingsmap' VALUES (8019, 3436, NULL, 8819);
INSERT INTO 'dancesrecordingsmap' VALUES (8020, 541, NULL, 8820);
INSERT INTO 'dancesrecordingsmap' VALUES (8021, 56, NULL, 8821);
INSERT INTO 'dancesrecordingsmap' VALUES (8022, 7242, NULL, 8822);
INSERT INTO 'dancesrecordingsmap' VALUES (8023, 3172, NULL, 8823);
INSERT INTO 'dancesrecordingsmap' VALUES (8024, 5591, NULL, 8824);
INSERT INTO 'dancesrecordingsmap' VALUES (8027, 6995, NULL, 8827);
INSERT INTO 'dancesrecordingsmap' VALUES (8028, 5308, NULL, 8828);
INSERT INTO 'dancesrecordingsmap' VALUES (8030, 1210, NULL, 8830);
INSERT INTO 'dancesrecordingsmap' VALUES (8032, 8654, NULL, 8832);
INSERT INTO 'dancesrecordingsmap' VALUES (8033, 13886, NULL, 8833);
INSERT INTO 'dancesrecordingsmap' VALUES (8035, 13888, NULL, 8835);
INSERT INTO 'dancesrecordingsmap' VALUES (8036, 13889, NULL, 8836);
INSERT INTO 'dancesrecordingsmap' VALUES (8037, 13890, NULL, 8837);
INSERT INTO 'dancesrecordingsmap' VALUES (8038, 13891, NULL, 8838);
INSERT INTO 'dancesrecordingsmap' VALUES (8039, 13892, NULL, 8839);
INSERT INTO 'dancesrecordingsmap' VALUES (8040, 13893, NULL, 8840);
INSERT INTO 'dancesrecordingsmap' VALUES (8041, 13894, NULL, 8841);
INSERT INTO 'dancesrecordingsmap' VALUES (8042, 13895, NULL, 8842);
INSERT INTO 'dancesrecordingsmap' VALUES (8043, 9649, NULL, 8843);
INSERT INTO 'dancesrecordingsmap' VALUES (8044, 9650, NULL, 8844);
INSERT INTO 'dancesrecordingsmap' VALUES (8045, 9540, NULL, 8845);
INSERT INTO 'dancesrecordingsmap' VALUES (8260, 14727, NULL, 9320);
INSERT INTO 'dancesrecordingsmap' VALUES (8261, 14728, NULL, 9321);
INSERT INTO 'dancesrecordingsmap' VALUES (8262, 14723, NULL, 9322);
INSERT INTO 'dancesrecordingsmap' VALUES (7931, 8162, NULL, 8617);
INSERT INTO 'dancesrecordingsmap' VALUES (7963, 13726, NULL, 8671);
INSERT INTO 'dancesrecordingsmap' VALUES (7996, 2317, NULL, 8774);
INSERT INTO 'dancesrecordingsmap' VALUES (8025, 164, NULL, 8825);
INSERT INTO 'dancesrecordingsmap' VALUES (8263, 14722, NULL, 9323);
INSERT INTO 'dancesrecordingsmap' VALUES (8264, 14725, NULL, 9324);
INSERT INTO 'dancesrecordingsmap' VALUES (8265, 14726, NULL, 9325);
INSERT INTO 'dancesrecordingsmap' VALUES (7230, 7552, NULL, 7532);
INSERT INTO 'dancesrecordingsmap' VALUES (8145, 14741, NULL, 9028);
INSERT INTO 'dancesrecordingsmap' VALUES (8266, 14984, NULL, 6467);
INSERT INTO 'dancesrecordingsmap' VALUES (8267, 15045, NULL, 9345);
INSERT INTO 'dancesrecordingsmap' VALUES (8268, 15046, NULL, 9346);
INSERT INTO 'dancesrecordingsmap' VALUES (8269, 15047, NULL, 9347);
INSERT INTO 'dancesrecordingsmap' VALUES (8016, 11763, NULL, 5807);
INSERT INTO 'dancesrecordingsmap' VALUES (8273, 15052, NULL, 9351);
INSERT INTO 'dancesrecordingsmap' VALUES (8274, 13576, NULL, 9352);
INSERT INTO 'dancesrecordingsmap' VALUES (8276, 15054, NULL, 9354);
INSERT INTO 'dancesrecordingsmap' VALUES (8277, 7457, NULL, 9355);
INSERT INTO 'dancesrecordingsmap' VALUES (8279, 13577, NULL, 9358);
INSERT INTO 'dancesrecordingsmap' VALUES (8280, 11284, NULL, 9359);
INSERT INTO 'dancesrecordingsmap' VALUES (8281, 11483, NULL, 9360);
INSERT INTO 'dancesrecordingsmap' VALUES (8283, 5093, NULL, 9362);
INSERT INTO 'dancesrecordingsmap' VALUES (8285, 14976, NULL, 9364);
INSERT INTO 'dancesrecordingsmap' VALUES (8286, 13730, NULL, 9365);
INSERT INTO 'dancesrecordingsmap' VALUES (8287, 14977, NULL, 9366);
INSERT INTO 'dancesrecordingsmap' VALUES (8289, 10232, NULL, 9368);
INSERT INTO 'dancesrecordingsmap' VALUES (8290, 14346, NULL, 9369);
INSERT INTO 'dancesrecordingsmap' VALUES (8291, 15220, NULL, 9370);
INSERT INTO 'dancesrecordingsmap' VALUES (8292, 14545, NULL, 9372);
INSERT INTO 'dancesrecordingsmap' VALUES (8294, 15227, NULL, 9373);
INSERT INTO 'dancesrecordingsmap' VALUES (8295, 14546, NULL, 9371);
INSERT INTO 'dancesrecordingsmap' VALUES (8297, 15228, NULL, 9376);
INSERT INTO 'dancesrecordingsmap' VALUES (8298, 14563, NULL, 9377);
INSERT INTO 'dancesrecordingsmap' VALUES (8299, 15225, NULL, 9378);
INSERT INTO 'dancesrecordingsmap' VALUES (8301, 13747, NULL, 9380);
INSERT INTO 'dancesrecordingsmap' VALUES (8302, 15226, NULL, 9381);
INSERT INTO 'dancesrecordingsmap' VALUES (8304, 15224, NULL, 9383);
INSERT INTO 'dancesrecordingsmap' VALUES (8305, 14541, NULL, 9384);
INSERT INTO 'dancesrecordingsmap' VALUES (8310, 5963, NULL, 9419);
INSERT INTO 'dancesrecordingsmap' VALUES (8313, 5239, NULL, 9422);
INSERT INTO 'dancesrecordingsmap' VALUES (8314, 4064, NULL, 9423);
INSERT INTO 'dancesrecordingsmap' VALUES (8324, 12249, NULL, 9434);
INSERT INTO 'dancesrecordingsmap' VALUES (8325, 9898, NULL, 9435);
INSERT INTO 'dancesrecordingsmap' VALUES (8326, 15277, NULL, 9435);
INSERT INTO 'dancesrecordingsmap' VALUES (8327, 11278, NULL, 9436);
INSERT INTO 'dancesrecordingsmap' VALUES (8328, 15282, NULL, 9436);
INSERT INTO 'dancesrecordingsmap' VALUES (8329, 14654, NULL, 9437);
INSERT INTO 'dancesrecordingsmap' VALUES (8330, 10459, NULL, 9437);
INSERT INTO 'dancesrecordingsmap' VALUES (8332, 15283, NULL, 9439);
INSERT INTO 'dancesrecordingsmap' VALUES (8334, 15285, NULL, 9441);
INSERT INTO 'dancesrecordingsmap' VALUES (8337, 2585, NULL, 9444);
INSERT INTO 'dancesrecordingsmap' VALUES (8338, 7999, NULL, 9445);
INSERT INTO 'dancesrecordingsmap' VALUES (8339, 15019, NULL, 9446);
INSERT INTO 'dancesrecordingsmap' VALUES (8312, 4641, NULL, 9421);
INSERT INTO 'dancesrecordingsmap' VALUES (8341, 15025, NULL, 9448);
INSERT INTO 'dancesrecordingsmap' VALUES (8342, 15026, NULL, 9449);
INSERT INTO 'dancesrecordingsmap' VALUES (8343, 15027, NULL, 9450);
INSERT INTO 'dancesrecordingsmap' VALUES (8344, 7580, NULL, 9451);
INSERT INTO 'dancesrecordingsmap' VALUES (8345, 15028, NULL, 9452);
INSERT INTO 'dancesrecordingsmap' VALUES (8346, 14357, NULL, 9453);
INSERT INTO 'dancesrecordingsmap' VALUES (8347, 5502, NULL, 9454);
INSERT INTO 'dancesrecordingsmap' VALUES (8348, 15030, NULL, 9455);
INSERT INTO 'dancesrecordingsmap' VALUES (8349, 15031, NULL, 9456);
INSERT INTO 'dancesrecordingsmap' VALUES (8352, 14961, NULL, 9459);
INSERT INTO 'dancesrecordingsmap' VALUES (8353, 14962, NULL, 9460);
INSERT INTO 'dancesrecordingsmap' VALUES (8354, 14963, NULL, 9461);
INSERT INTO 'dancesrecordingsmap' VALUES (8355, 14964, NULL, 9462);
INSERT INTO 'dancesrecordingsmap' VALUES (8356, 14965, NULL, 9463);
INSERT INTO 'dancesrecordingsmap' VALUES (8357, 14966, NULL, 9464);
INSERT INTO 'dancesrecordingsmap' VALUES (8358, 14967, NULL, 9465);
INSERT INTO 'dancesrecordingsmap' VALUES (8359, 14968, NULL, 9466);
INSERT INTO 'dancesrecordingsmap' VALUES (8360, 14969, NULL, 9467);
INSERT INTO 'dancesrecordingsmap' VALUES (8306, 10166, NULL, 9385);
INSERT INTO 'dancesrecordingsmap' VALUES (8271, 15049, NULL, 9349);
INSERT INTO 'dancesrecordingsmap' VALUES (8340, 13276, NULL, 9447);
INSERT INTO 'dancesrecordingsmap' VALUES (8034, 13887, NULL, 8834);
INSERT INTO 'dancesrecordingsmap' VALUES (8318, 10458, NULL, 9430);
INSERT INTO 'dancesrecordingsmap' VALUES (8282, 14974, NULL, 9361);
INSERT INTO 'dancesrecordingsmap' VALUES (8270, 15048, NULL, 9348);
INSERT INTO 'dancesrecordingsmap' VALUES (8308, 1834, NULL, 9417);
INSERT INTO 'dancesrecordingsmap' VALUES (8311, 3152, NULL, 9420);
INSERT INTO 'dancesrecordingsmap' VALUES (8275, 15053, NULL, 9353);
INSERT INTO 'dancesrecordingsmap' VALUES (8319, 12892, NULL, 9431);
INSERT INTO 'dancesrecordingsmap' VALUES (8307, 15221, NULL, 9386);
INSERT INTO 'dancesrecordingsmap' VALUES (8278, 11103, NULL, 9357);
INSERT INTO 'dancesrecordingsmap' VALUES (8331, 15279, NULL, 9438);
INSERT INTO 'dancesrecordingsmap' VALUES (8293, 14547, NULL, 9374);
INSERT INTO 'dancesrecordingsmap' VALUES (8018, 3526, NULL, 8818);
INSERT INTO 'dancesrecordingsmap' VALUES (7920, 8162, NULL, 8599);
INSERT INTO 'dancesrecordingsmap' VALUES (8284, 14975, NULL, 9363);
INSERT INTO 'dancesrecordingsmap' VALUES (8303, 14548, NULL, 9382);
INSERT INTO 'dancesrecordingsmap' VALUES (7973, 1931, NULL, 8689);
INSERT INTO 'dancesrecordingsmap' VALUES (8000, 1931, NULL, 8779);
INSERT INTO 'dancesrecordingsmap' VALUES (8006, 5637, NULL, 8794);
INSERT INTO 'dancesrecordingsmap' VALUES (8315, 2250, NULL, 9424);
INSERT INTO 'dancesrecordingsmap' VALUES (8351, 15032, NULL, 9458);
INSERT INTO 'dancesrecordingsmap' VALUES (8350, 8064, NULL, 9457);
INSERT INTO 'dancesrecordingsmap' VALUES (8309, 3561, NULL, 9418);
INSERT INTO 'dancesrecordingsmap' VALUES (8259, 14724, NULL, 9319);
INSERT INTO 'dancesrecordingsmap' VALUES (8335, 15284, NULL, 9442);
INSERT INTO 'dancesrecordingsmap' VALUES (8272, 15051, NULL, 9350);
INSERT INTO 'dancesrecordingsmap' VALUES (8321, 15286, NULL, 9432);
INSERT INTO 'dancesrecordingsmap' VALUES (8296, 15223, NULL, 9375);
INSERT INTO 'dancesrecordingsmap' VALUES (8361, 14970, NULL, 9468);
INSERT INTO 'dancesrecordingsmap' VALUES (8362, 14971, NULL, 9469);
INSERT INTO 'dancesrecordingsmap' VALUES (8364, 7283, NULL, 9471);
INSERT INTO 'dancesrecordingsmap' VALUES (8365, 10589, NULL, 9472);
INSERT INTO 'dancesrecordingsmap' VALUES (8366, 3684, NULL, 9473);
INSERT INTO 'dancesrecordingsmap' VALUES (8367, 584, NULL, 9474);
INSERT INTO 'dancesrecordingsmap' VALUES (8368, 1473, NULL, 9475);
INSERT INTO 'dancesrecordingsmap' VALUES (8369, 4491, NULL, 9476);
INSERT INTO 'dancesrecordingsmap' VALUES (8370, 4102, NULL, 9478);
INSERT INTO 'dancesrecordingsmap' VALUES (8371, 2222, NULL, 9479);
INSERT INTO 'dancesrecordingsmap' VALUES (8372, 10008, NULL, 9481);
INSERT INTO 'dancesrecordingsmap' VALUES (8373, 6592, NULL, 9482);
INSERT INTO 'dancesrecordingsmap' VALUES (8374, 894, NULL, 9483);
INSERT INTO 'dancesrecordingsmap' VALUES (8375, 4239, NULL, 9484);
INSERT INTO 'dancesrecordingsmap' VALUES (8376, 4998, NULL, 9486);
INSERT INTO 'dancesrecordingsmap' VALUES (8377, 9853, NULL, 9487);
INSERT INTO 'dancesrecordingsmap' VALUES (8378, 3027, NULL, 9488);
INSERT INTO 'dancesrecordingsmap' VALUES (8379, 11480, NULL, 9489);
INSERT INTO 'dancesrecordingsmap' VALUES (8380, 5296, NULL, 9490);
INSERT INTO 'dancesrecordingsmap' VALUES (8381, 6791, NULL, 9491);
INSERT INTO 'dancesrecordingsmap' VALUES (8382, 7147, NULL, 9492);
INSERT INTO 'dancesrecordingsmap' VALUES (8383, 8709, NULL, 9493);
INSERT INTO 'dancesrecordingsmap' VALUES (8384, 2604, NULL, 9495);
INSERT INTO 'dancesrecordingsmap' VALUES (8385, 7019, NULL, 9497);
INSERT INTO 'dancesrecordingsmap' VALUES (8386, 9838, NULL, 9498);
INSERT INTO 'dancesrecordingsmap' VALUES (8387, 3129, NULL, 9499);
INSERT INTO 'dancesrecordingsmap' VALUES (8388, 7560, NULL, 2289);
INSERT INTO 'dancesrecordingsmap' VALUES (8389, 2209, NULL, 9335);
INSERT INTO 'dancesrecordingsmap' VALUES (8390, 3659, NULL, 9334);
INSERT INTO 'dancesrecordingsmap' VALUES (8392, 6010, NULL, 9329);
INSERT INTO 'dancesrecordingsmap' VALUES (8393, 2130, NULL, 9332);
INSERT INTO 'dancesrecordingsmap' VALUES (8394, 4203, NULL, 9336);
INSERT INTO 'dancesrecordingsmap' VALUES (8395, 9004, NULL, 9339);
INSERT INTO 'dancesrecordingsmap' VALUES (8396, 2553, NULL, 9337);
INSERT INTO 'dancesrecordingsmap' VALUES (8397, 5080, NULL, 9338);
INSERT INTO 'dancesrecordingsmap' VALUES (8398, 642, NULL, 9340);
INSERT INTO 'dancesrecordingsmap' VALUES (8399, 2556, NULL, 9341);
INSERT INTO 'dancesrecordingsmap' VALUES (8401, 909, NULL, 9343);
INSERT INTO 'dancesrecordingsmap' VALUES (8403, 3027, NULL, 9344);
INSERT INTO 'dancesrecordingsmap' VALUES (8404, 14446, NULL, 8903);
INSERT INTO 'dancesrecordingsmap' VALUES (8405, 15359, NULL, 9500);
INSERT INTO 'dancesrecordingsmap' VALUES (8407, 6043, NULL, 9504);
INSERT INTO 'dancesrecordingsmap' VALUES (8408, 6995, NULL, 9506);
INSERT INTO 'dancesrecordingsmap' VALUES (8409, 6010, NULL, 9509);
INSERT INTO 'dancesrecordingsmap' VALUES (8410, 15360, NULL, 9510);
INSERT INTO 'dancesrecordingsmap' VALUES (8411, 6104, NULL, 9511);
INSERT INTO 'dancesrecordingsmap' VALUES (8412, 3222, NULL, 9512);
INSERT INTO 'dancesrecordingsmap' VALUES (8413, 14533, NULL, 9514);
INSERT INTO 'dancesrecordingsmap' VALUES (8414, 13577, NULL, 9515);
INSERT INTO 'dancesrecordingsmap' VALUES (8415, 1473, NULL, 9516);
INSERT INTO 'dancesrecordingsmap' VALUES (8416, 5308, NULL, 9517);
INSERT INTO 'dancesrecordingsmap' VALUES (8417, 10535, NULL, 9518);
INSERT INTO 'dancesrecordingsmap' VALUES (8418, 1615, NULL, 9519);
INSERT INTO 'dancesrecordingsmap' VALUES (8419, 5713, NULL, 9520);
INSERT INTO 'dancesrecordingsmap' VALUES (8420, 3743, NULL, 9521);
INSERT INTO 'dancesrecordingsmap' VALUES (8421, 4890, NULL, 9522);
INSERT INTO 'dancesrecordingsmap' VALUES (8422, 11769, NULL, 9523);
INSERT INTO 'dancesrecordingsmap' VALUES (8424, 13582, NULL, 9525);
INSERT INTO 'dancesrecordingsmap' VALUES (8425, 4404, NULL, 9526);
INSERT INTO 'dancesrecordingsmap' VALUES (8427, 373, NULL, 9528);
INSERT INTO 'dancesrecordingsmap' VALUES (8428, 2924, NULL, 9529);
INSERT INTO 'dancesrecordingsmap' VALUES (8430, 14713, NULL, 9532);
INSERT INTO 'dancesrecordingsmap' VALUES (8431, 5525, NULL, 9533);
INSERT INTO 'dancesrecordingsmap' VALUES (8432, 5525, NULL, 9534);
INSERT INTO 'dancesrecordingsmap' VALUES (8433, 1782, NULL, 9535);
INSERT INTO 'dancesrecordingsmap' VALUES (8434, 1782, NULL, 9536);
INSERT INTO 'dancesrecordingsmap' VALUES (8435, 2745, NULL, 9537);
INSERT INTO 'dancesrecordingsmap' VALUES (8436, 2745, NULL, 9538);
INSERT INTO 'dancesrecordingsmap' VALUES (8437, 1792, NULL, 9539);
INSERT INTO 'dancesrecordingsmap' VALUES (8438, 1792, NULL, 9540);
INSERT INTO 'dancesrecordingsmap' VALUES (8439, 1562, NULL, 9552);
INSERT INTO 'dancesrecordingsmap' VALUES (8441, 5525, NULL, 9554);
INSERT INTO 'dancesrecordingsmap' VALUES (8443, 4102, NULL, 9556);
INSERT INTO 'dancesrecordingsmap' VALUES (8444, 4032, NULL, 9557);
INSERT INTO 'dancesrecordingsmap' VALUES (8445, 1792, NULL, 9558);
INSERT INTO 'dancesrecordingsmap' VALUES (8447, 14820, NULL, 9566);
INSERT INTO 'dancesrecordingsmap' VALUES (8448, 14816, NULL, 9567);
INSERT INTO 'dancesrecordingsmap' VALUES (8451, 14817, NULL, 9572);
INSERT INTO 'dancesrecordingsmap' VALUES (8452, 14819, NULL, 9573);
INSERT INTO 'dancesrecordingsmap' VALUES (8300, 15222, NULL, 9379);
INSERT INTO 'dancesrecordingsmap' VALUES (8406, 9803, NULL, 9501);
INSERT INTO 'dancesrecordingsmap' VALUES (8423, 1829, NULL, 9524);
INSERT INTO 'dancesrecordingsmap' VALUES (8323, 15274, NULL, 9433);
INSERT INTO 'dancesrecordingsmap' VALUES (8391, 1087, NULL, 9333);
INSERT INTO 'dancesrecordingsmap' VALUES (8363, 14972, NULL, 9470);
INSERT INTO 'dancesrecordingsmap' VALUES (8453, 14814, NULL, 9574);
INSERT INTO 'dancesrecordingsmap' VALUES (8455, 1881, NULL, 9580);
INSERT INTO 'dancesrecordingsmap' VALUES (8456, 3802, NULL, 9584);
INSERT INTO 'dancesrecordingsmap' VALUES (8457, 15362, NULL, 6898);
INSERT INTO 'dancesrecordingsmap' VALUES (8450, 14818, NULL, 9570);
INSERT INTO 'dancesrecordingsmap' VALUES (8462, 15368, NULL, 5320);
INSERT INTO 'dancesrecordingsmap' VALUES (8463, 15369, NULL, 5712);
INSERT INTO 'dancesrecordingsmap' VALUES (8464, 15371, NULL, 7390);
INSERT INTO 'dancesrecordingsmap' VALUES (8466, 6048, NULL, 9601);
INSERT INTO 'dancesrecordingsmap' VALUES (8467, 14424, NULL, 9605);
INSERT INTO 'dancesrecordingsmap' VALUES (8468, 1927, NULL, 9608);
INSERT INTO 'dancesrecordingsmap' VALUES (8469, 2983, NULL, 9615);
INSERT INTO 'dancesrecordingsmap' VALUES (8470, 4782, NULL, 9618);
INSERT INTO 'dancesrecordingsmap' VALUES (8471, 3619, NULL, 9619);
INSERT INTO 'dancesrecordingsmap' VALUES (8473, 2745, NULL, 9625);
INSERT INTO 'dancesrecordingsmap' VALUES (8474, 3528, NULL, 9626);
INSERT INTO 'dancesrecordingsmap' VALUES (8476, 15415, NULL, 9505);
INSERT INTO 'dancesrecordingsmap' VALUES (8477, 15414, NULL, 9503);
INSERT INTO 'dancesrecordingsmap' VALUES (8478, 15416, NULL, 7322);
INSERT INTO 'dancesrecordingsmap' VALUES (8479, 15417, NULL, 7318);
INSERT INTO 'dancesrecordingsmap' VALUES (8480, 15418, NULL, 7320);
INSERT INTO 'dancesrecordingsmap' VALUES (8481, 15420, NULL, 7312);
INSERT INTO 'dancesrecordingsmap' VALUES (8483, 153, NULL, 9636);
INSERT INTO 'dancesrecordingsmap' VALUES (8484, 1624, NULL, 9639);
INSERT INTO 'dancesrecordingsmap' VALUES (8485, 3506, NULL, 9640);
INSERT INTO 'dancesrecordingsmap' VALUES (8486, 4014, NULL, 9638);
INSERT INTO 'dancesrecordingsmap' VALUES (8487, 3152, NULL, 9643);
INSERT INTO 'dancesrecordingsmap' VALUES (8488, 8142, NULL, 9644);
INSERT INTO 'dancesrecordingsmap' VALUES (8489, 5637, NULL, 9645);
INSERT INTO 'dancesrecordingsmap' VALUES (8490, 934, NULL, 9646);
INSERT INTO 'dancesrecordingsmap' VALUES (8491, 5637, NULL, 9647);
INSERT INTO 'dancesrecordingsmap' VALUES (8492, 3342, NULL, 9650);
INSERT INTO 'dancesrecordingsmap' VALUES (8493, 4293, NULL, 9651);
INSERT INTO 'dancesrecordingsmap' VALUES (8494, 1020, NULL, 9652);
INSERT INTO 'dancesrecordingsmap' VALUES (8495, 352, NULL, 9653);
INSERT INTO 'dancesrecordingsmap' VALUES (8497, 742, NULL, 9655);
INSERT INTO 'dancesrecordingsmap' VALUES (8498, 1834, NULL, 9656);
INSERT INTO 'dancesrecordingsmap' VALUES (8499, 1927, NULL, 9657);
INSERT INTO 'dancesrecordingsmap' VALUES (8500, 1501, NULL, 9658);
INSERT INTO 'dancesrecordingsmap' VALUES (8501, 2745, NULL, 9659);
INSERT INTO 'dancesrecordingsmap' VALUES (8502, 642, NULL, 9660);
INSERT INTO 'dancesrecordingsmap' VALUES (8503, 6711, NULL, 9661);
INSERT INTO 'dancesrecordingsmap' VALUES (8504, 1864, NULL, 9662);
INSERT INTO 'dancesrecordingsmap' VALUES (8505, 4014, NULL, 9663);
INSERT INTO 'dancesrecordingsmap' VALUES (8506, 223, NULL, 9665);
INSERT INTO 'dancesrecordingsmap' VALUES (8508, 15432, NULL, 9671);
INSERT INTO 'dancesrecordingsmap' VALUES (8510, 15434, NULL, 9673);
INSERT INTO 'dancesrecordingsmap' VALUES (8513, 15436, NULL, 9675);
INSERT INTO 'dancesrecordingsmap' VALUES (8515, 15438, NULL, 9677);
INSERT INTO 'dancesrecordingsmap' VALUES (8516, 15439, NULL, 9678);
INSERT INTO 'dancesrecordingsmap' VALUES (8517, 15440, NULL, 9679);
INSERT INTO 'dancesrecordingsmap' VALUES (8518, 15441, NULL, 9680);
INSERT INTO 'dancesrecordingsmap' VALUES (8519, 15442, NULL, 9681);
INSERT INTO 'dancesrecordingsmap' VALUES (8521, 7874, NULL, 1974);
INSERT INTO 'dancesrecordingsmap' VALUES (8522, 12397, NULL, 5617);
INSERT INTO 'dancesrecordingsmap' VALUES (8524, 15481, NULL, 462);
INSERT INTO 'dancesrecordingsmap' VALUES (8525, 15483, NULL, 9092);
INSERT INTO 'dancesrecordingsmap' VALUES (8526, 15484, NULL, 113);
INSERT INTO 'dancesrecordingsmap' VALUES (8527, 15494, NULL, 5751);
INSERT INTO 'dancesrecordingsmap' VALUES (8528, 937, NULL, 4072);
INSERT INTO 'dancesrecordingsmap' VALUES (8529, 13766, NULL, 6900);
INSERT INTO 'dancesrecordingsmap' VALUES (8530, 12792, NULL, 6867);
INSERT INTO 'dancesrecordingsmap' VALUES (8531, 4782, NULL, 9689);
INSERT INTO 'dancesrecordingsmap' VALUES (8532, 15401, NULL, 9690);
INSERT INTO 'dancesrecordingsmap' VALUES (8533, 14548, NULL, 9691);
INSERT INTO 'dancesrecordingsmap' VALUES (8534, 15402, NULL, 9692);
INSERT INTO 'dancesrecordingsmap' VALUES (8535, 14688, NULL, 9693);
INSERT INTO 'dancesrecordingsmap' VALUES (8536, 13163, NULL, 9694);
INSERT INTO 'dancesrecordingsmap' VALUES (8537, 13847, NULL, 9695);
INSERT INTO 'dancesrecordingsmap' VALUES (8538, 14712, NULL, 9696);
INSERT INTO 'dancesrecordingsmap' VALUES (8539, 9770, NULL, 9697);
INSERT INTO 'dancesrecordingsmap' VALUES (8540, 13766, NULL, 9698);
INSERT INTO 'dancesrecordingsmap' VALUES (8541, 15403, NULL, 9699);
INSERT INTO 'dancesrecordingsmap' VALUES (8542, 13544, NULL, 9700);
INSERT INTO 'dancesrecordingsmap' VALUES (8543, 14649, NULL, 9701);
INSERT INTO 'dancesrecordingsmap' VALUES (8544, 12124, NULL, 9702);
INSERT INTO 'dancesrecordingsmap' VALUES (8512, 15435, NULL, 9674);
INSERT INTO 'dancesrecordingsmap' VALUES (8507, 15431, NULL, 9670);
INSERT INTO 'dancesrecordingsmap' VALUES (8482, 12699, NULL, 902);
INSERT INTO 'dancesrecordingsmap' VALUES (8449, 14815, NULL, 9569);
INSERT INTO 'dancesrecordingsmap' VALUES (8465, 15372, NULL, 9440);
INSERT INTO 'dancesrecordingsmap' VALUES (8523, 15482, NULL, 1268);
INSERT INTO 'dancesrecordingsmap' VALUES (8520, 15443, NULL, 9682);
INSERT INTO 'dancesrecordingsmap' VALUES (8460, 15365, NULL, 2424);
INSERT INTO 'dancesrecordingsmap' VALUES (8442, 2745, NULL, 9555);
INSERT INTO 'dancesrecordingsmap' VALUES (8546, 15404, NULL, 9704);
INSERT INTO 'dancesrecordingsmap' VALUES (8514, 15437, NULL, 9676);
INSERT INTO 'dancesrecordingsmap' VALUES (8545, 14138, NULL, 9703);
INSERT INTO 'dancesrecordingsmap' VALUES (8440, 1931, NULL, 9553);
INSERT INTO 'dancesrecordingsmap' VALUES (8496, 3561, NULL, 9654);
INSERT INTO 'dancesrecordingsmap' VALUES (8446, 14813, NULL, 9565);
INSERT INTO 'dancesrecordingsmap' VALUES (8426, 10787, NULL, 9527);
INSERT INTO 'dancesrecordingsmap' VALUES (8547, 8526, NULL, 9705);
INSERT INTO 'dancesrecordingsmap' VALUES (8550, 1426, NULL, 9708);
INSERT INTO 'dancesrecordingsmap' VALUES (8551, 13727, NULL, 9709);
INSERT INTO 'dancesrecordingsmap' VALUES (8552, 7375, NULL, 9710);
INSERT INTO 'dancesrecordingsmap' VALUES (8553, 8482, NULL, 9711);
INSERT INTO 'dancesrecordingsmap' VALUES (8554, 14025, NULL, 9712);
INSERT INTO 'dancesrecordingsmap' VALUES (8555, 3397, NULL, 9713);
INSERT INTO 'dancesrecordingsmap' VALUES (8556, 15177, NULL, 9714);
INSERT INTO 'dancesrecordingsmap' VALUES (8557, 7351, NULL, 9715);
INSERT INTO 'dancesrecordingsmap' VALUES (8558, 695, NULL, 9716);
INSERT INTO 'dancesrecordingsmap' VALUES (8559, 15406, NULL, 9717);
INSERT INTO 'dancesrecordingsmap' VALUES (8560, 14552, NULL, 9718);
INSERT INTO 'dancesrecordingsmap' VALUES (8561, 306, NULL, 9719);
INSERT INTO 'dancesrecordingsmap' VALUES (8563, 950, NULL, 9721);
INSERT INTO 'dancesrecordingsmap' VALUES (8564, 1077, NULL, 9722);
INSERT INTO 'dancesrecordingsmap' VALUES (8566, 2383, NULL, 9724);
INSERT INTO 'dancesrecordingsmap' VALUES (8567, 2887, NULL, 9725);
INSERT INTO 'dancesrecordingsmap' VALUES (8569, 3320, NULL, 9727);
INSERT INTO 'dancesrecordingsmap' VALUES (8570, 3325, NULL, 9728);
INSERT INTO 'dancesrecordingsmap' VALUES (8571, 4863, NULL, 9729);
INSERT INTO 'dancesrecordingsmap' VALUES (8572, 4873, NULL, 9730);
INSERT INTO 'dancesrecordingsmap' VALUES (8573, 6188, NULL, 9731);
INSERT INTO 'dancesrecordingsmap' VALUES (8574, 7065, NULL, 9732);
INSERT INTO 'dancesrecordingsmap' VALUES (8575, 6995, NULL, 9733);
INSERT INTO 'dancesrecordingsmap' VALUES (8576, 14365, NULL, 886);
INSERT INTO 'dancesrecordingsmap' VALUES (8578, 15591, NULL, 3445);
INSERT INTO 'dancesrecordingsmap' VALUES (8580, 5532, NULL, 9328);
INSERT INTO 'dancesrecordingsmap' VALUES (8581, 7546, NULL, 9735);
INSERT INTO 'dancesrecordingsmap' VALUES (8582, 1562, NULL, 9736);
INSERT INTO 'dancesrecordingsmap' VALUES (8583, 15429, NULL, 9738);
INSERT INTO 'dancesrecordingsmap' VALUES (8585, 7552, NULL, 9740);
INSERT INTO 'dancesrecordingsmap' VALUES (8586, 5330, NULL, 9741);
INSERT INTO 'dancesrecordingsmap' VALUES (8587, 15428, NULL, 9742);
INSERT INTO 'dancesrecordingsmap' VALUES (8588, 7553, NULL, 9743);
INSERT INTO 'dancesrecordingsmap' VALUES (8589, 5525, NULL, 9744);
INSERT INTO 'dancesrecordingsmap' VALUES (8590, 8143, NULL, 9745);
INSERT INTO 'dancesrecordingsmap' VALUES (8591, 15427, NULL, 9746);
INSERT INTO 'dancesrecordingsmap' VALUES (8593, 7554, NULL, 9748);
INSERT INTO 'dancesrecordingsmap' VALUES (8594, 6359, NULL, 9749);
INSERT INTO 'dancesrecordingsmap' VALUES (371, 13595, 433, 504);
INSERT INTO 'dancesrecordingsmap' VALUES (8595, 15639, NULL, 9751);
INSERT INTO 'dancesrecordingsmap' VALUES (8596, 15640, NULL, 9752);
INSERT INTO 'dancesrecordingsmap' VALUES (8597, 15641, NULL, 9753);
INSERT INTO 'dancesrecordingsmap' VALUES (8598, 15642, NULL, 9754);
INSERT INTO 'dancesrecordingsmap' VALUES (8599, 15643, NULL, 9755);
INSERT INTO 'dancesrecordingsmap' VALUES (8600, 15645, NULL, 9756);
INSERT INTO 'dancesrecordingsmap' VALUES (8601, 15644, NULL, 9757);
INSERT INTO 'dancesrecordingsmap' VALUES (8602, 15646, NULL, 9758);
INSERT INTO 'dancesrecordingsmap' VALUES (8603, 15647, NULL, 9759);
INSERT INTO 'dancesrecordingsmap' VALUES (8604, 15648, NULL, 9760);
INSERT INTO 'dancesrecordingsmap' VALUES (8605, 15649, NULL, 9761);
INSERT INTO 'dancesrecordingsmap' VALUES (8606, 15650, NULL, 9762);
INSERT INTO 'dancesrecordingsmap' VALUES (8607, 3057, NULL, 9763);
INSERT INTO 'dancesrecordingsmap' VALUES (8608, 15653, NULL, 4487);
INSERT INTO 'dancesrecordingsmap' VALUES (8612, 13884, NULL, 1411);
INSERT INTO 'dancesrecordingsmap' VALUES (8613, 15665, NULL, 6293);
INSERT INTO 'dancesrecordingsmap' VALUES (8614, 15666, NULL, 6936);
INSERT INTO 'dancesrecordingsmap' VALUES (8615, 15664, NULL, 9321);
INSERT INTO 'dancesrecordingsmap' VALUES (8616, 15663, NULL, 6664);
INSERT INTO 'dancesrecordingsmap' VALUES (8617, 15662, NULL, 2206);
INSERT INTO 'dancesrecordingsmap' VALUES (8618, 15661, NULL, 5138);
INSERT INTO 'dancesrecordingsmap' VALUES (8619, 15660, NULL, 853);
INSERT INTO 'dancesrecordingsmap' VALUES (8621, 15668, NULL, 489);
INSERT INTO 'dancesrecordingsmap' VALUES (9130, 17560, NULL, 10194);
INSERT INTO 'dancesrecordingsmap' VALUES (8624, 3067, NULL, 1338);
INSERT INTO 'dancesrecordingsmap' VALUES (8625, 15672, NULL, 4059);
INSERT INTO 'dancesrecordingsmap' VALUES (9134, 17566, NULL, 10198);
INSERT INTO 'dancesrecordingsmap' VALUES (8629, 15677, NULL, 5332);
INSERT INTO 'dancesrecordingsmap' VALUES (8630, 11587, NULL, 3501);
INSERT INTO 'dancesrecordingsmap' VALUES (8632, 15686, NULL, 155);
INSERT INTO 'dancesrecordingsmap' VALUES (8633, 15035, NULL, 9766);
INSERT INTO 'dancesrecordingsmap' VALUES (8634, 15036, NULL, 9767);
INSERT INTO 'dancesrecordingsmap' VALUES (8636, 14352, NULL, 9769);
INSERT INTO 'dancesrecordingsmap' VALUES (8635, 15038, NULL, 9768);
INSERT INTO 'dancesrecordingsmap' VALUES (8637, 15037, NULL, 9770);
INSERT INTO 'dancesrecordingsmap' VALUES (8638, 15040, NULL, 9771);
INSERT INTO 'dancesrecordingsmap' VALUES (8639, 14711, NULL, 9772);
INSERT INTO 'dancesrecordingsmap' VALUES (8640, 15042, NULL, 9774);
INSERT INTO 'dancesrecordingsmap' VALUES (8641, 15043, NULL, 9775);
INSERT INTO 'dancesrecordingsmap' VALUES (8642, 6210, NULL, 9776);
INSERT INTO 'dancesrecordingsmap' VALUES (8643, 15033, NULL, 9764);
INSERT INTO 'dancesrecordingsmap' VALUES (8644, 15034, NULL, 9765);
INSERT INTO 'dancesrecordingsmap' VALUES (8646, 7316, NULL, 4624);
INSERT INTO 'dancesrecordingsmap' VALUES (8511, 14443, NULL, 8902);
INSERT INTO 'dancesrecordingsmap' VALUES (8454, 14819, NULL, 9575);
INSERT INTO 'dancesrecordingsmap' VALUES (8472, 648, NULL, 9620);
INSERT INTO 'dancesrecordingsmap' VALUES (8577, 15576, NULL, 5465);
INSERT INTO 'dancesrecordingsmap' VALUES (8459, 15364, NULL, 5719);
INSERT INTO 'dancesrecordingsmap' VALUES (8458, 12517, NULL, 5441);
INSERT INTO 'dancesrecordingsmap' VALUES (8475, 909, NULL, 9630);
INSERT INTO 'dancesrecordingsmap' VALUES (8562, 324, 428, 9720);
INSERT INTO 'dancesrecordingsmap' VALUES (299, 5480, NULL, 402);
INSERT INTO 'dancesrecordingsmap' VALUES (8011, 2250, NULL, 8804);
INSERT INTO 'dancesrecordingsmap' VALUES (7475, 1777, NULL, 7995);
INSERT INTO 'dancesrecordingsmap' VALUES (8647, 15708, NULL, 7995);
INSERT INTO 'dancesrecordingsmap' VALUES (8648, 15708, NULL, 8090);
INSERT INTO 'dancesrecordingsmap' VALUES (8674, 6756, NULL, 9781);
INSERT INTO 'dancesrecordingsmap' VALUES (6887, 13353, NULL, 7042);
INSERT INTO 'dancesrecordingsmap' VALUES (8626, 15673, NULL, 7042);
INSERT INTO 'dancesrecordingsmap' VALUES (8649, 15710, NULL, 7042);
INSERT INTO 'dancesrecordingsmap' VALUES (4901, 11478, NULL, 5588);
INSERT INTO 'dancesrecordingsmap' VALUES (8650, 15684, NULL, 5588);
INSERT INTO 'dancesrecordingsmap' VALUES (7116, 12089, NULL, 7382);
INSERT INTO 'dancesrecordingsmap' VALUES (8651, 6709, NULL, 9641);
INSERT INTO 'dancesrecordingsmap' VALUES (8549, 15411, NULL, 9707);
INSERT INTO 'dancesrecordingsmap' VALUES (1170, 2979, NULL, 1419);
INSERT INTO 'dancesrecordingsmap' VALUES (8683, 2250, NULL, 9824);
INSERT INTO 'dancesrecordingsmap' VALUES (4118, 9746, NULL, 1512);
INSERT INTO 'dancesrecordingsmap' VALUES (1491, 8138, NULL, 1831);
INSERT INTO 'dancesrecordingsmap' VALUES (8654, 15959, NULL, 1831);
INSERT INTO 'dancesrecordingsmap' VALUES (8655, 14962, NULL, 6419);
INSERT INTO 'dancesrecordingsmap' VALUES (8657, 16055, NULL, 9385);
INSERT INTO 'dancesrecordingsmap' VALUES (8658, 16068, NULL, 5589);
INSERT INTO 'dancesrecordingsmap' VALUES (1314, 3710, NULL, 1620);
INSERT INTO 'dancesrecordingsmap' VALUES (7738, 6395, NULL, 1620);
INSERT INTO 'dancesrecordingsmap' VALUES (8660, 16110, NULL, 1620);
INSERT INTO 'dancesrecordingsmap' VALUES (8579, 15593, NULL, 307);
INSERT INTO 'dancesrecordingsmap' VALUES (4353, 8773, NULL, 5318);
INSERT INTO 'dancesrecordingsmap' VALUES (6165, 12944, NULL, 5318);
INSERT INTO 'dancesrecordingsmap' VALUES (8610, 15658, NULL, 5318);
INSERT INTO 'dancesrecordingsmap' VALUES (8623, 15670, NULL, 5318);
INSERT INTO 'dancesrecordingsmap' VALUES (8662, 16110, NULL, 5318);
INSERT INTO 'dancesrecordingsmap' VALUES (8677, 10102, NULL, 9784);
INSERT INTO 'dancesrecordingsmap' VALUES (8675, 4928, NULL, 9782);
INSERT INTO 'dancesrecordingsmap' VALUES (8664, 6966, NULL, 6358);
INSERT INTO 'dancesrecordingsmap' VALUES (8665, 6010, NULL, 6324);
INSERT INTO 'dancesrecordingsmap' VALUES (6081, 5964, NULL, 6311);
INSERT INTO 'dancesrecordingsmap' VALUES (8666, 11113, NULL, 387);
INSERT INTO 'dancesrecordingsmap' VALUES (8667, 12450, NULL, 8697);
INSERT INTO 'dancesrecordingsmap' VALUES (406, 6995, NULL, 548);
INSERT INTO 'dancesrecordingsmap' VALUES (6068, 1330, NULL, 548);
INSERT INTO 'dancesrecordingsmap' VALUES (8668, 16177, NULL, 548);
INSERT INTO 'dancesrecordingsmap' VALUES (8669, 16221, NULL, 7453);
INSERT INTO 'dancesrecordingsmap' VALUES (8670, 16223, NULL, 5726);
INSERT INTO 'dancesrecordingsmap' VALUES (8671, 9836, NULL, 9777);
INSERT INTO 'dancesrecordingsmap' VALUES (8672, 5006, NULL, 9778);
INSERT INTO 'dancesrecordingsmap' VALUES (3206, 4928, NULL, 4055);
INSERT INTO 'dancesrecordingsmap' VALUES (8678, 3326, NULL, 9818);
INSERT INTO 'dancesrecordingsmap' VALUES (8679, 6091, NULL, 9819);
INSERT INTO 'dancesrecordingsmap' VALUES (8680, 16459, NULL, 9821);
INSERT INTO 'dancesrecordingsmap' VALUES (8681, 674, NULL, 9822);
INSERT INTO 'dancesrecordingsmap' VALUES (8682, 13588, NULL, 9823);
INSERT INTO 'dancesrecordingsmap' VALUES (8684, 1473, NULL, 9825);
INSERT INTO 'dancesrecordingsmap' VALUES (8685, 13621, NULL, 9826);
INSERT INTO 'dancesrecordingsmap' VALUES (8686, 4968, NULL, 9827);
INSERT INTO 'dancesrecordingsmap' VALUES (8687, 12941, NULL, 9828);
INSERT INTO 'dancesrecordingsmap' VALUES (8688, 14903, NULL, 9829);
INSERT INTO 'dancesrecordingsmap' VALUES (2808, 5800, NULL, 3467);
INSERT INTO 'dancesrecordingsmap' VALUES (8592, 1931, NULL, 9747);
INSERT INTO 'dancesrecordingsmap' VALUES (3809, 2979, NULL, 4880);
INSERT INTO 'dancesrecordingsmap' VALUES (8689, 1087, NULL, 9780);
INSERT INTO 'dancesrecordingsmap' VALUES (8690, 16522, NULL, 9830);
INSERT INTO 'dancesrecordingsmap' VALUES (8691, 16523, NULL, 9831);
INSERT INTO 'dancesrecordingsmap' VALUES (8693, 16525, NULL, 9833);
INSERT INTO 'dancesrecordingsmap' VALUES (8694, 16526, NULL, 9834);
INSERT INTO 'dancesrecordingsmap' VALUES (8695, 16527, NULL, 9836);
INSERT INTO 'dancesrecordingsmap' VALUES (8696, 13648, NULL, 9837);
INSERT INTO 'dancesrecordingsmap' VALUES (8697, 16533, NULL, 9838);
INSERT INTO 'dancesrecordingsmap' VALUES (8698, 16534, NULL, 9839);
INSERT INTO 'dancesrecordingsmap' VALUES (8699, 16535, NULL, 9840);
INSERT INTO 'dancesrecordingsmap' VALUES (8700, 16536, NULL, 9841);
INSERT INTO 'dancesrecordingsmap' VALUES (8701, 16537, NULL, 9842);
INSERT INTO 'dancesrecordingsmap' VALUES (8702, 2979, NULL, 9844);
INSERT INTO 'dancesrecordingsmap' VALUES (8703, 819, NULL, 9845);
INSERT INTO 'dancesrecordingsmap' VALUES (8704, 650, NULL, 9846);
INSERT INTO 'dancesrecordingsmap' VALUES (8673, 159, NULL, 9779);
INSERT INTO 'dancesrecordingsmap' VALUES (4484, 8138, NULL, 5438);
INSERT INTO 'dancesrecordingsmap' VALUES (8568, 3080, NULL, 9726);
INSERT INTO 'dancesrecordingsmap' VALUES (8692, 16524, NULL, 9832);
INSERT INTO 'dancesrecordingsmap' VALUES (8548, 15405, NULL, 9706);
INSERT INTO 'dancesrecordingsmap' VALUES (8611, 4075, NULL, 1523);
INSERT INTO 'dancesrecordingsmap' VALUES (8705, 16687, NULL, 9847);
INSERT INTO 'dancesrecordingsmap' VALUES (8706, 16688, NULL, 9848);
INSERT INTO 'dancesrecordingsmap' VALUES (8707, 16689, NULL, 9849);
INSERT INTO 'dancesrecordingsmap' VALUES (8609, 15656, NULL, 411);
INSERT INTO 'dancesrecordingsmap' VALUES (8584, 8162, NULL, 9739);
INSERT INTO 'dancesrecordingsmap' VALUES (8400, 7149, NULL, 9342);
INSERT INTO 'dancesrecordingsmap' VALUES (8631, 15685, NULL, 5492);
INSERT INTO 'dancesrecordingsmap' VALUES (3880, 6959, NULL, 4881);
INSERT INTO 'dancesrecordingsmap' VALUES (6088, 3231, NULL, 6318);
INSERT INTO 'dancesrecordingsmap' VALUES (8708, 16690, NULL, 9850);
INSERT INTO 'dancesrecordingsmap' VALUES (8711, 16693, NULL, 9852);
INSERT INTO 'dancesrecordingsmap' VALUES (8712, 16694, NULL, 9853);
INSERT INTO 'dancesrecordingsmap' VALUES (8713, 16695, NULL, 9854);
INSERT INTO 'dancesrecordingsmap' VALUES (8715, 16697, NULL, 9856);
INSERT INTO 'dancesrecordingsmap' VALUES (8709, 16691, NULL, 9851);
INSERT INTO 'dancesrecordingsmap' VALUES (8710, 16692, NULL, 9851);
INSERT INTO 'dancesrecordingsmap' VALUES (3987, 5100, NULL, 5030);
INSERT INTO 'dancesrecordingsmap' VALUES (8717, 11296, NULL, 5030);
INSERT INTO 'dancesrecordingsmap' VALUES (6605, 3854, NULL, 6758);
INSERT INTO 'dancesrecordingsmap' VALUES (8718, 16736, NULL, 6758);
INSERT INTO 'dancesrecordingsmap' VALUES (8, 335, NULL, 11);
INSERT INTO 'dancesrecordingsmap' VALUES (8719, 16737, NULL, 11);
INSERT INTO 'dancesrecordingsmap' VALUES (3736, 3396, NULL, 1448);
INSERT INTO 'dancesrecordingsmap' VALUES (8720, 2769, NULL, 1448);
INSERT INTO 'dancesrecordingsmap' VALUES (1141, 2868, NULL, 1403);
INSERT INTO 'dancesrecordingsmap' VALUES (3191, 8784, NULL, 1403);
INSERT INTO 'dancesrecordingsmap' VALUES (5809, 9073, NULL, 1403);
INSERT INTO 'dancesrecordingsmap' VALUES (5841, 12666, NULL, 1403);
INSERT INTO 'dancesrecordingsmap' VALUES (8721, 2769, NULL, 1403);
INSERT INTO 'dancesrecordingsmap' VALUES (731, 3941, 310, 902);
INSERT INTO 'dancesrecordingsmap' VALUES (8722, 1280, NULL, 9858);
INSERT INTO 'dancesrecordingsmap' VALUES (3312, 1521, NULL, 1716);
INSERT INTO 'dancesrecordingsmap' VALUES (2945, 20, NULL, 1984);
INSERT INTO 'dancesrecordingsmap' VALUES (2946, 4494, NULL, 1984);
INSERT INTO 'dancesrecordingsmap' VALUES (2947, 7681, NULL, 1984);
INSERT INTO 'dancesrecordingsmap' VALUES (8724, 15326, NULL, 5563);
INSERT INTO 'dancesrecordingsmap' VALUES (8725, 11461, NULL, 7578);
INSERT INTO 'dancesrecordingsmap' VALUES (8726, 8335, NULL, 1453);
INSERT INTO 'dancesrecordingsmap' VALUES (8727, 11842, NULL, 5860);
INSERT INTO 'dancesrecordingsmap' VALUES (3495, 8738, NULL, 4461);
INSERT INTO 'dancesrecordingsmap' VALUES (5207, 11529, NULL, 5812);
INSERT INTO 'dancesrecordingsmap' VALUES (8728, 16872, NULL, 5812);
INSERT INTO 'dancesrecordingsmap' VALUES (8729, 16891, NULL, 5021);
INSERT INTO 'dancesrecordingsmap' VALUES (8730, 16724, NULL, 9860);
INSERT INTO 'dancesrecordingsmap' VALUES (8732, 16726, NULL, 9861);
INSERT INTO 'dancesrecordingsmap' VALUES (8735, 12907, NULL, 9865);
INSERT INTO 'dancesrecordingsmap' VALUES (8737, 16730, NULL, 9867);
INSERT INTO 'dancesrecordingsmap' VALUES (8738, 16725, NULL, 9868);
INSERT INTO 'dancesrecordingsmap' VALUES (4638, 11050, NULL, 3441);
INSERT INTO 'dancesrecordingsmap' VALUES (8740, 15607, NULL, 3441);
INSERT INTO 'dancesrecordingsmap' VALUES (8741, 16060, NULL, 1618);
INSERT INTO 'dancesrecordingsmap' VALUES (8742, 3776, NULL, 2949);
INSERT INTO 'dancesrecordingsmap' VALUES (8743, 1981, NULL, 3143);
INSERT INTO 'dancesrecordingsmap' VALUES (8746, 523, NULL, 467);
INSERT INTO 'dancesrecordingsmap' VALUES (2032, 5262, NULL, 2525);
INSERT INTO 'dancesrecordingsmap' VALUES (5549, 4029, NULL, 2525);
INSERT INTO 'dancesrecordingsmap' VALUES (8747, 523, NULL, 2525);
INSERT INTO 'dancesrecordingsmap' VALUES (2584, 2056, NULL, 3251);
INSERT INTO 'dancesrecordingsmap' VALUES (8753, 16951, NULL, 1674);
INSERT INTO 'dancesrecordingsmap' VALUES (8731, 15341, NULL, 9864);
INSERT INTO 'dancesrecordingsmap' VALUES (8739, 6394, NULL, 9869);
INSERT INTO 'dancesrecordingsmap' VALUES (8754, 15740, NULL, 6958);
INSERT INTO 'dancesrecordingsmap' VALUES (8755, 6653, NULL, 1130);
INSERT INTO 'dancesrecordingsmap' VALUES (2023, 2918, NULL, 2495);
INSERT INTO 'dancesrecordingsmap' VALUES (5507, 6016, NULL, 2495);
INSERT INTO 'dancesrecordingsmap' VALUES (8756, 5536, NULL, 242);
INSERT INTO 'dancesrecordingsmap' VALUES (8757, 6220, NULL, 1516);
INSERT INTO 'dancesrecordingsmap' VALUES (8758, 6715, NULL, 89);
INSERT INTO 'dancesrecordingsmap' VALUES (8824, 15022, NULL, 9918);
INSERT INTO 'dancesrecordingsmap' VALUES (8766, 389, NULL, 9875);
INSERT INTO 'dancesrecordingsmap' VALUES (8768, 1367, NULL, 9880);
INSERT INTO 'dancesrecordingsmap' VALUES (8714, 16696, NULL, 9855);
INSERT INTO 'dancesrecordingsmap' VALUES (8770, 4270, NULL, 9882);
INSERT INTO 'dancesrecordingsmap' VALUES (8771, 5358, NULL, 9883);
INSERT INTO 'dancesrecordingsmap' VALUES (8774, 17227, NULL, 6935);
INSERT INTO 'dancesrecordingsmap' VALUES (6185, 12968, NULL, 6418);
INSERT INTO 'dancesrecordingsmap' VALUES (8775, 17226, NULL, 6418);
INSERT INTO 'dancesrecordingsmap' VALUES (8777, 17224, NULL, 7011);
INSERT INTO 'dancesrecordingsmap' VALUES (8778, 17220, NULL, 7010);
INSERT INTO 'dancesrecordingsmap' VALUES (8779, 17221, NULL, 7006);
INSERT INTO 'dancesrecordingsmap' VALUES (8780, 17222, NULL, 510);
INSERT INTO 'dancesrecordingsmap' VALUES (8101, 1280, NULL, 8940);
INSERT INTO 'dancesrecordingsmap' VALUES (8781, 17223, NULL, 8940);
INSERT INTO 'dancesrecordingsmap' VALUES (8782, 17231, NULL, 449);
INSERT INTO 'dancesrecordingsmap' VALUES (8783, 17237, NULL, 6381);
INSERT INTO 'dancesrecordingsmap' VALUES (8784, 17236, NULL, 6122);
INSERT INTO 'dancesrecordingsmap' VALUES (8622, 15669, NULL, 6219);
INSERT INTO 'dancesrecordingsmap' VALUES (8716, 13276, NULL, 6219);
INSERT INTO 'dancesrecordingsmap' VALUES (8785, 17235, NULL, 6219);
INSERT INTO 'dancesrecordingsmap' VALUES (8786, 17238, NULL, 6115);
INSERT INTO 'dancesrecordingsmap' VALUES (8787, 17240, NULL, 7574);
INSERT INTO 'dancesrecordingsmap' VALUES (8818, 17388, NULL, 7074);
INSERT INTO 'dancesrecordingsmap' VALUES (8752, 16947, NULL, 1446);
INSERT INTO 'dancesrecordingsmap' VALUES (8565, 2276, NULL, 9723);
INSERT INTO 'dancesrecordingsmap' VALUES (8628, 15675, NULL, 5655);
INSERT INTO 'dancesrecordingsmap' VALUES (8762, 17068, NULL, 1346);
INSERT INTO 'dancesrecordingsmap' VALUES (1798, 7028, NULL, 2244);
INSERT INTO 'dancesrecordingsmap' VALUES (8788, 17241, NULL, 9430);
INSERT INTO 'dancesrecordingsmap' VALUES (4236, 9817, NULL, 5217);
INSERT INTO 'dancesrecordingsmap' VALUES (8789, 17244, NULL, 5217);
INSERT INTO 'dancesrecordingsmap' VALUES (8790, 17245, NULL, 5653);
INSERT INTO 'dancesrecordingsmap' VALUES (5113, 9635, NULL, 5722);
INSERT INTO 'dancesrecordingsmap' VALUES (8772, 4196, NULL, 9885);
INSERT INTO 'dancesrecordingsmap' VALUES (8793, 17248, NULL, 4974);
INSERT INTO 'dancesrecordingsmap' VALUES (5423, 12018, NULL, 5438);
INSERT INTO 'dancesrecordingsmap' VALUES (8653, 15959, NULL, 5438);
INSERT INTO 'dancesrecordingsmap' VALUES (6300, 13204, NULL, 1660);
INSERT INTO 'dancesrecordingsmap' VALUES (8795, 17250, NULL, 1660);
INSERT INTO 'dancesrecordingsmap' VALUES (4145, 4838, NULL, 5151);
INSERT INTO 'dancesrecordingsmap' VALUES (8797, 17252, NULL, 5151);
INSERT INTO 'dancesrecordingsmap' VALUES (8333, 15281, NULL, 9440);
INSERT INTO 'dancesrecordingsmap' VALUES (8798, 17253, NULL, 9440);
INSERT INTO 'dancesrecordingsmap' VALUES (8799, 17254, NULL, 6551);
INSERT INTO 'dancesrecordingsmap' VALUES (8800, 17255, NULL, 6692);
INSERT INTO 'dancesrecordingsmap' VALUES (8801, 17256, NULL, 7577);
INSERT INTO 'dancesrecordingsmap' VALUES (4973, 11369, NULL, 5626);
INSERT INTO 'dancesrecordingsmap' VALUES (8802, 17257, NULL, 5626);
INSERT INTO 'dancesrecordingsmap' VALUES (8803, 17258, NULL, 5696);
INSERT INTO 'dancesrecordingsmap' VALUES (8804, 16939, NULL, 1454);
INSERT INTO 'dancesrecordingsmap' VALUES (8806, 17133, NULL, 9889);
INSERT INTO 'dancesrecordingsmap' VALUES (8807, 17134, NULL, 9890);
INSERT INTO 'dancesrecordingsmap' VALUES (8808, 17136, NULL, 9891);
INSERT INTO 'dancesrecordingsmap' VALUES (8809, 17137, NULL, 9892);
INSERT INTO 'dancesrecordingsmap' VALUES (8810, 17138, NULL, 9894);
INSERT INTO 'dancesrecordingsmap' VALUES (8811, 17139, NULL, 9895);
INSERT INTO 'dancesrecordingsmap' VALUES (8812, 17140, NULL, 9896);
INSERT INTO 'dancesrecordingsmap' VALUES (8814, 17141, NULL, 9899);
INSERT INTO 'dancesrecordingsmap' VALUES (8815, 17142, NULL, 9900);
INSERT INTO 'dancesrecordingsmap' VALUES (8816, 17143, NULL, 9901);
INSERT INTO 'dancesrecordingsmap' VALUES (8819, 13847, NULL, 9912);
INSERT INTO 'dancesrecordingsmap' VALUES (8822, 16465, NULL, 9914);
INSERT INTO 'dancesrecordingsmap' VALUES (8823, 11284, NULL, 9909);
INSERT INTO 'dancesrecordingsmap' VALUES (8820, 17194, NULL, 9916);
INSERT INTO 'dancesrecordingsmap' VALUES (8837, 13771, NULL, 9931);
INSERT INTO 'dancesrecordingsmap' VALUES (8733, 16727, NULL, 9862);
INSERT INTO 'dancesrecordingsmap' VALUES (8763, 4239, NULL, 9870);
INSERT INTO 'dancesrecordingsmap' VALUES (8764, 480, NULL, 9871);
INSERT INTO 'dancesrecordingsmap' VALUES (8734, 16728, NULL, 9863);
INSERT INTO 'dancesrecordingsmap' VALUES (9131, 17562, NULL, 10195);
INSERT INTO 'dancesrecordingsmap' VALUES (8825, 15020, NULL, 9919);
INSERT INTO 'dancesrecordingsmap' VALUES (8826, 17403, NULL, 9920);
INSERT INTO 'dancesrecordingsmap' VALUES (8827, 15913, NULL, 9920);
INSERT INTO 'dancesrecordingsmap' VALUES (8828, 17404, NULL, 9921);
INSERT INTO 'dancesrecordingsmap' VALUES (8829, 15600, NULL, 9923);
INSERT INTO 'dancesrecordingsmap' VALUES (8830, 17405, NULL, 9924);
INSERT INTO 'dancesrecordingsmap' VALUES (8831, 17406, NULL, 9925);
INSERT INTO 'dancesrecordingsmap' VALUES (8832, 16930, NULL, 9926);
INSERT INTO 'dancesrecordingsmap' VALUES (8833, 15021, NULL, 9927);
INSERT INTO 'dancesrecordingsmap' VALUES (8834, 15657, NULL, 9928);
INSERT INTO 'dancesrecordingsmap' VALUES (8836, 17360, NULL, 9930);
INSERT INTO 'dancesrecordingsmap' VALUES (8838, 17408, NULL, 9932);
INSERT INTO 'dancesrecordingsmap' VALUES (8839, 15044, NULL, 9933);
INSERT INTO 'dancesrecordingsmap' VALUES (8761, 17023, NULL, 9350);
INSERT INTO 'dancesrecordingsmap' VALUES (8843, 16811, NULL, 9936);
INSERT INTO 'dancesrecordingsmap' VALUES (8844, 16806, NULL, 9937);
INSERT INTO 'dancesrecordingsmap' VALUES (8736, 16729, NULL, 9866);
INSERT INTO 'dancesrecordingsmap' VALUES (8846, 17460, NULL, 9832);
INSERT INTO 'dancesrecordingsmap' VALUES (8847, 15311, NULL, 9395);
INSERT INTO 'dancesrecordingsmap' VALUES (8848, 14363, NULL, 9388);
INSERT INTO 'dancesrecordingsmap' VALUES (8849, 15306, NULL, 9389);
INSERT INTO 'dancesrecordingsmap' VALUES (8461, 14988, NULL, 5722);
INSERT INTO 'dancesrecordingsmap' VALUES (8765, 2024, NULL, 9874);
INSERT INTO 'dancesrecordingsmap' VALUES (8850, 15304, NULL, 9387);
INSERT INTO 'dancesrecordingsmap' VALUES (774, 6823, NULL, 921);
INSERT INTO 'dancesrecordingsmap' VALUES (8744, 8206, NULL, 921);
INSERT INTO 'dancesrecordingsmap' VALUES (8749, 8204, NULL, 950);
INSERT INTO 'dancesrecordingsmap' VALUES (8769, 2970, NULL, 9881);
INSERT INTO 'dancesrecordingsmap' VALUES (8627, 15674, NULL, 6374);
INSERT INTO 'dancesrecordingsmap' VALUES (8776, 17225, NULL, 6374);
INSERT INTO 'dancesrecordingsmap' VALUES (8767, 3561, NULL, 9876);
INSERT INTO 'dancesrecordingsmap' VALUES (8841, 16855, NULL, 7031);
INSERT INTO 'dancesrecordingsmap' VALUES (8821, 8992, NULL, 9917);
INSERT INTO 'dancesrecordingsmap' VALUES (8852, 15308, NULL, 9391);
INSERT INTO 'dancesrecordingsmap' VALUES (8853, 15309, NULL, 9392);
INSERT INTO 'dancesrecordingsmap' VALUES (8854, 14356, NULL, 9393);
INSERT INTO 'dancesrecordingsmap' VALUES (8855, 15310, NULL, 9394);
INSERT INTO 'dancesrecordingsmap' VALUES (8857, 13584, NULL, 9397);
INSERT INTO 'dancesrecordingsmap' VALUES (8858, 13587, NULL, 9398);
INSERT INTO 'dancesrecordingsmap' VALUES (8859, 14741, NULL, 9399);
INSERT INTO 'dancesrecordingsmap' VALUES (8760, 17022, NULL, 9400);
INSERT INTO 'dancesrecordingsmap' VALUES (8791, 17246, NULL, 9400);
INSERT INTO 'dancesrecordingsmap' VALUES (8860, 14636, NULL, 9400);
INSERT INTO 'dancesrecordingsmap' VALUES (8861, 17400, NULL, 9904);
INSERT INTO 'dancesrecordingsmap' VALUES (8862, 17481, NULL, 426);
INSERT INTO 'dancesrecordingsmap' VALUES (8748, 8210, NULL, 427);
INSERT INTO 'dancesrecordingsmap' VALUES (8656, 16054, NULL, 5582);
INSERT INTO 'dancesrecordingsmap' VALUES (5574, 1187, NULL, 6010);
INSERT INTO 'dancesrecordingsmap' VALUES (8817, 5028, NULL, 9902);
INSERT INTO 'dancesrecordingsmap' VALUES (8813, 17144, NULL, 9897);
INSERT INTO 'dancesrecordingsmap' VALUES (8794, 17249, NULL, 4690);
INSERT INTO 'dancesrecordingsmap' VALUES (8773, 1246, NULL, 9886);
INSERT INTO 'dancesrecordingsmap' VALUES (8805, 16255, NULL, 9888);
INSERT INTO 'dancesrecordingsmap' VALUES (8863, 3870, NULL, 8063);
INSERT INTO 'dancesrecordingsmap' VALUES (8864, 16927, NULL, 9922);
INSERT INTO 'dancesrecordingsmap' VALUES (8866, 16952, NULL, 2659);
INSERT INTO 'dancesrecordingsmap' VALUES (8840, 16855, NULL, 5722);
INSERT INTO 'dancesrecordingsmap' VALUES (8868, 17485, NULL, 5722);
INSERT INTO 'dancesrecordingsmap' VALUES (4506, 9888, NULL, 5448);
INSERT INTO 'dancesrecordingsmap' VALUES (8869, 7380, NULL, 6457);
INSERT INTO 'dancesrecordingsmap' VALUES (8870, 10113, NULL, 4454);
INSERT INTO 'dancesrecordingsmap' VALUES (8871, 14738, NULL, 5105);
INSERT INTO 'dancesrecordingsmap' VALUES (8872, 2250, NULL, 9967);
INSERT INTO 'dancesrecordingsmap' VALUES (8873, 13581, NULL, 9968);
INSERT INTO 'dancesrecordingsmap' VALUES (8875, 6748, NULL, 9970);
INSERT INTO 'dancesrecordingsmap' VALUES (8876, 1647, NULL, 9971);
INSERT INTO 'dancesrecordingsmap' VALUES (8877, 522, NULL, 9972);
INSERT INTO 'dancesrecordingsmap' VALUES (8878, 4844, NULL, 9973);
INSERT INTO 'dancesrecordingsmap' VALUES (8879, 5407, NULL, 9974);
INSERT INTO 'dancesrecordingsmap' VALUES (8881, 7282, NULL, 9976);
INSERT INTO 'dancesrecordingsmap' VALUES (8882, 2616, NULL, 9977);
INSERT INTO 'dancesrecordingsmap' VALUES (8883, 109, NULL, 9978);
INSERT INTO 'dancesrecordingsmap' VALUES (8884, 1280, NULL, 9979);
INSERT INTO 'dancesrecordingsmap' VALUES (8886, 12941, NULL, 9981);
INSERT INTO 'dancesrecordingsmap' VALUES (8887, 13694, NULL, 9981);
INSERT INTO 'dancesrecordingsmap' VALUES (9009, 15023, NULL, 10067);
INSERT INTO 'dancesrecordingsmap' VALUES (8889, 17523, NULL, 9983);
INSERT INTO 'dancesrecordingsmap' VALUES (8961, 17794, NULL, 10031);
INSERT INTO 'dancesrecordingsmap' VALUES (8891, 17526, NULL, 9985);
INSERT INTO 'dancesrecordingsmap' VALUES (8892, 17527, NULL, 9986);
INSERT INTO 'dancesrecordingsmap' VALUES (8893, 17528, NULL, 9987);
INSERT INTO 'dancesrecordingsmap' VALUES (8894, 17529, NULL, 9988);
INSERT INTO 'dancesrecordingsmap' VALUES (9006, 16126, NULL, 10063);
INSERT INTO 'dancesrecordingsmap' VALUES (9007, 10800, NULL, 10064);
INSERT INTO 'dancesrecordingsmap' VALUES (8900, 17535, NULL, 9994);
INSERT INTO 'dancesrecordingsmap' VALUES (8901, 17536, NULL, 9995);
INSERT INTO 'dancesrecordingsmap' VALUES (8902, 17537, NULL, 9996);
INSERT INTO 'dancesrecordingsmap' VALUES (8903, 8453, NULL, 2635);
INSERT INTO 'dancesrecordingsmap' VALUES (930, 615, NULL, 1145);
INSERT INTO 'dancesrecordingsmap' VALUES (8904, 938, NULL, 1145);
INSERT INTO 'dancesrecordingsmap' VALUES (8905, 7389, NULL, 5833);
INSERT INTO 'dancesrecordingsmap' VALUES (8906, 6048, NULL, 9998);
INSERT INTO 'dancesrecordingsmap' VALUES (8908, 894, NULL, 10000);
INSERT INTO 'dancesrecordingsmap' VALUES (8907, 12426, NULL, 9999);
INSERT INTO 'dancesrecordingsmap' VALUES (8962, 17795, NULL, 10032);
INSERT INTO 'dancesrecordingsmap' VALUES (8963, 16384, NULL, 10033);
INSERT INTO 'dancesrecordingsmap' VALUES (8909, 4291, NULL, 10001);
INSERT INTO 'dancesrecordingsmap' VALUES (8911, 4411, NULL, 10003);
INSERT INTO 'dancesrecordingsmap' VALUES (8910, 4805, NULL, 10002);
INSERT INTO 'dancesrecordingsmap' VALUES (8965, 14350, NULL, 10034);
INSERT INTO 'dancesrecordingsmap' VALUES (8913, 13584, NULL, 10007);
INSERT INTO 'dancesrecordingsmap' VALUES (8915, 2437, NULL, 10009);
INSERT INTO 'dancesrecordingsmap' VALUES (8966, 3277, NULL, 10035);
INSERT INTO 'dancesrecordingsmap' VALUES (8917, 4102, NULL, 10011);
INSERT INTO 'dancesrecordingsmap' VALUES (8918, 3027, NULL, 10012);
INSERT INTO 'dancesrecordingsmap' VALUES (8919, 13847, NULL, 10013);
INSERT INTO 'dancesrecordingsmap' VALUES (8920, 17626, NULL, 10014);
INSERT INTO 'dancesrecordingsmap' VALUES (8921, 13544, NULL, 10014);
INSERT INTO 'dancesrecordingsmap' VALUES (8922, 13357, NULL, 10014);
INSERT INTO 'dancesrecordingsmap' VALUES (8923, 17532, NULL, 9992);
INSERT INTO 'dancesrecordingsmap' VALUES (8896, 17530, NULL, 9990);
INSERT INTO 'dancesrecordingsmap' VALUES (776, 2278, NULL, 948);
INSERT INTO 'dancesrecordingsmap' VALUES (8924, 17638, NULL, 5497);
INSERT INTO 'dancesrecordingsmap' VALUES (8925, 17643, NULL, 6451);
INSERT INTO 'dancesrecordingsmap' VALUES (8927, 17645, NULL, 3437);
INSERT INTO 'dancesrecordingsmap' VALUES (8929, 14534, NULL, 9022);
INSERT INTO 'dancesrecordingsmap' VALUES (8930, 16963, NULL, 6290);
INSERT INTO 'dancesrecordingsmap' VALUES (8931, 1578, NULL, 10018);
INSERT INTO 'dancesrecordingsmap' VALUES (8934, 754, NULL, 10017);
INSERT INTO 'dancesrecordingsmap' VALUES (8937, 5904, NULL, 10020);
INSERT INTO 'dancesrecordingsmap' VALUES (8938, 584, NULL, 10021);
INSERT INTO 'dancesrecordingsmap' VALUES (8939, 2024, NULL, 10022);
INSERT INTO 'dancesrecordingsmap' VALUES (8940, 5885, NULL, 10023);
INSERT INTO 'dancesrecordingsmap' VALUES (8941, 1582, NULL, 10024);
INSERT INTO 'dancesrecordingsmap' VALUES (8942, 3743, NULL, 10025);
INSERT INTO 'dancesrecordingsmap' VALUES (8943, 17395, NULL, 9905);
INSERT INTO 'dancesrecordingsmap' VALUES (8944, 17398, NULL, 9906);
INSERT INTO 'dancesrecordingsmap' VALUES (8945, 17397, NULL, 9908);
INSERT INTO 'dancesrecordingsmap' VALUES (8967, 17796, NULL, 10035);
INSERT INTO 'dancesrecordingsmap' VALUES (8885, 13588, NULL, 9980);
INSERT INTO 'dancesrecordingsmap' VALUES (4080, 9013, NULL, 5109);
INSERT INTO 'dancesrecordingsmap' VALUES (558, 3695, NULL, 726);
INSERT INTO 'dancesrecordingsmap' VALUES (8835, 17407, NULL, 9929);
INSERT INTO 'dancesrecordingsmap' VALUES (8895, 17538, 530, 9989);
INSERT INTO 'dancesrecordingsmap' VALUES (8888, 5497, NULL, 9982);
INSERT INTO 'dancesrecordingsmap' VALUES (8948, 17396, NULL, 9915);
INSERT INTO 'dancesrecordingsmap' VALUES (8890, 17524, NULL, 9984);
INSERT INTO 'dancesrecordingsmap' VALUES (8968, 17797, NULL, 10036);
INSERT INTO 'dancesrecordingsmap' VALUES (8950, 17791, NULL, 5425);
INSERT INTO 'dancesrecordingsmap' VALUES (8951, 17791, NULL, 8516);
INSERT INTO 'dancesrecordingsmap' VALUES (8952, 17791, NULL, 4628);
INSERT INTO 'dancesrecordingsmap' VALUES (8953, 17791, NULL, 2666);
INSERT INTO 'dancesrecordingsmap' VALUES (8954, 17791, NULL, 6022);
INSERT INTO 'dancesrecordingsmap' VALUES (8955, 17791, NULL, 3358);
INSERT INTO 'dancesrecordingsmap' VALUES (8956, 17791, NULL, 7716);
INSERT INTO 'dancesrecordingsmap' VALUES (8957, 17791, NULL, 7734);
INSERT INTO 'dancesrecordingsmap' VALUES (8958, 17791, NULL, 8179);
INSERT INTO 'dancesrecordingsmap' VALUES (8998, 17949, NULL, 1460);
INSERT INTO 'dancesrecordingsmap' VALUES (8969, 17798, NULL, 10037);
INSERT INTO 'dancesrecordingsmap' VALUES (8979, 13278, NULL, 10046);
INSERT INTO 'dancesrecordingsmap' VALUES (8970, 6858, NULL, 10038);
INSERT INTO 'dancesrecordingsmap' VALUES (8972, 4246, NULL, 10040);
INSERT INTO 'dancesrecordingsmap' VALUES (6289, 8941, NULL, 4971);
INSERT INTO 'dancesrecordingsmap' VALUES (8999, 10052, NULL, 4971);
INSERT INTO 'dancesrecordingsmap' VALUES (8976, 17801, NULL, 10043);
INSERT INTO 'dancesrecordingsmap' VALUES (8959, 17792, NULL, 10029);
INSERT INTO 'dancesrecordingsmap' VALUES (8960, 17793, NULL, 10030);
INSERT INTO 'dancesrecordingsmap' VALUES (8980, 17882, NULL, 1489);
INSERT INTO 'dancesrecordingsmap' VALUES (9000, 6373, NULL, 3148);
INSERT INTO 'dancesrecordingsmap' VALUES (8973, 17800, NULL, 10041);
INSERT INTO 'dancesrecordingsmap' VALUES (8982, 14667, NULL, 1608);
INSERT INTO 'dancesrecordingsmap' VALUES (8983, 17903, NULL, 7987);
INSERT INTO 'dancesrecordingsmap' VALUES (8984, 17630, NULL, 8875);
INSERT INTO 'dancesrecordingsmap' VALUES (8985, 17891, NULL, 10047);
INSERT INTO 'dancesrecordingsmap' VALUES (8986, 17892, NULL, 10048);
INSERT INTO 'dancesrecordingsmap' VALUES (8987, 17893, NULL, 10049);
INSERT INTO 'dancesrecordingsmap' VALUES (8988, 16803, NULL, 10050);
INSERT INTO 'dancesrecordingsmap' VALUES (8989, 17895, NULL, 10051);
INSERT INTO 'dancesrecordingsmap' VALUES (8990, 17896, NULL, 10052);
INSERT INTO 'dancesrecordingsmap' VALUES (8991, 17897, NULL, 10054);
INSERT INTO 'dancesrecordingsmap' VALUES (8992, 17898, NULL, 10055);
INSERT INTO 'dancesrecordingsmap' VALUES (8993, 17899, NULL, 10056);
INSERT INTO 'dancesrecordingsmap' VALUES (8994, 9486, NULL, 10058);
INSERT INTO 'dancesrecordingsmap' VALUES (8995, 17901, NULL, 10060);
INSERT INTO 'dancesrecordingsmap' VALUES (8996, 17948, NULL, 4586);
INSERT INTO 'dancesrecordingsmap' VALUES (8997, 17949, NULL, 6196);
INSERT INTO 'dancesrecordingsmap' VALUES (9002, 8947, NULL, 6577);
INSERT INTO 'dancesrecordingsmap' VALUES (9003, 18022, NULL, 5757);
INSERT INTO 'dancesrecordingsmap' VALUES (8865, 13268, NULL, 6643);
INSERT INTO 'dancesrecordingsmap' VALUES (9004, 16887, NULL, 6643);
INSERT INTO 'dancesrecordingsmap' VALUES (8897, 17531, NULL, 9991);
INSERT INTO 'dancesrecordingsmap' VALUES (8899, 17533, NULL, 9993);
INSERT INTO 'dancesrecordingsmap' VALUES (9008, 10298, NULL, 10066);
INSERT INTO 'dancesrecordingsmap' VALUES (9010, 17889, NULL, 10068);
INSERT INTO 'dancesrecordingsmap' VALUES (9011, 6073, NULL, 10073);
INSERT INTO 'dancesrecordingsmap' VALUES (9012, 4796, NULL, 10074);
INSERT INTO 'dancesrecordingsmap' VALUES (9013, 13594, NULL, 10075);
INSERT INTO 'dancesrecordingsmap' VALUES (9014, 6689, NULL, 10076);
INSERT INTO 'dancesrecordingsmap' VALUES (9015, 13270, NULL, 10077);
INSERT INTO 'dancesrecordingsmap' VALUES (9016, 10653, NULL, 10078);
INSERT INTO 'dancesrecordingsmap' VALUES (9017, 17886, NULL, 10080);
INSERT INTO 'dancesrecordingsmap' VALUES (9018, 3695, NULL, 10081);
INSERT INTO 'dancesrecordingsmap' VALUES (9019, 18047, NULL, 10082);
INSERT INTO 'dancesrecordingsmap' VALUES (9020, 18048, NULL, 10083);
INSERT INTO 'dancesrecordingsmap' VALUES (9021, 16522, NULL, 10084);
INSERT INTO 'dancesrecordingsmap' VALUES (9022, 17887, NULL, 10085);
INSERT INTO 'dancesrecordingsmap' VALUES (9023, 7795, NULL, 10086);
INSERT INTO 'dancesrecordingsmap' VALUES (9024, 17144, NULL, 10087);
INSERT INTO 'dancesrecordingsmap' VALUES (9025, 1087, NULL, 10088);
INSERT INTO 'dancesrecordingsmap' VALUES (9026, 13847, NULL, 10089);
INSERT INTO 'dancesrecordingsmap' VALUES (9027, 17885, NULL, 10090);
INSERT INTO 'dancesrecordingsmap' VALUES (9028, 18049, NULL, 10091);
INSERT INTO 'dancesrecordingsmap' VALUES (8977, 5696, NULL, 10044);
INSERT INTO 'dancesrecordingsmap' VALUES (8974, 7204, NULL, 10042);
INSERT INTO 'dancesrecordingsmap' VALUES (8978, 17802, NULL, 10045);
INSERT INTO 'dancesrecordingsmap' VALUES (8936, 8328, NULL, 10027);
INSERT INTO 'dancesrecordingsmap' VALUES (8935, 5906, NULL, 10019);
INSERT INTO 'dancesrecordingsmap' VALUES (8932, 9382, NULL, 10016);
INSERT INTO 'dancesrecordingsmap' VALUES (8933, 7182, NULL, 10015);
INSERT INTO 'dancesrecordingsmap' VALUES (9132, 17563, NULL, 10196);
INSERT INTO 'dancesrecordingsmap' VALUES (9029, 17904, NULL, 10093);
INSERT INTO 'dancesrecordingsmap' VALUES (9058, 18121, NULL, 10079);
INSERT INTO 'dancesrecordingsmap' VALUES (9135, 18218, NULL, 9330);
INSERT INTO 'dancesrecordingsmap' VALUES (9059, 4692, NULL, 897);
INSERT INTO 'dancesrecordingsmap' VALUES (8947, 17399, NULL, 9913);
INSERT INTO 'dancesrecordingsmap' VALUES (8949, 17401, NULL, 9913);
INSERT INTO 'dancesrecordingsmap' VALUES (9060, 17789, NULL, 9913);
INSERT INTO 'dancesrecordingsmap' VALUES (8964, 12516, NULL, 10033);
INSERT INTO 'dancesrecordingsmap' VALUES (9042, 12692, NULL, 10106);
INSERT INTO 'dancesrecordingsmap' VALUES (9143, 3119, NULL, 6466);
INSERT INTO 'dancesrecordingsmap' VALUES (9138, 3616, NULL, 10205);
INSERT INTO 'dancesrecordingsmap' VALUES (7654, 2484, NULL, 8259);
INSERT INTO 'dancesrecordingsmap' VALUES (9146, 18610, NULL, 7338);
INSERT INTO 'dancesrecordingsmap' VALUES (9147, 2302, NULL, 10231);
INSERT INTO 'dancesrecordingsmap' VALUES (9076, 17439, NULL, 10138);
INSERT INTO 'dancesrecordingsmap' VALUES (9079, 17457, NULL, 10141);
INSERT INTO 'dancesrecordingsmap' VALUES (9080, 17433, NULL, 10142);
INSERT INTO 'dancesrecordingsmap' VALUES (9209, 15516, NULL, 45);
INSERT INTO 'dancesrecordingsmap' VALUES (8981, 10083, NULL, 5498);
INSERT INTO 'dancesrecordingsmap' VALUES (8880, 1176, NULL, 9975);
INSERT INTO 'dancesrecordingsmap' VALUES (8874, 14738, NULL, 9969);
INSERT INTO 'dancesrecordingsmap' VALUES (8926, 17644, NULL, 5713);
INSERT INTO 'dancesrecordingsmap' VALUES (9093, 17100, NULL, 7062);
INSERT INTO 'dancesrecordingsmap' VALUES (8971, 17799, NULL, 10039);
INSERT INTO 'dancesrecordingsmap' VALUES (8928, 14740, NULL, 9027);
INSERT INTO 'dancesrecordingsmap' VALUES (8914, 4641, NULL, 10004);
INSERT INTO 'dancesrecordingsmap' VALUES (9074, 17448, NULL, 10136);
INSERT INTO 'dancesrecordingsmap' VALUES (9081, 17453, NULL, 10143);
INSERT INTO 'dancesrecordingsmap' VALUES (9082, 17446, NULL, 10145);
INSERT INTO 'dancesrecordingsmap' VALUES (9078, 17435, NULL, 10140);
INSERT INTO 'dancesrecordingsmap' VALUES (9064, 17432, NULL, 10122);
INSERT INTO 'dancesrecordingsmap' VALUES (9062, 17452, NULL, 10123);
INSERT INTO 'dancesrecordingsmap' VALUES (9063, 17444, NULL, 10124);
INSERT INTO 'dancesrecordingsmap' VALUES (9065, 17440, NULL, 10125);
INSERT INTO 'dancesrecordingsmap' VALUES (9066, 8102, NULL, 10126);
INSERT INTO 'dancesrecordingsmap' VALUES (9067, 4102, NULL, 10127);
INSERT INTO 'dancesrecordingsmap' VALUES (9068, 17455, NULL, 10128);
INSERT INTO 'dancesrecordingsmap' VALUES (9069, 17441, NULL, 10130);
INSERT INTO 'dancesrecordingsmap' VALUES (9070, 17449, NULL, 10131);
INSERT INTO 'dancesrecordingsmap' VALUES (9071, 17437, NULL, 10132);
INSERT INTO 'dancesrecordingsmap' VALUES (9072, 17447, NULL, 10133);
INSERT INTO 'dancesrecordingsmap' VALUES (9083, 2153, NULL, 10146);
INSERT INTO 'dancesrecordingsmap' VALUES (9075, 17430, NULL, 10137);
INSERT INTO 'dancesrecordingsmap' VALUES (9077, 17442, NULL, 10139);
INSERT INTO 'dancesrecordingsmap' VALUES (9084, 17428, NULL, 10147);
INSERT INTO 'dancesrecordingsmap' VALUES (9086, 7503, NULL, 10149);
INSERT INTO 'dancesrecordingsmap' VALUES (9087, 17438, NULL, 10150);
INSERT INTO 'dancesrecordingsmap' VALUES (9088, 17436, NULL, 10152);
INSERT INTO 'dancesrecordingsmap' VALUES (9089, 17454, NULL, 10153);
INSERT INTO 'dancesrecordingsmap' VALUES (9090, 17450, NULL, 10154);
INSERT INTO 'dancesrecordingsmap' VALUES (9091, 17456, NULL, 10155);
INSERT INTO 'dancesrecordingsmap' VALUES (9092, 17434, NULL, 10158);
INSERT INTO 'dancesrecordingsmap' VALUES (9085, 7546, NULL, 10148);
INSERT INTO 'dancesrecordingsmap' VALUES (9150, 17122, NULL, 10224);
INSERT INTO 'dancesrecordingsmap' VALUES (9030, 12680, NULL, 10094);
INSERT INTO 'dancesrecordingsmap' VALUES (9031, 12681, NULL, 10095);
INSERT INTO 'dancesrecordingsmap' VALUES (9033, 12683, NULL, 10097);
INSERT INTO 'dancesrecordingsmap' VALUES (9034, 12684, NULL, 10098);
INSERT INTO 'dancesrecordingsmap' VALUES (9035, 12685, NULL, 10099);
INSERT INTO 'dancesrecordingsmap' VALUES (9036, 12686, NULL, 10100);
INSERT INTO 'dancesrecordingsmap' VALUES (9037, 12687, NULL, 10101);
INSERT INTO 'dancesrecordingsmap' VALUES (9038, 12688, NULL, 10102);
INSERT INTO 'dancesrecordingsmap' VALUES (9040, 12690, NULL, 10104);
INSERT INTO 'dancesrecordingsmap' VALUES (9041, 12691, NULL, 10105);
INSERT INTO 'dancesrecordingsmap' VALUES (9210, 15517, NULL, 133);
INSERT INTO 'dancesrecordingsmap' VALUES (9043, 12693, NULL, 10107);
INSERT INTO 'dancesrecordingsmap' VALUES (9044, 12694, NULL, 10108);
INSERT INTO 'dancesrecordingsmap' VALUES (9045, 12695, NULL, 10109);
INSERT INTO 'dancesrecordingsmap' VALUES (9047, 16489, NULL, 10111);
INSERT INTO 'dancesrecordingsmap' VALUES (9048, 16490, NULL, 10112);
INSERT INTO 'dancesrecordingsmap' VALUES (9049, 16491, NULL, 10113);
INSERT INTO 'dancesrecordingsmap' VALUES (9050, 16492, NULL, 10114);
INSERT INTO 'dancesrecordingsmap' VALUES (9051, 16493, NULL, 10115);
INSERT INTO 'dancesrecordingsmap' VALUES (9053, 11039, NULL, 10117);
INSERT INTO 'dancesrecordingsmap' VALUES (9054, 16496, NULL, 10118);
INSERT INTO 'dancesrecordingsmap' VALUES (9055, 16497, NULL, 10119);
INSERT INTO 'dancesrecordingsmap' VALUES (9056, 16498, NULL, 10120);
INSERT INTO 'dancesrecordingsmap' VALUES (9057, 16499, NULL, 10121);
INSERT INTO 'dancesrecordingsmap' VALUES (9094, 3127, NULL, 1371);
INSERT INTO 'dancesrecordingsmap' VALUES (1167, 5529, NULL, 1416);
INSERT INTO 'dancesrecordingsmap' VALUES (9098, 18238, NULL, 1416);
INSERT INTO 'dancesrecordingsmap' VALUES (9099, 18239, NULL, 9984);
INSERT INTO 'dancesrecordingsmap' VALUES (9100, 16718, NULL, 4893);
INSERT INTO 'dancesrecordingsmap' VALUES (9152, 18410, NULL, 10222);
INSERT INTO 'dancesrecordingsmap' VALUES (9153, 18272, NULL, 10221);
INSERT INTO 'dancesrecordingsmap' VALUES (9159, 9800, NULL, 10219);
INSERT INTO 'dancesrecordingsmap' VALUES (7253, 13560, NULL, 7579);
INSERT INTO 'dancesrecordingsmap' VALUES (9160, 18646, NULL, 7579);
INSERT INTO 'dancesrecordingsmap' VALUES (9161, 18647, NULL, 7580);
INSERT INTO 'dancesrecordingsmap' VALUES (9127, 17556, NULL, 10191);
INSERT INTO 'dancesrecordingsmap' VALUES (9133, 17565, NULL, 10197);
INSERT INTO 'dancesrecordingsmap' VALUES (9163, 18941, NULL, 7215);
INSERT INTO 'dancesrecordingsmap' VALUES (9165, 18947, NULL, 9885);
INSERT INTO 'dancesrecordingsmap' VALUES (9166, 18956, NULL, 7032);
INSERT INTO 'dancesrecordingsmap' VALUES (9073, 17445, NULL, 10135);
INSERT INTO 'dancesrecordingsmap' VALUES (8645, 15041, NULL, 9773);
INSERT INTO 'dancesrecordingsmap' VALUES (9167, 18971, NULL, 4540);
INSERT INTO 'dancesrecordingsmap' VALUES (4557, 10507, NULL, 4124);
INSERT INTO 'dancesrecordingsmap' VALUES (9005, 17888, NULL, 10062);
INSERT INTO 'dancesrecordingsmap' VALUES (8856, 15312, NULL, 9396);
INSERT INTO 'dancesrecordingsmap' VALUES (9144, 13206, NULL, 4912);
INSERT INTO 'dancesrecordingsmap' VALUES (9164, 18944, NULL, 9396);
INSERT INTO 'dancesrecordingsmap' VALUES (9039, 12689, NULL, 10103);
INSERT INTO 'dancesrecordingsmap' VALUES (9046, 16488, NULL, 10110);
INSERT INTO 'dancesrecordingsmap' VALUES (9157, 17460, NULL, 10217);
INSERT INTO 'dancesrecordingsmap' VALUES (9061, 17789, NULL, 5441);
INSERT INTO 'dancesrecordingsmap' VALUES (9155, 18408, NULL, 10215);
INSERT INTO 'dancesrecordingsmap' VALUES (9168, 18969, NULL, 4124);
INSERT INTO 'dancesrecordingsmap' VALUES (9129, 17561, NULL, 10193);
INSERT INTO 'dancesrecordingsmap' VALUES (9115, 17567, NULL, 10171);
INSERT INTO 'dancesrecordingsmap' VALUES (9169, 18695, NULL, 6507);
INSERT INTO 'dancesrecordingsmap' VALUES (9170, 18695, NULL, 855);
INSERT INTO 'dancesrecordingsmap' VALUES (7785, 3770, NULL, 8406);
INSERT INTO 'dancesrecordingsmap' VALUES (7786, 3769, NULL, 8406);
INSERT INTO 'dancesrecordingsmap' VALUES (9171, 14817, NULL, 9571);
INSERT INTO 'dancesrecordingsmap' VALUES (9172, 11616, NULL, 2566);
INSERT INTO 'dancesrecordingsmap' VALUES (6458, 742, NULL, 6610);
INSERT INTO 'dancesrecordingsmap' VALUES (9109, 272, NULL, 10162);
INSERT INTO 'dancesrecordingsmap' VALUES (9178, 14448, NULL, 8906);
INSERT INTO 'dancesrecordingsmap' VALUES (9181, 14452, NULL, 8911);
INSERT INTO 'dancesrecordingsmap' VALUES (9182, 14453, NULL, 8912);
INSERT INTO 'dancesrecordingsmap' VALUES (9184, 14456, NULL, 8914);
INSERT INTO 'dancesrecordingsmap' VALUES (9185, 14457, NULL, 8915);
INSERT INTO 'dancesrecordingsmap' VALUES (9189, 19143, NULL, 83);
INSERT INTO 'dancesrecordingsmap' VALUES (9190, 15491, NULL, 40);
INSERT INTO 'dancesrecordingsmap' VALUES (9191, 15493, NULL, 6875);
INSERT INTO 'dancesrecordingsmap' VALUES (9193, 15500, NULL, 3462);
INSERT INTO 'dancesrecordingsmap' VALUES (9196, 15503, NULL, 7162);
INSERT INTO 'dancesrecordingsmap' VALUES (3525, 8921, NULL, 317);
INSERT INTO 'dancesrecordingsmap' VALUES (9197, 15504, NULL, 317);
INSERT INTO 'dancesrecordingsmap' VALUES (9198, 15505, NULL, 6044);
INSERT INTO 'dancesrecordingsmap' VALUES (9199, 15506, NULL, 165);
INSERT INTO 'dancesrecordingsmap' VALUES (9200, 15507, NULL, 327);
INSERT INTO 'dancesrecordingsmap' VALUES (9201, 15508, NULL, 116);
INSERT INTO 'dancesrecordingsmap' VALUES (9202, 15509, NULL, 5943);
INSERT INTO 'dancesrecordingsmap' VALUES (9203, 15510, NULL, 809);
INSERT INTO 'dancesrecordingsmap' VALUES (9204, 15511, NULL, 9097);
INSERT INTO 'dancesrecordingsmap' VALUES (9205, 15512, NULL, 712);
INSERT INTO 'dancesrecordingsmap' VALUES (9206, 15513, NULL, 5705);
INSERT INTO 'dancesrecordingsmap' VALUES (9207, 15514, NULL, 465);
INSERT INTO 'dancesrecordingsmap' VALUES (9208, 15515, NULL, 3591);
INSERT INTO 'dancesrecordingsmap' VALUES (9211, 15518, NULL, 928);
INSERT INTO 'dancesrecordingsmap' VALUES (9212, 15519, NULL, 363);
INSERT INTO 'dancesrecordingsmap' VALUES (9213, 15520, NULL, 4918);
INSERT INTO 'dancesrecordingsmap' VALUES (9214, 15521, NULL, 1253);
INSERT INTO 'dancesrecordingsmap' VALUES (9215, 15522, NULL, 226);
INSERT INTO 'dancesrecordingsmap' VALUES (3351, 7457, NULL, 4219);
INSERT INTO 'dancesrecordingsmap' VALUES (9216, 15523, NULL, 4219);
INSERT INTO 'dancesrecordingsmap' VALUES (9217, 15524, NULL, 359);
INSERT INTO 'dancesrecordingsmap' VALUES (3850, 3625, NULL, 4907);
INSERT INTO 'dancesrecordingsmap' VALUES (9218, 15525, NULL, 4907);
INSERT INTO 'dancesrecordingsmap' VALUES (3, 109, NULL, 6);
INSERT INTO 'dancesrecordingsmap' VALUES (9219, 15496, NULL, 6);
INSERT INTO 'dancesrecordingsmap' VALUES (9220, 15495, NULL, 4222);
INSERT INTO 'dancesrecordingsmap' VALUES (9224, 19135, NULL, 10234);
INSERT INTO 'dancesrecordingsmap' VALUES (9225, 18941, NULL, 10235);
INSERT INTO 'dancesrecordingsmap' VALUES (9226, 18956, NULL, 10236);
INSERT INTO 'dancesrecordingsmap' VALUES (9227, 18655, NULL, 10237);
INSERT INTO 'dancesrecordingsmap' VALUES (9228, 19136, NULL, 10238);
INSERT INTO 'dancesrecordingsmap' VALUES (9229, 19137, NULL, 10239);
INSERT INTO 'dancesrecordingsmap' VALUES (9230, 19138, NULL, 10241);
INSERT INTO 'dancesrecordingsmap' VALUES (9231, 19139, NULL, 10242);
INSERT INTO 'dancesrecordingsmap' VALUES (9162, 15609, NULL, 3327);
INSERT INTO 'dancesrecordingsmap' VALUES (9175, 14442, NULL, 8901);
INSERT INTO 'dancesrecordingsmap' VALUES (9192, 15497, NULL, 909);
INSERT INTO 'dancesrecordingsmap' VALUES (9238, 2363, NULL, 2558);
INSERT INTO 'dancesrecordingsmap' VALUES (9239, 12297, NULL, 1379);
INSERT INTO 'dancesrecordingsmap' VALUES (9255, 14478, NULL, 6148);
INSERT INTO 'dancesrecordingsmap' VALUES (9257, 5966, NULL, 1332);
INSERT INTO 'dancesrecordingsmap' VALUES (9258, 18356, NULL, 6291);
INSERT INTO 'dancesrecordingsmap' VALUES (9259, 19272, NULL, 4670);
INSERT INTO 'dancesrecordingsmap' VALUES (8336, 15278, NULL, 9442);
INSERT INTO 'dancesrecordingsmap' VALUES (9260, 19285, NULL, 9442);
INSERT INTO 'dancesrecordingsmap' VALUES (9261, 19286, NULL, 307);
INSERT INTO 'dancesrecordingsmap' VALUES (6849, 13450, NULL, 7004);
INSERT INTO 'dancesrecordingsmap' VALUES (9148, 14903, NULL, 10226);
INSERT INTO 'dancesrecordingsmap' VALUES (9264, 8568, NULL, 10026);
INSERT INTO 'dancesrecordingsmap' VALUES (9267, 12027, NULL, 10278);
INSERT INTO 'dancesrecordingsmap' VALUES (9268, 17811, NULL, 10280);
INSERT INTO 'dancesrecordingsmap' VALUES (9269, 17477, NULL, 10281);
INSERT INTO 'dancesrecordingsmap' VALUES (9270, 3690, NULL, 10282);
INSERT INTO 'dancesrecordingsmap' VALUES (9271, 14484, NULL, 10283);
INSERT INTO 'dancesrecordingsmap' VALUES (9272, 2208, NULL, 10284);
INSERT INTO 'dancesrecordingsmap' VALUES (9273, 17745, NULL, 10285);
INSERT INTO 'dancesrecordingsmap' VALUES (9276, 14567, NULL, 10288);
INSERT INTO 'dancesrecordingsmap' VALUES (9277, 7878, NULL, 10289);
INSERT INTO 'dancesrecordingsmap' VALUES (9240, 16527, NULL, 10247);
INSERT INTO 'dancesrecordingsmap' VALUES (9241, 17122, NULL, 10248);
INSERT INTO 'dancesrecordingsmap' VALUES (9242, 16523, NULL, 10249);
INSERT INTO 'dancesrecordingsmap' VALUES (9243, 10535, NULL, 10251);
INSERT INTO 'dancesrecordingsmap' VALUES (9244, 17836, NULL, 10252);
INSERT INTO 'dancesrecordingsmap' VALUES (9245, 11773, NULL, 10253);
INSERT INTO 'dancesrecordingsmap' VALUES (9246, 5209, NULL, 10254);
INSERT INTO 'dancesrecordingsmap' VALUES (9247, 1582, NULL, 10255);
INSERT INTO 'dancesrecordingsmap' VALUES (9248, 1087, NULL, 10256);
INSERT INTO 'dancesrecordingsmap' VALUES (9249, 2014, NULL, 10258);
INSERT INTO 'dancesrecordingsmap' VALUES (9250, 15309, NULL, 10259);
INSERT INTO 'dancesrecordingsmap' VALUES (9252, 12426, NULL, 10261);
INSERT INTO 'dancesrecordingsmap' VALUES (9251, 5440, NULL, 10260);
INSERT INTO 'dancesrecordingsmap' VALUES (9254, 15676, NULL, 10263);
INSERT INTO 'dancesrecordingsmap' VALUES (9223, 19134, NULL, 10233);
INSERT INTO 'dancesrecordingsmap' VALUES (5830, 6150, NULL, 6100);
INSERT INTO 'dancesrecordingsmap' VALUES (9052, 16494, NULL, 10116);
INSERT INTO 'dancesrecordingsmap' VALUES (9095, 5083, NULL, 5747);
INSERT INTO 'dancesrecordingsmap' VALUES (9032, 12682, NULL, 10096);
INSERT INTO 'dancesrecordingsmap' VALUES (9096, 15690, NULL, 5754);
INSERT INTO 'dancesrecordingsmap' VALUES (9097, 13282, NULL, 5755);
INSERT INTO 'dancesrecordingsmap' VALUES (9180, 14451, NULL, 9734);
INSERT INTO 'dancesrecordingsmap' VALUES (9278, 10684, NULL, 10290);
INSERT INTO 'dancesrecordingsmap' VALUES (9279, 12508, NULL, 10291);
INSERT INTO 'dancesrecordingsmap' VALUES (9275, 5805, NULL, 10287);
INSERT INTO 'dancesrecordingsmap' VALUES (9281, 19243, NULL, 10287);
INSERT INTO 'dancesrecordingsmap' VALUES (9283, 19357, NULL, 5482);
INSERT INTO 'dancesrecordingsmap' VALUES (9284, 17510, NULL, 5379);
INSERT INTO 'dancesrecordingsmap' VALUES (9285, 17512, NULL, 396);
INSERT INTO 'dancesrecordingsmap' VALUES (9286, 17513, NULL, 408);
INSERT INTO 'dancesrecordingsmap' VALUES (9287, 17514, NULL, 5421);
INSERT INTO 'dancesrecordingsmap' VALUES (9288, 17515, NULL, 5181);
INSERT INTO 'dancesrecordingsmap' VALUES (9289, 17517, NULL, 5815);
INSERT INTO 'dancesrecordingsmap' VALUES (5810, 10325, NULL, 965);
INSERT INTO 'dancesrecordingsmap' VALUES (9290, 17518, NULL, 965);
INSERT INTO 'dancesrecordingsmap' VALUES (9291, 17520, NULL, 5170);
INSERT INTO 'dancesrecordingsmap' VALUES (9292, 17521, NULL, 4699);
INSERT INTO 'dancesrecordingsmap' VALUES (9293, 17522, NULL, 405);
INSERT INTO 'dancesrecordingsmap' VALUES (9236, 19179, NULL, 5172);
INSERT INTO 'dancesrecordingsmap' VALUES (9294, 19482, NULL, 5172);
INSERT INTO 'dancesrecordingsmap' VALUES (2063, 1077, NULL, 2561);
INSERT INTO 'dancesrecordingsmap' VALUES (9295, 19483, NULL, 2561);
INSERT INTO 'dancesrecordingsmap' VALUES (5421, 11773, NULL, 5743);
INSERT INTO 'dancesrecordingsmap' VALUES (9296, 19489, NULL, 5743);
INSERT INTO 'dancesrecordingsmap' VALUES (9297, 19490, NULL, 3504);
INSERT INTO 'dancesrecordingsmap' VALUES (9298, 19492, NULL, 9350);
INSERT INTO 'dancesrecordingsmap' VALUES (9299, 19507, NULL, 6793);
INSERT INTO 'dancesrecordingsmap' VALUES (9300, 19515, NULL, 3495);
INSERT INTO 'dancesrecordingsmap' VALUES (9301, 16592, NULL, 5376);
INSERT INTO 'dancesrecordingsmap' VALUES (9302, 16589, NULL, 5587);
INSERT INTO 'dancesrecordingsmap' VALUES (9305, 19527, NULL, 1970);
INSERT INTO 'dancesrecordingsmap' VALUES (5086, 11699, NULL, 1512);
INSERT INTO 'dancesrecordingsmap' VALUES (8659, 5696, NULL, 1512);
INSERT INTO 'dancesrecordingsmap' VALUES (9306, 15681, NULL, 1512);
INSERT INTO 'dancesrecordingsmap' VALUES (9308, 14053, NULL, 10294);
INSERT INTO 'dancesrecordingsmap' VALUES (9309, 19555, NULL, 10293);
INSERT INTO 'dancesrecordingsmap' VALUES (9310, 14898, NULL, 10295);
INSERT INTO 'dancesrecordingsmap' VALUES (9311, 19556, NULL, 10296);
INSERT INTO 'dancesrecordingsmap' VALUES (9312, 19557, NULL, 10297);
INSERT INTO 'dancesrecordingsmap' VALUES (9313, 19558, NULL, 10298);
INSERT INTO 'dancesrecordingsmap' VALUES (9314, 19559, NULL, 10301);
INSERT INTO 'dancesrecordingsmap' VALUES (9315, 9546, NULL, 10302);
INSERT INTO 'dancesrecordingsmap' VALUES (9316, 19572, NULL, 6430);
INSERT INTO 'dancesrecordingsmap' VALUES (9317, 19589, NULL, 6647);
INSERT INTO 'dancesrecordingsmap' VALUES (9318, 19594, NULL, 7031);
INSERT INTO 'dancesrecordingsmap' VALUES (8322, 15275, NULL, 9432);
INSERT INTO 'dancesrecordingsmap' VALUES (9319, 19595, NULL, 9432);
INSERT INTO 'dancesrecordingsmap' VALUES (9320, 18567, NULL, 5583);
INSERT INTO 'dancesrecordingsmap' VALUES (9307, 19554, NULL, 9375);
INSERT INTO 'dancesrecordingsmap' VALUES (9321, 19599, NULL, 9375);
INSERT INTO 'dancesrecordingsmap' VALUES (9322, 13985, NULL, 5145);
INSERT INTO 'dancesrecordingsmap' VALUES (9324, 16789, NULL, 3448);
INSERT INTO 'dancesrecordingsmap' VALUES (9325, 16789, NULL, 5394);
INSERT INTO 'dancesrecordingsmap' VALUES (9326, 18881, NULL, 3327);
INSERT INTO 'dancesrecordingsmap' VALUES (9328, 19684, NULL, 826);
INSERT INTO 'dancesrecordingsmap' VALUES (9329, 19685, NULL, 3483);
INSERT INTO 'dancesrecordingsmap' VALUES (9330, 19689, NULL, 6245);
INSERT INTO 'dancesrecordingsmap' VALUES (4705, 348, NULL, 909);
INSERT INTO 'dancesrecordingsmap' VALUES (9331, 7378, NULL, 909);
INSERT INTO 'dancesrecordingsmap' VALUES (9332, 19165, NULL, 1522);
INSERT INTO 'dancesrecordingsmap' VALUES (5254, 11903, NULL, 1523);
INSERT INTO 'dancesrecordingsmap' VALUES (9333, 19165, NULL, 1523);
INSERT INTO 'dancesrecordingsmap' VALUES (9334, 19718, NULL, 5629);
INSERT INTO 'dancesrecordingsmap' VALUES (9335, 19725, NULL, 870);
INSERT INTO 'dancesrecordingsmap' VALUES (9187, 14459, NULL, 8917);
INSERT INTO 'dancesrecordingsmap' VALUES (9176, 14445, NULL, 8904);
INSERT INTO 'dancesrecordingsmap' VALUES (9183, 12368, NULL, 8913);
INSERT INTO 'dancesrecordingsmap' VALUES (9174, 14441, NULL, 8900);
INSERT INTO 'dancesrecordingsmap' VALUES (9265, 17900, NULL, 10059);
INSERT INTO 'dancesrecordingsmap' VALUES (9282, 12348, NULL, 3492);
INSERT INTO 'dancesrecordingsmap' VALUES (9222, 18946, NULL, 10232);
INSERT INTO 'dancesrecordingsmap' VALUES (9266, 8674, NULL, 10279);
INSERT INTO 'dancesrecordingsmap' VALUES (5545, 3086, NULL, 726);
INSERT INTO 'dancesrecordingsmap' VALUES (9262, 19360, NULL, 9929);
INSERT INTO 'dancesrecordingsmap' VALUES (9194, 15501, NULL, 5758);
INSERT INTO 'dancesrecordingsmap' VALUES (9253, 18019, NULL, 10262);
INSERT INTO 'dancesrecordingsmap' VALUES (9256, 3129, NULL, 9796);
INSERT INTO 'dancesrecordingsmap' VALUES (9274, 2233, NULL, 10286);
INSERT INTO 'dancesrecordingsmap' VALUES (9336, 19726, NULL, 6555);
INSERT INTO 'dancesrecordingsmap' VALUES (9337, 19727, NULL, 1557);
INSERT INTO 'dancesrecordingsmap' VALUES (9338, 19755, NULL, 585);
INSERT INTO 'dancesrecordingsmap' VALUES (9340, 19757, NULL, 4605);
INSERT INTO 'dancesrecordingsmap' VALUES (9341, 3333, NULL, 8042);
INSERT INTO 'dancesrecordingsmap' VALUES (9343, 19730, NULL, 10307);
INSERT INTO 'dancesrecordingsmap' VALUES (9342, 19734, NULL, 10306);
INSERT INTO 'dancesrecordingsmap' VALUES (9339, 19756, NULL, 10305);
INSERT INTO 'dancesrecordingsmap' VALUES (1087, 6406, NULL, 1255);
INSERT INTO 'dancesrecordingsmap' VALUES (5570, 5284, NULL, 1255);
INSERT INTO 'dancesrecordingsmap' VALUES (9344, 19759, NULL, 1255);
INSERT INTO 'dancesrecordingsmap' VALUES (1339, 3676, NULL, 1651);
INSERT INTO 'dancesrecordingsmap' VALUES (9345, 17824, NULL, 1651);
INSERT INTO 'dancesrecordingsmap' VALUES (6665, 5441, NULL, 6818);
INSERT INTO 'dancesrecordingsmap' VALUES (9346, 18149, NULL, 6818);
INSERT INTO 'dancesrecordingsmap' VALUES (3813, 9094, NULL, 2762);
INSERT INTO 'dancesrecordingsmap' VALUES (5910, 10822, NULL, 6177);
INSERT INTO 'dancesrecordingsmap' VALUES (9347, 14320, NULL, 6177);
INSERT INTO 'dancesrecordingsmap' VALUES (9349, 15037, NULL, 6230);
INSERT INTO 'dancesrecordingsmap' VALUES (9350, 2781, NULL, 9056);
INSERT INTO 'dancesrecordingsmap' VALUES (6492, 658, NULL, 6644);
INSERT INTO 'dancesrecordingsmap' VALUES (4085, 9542, NULL, 5113);
INSERT INTO 'dancesrecordingsmap' VALUES (9351, 19773, NULL, 5113);
INSERT INTO 'dancesrecordingsmap' VALUES (5694, 12459, NULL, 4674);
INSERT INTO 'dancesrecordingsmap' VALUES (6191, 13048, NULL, 4674);
INSERT INTO 'dancesrecordingsmap' VALUES (9353, 9137, NULL, 4674);
INSERT INTO 'dancesrecordingsmap' VALUES (9354, 10111, NULL, 4585);
INSERT INTO 'dancesrecordingsmap' VALUES (9355, 1881, NULL, 6108);
INSERT INTO 'dancesrecordingsmap' VALUES (9356, 6153, NULL, 8052);
INSERT INTO 'dancesrecordingsmap' VALUES (9357, 1834, NULL, 6101);
INSERT INTO 'dancesrecordingsmap' VALUES (9358, 15889, NULL, 6427);
INSERT INTO 'dancesrecordingsmap' VALUES (85, 3172, NULL, 132);
INSERT INTO 'dancesrecordingsmap' VALUES (167, 5260, NULL, 254);
INSERT INTO 'dancesrecordingsmap' VALUES (5310, 11952, NULL, 5485);
INSERT INTO 'dancesrecordingsmap' VALUES (7722, 13829, NULL, 5485);
INSERT INTO 'dancesrecordingsmap' VALUES (7657, 1931, NULL, 8285);
INSERT INTO 'dancesrecordingsmap' VALUES (4986, 3748, NULL, 5640);
INSERT INTO 'dancesrecordingsmap' VALUES (9359, 3561, NULL, 9302);
INSERT INTO 'dancesrecordingsmap' VALUES (9360, 3310, NULL, 9303);
INSERT INTO 'dancesrecordingsmap' VALUES (9361, 8152, NULL, 9306);
INSERT INTO 'dancesrecordingsmap' VALUES (9362, 12735, NULL, 9309);
INSERT INTO 'dancesrecordingsmap' VALUES (9363, 445, NULL, 9313);
INSERT INTO 'dancesrecordingsmap' VALUES (9364, 8153, NULL, 9314);
INSERT INTO 'dancesrecordingsmap' VALUES (9365, 3129, NULL, 9315);
INSERT INTO 'dancesrecordingsmap' VALUES (9366, 6010, NULL, 9317);
INSERT INTO 'dancesrecordingsmap' VALUES (9367, 2203, NULL, 9318);
INSERT INTO 'dancesrecordingsmap' VALUES (9368, 1038, NULL, 9820);
INSERT INTO 'dancesrecordingsmap' VALUES (9369, 16012, NULL, 9817);
INSERT INTO 'dancesrecordingsmap' VALUES (9370, 6359, NULL, 2171);
INSERT INTO 'dancesrecordingsmap' VALUES (9371, 1792, NULL, 6344);
INSERT INTO 'dancesrecordingsmap' VALUES (9372, 15051, NULL, 6597);
INSERT INTO 'dancesrecordingsmap' VALUES (9373, 18772, NULL, 5488);
INSERT INTO 'dancesrecordingsmap' VALUES (4663, 4565, NULL, 5486);
INSERT INTO 'dancesrecordingsmap' VALUES (9263, 13737, NULL, 5486);
INSERT INTO 'dancesrecordingsmap' VALUES (3304, 8830, NULL, 360);
INSERT INTO 'dancesrecordingsmap' VALUES (4271, 10250, NULL, 360);
INSERT INTO 'dancesrecordingsmap' VALUES (9374, 18706, NULL, 360);
INSERT INTO 'dancesrecordingsmap' VALUES (3638, 8968, NULL, 311);
INSERT INTO 'dancesrecordingsmap' VALUES (4888, 11465, NULL, 311);
INSERT INTO 'dancesrecordingsmap' VALUES (6293, 13197, NULL, 311);
INSERT INTO 'dancesrecordingsmap' VALUES (9145, 18507, NULL, 311);
INSERT INTO 'dancesrecordingsmap' VALUES (8107, 4015, NULL, 8947);
INSERT INTO 'dancesrecordingsmap' VALUES (9375, 19778, NULL, 8058);
INSERT INTO 'dancesrecordingsmap' VALUES (9377, 7574, NULL, 7469);
INSERT INTO 'dancesrecordingsmap' VALUES (9378, 411, NULL, 7568);
INSERT INTO 'dancesrecordingsmap' VALUES (9379, 8044, NULL, 7568);
INSERT INTO 'dancesrecordingsmap' VALUES (9380, 3677, NULL, 7568);
INSERT INTO 'dancesrecordingsmap' VALUES (9381, 5576, NULL, 7568);
INSERT INTO 'dancesrecordingsmap' VALUES (7028, 12302, NULL, 7243);
INSERT INTO 'dancesrecordingsmap' VALUES (7418, 6037, NULL, 7821);
INSERT INTO 'dancesrecordingsmap' VALUES (8026, 4862, NULL, 8826);
INSERT INTO 'dancesrecordingsmap' VALUES (8851, 15307, NULL, 9390);
INSERT INTO 'dancesrecordingsmap' VALUES (9383, 19797, NULL, 9390);
INSERT INTO 'dancesrecordingsmap' VALUES (1834, 4227, NULL, 2286);
INSERT INTO 'dancesrecordingsmap' VALUES (9384, 15676, NULL, 9783);
INSERT INTO 'dancesrecordingsmap' VALUES (1194, 2431, NULL, 1446);
INSERT INTO 'dancesrecordingsmap' VALUES (9386, 2477, NULL, 1446);
INSERT INTO 'dancesrecordingsmap' VALUES (9387, 4278, NULL, 3551);
INSERT INTO 'dancesrecordingsmap' VALUES (9388, 19785, NULL, 9963);
INSERT INTO 'dancesrecordingsmap' VALUES (9389, 18232, NULL, 10313);
INSERT INTO 'dancesrecordingsmap' VALUES (5102, 11394, NULL, 5714);
INSERT INTO 'dancesrecordingsmap' VALUES (8620, 15667, NULL, 5714);
INSERT INTO 'dancesrecordingsmap' VALUES (9390, 14140, NULL, 5714);
INSERT INTO 'dancesrecordingsmap' VALUES (9173, 14450, NULL, 8908);
INSERT INTO 'dancesrecordingsmap' VALUES (1449, 1777, NULL, 1786);
INSERT INTO 'dancesrecordingsmap' VALUES (9391, 7397, NULL, 1786);
INSERT INTO 'dancesrecordingsmap' VALUES (9392, 19837, NULL, 10300);
INSERT INTO 'dancesrecordingsmap' VALUES (8316, 11629, NULL, 9429);
INSERT INTO 'dancesrecordingsmap' VALUES (8317, 15280, NULL, 9429);
INSERT INTO 'dancesrecordingsmap' VALUES (8089, 428, NULL, 8928);
INSERT INTO 'dancesrecordingsmap' VALUES (2155, 5330, NULL, 2675);
INSERT INTO 'dancesrecordingsmap' VALUES (4385, 10475, NULL, 8);
INSERT INTO 'dancesrecordingsmap' VALUES (9393, 624, NULL, 8);
INSERT INTO 'dancesrecordingsmap' VALUES (9394, 3168, NULL, 7769);
INSERT INTO 'dancesrecordingsmap' VALUES (851, 3542, NULL, 1031);
INSERT INTO 'dancesrecordingsmap' VALUES (9395, 5471, NULL, 1031);
INSERT INTO 'dancesrecordingsmap' VALUES (9396, 19841, NULL, 322);
INSERT INTO 'dancesrecordingsmap' VALUES (5007, 10682, NULL, 5655);
INSERT INTO 'dancesrecordingsmap' VALUES (8723, 12579, NULL, 5655);
INSERT INTO 'dancesrecordingsmap' VALUES (9385, 16567, NULL, 5655);
INSERT INTO 'dancesrecordingsmap' VALUES (9397, 16906, NULL, 5655);
INSERT INTO 'dancesrecordingsmap' VALUES (9280, 4938, NULL, 10292);
INSERT INTO 'dancesrecordingsmap' VALUES (9102, 11549, NULL, 2519);
INSERT INTO 'dancesrecordingsmap' VALUES (9376, 13593, NULL, 10071);
INSERT INTO 'dancesrecordingsmap' VALUES (9327, 19682, NULL, 8046);
INSERT INTO 'dancesrecordingsmap' VALUES (6716, 745, NULL, 6869);
INSERT INTO 'dancesrecordingsmap' VALUES (302, 1210, NULL, 220);
INSERT INTO 'dancesrecordingsmap' VALUES (9398, 16715, NULL, 220);
INSERT INTO 'dancesrecordingsmap' VALUES (9399, 19828, NULL, 6203);
INSERT INTO 'dancesrecordingsmap' VALUES (9400, 16101, NULL, 1410);
INSERT INTO 'dancesrecordingsmap' VALUES (9401, 13263, NULL, 6980);
INSERT INTO 'dancesrecordingsmap' VALUES (9402, 19849, NULL, 7074);
INSERT INTO 'dancesrecordingsmap' VALUES (9403, 19859, NULL, 5752);
INSERT INTO 'dancesrecordingsmap' VALUES (9404, 18084, NULL, 6226);
INSERT INTO 'dancesrecordingsmap' VALUES (9405, 19722, NULL, 2515);
INSERT INTO 'dancesrecordingsmap' VALUES (9406, 19887, NULL, 3492);
INSERT INTO 'dancesrecordingsmap' VALUES (670, 4679, NULL, 845);
INSERT INTO 'dancesrecordingsmap' VALUES (4288, 10268, NULL, 845);
INSERT INTO 'dancesrecordingsmap' VALUES (9407, 14540, NULL, 845);
INSERT INTO 'dancesrecordingsmap' VALUES (9408, 13758, NULL, 937);
INSERT INTO 'dancesrecordingsmap' VALUES (4081, 1804, NULL, 5109);
INSERT INTO 'dancesrecordingsmap' VALUES (8796, 17251, NULL, 5109);
INSERT INTO 'dancesrecordingsmap' VALUES (9410, 8326, NULL, 2222);
INSERT INTO 'dancesrecordingsmap' VALUES (1669, 1624, NULL, 2085);
INSERT INTO 'dancesrecordingsmap' VALUES (1959, 549, NULL, 2416);
INSERT INTO 'dancesrecordingsmap' VALUES (9411, 6928, NULL, 2416);
INSERT INTO 'dancesrecordingsmap' VALUES (9412, 1943, NULL, 352);
INSERT INTO 'dancesrecordingsmap' VALUES (9413, 6701, NULL, 10350);
INSERT INTO 'dancesrecordingsmap' VALUES (9414, 6748, NULL, 10351);
INSERT INTO 'dancesrecordingsmap' VALUES (9415, 1473, NULL, 10352);
INSERT INTO 'dancesrecordingsmap' VALUES (9416, 4805, NULL, 10353);
INSERT INTO 'dancesrecordingsmap' VALUES (9417, 3941, NULL, 10354);
INSERT INTO 'dancesrecordingsmap' VALUES (9420, 19517, NULL, 10357);
INSERT INTO 'dancesrecordingsmap' VALUES (9421, 7180, NULL, 10358);
INSERT INTO 'dancesrecordingsmap' VALUES (9422, 19979, NULL, 10359);
INSERT INTO 'dancesrecordingsmap' VALUES (9423, 7061, NULL, 10360);
INSERT INTO 'dancesrecordingsmap' VALUES (9425, 16535, NULL, 10362);
INSERT INTO 'dancesrecordingsmap' VALUES (9426, 19516, NULL, 10363);
INSERT INTO 'dancesrecordingsmap' VALUES (9427, 19514, NULL, 10364);
INSERT INTO 'dancesrecordingsmap' VALUES (9428, 4968, NULL, 10365);
INSERT INTO 'dancesrecordingsmap' VALUES (9429, 4491, NULL, 10366);
INSERT INTO 'dancesrecordingsmap' VALUES (9424, 7284, NULL, 10361);
INSERT INTO 'dancesrecordingsmap' VALUES (9418, 314, NULL, 10355);
INSERT INTO 'dancesrecordingsmap' VALUES (4491, 9124, NULL, 5451);
INSERT INTO 'dancesrecordingsmap' VALUES (9430, 13089, NULL, 5451);
INSERT INTO 'dancesrecordingsmap' VALUES (7853, 2934, NULL, 8466);
INSERT INTO 'dancesrecordingsmap' VALUES (9431, 8087, NULL, 8466);
INSERT INTO 'dancesrecordingsmap' VALUES (9433, 12247, 285, 10369);
INSERT INTO 'dancesrecordingsmap' VALUES (9432, 17669, NULL, 10367);
INSERT INTO 'dancesrecordingsmap' VALUES (9435, 2413, NULL, 10371);
INSERT INTO 'dancesrecordingsmap' VALUES (6928, 13500, NULL, 7085);
INSERT INTO 'dancesrecordingsmap' VALUES (9436, 19986, NULL, 7085);
INSERT INTO 'dancesrecordingsmap' VALUES (2770, 7368, NULL, 3432);
INSERT INTO 'dancesrecordingsmap' VALUES (2771, 215, NULL, 3432);
INSERT INTO 'dancesrecordingsmap' VALUES (9437, 19733, NULL, 3432);
INSERT INTO 'dancesrecordingsmap' VALUES (9438, 19987, NULL, 6582);
INSERT INTO 'dancesrecordingsmap' VALUES (9439, 18446, NULL, 893);
INSERT INTO 'dancesrecordingsmap' VALUES (9440, 20001, NULL, 9379);
INSERT INTO 'dancesrecordingsmap' VALUES (9441, 19992, NULL, 5912);
INSERT INTO 'dancesrecordingsmap' VALUES (9442, 19992, NULL, 5465);
INSERT INTO 'dancesrecordingsmap' VALUES (9443, 18451, NULL, 7783);
INSERT INTO 'dancesrecordingsmap' VALUES (5111, 11399, NULL, 5721);
INSERT INTO 'dancesrecordingsmap' VALUES (9444, 19993, NULL, 5721);
INSERT INTO 'dancesrecordingsmap' VALUES (9445, 20009, NULL, 10232);
INSERT INTO 'dancesrecordingsmap' VALUES (9446, 20010, NULL, 10225);
INSERT INTO 'dancesrecordingsmap' VALUES (9447, 20028, NULL, 5659);
INSERT INTO 'dancesrecordingsmap' VALUES (9448, 20034, NULL, 5947);
INSERT INTO 'dancesrecordingsmap' VALUES (9451, 6010, NULL, 10405);
INSERT INTO 'dancesrecordingsmap' VALUES (9452, 16484, NULL, 10404);
INSERT INTO 'dancesrecordingsmap' VALUES (9453, 16485, NULL, 10403);
INSERT INTO 'dancesrecordingsmap' VALUES (9454, 16487, NULL, 10400);
INSERT INTO 'dancesrecordingsmap' VALUES (9455, 16486, NULL, 10398);
INSERT INTO 'dancesrecordingsmap' VALUES (9456, 20041, NULL, 8811);
INSERT INTO 'dancesrecordingsmap' VALUES (9457, 14640, NULL, 8813);
INSERT INTO 'dancesrecordingsmap' VALUES (9458, 20042, NULL, 10279);
INSERT INTO 'dancesrecordingsmap' VALUES (9462, 18494, NULL, 10412);
INSERT INTO 'dancesrecordingsmap' VALUES (9450, 20032, NULL, 6970);
INSERT INTO 'dancesrecordingsmap' VALUES (9459, 20043, NULL, 9433);
INSERT INTO 'dancesrecordingsmap' VALUES (8663, 16110, NULL, 2244);
INSERT INTO 'dancesrecordingsmap' VALUES (9466, 10820, NULL, 10406);
INSERT INTO 'dancesrecordingsmap' VALUES (9467, 18490, NULL, 10407);
INSERT INTO 'dancesrecordingsmap' VALUES (9468, 17882, NULL, 10408);
INSERT INTO 'dancesrecordingsmap' VALUES (9461, 18491, NULL, 10409);
INSERT INTO 'dancesrecordingsmap' VALUES (9469, 18492, NULL, 10410);
INSERT INTO 'dancesrecordingsmap' VALUES (9470, 18493, NULL, 10411);
INSERT INTO 'dancesrecordingsmap' VALUES (9463, 12036, NULL, 10413);
INSERT INTO 'dancesrecordingsmap' VALUES (9464, 152, NULL, 10414);
INSERT INTO 'dancesrecordingsmap' VALUES (9465, 428, NULL, 10415);
INSERT INTO 'dancesrecordingsmap' VALUES (9472, 20070, NULL, 5945);
INSERT INTO 'dancesrecordingsmap' VALUES (9473, 20073, NULL, 5691);
INSERT INTO 'dancesrecordingsmap' VALUES (9474, 20075, NULL, 5144);
INSERT INTO 'dancesrecordingsmap' VALUES (9475, 5731, NULL, 7538);
INSERT INTO 'dancesrecordingsmap' VALUES (9476, 20078, NULL, 6502);
INSERT INTO 'dancesrecordingsmap' VALUES (9477, 7487, NULL, 906);
INSERT INTO 'dancesrecordingsmap' VALUES (9478, 20083, NULL, 566);
INSERT INTO 'dancesrecordingsmap' VALUES (9479, 20084, NULL, 6970);
INSERT INTO 'dancesrecordingsmap' VALUES (9492, 16852, NULL, 9433);
INSERT INTO 'dancesrecordingsmap' VALUES (9493, 16850, NULL, 6376);
INSERT INTO 'dancesrecordingsmap' VALUES (9494, 16849, NULL, 6117);
INSERT INTO 'dancesrecordingsmap' VALUES (9496, 19942, NULL, 441);
INSERT INTO 'dancesrecordingsmap' VALUES (9497, 20199, NULL, 437);
INSERT INTO 'dancesrecordingsmap' VALUES (9498, 15419, NULL, 7316);
INSERT INTO 'dancesrecordingsmap' VALUES (9499, 15774, NULL, 5229);
INSERT INTO 'dancesrecordingsmap' VALUES (8759, 6717, NULL, 726);
INSERT INTO 'dancesrecordingsmap' VALUES (9304, 19521, NULL, 726);
INSERT INTO 'dancesrecordingsmap' VALUES (9500, 10745, NULL, 726);
INSERT INTO 'dancesrecordingsmap' VALUES (9501, 11774, NULL, 4689);
INSERT INTO 'dancesrecordingsmap' VALUES (9502, 20222, NULL, 9951);
INSERT INTO 'dancesrecordingsmap' VALUES (9503, 20050, NULL, 7014);
INSERT INTO 'dancesrecordingsmap' VALUES (9504, 19712, NULL, 5385);
INSERT INTO 'dancesrecordingsmap' VALUES (9505, 13100, NULL, 3242);
INSERT INTO 'dancesrecordingsmap' VALUES (9506, 8246, NULL, 3046);
INSERT INTO 'dancesrecordingsmap' VALUES (9508, 7348, NULL, 1349);
INSERT INTO 'dancesrecordingsmap' VALUES (9509, 7318, NULL, 940);
INSERT INTO 'dancesrecordingsmap' VALUES (9510, 7256, NULL, 2562);
INSERT INTO 'dancesrecordingsmap' VALUES (6001, 12781, NULL, 4441);
INSERT INTO 'dancesrecordingsmap' VALUES (9511, 20286, NULL, 4441);
INSERT INTO 'dancesrecordingsmap' VALUES (9471, 20059, NULL, 2037);
INSERT INTO 'dancesrecordingsmap' VALUES (9513, 15093, NULL, 2037);
INSERT INTO 'dancesrecordingsmap' VALUES (9514, 20283, NULL, 2268);
INSERT INTO 'dancesrecordingsmap' VALUES (554, 5111, NULL, 722);
INSERT INTO 'dancesrecordingsmap' VALUES (9515, 20293, NULL, 722);
INSERT INTO 'dancesrecordingsmap' VALUES (9516, 3743, NULL, 10436);
INSERT INTO 'dancesrecordingsmap' VALUES (9517, 6890, NULL, 529);
INSERT INTO 'dancesrecordingsmap' VALUES (9518, 2306, NULL, 1969);
INSERT INTO 'dancesrecordingsmap' VALUES (2974, 523, NULL, 2024);
INSERT INTO 'dancesrecordingsmap' VALUES (9520, 6783, NULL, 2024);
INSERT INTO 'dancesrecordingsmap' VALUES (6327, 13249, NULL, 5728);
INSERT INTO 'dancesrecordingsmap' VALUES (9521, 7419, NULL, 2379);
INSERT INTO 'dancesrecordingsmap' VALUES (2465, 3941, NULL, 3098);
INSERT INTO 'dancesrecordingsmap' VALUES (9522, 5534, NULL, 3098);
INSERT INTO 'dancesrecordingsmap' VALUES (9523, 20334, NULL, 9024);
INSERT INTO 'dancesrecordingsmap' VALUES (9524, 20336, NULL, 9396);
INSERT INTO 'dancesrecordingsmap' VALUES (9525, 5564, NULL, 2192);
INSERT INTO 'dancesrecordingsmap' VALUES (9526, 20336, NULL, 10103);
INSERT INTO 'dancesrecordingsmap' VALUES (9527, 17483, NULL, 10110);
INSERT INTO 'dancesrecordingsmap' VALUES (9528, 4875, NULL, 4804);
INSERT INTO 'dancesrecordingsmap' VALUES (9529, 20343, NULL, 5719);
INSERT INTO 'dancesrecordingsmap' VALUES (9530, 20342, NULL, 9524);
INSERT INTO 'dancesrecordingsmap' VALUES (9531, 17992, NULL, 5788);
INSERT INTO 'dancesrecordingsmap' VALUES (9532, 8112, NULL, 1422);
INSERT INTO 'dancesrecordingsmap' VALUES (9533, 3900, NULL, 4143);
INSERT INTO 'dancesrecordingsmap' VALUES (9534, 15768, NULL, 6892);
INSERT INTO 'dancesrecordingsmap' VALUES (9537, 3475, NULL, 1536);
INSERT INTO 'dancesrecordingsmap' VALUES (9539, 3387, NULL, 10440);
INSERT INTO 'dancesrecordingsmap' VALUES (9540, 3261, NULL, 2338);
INSERT INTO 'dancesrecordingsmap' VALUES (9541, 3200, NULL, 1542);
INSERT INTO 'dancesrecordingsmap' VALUES (9543, 20346, NULL, 6811);
INSERT INTO 'dancesrecordingsmap' VALUES (9544, 20344, NULL, 9929);
INSERT INTO 'dancesrecordingsmap' VALUES (9545, 17285, NULL, 6651);
INSERT INTO 'dancesrecordingsmap' VALUES (9548, 4747, NULL, 2288);
INSERT INTO 'dancesrecordingsmap' VALUES (9550, 20345, NULL, 6216);
INSERT INTO 'dancesrecordingsmap' VALUES (9495, 16848, NULL, 5731);
INSERT INTO 'dancesrecordingsmap' VALUES (9551, 18841, NULL, 5731);
INSERT INTO 'dancesrecordingsmap' VALUES (4894, 11470, NULL, 5331);
INSERT INTO 'dancesrecordingsmap' VALUES (9553, 18708, NULL, 5331);
INSERT INTO 'dancesrecordingsmap' VALUES (9554, 19690, NULL, 347);
INSERT INTO 'dancesrecordingsmap' VALUES (9555, 15076, NULL, 5720);
INSERT INTO 'dancesrecordingsmap' VALUES (9556, 8394, NULL, 151);
INSERT INTO 'dancesrecordingsmap' VALUES (9557, 7057, NULL, 2145);
INSERT INTO 'dancesrecordingsmap' VALUES (5540, 341, NULL, 2400);
INSERT INTO 'dancesrecordingsmap' VALUES (9558, 935, NULL, 2400);
INSERT INTO 'dancesrecordingsmap' VALUES (9559, 1878, NULL, 1346);
INSERT INTO 'dancesrecordingsmap' VALUES (9560, 3944, NULL, 2455);
INSERT INTO 'dancesrecordingsmap' VALUES (9561, 4792, NULL, 2003);
INSERT INTO 'dancesrecordingsmap' VALUES (9562, 861, NULL, 1980);
INSERT INTO 'dancesrecordingsmap' VALUES (1880, 462, NULL, 2327);
INSERT INTO 'dancesrecordingsmap' VALUES (9563, 6013, NULL, 2327);
INSERT INTO 'dancesrecordingsmap' VALUES (9564, 3860, NULL, 2051);
INSERT INTO 'dancesrecordingsmap' VALUES (9481, 5239, NULL, 10418);
INSERT INTO 'dancesrecordingsmap' VALUES (9482, 4565, NULL, 10419);
INSERT INTO 'dancesrecordingsmap' VALUES (9483, 2024, NULL, 10420);
INSERT INTO 'dancesrecordingsmap' VALUES (9484, 3828, NULL, 10421);
INSERT INTO 'dancesrecordingsmap' VALUES (9485, 19619, NULL, 10422);
INSERT INTO 'dancesrecordingsmap' VALUES (9486, 20181, NULL, 10423);
INSERT INTO 'dancesrecordingsmap' VALUES (9487, 20182, NULL, 10424);
INSERT INTO 'dancesrecordingsmap' VALUES (9489, 13588, NULL, 10426);
INSERT INTO 'dancesrecordingsmap' VALUES (9490, 9770, NULL, 10427);
INSERT INTO 'dancesrecordingsmap' VALUES (9491, 19118, NULL, 10430);
INSERT INTO 'dancesrecordingsmap' VALUES (9449, 20033, NULL, 5582);
INSERT INTO 'dancesrecordingsmap' VALUES (9409, 19864, NULL, 6523);
INSERT INTO 'dancesrecordingsmap' VALUES (9382, 19789, NULL, 7080);
INSERT INTO 'dancesrecordingsmap' VALUES (9538, 3446, NULL, 1809);
INSERT INTO 'dancesrecordingsmap' VALUES (9419, 11190, NULL, 10356);
INSERT INTO 'dancesrecordingsmap' VALUES (9536, 3613, NULL, 464);
INSERT INTO 'dancesrecordingsmap' VALUES (9542, 20347, NULL, 10039);
INSERT INTO 'dancesrecordingsmap' VALUES (9552, 17693, NULL, 7582);
INSERT INTO 'dancesrecordingsmap' VALUES (9434, 7572, NULL, 10370);
INSERT INTO 'dancesrecordingsmap' VALUES (9546, 3085, NULL, 1414);
INSERT INTO 'dancesrecordingsmap' VALUES (9565, 3135, NULL, 1414);
INSERT INTO 'dancesrecordingsmap' VALUES (9566, 15871, NULL, 5849);
INSERT INTO 'dancesrecordingsmap' VALUES (9519, 11873, NULL, 5501);
INSERT INTO 'dancesrecordingsmap' VALUES (9567, 15873, NULL, 5501);
INSERT INTO 'dancesrecordingsmap' VALUES (7372, 7245, NULL, 7773);
INSERT INTO 'dancesrecordingsmap' VALUES (9568, 15880, NULL, 7773);
INSERT INTO 'dancesrecordingsmap' VALUES (9570, 1180, NULL, 1614);
INSERT INTO 'dancesrecordingsmap' VALUES (5650, 5381, NULL, 1617);
INSERT INTO 'dancesrecordingsmap' VALUES (9569, 2032, NULL, 1617);
INSERT INTO 'dancesrecordingsmap' VALUES (9571, 6283, NULL, 1617);
INSERT INTO 'dancesrecordingsmap' VALUES (1625, 849, NULL, 1998);
INSERT INTO 'dancesrecordingsmap' VALUES (9547, 2882, NULL, 1998);
INSERT INTO 'dancesrecordingsmap' VALUES (9573, 1882, NULL, 1998);
INSERT INTO 'dancesrecordingsmap' VALUES (9572, 2467, NULL, 1613);
INSERT INTO 'dancesrecordingsmap' VALUES (9574, 828, NULL, 1613);
INSERT INTO 'dancesrecordingsmap' VALUES (9576, 3069, NULL, 1857);
INSERT INTO 'dancesrecordingsmap' VALUES (9577, 931, NULL, 1819);
INSERT INTO 'dancesrecordingsmap' VALUES (9549, 5772, NULL, 1914);
INSERT INTO 'dancesrecordingsmap' VALUES (9578, 3877, NULL, 1914);
INSERT INTO 'dancesrecordingsmap' VALUES (9579, 1511, NULL, 2048);
INSERT INTO 'dancesrecordingsmap' VALUES (1720, 7678, NULL, 2141);
INSERT INTO 'dancesrecordingsmap' VALUES (9580, 20352, NULL, 2141);
INSERT INTO 'dancesrecordingsmap' VALUES (9581, 11808, NULL, 578);
INSERT INTO 'dancesrecordingsmap' VALUES (9582, 14553, NULL, 2645);
INSERT INTO 'dancesrecordingsmap' VALUES (9583, 20353, NULL, 4698);
INSERT INTO 'dancesrecordingsmap' VALUES (9584, 20354, NULL, 682);
INSERT INTO 'dancesrecordingsmap' VALUES (9585, 20355, NULL, 1404);
INSERT INTO 'dancesrecordingsmap' VALUES (9586, 20356, NULL, 498);
INSERT INTO 'dancesrecordingsmap' VALUES (2132, 2595, NULL, 2643);
INSERT INTO 'dancesrecordingsmap' VALUES (9587, 20357, NULL, 2643);
INSERT INTO 'dancesrecordingsmap' VALUES (9588, 20358, NULL, 1855);
INSERT INTO 'dancesrecordingsmap' VALUES (9589, 103, NULL, 1398);
INSERT INTO 'dancesrecordingsmap' VALUES (9591, 547, NULL, 1373);
INSERT INTO 'dancesrecordingsmap' VALUES (9592, 545, NULL, 706);
INSERT INTO 'dancesrecordingsmap' VALUES (9593, 10117, NULL, 1815);
INSERT INTO 'dancesrecordingsmap' VALUES (9512, 7164, NULL, 2463);
INSERT INTO 'dancesrecordingsmap' VALUES (9594, 10120, NULL, 2463);
INSERT INTO 'dancesrecordingsmap' VALUES (9595, 10119, NULL, 2244);
INSERT INTO 'dancesrecordingsmap' VALUES (9596, 10119, NULL, 521);
INSERT INTO 'dancesrecordingsmap' VALUES (454, 4907, NULL, 614);
INSERT INTO 'dancesrecordingsmap' VALUES (9597, 10119, NULL, 614);
INSERT INTO 'dancesrecordingsmap' VALUES (9598, 10118, NULL, 3499);
INSERT INTO 'dancesrecordingsmap' VALUES (9599, 10118, NULL, 1563);
INSERT INTO 'dancesrecordingsmap' VALUES (9575, 2177, NULL, 2457);
INSERT INTO 'dancesrecordingsmap' VALUES (9600, 397, NULL, 2457);
INSERT INTO 'dancesrecordingsmap' VALUES (1481, 6152, NULL, 1820);
INSERT INTO 'dancesrecordingsmap' VALUES (9601, 397, NULL, 1820);
INSERT INTO 'dancesrecordingsmap' VALUES (9602, 19975, NULL, 10447);
INSERT INTO 'dancesrecordingsmap' VALUES (9603, 11331, NULL, 3471);
INSERT INTO 'dancesrecordingsmap' VALUES (9604, 20390, NULL, 5811);
INSERT INTO 'dancesrecordingsmap' VALUES (9605, 13797, NULL, 5758);
INSERT INTO 'dancesrecordingsmap' VALUES (9606, 12629, NULL, 680);
INSERT INTO 'dancesrecordingsmap' VALUES (9608, 20393, NULL, 7026);
INSERT INTO 'dancesrecordingsmap' VALUES (9609, 20394, NULL, 6052);
INSERT INTO 'dancesrecordingsmap' VALUES (9610, 9157, NULL, 10446);
INSERT INTO 'dancesrecordingsmap' VALUES (9611, 20421, NULL, 6566);
INSERT INTO 'dancesrecordingsmap' VALUES (9612, 20351, NULL, 987);
INSERT INTO 'dancesrecordingsmap' VALUES (9613, 20427, NULL, 8253);
INSERT INTO 'dancesrecordingsmap' VALUES (9614, 12635, NULL, 10451);
INSERT INTO 'dancesrecordingsmap' VALUES (9615, 12140, NULL, 1096);
INSERT INTO 'dancesrecordingsmap' VALUES (9616, 17145, NULL, 299);
INSERT INTO 'dancesrecordingsmap' VALUES (9617, 20428, NULL, 7960);
INSERT INTO 'dancesrecordingsmap' VALUES (9618, 20430, NULL, 6993);
INSERT INTO 'dancesrecordingsmap' VALUES (9619, 20431, NULL, 1345);
INSERT INTO 'dancesrecordingsmap' VALUES (9622, 20434, NULL, 5235);
INSERT INTO 'dancesrecordingsmap' VALUES (9623, 20444, NULL, 1919);
INSERT INTO 'dancesrecordingsmap' VALUES (9624, 20447, NULL, 7060);
INSERT INTO 'dancesrecordingsmap' VALUES (9625, 20432, NULL, 10452);
INSERT INTO 'dancesrecordingsmap' VALUES (9626, 20437, NULL, 10453);
INSERT INTO 'dancesrecordingsmap' VALUES (9627, 20436, NULL, 10454);
INSERT INTO 'dancesrecordingsmap' VALUES (9607, 20392, NULL, 10215);
INSERT INTO 'dancesrecordingsmap' VALUES (9507, 14750, NULL, 406);
INSERT INTO 'dancesrecordingsmap' VALUES (9628, 20435, NULL, 10455);
INSERT INTO 'dancesrecordingsmap' VALUES (9629, 20439, NULL, 10457);
INSERT INTO 'dancesrecordingsmap' VALUES (9630, 20441, NULL, 10459);
INSERT INTO 'dancesrecordingsmap' VALUES (9631, 20442, NULL, 10460);
INSERT INTO 'dancesrecordingsmap' VALUES (9632, 20448, NULL, 2454);
INSERT INTO 'dancesrecordingsmap' VALUES (9633, 20443, NULL, 10461);
INSERT INTO 'dancesrecordingsmap' VALUES (9634, 20445, NULL, 10462);
INSERT INTO 'dancesrecordingsmap' VALUES (9636, 20401, NULL, 3484);
INSERT INTO 'dancesrecordingsmap' VALUES (9637, 19120, NULL, 9470);
INSERT INTO 'dancesrecordingsmap' VALUES (3541, 8913, NULL, 1232);
INSERT INTO 'dancesrecordingsmap' VALUES (9640, 20451, NULL, 724);
INSERT INTO 'dancesrecordingsmap' VALUES (9642, 20453, NULL, 5734);
INSERT INTO 'dancesrecordingsmap' VALUES (9643, 20455, NULL, 9989);
INSERT INTO 'dancesrecordingsmap' VALUES (9644, 20454, NULL, 5843);
INSERT INTO 'dancesrecordingsmap' VALUES (9645, 20456, NULL, 6378);
INSERT INTO 'dancesrecordingsmap' VALUES (9646, 20458, NULL, 3915);
INSERT INTO 'dancesrecordingsmap' VALUES (9647, 20459, NULL, 6895);
INSERT INTO 'dancesrecordingsmap' VALUES (9648, 6056, NULL, 10382);
INSERT INTO 'dancesrecordingsmap' VALUES (9649, 11724, NULL, 10368);
INSERT INTO 'dancesrecordingsmap' VALUES (9650, 17664, NULL, 10372);
INSERT INTO 'dancesrecordingsmap' VALUES (9651, 17671, NULL, 10373);
INSERT INTO 'dancesrecordingsmap' VALUES (9652, 17665, NULL, 10374);
INSERT INTO 'dancesrecordingsmap' VALUES (9653, 17666, NULL, 10375);
INSERT INTO 'dancesrecordingsmap' VALUES (9654, 17672, NULL, 10376);
INSERT INTO 'dancesrecordingsmap' VALUES (9655, 17673, NULL, 10377);
INSERT INTO 'dancesrecordingsmap' VALUES (9656, 17674, NULL, 10378);
INSERT INTO 'dancesrecordingsmap' VALUES (9657, 5272, NULL, 10379);
INSERT INTO 'dancesrecordingsmap' VALUES (9658, 17670, NULL, 10380);
INSERT INTO 'dancesrecordingsmap' VALUES (9659, 7935, NULL, 10381);
INSERT INTO 'dancesrecordingsmap' VALUES (9660, 17667, NULL, 10383);
INSERT INTO 'dancesrecordingsmap' VALUES (9661, 3629, NULL, 2001);
INSERT INTO 'dancesrecordingsmap' VALUES (6074, 6036, NULL, 6304);
INSERT INTO 'dancesrecordingsmap' VALUES (9662, 16876, NULL, 10464);
INSERT INTO 'dancesrecordingsmap' VALUES (9663, 20397, NULL, 10466);
INSERT INTO 'dancesrecordingsmap' VALUES (9664, 20398, NULL, 10467);
INSERT INTO 'dancesrecordingsmap' VALUES (9665, 20399, NULL, 10468);
INSERT INTO 'dancesrecordingsmap' VALUES (9666, 20402, NULL, 10471);
INSERT INTO 'dancesrecordingsmap' VALUES (9667, 20403, NULL, 10472);
INSERT INTO 'dancesrecordingsmap' VALUES (9668, 20404, NULL, 10473);
INSERT INTO 'dancesrecordingsmap' VALUES (9669, 20405, NULL, 10474);
INSERT INTO 'dancesrecordingsmap' VALUES (9670, 16520, NULL, 10475);
INSERT INTO 'dancesrecordingsmap' VALUES (9671, 16520, NULL, 10476);
INSERT INTO 'dancesrecordingsmap' VALUES (4504, 10795, NULL, 5441);
INSERT INTO 'dancesrecordingsmap' VALUES (9672, 20497, NULL, 5452);
INSERT INTO 'dancesrecordingsmap' VALUES (9673, 20527, NULL, 97);
INSERT INTO 'dancesrecordingsmap' VALUES (9674, 20529, NULL, 10215);
INSERT INTO 'dancesrecordingsmap' VALUES (9675, 20530, NULL, 10217);
INSERT INTO 'dancesrecordingsmap' VALUES (300, 2135, NULL, 406);
INSERT INTO 'dancesrecordingsmap' VALUES (9676, 20067, NULL, 406);
INSERT INTO 'dancesrecordingsmap' VALUES (9677, 20548, NULL, 6222);
INSERT INTO 'dancesrecordingsmap' VALUES (9683, 5384, NULL, 10481);
INSERT INTO 'dancesrecordingsmap' VALUES (9684, 12428, NULL, 10482);
INSERT INTO 'dancesrecordingsmap' VALUES (9685, 739, NULL, 10483);
INSERT INTO 'dancesrecordingsmap' VALUES (9686, 3108, NULL, 10484);
INSERT INTO 'dancesrecordingsmap' VALUES (9687, 6701, NULL, 10485);
INSERT INTO 'dancesrecordingsmap' VALUES (9688, 6091, NULL, 10486);
INSERT INTO 'dancesrecordingsmap' VALUES (9691, 7282, NULL, 10489);
INSERT INTO 'dancesrecordingsmap' VALUES (9681, 8203, NULL, 10479);
INSERT INTO 'dancesrecordingsmap' VALUES (9680, 13617, NULL, 10478);
INSERT INTO 'dancesrecordingsmap' VALUES (9690, 845, NULL, 10488);
INSERT INTO 'dancesrecordingsmap' VALUES (9682, 13619, NULL, 10480);
INSERT INTO 'dancesrecordingsmap' VALUES (5893, 5964, NULL, 6159);
INSERT INTO 'dancesrecordingsmap' VALUES (9689, 13581, NULL, 10487);
INSERT INTO 'dancesrecordingsmap' VALUES (9679, 4336, NULL, 10477);
INSERT INTO 'dancesrecordingsmap' VALUES (9692, 20563, NULL, 10490);
INSERT INTO 'dancesrecordingsmap' VALUES (9693, 20543, NULL, 10286);
INSERT INTO 'dancesrecordingsmap' VALUES (6319, 13214, NULL, 6455);
INSERT INTO 'dancesrecordingsmap' VALUES (6375, 13357, NULL, 6518);
INSERT INTO 'dancesrecordingsmap' VALUES (8652, 13544, NULL, 6518);
INSERT INTO 'dancesrecordingsmap' VALUES (9694, 16191, NULL, 6518);
INSERT INTO 'dancesrecordingsmap' VALUES (9695, 14122, NULL, 5946);
INSERT INTO 'dancesrecordingsmap' VALUES (8867, 16952, NULL, 779);
INSERT INTO 'dancesrecordingsmap' VALUES (5077, 9008, NULL, 776);
INSERT INTO 'dancesrecordingsmap' VALUES (5078, 6063, NULL, 776);
INSERT INTO 'dancesrecordingsmap' VALUES (5057, 3659, NULL, 5671);
INSERT INTO 'dancesrecordingsmap' VALUES (3705, 3165, NULL, 4692);
INSERT INTO 'dancesrecordingsmap' VALUES (9697, 20618, NULL, 4692);
INSERT INTO 'dancesrecordingsmap' VALUES (9698, 3057, NULL, 9790);
INSERT INTO 'dancesrecordingsmap' VALUES (9699, 6233, 15, 9791);
INSERT INTO 'dancesrecordingsmap' VALUES (9700, 9561, NULL, 9792);
INSERT INTO 'dancesrecordingsmap' VALUES (9701, 5006, NULL, 9793);
INSERT INTO 'dancesrecordingsmap' VALUES (9702, 10008, NULL, 9794);
INSERT INTO 'dancesrecordingsmap' VALUES (9703, 3336, NULL, 9795);
INSERT INTO 'dancesrecordingsmap' VALUES (9704, 6915, NULL, 9797);
INSERT INTO 'dancesrecordingsmap' VALUES (9705, 10787, NULL, 9798);
INSERT INTO 'dancesrecordingsmap' VALUES (9706, 4782, NULL, 9799);
INSERT INTO 'dancesrecordingsmap' VALUES (9707, 6144, NULL, 9800);
INSERT INTO 'dancesrecordingsmap' VALUES (9708, 2203, NULL, 9801);
INSERT INTO 'dancesrecordingsmap' VALUES (9709, 985, NULL, 9802);
INSERT INTO 'dancesrecordingsmap' VALUES (9710, 1176, NULL, 9803);
INSERT INTO 'dancesrecordingsmap' VALUES (9711, 312, NULL, 9804);
INSERT INTO 'dancesrecordingsmap' VALUES (9712, 445, NULL, 9805);
INSERT INTO 'dancesrecordingsmap' VALUES (9713, 462, NULL, 9806);
INSERT INTO 'dancesrecordingsmap' VALUES (9714, 4641, NULL, 9807);
INSERT INTO 'dancesrecordingsmap' VALUES (9719, 19062, NULL, 10494);
INSERT INTO 'dancesrecordingsmap' VALUES (9720, 19063, NULL, 10495);
INSERT INTO 'dancesrecordingsmap' VALUES (9716, 19059, NULL, 10491);
INSERT INTO 'dancesrecordingsmap' VALUES (9717, 19060, NULL, 10492);
INSERT INTO 'dancesrecordingsmap' VALUES (9718, 19061, NULL, 10493);
INSERT INTO 'dancesrecordingsmap' VALUES (9721, 19064, NULL, 10496);
INSERT INTO 'dancesrecordingsmap' VALUES (9722, 19077, NULL, 10498);
INSERT INTO 'dancesrecordingsmap' VALUES (9723, 19078, NULL, 10499);
INSERT INTO 'dancesrecordingsmap' VALUES (9715, 20625, NULL, 7149);
INSERT INTO 'dancesrecordingsmap' VALUES (9480, 20148, NULL, 7080);
INSERT INTO 'dancesrecordingsmap' VALUES (9620, 20433, NULL, 6483);
INSERT INTO 'dancesrecordingsmap' VALUES (9678, 20551, NULL, 5268);
INSERT INTO 'dancesrecordingsmap' VALUES (5056, 3137, NULL, 5670);
INSERT INTO 'dancesrecordingsmap' VALUES (9696, 5232, NULL, 5670);
INSERT INTO 'dancesrecordingsmap' VALUES (9590, 20247, NULL, 7090);
INSERT INTO 'dancesrecordingsmap' VALUES (9724, 19079, NULL, 10500);
INSERT INTO 'dancesrecordingsmap' VALUES (9725, 19080, NULL, 10501);
INSERT INTO 'dancesrecordingsmap' VALUES (9726, 19081, NULL, 10502);
INSERT INTO 'dancesrecordingsmap' VALUES (9727, 19082, NULL, 10503);
INSERT INTO 'dancesrecordingsmap' VALUES (9728, 19083, NULL, 10504);
INSERT INTO 'dancesrecordingsmap' VALUES (9729, 19084, NULL, 10505);
INSERT INTO 'dancesrecordingsmap' VALUES (9730, 19085, NULL, 10506);
INSERT INTO 'dancesrecordingsmap' VALUES (1209, 7189, NULL, 1475);
INSERT INTO 'dancesrecordingsmap' VALUES (9731, 20626, NULL, 1475);
INSERT INTO 'dancesrecordingsmap' VALUES (725, 6010, 308, 895);
INSERT INTO 'dancesrecordingsmap' VALUES (2372, 4015, NULL, 2985);
INSERT INTO 'dancesrecordingsmap' VALUES (9733, 1404, NULL, 2985);
INSERT INTO 'dancesrecordingsmap' VALUES (8060, 14436, NULL, 8879);
INSERT INTO 'dancesrecordingsmap' VALUES (9734, 20640, NULL, 7027);
INSERT INTO 'dancesrecordingsmap' VALUES (309, 6089, NULL, 411);
INSERT INTO 'dancesrecordingsmap' VALUES (4206, 8492, NULL, 411);
INSERT INTO 'dancesrecordingsmap' VALUES (4824, 11360, NULL, 411);
INSERT INTO 'dancesrecordingsmap' VALUES (9735, 17826, NULL, 411);
INSERT INTO 'dancesrecordingsmap' VALUES (5495, 4929, NULL, 5999);
INSERT INTO 'dancesrecordingsmap' VALUES (9460, 18219, NULL, 5999);
INSERT INTO 'dancesrecordingsmap' VALUES (9736, 15602, NULL, 5999);
INSERT INTO 'dancesrecordingsmap' VALUES (2586, 3906, NULL, 3253);
INSERT INTO 'dancesrecordingsmap' VALUES (8031, 13885, NULL, 8831);
INSERT INTO 'dancesrecordingsmap' VALUES (9737, 19224, NULL, 8831);
INSERT INTO 'dancesrecordingsmap' VALUES (7674, 1562, NULL, 8302);
INSERT INTO 'dancesrecordingsmap' VALUES (9738, 20668, NULL, 8302);
INSERT INTO 'dancesrecordingsmap' VALUES (9739, 2858, NULL, 427);
INSERT INTO 'dancesrecordingsmap' VALUES (9740, 660, NULL, 10417);
INSERT INTO 'dancesrecordingsmap' VALUES (9488, 6368, NULL, 10425);
INSERT INTO 'dancesrecordingsmap' VALUES (6003, 12720, NULL, 5179);
INSERT INTO 'dancesrecordingsmap' VALUES (9743, 19476, NULL, 5179);
INSERT INTO 'dancesrecordingsmap' VALUES (9744, 20770, NULL, 5582);
INSERT INTO 'dancesrecordingsmap' VALUES (7751, 3789, NULL, 8356);
INSERT INTO 'dancesrecordingsmap' VALUES (9745, 18487, NULL, 8356);
INSERT INTO 'dancesrecordingsmap' VALUES (9746, 20778, NULL, 5498);
INSERT INTO 'dancesrecordingsmap' VALUES (4235, 9816, NULL, 5216);
INSERT INTO 'dancesrecordingsmap' VALUES (9747, 20779, NULL, 5216);
INSERT INTO 'dancesrecordingsmap' VALUES (9748, 20780, NULL, 8266);
INSERT INTO 'dancesrecordingsmap' VALUES (9749, 20781, NULL, 10507);
INSERT INTO 'dancesrecordingsmap' VALUES (9750, 20787, NULL, 10508);
INSERT INTO 'dancesrecordingsmap' VALUES (9751, 20784, NULL, 10509);
INSERT INTO 'dancesrecordingsmap' VALUES (9752, 20788, NULL, 10510);
INSERT INTO 'dancesrecordingsmap' VALUES (9753, 20794, NULL, 10511);
INSERT INTO 'dancesrecordingsmap' VALUES (9755, 20790, NULL, 10514);
INSERT INTO 'dancesrecordingsmap' VALUES (9756, 20785, NULL, 10515);
INSERT INTO 'dancesrecordingsmap' VALUES (9757, 20792, NULL, 10516);
INSERT INTO 'dancesrecordingsmap' VALUES (9758, 20783, NULL, 10517);
INSERT INTO 'dancesrecordingsmap' VALUES (9760, 20789, NULL, 10519);
INSERT INTO 'dancesrecordingsmap' VALUES (9759, 20793, NULL, 10518);
INSERT INTO 'dancesrecordingsmap' VALUES (9762, 20797, NULL, 10521);
INSERT INTO 'dancesrecordingsmap' VALUES (9763, 20800, NULL, 10524);
INSERT INTO 'dancesrecordingsmap' VALUES (9764, 20801, NULL, 10525);
INSERT INTO 'dancesrecordingsmap' VALUES (4274, 10253, NULL, 1675);
INSERT INTO 'dancesrecordingsmap' VALUES (9766, 11602, NULL, 1675);
INSERT INTO 'dancesrecordingsmap' VALUES (9765, 20799, NULL, 10523);
INSERT INTO 'dancesrecordingsmap' VALUES (9767, 16009, NULL, 1471);
INSERT INTO 'dancesrecordingsmap' VALUES (9768, 16010, NULL, 1473);
INSERT INTO 'dancesrecordingsmap' VALUES (3568, 2910, NULL, 1469);
INSERT INTO 'dancesrecordingsmap' VALUES (9769, 16011, NULL, 1469);
INSERT INTO 'dancesrecordingsmap' VALUES (9770, 16847, NULL, 7082);
INSERT INTO 'dancesrecordingsmap' VALUES (4686, 562, NULL, 1268);
INSERT INTO 'dancesrecordingsmap' VALUES (9771, 20733, NULL, 1268);
INSERT INTO 'dancesrecordingsmap' VALUES (9754, 20782, NULL, 10513);
INSERT INTO 'dancesrecordingsmap' VALUES (7361, 1916, NULL, 7762);
INSERT INTO 'dancesrecordingsmap' VALUES (9772, 14116, NULL, 7762);
INSERT INTO 'dancesrecordingsmap' VALUES (9773, 14116, NULL, 9342);
INSERT INTO 'dancesrecordingsmap' VALUES (4426, 10594, NULL, 5355);
INSERT INTO 'dancesrecordingsmap' VALUES (9774, 14116, NULL, 5355);
INSERT INTO 'dancesrecordingsmap' VALUES (8745, 8206, NULL, 6010);
INSERT INTO 'dancesrecordingsmap' VALUES (9775, 10847, NULL, 6010);
INSERT INTO 'dancesrecordingsmap' VALUES (72, 2600, NULL, 110);
INSERT INTO 'dancesrecordingsmap' VALUES (3891, 9159, NULL, 110);
INSERT INTO 'dancesrecordingsmap' VALUES (9776, 10851, NULL, 110);
INSERT INTO 'dancesrecordingsmap' VALUES (9777, 10851, NULL, 6671);
INSERT INTO 'dancesrecordingsmap' VALUES (6719, 1100, NULL, 6872);
INSERT INTO 'dancesrecordingsmap' VALUES (9778, 10852, NULL, 6872);
INSERT INTO 'dancesrecordingsmap' VALUES (602, 1100, NULL, 771);
INSERT INTO 'dancesrecordingsmap' VALUES (5459, 7482, NULL, 771);
INSERT INTO 'dancesrecordingsmap' VALUES (5462, 7479, NULL, 771);
INSERT INTO 'dancesrecordingsmap' VALUES (9779, 10852, NULL, 771);
INSERT INTO 'dancesrecordingsmap' VALUES (9780, 9363, NULL, 2304);
INSERT INTO 'dancesrecordingsmap' VALUES (9781, 19635, NULL, 9969);
INSERT INTO 'dancesrecordingsmap' VALUES (9782, 20895, NULL, 6385);
INSERT INTO 'dancesrecordingsmap' VALUES (4041, 5308, NULL, 5068);
INSERT INTO 'dancesrecordingsmap' VALUES (9761, 20786, NULL, 10520);
INSERT INTO 'dancesrecordingsmap' VALUES (9784, 20910, NULL, 10527);
INSERT INTO 'dancesrecordingsmap' VALUES (9785, 20911, NULL, 10528);
INSERT INTO 'dancesrecordingsmap' VALUES (9786, 20912, NULL, 10529);
INSERT INTO 'dancesrecordingsmap' VALUES (9787, 20914, NULL, 10530);
INSERT INTO 'dancesrecordingsmap' VALUES (9788, 20917, NULL, 10531);
INSERT INTO 'dancesrecordingsmap' VALUES (9789, 14994, NULL, 10532);
INSERT INTO 'dancesrecordingsmap' VALUES (9790, 20920, NULL, 10533);
INSERT INTO 'dancesrecordingsmap' VALUES (9794, 20915, NULL, 10537);
INSERT INTO 'dancesrecordingsmap' VALUES (9795, 20916, NULL, 10538);
INSERT INTO 'dancesrecordingsmap' VALUES (9796, 20918, NULL, 10539);
INSERT INTO 'dancesrecordingsmap' VALUES (9797, 20919, NULL, 10540);
INSERT INTO 'dancesrecordingsmap' VALUES (9798, 20921, NULL, 10541);
INSERT INTO 'dancesrecordingsmap' VALUES (9826, 21026, NULL, 747);
INSERT INTO 'dancesrecordingsmap' VALUES (9827, 21027, NULL, 9902);
INSERT INTO 'dancesrecordingsmap' VALUES (9793, 20913, NULL, 10536);
INSERT INTO 'dancesrecordingsmap' VALUES (9303, 14677, NULL, 5478);
INSERT INTO 'dancesrecordingsmap' VALUES (9799, 20924, NULL, 5478);
INSERT INTO 'dancesrecordingsmap' VALUES (9802, 20927, NULL, 6523);
INSERT INTO 'dancesrecordingsmap' VALUES (7201, 13546, NULL, 7488);
INSERT INTO 'dancesrecordingsmap' VALUES (9805, 4968, NULL, 3127);
INSERT INTO 'dancesrecordingsmap' VALUES (3946, 2349, NULL, 4988);
INSERT INTO 'dancesrecordingsmap' VALUES (9806, 7554, NULL, 10542);
INSERT INTO 'dancesrecordingsmap' VALUES (9807, 20864, NULL, 7149);
INSERT INTO 'dancesrecordingsmap' VALUES (9639, 20225, NULL, 7080);
INSERT INTO 'dancesrecordingsmap' VALUES (9808, 20871, NULL, 7080);
INSERT INTO 'dancesrecordingsmap' VALUES (9809, 7435, NULL, 923);
INSERT INTO 'dancesrecordingsmap' VALUES (9810, 20718, NULL, 10318);
INSERT INTO 'dancesrecordingsmap' VALUES (9811, 17116, NULL, 5177);
INSERT INTO 'dancesrecordingsmap' VALUES (9812, 16147, NULL, 7294);
INSERT INTO 'dancesrecordingsmap' VALUES (9813, 17689, NULL, 8415);
INSERT INTO 'dancesrecordingsmap' VALUES (9814, 17024, NULL, 6350);
INSERT INTO 'dancesrecordingsmap' VALUES (9732, 20629, NULL, 3765);
INSERT INTO 'dancesrecordingsmap' VALUES (1466, 2979, NULL, 1805);
INSERT INTO 'dancesrecordingsmap' VALUES (5638, 1917, NULL, 1812);
INSERT INTO 'dancesrecordingsmap' VALUES (2280, 4827, NULL, 2856);
INSERT INTO 'dancesrecordingsmap' VALUES (1432, 5207, NULL, 1769);
INSERT INTO 'dancesrecordingsmap' VALUES (4401, 10256, NULL, 1765);
INSERT INTO 'dancesrecordingsmap' VALUES (1427, 4318, NULL, 1764);
INSERT INTO 'dancesrecordingsmap' VALUES (3796, 3940, NULL, 4835);
INSERT INTO 'dancesrecordingsmap' VALUES (2178, 1562, NULL, 2713);
INSERT INTO 'dancesrecordingsmap' VALUES (6351, 56, NULL, 6478);
INSERT INTO 'dancesrecordingsmap' VALUES (9815, 6609, NULL, 6479);
INSERT INTO 'dancesrecordingsmap' VALUES (9816, 2826, NULL, 6479);
INSERT INTO 'dancesrecordingsmap' VALUES (9817, 312, NULL, 6477);
INSERT INTO 'dancesrecordingsmap' VALUES (1656, 1792, NULL, 2053);
INSERT INTO 'dancesrecordingsmap' VALUES (855, 7554, NULL, 1038);
INSERT INTO 'dancesrecordingsmap' VALUES (9818, 6484, NULL, 10564);
INSERT INTO 'dancesrecordingsmap' VALUES (9819, 7553, NULL, 10566);
INSERT INTO 'dancesrecordingsmap' VALUES (9820, 4431, NULL, 10569);
INSERT INTO 'dancesrecordingsmap' VALUES (9821, 19905, NULL, 7015);
INSERT INTO 'dancesrecordingsmap' VALUES (9822, 1782, NULL, 10573);
INSERT INTO 'dancesrecordingsmap' VALUES (9823, 21023, NULL, 5268);
INSERT INTO 'dancesrecordingsmap' VALUES (9824, 21024, NULL, 5713);
INSERT INTO 'dancesrecordingsmap' VALUES (9825, 21025, NULL, 5618);
INSERT INTO 'dancesrecordingsmap' VALUES (9828, 21028, NULL, 7570);
INSERT INTO 'dancesrecordingsmap' VALUES (9829, 21029, NULL, 6972);
INSERT INTO 'dancesrecordingsmap' VALUES (9195, 15502, NULL, 6100);
INSERT INTO 'dancesrecordingsmap' VALUES (9830, 21030, NULL, 6100);
INSERT INTO 'dancesrecordingsmap' VALUES (234, 7545, NULL, 172);
INSERT INTO 'dancesrecordingsmap' VALUES (9832, 21033, NULL, 172);
INSERT INTO 'dancesrecordingsmap' VALUES (5106, 9633, NULL, 5717);
INSERT INTO 'dancesrecordingsmap' VALUES (9142, 13648, NULL, 5717);
INSERT INTO 'dancesrecordingsmap' VALUES (9833, 21034, NULL, 5717);
INSERT INTO 'dancesrecordingsmap' VALUES (6266, 13166, NULL, 5477);
INSERT INTO 'dancesrecordingsmap' VALUES (6279, 13183, NULL, 5477);
INSERT INTO 'dancesrecordingsmap' VALUES (9834, 21035, NULL, 5477);
INSERT INTO 'dancesrecordingsmap' VALUES (9835, 21036, NULL, 5560);
INSERT INTO 'dancesrecordingsmap' VALUES (6109, 2189, NULL, 6340);
INSERT INTO 'dancesrecordingsmap' VALUES (9837, 21038, NULL, 6340);
INSERT INTO 'dancesrecordingsmap' VALUES (8509, 12437, NULL, 9672);
INSERT INTO 'dancesrecordingsmap' VALUES (6299, 13203, NULL, 5028);
INSERT INTO 'dancesrecordingsmap' VALUES (9836, 21037, NULL, 9438);
INSERT INTO 'dancesrecordingsmap' VALUES (9840, 21041, NULL, 5656);
INSERT INTO 'dancesrecordingsmap' VALUES (9841, 21042, NULL, 5662);
INSERT INTO 'dancesrecordingsmap' VALUES (9831, 21032, NULL, 5670);
INSERT INTO 'dancesrecordingsmap' VALUES (9844, 21045, NULL, 6348);
INSERT INTO 'dancesrecordingsmap' VALUES (9804, 20929, NULL, 981);
INSERT INTO 'dancesrecordingsmap' VALUES (9845, 21046, NULL, 981);
INSERT INTO 'dancesrecordingsmap' VALUES (9846, 21047, NULL, 829);
INSERT INTO 'dancesrecordingsmap' VALUES (9847, 21048, NULL, 8085);
INSERT INTO 'dancesrecordingsmap' VALUES (9849, 21050, NULL, 4455);
INSERT INTO 'dancesrecordingsmap' VALUES (6873, 5832, NULL, 7028);
INSERT INTO 'dancesrecordingsmap' VALUES (9848, 21049, NULL, 5103);
INSERT INTO 'dancesrecordingsmap' VALUES (6284, 13188, NULL, 5669);
INSERT INTO 'dancesrecordingsmap' VALUES (8792, 17247, NULL, 5669);
INSERT INTO 'dancesrecordingsmap' VALUES (9783, 20907, NULL, 10526);
INSERT INTO 'dancesrecordingsmap' VALUES (9741, 20704, NULL, 9672);
INSERT INTO 'dancesrecordingsmap' VALUES (8320, 15276, NULL, 9431);
INSERT INTO 'dancesrecordingsmap' VALUES (9803, 20928, NULL, 9431);
INSERT INTO 'dancesrecordingsmap' VALUES (9843, 21044, NULL, 5755);
INSERT INTO 'dancesrecordingsmap' VALUES (9801, 20926, NULL, 5576);
INSERT INTO 'dancesrecordingsmap' VALUES (9842, 21043, NULL, 5576);
INSERT INTO 'dancesrecordingsmap' VALUES (9791, 20908, NULL, 10534);
INSERT INTO 'dancesrecordingsmap' VALUES (9792, 20909, NULL, 10535);
INSERT INTO 'dancesrecordingsmap' VALUES (9850, 21051, NULL, 6452);
INSERT INTO 'dancesrecordingsmap' VALUES (9839, 21040, NULL, 5661);
INSERT INTO 'dancesrecordingsmap' VALUES (9852, 21053, NULL, 5661);
INSERT INTO 'dancesrecordingsmap' VALUES (9323, 8329, NULL, 2519);
INSERT INTO 'dancesrecordingsmap' VALUES (9853, 21054, NULL, 2519);
INSERT INTO 'dancesrecordingsmap' VALUES (9854, 21055, NULL, 8464);
INSERT INTO 'dancesrecordingsmap' VALUES (9856, 21057, NULL, 5040);
INSERT INTO 'dancesrecordingsmap' VALUES (9858, 21059, NULL, 977);
INSERT INTO 'dancesrecordingsmap' VALUES (9859, 21060, NULL, 776);
INSERT INTO 'dancesrecordingsmap' VALUES (9860, 21061, NULL, 5103);
INSERT INTO 'dancesrecordingsmap' VALUES (9861, 21062, NULL, 9386);
INSERT INTO 'dancesrecordingsmap' VALUES (9851, 21052, NULL, 10039);
INSERT INTO 'dancesrecordingsmap' VALUES (9862, 21063, NULL, 10039);
INSERT INTO 'dancesrecordingsmap' VALUES (9855, 21056, NULL, 5664);
INSERT INTO 'dancesrecordingsmap' VALUES (9863, 21064, NULL, 5664);
INSERT INTO 'dancesrecordingsmap' VALUES (9864, 21065, NULL, 5562);
INSERT INTO 'dancesrecordingsmap' VALUES (9865, 21066, NULL, 5747);
INSERT INTO 'dancesrecordingsmap' VALUES (4882, 11457, NULL, 5039);
INSERT INTO 'dancesrecordingsmap' VALUES (4912, 11489, NULL, 5039);
INSERT INTO 'dancesrecordingsmap' VALUES (6285, 13189, NULL, 5039);
INSERT INTO 'dancesrecordingsmap' VALUES (9234, 18719, NULL, 5039);
INSERT INTO 'dancesrecordingsmap' VALUES (9866, 21067, NULL, 5039);
INSERT INTO 'dancesrecordingsmap' VALUES (9867, 21068, NULL, 9682);
INSERT INTO 'dancesrecordingsmap' VALUES (9868, 21069, NULL, 2269);
INSERT INTO 'dancesrecordingsmap' VALUES (9742, 18017, NULL, 5669);
INSERT INTO 'dancesrecordingsmap' VALUES (9838, 21039, NULL, 5669);
INSERT INTO 'dancesrecordingsmap' VALUES (9869, 21070, NULL, 5669);
INSERT INTO 'dancesrecordingsmap' VALUES (9870, 21071, NULL, 2424);
INSERT INTO 'dancesrecordingsmap' VALUES (4805, 10872, NULL, 4114);
INSERT INTO 'dancesrecordingsmap' VALUES (4806, 2287, NULL, 4114);
INSERT INTO 'dancesrecordingsmap' VALUES (4807, 2693, NULL, 4114);
INSERT INTO 'dancesrecordingsmap' VALUES (4808, 3774, NULL, 4114);
INSERT INTO 'dancesrecordingsmap' VALUES (4809, 5348, NULL, 4114);
INSERT INTO 'dancesrecordingsmap' VALUES (4810, 5793, NULL, 4114);
INSERT INTO 'dancesrecordingsmap' VALUES (4846, 11427, NULL, 4114);
INSERT INTO 'dancesrecordingsmap' VALUES (9871, 21072, NULL, 4114);
INSERT INTO 'dancesrecordingsmap' VALUES (9872, 21073, NULL, 9357);
INSERT INTO 'dancesrecordingsmap' VALUES (9873, 21074, NULL, 9958);
INSERT INTO 'dancesrecordingsmap' VALUES (9874, 21075, NULL, 10096);
INSERT INTO 'dancesrecordingsmap' VALUES (9876, 21077, NULL, 6038);
INSERT INTO 'dancesrecordingsmap' VALUES (9964, 7546, NULL, 8561);
INSERT INTO 'dancesrecordingsmap' VALUES (9965, 8142, NULL, 8563);
INSERT INTO 'dancesrecordingsmap' VALUES (9966, 8154, NULL, 8278);
INSERT INTO 'dancesrecordingsmap' VALUES (9880, 21081, NULL, 5668);
INSERT INTO 'dancesrecordingsmap' VALUES (9881, 21082, NULL, 9438);
INSERT INTO 'dancesrecordingsmap' VALUES (9875, 21076, NULL, 4690);
INSERT INTO 'dancesrecordingsmap' VALUES (9883, 21084, NULL, 4690);
INSERT INTO 'dancesrecordingsmap' VALUES (9877, 21078, NULL, 5670);
INSERT INTO 'dancesrecordingsmap' VALUES (9885, 21086, NULL, 5670);
INSERT INTO 'dancesrecordingsmap' VALUES (9886, 21087, NULL, 5754);
INSERT INTO 'dancesrecordingsmap' VALUES (9887, 21088, NULL, 9672);
INSERT INTO 'dancesrecordingsmap' VALUES (9888, 21089, NULL, 9431);
INSERT INTO 'dancesrecordingsmap' VALUES (9535, 15768, NULL, 5755);
INSERT INTO 'dancesrecordingsmap' VALUES (9889, 21090, NULL, 5755);
INSERT INTO 'dancesrecordingsmap' VALUES (9890, 21091, NULL, 7090);
INSERT INTO 'dancesrecordingsmap' VALUES (9884, 21085, NULL, 5748);
INSERT INTO 'dancesrecordingsmap' VALUES (9891, 21092, NULL, 5748);
INSERT INTO 'dancesrecordingsmap' VALUES (9892, 21093, NULL, 986);
INSERT INTO 'dancesrecordingsmap' VALUES (9967, 13275, NULL, 8044);
INSERT INTO 'dancesrecordingsmap' VALUES (9968, 8142, NULL, 7649);
INSERT INTO 'dancesrecordingsmap' VALUES (9969, 7546, NULL, 7650);
INSERT INTO 'dancesrecordingsmap' VALUES (9970, 8152, NULL, 7642);
INSERT INTO 'dancesrecordingsmap' VALUES (9894, 16909, NULL, 10071);
INSERT INTO 'dancesrecordingsmap' VALUES (9895, 21111, NULL, 7810);
INSERT INTO 'dancesrecordingsmap' VALUES (9896, 10009, NULL, 200);
INSERT INTO 'dancesrecordingsmap' VALUES (9897, 21149, NULL, 10340);
INSERT INTO 'dancesrecordingsmap' VALUES (9898, 21150, NULL, 10116);
INSERT INTO 'dancesrecordingsmap' VALUES (9899, 21151, NULL, 5468);
INSERT INTO 'dancesrecordingsmap' VALUES (9900, 10872, NULL, 5038);
INSERT INTO 'dancesrecordingsmap' VALUES (9901, 21157, NULL, 9897);
INSERT INTO 'dancesrecordingsmap' VALUES (2073, 3906, NULL, 2576);
INSERT INTO 'dancesrecordingsmap' VALUES (9902, 4697, NULL, 2576);
INSERT INTO 'dancesrecordingsmap' VALUES (9903, 20562, NULL, 9353);
INSERT INTO 'dancesrecordingsmap' VALUES (9904, 21186, NULL, 4961);
INSERT INTO 'dancesrecordingsmap' VALUES (9905, 21189, NULL, 9374);
INSERT INTO 'dancesrecordingsmap' VALUES (9906, 17112, NULL, 5492);
INSERT INTO 'dancesrecordingsmap' VALUES (9907, 1641, NULL, 8888);
INSERT INTO 'dancesrecordingsmap' VALUES (9908, 21193, NULL, 10250);
INSERT INTO 'dancesrecordingsmap' VALUES (9909, 21195, NULL, 10257);
INSERT INTO 'dancesrecordingsmap' VALUES (9910, 21196, NULL, 10264);
INSERT INTO 'dancesrecordingsmap' VALUES (9911, 9872, NULL, 869);
INSERT INTO 'dancesrecordingsmap' VALUES (9912, 14239, NULL, 8070);
INSERT INTO 'dancesrecordingsmap' VALUES (9971, 8142, NULL, 8560);
INSERT INTO 'dancesrecordingsmap' VALUES (9914, 8086, NULL, 9886);
INSERT INTO 'dancesrecordingsmap' VALUES (9916, 4638, NULL, 10208);
INSERT INTO 'dancesrecordingsmap' VALUES (9915, 4948, NULL, 10214);
INSERT INTO 'dancesrecordingsmap' VALUES (9917, 4451, NULL, 9877);
INSERT INTO 'dancesrecordingsmap' VALUES (9918, 2713, NULL, 9878);
INSERT INTO 'dancesrecordingsmap' VALUES (9919, 21197, NULL, 7087);
INSERT INTO 'dancesrecordingsmap' VALUES (9920, 17268, NULL, 1698);
INSERT INTO 'dancesrecordingsmap' VALUES (9921, 17269, NULL, 823);
INSERT INTO 'dancesrecordingsmap' VALUES (9922, 19281, NULL, 10607);
INSERT INTO 'dancesrecordingsmap' VALUES (9923, 2886, NULL, 5275);
INSERT INTO 'dancesrecordingsmap' VALUES (9924, 20610, NULL, 9062);
INSERT INTO 'dancesrecordingsmap' VALUES (9925, 1881, NULL, 75);
INSERT INTO 'dancesrecordingsmap' VALUES (9926, 17534, NULL, 7073);
INSERT INTO 'dancesrecordingsmap' VALUES (9927, 17525, NULL, 7076);
INSERT INTO 'dancesrecordingsmap' VALUES (9928, 18020, NULL, 7999);
INSERT INTO 'dancesrecordingsmap' VALUES (9929, 18021, NULL, 8004);
INSERT INTO 'dancesrecordingsmap' VALUES (9930, 19270, NULL, 8010);
INSERT INTO 'dancesrecordingsmap' VALUES (9933, 522, NULL, 8954);
INSERT INTO 'dancesrecordingsmap' VALUES (9932, 21198, NULL, 9312);
INSERT INTO 'dancesrecordingsmap' VALUES (9934, 12835, NULL, 10265);
INSERT INTO 'dancesrecordingsmap' VALUES (9935, 743, NULL, 10266);
INSERT INTO 'dancesrecordingsmap' VALUES (9936, 2250, NULL, 10267);
INSERT INTO 'dancesrecordingsmap' VALUES (9937, 12838, NULL, 10270);
INSERT INTO 'dancesrecordingsmap' VALUES (9938, 2030, NULL, 10272);
INSERT INTO 'dancesrecordingsmap' VALUES (9939, 12837, NULL, 10273);
INSERT INTO 'dancesrecordingsmap' VALUES (9940, 3672, NULL, 10274);
INSERT INTO 'dancesrecordingsmap' VALUES (9941, 4782, NULL, 10276);
INSERT INTO 'dancesrecordingsmap' VALUES (9942, 2267, NULL, 10268);
INSERT INTO 'dancesrecordingsmap' VALUES (9943, 1582, NULL, 10616);
INSERT INTO 'dancesrecordingsmap' VALUES (9944, 3110, NULL, 6909);
INSERT INTO 'dancesrecordingsmap' VALUES (9945, 8714, NULL, 623);
INSERT INTO 'dancesrecordingsmap' VALUES (9188, 19144, NULL, 5028);
INSERT INTO 'dancesrecordingsmap' VALUES (9800, 20925, NULL, 5028);
INSERT INTO 'dancesrecordingsmap' VALUES (9857, 21058, NULL, 5028);
INSERT INTO 'dancesrecordingsmap' VALUES (9879, 21080, NULL, 5028);
INSERT INTO 'dancesrecordingsmap' VALUES (9893, 21094, NULL, 5028);
INSERT INTO 'dancesrecordingsmap' VALUES (9946, 21200, NULL, 5028);
INSERT INTO 'dancesrecordingsmap' VALUES (9878, 21079, NULL, 7575);
INSERT INTO 'dancesrecordingsmap' VALUES (9947, 21201, NULL, 7575);
INSERT INTO 'dancesrecordingsmap' VALUES (9948, 21202, NULL, 5657);
INSERT INTO 'dancesrecordingsmap' VALUES (9949, 4561, NULL, 5789);
INSERT INTO 'dancesrecordingsmap' VALUES (9882, 21083, NULL, 5576);
INSERT INTO 'dancesrecordingsmap' VALUES (9950, 21204, NULL, 5576);
INSERT INTO 'dancesrecordingsmap' VALUES (9352, 16962, NULL, 6869);
INSERT INTO 'dancesrecordingsmap' VALUES (9951, 21212, NULL, 9305);
INSERT INTO 'dancesrecordingsmap' VALUES (9952, 4662, NULL, 1028);
INSERT INTO 'dancesrecordingsmap' VALUES (9953, 8720, NULL, 1090);
INSERT INTO 'dancesrecordingsmap' VALUES (9954, 11764, NULL, 1223);
INSERT INTO 'dancesrecordingsmap' VALUES (9955, 14518, NULL, 2543);
INSERT INTO 'dancesrecordingsmap' VALUES (9956, 21212, NULL, 3338);
INSERT INTO 'dancesrecordingsmap' VALUES (9957, 21212, NULL, 10553);
INSERT INTO 'dancesrecordingsmap' VALUES (9958, 21212, NULL, 4442);
INSERT INTO 'dancesrecordingsmap' VALUES (9959, 21212, NULL, 6036);
INSERT INTO 'dancesrecordingsmap' VALUES (9960, 21212, NULL, 10129);
INSERT INTO 'dancesrecordingsmap' VALUES (9961, 21214, NULL, 9316);
INSERT INTO 'dancesrecordingsmap' VALUES (9962, 21214, NULL, 7653);
INSERT INTO 'dancesrecordingsmap' VALUES (986, 5702, NULL, 1243);
INSERT INTO 'dancesrecordingsmap' VALUES (8946, 17402, NULL, 9910);
INSERT INTO 'dancesrecordingsmap' VALUES (9931, 20227, NULL, 8011);
INSERT INTO 'dancesrecordingsmap' VALUES (9975, 8161, NULL, 8559);
INSERT INTO 'dancesrecordingsmap' VALUES (9976, 4782, NULL, 8273);
INSERT INTO 'dancesrecordingsmap' VALUES (9977, 1562, NULL, 8273);
INSERT INTO 'dancesrecordingsmap' VALUES (9978, 8142, NULL, 8557);
INSERT INTO 'dancesrecordingsmap' VALUES (9979, 8146, NULL, 7644);
INSERT INTO 'dancesrecordingsmap' VALUES (9980, 8143, NULL, 7656);
INSERT INTO 'dancesrecordingsmap' VALUES (9981, 7554, NULL, 8272);
INSERT INTO 'dancesrecordingsmap' VALUES (9982, 8143, NULL, 8569);
INSERT INTO 'dancesrecordingsmap' VALUES (9983, 8153, NULL, 8269);
INSERT INTO 'dancesrecordingsmap' VALUES (9984, 5658, NULL, 8270);
INSERT INTO 'dancesrecordingsmap' VALUES (9985, 6233, NULL, 9530);
INSERT INTO 'dancesrecordingsmap' VALUES (9986, 5713, NULL, 10686);
INSERT INTO 'dancesrecordingsmap' VALUES (9987, 6359, NULL, 10688);
INSERT INTO 'dancesrecordingsmap' VALUES (9988, 1562, NULL, 10670);
INSERT INTO 'dancesrecordingsmap' VALUES (9989, 1562, NULL, 10671);
INSERT INTO 'dancesrecordingsmap' VALUES (9990, 7552, NULL, 10672);
INSERT INTO 'dancesrecordingsmap' VALUES (9991, 7552, NULL, 10673);
INSERT INTO 'dancesrecordingsmap' VALUES (9996, 1210, NULL, 10683);
INSERT INTO 'dancesrecordingsmap' VALUES (9997, 1792, NULL, 10684);
INSERT INTO 'dancesrecordingsmap' VALUES (9974, 2979, NULL, 10664);
INSERT INTO 'dancesrecordingsmap' VALUES (9998, 7553, NULL, 7152);
INSERT INTO 'dancesrecordingsmap' VALUES (9999, 8142, NULL, 7157);
INSERT INTO 'dancesrecordingsmap' VALUES (10000, 5915, NULL, 7154);
INSERT INTO 'dancesrecordingsmap' VALUES (10001, 9807, NULL, 5158);
INSERT INTO 'dancesrecordingsmap' VALUES (10002, 5239, NULL, 8267);
INSERT INTO 'dancesrecordingsmap' VALUES (10003, 1210, NULL, 8267);
INSERT INTO 'dancesrecordingsmap' VALUES (10004, 7546, NULL, 7146);
INSERT INTO 'dancesrecordingsmap' VALUES (10005, 7553, NULL, 8274);
INSERT INTO 'dancesrecordingsmap' VALUES (10006, 7555, NULL, 8274);
INSERT INTO 'dancesrecordingsmap' VALUES (10007, 21222, NULL, 4451);
INSERT INTO 'dancesrecordingsmap' VALUES (10008, 21223, NULL, 9003);
INSERT INTO 'dancesrecordingsmap' VALUES (10009, 21223, NULL, 10555);
INSERT INTO 'dancesrecordingsmap' VALUES (10010, 21223, NULL, 8265);
INSERT INTO 'dancesrecordingsmap' VALUES (9994, 7554, NULL, 10675);
INSERT INTO 'dancesrecordingsmap' VALUES (9995, 8154, NULL, 10675);
INSERT INTO 'dancesrecordingsmap' VALUES (9973, 1931, NULL, 10669);
INSERT INTO 'dancesrecordingsmap' VALUES (9972, 7546, NULL, 10658);
INSERT INTO 'dancesrecordingsmap' VALUES (9963, 4070, NULL, 2147);
INSERT INTO 'dancesrecordingsmap' VALUES (5674, 4003, NULL, 2489);
INSERT INTO 'dancesrecordingsmap' VALUES (10011, 21223, NULL, 7706);
INSERT INTO 'dancesrecordingsmap' VALUES (10013, 21223, NULL, 7724);
INSERT INTO 'dancesrecordingsmap' VALUES (10014, 1024, NULL, 8282);
INSERT INTO 'dancesrecordingsmap' VALUES (10015, 2350, NULL, 8282);
INSERT INTO 'dancesrecordingsmap' VALUES (10016, 21224, NULL, 3353);
INSERT INTO 'dancesrecordingsmap' VALUES (10017, 21224, NULL, 8001);
INSERT INTO 'dancesrecordingsmap' VALUES (10018, 21225, NULL, 4456);
INSERT INTO 'dancesrecordingsmap' VALUES (10019, 21226, NULL, 8006);
INSERT INTO 'dancesrecordingsmap' VALUES (10020, 21227, NULL, 9307);
INSERT INTO 'dancesrecordingsmap' VALUES (10021, 8146, NULL, 8284);
INSERT INTO 'dancesrecordingsmap' VALUES (10022, 8152, NULL, 8277);
INSERT INTO 'dancesrecordingsmap' VALUES (10023, 18021, NULL, 8277);
INSERT INTO 'dancesrecordingsmap' VALUES (9992, 7554, NULL, 10674);
INSERT INTO 'dancesrecordingsmap' VALUES (9993, 8154, NULL, 10674);
INSERT INTO 'dancesrecordingsmap' VALUES (10024, 7552, NULL, 8276);
INSERT INTO 'dancesrecordingsmap' VALUES (10025, 8142, NULL, 8276);
INSERT INTO 'dancesrecordingsmap' VALUES (10026, 7548, NULL, 7516);
INSERT INTO 'dancesrecordingsmap' VALUES (10027, 6959, NULL, 3109);
INSERT INTO 'dancesrecordingsmap' VALUES (10028, 6959, NULL, 9122);
INSERT INTO 'dancesrecordingsmap' VALUES (10029, 6959, NULL, 8009);
INSERT INTO 'dancesrecordingsmap' VALUES (3287, 3129, NULL, 4158);
INSERT INTO 'dancesrecordingsmap' VALUES (10012, 21223, NULL, 8008);
INSERT INTO 'dancesrecordingsmap' VALUES (10031, 1931, NULL, 2686);
INSERT INTO 'dancesrecordingsmap' VALUES (10032, 5525, NULL, 10008);
INSERT INTO 'dancesrecordingsmap' VALUES (10033, 3407, NULL, 2147);
INSERT INTO 'dancesrecordingsmap' VALUES (10030, 6959, NULL, 2706);
INSERT INTO 'dancesrecordingsmap' VALUES (10034, 18125, NULL, 4584);
INSERT INTO 'dancesrecordingsmap' VALUES (1530, 594, NULL, 1873);
INSERT INTO 'dancesrecordingsmap' VALUES (10035, 2345, NULL, 1873);
INSERT INTO 'dancesrecordingsmap' VALUES (10036, 5638, NULL, 1873);
INSERT INTO 'dancesrecordingsmap' VALUES (10039, 2345, NULL, 7692);
INSERT INTO 'dancesrecordingsmap' VALUES (10040, 5638, NULL, 7692);
INSERT INTO 'dancesrecordingsmap' VALUES (10041, 12432, NULL, 323);
INSERT INTO 'dancesrecordingsmap' VALUES (10042, 12432, NULL, 2113);
INSERT INTO 'dancesrecordingsmap' VALUES (5436, 377, NULL, 5973);
INSERT INTO 'dancesrecordingsmap' VALUES (10043, 21317, NULL, 2353);
INSERT INTO 'dancesrecordingsmap' VALUES (10045, 18137, NULL, 10065);
INSERT INTO 'dancesrecordingsmap' VALUES (10044, 21335, NULL, 10070);
INSERT INTO 'dancesrecordingsmap' VALUES (2568, 4832, NULL, 3229);
INSERT INTO 'dancesrecordingsmap' VALUES (10046, 2398, NULL, 3229);
INSERT INTO 'dancesrecordingsmap' VALUES (10047, 3818, NULL, 207);
INSERT INTO 'dancesrecordingsmap' VALUES (10048, 18886, NULL, 9703);
INSERT INTO 'dancesrecordingsmap' VALUES (10049, 8166, NULL, 5466);
INSERT INTO 'dancesrecordingsmap' VALUES (10050, 17830, NULL, 1010);
INSERT INTO 'dancesrecordingsmap' VALUES (10051, 17807, NULL, 5354);
INSERT INTO 'dancesrecordingsmap' VALUES (10052, 17809, NULL, 6498);
INSERT INTO 'dancesrecordingsmap' VALUES (10053, 998, NULL, 2770);
INSERT INTO 'dancesrecordingsmap' VALUES (3896, 9163, NULL, 3427);
INSERT INTO 'dancesrecordingsmap' VALUES (10054, 9809, NULL, 3427);
INSERT INTO 'dancesrecordingsmap' VALUES (10055, 20886, NULL, 10699);
INSERT INTO 'dancesrecordingsmap' VALUES (10056, 20887, NULL, 10700);
INSERT INTO 'dancesrecordingsmap' VALUES (10057, 20885, NULL, 10698);
INSERT INTO 'dancesrecordingsmap' VALUES (10058, 20875, NULL, 10697);
INSERT INTO 'dancesrecordingsmap' VALUES (10059, 20884, NULL, 10696);
INSERT INTO 'dancesrecordingsmap' VALUES (10060, 20883, NULL, 10695);
INSERT INTO 'dancesrecordingsmap' VALUES (10062, 20881, NULL, 10693);
INSERT INTO 'dancesrecordingsmap' VALUES (10063, 20880, NULL, 10692);
INSERT INTO 'dancesrecordingsmap' VALUES (10064, 20879, NULL, 10691);
INSERT INTO 'dancesrecordingsmap' VALUES (10065, 20878, NULL, 10690);
INSERT INTO 'dancesrecordingsmap' VALUES (10066, 20877, NULL, 10689);
INSERT INTO 'dancesrecordingsmap' VALUES (10061, 20882, NULL, 10694);


--
INSERT INTO 'dancesstepsmap' VALUES (1, 2, 1);
INSERT INTO 'dancesstepsmap' VALUES (2, 3, 4);
INSERT INTO 'dancesstepsmap' VALUES (3, 4, 4);
INSERT INTO 'dancesstepsmap' VALUES (4, 5, 4);
INSERT INTO 'dancesstepsmap' VALUES (5, 6, 1);
INSERT INTO 'dancesstepsmap' VALUES (6, 7, 1);
INSERT INTO 'dancesstepsmap' VALUES (7, 8, 4);
INSERT INTO 'dancesstepsmap' VALUES (8, 9, 1);
INSERT INTO 'dancesstepsmap' VALUES (9, 10, 4);
INSERT INTO 'dancesstepsmap' VALUES (10, 12, 4);
INSERT INTO 'dancesstepsmap' VALUES (11, 13, 4);
INSERT INTO 'dancesstepsmap' VALUES (12, 14, 1);
INSERT INTO 'dancesstepsmap' VALUES (13, 15, 1);
INSERT INTO 'dancesstepsmap' VALUES (14, 16, 1);
INSERT INTO 'dancesstepsmap' VALUES (15, 18, 1);
INSERT INTO 'dancesstepsmap' VALUES (16, 19, 4);
INSERT INTO 'dancesstepsmap' VALUES (17, 20, 4);
INSERT INTO 'dancesstepsmap' VALUES (18, 21, 1);
INSERT INTO 'dancesstepsmap' VALUES (19, 22, 1);
INSERT INTO 'dancesstepsmap' VALUES (20, 23, 4);
INSERT INTO 'dancesstepsmap' VALUES (21, 24, 4);
INSERT INTO 'dancesstepsmap' VALUES (22, 25, 4);
INSERT INTO 'dancesstepsmap' VALUES (23, 26, 4);
INSERT INTO 'dancesstepsmap' VALUES (24, 27, 1);
INSERT INTO 'dancesstepsmap' VALUES (25, 28, 1);
INSERT INTO 'dancesstepsmap' VALUES (26, 29, 1);
INSERT INTO 'dancesstepsmap' VALUES (27, 30, 1);
INSERT INTO 'dancesstepsmap' VALUES (28, 31, 1);
INSERT INTO 'dancesstepsmap' VALUES (29, 32, 1);
INSERT INTO 'dancesstepsmap' VALUES (30, 33, 4);
INSERT INTO 'dancesstepsmap' VALUES (31, 34, 1);
INSERT INTO 'dancesstepsmap' VALUES (32, 35, 1);
INSERT INTO 'dancesstepsmap' VALUES (33, 36, 1);
INSERT INTO 'dancesstepsmap' VALUES (34, 37, 1);
INSERT INTO 'dancesstepsmap' VALUES (35, 38, 1);
INSERT INTO 'dancesstepsmap' VALUES (36, 39, 1);
INSERT INTO 'dancesstepsmap' VALUES (37, 40, 4);
INSERT INTO 'dancesstepsmap' VALUES (38, 41, 1);
INSERT INTO 'dancesstepsmap' VALUES (39, 42, 1);
INSERT INTO 'dancesstepsmap' VALUES (40, 43, 1);
INSERT INTO 'dancesstepsmap' VALUES (41, 44, 1);
INSERT INTO 'dancesstepsmap' VALUES (42, 45, 1);
INSERT INTO 'dancesstepsmap' VALUES (43, 46, 4);
INSERT INTO 'dancesstepsmap' VALUES (44, 47, 1);
INSERT INTO 'dancesstepsmap' VALUES (45, 48, 1);
INSERT INTO 'dancesstepsmap' VALUES (46, 49, 4);
INSERT INTO 'dancesstepsmap' VALUES (47, 50, 1);
INSERT INTO 'dancesstepsmap' VALUES (48, 51, 4);
INSERT INTO 'dancesstepsmap' VALUES (49, 52, 1);
INSERT INTO 'dancesstepsmap' VALUES (50, 53, 4);
INSERT INTO 'dancesstepsmap' VALUES (51, 54, 1);
INSERT INTO 'dancesstepsmap' VALUES (52, 55, 1);
INSERT INTO 'dancesstepsmap' VALUES (53, 56, 1);
INSERT INTO 'dancesstepsmap' VALUES (54, 57, 1);
INSERT INTO 'dancesstepsmap' VALUES (55, 58, 4);
INSERT INTO 'dancesstepsmap' VALUES (56, 59, 1);
INSERT INTO 'dancesstepsmap' VALUES (57, 60, 1);
INSERT INTO 'dancesstepsmap' VALUES (58, 61, 1);
INSERT INTO 'dancesstepsmap' VALUES (59, 62, 1);
INSERT INTO 'dancesstepsmap' VALUES (60, 63, 4);
INSERT INTO 'dancesstepsmap' VALUES (61, 64, 1);
INSERT INTO 'dancesstepsmap' VALUES (62, 65, 1);
INSERT INTO 'dancesstepsmap' VALUES (63, 66, 1);
INSERT INTO 'dancesstepsmap' VALUES (64, 67, 4);
INSERT INTO 'dancesstepsmap' VALUES (65, 68, 1);
INSERT INTO 'dancesstepsmap' VALUES (66, 70, 4);
INSERT INTO 'dancesstepsmap' VALUES (67, 71, 1);
INSERT INTO 'dancesstepsmap' VALUES (68, 72, 1);
INSERT INTO 'dancesstepsmap' VALUES (69, 74, 4);
INSERT INTO 'dancesstepsmap' VALUES (70, 75, 4);
INSERT INTO 'dancesstepsmap' VALUES (71, 76, 1);
INSERT INTO 'dancesstepsmap' VALUES (72, 77, 1);
INSERT INTO 'dancesstepsmap' VALUES (73, 78, 1);
INSERT INTO 'dancesstepsmap' VALUES (74, 79, 1);
INSERT INTO 'dancesstepsmap' VALUES (75, 80, 1);
INSERT INTO 'dancesstepsmap' VALUES (76, 81, 1);
INSERT INTO 'dancesstepsmap' VALUES (77, 82, 1);
INSERT INTO 'dancesstepsmap' VALUES (78, 83, 1);
INSERT INTO 'dancesstepsmap' VALUES (79, 84, 4);
INSERT INTO 'dancesstepsmap' VALUES (80, 85, 4);
INSERT INTO 'dancesstepsmap' VALUES (81, 86, 4);
INSERT INTO 'dancesstepsmap' VALUES (82, 87, 1);
INSERT INTO 'dancesstepsmap' VALUES (83, 88, 1);
INSERT INTO 'dancesstepsmap' VALUES (84, 89, 4);
INSERT INTO 'dancesstepsmap' VALUES (85, 90, 1);
INSERT INTO 'dancesstepsmap' VALUES (86, 91, 4);
INSERT INTO 'dancesstepsmap' VALUES (87, 92, 1);
INSERT INTO 'dancesstepsmap' VALUES (88, 93, 1);
INSERT INTO 'dancesstepsmap' VALUES (89, 94, 4);
INSERT INTO 'dancesstepsmap' VALUES (90, 95, 4);
INSERT INTO 'dancesstepsmap' VALUES (91, 96, 1);
INSERT INTO 'dancesstepsmap' VALUES (92, 97, 1);
INSERT INTO 'dancesstepsmap' VALUES (9986, 9097, 4);
INSERT INTO 'dancesstepsmap' VALUES (9987, 9098, 3);
INSERT INTO 'dancesstepsmap' VALUES (9988, 9098, 1);
INSERT INTO 'dancesstepsmap' VALUES (9989, 9098, 2);
INSERT INTO 'dancesstepsmap' VALUES (9990, 9099, 3);
INSERT INTO 'dancesstepsmap' VALUES (9991, 9100, 2);
INSERT INTO 'dancesstepsmap' VALUES (9992, 9101, 2);
INSERT INTO 'dancesstepsmap' VALUES (9993, 9102, 3);
INSERT INTO 'dancesstepsmap' VALUES (13557, 11837, 2);
INSERT INTO 'dancesstepsmap' VALUES (13558, 11839, 1);
INSERT INTO 'dancesstepsmap' VALUES (13559, 11840, 4);
INSERT INTO 'dancesstepsmap' VALUES (13560, 11841, 4);
INSERT INTO 'dancesstepsmap' VALUES (13561, 11841, 5);
INSERT INTO 'dancesstepsmap' VALUES (13562, 11842, 2);
INSERT INTO 'dancesstepsmap' VALUES (13563, 11843, 1);
INSERT INTO 'dancesstepsmap' VALUES (13564, 11844, 1);
INSERT INTO 'dancesstepsmap' VALUES (13565, 11844, 2);
INSERT INTO 'dancesstepsmap' VALUES (13566, 11846, 1);
INSERT INTO 'dancesstepsmap' VALUES (13567, 11847, 4);
INSERT INTO 'dancesstepsmap' VALUES (13568, 11848, 1);
INSERT INTO 'dancesstepsmap' VALUES (13569, 11849, 1);
INSERT INTO 'dancesstepsmap' VALUES (13570, 11850, 4);
INSERT INTO 'dancesstepsmap' VALUES (13571, 11851, 5);
INSERT INTO 'dancesstepsmap' VALUES (13572, 11853, 1);
INSERT INTO 'dancesstepsmap' VALUES (13573, 11854, 2);
INSERT INTO 'dancesstepsmap' VALUES (13574, 11854, 1);
INSERT INTO 'dancesstepsmap' VALUES (13575, 11855, 1);
INSERT INTO 'dancesstepsmap' VALUES (13576, 11858, 1);
INSERT INTO 'dancesstepsmap' VALUES (13577, 11859, 4);
INSERT INTO 'dancesstepsmap' VALUES (13578, 11859, 5);
INSERT INTO 'dancesstepsmap' VALUES (13579, 11860, 1);
INSERT INTO 'dancesstepsmap' VALUES (13580, 11861, 1);
INSERT INTO 'dancesstepsmap' VALUES (13581, 11863, 2);
INSERT INTO 'dancesstepsmap' VALUES (13582, 11863, 1);
INSERT INTO 'dancesstepsmap' VALUES (13583, 11864, 1);
INSERT INTO 'dancesstepsmap' VALUES (13584, 11864, 2);
INSERT INTO 'dancesstepsmap' VALUES (13585, 11866, 1);
INSERT INTO 'dancesstepsmap' VALUES (13586, 11866, 3);
INSERT INTO 'dancesstepsmap' VALUES (13587, 11870, 4);
INSERT INTO 'dancesstepsmap' VALUES (13588, 11872, 4);
INSERT INTO 'dancesstepsmap' VALUES (13589, 11872, 5);
INSERT INTO 'dancesstepsmap' VALUES (13590, 11875, 3);
INSERT INTO 'dancesstepsmap' VALUES (13591, 11875, 1);
INSERT INTO 'dancesstepsmap' VALUES (13592, 11876, 3);
INSERT INTO 'dancesstepsmap' VALUES (13593, 11877, 1);
INSERT INTO 'dancesstepsmap' VALUES (13594, 11877, 8);
INSERT INTO 'dancesstepsmap' VALUES (16887, 14401, 1);
INSERT INTO 'dancesstepsmap' VALUES (16888, 14401, 2);
INSERT INTO 'dancesstepsmap' VALUES (16889, 12071, 7);
INSERT INTO 'dancesstepsmap' VALUES (16894, 1786, 2);
INSERT INTO 'dancesstepsmap' VALUES (16896, 2777, 3);
INSERT INTO 'dancesstepsmap' VALUES (16897, 2777, 2);
INSERT INTO 'dancesstepsmap' VALUES (16898, 9968, 5);
INSERT INTO 'dancesstepsmap' VALUES (16899, 14403, 3);
INSERT INTO 'dancesstepsmap' VALUES (16900, 14403, 1);
INSERT INTO 'dancesstepsmap' VALUES (16901, 14403, 2);
INSERT INTO 'dancesstepsmap' VALUES (16902, 12983, 2);
INSERT INTO 'dancesstepsmap' VALUES (16903, 12983, 1);
INSERT INTO 'dancesstepsmap' VALUES (93, 98, 1);
INSERT INTO 'dancesstepsmap' VALUES (94, 99, 1);
INSERT INTO 'dancesstepsmap' VALUES (95, 100, 1);
INSERT INTO 'dancesstepsmap' VALUES (96, 101, 1);
INSERT INTO 'dancesstepsmap' VALUES (97, 102, 1);
INSERT INTO 'dancesstepsmap' VALUES (98, 103, 1);
INSERT INTO 'dancesstepsmap' VALUES (99, 104, 1);
INSERT INTO 'dancesstepsmap' VALUES (100, 105, 1);
INSERT INTO 'dancesstepsmap' VALUES (101, 106, 1);
INSERT INTO 'dancesstepsmap' VALUES (102, 107, 1);
INSERT INTO 'dancesstepsmap' VALUES (103, 109, 4);
INSERT INTO 'dancesstepsmap' VALUES (104, 110, 1);
INSERT INTO 'dancesstepsmap' VALUES (105, 111, 1);
INSERT INTO 'dancesstepsmap' VALUES (106, 112, 4);
INSERT INTO 'dancesstepsmap' VALUES (107, 113, 1);
INSERT INTO 'dancesstepsmap' VALUES (108, 114, 1);
INSERT INTO 'dancesstepsmap' VALUES (109, 115, 1);
INSERT INTO 'dancesstepsmap' VALUES (110, 116, 1);
INSERT INTO 'dancesstepsmap' VALUES (111, 117, 4);
INSERT INTO 'dancesstepsmap' VALUES (112, 118, 4);
INSERT INTO 'dancesstepsmap' VALUES (113, 119, 1);
INSERT INTO 'dancesstepsmap' VALUES (114, 120, 4);
INSERT INTO 'dancesstepsmap' VALUES (115, 121, 1);
INSERT INTO 'dancesstepsmap' VALUES (116, 122, 1);
INSERT INTO 'dancesstepsmap' VALUES (117, 123, 4);
INSERT INTO 'dancesstepsmap' VALUES (118, 124, 4);
INSERT INTO 'dancesstepsmap' VALUES (119, 125, 4);
INSERT INTO 'dancesstepsmap' VALUES (120, 126, 1);
INSERT INTO 'dancesstepsmap' VALUES (121, 128, 4);
INSERT INTO 'dancesstepsmap' VALUES (122, 129, 1);
INSERT INTO 'dancesstepsmap' VALUES (123, 132, 1);
INSERT INTO 'dancesstepsmap' VALUES (124, 133, 4);
INSERT INTO 'dancesstepsmap' VALUES (125, 134, 4);
INSERT INTO 'dancesstepsmap' VALUES (126, 135, 4);
INSERT INTO 'dancesstepsmap' VALUES (127, 136, 1);
INSERT INTO 'dancesstepsmap' VALUES (128, 137, 4);
INSERT INTO 'dancesstepsmap' VALUES (129, 138, 1);
INSERT INTO 'dancesstepsmap' VALUES (130, 139, 1);
INSERT INTO 'dancesstepsmap' VALUES (131, 140, 1);
INSERT INTO 'dancesstepsmap' VALUES (132, 141, 4);
INSERT INTO 'dancesstepsmap' VALUES (133, 142, 1);
INSERT INTO 'dancesstepsmap' VALUES (134, 143, 1);
INSERT INTO 'dancesstepsmap' VALUES (135, 144, 1);
INSERT INTO 'dancesstepsmap' VALUES (136, 145, 4);
INSERT INTO 'dancesstepsmap' VALUES (137, 146, 1);
INSERT INTO 'dancesstepsmap' VALUES (138, 147, 1);
INSERT INTO 'dancesstepsmap' VALUES (139, 148, 1);
INSERT INTO 'dancesstepsmap' VALUES (140, 149, 1);
INSERT INTO 'dancesstepsmap' VALUES (141, 151, 4);
INSERT INTO 'dancesstepsmap' VALUES (142, 152, 1);
INSERT INTO 'dancesstepsmap' VALUES (143, 153, 1);
INSERT INTO 'dancesstepsmap' VALUES (144, 154, 1);
INSERT INTO 'dancesstepsmap' VALUES (145, 155, 4);
INSERT INTO 'dancesstepsmap' VALUES (146, 156, 4);
INSERT INTO 'dancesstepsmap' VALUES (147, 158, 4);
INSERT INTO 'dancesstepsmap' VALUES (148, 159, 4);
INSERT INTO 'dancesstepsmap' VALUES (149, 160, 1);
INSERT INTO 'dancesstepsmap' VALUES (150, 161, 4);
INSERT INTO 'dancesstepsmap' VALUES (151, 162, 1);
INSERT INTO 'dancesstepsmap' VALUES (152, 163, 1);
INSERT INTO 'dancesstepsmap' VALUES (153, 164, 4);
INSERT INTO 'dancesstepsmap' VALUES (154, 165, 4);
INSERT INTO 'dancesstepsmap' VALUES (155, 166, 1);
INSERT INTO 'dancesstepsmap' VALUES (156, 167, 1);
INSERT INTO 'dancesstepsmap' VALUES (157, 168, 1);
INSERT INTO 'dancesstepsmap' VALUES (158, 169, 1);
INSERT INTO 'dancesstepsmap' VALUES (159, 170, 1);
INSERT INTO 'dancesstepsmap' VALUES (160, 171, 1);
INSERT INTO 'dancesstepsmap' VALUES (161, 172, 4);
INSERT INTO 'dancesstepsmap' VALUES (162, 173, 1);
INSERT INTO 'dancesstepsmap' VALUES (163, 174, 4);
INSERT INTO 'dancesstepsmap' VALUES (164, 175, 1);
INSERT INTO 'dancesstepsmap' VALUES (165, 176, 4);
INSERT INTO 'dancesstepsmap' VALUES (166, 177, 1);
INSERT INTO 'dancesstepsmap' VALUES (167, 178, 4);
INSERT INTO 'dancesstepsmap' VALUES (168, 179, 1);
INSERT INTO 'dancesstepsmap' VALUES (169, 182, 1);
INSERT INTO 'dancesstepsmap' VALUES (170, 183, 1);
INSERT INTO 'dancesstepsmap' VALUES (171, 184, 1);
INSERT INTO 'dancesstepsmap' VALUES (172, 185, 4);
INSERT INTO 'dancesstepsmap' VALUES (173, 186, 4);
INSERT INTO 'dancesstepsmap' VALUES (174, 187, 4);
INSERT INTO 'dancesstepsmap' VALUES (175, 188, 1);
INSERT INTO 'dancesstepsmap' VALUES (176, 190, 4);
INSERT INTO 'dancesstepsmap' VALUES (177, 191, 1);
INSERT INTO 'dancesstepsmap' VALUES (178, 192, 1);
INSERT INTO 'dancesstepsmap' VALUES (179, 193, 4);
INSERT INTO 'dancesstepsmap' VALUES (180, 194, 1);
INSERT INTO 'dancesstepsmap' VALUES (181, 196, 1);
INSERT INTO 'dancesstepsmap' VALUES (182, 197, 1);
INSERT INTO 'dancesstepsmap' VALUES (183, 198, 1);
INSERT INTO 'dancesstepsmap' VALUES (184, 200, 1);
INSERT INTO 'dancesstepsmap' VALUES (185, 201, 1);
INSERT INTO 'dancesstepsmap' VALUES (9931, 9041, 1);
INSERT INTO 'dancesstepsmap' VALUES (9932, 9041, 3);
INSERT INTO 'dancesstepsmap' VALUES (9933, 9042, 4);
INSERT INTO 'dancesstepsmap' VALUES (9934, 9043, 1);
INSERT INTO 'dancesstepsmap' VALUES (9935, 9044, 4);
INSERT INTO 'dancesstepsmap' VALUES (9936, 9044, 5);
INSERT INTO 'dancesstepsmap' VALUES (9937, 9045, 3);
INSERT INTO 'dancesstepsmap' VALUES (9938, 9046, 3);
INSERT INTO 'dancesstepsmap' VALUES (9939, 9046, 1);
INSERT INTO 'dancesstepsmap' VALUES (9940, 9048, 4);
INSERT INTO 'dancesstepsmap' VALUES (9941, 9074, 4);
INSERT INTO 'dancesstepsmap' VALUES (9942, 9074, 5);
INSERT INTO 'dancesstepsmap' VALUES (9943, 9075, 1);
INSERT INTO 'dancesstepsmap' VALUES (9944, 9075, 2);
INSERT INTO 'dancesstepsmap' VALUES (9945, 9076, 3);
INSERT INTO 'dancesstepsmap' VALUES (9946, 9076, 1);
INSERT INTO 'dancesstepsmap' VALUES (9947, 9077, 5);
INSERT INTO 'dancesstepsmap' VALUES (9948, 9077, 2);
INSERT INTO 'dancesstepsmap' VALUES (9949, 9078, 2);
INSERT INTO 'dancesstepsmap' VALUES (9950, 9078, 1);
INSERT INTO 'dancesstepsmap' VALUES (9951, 9079, 2);
INSERT INTO 'dancesstepsmap' VALUES (9952, 9079, 3);
INSERT INTO 'dancesstepsmap' VALUES (9953, 9079, 1);
INSERT INTO 'dancesstepsmap' VALUES (9954, 9080, 2);
INSERT INTO 'dancesstepsmap' VALUES (9955, 9080, 1);
INSERT INTO 'dancesstepsmap' VALUES (9956, 2441, 3);
INSERT INTO 'dancesstepsmap' VALUES (9957, 3897, 5);
INSERT INTO 'dancesstepsmap' VALUES (9958, 9082, 4);
INSERT INTO 'dancesstepsmap' VALUES (9959, 9083, 1);
INSERT INTO 'dancesstepsmap' VALUES (9960, 9084, 1);
INSERT INTO 'dancesstepsmap' VALUES (9961, 9086, 5);
INSERT INTO 'dancesstepsmap' VALUES (9962, 9086, 4);
INSERT INTO 'dancesstepsmap' VALUES (9963, 9087, 1);
INSERT INTO 'dancesstepsmap' VALUES (9964, 9087, 2);
INSERT INTO 'dancesstepsmap' VALUES (9965, 3485, 5);
INSERT INTO 'dancesstepsmap' VALUES (9966, 9088, 4);
INSERT INTO 'dancesstepsmap' VALUES (9967, 9088, 1);
INSERT INTO 'dancesstepsmap' VALUES (9968, 9089, 1);
INSERT INTO 'dancesstepsmap' VALUES (9969, 9001, 1);
INSERT INTO 'dancesstepsmap' VALUES (9970, 9001, 2);
INSERT INTO 'dancesstepsmap' VALUES (9971, 9001, 3);
INSERT INTO 'dancesstepsmap' VALUES (9972, 9002, 1);
INSERT INTO 'dancesstepsmap' VALUES (16890, 12071, 8);
INSERT INTO 'dancesstepsmap' VALUES (16895, 2349, 2);
INSERT INTO 'dancesstepsmap' VALUES (16904, 2138, 4);
INSERT INTO 'dancesstepsmap' VALUES (186, 202, 4);
INSERT INTO 'dancesstepsmap' VALUES (187, 204, 1);
INSERT INTO 'dancesstepsmap' VALUES (188, 205, 4);
INSERT INTO 'dancesstepsmap' VALUES (189, 206, 1);
INSERT INTO 'dancesstepsmap' VALUES (190, 207, 1);
INSERT INTO 'dancesstepsmap' VALUES (191, 208, 1);
INSERT INTO 'dancesstepsmap' VALUES (192, 209, 1);
INSERT INTO 'dancesstepsmap' VALUES (193, 210, 1);
INSERT INTO 'dancesstepsmap' VALUES (194, 211, 1);
INSERT INTO 'dancesstepsmap' VALUES (195, 212, 4);
INSERT INTO 'dancesstepsmap' VALUES (196, 213, 4);
INSERT INTO 'dancesstepsmap' VALUES (197, 214, 1);
INSERT INTO 'dancesstepsmap' VALUES (198, 215, 1);
INSERT INTO 'dancesstepsmap' VALUES (199, 218, 1);
INSERT INTO 'dancesstepsmap' VALUES (200, 219, 4);
INSERT INTO 'dancesstepsmap' VALUES (201, 220, 1);
INSERT INTO 'dancesstepsmap' VALUES (202, 221, 4);
INSERT INTO 'dancesstepsmap' VALUES (203, 222, 1);
INSERT INTO 'dancesstepsmap' VALUES (204, 223, 1);
INSERT INTO 'dancesstepsmap' VALUES (205, 224, 1);
INSERT INTO 'dancesstepsmap' VALUES (206, 226, 1);
INSERT INTO 'dancesstepsmap' VALUES (207, 227, 1);
INSERT INTO 'dancesstepsmap' VALUES (208, 228, 1);
INSERT INTO 'dancesstepsmap' VALUES (209, 229, 1);
INSERT INTO 'dancesstepsmap' VALUES (210, 230, 1);
INSERT INTO 'dancesstepsmap' VALUES (211, 231, 4);
INSERT INTO 'dancesstepsmap' VALUES (212, 232, 4);
INSERT INTO 'dancesstepsmap' VALUES (213, 233, 1);
INSERT INTO 'dancesstepsmap' VALUES (214, 234, 4);
INSERT INTO 'dancesstepsmap' VALUES (215, 236, 1);
INSERT INTO 'dancesstepsmap' VALUES (216, 237, 1);
INSERT INTO 'dancesstepsmap' VALUES (217, 238, 1);
INSERT INTO 'dancesstepsmap' VALUES (218, 239, 1);
INSERT INTO 'dancesstepsmap' VALUES (219, 240, 1);
INSERT INTO 'dancesstepsmap' VALUES (220, 242, 4);
INSERT INTO 'dancesstepsmap' VALUES (221, 244, 1);
INSERT INTO 'dancesstepsmap' VALUES (222, 245, 1);
INSERT INTO 'dancesstepsmap' VALUES (223, 246, 4);
INSERT INTO 'dancesstepsmap' VALUES (224, 247, 1);
INSERT INTO 'dancesstepsmap' VALUES (225, 248, 4);
INSERT INTO 'dancesstepsmap' VALUES (226, 249, 1);
INSERT INTO 'dancesstepsmap' VALUES (227, 251, 1);
INSERT INTO 'dancesstepsmap' VALUES (228, 252, 4);
INSERT INTO 'dancesstepsmap' VALUES (229, 253, 4);
INSERT INTO 'dancesstepsmap' VALUES (230, 254, 1);
INSERT INTO 'dancesstepsmap' VALUES (231, 255, 4);
INSERT INTO 'dancesstepsmap' VALUES (232, 256, 4);
INSERT INTO 'dancesstepsmap' VALUES (233, 257, 1);
INSERT INTO 'dancesstepsmap' VALUES (234, 258, 1);
INSERT INTO 'dancesstepsmap' VALUES (235, 259, 1);
INSERT INTO 'dancesstepsmap' VALUES (236, 260, 1);
INSERT INTO 'dancesstepsmap' VALUES (237, 261, 1);
INSERT INTO 'dancesstepsmap' VALUES (238, 262, 4);
INSERT INTO 'dancesstepsmap' VALUES (239, 263, 1);
INSERT INTO 'dancesstepsmap' VALUES (240, 264, 1);
INSERT INTO 'dancesstepsmap' VALUES (241, 266, 1);
INSERT INTO 'dancesstepsmap' VALUES (242, 267, 1);
INSERT INTO 'dancesstepsmap' VALUES (243, 268, 1);
INSERT INTO 'dancesstepsmap' VALUES (244, 269, 1);
INSERT INTO 'dancesstepsmap' VALUES (245, 270, 4);
INSERT INTO 'dancesstepsmap' VALUES (246, 271, 1);
INSERT INTO 'dancesstepsmap' VALUES (247, 272, 1);
INSERT INTO 'dancesstepsmap' VALUES (248, 273, 1);
INSERT INTO 'dancesstepsmap' VALUES (249, 274, 1);
INSERT INTO 'dancesstepsmap' VALUES (250, 275, 4);
INSERT INTO 'dancesstepsmap' VALUES (251, 276, 1);
INSERT INTO 'dancesstepsmap' VALUES (252, 277, 4);
INSERT INTO 'dancesstepsmap' VALUES (253, 278, 1);
INSERT INTO 'dancesstepsmap' VALUES (254, 279, 1);
INSERT INTO 'dancesstepsmap' VALUES (255, 280, 1);
INSERT INTO 'dancesstepsmap' VALUES (256, 281, 1);
INSERT INTO 'dancesstepsmap' VALUES (257, 282, 1);
INSERT INTO 'dancesstepsmap' VALUES (258, 283, 1);
INSERT INTO 'dancesstepsmap' VALUES (259, 284, 4);
INSERT INTO 'dancesstepsmap' VALUES (260, 285, 4);
INSERT INTO 'dancesstepsmap' VALUES (261, 286, 4);
INSERT INTO 'dancesstepsmap' VALUES (262, 287, 4);
INSERT INTO 'dancesstepsmap' VALUES (263, 288, 1);
INSERT INTO 'dancesstepsmap' VALUES (264, 289, 1);
INSERT INTO 'dancesstepsmap' VALUES (265, 290, 1);
INSERT INTO 'dancesstepsmap' VALUES (266, 291, 1);
INSERT INTO 'dancesstepsmap' VALUES (267, 292, 4);
INSERT INTO 'dancesstepsmap' VALUES (268, 293, 1);
INSERT INTO 'dancesstepsmap' VALUES (269, 294, 1);
INSERT INTO 'dancesstepsmap' VALUES (270, 295, 1);
INSERT INTO 'dancesstepsmap' VALUES (271, 296, 1);
INSERT INTO 'dancesstepsmap' VALUES (272, 297, 1);
INSERT INTO 'dancesstepsmap' VALUES (273, 298, 4);
INSERT INTO 'dancesstepsmap' VALUES (274, 299, 4);
INSERT INTO 'dancesstepsmap' VALUES (275, 300, 4);
INSERT INTO 'dancesstepsmap' VALUES (276, 301, 4);
INSERT INTO 'dancesstepsmap' VALUES (277, 302, 4);
INSERT INTO 'dancesstepsmap' VALUES (9994, 9102, 1);
INSERT INTO 'dancesstepsmap' VALUES (9995, 9103, 1);
INSERT INTO 'dancesstepsmap' VALUES (9996, 9104, 2);
INSERT INTO 'dancesstepsmap' VALUES (9997, 9104, 3);
INSERT INTO 'dancesstepsmap' VALUES (9998, 9104, 1);
INSERT INTO 'dancesstepsmap' VALUES (9999, 9105, 2);
INSERT INTO 'dancesstepsmap' VALUES (10000, 9106, 4);
INSERT INTO 'dancesstepsmap' VALUES (10001, 9106, 5);
INSERT INTO 'dancesstepsmap' VALUES (10002, 9107, 1);
INSERT INTO 'dancesstepsmap' VALUES (10003, 9108, 1);
INSERT INTO 'dancesstepsmap' VALUES (10004, 9109, 3);
INSERT INTO 'dancesstepsmap' VALUES (10005, 9110, 1);
INSERT INTO 'dancesstepsmap' VALUES (10006, 9111, 3);
INSERT INTO 'dancesstepsmap' VALUES (10007, 9111, 1);
INSERT INTO 'dancesstepsmap' VALUES (10008, 9113, 5);
INSERT INTO 'dancesstepsmap' VALUES (10009, 9113, 4);
INSERT INTO 'dancesstepsmap' VALUES (10010, 9114, 4);
INSERT INTO 'dancesstepsmap' VALUES (10011, 8138, 5);
INSERT INTO 'dancesstepsmap' VALUES (10012, 9115, 4);
INSERT INTO 'dancesstepsmap' VALUES (10013, 9116, 1);
INSERT INTO 'dancesstepsmap' VALUES (10014, 9117, 1);
INSERT INTO 'dancesstepsmap' VALUES (10015, 9117, 3);
INSERT INTO 'dancesstepsmap' VALUES (10016, 9118, 2);
INSERT INTO 'dancesstepsmap' VALUES (10017, 9119, 4);
INSERT INTO 'dancesstepsmap' VALUES (10018, 1453, 5);
INSERT INTO 'dancesstepsmap' VALUES (10019, 9120, 4);
INSERT INTO 'dancesstepsmap' VALUES (10020, 9121, 1);
INSERT INTO 'dancesstepsmap' VALUES (10021, 9122, 4);
INSERT INTO 'dancesstepsmap' VALUES (10022, 9123, 2);
INSERT INTO 'dancesstepsmap' VALUES (10023, 9124, 1);
INSERT INTO 'dancesstepsmap' VALUES (10024, 9124, 3);
INSERT INTO 'dancesstepsmap' VALUES (10025, 9125, 1);
INSERT INTO 'dancesstepsmap' VALUES (10026, 9126, 1);
INSERT INTO 'dancesstepsmap' VALUES (10027, 9127, 4);
INSERT INTO 'dancesstepsmap' VALUES (10028, 8930, 1);
INSERT INTO 'dancesstepsmap' VALUES (10029, 9128, 1);
INSERT INTO 'dancesstepsmap' VALUES (10030, 9128, 2);
INSERT INTO 'dancesstepsmap' VALUES (10031, 9129, 3);
INSERT INTO 'dancesstepsmap' VALUES (10032, 9130, 4);
INSERT INTO 'dancesstepsmap' VALUES (10033, 9132, 1);
INSERT INTO 'dancesstepsmap' VALUES (10034, 9134, 4);
INSERT INTO 'dancesstepsmap' VALUES (10035, 9135, 1);
INSERT INTO 'dancesstepsmap' VALUES (10036, 9135, 2);
INSERT INTO 'dancesstepsmap' VALUES (10037, 9135, 4);
INSERT INTO 'dancesstepsmap' VALUES (10038, 9135, 5);
INSERT INTO 'dancesstepsmap' VALUES (10039, 9136, 4);
INSERT INTO 'dancesstepsmap' VALUES (10040, 9136, 5);
INSERT INTO 'dancesstepsmap' VALUES (10041, 9148, 4);
INSERT INTO 'dancesstepsmap' VALUES (10042, 802, 4);
INSERT INTO 'dancesstepsmap' VALUES (10043, 802, 5);
INSERT INTO 'dancesstepsmap' VALUES (10044, 9157, 1);
INSERT INTO 'dancesstepsmap' VALUES (16905, 930, 2);
INSERT INTO 'dancesstepsmap' VALUES (16908, 988, 2);
INSERT INTO 'dancesstepsmap' VALUES (278, 303, 4);
INSERT INTO 'dancesstepsmap' VALUES (279, 305, 1);
INSERT INTO 'dancesstepsmap' VALUES (280, 306, 4);
INSERT INTO 'dancesstepsmap' VALUES (281, 307, 4);
INSERT INTO 'dancesstepsmap' VALUES (282, 308, 1);
INSERT INTO 'dancesstepsmap' VALUES (283, 309, 1);
INSERT INTO 'dancesstepsmap' VALUES (284, 310, 1);
INSERT INTO 'dancesstepsmap' VALUES (285, 311, 4);
INSERT INTO 'dancesstepsmap' VALUES (286, 312, 1);
INSERT INTO 'dancesstepsmap' VALUES (287, 313, 1);
INSERT INTO 'dancesstepsmap' VALUES (288, 314, 4);
INSERT INTO 'dancesstepsmap' VALUES (289, 315, 1);
INSERT INTO 'dancesstepsmap' VALUES (290, 316, 4);
INSERT INTO 'dancesstepsmap' VALUES (291, 317, 4);
INSERT INTO 'dancesstepsmap' VALUES (292, 318, 4);
INSERT INTO 'dancesstepsmap' VALUES (293, 319, 4);
INSERT INTO 'dancesstepsmap' VALUES (294, 321, 4);
INSERT INTO 'dancesstepsmap' VALUES (295, 322, 1);
INSERT INTO 'dancesstepsmap' VALUES (296, 323, 1);
INSERT INTO 'dancesstepsmap' VALUES (297, 324, 1);
INSERT INTO 'dancesstepsmap' VALUES (298, 325, 1);
INSERT INTO 'dancesstepsmap' VALUES (299, 326, 1);
INSERT INTO 'dancesstepsmap' VALUES (300, 327, 4);
INSERT INTO 'dancesstepsmap' VALUES (301, 328, 4);
INSERT INTO 'dancesstepsmap' VALUES (302, 329, 1);
INSERT INTO 'dancesstepsmap' VALUES (303, 330, 1);
INSERT INTO 'dancesstepsmap' VALUES (304, 331, 1);
INSERT INTO 'dancesstepsmap' VALUES (305, 332, 1);
INSERT INTO 'dancesstepsmap' VALUES (306, 333, 1);
INSERT INTO 'dancesstepsmap' VALUES (307, 334, 4);
INSERT INTO 'dancesstepsmap' VALUES (308, 335, 1);
INSERT INTO 'dancesstepsmap' VALUES (309, 336, 4);
INSERT INTO 'dancesstepsmap' VALUES (310, 337, 4);
INSERT INTO 'dancesstepsmap' VALUES (311, 338, 1);
INSERT INTO 'dancesstepsmap' VALUES (312, 339, 1);
INSERT INTO 'dancesstepsmap' VALUES (313, 340, 1);
INSERT INTO 'dancesstepsmap' VALUES (314, 341, 1);
INSERT INTO 'dancesstepsmap' VALUES (23130, 18245, 2);
INSERT INTO 'dancesstepsmap' VALUES (316, 343, 1);
INSERT INTO 'dancesstepsmap' VALUES (317, 344, 1);
INSERT INTO 'dancesstepsmap' VALUES (318, 345, 1);
INSERT INTO 'dancesstepsmap' VALUES (319, 346, 1);
INSERT INTO 'dancesstepsmap' VALUES (320, 347, 1);
INSERT INTO 'dancesstepsmap' VALUES (321, 348, 4);
INSERT INTO 'dancesstepsmap' VALUES (322, 349, 1);
INSERT INTO 'dancesstepsmap' VALUES (323, 350, 1);
INSERT INTO 'dancesstepsmap' VALUES (324, 351, 1);
INSERT INTO 'dancesstepsmap' VALUES (325, 352, 1);
INSERT INTO 'dancesstepsmap' VALUES (326, 353, 1);
INSERT INTO 'dancesstepsmap' VALUES (327, 354, 4);
INSERT INTO 'dancesstepsmap' VALUES (328, 355, 4);
INSERT INTO 'dancesstepsmap' VALUES (329, 356, 1);
INSERT INTO 'dancesstepsmap' VALUES (330, 358, 1);
INSERT INTO 'dancesstepsmap' VALUES (331, 360, 4);
INSERT INTO 'dancesstepsmap' VALUES (332, 361, 4);
INSERT INTO 'dancesstepsmap' VALUES (333, 362, 4);
INSERT INTO 'dancesstepsmap' VALUES (334, 363, 4);
INSERT INTO 'dancesstepsmap' VALUES (335, 364, 1);
INSERT INTO 'dancesstepsmap' VALUES (336, 365, 4);
INSERT INTO 'dancesstepsmap' VALUES (337, 366, 4);
INSERT INTO 'dancesstepsmap' VALUES (338, 367, 1);
INSERT INTO 'dancesstepsmap' VALUES (339, 368, 1);
INSERT INTO 'dancesstepsmap' VALUES (340, 369, 4);
INSERT INTO 'dancesstepsmap' VALUES (341, 370, 4);
INSERT INTO 'dancesstepsmap' VALUES (342, 371, 1);
INSERT INTO 'dancesstepsmap' VALUES (343, 372, 1);
INSERT INTO 'dancesstepsmap' VALUES (344, 373, 4);
INSERT INTO 'dancesstepsmap' VALUES (345, 374, 1);
INSERT INTO 'dancesstepsmap' VALUES (346, 375, 4);
INSERT INTO 'dancesstepsmap' VALUES (347, 376, 1);
INSERT INTO 'dancesstepsmap' VALUES (348, 377, 4);
INSERT INTO 'dancesstepsmap' VALUES (349, 378, 4);
INSERT INTO 'dancesstepsmap' VALUES (350, 379, 1);
INSERT INTO 'dancesstepsmap' VALUES (351, 380, 4);
INSERT INTO 'dancesstepsmap' VALUES (352, 382, 1);
INSERT INTO 'dancesstepsmap' VALUES (353, 383, 1);
INSERT INTO 'dancesstepsmap' VALUES (354, 384, 1);
INSERT INTO 'dancesstepsmap' VALUES (355, 385, 1);
INSERT INTO 'dancesstepsmap' VALUES (356, 386, 1);
INSERT INTO 'dancesstepsmap' VALUES (357, 388, 1);
INSERT INTO 'dancesstepsmap' VALUES (358, 389, 1);
INSERT INTO 'dancesstepsmap' VALUES (359, 390, 4);
INSERT INTO 'dancesstepsmap' VALUES (360, 391, 1);
INSERT INTO 'dancesstepsmap' VALUES (361, 392, 4);
INSERT INTO 'dancesstepsmap' VALUES (362, 393, 1);
INSERT INTO 'dancesstepsmap' VALUES (363, 394, 4);
INSERT INTO 'dancesstepsmap' VALUES (364, 396, 1);
INSERT INTO 'dancesstepsmap' VALUES (365, 397, 1);
INSERT INTO 'dancesstepsmap' VALUES (366, 398, 1);
INSERT INTO 'dancesstepsmap' VALUES (367, 399, 1);
INSERT INTO 'dancesstepsmap' VALUES (368, 400, 1);
INSERT INTO 'dancesstepsmap' VALUES (369, 401, 1);
INSERT INTO 'dancesstepsmap' VALUES (370, 402, 1);
INSERT INTO 'dancesstepsmap' VALUES (9973, 9015, 2);
INSERT INTO 'dancesstepsmap' VALUES (9974, 9015, 1);
INSERT INTO 'dancesstepsmap' VALUES (9975, 9091, 1);
INSERT INTO 'dancesstepsmap' VALUES (9976, 9092, 4);
INSERT INTO 'dancesstepsmap' VALUES (9977, 9093, 2);
INSERT INTO 'dancesstepsmap' VALUES (9978, 9093, 1);
INSERT INTO 'dancesstepsmap' VALUES (9979, 9094, 2);
INSERT INTO 'dancesstepsmap' VALUES (9980, 9094, 3);
INSERT INTO 'dancesstepsmap' VALUES (9981, 9094, 1);
INSERT INTO 'dancesstepsmap' VALUES (9982, 9095, 4);
INSERT INTO 'dancesstepsmap' VALUES (9983, 9096, 2);
INSERT INTO 'dancesstepsmap' VALUES (9984, 9054, 1);
INSERT INTO 'dancesstepsmap' VALUES (9985, 9054, 2);
INSERT INTO 'dancesstepsmap' VALUES (10045, 9158, 1);
INSERT INTO 'dancesstepsmap' VALUES (10046, 9158, 3);
INSERT INTO 'dancesstepsmap' VALUES (10047, 9159, 4);
INSERT INTO 'dancesstepsmap' VALUES (10048, 9161, 4);
INSERT INTO 'dancesstepsmap' VALUES (10049, 9161, 5);
INSERT INTO 'dancesstepsmap' VALUES (10050, 9163, 1);
INSERT INTO 'dancesstepsmap' VALUES (10051, 9163, 2);
INSERT INTO 'dancesstepsmap' VALUES (10052, 9164, 4);
INSERT INTO 'dancesstepsmap' VALUES (10053, 9149, 4);
INSERT INTO 'dancesstepsmap' VALUES (10054, 9150, 2);
INSERT INTO 'dancesstepsmap' VALUES (10055, 9150, 1);
INSERT INTO 'dancesstepsmap' VALUES (10056, 9151, 1);
INSERT INTO 'dancesstepsmap' VALUES (10057, 9152, 2);
INSERT INTO 'dancesstepsmap' VALUES (10058, 9152, 1);
INSERT INTO 'dancesstepsmap' VALUES (10059, 9152, 3);
INSERT INTO 'dancesstepsmap' VALUES (10060, 9153, 4);
INSERT INTO 'dancesstepsmap' VALUES (10061, 9154, 1);
INSERT INTO 'dancesstepsmap' VALUES (10062, 9154, 2);
INSERT INTO 'dancesstepsmap' VALUES (10063, 9155, 1);
INSERT INTO 'dancesstepsmap' VALUES (10064, 9156, 4);
INSERT INTO 'dancesstepsmap' VALUES (10065, 9156, 5);
INSERT INTO 'dancesstepsmap' VALUES (10066, 9165, 4);
INSERT INTO 'dancesstepsmap' VALUES (10067, 9165, 5);
INSERT INTO 'dancesstepsmap' VALUES (10068, 9166, 1);
INSERT INTO 'dancesstepsmap' VALUES (10069, 9167, 1);
INSERT INTO 'dancesstepsmap' VALUES (10070, 9179, 1);
INSERT INTO 'dancesstepsmap' VALUES (10071, 9180, 3);
INSERT INTO 'dancesstepsmap' VALUES (10072, 9181, 1);
INSERT INTO 'dancesstepsmap' VALUES (10073, 9184, 4);
INSERT INTO 'dancesstepsmap' VALUES (10074, 9184, 5);
INSERT INTO 'dancesstepsmap' VALUES (10075, 9090, 5);
INSERT INTO 'dancesstepsmap' VALUES (10076, 9090, 4);
INSERT INTO 'dancesstepsmap' VALUES (10077, 9169, 3);
INSERT INTO 'dancesstepsmap' VALUES (10078, 9169, 1);
INSERT INTO 'dancesstepsmap' VALUES (10079, 9169, 2);
INSERT INTO 'dancesstepsmap' VALUES (16906, 2714, 2);
INSERT INTO 'dancesstepsmap' VALUES (16911, 7785, 2);
INSERT INTO 'dancesstepsmap' VALUES (16919, 8294, 5);
INSERT INTO 'dancesstepsmap' VALUES (371, 403, 1);
INSERT INTO 'dancesstepsmap' VALUES (372, 404, 1);
INSERT INTO 'dancesstepsmap' VALUES (373, 405, 1);
INSERT INTO 'dancesstepsmap' VALUES (374, 406, 1);
INSERT INTO 'dancesstepsmap' VALUES (375, 407, 4);
INSERT INTO 'dancesstepsmap' VALUES (376, 408, 1);
INSERT INTO 'dancesstepsmap' VALUES (377, 409, 1);
INSERT INTO 'dancesstepsmap' VALUES (378, 410, 1);
INSERT INTO 'dancesstepsmap' VALUES (379, 411, 1);
INSERT INTO 'dancesstepsmap' VALUES (380, 412, 1);
INSERT INTO 'dancesstepsmap' VALUES (381, 413, 1);
INSERT INTO 'dancesstepsmap' VALUES (382, 414, 1);
INSERT INTO 'dancesstepsmap' VALUES (383, 415, 1);
INSERT INTO 'dancesstepsmap' VALUES (384, 416, 1);
INSERT INTO 'dancesstepsmap' VALUES (385, 417, 1);
INSERT INTO 'dancesstepsmap' VALUES (386, 418, 1);
INSERT INTO 'dancesstepsmap' VALUES (387, 420, 1);
INSERT INTO 'dancesstepsmap' VALUES (388, 421, 1);
INSERT INTO 'dancesstepsmap' VALUES (389, 422, 1);
INSERT INTO 'dancesstepsmap' VALUES (390, 423, 1);
INSERT INTO 'dancesstepsmap' VALUES (391, 424, 1);
INSERT INTO 'dancesstepsmap' VALUES (392, 425, 1);
INSERT INTO 'dancesstepsmap' VALUES (393, 426, 4);
INSERT INTO 'dancesstepsmap' VALUES (394, 427, 1);
INSERT INTO 'dancesstepsmap' VALUES (395, 428, 1);
INSERT INTO 'dancesstepsmap' VALUES (396, 429, 1);
INSERT INTO 'dancesstepsmap' VALUES (397, 430, 1);
INSERT INTO 'dancesstepsmap' VALUES (398, 431, 1);
INSERT INTO 'dancesstepsmap' VALUES (399, 432, 4);
INSERT INTO 'dancesstepsmap' VALUES (400, 433, 1);
INSERT INTO 'dancesstepsmap' VALUES (401, 434, 1);
INSERT INTO 'dancesstepsmap' VALUES (402, 435, 1);
INSERT INTO 'dancesstepsmap' VALUES (403, 436, 4);
INSERT INTO 'dancesstepsmap' VALUES (404, 437, 1);
INSERT INTO 'dancesstepsmap' VALUES (405, 438, 1);
INSERT INTO 'dancesstepsmap' VALUES (406, 439, 4);
INSERT INTO 'dancesstepsmap' VALUES (407, 440, 4);
INSERT INTO 'dancesstepsmap' VALUES (408, 442, 4);
INSERT INTO 'dancesstepsmap' VALUES (409, 443, 1);
INSERT INTO 'dancesstepsmap' VALUES (410, 445, 1);
INSERT INTO 'dancesstepsmap' VALUES (411, 446, 1);
INSERT INTO 'dancesstepsmap' VALUES (412, 447, 1);
INSERT INTO 'dancesstepsmap' VALUES (413, 448, 1);
INSERT INTO 'dancesstepsmap' VALUES (414, 449, 4);
INSERT INTO 'dancesstepsmap' VALUES (415, 450, 1);
INSERT INTO 'dancesstepsmap' VALUES (416, 451, 1);
INSERT INTO 'dancesstepsmap' VALUES (417, 452, 1);
INSERT INTO 'dancesstepsmap' VALUES (418, 453, 1);
INSERT INTO 'dancesstepsmap' VALUES (419, 454, 1);
INSERT INTO 'dancesstepsmap' VALUES (420, 456, 1);
INSERT INTO 'dancesstepsmap' VALUES (421, 457, 1);
INSERT INTO 'dancesstepsmap' VALUES (422, 460, 4);
INSERT INTO 'dancesstepsmap' VALUES (423, 461, 4);
INSERT INTO 'dancesstepsmap' VALUES (424, 462, 4);
INSERT INTO 'dancesstepsmap' VALUES (425, 463, 1);
INSERT INTO 'dancesstepsmap' VALUES (426, 464, 1);
INSERT INTO 'dancesstepsmap' VALUES (427, 465, 1);
INSERT INTO 'dancesstepsmap' VALUES (428, 466, 4);
INSERT INTO 'dancesstepsmap' VALUES (429, 467, 1);
INSERT INTO 'dancesstepsmap' VALUES (430, 469, 1);
INSERT INTO 'dancesstepsmap' VALUES (431, 471, 1);
INSERT INTO 'dancesstepsmap' VALUES (432, 472, 1);
INSERT INTO 'dancesstepsmap' VALUES (433, 473, 4);
INSERT INTO 'dancesstepsmap' VALUES (434, 474, 1);
INSERT INTO 'dancesstepsmap' VALUES (435, 475, 4);
INSERT INTO 'dancesstepsmap' VALUES (436, 476, 1);
INSERT INTO 'dancesstepsmap' VALUES (437, 477, 1);
INSERT INTO 'dancesstepsmap' VALUES (438, 478, 1);
INSERT INTO 'dancesstepsmap' VALUES (439, 479, 1);
INSERT INTO 'dancesstepsmap' VALUES (440, 480, 1);
INSERT INTO 'dancesstepsmap' VALUES (441, 481, 1);
INSERT INTO 'dancesstepsmap' VALUES (442, 482, 1);
INSERT INTO 'dancesstepsmap' VALUES (443, 483, 4);
INSERT INTO 'dancesstepsmap' VALUES (444, 484, 1);
INSERT INTO 'dancesstepsmap' VALUES (445, 486, 1);
INSERT INTO 'dancesstepsmap' VALUES (446, 487, 4);
INSERT INTO 'dancesstepsmap' VALUES (447, 488, 1);
INSERT INTO 'dancesstepsmap' VALUES (448, 489, 1);
INSERT INTO 'dancesstepsmap' VALUES (449, 490, 4);
INSERT INTO 'dancesstepsmap' VALUES (450, 491, 4);
INSERT INTO 'dancesstepsmap' VALUES (451, 492, 1);
INSERT INTO 'dancesstepsmap' VALUES (452, 493, 1);
INSERT INTO 'dancesstepsmap' VALUES (453, 494, 1);
INSERT INTO 'dancesstepsmap' VALUES (454, 495, 1);
INSERT INTO 'dancesstepsmap' VALUES (455, 496, 1);
INSERT INTO 'dancesstepsmap' VALUES (456, 498, 1);
INSERT INTO 'dancesstepsmap' VALUES (457, 499, 1);
INSERT INTO 'dancesstepsmap' VALUES (458, 500, 1);
INSERT INTO 'dancesstepsmap' VALUES (459, 503, 1);
INSERT INTO 'dancesstepsmap' VALUES (460, 504, 4);
INSERT INTO 'dancesstepsmap' VALUES (461, 506, 4);
INSERT INTO 'dancesstepsmap' VALUES (462, 507, 1);
INSERT INTO 'dancesstepsmap' VALUES (10080, 8954, 4);
INSERT INTO 'dancesstepsmap' VALUES (10081, 9332, 1);
INSERT INTO 'dancesstepsmap' VALUES (10082, 9332, 3);
INSERT INTO 'dancesstepsmap' VALUES (10083, 6221, 5);
INSERT INTO 'dancesstepsmap' VALUES (10084, 9333, 4);
INSERT INTO 'dancesstepsmap' VALUES (10085, 9333, 5);
INSERT INTO 'dancesstepsmap' VALUES (10086, 9334, 4);
INSERT INTO 'dancesstepsmap' VALUES (10087, 9335, 6);
INSERT INTO 'dancesstepsmap' VALUES (10088, 9335, 4);
INSERT INTO 'dancesstepsmap' VALUES (10089, 9336, 1);
INSERT INTO 'dancesstepsmap' VALUES (10090, 9337, 1);
INSERT INTO 'dancesstepsmap' VALUES (10091, 9337, 3);
INSERT INTO 'dancesstepsmap' VALUES (10092, 9338, 1);
INSERT INTO 'dancesstepsmap' VALUES (10093, 9338, 2);
INSERT INTO 'dancesstepsmap' VALUES (10094, 8490, 2);
INSERT INTO 'dancesstepsmap' VALUES (10097, 9340, 3);
INSERT INTO 'dancesstepsmap' VALUES (10098, 9341, 5);
INSERT INTO 'dancesstepsmap' VALUES (10099, 9341, 4);
INSERT INTO 'dancesstepsmap' VALUES (10100, 9342, 10);
INSERT INTO 'dancesstepsmap' VALUES (10101, 9350, 3);
INSERT INTO 'dancesstepsmap' VALUES (10102, 9351, 3);
INSERT INTO 'dancesstepsmap' VALUES (10104, 9351, 1);
INSERT INTO 'dancesstepsmap' VALUES (10105, 9350, 1);
INSERT INTO 'dancesstepsmap' VALUES (10106, 9353, 4);
INSERT INTO 'dancesstepsmap' VALUES (10107, 8626, 10);
INSERT INTO 'dancesstepsmap' VALUES (10108, 9355, 1);
INSERT INTO 'dancesstepsmap' VALUES (10109, 9355, 3);
INSERT INTO 'dancesstepsmap' VALUES (10110, 9357, 6);
INSERT INTO 'dancesstepsmap' VALUES (10111, 9357, 4);
INSERT INTO 'dancesstepsmap' VALUES (10112, 9358, 4);
INSERT INTO 'dancesstepsmap' VALUES (10113, 9358, 5);
INSERT INTO 'dancesstepsmap' VALUES (10114, 9359, 4);
INSERT INTO 'dancesstepsmap' VALUES (10115, 9364, 1);
INSERT INTO 'dancesstepsmap' VALUES (10116, 9132, 3);
INSERT INTO 'dancesstepsmap' VALUES (10117, 9356, 4);
INSERT INTO 'dancesstepsmap' VALUES (10118, 9362, 1);
INSERT INTO 'dancesstepsmap' VALUES (10119, 9360, 3);
INSERT INTO 'dancesstepsmap' VALUES (10120, 9363, 1);
INSERT INTO 'dancesstepsmap' VALUES (10121, 9365, 1);
INSERT INTO 'dancesstepsmap' VALUES (10122, 3778, 3);
INSERT INTO 'dancesstepsmap' VALUES (10123, 8331, 5);
INSERT INTO 'dancesstepsmap' VALUES (16907, 714, 5);
INSERT INTO 'dancesstepsmap' VALUES (16912, 7451, 2);
INSERT INTO 'dancesstepsmap' VALUES (16920, 13982, 4);
INSERT INTO 'dancesstepsmap' VALUES (16921, 13982, 5);
INSERT INTO 'dancesstepsmap' VALUES (16922, 14405, 1);
INSERT INTO 'dancesstepsmap' VALUES (16923, 14405, 2);
INSERT INTO 'dancesstepsmap' VALUES (16924, 13640, 3);
INSERT INTO 'dancesstepsmap' VALUES (16925, 13850, 1);
INSERT INTO 'dancesstepsmap' VALUES (16926, 13850, 2);
INSERT INTO 'dancesstepsmap' VALUES (16927, 13850, 3);
INSERT INTO 'dancesstepsmap' VALUES (16928, 587, 2);
INSERT INTO 'dancesstepsmap' VALUES (16929, 14406, 1);
INSERT INTO 'dancesstepsmap' VALUES (16930, 14418, 1);
INSERT INTO 'dancesstepsmap' VALUES (16931, 14418, 2);
INSERT INTO 'dancesstepsmap' VALUES (16932, 11282, 1);
INSERT INTO 'dancesstepsmap' VALUES (16933, 9701, 5);
INSERT INTO 'dancesstepsmap' VALUES (16936, 11289, 5);
INSERT INTO 'dancesstepsmap' VALUES (16938, 14419, 4);
INSERT INTO 'dancesstepsmap' VALUES (16940, 13071, 2);
INSERT INTO 'dancesstepsmap' VALUES (16941, 13593, 1);
INSERT INTO 'dancesstepsmap' VALUES (16942, 13593, 2);
INSERT INTO 'dancesstepsmap' VALUES (16943, 13594, 1);
INSERT INTO 'dancesstepsmap' VALUES (16944, 13594, 2);
INSERT INTO 'dancesstepsmap' VALUES (463, 508, 1);
INSERT INTO 'dancesstepsmap' VALUES (464, 509, 4);
INSERT INTO 'dancesstepsmap' VALUES (465, 510, 1);
INSERT INTO 'dancesstepsmap' VALUES (466, 511, 1);
INSERT INTO 'dancesstepsmap' VALUES (467, 512, 1);
INSERT INTO 'dancesstepsmap' VALUES (468, 513, 1);
INSERT INTO 'dancesstepsmap' VALUES (469, 514, 4);
INSERT INTO 'dancesstepsmap' VALUES (470, 515, 1);
INSERT INTO 'dancesstepsmap' VALUES (471, 516, 4);
INSERT INTO 'dancesstepsmap' VALUES (472, 517, 4);
INSERT INTO 'dancesstepsmap' VALUES (473, 518, 4);
INSERT INTO 'dancesstepsmap' VALUES (474, 520, 4);
INSERT INTO 'dancesstepsmap' VALUES (475, 521, 1);
INSERT INTO 'dancesstepsmap' VALUES (476, 522, 4);
INSERT INTO 'dancesstepsmap' VALUES (477, 523, 1);
INSERT INTO 'dancesstepsmap' VALUES (478, 524, 1);
INSERT INTO 'dancesstepsmap' VALUES (479, 525, 1);
INSERT INTO 'dancesstepsmap' VALUES (480, 526, 1);
INSERT INTO 'dancesstepsmap' VALUES (481, 527, 1);
INSERT INTO 'dancesstepsmap' VALUES (482, 528, 4);
INSERT INTO 'dancesstepsmap' VALUES (483, 529, 1);
INSERT INTO 'dancesstepsmap' VALUES (484, 530, 4);
INSERT INTO 'dancesstepsmap' VALUES (485, 531, 1);
INSERT INTO 'dancesstepsmap' VALUES (486, 532, 1);
INSERT INTO 'dancesstepsmap' VALUES (487, 533, 1);
INSERT INTO 'dancesstepsmap' VALUES (488, 534, 1);
INSERT INTO 'dancesstepsmap' VALUES (489, 535, 1);
INSERT INTO 'dancesstepsmap' VALUES (490, 536, 1);
INSERT INTO 'dancesstepsmap' VALUES (491, 537, 1);
INSERT INTO 'dancesstepsmap' VALUES (492, 538, 1);
INSERT INTO 'dancesstepsmap' VALUES (493, 539, 4);
INSERT INTO 'dancesstepsmap' VALUES (494, 540, 1);
INSERT INTO 'dancesstepsmap' VALUES (495, 541, 1);
INSERT INTO 'dancesstepsmap' VALUES (496, 542, 1);
INSERT INTO 'dancesstepsmap' VALUES (497, 543, 1);
INSERT INTO 'dancesstepsmap' VALUES (498, 545, 1);
INSERT INTO 'dancesstepsmap' VALUES (499, 546, 4);
INSERT INTO 'dancesstepsmap' VALUES (500, 547, 1);
INSERT INTO 'dancesstepsmap' VALUES (501, 549, 1);
INSERT INTO 'dancesstepsmap' VALUES (502, 550, 4);
INSERT INTO 'dancesstepsmap' VALUES (503, 551, 4);
INSERT INTO 'dancesstepsmap' VALUES (504, 552, 1);
INSERT INTO 'dancesstepsmap' VALUES (505, 553, 1);
INSERT INTO 'dancesstepsmap' VALUES (506, 554, 4);
INSERT INTO 'dancesstepsmap' VALUES (507, 555, 4);
INSERT INTO 'dancesstepsmap' VALUES (508, 556, 1);
INSERT INTO 'dancesstepsmap' VALUES (509, 557, 1);
INSERT INTO 'dancesstepsmap' VALUES (510, 558, 1);
INSERT INTO 'dancesstepsmap' VALUES (511, 559, 1);
INSERT INTO 'dancesstepsmap' VALUES (512, 560, 1);
INSERT INTO 'dancesstepsmap' VALUES (513, 561, 1);
INSERT INTO 'dancesstepsmap' VALUES (514, 562, 1);
INSERT INTO 'dancesstepsmap' VALUES (515, 563, 4);
INSERT INTO 'dancesstepsmap' VALUES (516, 564, 4);
INSERT INTO 'dancesstepsmap' VALUES (517, 565, 4);
INSERT INTO 'dancesstepsmap' VALUES (518, 566, 1);
INSERT INTO 'dancesstepsmap' VALUES (519, 567, 4);
INSERT INTO 'dancesstepsmap' VALUES (520, 568, 4);
INSERT INTO 'dancesstepsmap' VALUES (521, 569, 4);
INSERT INTO 'dancesstepsmap' VALUES (522, 570, 4);
INSERT INTO 'dancesstepsmap' VALUES (523, 571, 1);
INSERT INTO 'dancesstepsmap' VALUES (524, 572, 1);
INSERT INTO 'dancesstepsmap' VALUES (525, 573, 4);
INSERT INTO 'dancesstepsmap' VALUES (526, 574, 1);
INSERT INTO 'dancesstepsmap' VALUES (527, 575, 4);
INSERT INTO 'dancesstepsmap' VALUES (528, 576, 1);
INSERT INTO 'dancesstepsmap' VALUES (529, 577, 1);
INSERT INTO 'dancesstepsmap' VALUES (530, 578, 4);
INSERT INTO 'dancesstepsmap' VALUES (531, 579, 1);
INSERT INTO 'dancesstepsmap' VALUES (532, 580, 4);
INSERT INTO 'dancesstepsmap' VALUES (533, 581, 4);
INSERT INTO 'dancesstepsmap' VALUES (534, 582, 4);
INSERT INTO 'dancesstepsmap' VALUES (535, 583, 4);
INSERT INTO 'dancesstepsmap' VALUES (536, 584, 1);
INSERT INTO 'dancesstepsmap' VALUES (537, 585, 1);
INSERT INTO 'dancesstepsmap' VALUES (538, 586, 1);
INSERT INTO 'dancesstepsmap' VALUES (539, 587, 1);
INSERT INTO 'dancesstepsmap' VALUES (540, 588, 1);
INSERT INTO 'dancesstepsmap' VALUES (541, 590, 1);
INSERT INTO 'dancesstepsmap' VALUES (542, 591, 1);
INSERT INTO 'dancesstepsmap' VALUES (543, 592, 1);
INSERT INTO 'dancesstepsmap' VALUES (544, 593, 4);
INSERT INTO 'dancesstepsmap' VALUES (545, 594, 4);
INSERT INTO 'dancesstepsmap' VALUES (546, 595, 1);
INSERT INTO 'dancesstepsmap' VALUES (547, 596, 1);
INSERT INTO 'dancesstepsmap' VALUES (548, 597, 4);
INSERT INTO 'dancesstepsmap' VALUES (549, 598, 4);
INSERT INTO 'dancesstepsmap' VALUES (550, 599, 4);
INSERT INTO 'dancesstepsmap' VALUES (551, 600, 1);
INSERT INTO 'dancesstepsmap' VALUES (552, 601, 4);
INSERT INTO 'dancesstepsmap' VALUES (553, 602, 4);
INSERT INTO 'dancesstepsmap' VALUES (554, 603, 1);
INSERT INTO 'dancesstepsmap' VALUES (555, 604, 4);
INSERT INTO 'dancesstepsmap' VALUES (556, 605, 1);
INSERT INTO 'dancesstepsmap' VALUES (557, 606, 4);
INSERT INTO 'dancesstepsmap' VALUES (558, 607, 1);
INSERT INTO 'dancesstepsmap' VALUES (559, 608, 4);
INSERT INTO 'dancesstepsmap' VALUES (560, 609, 1);
INSERT INTO 'dancesstepsmap' VALUES (561, 610, 1);
INSERT INTO 'dancesstepsmap' VALUES (562, 611, 1);
INSERT INTO 'dancesstepsmap' VALUES (563, 612, 1);
INSERT INTO 'dancesstepsmap' VALUES (564, 613, 1);
INSERT INTO 'dancesstepsmap' VALUES (565, 615, 1);
INSERT INTO 'dancesstepsmap' VALUES (566, 616, 1);
INSERT INTO 'dancesstepsmap' VALUES (567, 617, 1);
INSERT INTO 'dancesstepsmap' VALUES (568, 618, 1);
INSERT INTO 'dancesstepsmap' VALUES (569, 619, 1);
INSERT INTO 'dancesstepsmap' VALUES (570, 621, 1);
INSERT INTO 'dancesstepsmap' VALUES (571, 622, 1);
INSERT INTO 'dancesstepsmap' VALUES (572, 623, 1);
INSERT INTO 'dancesstepsmap' VALUES (10124, 9366, 1);
INSERT INTO 'dancesstepsmap' VALUES (10125, 9366, 2);
INSERT INTO 'dancesstepsmap' VALUES (10126, 9367, 1);
INSERT INTO 'dancesstepsmap' VALUES (10127, 9367, 2);
INSERT INTO 'dancesstepsmap' VALUES (10128, 9368, 1);
INSERT INTO 'dancesstepsmap' VALUES (10129, 9370, 1);
INSERT INTO 'dancesstepsmap' VALUES (10130, 9371, 1);
INSERT INTO 'dancesstepsmap' VALUES (10131, 9371, 2);
INSERT INTO 'dancesstepsmap' VALUES (10132, 9372, 4);
INSERT INTO 'dancesstepsmap' VALUES (10133, 9373, 4);
INSERT INTO 'dancesstepsmap' VALUES (10134, 9373, 5);
INSERT INTO 'dancesstepsmap' VALUES (10135, 9374, 1);
INSERT INTO 'dancesstepsmap' VALUES (10136, 9374, 2);
INSERT INTO 'dancesstepsmap' VALUES (10137, 9375, 1);
INSERT INTO 'dancesstepsmap' VALUES (10138, 9375, 2);
INSERT INTO 'dancesstepsmap' VALUES (10139, 9376, 1);
INSERT INTO 'dancesstepsmap' VALUES (10140, 9377, 4);
INSERT INTO 'dancesstepsmap' VALUES (10141, 9379, 4);
INSERT INTO 'dancesstepsmap' VALUES (10142, 9379, 5);
INSERT INTO 'dancesstepsmap' VALUES (10143, 9391, 2);
INSERT INTO 'dancesstepsmap' VALUES (10144, 9380, 1);
INSERT INTO 'dancesstepsmap' VALUES (10145, 9380, 3);
INSERT INTO 'dancesstepsmap' VALUES (10146, 9381, 4);
INSERT INTO 'dancesstepsmap' VALUES (10147, 9382, 1);
INSERT INTO 'dancesstepsmap' VALUES (10148, 5100, 1);
INSERT INTO 'dancesstepsmap' VALUES (10149, 9384, 1);
INSERT INTO 'dancesstepsmap' VALUES (10150, 9385, 4);
INSERT INTO 'dancesstepsmap' VALUES (10151, 9385, 5);
INSERT INTO 'dancesstepsmap' VALUES (10152, 9386, 1);
INSERT INTO 'dancesstepsmap' VALUES (10153, 9388, 1);
INSERT INTO 'dancesstepsmap' VALUES (10155, 9389, 4);
INSERT INTO 'dancesstepsmap' VALUES (10156, 9390, 1);
INSERT INTO 'dancesstepsmap' VALUES (16913, 265, 5);
INSERT INTO 'dancesstepsmap' VALUES (16914, 265, 4);
INSERT INTO 'dancesstepsmap' VALUES (16915, 265, 2);
INSERT INTO 'dancesstepsmap' VALUES (16934, 11287, 2);
INSERT INTO 'dancesstepsmap' VALUES (16935, 11287, 1);
INSERT INTO 'dancesstepsmap' VALUES (16937, 11291, 1);
INSERT INTO 'dancesstepsmap' VALUES (16939, 14419, 5);
INSERT INTO 'dancesstepsmap' VALUES (573, 624, 1);
INSERT INTO 'dancesstepsmap' VALUES (574, 625, 1);
INSERT INTO 'dancesstepsmap' VALUES (575, 627, 1);
INSERT INTO 'dancesstepsmap' VALUES (576, 628, 1);
INSERT INTO 'dancesstepsmap' VALUES (577, 629, 1);
INSERT INTO 'dancesstepsmap' VALUES (578, 630, 1);
INSERT INTO 'dancesstepsmap' VALUES (579, 631, 1);
INSERT INTO 'dancesstepsmap' VALUES (580, 632, 1);
INSERT INTO 'dancesstepsmap' VALUES (581, 633, 1);
INSERT INTO 'dancesstepsmap' VALUES (582, 634, 4);
INSERT INTO 'dancesstepsmap' VALUES (583, 635, 1);
INSERT INTO 'dancesstepsmap' VALUES (584, 636, 1);
INSERT INTO 'dancesstepsmap' VALUES (585, 638, 1);
INSERT INTO 'dancesstepsmap' VALUES (586, 639, 1);
INSERT INTO 'dancesstepsmap' VALUES (587, 640, 4);
INSERT INTO 'dancesstepsmap' VALUES (588, 641, 4);
INSERT INTO 'dancesstepsmap' VALUES (589, 643, 1);
INSERT INTO 'dancesstepsmap' VALUES (590, 644, 1);
INSERT INTO 'dancesstepsmap' VALUES (591, 645, 4);
INSERT INTO 'dancesstepsmap' VALUES (592, 646, 1);
INSERT INTO 'dancesstepsmap' VALUES (593, 647, 1);
INSERT INTO 'dancesstepsmap' VALUES (594, 648, 1);
INSERT INTO 'dancesstepsmap' VALUES (595, 649, 4);
INSERT INTO 'dancesstepsmap' VALUES (596, 650, 1);
INSERT INTO 'dancesstepsmap' VALUES (597, 652, 4);
INSERT INTO 'dancesstepsmap' VALUES (598, 653, 4);
INSERT INTO 'dancesstepsmap' VALUES (599, 654, 4);
INSERT INTO 'dancesstepsmap' VALUES (600, 655, 1);
INSERT INTO 'dancesstepsmap' VALUES (601, 656, 1);
INSERT INTO 'dancesstepsmap' VALUES (602, 657, 4);
INSERT INTO 'dancesstepsmap' VALUES (603, 658, 4);
INSERT INTO 'dancesstepsmap' VALUES (604, 659, 4);
INSERT INTO 'dancesstepsmap' VALUES (605, 660, 1);
INSERT INTO 'dancesstepsmap' VALUES (606, 661, 1);
INSERT INTO 'dancesstepsmap' VALUES (607, 662, 1);
INSERT INTO 'dancesstepsmap' VALUES (608, 663, 1);
INSERT INTO 'dancesstepsmap' VALUES (609, 664, 4);
INSERT INTO 'dancesstepsmap' VALUES (610, 665, 1);
INSERT INTO 'dancesstepsmap' VALUES (611, 666, 4);
INSERT INTO 'dancesstepsmap' VALUES (612, 667, 1);
INSERT INTO 'dancesstepsmap' VALUES (613, 668, 1);
INSERT INTO 'dancesstepsmap' VALUES (614, 669, 4);
INSERT INTO 'dancesstepsmap' VALUES (615, 671, 1);
INSERT INTO 'dancesstepsmap' VALUES (616, 672, 4);
INSERT INTO 'dancesstepsmap' VALUES (617, 673, 1);
INSERT INTO 'dancesstepsmap' VALUES (618, 674, 4);
INSERT INTO 'dancesstepsmap' VALUES (619, 675, 1);
INSERT INTO 'dancesstepsmap' VALUES (620, 676, 4);
INSERT INTO 'dancesstepsmap' VALUES (621, 677, 1);
INSERT INTO 'dancesstepsmap' VALUES (622, 678, 4);
INSERT INTO 'dancesstepsmap' VALUES (623, 679, 4);
INSERT INTO 'dancesstepsmap' VALUES (624, 680, 4);
INSERT INTO 'dancesstepsmap' VALUES (625, 681, 1);
INSERT INTO 'dancesstepsmap' VALUES (626, 682, 4);
INSERT INTO 'dancesstepsmap' VALUES (627, 683, 1);
INSERT INTO 'dancesstepsmap' VALUES (628, 685, 1);
INSERT INTO 'dancesstepsmap' VALUES (629, 686, 1);
INSERT INTO 'dancesstepsmap' VALUES (630, 687, 1);
INSERT INTO 'dancesstepsmap' VALUES (631, 688, 4);
INSERT INTO 'dancesstepsmap' VALUES (632, 689, 4);
INSERT INTO 'dancesstepsmap' VALUES (633, 690, 1);
INSERT INTO 'dancesstepsmap' VALUES (634, 691, 1);
INSERT INTO 'dancesstepsmap' VALUES (635, 692, 4);
INSERT INTO 'dancesstepsmap' VALUES (636, 694, 4);
INSERT INTO 'dancesstepsmap' VALUES (637, 696, 1);
INSERT INTO 'dancesstepsmap' VALUES (638, 697, 1);
INSERT INTO 'dancesstepsmap' VALUES (639, 698, 4);
INSERT INTO 'dancesstepsmap' VALUES (640, 699, 1);
INSERT INTO 'dancesstepsmap' VALUES (641, 700, 1);
INSERT INTO 'dancesstepsmap' VALUES (642, 702, 1);
INSERT INTO 'dancesstepsmap' VALUES (643, 703, 1);
INSERT INTO 'dancesstepsmap' VALUES (644, 705, 1);
INSERT INTO 'dancesstepsmap' VALUES (645, 706, 4);
INSERT INTO 'dancesstepsmap' VALUES (646, 707, 1);
INSERT INTO 'dancesstepsmap' VALUES (647, 709, 1);
INSERT INTO 'dancesstepsmap' VALUES (648, 710, 1);
INSERT INTO 'dancesstepsmap' VALUES (649, 711, 1);
INSERT INTO 'dancesstepsmap' VALUES (650, 712, 1);
INSERT INTO 'dancesstepsmap' VALUES (651, 713, 1);
INSERT INTO 'dancesstepsmap' VALUES (652, 714, 4);
INSERT INTO 'dancesstepsmap' VALUES (653, 715, 1);
INSERT INTO 'dancesstepsmap' VALUES (654, 717, 1);
INSERT INTO 'dancesstepsmap' VALUES (655, 718, 1);
INSERT INTO 'dancesstepsmap' VALUES (656, 719, 4);
INSERT INTO 'dancesstepsmap' VALUES (657, 720, 1);
INSERT INTO 'dancesstepsmap' VALUES (658, 721, 4);
INSERT INTO 'dancesstepsmap' VALUES (659, 722, 1);
INSERT INTO 'dancesstepsmap' VALUES (660, 723, 1);
INSERT INTO 'dancesstepsmap' VALUES (661, 724, 1);
INSERT INTO 'dancesstepsmap' VALUES (662, 726, 4);
INSERT INTO 'dancesstepsmap' VALUES (663, 727, 4);
INSERT INTO 'dancesstepsmap' VALUES (664, 728, 1);
INSERT INTO 'dancesstepsmap' VALUES (10157, 9408, 4);
INSERT INTO 'dancesstepsmap' VALUES (10158, 9408, 5);
INSERT INTO 'dancesstepsmap' VALUES (10159, 9409, 2);
INSERT INTO 'dancesstepsmap' VALUES (10160, 9409, 1);
INSERT INTO 'dancesstepsmap' VALUES (10161, 9410, 1);
INSERT INTO 'dancesstepsmap' VALUES (10162, 9411, 2);
INSERT INTO 'dancesstepsmap' VALUES (10163, 9411, 1);
INSERT INTO 'dancesstepsmap' VALUES (10164, 9412, 1);
INSERT INTO 'dancesstepsmap' VALUES (10165, 9413, 4);
INSERT INTO 'dancesstepsmap' VALUES (10166, 9413, 5);
INSERT INTO 'dancesstepsmap' VALUES (10167, 9414, 1);
INSERT INTO 'dancesstepsmap' VALUES (10168, 9414, 2);
INSERT INTO 'dancesstepsmap' VALUES (10169, 9415, 4);
INSERT INTO 'dancesstepsmap' VALUES (10170, 9416, 1);
INSERT INTO 'dancesstepsmap' VALUES (10171, 9331, 1);
INSERT INTO 'dancesstepsmap' VALUES (10172, 9331, 3);
INSERT INTO 'dancesstepsmap' VALUES (10173, 9383, 1);
INSERT INTO 'dancesstepsmap' VALUES (10174, 9417, 4);
INSERT INTO 'dancesstepsmap' VALUES (10175, 9418, 4);
INSERT INTO 'dancesstepsmap' VALUES (10176, 9419, 2);
INSERT INTO 'dancesstepsmap' VALUES (10177, 9419, 1);
INSERT INTO 'dancesstepsmap' VALUES (10178, 9421, 1);
INSERT INTO 'dancesstepsmap' VALUES (10179, 9421, 2);
INSERT INTO 'dancesstepsmap' VALUES (10180, 9422, 1);
INSERT INTO 'dancesstepsmap' VALUES (10181, 9422, 3);
INSERT INTO 'dancesstepsmap' VALUES (10182, 9424, 1);
INSERT INTO 'dancesstepsmap' VALUES (10183, 5588, 2);
INSERT INTO 'dancesstepsmap' VALUES (10184, 7265, 5);
INSERT INTO 'dancesstepsmap' VALUES (10185, 7019, 2);
INSERT INTO 'dancesstepsmap' VALUES (10186, 3738, 2);
INSERT INTO 'dancesstepsmap' VALUES (10187, 5573, 2);
INSERT INTO 'dancesstepsmap' VALUES (10188, 7721, 2);
INSERT INTO 'dancesstepsmap' VALUES (10189, 7752, 2);
INSERT INTO 'dancesstepsmap' VALUES (10190, 7740, 5);
INSERT INTO 'dancesstepsmap' VALUES (10191, 7159, 2);
INSERT INTO 'dancesstepsmap' VALUES (10192, 7159, 3);
INSERT INTO 'dancesstepsmap' VALUES (10193, 451, 3);
INSERT INTO 'dancesstepsmap' VALUES (10194, 1760, 2);
INSERT INTO 'dancesstepsmap' VALUES (10195, 1896, 2);
INSERT INTO 'dancesstepsmap' VALUES (10196, 1896, 3);
INSERT INTO 'dancesstepsmap' VALUES (10197, 5685, 5);
INSERT INTO 'dancesstepsmap' VALUES (10198, 4575, 5);
INSERT INTO 'dancesstepsmap' VALUES (16916, 265, 1);
INSERT INTO 'dancesstepsmap' VALUES (16945, 3231, 2);
INSERT INTO 'dancesstepsmap' VALUES (665, 729, 4);
INSERT INTO 'dancesstepsmap' VALUES (666, 730, 1);
INSERT INTO 'dancesstepsmap' VALUES (667, 731, 4);
INSERT INTO 'dancesstepsmap' VALUES (668, 733, 4);
INSERT INTO 'dancesstepsmap' VALUES (669, 734, 4);
INSERT INTO 'dancesstepsmap' VALUES (670, 735, 1);
INSERT INTO 'dancesstepsmap' VALUES (671, 736, 4);
INSERT INTO 'dancesstepsmap' VALUES (672, 737, 4);
INSERT INTO 'dancesstepsmap' VALUES (673, 738, 4);
INSERT INTO 'dancesstepsmap' VALUES (674, 739, 1);
INSERT INTO 'dancesstepsmap' VALUES (675, 740, 4);
INSERT INTO 'dancesstepsmap' VALUES (676, 741, 1);
INSERT INTO 'dancesstepsmap' VALUES (677, 742, 4);
INSERT INTO 'dancesstepsmap' VALUES (678, 743, 4);
INSERT INTO 'dancesstepsmap' VALUES (679, 744, 4);
INSERT INTO 'dancesstepsmap' VALUES (680, 745, 4);
INSERT INTO 'dancesstepsmap' VALUES (681, 746, 4);
INSERT INTO 'dancesstepsmap' VALUES (682, 747, 1);
INSERT INTO 'dancesstepsmap' VALUES (683, 748, 4);
INSERT INTO 'dancesstepsmap' VALUES (684, 749, 4);
INSERT INTO 'dancesstepsmap' VALUES (685, 750, 4);
INSERT INTO 'dancesstepsmap' VALUES (686, 752, 4);
INSERT INTO 'dancesstepsmap' VALUES (687, 753, 4);
INSERT INTO 'dancesstepsmap' VALUES (688, 754, 4);
INSERT INTO 'dancesstepsmap' VALUES (689, 755, 4);
INSERT INTO 'dancesstepsmap' VALUES (690, 756, 4);
INSERT INTO 'dancesstepsmap' VALUES (691, 757, 4);
INSERT INTO 'dancesstepsmap' VALUES (692, 758, 1);
INSERT INTO 'dancesstepsmap' VALUES (693, 759, 1);
INSERT INTO 'dancesstepsmap' VALUES (694, 760, 1);
INSERT INTO 'dancesstepsmap' VALUES (695, 761, 1);
INSERT INTO 'dancesstepsmap' VALUES (696, 762, 4);
INSERT INTO 'dancesstepsmap' VALUES (697, 763, 1);
INSERT INTO 'dancesstepsmap' VALUES (698, 764, 4);
INSERT INTO 'dancesstepsmap' VALUES (699, 765, 1);
INSERT INTO 'dancesstepsmap' VALUES (700, 766, 1);
INSERT INTO 'dancesstepsmap' VALUES (701, 767, 1);
INSERT INTO 'dancesstepsmap' VALUES (702, 768, 4);
INSERT INTO 'dancesstepsmap' VALUES (703, 769, 1);
INSERT INTO 'dancesstepsmap' VALUES (704, 770, 4);
INSERT INTO 'dancesstepsmap' VALUES (705, 772, 1);
INSERT INTO 'dancesstepsmap' VALUES (706, 773, 1);
INSERT INTO 'dancesstepsmap' VALUES (707, 774, 1);
INSERT INTO 'dancesstepsmap' VALUES (708, 775, 4);
INSERT INTO 'dancesstepsmap' VALUES (709, 776, 1);
INSERT INTO 'dancesstepsmap' VALUES (710, 777, 1);
INSERT INTO 'dancesstepsmap' VALUES (711, 778, 1);
INSERT INTO 'dancesstepsmap' VALUES (712, 779, 1);
INSERT INTO 'dancesstepsmap' VALUES (713, 780, 1);
INSERT INTO 'dancesstepsmap' VALUES (714, 781, 1);
INSERT INTO 'dancesstepsmap' VALUES (715, 782, 4);
INSERT INTO 'dancesstepsmap' VALUES (716, 783, 1);
INSERT INTO 'dancesstepsmap' VALUES (717, 784, 1);
INSERT INTO 'dancesstepsmap' VALUES (718, 785, 4);
INSERT INTO 'dancesstepsmap' VALUES (719, 786, 4);
INSERT INTO 'dancesstepsmap' VALUES (720, 787, 1);
INSERT INTO 'dancesstepsmap' VALUES (721, 788, 1);
INSERT INTO 'dancesstepsmap' VALUES (722, 789, 4);
INSERT INTO 'dancesstepsmap' VALUES (723, 790, 1);
INSERT INTO 'dancesstepsmap' VALUES (724, 792, 4);
INSERT INTO 'dancesstepsmap' VALUES (725, 793, 4);
INSERT INTO 'dancesstepsmap' VALUES (726, 794, 4);
INSERT INTO 'dancesstepsmap' VALUES (727, 795, 4);
INSERT INTO 'dancesstepsmap' VALUES (728, 796, 4);
INSERT INTO 'dancesstepsmap' VALUES (729, 797, 4);
INSERT INTO 'dancesstepsmap' VALUES (730, 798, 1);
INSERT INTO 'dancesstepsmap' VALUES (731, 800, 4);
INSERT INTO 'dancesstepsmap' VALUES (732, 801, 4);
INSERT INTO 'dancesstepsmap' VALUES (733, 803, 1);
INSERT INTO 'dancesstepsmap' VALUES (734, 804, 4);
INSERT INTO 'dancesstepsmap' VALUES (735, 805, 4);
INSERT INTO 'dancesstepsmap' VALUES (736, 806, 1);
INSERT INTO 'dancesstepsmap' VALUES (737, 807, 1);
INSERT INTO 'dancesstepsmap' VALUES (738, 808, 1);
INSERT INTO 'dancesstepsmap' VALUES (739, 809, 1);
INSERT INTO 'dancesstepsmap' VALUES (740, 810, 4);
INSERT INTO 'dancesstepsmap' VALUES (741, 811, 4);
INSERT INTO 'dancesstepsmap' VALUES (742, 813, 4);
INSERT INTO 'dancesstepsmap' VALUES (743, 814, 4);
INSERT INTO 'dancesstepsmap' VALUES (744, 815, 4);
INSERT INTO 'dancesstepsmap' VALUES (745, 816, 1);
INSERT INTO 'dancesstepsmap' VALUES (746, 817, 4);
INSERT INTO 'dancesstepsmap' VALUES (747, 818, 1);
INSERT INTO 'dancesstepsmap' VALUES (748, 819, 1);
INSERT INTO 'dancesstepsmap' VALUES (749, 820, 1);
INSERT INTO 'dancesstepsmap' VALUES (750, 821, 1);
INSERT INTO 'dancesstepsmap' VALUES (751, 822, 1);
INSERT INTO 'dancesstepsmap' VALUES (752, 824, 4);
INSERT INTO 'dancesstepsmap' VALUES (753, 825, 1);
INSERT INTO 'dancesstepsmap' VALUES (754, 827, 1);
INSERT INTO 'dancesstepsmap' VALUES (755, 828, 1);
INSERT INTO 'dancesstepsmap' VALUES (756, 829, 4);
INSERT INTO 'dancesstepsmap' VALUES (757, 830, 1);
INSERT INTO 'dancesstepsmap' VALUES (10199, 2563, 5);
INSERT INTO 'dancesstepsmap' VALUES (10200, 2124, 5);
INSERT INTO 'dancesstepsmap' VALUES (10201, 2433, 5);
INSERT INTO 'dancesstepsmap' VALUES (10202, 3538, 5);
INSERT INTO 'dancesstepsmap' VALUES (10203, 5593, 5);
INSERT INTO 'dancesstepsmap' VALUES (10204, 5719, 3);
INSERT INTO 'dancesstepsmap' VALUES (10205, 9427, 1);
INSERT INTO 'dancesstepsmap' VALUES (10206, 1421, 1);
INSERT INTO 'dancesstepsmap' VALUES (10207, 6672, 1);
INSERT INTO 'dancesstepsmap' VALUES (10208, 6672, 2);
INSERT INTO 'dancesstepsmap' VALUES (10209, 9428, 4);
INSERT INTO 'dancesstepsmap' VALUES (10210, 9428, 5);
INSERT INTO 'dancesstepsmap' VALUES (10211, 9429, 1);
INSERT INTO 'dancesstepsmap' VALUES (10212, 9431, 1);
INSERT INTO 'dancesstepsmap' VALUES (10213, 9432, 1);
INSERT INTO 'dancesstepsmap' VALUES (10214, 9433, 4);
INSERT INTO 'dancesstepsmap' VALUES (10215, 9433, 5);
INSERT INTO 'dancesstepsmap' VALUES (10216, 9434, 1);
INSERT INTO 'dancesstepsmap' VALUES (10217, 9435, 1);
INSERT INTO 'dancesstepsmap' VALUES (10218, 9430, 4);
INSERT INTO 'dancesstepsmap' VALUES (10219, 9430, 5);
INSERT INTO 'dancesstepsmap' VALUES (10220, 9436, 3);
INSERT INTO 'dancesstepsmap' VALUES (10221, 9438, 1);
INSERT INTO 'dancesstepsmap' VALUES (10222, 9441, 1);
INSERT INTO 'dancesstepsmap' VALUES (10223, 9443, 4);
INSERT INTO 'dancesstepsmap' VALUES (10224, 9446, 1);
INSERT INTO 'dancesstepsmap' VALUES (10225, 9447, 1);
INSERT INTO 'dancesstepsmap' VALUES (10226, 9447, 3);
INSERT INTO 'dancesstepsmap' VALUES (10227, 9449, 4);
INSERT INTO 'dancesstepsmap' VALUES (10228, 9452, 2);
INSERT INTO 'dancesstepsmap' VALUES (10229, 9452, 1);
INSERT INTO 'dancesstepsmap' VALUES (10230, 9482, 1);
INSERT INTO 'dancesstepsmap' VALUES (10231, 9485, 2);
INSERT INTO 'dancesstepsmap' VALUES (10232, 9485, 1);
INSERT INTO 'dancesstepsmap' VALUES (10233, 9486, 1);
INSERT INTO 'dancesstepsmap' VALUES (10234, 9486, 3);
INSERT INTO 'dancesstepsmap' VALUES (10235, 9487, 1);
INSERT INTO 'dancesstepsmap' VALUES (10236, 9488, 4);
INSERT INTO 'dancesstepsmap' VALUES (10237, 9489, 1);
INSERT INTO 'dancesstepsmap' VALUES (10238, 9489, 2);
INSERT INTO 'dancesstepsmap' VALUES (10239, 9491, 1);
INSERT INTO 'dancesstepsmap' VALUES (10240, 9495, 1);
INSERT INTO 'dancesstepsmap' VALUES (16946, 433, 2);
INSERT INTO 'dancesstepsmap' VALUES (16947, 604, 5);
INSERT INTO 'dancesstepsmap' VALUES (16948, 11813, 1);
INSERT INTO 'dancesstepsmap' VALUES (16949, 6133, 2);
INSERT INTO 'dancesstepsmap' VALUES (16950, 12334, 1);
INSERT INTO 'dancesstepsmap' VALUES (16951, 14420, 4);
INSERT INTO 'dancesstepsmap' VALUES (16952, 14420, 5);
INSERT INTO 'dancesstepsmap' VALUES (16953, 1907, 5);
INSERT INTO 'dancesstepsmap' VALUES (16954, 14421, 3);
INSERT INTO 'dancesstepsmap' VALUES (16955, 14421, 1);
INSERT INTO 'dancesstepsmap' VALUES (16956, 14421, 2);
INSERT INTO 'dancesstepsmap' VALUES (16957, 10354, 4);
INSERT INTO 'dancesstepsmap' VALUES (4449, 4810, 2);
INSERT INTO 'dancesstepsmap' VALUES (16967, 4810, 1);
INSERT INTO 'dancesstepsmap' VALUES (16968, 594, 5);
INSERT INTO 'dancesstepsmap' VALUES (16969, 1838, 5);
INSERT INTO 'dancesstepsmap' VALUES (16975, 14425, 2);
INSERT INTO 'dancesstepsmap' VALUES (16976, 14425, 1);
INSERT INTO 'dancesstepsmap' VALUES (16977, 14425, 3);
INSERT INTO 'dancesstepsmap' VALUES (16982, 14428, 1);
INSERT INTO 'dancesstepsmap' VALUES (16983, 14428, 2);
INSERT INTO 'dancesstepsmap' VALUES (16984, 8376, 2);
INSERT INTO 'dancesstepsmap' VALUES (758, 831, 1);
INSERT INTO 'dancesstepsmap' VALUES (759, 832, 1);
INSERT INTO 'dancesstepsmap' VALUES (760, 833, 4);
INSERT INTO 'dancesstepsmap' VALUES (761, 834, 1);
INSERT INTO 'dancesstepsmap' VALUES (762, 835, 4);
INSERT INTO 'dancesstepsmap' VALUES (763, 836, 1);
INSERT INTO 'dancesstepsmap' VALUES (764, 837, 4);
INSERT INTO 'dancesstepsmap' VALUES (765, 838, 4);
INSERT INTO 'dancesstepsmap' VALUES (766, 839, 1);
INSERT INTO 'dancesstepsmap' VALUES (767, 840, 4);
INSERT INTO 'dancesstepsmap' VALUES (768, 841, 1);
INSERT INTO 'dancesstepsmap' VALUES (769, 842, 4);
INSERT INTO 'dancesstepsmap' VALUES (770, 843, 4);
INSERT INTO 'dancesstepsmap' VALUES (771, 844, 1);
INSERT INTO 'dancesstepsmap' VALUES (772, 845, 1);
INSERT INTO 'dancesstepsmap' VALUES (773, 846, 4);
INSERT INTO 'dancesstepsmap' VALUES (774, 847, 4);
INSERT INTO 'dancesstepsmap' VALUES (775, 848, 1);
INSERT INTO 'dancesstepsmap' VALUES (776, 849, 1);
INSERT INTO 'dancesstepsmap' VALUES (777, 850, 4);
INSERT INTO 'dancesstepsmap' VALUES (778, 851, 1);
INSERT INTO 'dancesstepsmap' VALUES (779, 852, 1);
INSERT INTO 'dancesstepsmap' VALUES (780, 853, 1);
INSERT INTO 'dancesstepsmap' VALUES (781, 854, 1);
INSERT INTO 'dancesstepsmap' VALUES (782, 855, 1);
INSERT INTO 'dancesstepsmap' VALUES (783, 856, 1);
INSERT INTO 'dancesstepsmap' VALUES (784, 857, 4);
INSERT INTO 'dancesstepsmap' VALUES (785, 859, 1);
INSERT INTO 'dancesstepsmap' VALUES (786, 860, 1);
INSERT INTO 'dancesstepsmap' VALUES (787, 861, 1);
INSERT INTO 'dancesstepsmap' VALUES (788, 862, 1);
INSERT INTO 'dancesstepsmap' VALUES (789, 863, 1);
INSERT INTO 'dancesstepsmap' VALUES (790, 864, 1);
INSERT INTO 'dancesstepsmap' VALUES (791, 865, 1);
INSERT INTO 'dancesstepsmap' VALUES (792, 866, 4);
INSERT INTO 'dancesstepsmap' VALUES (793, 867, 4);
INSERT INTO 'dancesstepsmap' VALUES (794, 869, 1);
INSERT INTO 'dancesstepsmap' VALUES (795, 870, 4);
INSERT INTO 'dancesstepsmap' VALUES (796, 871, 1);
INSERT INTO 'dancesstepsmap' VALUES (797, 872, 1);
INSERT INTO 'dancesstepsmap' VALUES (798, 873, 1);
INSERT INTO 'dancesstepsmap' VALUES (799, 874, 4);
INSERT INTO 'dancesstepsmap' VALUES (800, 875, 1);
INSERT INTO 'dancesstepsmap' VALUES (801, 877, 1);
INSERT INTO 'dancesstepsmap' VALUES (802, 878, 4);
INSERT INTO 'dancesstepsmap' VALUES (803, 879, 4);
INSERT INTO 'dancesstepsmap' VALUES (804, 880, 1);
INSERT INTO 'dancesstepsmap' VALUES (805, 881, 1);
INSERT INTO 'dancesstepsmap' VALUES (806, 882, 1);
INSERT INTO 'dancesstepsmap' VALUES (807, 883, 4);
INSERT INTO 'dancesstepsmap' VALUES (808, 884, 4);
INSERT INTO 'dancesstepsmap' VALUES (809, 886, 1);
INSERT INTO 'dancesstepsmap' VALUES (810, 887, 4);
INSERT INTO 'dancesstepsmap' VALUES (811, 888, 1);
INSERT INTO 'dancesstepsmap' VALUES (812, 889, 4);
INSERT INTO 'dancesstepsmap' VALUES (813, 890, 4);
INSERT INTO 'dancesstepsmap' VALUES (814, 891, 1);
INSERT INTO 'dancesstepsmap' VALUES (815, 892, 4);
INSERT INTO 'dancesstepsmap' VALUES (816, 893, 4);
INSERT INTO 'dancesstepsmap' VALUES (817, 894, 4);
INSERT INTO 'dancesstepsmap' VALUES (818, 895, 1);
INSERT INTO 'dancesstepsmap' VALUES (819, 896, 1);
INSERT INTO 'dancesstepsmap' VALUES (820, 897, 1);
INSERT INTO 'dancesstepsmap' VALUES (821, 898, 4);
INSERT INTO 'dancesstepsmap' VALUES (822, 899, 4);
INSERT INTO 'dancesstepsmap' VALUES (823, 900, 1);
INSERT INTO 'dancesstepsmap' VALUES (824, 901, 1);
INSERT INTO 'dancesstepsmap' VALUES (825, 902, 1);
INSERT INTO 'dancesstepsmap' VALUES (826, 903, 1);
INSERT INTO 'dancesstepsmap' VALUES (827, 904, 4);
INSERT INTO 'dancesstepsmap' VALUES (828, 905, 1);
INSERT INTO 'dancesstepsmap' VALUES (829, 906, 1);
INSERT INTO 'dancesstepsmap' VALUES (830, 907, 4);
INSERT INTO 'dancesstepsmap' VALUES (831, 908, 1);
INSERT INTO 'dancesstepsmap' VALUES (832, 909, 1);
INSERT INTO 'dancesstepsmap' VALUES (833, 910, 1);
INSERT INTO 'dancesstepsmap' VALUES (834, 911, 1);
INSERT INTO 'dancesstepsmap' VALUES (835, 912, 4);
INSERT INTO 'dancesstepsmap' VALUES (836, 913, 4);
INSERT INTO 'dancesstepsmap' VALUES (837, 914, 1);
INSERT INTO 'dancesstepsmap' VALUES (838, 915, 1);
INSERT INTO 'dancesstepsmap' VALUES (839, 916, 1);
INSERT INTO 'dancesstepsmap' VALUES (840, 917, 4);
INSERT INTO 'dancesstepsmap' VALUES (841, 918, 4);
INSERT INTO 'dancesstepsmap' VALUES (842, 919, 4);
INSERT INTO 'dancesstepsmap' VALUES (843, 920, 1);
INSERT INTO 'dancesstepsmap' VALUES (844, 921, 1);
INSERT INTO 'dancesstepsmap' VALUES (845, 922, 4);
INSERT INTO 'dancesstepsmap' VALUES (846, 923, 1);
INSERT INTO 'dancesstepsmap' VALUES (847, 924, 4);
INSERT INTO 'dancesstepsmap' VALUES (848, 925, 1);
INSERT INTO 'dancesstepsmap' VALUES (849, 926, 1);
INSERT INTO 'dancesstepsmap' VALUES (10241, 7243, 1);
INSERT INTO 'dancesstepsmap' VALUES (10242, 8832, 4);
INSERT INTO 'dancesstepsmap' VALUES (10243, 8833, 4);
INSERT INTO 'dancesstepsmap' VALUES (10244, 8834, 4);
INSERT INTO 'dancesstepsmap' VALUES (10245, 8835, 1);
INSERT INTO 'dancesstepsmap' VALUES (10246, 8835, 2);
INSERT INTO 'dancesstepsmap' VALUES (10247, 8836, 1);
INSERT INTO 'dancesstepsmap' VALUES (10248, 8837, 1);
INSERT INTO 'dancesstepsmap' VALUES (10249, 8838, 3);
INSERT INTO 'dancesstepsmap' VALUES (10250, 8839, 3);
INSERT INTO 'dancesstepsmap' VALUES (10251, 8839, 1);
INSERT INTO 'dancesstepsmap' VALUES (10252, 9497, 1);
INSERT INTO 'dancesstepsmap' VALUES (10253, 9497, 3);
INSERT INTO 'dancesstepsmap' VALUES (10254, 9498, 5);
INSERT INTO 'dancesstepsmap' VALUES (10255, 9498, 4);
INSERT INTO 'dancesstepsmap' VALUES (10256, 8831, 1);
INSERT INTO 'dancesstepsmap' VALUES (10257, 8831, 2);
INSERT INTO 'dancesstepsmap' VALUES (10258, 9499, 1);
INSERT INTO 'dancesstepsmap' VALUES (10259, 9500, 4);
INSERT INTO 'dancesstepsmap' VALUES (10260, 9501, 1);
INSERT INTO 'dancesstepsmap' VALUES (10261, 9502, 3);
INSERT INTO 'dancesstepsmap' VALUES (10262, 9503, 2);
INSERT INTO 'dancesstepsmap' VALUES (10263, 9503, 1);
INSERT INTO 'dancesstepsmap' VALUES (10264, 9503, 3);
INSERT INTO 'dancesstepsmap' VALUES (10265, 9505, 1);
INSERT INTO 'dancesstepsmap' VALUES (10266, 9505, 2);
INSERT INTO 'dancesstepsmap' VALUES (10267, 894, 5);
INSERT INTO 'dancesstepsmap' VALUES (10268, 3672, 2);
INSERT INTO 'dancesstepsmap' VALUES (10269, 8365, 2);
INSERT INTO 'dancesstepsmap' VALUES (10270, 8365, 3);
INSERT INTO 'dancesstepsmap' VALUES (10271, 9513, 1);
INSERT INTO 'dancesstepsmap' VALUES (10272, 9513, 2);
INSERT INTO 'dancesstepsmap' VALUES (10273, 9516, 1);
INSERT INTO 'dancesstepsmap' VALUES (10274, 9518, 4);
INSERT INTO 'dancesstepsmap' VALUES (10275, 9518, 5);
INSERT INTO 'dancesstepsmap' VALUES (10276, 9519, 1);
INSERT INTO 'dancesstepsmap' VALUES (10277, 9521, 4);
INSERT INTO 'dancesstepsmap' VALUES (10278, 9522, 1);
INSERT INTO 'dancesstepsmap' VALUES (10279, 9523, 1);
INSERT INTO 'dancesstepsmap' VALUES (10280, 9524, 4);
INSERT INTO 'dancesstepsmap' VALUES (10281, 9524, 5);
INSERT INTO 'dancesstepsmap' VALUES (10282, 9526, 1);
INSERT INTO 'dancesstepsmap' VALUES (10283, 9527, 1);
INSERT INTO 'dancesstepsmap' VALUES (16958, 4146, 5);
INSERT INTO 'dancesstepsmap' VALUES (16970, 5412, 1);
INSERT INTO 'dancesstepsmap' VALUES (16971, 5412, 3);
INSERT INTO 'dancesstepsmap' VALUES (16972, 5412, 2);
INSERT INTO 'dancesstepsmap' VALUES (16973, 5412, 4);
INSERT INTO 'dancesstepsmap' VALUES (16978, 14426, 5);
INSERT INTO 'dancesstepsmap' VALUES (16979, 14426, 4);
INSERT INTO 'dancesstepsmap' VALUES (16985, 8377, 3);
INSERT INTO 'dancesstepsmap' VALUES (850, 927, 1);
INSERT INTO 'dancesstepsmap' VALUES (851, 928, 1);
INSERT INTO 'dancesstepsmap' VALUES (852, 929, 1);
INSERT INTO 'dancesstepsmap' VALUES (853, 930, 1);
INSERT INTO 'dancesstepsmap' VALUES (854, 931, 1);
INSERT INTO 'dancesstepsmap' VALUES (855, 932, 1);
INSERT INTO 'dancesstepsmap' VALUES (856, 933, 1);
INSERT INTO 'dancesstepsmap' VALUES (857, 934, 4);
INSERT INTO 'dancesstepsmap' VALUES (858, 935, 1);
INSERT INTO 'dancesstepsmap' VALUES (859, 936, 4);
INSERT INTO 'dancesstepsmap' VALUES (23131, 18245, 1);
INSERT INTO 'dancesstepsmap' VALUES (861, 939, 4);
INSERT INTO 'dancesstepsmap' VALUES (862, 940, 1);
INSERT INTO 'dancesstepsmap' VALUES (863, 941, 1);
INSERT INTO 'dancesstepsmap' VALUES (864, 942, 1);
INSERT INTO 'dancesstepsmap' VALUES (865, 943, 1);
INSERT INTO 'dancesstepsmap' VALUES (866, 944, 4);
INSERT INTO 'dancesstepsmap' VALUES (867, 945, 1);
INSERT INTO 'dancesstepsmap' VALUES (868, 946, 4);
INSERT INTO 'dancesstepsmap' VALUES (869, 947, 1);
INSERT INTO 'dancesstepsmap' VALUES (870, 948, 4);
INSERT INTO 'dancesstepsmap' VALUES (871, 949, 1);
INSERT INTO 'dancesstepsmap' VALUES (872, 950, 1);
INSERT INTO 'dancesstepsmap' VALUES (873, 951, 1);
INSERT INTO 'dancesstepsmap' VALUES (874, 952, 1);
INSERT INTO 'dancesstepsmap' VALUES (875, 954, 1);
INSERT INTO 'dancesstepsmap' VALUES (876, 955, 1);
INSERT INTO 'dancesstepsmap' VALUES (877, 957, 1);
INSERT INTO 'dancesstepsmap' VALUES (878, 958, 1);
INSERT INTO 'dancesstepsmap' VALUES (879, 959, 1);
INSERT INTO 'dancesstepsmap' VALUES (880, 960, 1);
INSERT INTO 'dancesstepsmap' VALUES (881, 961, 1);
INSERT INTO 'dancesstepsmap' VALUES (882, 962, 4);
INSERT INTO 'dancesstepsmap' VALUES (883, 963, 1);
INSERT INTO 'dancesstepsmap' VALUES (884, 964, 4);
INSERT INTO 'dancesstepsmap' VALUES (885, 965, 1);
INSERT INTO 'dancesstepsmap' VALUES (886, 966, 1);
INSERT INTO 'dancesstepsmap' VALUES (887, 968, 4);
INSERT INTO 'dancesstepsmap' VALUES (888, 969, 1);
INSERT INTO 'dancesstepsmap' VALUES (889, 970, 1);
INSERT INTO 'dancesstepsmap' VALUES (890, 971, 1);
INSERT INTO 'dancesstepsmap' VALUES (891, 972, 4);
INSERT INTO 'dancesstepsmap' VALUES (892, 973, 4);
INSERT INTO 'dancesstepsmap' VALUES (893, 974, 4);
INSERT INTO 'dancesstepsmap' VALUES (894, 975, 1);
INSERT INTO 'dancesstepsmap' VALUES (895, 977, 1);
INSERT INTO 'dancesstepsmap' VALUES (896, 978, 1);
INSERT INTO 'dancesstepsmap' VALUES (897, 979, 1);
INSERT INTO 'dancesstepsmap' VALUES (898, 980, 1);
INSERT INTO 'dancesstepsmap' VALUES (899, 981, 1);
INSERT INTO 'dancesstepsmap' VALUES (900, 982, 4);
INSERT INTO 'dancesstepsmap' VALUES (901, 983, 4);
INSERT INTO 'dancesstepsmap' VALUES (902, 984, 1);
INSERT INTO 'dancesstepsmap' VALUES (903, 985, 1);
INSERT INTO 'dancesstepsmap' VALUES (904, 986, 4);
INSERT INTO 'dancesstepsmap' VALUES (905, 987, 1);
INSERT INTO 'dancesstepsmap' VALUES (906, 988, 1);
INSERT INTO 'dancesstepsmap' VALUES (908, 990, 4);
INSERT INTO 'dancesstepsmap' VALUES (909, 991, 4);
INSERT INTO 'dancesstepsmap' VALUES (910, 992, 4);
INSERT INTO 'dancesstepsmap' VALUES (911, 993, 1);
INSERT INTO 'dancesstepsmap' VALUES (912, 995, 1);
INSERT INTO 'dancesstepsmap' VALUES (913, 996, 1);
INSERT INTO 'dancesstepsmap' VALUES (914, 997, 1);
INSERT INTO 'dancesstepsmap' VALUES (915, 998, 1);
INSERT INTO 'dancesstepsmap' VALUES (916, 999, 1);
INSERT INTO 'dancesstepsmap' VALUES (917, 1001, 1);
INSERT INTO 'dancesstepsmap' VALUES (918, 1002, 4);
INSERT INTO 'dancesstepsmap' VALUES (919, 1003, 1);
INSERT INTO 'dancesstepsmap' VALUES (920, 1004, 1);
INSERT INTO 'dancesstepsmap' VALUES (921, 1005, 1);
INSERT INTO 'dancesstepsmap' VALUES (922, 1006, 4);
INSERT INTO 'dancesstepsmap' VALUES (923, 1007, 1);
INSERT INTO 'dancesstepsmap' VALUES (924, 1008, 1);
INSERT INTO 'dancesstepsmap' VALUES (925, 1010, 4);
INSERT INTO 'dancesstepsmap' VALUES (926, 1011, 1);
INSERT INTO 'dancesstepsmap' VALUES (927, 1012, 1);
INSERT INTO 'dancesstepsmap' VALUES (928, 1013, 1);
INSERT INTO 'dancesstepsmap' VALUES (929, 1014, 4);
INSERT INTO 'dancesstepsmap' VALUES (930, 1015, 1);
INSERT INTO 'dancesstepsmap' VALUES (931, 1016, 1);
INSERT INTO 'dancesstepsmap' VALUES (932, 1017, 1);
INSERT INTO 'dancesstepsmap' VALUES (933, 1018, 1);
INSERT INTO 'dancesstepsmap' VALUES (934, 1019, 1);
INSERT INTO 'dancesstepsmap' VALUES (935, 1020, 1);
INSERT INTO 'dancesstepsmap' VALUES (936, 1021, 4);
INSERT INTO 'dancesstepsmap' VALUES (937, 1022, 1);
INSERT INTO 'dancesstepsmap' VALUES (938, 1023, 1);
INSERT INTO 'dancesstepsmap' VALUES (939, 1024, 1);
INSERT INTO 'dancesstepsmap' VALUES (940, 1025, 1);
INSERT INTO 'dancesstepsmap' VALUES (941, 1027, 1);
INSERT INTO 'dancesstepsmap' VALUES (942, 1028, 1);
INSERT INTO 'dancesstepsmap' VALUES (943, 1029, 1);
INSERT INTO 'dancesstepsmap' VALUES (10284, 9528, 1);
INSERT INTO 'dancesstepsmap' VALUES (10285, 9529, 4);
INSERT INTO 'dancesstepsmap' VALUES (10286, 9530, 4);
INSERT INTO 'dancesstepsmap' VALUES (10288, 9532, 4);
INSERT INTO 'dancesstepsmap' VALUES (10289, 9533, 4);
INSERT INTO 'dancesstepsmap' VALUES (10290, 9534, 1);
INSERT INTO 'dancesstepsmap' VALUES (10291, 9534, 3);
INSERT INTO 'dancesstepsmap' VALUES (10292, 9536, 3);
INSERT INTO 'dancesstepsmap' VALUES (10293, 9354, 1);
INSERT INTO 'dancesstepsmap' VALUES (10294, 9354, 3);
INSERT INTO 'dancesstepsmap' VALUES (10295, 9537, 1);
INSERT INTO 'dancesstepsmap' VALUES (10296, 9538, 1);
INSERT INTO 'dancesstepsmap' VALUES (10297, 9544, 10);
INSERT INTO 'dancesstepsmap' VALUES (10298, 9544, 1);
INSERT INTO 'dancesstepsmap' VALUES (10299, 9544, 2);
INSERT INTO 'dancesstepsmap' VALUES (10300, 7227, 3);
INSERT INTO 'dancesstepsmap' VALUES (10302, 6707, 2);
INSERT INTO 'dancesstepsmap' VALUES (10303, 9545, 2);
INSERT INTO 'dancesstepsmap' VALUES (10304, 9545, 1);
INSERT INTO 'dancesstepsmap' VALUES (10305, 9546, 2);
INSERT INTO 'dancesstepsmap' VALUES (10306, 9546, 1);
INSERT INTO 'dancesstepsmap' VALUES (10307, 9548, 2);
INSERT INTO 'dancesstepsmap' VALUES (10308, 9548, 3);
INSERT INTO 'dancesstepsmap' VALUES (10309, 9549, 2);
INSERT INTO 'dancesstepsmap' VALUES (10310, 9549, 1);
INSERT INTO 'dancesstepsmap' VALUES (10311, 9550, 1);
INSERT INTO 'dancesstepsmap' VALUES (10312, 9550, 2);
INSERT INTO 'dancesstepsmap' VALUES (10313, 9551, 5);
INSERT INTO 'dancesstepsmap' VALUES (10314, 9551, 4);
INSERT INTO 'dancesstepsmap' VALUES (10315, 9552, 5);
INSERT INTO 'dancesstepsmap' VALUES (10316, 9552, 4);
INSERT INTO 'dancesstepsmap' VALUES (10317, 9553, 1);
INSERT INTO 'dancesstepsmap' VALUES (10318, 9554, 1);
INSERT INTO 'dancesstepsmap' VALUES (10319, 9554, 3);
INSERT INTO 'dancesstepsmap' VALUES (10320, 9555, 2);
INSERT INTO 'dancesstepsmap' VALUES (10321, 9555, 1);
INSERT INTO 'dancesstepsmap' VALUES (10322, 9556, 1);
INSERT INTO 'dancesstepsmap' VALUES (10323, 9556, 3);
INSERT INTO 'dancesstepsmap' VALUES (10324, 9557, 1);
INSERT INTO 'dancesstepsmap' VALUES (10325, 2372, 1);
INSERT INTO 'dancesstepsmap' VALUES (16959, 4361, 2);
INSERT INTO 'dancesstepsmap' VALUES (16960, 4361, 3);
INSERT INTO 'dancesstepsmap' VALUES (16974, 5412, 5);
INSERT INTO 'dancesstepsmap' VALUES (16980, 14427, 1);
INSERT INTO 'dancesstepsmap' VALUES (16981, 14427, 2);
INSERT INTO 'dancesstepsmap' VALUES (16986, 7744, 2);
INSERT INTO 'dancesstepsmap' VALUES (944, 1030, 1);
INSERT INTO 'dancesstepsmap' VALUES (945, 1031, 4);
INSERT INTO 'dancesstepsmap' VALUES (946, 1032, 1);
INSERT INTO 'dancesstepsmap' VALUES (947, 1033, 4);
INSERT INTO 'dancesstepsmap' VALUES (948, 1034, 1);
INSERT INTO 'dancesstepsmap' VALUES (949, 1036, 1);
INSERT INTO 'dancesstepsmap' VALUES (950, 1037, 4);
INSERT INTO 'dancesstepsmap' VALUES (951, 1038, 1);
INSERT INTO 'dancesstepsmap' VALUES (952, 1039, 4);
INSERT INTO 'dancesstepsmap' VALUES (953, 1040, 4);
INSERT INTO 'dancesstepsmap' VALUES (954, 1041, 1);
INSERT INTO 'dancesstepsmap' VALUES (955, 1042, 1);
INSERT INTO 'dancesstepsmap' VALUES (956, 1043, 1);
INSERT INTO 'dancesstepsmap' VALUES (957, 1044, 1);
INSERT INTO 'dancesstepsmap' VALUES (958, 1045, 1);
INSERT INTO 'dancesstepsmap' VALUES (959, 1046, 1);
INSERT INTO 'dancesstepsmap' VALUES (960, 1047, 4);
INSERT INTO 'dancesstepsmap' VALUES (961, 1049, 4);
INSERT INTO 'dancesstepsmap' VALUES (962, 1050, 1);
INSERT INTO 'dancesstepsmap' VALUES (963, 1051, 1);
INSERT INTO 'dancesstepsmap' VALUES (964, 1052, 1);
INSERT INTO 'dancesstepsmap' VALUES (965, 1053, 4);
INSERT INTO 'dancesstepsmap' VALUES (966, 1054, 4);
INSERT INTO 'dancesstepsmap' VALUES (967, 1055, 4);
INSERT INTO 'dancesstepsmap' VALUES (968, 1056, 1);
INSERT INTO 'dancesstepsmap' VALUES (969, 1057, 1);
INSERT INTO 'dancesstepsmap' VALUES (970, 1058, 1);
INSERT INTO 'dancesstepsmap' VALUES (971, 1059, 1);
INSERT INTO 'dancesstepsmap' VALUES (972, 1060, 4);
INSERT INTO 'dancesstepsmap' VALUES (973, 1062, 1);
INSERT INTO 'dancesstepsmap' VALUES (974, 1063, 1);
INSERT INTO 'dancesstepsmap' VALUES (975, 1064, 4);
INSERT INTO 'dancesstepsmap' VALUES (976, 1065, 4);
INSERT INTO 'dancesstepsmap' VALUES (977, 1066, 4);
INSERT INTO 'dancesstepsmap' VALUES (978, 1067, 4);
INSERT INTO 'dancesstepsmap' VALUES (979, 1068, 4);
INSERT INTO 'dancesstepsmap' VALUES (980, 1069, 4);
INSERT INTO 'dancesstepsmap' VALUES (981, 1070, 4);
INSERT INTO 'dancesstepsmap' VALUES (982, 1071, 1);
INSERT INTO 'dancesstepsmap' VALUES (983, 1072, 1);
INSERT INTO 'dancesstepsmap' VALUES (984, 1073, 4);
INSERT INTO 'dancesstepsmap' VALUES (985, 1074, 1);
INSERT INTO 'dancesstepsmap' VALUES (986, 1075, 4);
INSERT INTO 'dancesstepsmap' VALUES (987, 1076, 1);
INSERT INTO 'dancesstepsmap' VALUES (988, 1077, 4);
INSERT INTO 'dancesstepsmap' VALUES (989, 1078, 4);
INSERT INTO 'dancesstepsmap' VALUES (990, 1079, 4);
INSERT INTO 'dancesstepsmap' VALUES (991, 1080, 1);
INSERT INTO 'dancesstepsmap' VALUES (992, 1082, 1);
INSERT INTO 'dancesstepsmap' VALUES (993, 1083, 4);
INSERT INTO 'dancesstepsmap' VALUES (994, 1084, 4);
INSERT INTO 'dancesstepsmap' VALUES (995, 1085, 1);
INSERT INTO 'dancesstepsmap' VALUES (996, 1086, 1);
INSERT INTO 'dancesstepsmap' VALUES (997, 1087, 1);
INSERT INTO 'dancesstepsmap' VALUES (998, 1089, 4);
INSERT INTO 'dancesstepsmap' VALUES (999, 1090, 1);
INSERT INTO 'dancesstepsmap' VALUES (1000, 1091, 1);
INSERT INTO 'dancesstepsmap' VALUES (1001, 1092, 1);
INSERT INTO 'dancesstepsmap' VALUES (1002, 1093, 1);
INSERT INTO 'dancesstepsmap' VALUES (1003, 1094, 1);
INSERT INTO 'dancesstepsmap' VALUES (1004, 1095, 4);
INSERT INTO 'dancesstepsmap' VALUES (1005, 1096, 1);
INSERT INTO 'dancesstepsmap' VALUES (1006, 1097, 4);
INSERT INTO 'dancesstepsmap' VALUES (1007, 1098, 1);
INSERT INTO 'dancesstepsmap' VALUES (1008, 1099, 1);
INSERT INTO 'dancesstepsmap' VALUES (1009, 1101, 1);
INSERT INTO 'dancesstepsmap' VALUES (1010, 1102, 1);
INSERT INTO 'dancesstepsmap' VALUES (1011, 1103, 1);
INSERT INTO 'dancesstepsmap' VALUES (1012, 1104, 1);
INSERT INTO 'dancesstepsmap' VALUES (1013, 1105, 4);
INSERT INTO 'dancesstepsmap' VALUES (1014, 1106, 4);
INSERT INTO 'dancesstepsmap' VALUES (1015, 1107, 1);
INSERT INTO 'dancesstepsmap' VALUES (1016, 1108, 1);
INSERT INTO 'dancesstepsmap' VALUES (1017, 1109, 1);
INSERT INTO 'dancesstepsmap' VALUES (1018, 1110, 4);
INSERT INTO 'dancesstepsmap' VALUES (1019, 1111, 1);
INSERT INTO 'dancesstepsmap' VALUES (1020, 1112, 1);
INSERT INTO 'dancesstepsmap' VALUES (1021, 1113, 1);
INSERT INTO 'dancesstepsmap' VALUES (1022, 1114, 1);
INSERT INTO 'dancesstepsmap' VALUES (1023, 1115, 1);
INSERT INTO 'dancesstepsmap' VALUES (1024, 1116, 1);
INSERT INTO 'dancesstepsmap' VALUES (1025, 1117, 1);
INSERT INTO 'dancesstepsmap' VALUES (1026, 1118, 1);
INSERT INTO 'dancesstepsmap' VALUES (1027, 1119, 1);
INSERT INTO 'dancesstepsmap' VALUES (1028, 1120, 4);
INSERT INTO 'dancesstepsmap' VALUES (1029, 1121, 1);
INSERT INTO 'dancesstepsmap' VALUES (1030, 1124, 1);
INSERT INTO 'dancesstepsmap' VALUES (1031, 1125, 1);
INSERT INTO 'dancesstepsmap' VALUES (1032, 1127, 4);
INSERT INTO 'dancesstepsmap' VALUES (1033, 1128, 1);
INSERT INTO 'dancesstepsmap' VALUES (1034, 1130, 1);
INSERT INTO 'dancesstepsmap' VALUES (1035, 1131, 1);
INSERT INTO 'dancesstepsmap' VALUES (1036, 1132, 1);
INSERT INTO 'dancesstepsmap' VALUES (1037, 1133, 1);
INSERT INTO 'dancesstepsmap' VALUES (1038, 1134, 1);
INSERT INTO 'dancesstepsmap' VALUES (1039, 1135, 1);
INSERT INTO 'dancesstepsmap' VALUES (1040, 1136, 4);
INSERT INTO 'dancesstepsmap' VALUES (1041, 1137, 4);
INSERT INTO 'dancesstepsmap' VALUES (1042, 1138, 1);
INSERT INTO 'dancesstepsmap' VALUES (1043, 1139, 1);
INSERT INTO 'dancesstepsmap' VALUES (1044, 1140, 4);
INSERT INTO 'dancesstepsmap' VALUES (1045, 1141, 1);
INSERT INTO 'dancesstepsmap' VALUES (1046, 1142, 4);
INSERT INTO 'dancesstepsmap' VALUES (1047, 1143, 1);
INSERT INTO 'dancesstepsmap' VALUES (1048, 1144, 4);
INSERT INTO 'dancesstepsmap' VALUES (1049, 1145, 1);
INSERT INTO 'dancesstepsmap' VALUES (1050, 1146, 1);
INSERT INTO 'dancesstepsmap' VALUES (1051, 1147, 4);
INSERT INTO 'dancesstepsmap' VALUES (1052, 1148, 1);
INSERT INTO 'dancesstepsmap' VALUES (1053, 1149, 1);
INSERT INTO 'dancesstepsmap' VALUES (1054, 1150, 1);
INSERT INTO 'dancesstepsmap' VALUES (1055, 1151, 1);
INSERT INTO 'dancesstepsmap' VALUES (1056, 1152, 4);
INSERT INTO 'dancesstepsmap' VALUES (1057, 1153, 1);
INSERT INTO 'dancesstepsmap' VALUES (1058, 1154, 1);
INSERT INTO 'dancesstepsmap' VALUES (1059, 1155, 1);
INSERT INTO 'dancesstepsmap' VALUES (1060, 1156, 4);
INSERT INTO 'dancesstepsmap' VALUES (1061, 1157, 4);
INSERT INTO 'dancesstepsmap' VALUES (1062, 1158, 4);
INSERT INTO 'dancesstepsmap' VALUES (10326, 6131, 5);
INSERT INTO 'dancesstepsmap' VALUES (10327, 6131, 4);
INSERT INTO 'dancesstepsmap' VALUES (10328, 9559, 1);
INSERT INTO 'dancesstepsmap' VALUES (10329, 9559, 2);
INSERT INTO 'dancesstepsmap' VALUES (10330, 7654, 2);
INSERT INTO 'dancesstepsmap' VALUES (10331, 9560, 1);
INSERT INTO 'dancesstepsmap' VALUES (10332, 9560, 2);
INSERT INTO 'dancesstepsmap' VALUES (10333, 9561, 4);
INSERT INTO 'dancesstepsmap' VALUES (10334, 9562, 1);
INSERT INTO 'dancesstepsmap' VALUES (10335, 9563, 1);
INSERT INTO 'dancesstepsmap' VALUES (10336, 9564, 1);
INSERT INTO 'dancesstepsmap' VALUES (10337, 9565, 4);
INSERT INTO 'dancesstepsmap' VALUES (10338, 5295, 3);
INSERT INTO 'dancesstepsmap' VALUES (10341, 9566, 4);
INSERT INTO 'dancesstepsmap' VALUES (10342, 9567, 1);
INSERT INTO 'dancesstepsmap' VALUES (10343, 9568, 1);
INSERT INTO 'dancesstepsmap' VALUES (10344, 9569, 1);
INSERT INTO 'dancesstepsmap' VALUES (10345, 9569, 2);
INSERT INTO 'dancesstepsmap' VALUES (10346, 9571, 1);
INSERT INTO 'dancesstepsmap' VALUES (10347, 9572, 1);
INSERT INTO 'dancesstepsmap' VALUES (10348, 9573, 4);
INSERT INTO 'dancesstepsmap' VALUES (10349, 9573, 5);
INSERT INTO 'dancesstepsmap' VALUES (10350, 9574, 1);
INSERT INTO 'dancesstepsmap' VALUES (10351, 9575, 1);
INSERT INTO 'dancesstepsmap' VALUES (16961, 2984, 3);
INSERT INTO 'dancesstepsmap' VALUES (1063, 1159, 1);
INSERT INTO 'dancesstepsmap' VALUES (1064, 1160, 4);
INSERT INTO 'dancesstepsmap' VALUES (1065, 1161, 4);
INSERT INTO 'dancesstepsmap' VALUES (1066, 1162, 1);
INSERT INTO 'dancesstepsmap' VALUES (1067, 1163, 1);
INSERT INTO 'dancesstepsmap' VALUES (1068, 1164, 1);
INSERT INTO 'dancesstepsmap' VALUES (1069, 1165, 1);
INSERT INTO 'dancesstepsmap' VALUES (1070, 1166, 4);
INSERT INTO 'dancesstepsmap' VALUES (1071, 1167, 1);
INSERT INTO 'dancesstepsmap' VALUES (1072, 1168, 1);
INSERT INTO 'dancesstepsmap' VALUES (1073, 1169, 1);
INSERT INTO 'dancesstepsmap' VALUES (1074, 1170, 1);
INSERT INTO 'dancesstepsmap' VALUES (1075, 1171, 4);
INSERT INTO 'dancesstepsmap' VALUES (1076, 1172, 1);
INSERT INTO 'dancesstepsmap' VALUES (1077, 1173, 4);
INSERT INTO 'dancesstepsmap' VALUES (1078, 1174, 4);
INSERT INTO 'dancesstepsmap' VALUES (1079, 1175, 1);
INSERT INTO 'dancesstepsmap' VALUES (1080, 1176, 4);
INSERT INTO 'dancesstepsmap' VALUES (1081, 1177, 4);
INSERT INTO 'dancesstepsmap' VALUES (1082, 1178, 1);
INSERT INTO 'dancesstepsmap' VALUES (1083, 1179, 4);
INSERT INTO 'dancesstepsmap' VALUES (1084, 1180, 4);
INSERT INTO 'dancesstepsmap' VALUES (1085, 1181, 4);
INSERT INTO 'dancesstepsmap' VALUES (1086, 1182, 1);
INSERT INTO 'dancesstepsmap' VALUES (1087, 1183, 1);
INSERT INTO 'dancesstepsmap' VALUES (1088, 1184, 1);
INSERT INTO 'dancesstepsmap' VALUES (1089, 1185, 1);
INSERT INTO 'dancesstepsmap' VALUES (1090, 1186, 1);
INSERT INTO 'dancesstepsmap' VALUES (1091, 1187, 1);
INSERT INTO 'dancesstepsmap' VALUES (1092, 1188, 1);
INSERT INTO 'dancesstepsmap' VALUES (1094, 1190, 1);
INSERT INTO 'dancesstepsmap' VALUES (1095, 1191, 1);
INSERT INTO 'dancesstepsmap' VALUES (1096, 1192, 1);
INSERT INTO 'dancesstepsmap' VALUES (1097, 1193, 4);
INSERT INTO 'dancesstepsmap' VALUES (1098, 1194, 1);
INSERT INTO 'dancesstepsmap' VALUES (1099, 1195, 1);
INSERT INTO 'dancesstepsmap' VALUES (1100, 1196, 1);
INSERT INTO 'dancesstepsmap' VALUES (1101, 1197, 1);
INSERT INTO 'dancesstepsmap' VALUES (1102, 1198, 1);
INSERT INTO 'dancesstepsmap' VALUES (1103, 1199, 4);
INSERT INTO 'dancesstepsmap' VALUES (1104, 1200, 1);
INSERT INTO 'dancesstepsmap' VALUES (1105, 1201, 1);
INSERT INTO 'dancesstepsmap' VALUES (1106, 1204, 1);
INSERT INTO 'dancesstepsmap' VALUES (1107, 1205, 1);
INSERT INTO 'dancesstepsmap' VALUES (1108, 1206, 1);
INSERT INTO 'dancesstepsmap' VALUES (1109, 1207, 1);
INSERT INTO 'dancesstepsmap' VALUES (1110, 1208, 4);
INSERT INTO 'dancesstepsmap' VALUES (1111, 1209, 4);
INSERT INTO 'dancesstepsmap' VALUES (1112, 1210, 1);
INSERT INTO 'dancesstepsmap' VALUES (1113, 1211, 4);
INSERT INTO 'dancesstepsmap' VALUES (1114, 1212, 4);
INSERT INTO 'dancesstepsmap' VALUES (1115, 1213, 4);
INSERT INTO 'dancesstepsmap' VALUES (1116, 1214, 4);
INSERT INTO 'dancesstepsmap' VALUES (1117, 1215, 1);
INSERT INTO 'dancesstepsmap' VALUES (1118, 1216, 4);
INSERT INTO 'dancesstepsmap' VALUES (1119, 1217, 1);
INSERT INTO 'dancesstepsmap' VALUES (1120, 1218, 1);
INSERT INTO 'dancesstepsmap' VALUES (1121, 1219, 4);
INSERT INTO 'dancesstepsmap' VALUES (1122, 1221, 1);
INSERT INTO 'dancesstepsmap' VALUES (1123, 1222, 1);
INSERT INTO 'dancesstepsmap' VALUES (1124, 1223, 1);
INSERT INTO 'dancesstepsmap' VALUES (1125, 1224, 1);
INSERT INTO 'dancesstepsmap' VALUES (1126, 1225, 1);
INSERT INTO 'dancesstepsmap' VALUES (1127, 1226, 1);
INSERT INTO 'dancesstepsmap' VALUES (1128, 1227, 1);
INSERT INTO 'dancesstepsmap' VALUES (1129, 1228, 1);
INSERT INTO 'dancesstepsmap' VALUES (1130, 1229, 1);
INSERT INTO 'dancesstepsmap' VALUES (1131, 1230, 1);
INSERT INTO 'dancesstepsmap' VALUES (1132, 1231, 1);
INSERT INTO 'dancesstepsmap' VALUES (1133, 1233, 1);
INSERT INTO 'dancesstepsmap' VALUES (1134, 1234, 1);
INSERT INTO 'dancesstepsmap' VALUES (1135, 1235, 1);
INSERT INTO 'dancesstepsmap' VALUES (1136, 1236, 1);
INSERT INTO 'dancesstepsmap' VALUES (1137, 1237, 4);
INSERT INTO 'dancesstepsmap' VALUES (1138, 1238, 1);
INSERT INTO 'dancesstepsmap' VALUES (1139, 1239, 4);
INSERT INTO 'dancesstepsmap' VALUES (1140, 1240, 1);
INSERT INTO 'dancesstepsmap' VALUES (1141, 1241, 1);
INSERT INTO 'dancesstepsmap' VALUES (1142, 1242, 4);
INSERT INTO 'dancesstepsmap' VALUES (1143, 1243, 4);
INSERT INTO 'dancesstepsmap' VALUES (1144, 1244, 1);
INSERT INTO 'dancesstepsmap' VALUES (1145, 1245, 1);
INSERT INTO 'dancesstepsmap' VALUES (1146, 1246, 1);
INSERT INTO 'dancesstepsmap' VALUES (1147, 1247, 4);
INSERT INTO 'dancesstepsmap' VALUES (1148, 1248, 1);
INSERT INTO 'dancesstepsmap' VALUES (1149, 1249, 1);
INSERT INTO 'dancesstepsmap' VALUES (1150, 1250, 1);
INSERT INTO 'dancesstepsmap' VALUES (1151, 1251, 4);
INSERT INTO 'dancesstepsmap' VALUES (1152, 1252, 1);
INSERT INTO 'dancesstepsmap' VALUES (1153, 1253, 1);
INSERT INTO 'dancesstepsmap' VALUES (1154, 1254, 1);
INSERT INTO 'dancesstepsmap' VALUES (1155, 1257, 1);
INSERT INTO 'dancesstepsmap' VALUES (10352, 9576, 4);
INSERT INTO 'dancesstepsmap' VALUES (10353, 9577, 1);
INSERT INTO 'dancesstepsmap' VALUES (10354, 9578, 1);
INSERT INTO 'dancesstepsmap' VALUES (10355, 9579, 4);
INSERT INTO 'dancesstepsmap' VALUES (10356, 9580, 1);
INSERT INTO 'dancesstepsmap' VALUES (10357, 9581, 4);
INSERT INTO 'dancesstepsmap' VALUES (10358, 9582, 1);
INSERT INTO 'dancesstepsmap' VALUES (10359, 9583, 4);
INSERT INTO 'dancesstepsmap' VALUES (10360, 9584, 1);
INSERT INTO 'dancesstepsmap' VALUES (10361, 9584, 3);
INSERT INTO 'dancesstepsmap' VALUES (10362, 9585, 2);
INSERT INTO 'dancesstepsmap' VALUES (10363, 9586, 1);
INSERT INTO 'dancesstepsmap' VALUES (10364, 9587, 4);
INSERT INTO 'dancesstepsmap' VALUES (10365, 9588, 4);
INSERT INTO 'dancesstepsmap' VALUES (10366, 9589, 2);
INSERT INTO 'dancesstepsmap' VALUES (10367, 9589, 1);
INSERT INTO 'dancesstepsmap' VALUES (10368, 9586, 2);
INSERT INTO 'dancesstepsmap' VALUES (10369, 9590, 5);
INSERT INTO 'dancesstepsmap' VALUES (10370, 9590, 4);
INSERT INTO 'dancesstepsmap' VALUES (10371, 9591, 1);
INSERT INTO 'dancesstepsmap' VALUES (10372, 9592, 4);
INSERT INTO 'dancesstepsmap' VALUES (10373, 9593, 1);
INSERT INTO 'dancesstepsmap' VALUES (10374, 9594, 1);
INSERT INTO 'dancesstepsmap' VALUES (10375, 9595, 1);
INSERT INTO 'dancesstepsmap' VALUES (10376, 9596, 3);
INSERT INTO 'dancesstepsmap' VALUES (10377, 9596, 1);
INSERT INTO 'dancesstepsmap' VALUES (10378, 9598, 4);
INSERT INTO 'dancesstepsmap' VALUES (10379, 9599, 1);
INSERT INTO 'dancesstepsmap' VALUES (10380, 9599, 2);
INSERT INTO 'dancesstepsmap' VALUES (10381, 9600, 1);
INSERT INTO 'dancesstepsmap' VALUES (10382, 9602, 1);
INSERT INTO 'dancesstepsmap' VALUES (10383, 9604, 1);
INSERT INTO 'dancesstepsmap' VALUES (10384, 9605, 1);
INSERT INTO 'dancesstepsmap' VALUES (10385, 9607, 8);
INSERT INTO 'dancesstepsmap' VALUES (10386, 9607, 1);
INSERT INTO 'dancesstepsmap' VALUES (10387, 9570, 3);
INSERT INTO 'dancesstepsmap' VALUES (10388, 9570, 1);
INSERT INTO 'dancesstepsmap' VALUES (10389, 9644, 1);
INSERT INTO 'dancesstepsmap' VALUES (10390, 9645, 4);
INSERT INTO 'dancesstepsmap' VALUES (10391, 9646, 3);
INSERT INTO 'dancesstepsmap' VALUES (10392, 9647, 1);
INSERT INTO 'dancesstepsmap' VALUES (10393, 9647, 3);
INSERT INTO 'dancesstepsmap' VALUES (10394, 9648, 3);
INSERT INTO 'dancesstepsmap' VALUES (16962, 14423, 1);
INSERT INTO 'dancesstepsmap' VALUES (16963, 14423, 2);
INSERT INTO 'dancesstepsmap' VALUES (16964, 14423, 3);
INSERT INTO 'dancesstepsmap' VALUES (16987, 8380, 2);
INSERT INTO 'dancesstepsmap' VALUES (1156, 1258, 4);
INSERT INTO 'dancesstepsmap' VALUES (1157, 1259, 4);
INSERT INTO 'dancesstepsmap' VALUES (1158, 1260, 4);
INSERT INTO 'dancesstepsmap' VALUES (1159, 1261, 1);
INSERT INTO 'dancesstepsmap' VALUES (1160, 1262, 1);
INSERT INTO 'dancesstepsmap' VALUES (1161, 1263, 1);
INSERT INTO 'dancesstepsmap' VALUES (1162, 1264, 1);
INSERT INTO 'dancesstepsmap' VALUES (1163, 1266, 1);
INSERT INTO 'dancesstepsmap' VALUES (1164, 1267, 1);
INSERT INTO 'dancesstepsmap' VALUES (1165, 1269, 4);
INSERT INTO 'dancesstepsmap' VALUES (1166, 1270, 1);
INSERT INTO 'dancesstepsmap' VALUES (1167, 1271, 4);
INSERT INTO 'dancesstepsmap' VALUES (1168, 1272, 1);
INSERT INTO 'dancesstepsmap' VALUES (1169, 1273, 4);
INSERT INTO 'dancesstepsmap' VALUES (1170, 1274, 1);
INSERT INTO 'dancesstepsmap' VALUES (1171, 1275, 4);
INSERT INTO 'dancesstepsmap' VALUES (1172, 1276, 4);
INSERT INTO 'dancesstepsmap' VALUES (1173, 1277, 1);
INSERT INTO 'dancesstepsmap' VALUES (1174, 1278, 1);
INSERT INTO 'dancesstepsmap' VALUES (1175, 1279, 1);
INSERT INTO 'dancesstepsmap' VALUES (1176, 1280, 1);
INSERT INTO 'dancesstepsmap' VALUES (1177, 1281, 1);
INSERT INTO 'dancesstepsmap' VALUES (1178, 1282, 4);
INSERT INTO 'dancesstepsmap' VALUES (1179, 1283, 1);
INSERT INTO 'dancesstepsmap' VALUES (1180, 1285, 1);
INSERT INTO 'dancesstepsmap' VALUES (1181, 1286, 1);
INSERT INTO 'dancesstepsmap' VALUES (1182, 1287, 1);
INSERT INTO 'dancesstepsmap' VALUES (1183, 1288, 1);
INSERT INTO 'dancesstepsmap' VALUES (1184, 1289, 4);
INSERT INTO 'dancesstepsmap' VALUES (1185, 1290, 1);
INSERT INTO 'dancesstepsmap' VALUES (1186, 1291, 1);
INSERT INTO 'dancesstepsmap' VALUES (1187, 1292, 1);
INSERT INTO 'dancesstepsmap' VALUES (1188, 1293, 4);
INSERT INTO 'dancesstepsmap' VALUES (1189, 1294, 4);
INSERT INTO 'dancesstepsmap' VALUES (1190, 1295, 4);
INSERT INTO 'dancesstepsmap' VALUES (1191, 1296, 1);
INSERT INTO 'dancesstepsmap' VALUES (1192, 1297, 1);
INSERT INTO 'dancesstepsmap' VALUES (1193, 1298, 1);
INSERT INTO 'dancesstepsmap' VALUES (1194, 1299, 1);
INSERT INTO 'dancesstepsmap' VALUES (1195, 1300, 1);
INSERT INTO 'dancesstepsmap' VALUES (1196, 1301, 1);
INSERT INTO 'dancesstepsmap' VALUES (1197, 1303, 1);
INSERT INTO 'dancesstepsmap' VALUES (1198, 1304, 1);
INSERT INTO 'dancesstepsmap' VALUES (1199, 1305, 4);
INSERT INTO 'dancesstepsmap' VALUES (1200, 1306, 1);
INSERT INTO 'dancesstepsmap' VALUES (1201, 1307, 4);
INSERT INTO 'dancesstepsmap' VALUES (1202, 1308, 1);
INSERT INTO 'dancesstepsmap' VALUES (1203, 1310, 4);
INSERT INTO 'dancesstepsmap' VALUES (1204, 1311, 1);
INSERT INTO 'dancesstepsmap' VALUES (1205, 1312, 1);
INSERT INTO 'dancesstepsmap' VALUES (1206, 1313, 1);
INSERT INTO 'dancesstepsmap' VALUES (1207, 1314, 1);
INSERT INTO 'dancesstepsmap' VALUES (1208, 1315, 4);
INSERT INTO 'dancesstepsmap' VALUES (1209, 1316, 4);
INSERT INTO 'dancesstepsmap' VALUES (1210, 1317, 1);
INSERT INTO 'dancesstepsmap' VALUES (1211, 1318, 4);
INSERT INTO 'dancesstepsmap' VALUES (1212, 1319, 4);
INSERT INTO 'dancesstepsmap' VALUES (1213, 1320, 1);
INSERT INTO 'dancesstepsmap' VALUES (1214, 1321, 4);
INSERT INTO 'dancesstepsmap' VALUES (1215, 1322, 1);
INSERT INTO 'dancesstepsmap' VALUES (1216, 1323, 4);
INSERT INTO 'dancesstepsmap' VALUES (1217, 1324, 4);
INSERT INTO 'dancesstepsmap' VALUES (1218, 1326, 1);
INSERT INTO 'dancesstepsmap' VALUES (1219, 1327, 1);
INSERT INTO 'dancesstepsmap' VALUES (1220, 1328, 1);
INSERT INTO 'dancesstepsmap' VALUES (1221, 1329, 1);
INSERT INTO 'dancesstepsmap' VALUES (1222, 1330, 1);
INSERT INTO 'dancesstepsmap' VALUES (1223, 1331, 4);
INSERT INTO 'dancesstepsmap' VALUES (1224, 1332, 1);
INSERT INTO 'dancesstepsmap' VALUES (1225, 1334, 1);
INSERT INTO 'dancesstepsmap' VALUES (1226, 1335, 1);
INSERT INTO 'dancesstepsmap' VALUES (1227, 1336, 1);
INSERT INTO 'dancesstepsmap' VALUES (1228, 1337, 1);
INSERT INTO 'dancesstepsmap' VALUES (1229, 1338, 4);
INSERT INTO 'dancesstepsmap' VALUES (1230, 1339, 4);
INSERT INTO 'dancesstepsmap' VALUES (1231, 1340, 4);
INSERT INTO 'dancesstepsmap' VALUES (1232, 1341, 1);
INSERT INTO 'dancesstepsmap' VALUES (1233, 1342, 1);
INSERT INTO 'dancesstepsmap' VALUES (1234, 1343, 1);
INSERT INTO 'dancesstepsmap' VALUES (1235, 1344, 1);
INSERT INTO 'dancesstepsmap' VALUES (1236, 1345, 1);
INSERT INTO 'dancesstepsmap' VALUES (1237, 1346, 1);
INSERT INTO 'dancesstepsmap' VALUES (1238, 1347, 1);
INSERT INTO 'dancesstepsmap' VALUES (1239, 1348, 1);
INSERT INTO 'dancesstepsmap' VALUES (1240, 1349, 1);
INSERT INTO 'dancesstepsmap' VALUES (1241, 1350, 1);
INSERT INTO 'dancesstepsmap' VALUES (1242, 1351, 4);
INSERT INTO 'dancesstepsmap' VALUES (1243, 1352, 1);
INSERT INTO 'dancesstepsmap' VALUES (1244, 1353, 4);
INSERT INTO 'dancesstepsmap' VALUES (1245, 1354, 1);
INSERT INTO 'dancesstepsmap' VALUES (1246, 1355, 1);
INSERT INTO 'dancesstepsmap' VALUES (1247, 1356, 1);
INSERT INTO 'dancesstepsmap' VALUES (1248, 1357, 1);
INSERT INTO 'dancesstepsmap' VALUES (10395, 9661, 1);
INSERT INTO 'dancesstepsmap' VALUES (10396, 9661, 2);
INSERT INTO 'dancesstepsmap' VALUES (10397, 9662, 1);
INSERT INTO 'dancesstepsmap' VALUES (10398, 9663, 1);
INSERT INTO 'dancesstepsmap' VALUES (10399, 9664, 6);
INSERT INTO 'dancesstepsmap' VALUES (10400, 9664, 10);
INSERT INTO 'dancesstepsmap' VALUES (10401, 9664, 4);
INSERT INTO 'dancesstepsmap' VALUES (10402, 9666, 3);
INSERT INTO 'dancesstepsmap' VALUES (10403, 9666, 2);
INSERT INTO 'dancesstepsmap' VALUES (10404, 9667, 2);
INSERT INTO 'dancesstepsmap' VALUES (10405, 9669, 1);
INSERT INTO 'dancesstepsmap' VALUES (10406, 9670, 4);
INSERT INTO 'dancesstepsmap' VALUES (10407, 9671, 4);
INSERT INTO 'dancesstepsmap' VALUES (10408, 9672, 4);
INSERT INTO 'dancesstepsmap' VALUES (10409, 9673, 1);
INSERT INTO 'dancesstepsmap' VALUES (10410, 9673, 2);
INSERT INTO 'dancesstepsmap' VALUES (10411, 9674, 1);
INSERT INTO 'dancesstepsmap' VALUES (10412, 9678, 4);
INSERT INTO 'dancesstepsmap' VALUES (10413, 9679, 1);
INSERT INTO 'dancesstepsmap' VALUES (10414, 9680, 1);
INSERT INTO 'dancesstepsmap' VALUES (10415, 9681, 4);
INSERT INTO 'dancesstepsmap' VALUES (10416, 9681, 5);
INSERT INTO 'dancesstepsmap' VALUES (10417, 9682, 1);
INSERT INTO 'dancesstepsmap' VALUES (10418, 9683, 4);
INSERT INTO 'dancesstepsmap' VALUES (10419, 9685, 4);
INSERT INTO 'dancesstepsmap' VALUES (10420, 9686, 1);
INSERT INTO 'dancesstepsmap' VALUES (10421, 9687, 1);
INSERT INTO 'dancesstepsmap' VALUES (10422, 9688, 1);
INSERT INTO 'dancesstepsmap' VALUES (10423, 9689, 1);
INSERT INTO 'dancesstepsmap' VALUES (10424, 9690, 3);
INSERT INTO 'dancesstepsmap' VALUES (10425, 9691, 1);
INSERT INTO 'dancesstepsmap' VALUES (10426, 9692, 3);
INSERT INTO 'dancesstepsmap' VALUES (10427, 9692, 1);
INSERT INTO 'dancesstepsmap' VALUES (10428, 9693, 1);
INSERT INTO 'dancesstepsmap' VALUES (10429, 9693, 2);
INSERT INTO 'dancesstepsmap' VALUES (10430, 9695, 6);
INSERT INTO 'dancesstepsmap' VALUES (10431, 9695, 4);
INSERT INTO 'dancesstepsmap' VALUES (10432, 9696, 1);
INSERT INTO 'dancesstepsmap' VALUES (10433, 9696, 2);
INSERT INTO 'dancesstepsmap' VALUES (10434, 9697, 3);
INSERT INTO 'dancesstepsmap' VALUES (10435, 9697, 2);
INSERT INTO 'dancesstepsmap' VALUES (10436, 9697, 1);
INSERT INTO 'dancesstepsmap' VALUES (16965, 14424, 1);
INSERT INTO 'dancesstepsmap' VALUES (16966, 14424, 2);
INSERT INTO 'dancesstepsmap' VALUES (16988, 8381, 2);
INSERT INTO 'dancesstepsmap' VALUES (16991, 3980, 2);
INSERT INTO 'dancesstepsmap' VALUES (16992, 1244, 2);
INSERT INTO 'dancesstepsmap' VALUES (16993, 12334, 2);
INSERT INTO 'dancesstepsmap' VALUES (1249, 1358, 1);
INSERT INTO 'dancesstepsmap' VALUES (1250, 1359, 4);
INSERT INTO 'dancesstepsmap' VALUES (1251, 1360, 1);
INSERT INTO 'dancesstepsmap' VALUES (1252, 1361, 1);
INSERT INTO 'dancesstepsmap' VALUES (1253, 1362, 1);
INSERT INTO 'dancesstepsmap' VALUES (1254, 1363, 4);
INSERT INTO 'dancesstepsmap' VALUES (1255, 1364, 1);
INSERT INTO 'dancesstepsmap' VALUES (1256, 1365, 1);
INSERT INTO 'dancesstepsmap' VALUES (1257, 1366, 4);
INSERT INTO 'dancesstepsmap' VALUES (1258, 1367, 1);
INSERT INTO 'dancesstepsmap' VALUES (1259, 1368, 1);
INSERT INTO 'dancesstepsmap' VALUES (1260, 1369, 1);
INSERT INTO 'dancesstepsmap' VALUES (1261, 1370, 4);
INSERT INTO 'dancesstepsmap' VALUES (1262, 1372, 1);
INSERT INTO 'dancesstepsmap' VALUES (1263, 1373, 1);
INSERT INTO 'dancesstepsmap' VALUES (1264, 1374, 1);
INSERT INTO 'dancesstepsmap' VALUES (1265, 1375, 1);
INSERT INTO 'dancesstepsmap' VALUES (1266, 1376, 4);
INSERT INTO 'dancesstepsmap' VALUES (1267, 1377, 4);
INSERT INTO 'dancesstepsmap' VALUES (1268, 1378, 1);
INSERT INTO 'dancesstepsmap' VALUES (1269, 1379, 4);
INSERT INTO 'dancesstepsmap' VALUES (1270, 1380, 1);
INSERT INTO 'dancesstepsmap' VALUES (1271, 1381, 1);
INSERT INTO 'dancesstepsmap' VALUES (1272, 1382, 4);
INSERT INTO 'dancesstepsmap' VALUES (1273, 1383, 4);
INSERT INTO 'dancesstepsmap' VALUES (1274, 1384, 4);
INSERT INTO 'dancesstepsmap' VALUES (1275, 1385, 1);
INSERT INTO 'dancesstepsmap' VALUES (1276, 1386, 1);
INSERT INTO 'dancesstepsmap' VALUES (1277, 1387, 1);
INSERT INTO 'dancesstepsmap' VALUES (1278, 1388, 4);
INSERT INTO 'dancesstepsmap' VALUES (1279, 1389, 1);
INSERT INTO 'dancesstepsmap' VALUES (1280, 1390, 1);
INSERT INTO 'dancesstepsmap' VALUES (1281, 1391, 1);
INSERT INTO 'dancesstepsmap' VALUES (1282, 1392, 1);
INSERT INTO 'dancesstepsmap' VALUES (1283, 1393, 4);
INSERT INTO 'dancesstepsmap' VALUES (1284, 1394, 1);
INSERT INTO 'dancesstepsmap' VALUES (1285, 1395, 1);
INSERT INTO 'dancesstepsmap' VALUES (1286, 1396, 1);
INSERT INTO 'dancesstepsmap' VALUES (1287, 1397, 1);
INSERT INTO 'dancesstepsmap' VALUES (1288, 1398, 4);
INSERT INTO 'dancesstepsmap' VALUES (1289, 1399, 1);
INSERT INTO 'dancesstepsmap' VALUES (1290, 1400, 1);
INSERT INTO 'dancesstepsmap' VALUES (1291, 1401, 4);
INSERT INTO 'dancesstepsmap' VALUES (1292, 1402, 1);
INSERT INTO 'dancesstepsmap' VALUES (1293, 1403, 1);
INSERT INTO 'dancesstepsmap' VALUES (1294, 1404, 4);
INSERT INTO 'dancesstepsmap' VALUES (1295, 1405, 1);
INSERT INTO 'dancesstepsmap' VALUES (1296, 1406, 4);
INSERT INTO 'dancesstepsmap' VALUES (1297, 1407, 1);
INSERT INTO 'dancesstepsmap' VALUES (1298, 1408, 4);
INSERT INTO 'dancesstepsmap' VALUES (1299, 1409, 1);
INSERT INTO 'dancesstepsmap' VALUES (1300, 1410, 4);
INSERT INTO 'dancesstepsmap' VALUES (1301, 1411, 1);
INSERT INTO 'dancesstepsmap' VALUES (1302, 1412, 1);
INSERT INTO 'dancesstepsmap' VALUES (1303, 1413, 1);
INSERT INTO 'dancesstepsmap' VALUES (1304, 1414, 1);
INSERT INTO 'dancesstepsmap' VALUES (1305, 1415, 1);
INSERT INTO 'dancesstepsmap' VALUES (1306, 1416, 1);
INSERT INTO 'dancesstepsmap' VALUES (1307, 1417, 1);
INSERT INTO 'dancesstepsmap' VALUES (1308, 1418, 4);
INSERT INTO 'dancesstepsmap' VALUES (1309, 1419, 4);
INSERT INTO 'dancesstepsmap' VALUES (1310, 1420, 1);
INSERT INTO 'dancesstepsmap' VALUES (1311, 1422, 1);
INSERT INTO 'dancesstepsmap' VALUES (1312, 1423, 1);
INSERT INTO 'dancesstepsmap' VALUES (1313, 1424, 1);
INSERT INTO 'dancesstepsmap' VALUES (1314, 1425, 1);
INSERT INTO 'dancesstepsmap' VALUES (1315, 1426, 1);
INSERT INTO 'dancesstepsmap' VALUES (1316, 1427, 1);
INSERT INTO 'dancesstepsmap' VALUES (1317, 1428, 1);
INSERT INTO 'dancesstepsmap' VALUES (1318, 1430, 4);
INSERT INTO 'dancesstepsmap' VALUES (1319, 1431, 1);
INSERT INTO 'dancesstepsmap' VALUES (1320, 1432, 1);
INSERT INTO 'dancesstepsmap' VALUES (1321, 1433, 1);
INSERT INTO 'dancesstepsmap' VALUES (1322, 1434, 4);
INSERT INTO 'dancesstepsmap' VALUES (1323, 1436, 1);
INSERT INTO 'dancesstepsmap' VALUES (1324, 1437, 4);
INSERT INTO 'dancesstepsmap' VALUES (1325, 1438, 4);
INSERT INTO 'dancesstepsmap' VALUES (1326, 1439, 1);
INSERT INTO 'dancesstepsmap' VALUES (1327, 1440, 1);
INSERT INTO 'dancesstepsmap' VALUES (1328, 1441, 1);
INSERT INTO 'dancesstepsmap' VALUES (1329, 1442, 1);
INSERT INTO 'dancesstepsmap' VALUES (1330, 1443, 1);
INSERT INTO 'dancesstepsmap' VALUES (1331, 1444, 1);
INSERT INTO 'dancesstepsmap' VALUES (1332, 1445, 4);
INSERT INTO 'dancesstepsmap' VALUES (1333, 1446, 4);
INSERT INTO 'dancesstepsmap' VALUES (1334, 1447, 4);
INSERT INTO 'dancesstepsmap' VALUES (1335, 1448, 4);
INSERT INTO 'dancesstepsmap' VALUES (1336, 1449, 1);
INSERT INTO 'dancesstepsmap' VALUES (1337, 1450, 1);
INSERT INTO 'dancesstepsmap' VALUES (1338, 1451, 1);
INSERT INTO 'dancesstepsmap' VALUES (1339, 1452, 1);
INSERT INTO 'dancesstepsmap' VALUES (1340, 1453, 4);
INSERT INTO 'dancesstepsmap' VALUES (10437, 9701, 4);
INSERT INTO 'dancesstepsmap' VALUES (10438, 9702, 3);
INSERT INTO 'dancesstepsmap' VALUES (10439, 9702, 1);
INSERT INTO 'dancesstepsmap' VALUES (10440, 9703, 4);
INSERT INTO 'dancesstepsmap' VALUES (10441, 9704, 1);
INSERT INTO 'dancesstepsmap' VALUES (10442, 9704, 2);
INSERT INTO 'dancesstepsmap' VALUES (10443, 9705, 4);
INSERT INTO 'dancesstepsmap' VALUES (10444, 9706, 1);
INSERT INTO 'dancesstepsmap' VALUES (10445, 9709, 5);
INSERT INTO 'dancesstepsmap' VALUES (10446, 8960, 3);
INSERT INTO 'dancesstepsmap' VALUES (10447, 9710, 1);
INSERT INTO 'dancesstepsmap' VALUES (10448, 9713, 5);
INSERT INTO 'dancesstepsmap' VALUES (10449, 9713, 4);
INSERT INTO 'dancesstepsmap' VALUES (10450, 9714, 4);
INSERT INTO 'dancesstepsmap' VALUES (10451, 9715, 2);
INSERT INTO 'dancesstepsmap' VALUES (10452, 8959, 2);
INSERT INTO 'dancesstepsmap' VALUES (10453, 9716, 4);
INSERT INTO 'dancesstepsmap' VALUES (10454, 9717, 1);
INSERT INTO 'dancesstepsmap' VALUES (10455, 9718, 6);
INSERT INTO 'dancesstepsmap' VALUES (10456, 9718, 9);
INSERT INTO 'dancesstepsmap' VALUES (10457, 9719, 4);
INSERT INTO 'dancesstepsmap' VALUES (10458, 9720, 4);
INSERT INTO 'dancesstepsmap' VALUES (10459, 9721, 2);
INSERT INTO 'dancesstepsmap' VALUES (10460, 9722, 1);
INSERT INTO 'dancesstepsmap' VALUES (10461, 9723, 4);
INSERT INTO 'dancesstepsmap' VALUES (10462, 9723, 5);
INSERT INTO 'dancesstepsmap' VALUES (10463, 9723, 1);
INSERT INTO 'dancesstepsmap' VALUES (10464, 9723, 2);
INSERT INTO 'dancesstepsmap' VALUES (10465, 9724, 5);
INSERT INTO 'dancesstepsmap' VALUES (10466, 9724, 4);
INSERT INTO 'dancesstepsmap' VALUES (10467, 9725, 2);
INSERT INTO 'dancesstepsmap' VALUES (10468, 9726, 4);
INSERT INTO 'dancesstepsmap' VALUES (10469, 9727, 1);
INSERT INTO 'dancesstepsmap' VALUES (10470, 9727, 2);
INSERT INTO 'dancesstepsmap' VALUES (10471, 9728, 3);
INSERT INTO 'dancesstepsmap' VALUES (10472, 9728, 1);
INSERT INTO 'dancesstepsmap' VALUES (10473, 9729, 1);
INSERT INTO 'dancesstepsmap' VALUES (10474, 9729, 2);
INSERT INTO 'dancesstepsmap' VALUES (10475, 9730, 2);
INSERT INTO 'dancesstepsmap' VALUES (10476, 9730, 1);
INSERT INTO 'dancesstepsmap' VALUES (23132, 18245, 3);
INSERT INTO 'dancesstepsmap' VALUES (10478, 9732, 1);
INSERT INTO 'dancesstepsmap' VALUES (16989, 8382, 5);
INSERT INTO 'dancesstepsmap' VALUES (16994, 14429, 4);
INSERT INTO 'dancesstepsmap' VALUES (16995, 14429, 5);
INSERT INTO 'dancesstepsmap' VALUES (1341, 1454, 4);
INSERT INTO 'dancesstepsmap' VALUES (1342, 1455, 1);
INSERT INTO 'dancesstepsmap' VALUES (1343, 1456, 1);
INSERT INTO 'dancesstepsmap' VALUES (1344, 1457, 1);
INSERT INTO 'dancesstepsmap' VALUES (1345, 1458, 1);
INSERT INTO 'dancesstepsmap' VALUES (1346, 1459, 4);
INSERT INTO 'dancesstepsmap' VALUES (1347, 1460, 4);
INSERT INTO 'dancesstepsmap' VALUES (1348, 1461, 1);
INSERT INTO 'dancesstepsmap' VALUES (1349, 1462, 4);
INSERT INTO 'dancesstepsmap' VALUES (1350, 1463, 1);
INSERT INTO 'dancesstepsmap' VALUES (1351, 1464, 1);
INSERT INTO 'dancesstepsmap' VALUES (1352, 1465, 1);
INSERT INTO 'dancesstepsmap' VALUES (1353, 1466, 1);
INSERT INTO 'dancesstepsmap' VALUES (1354, 1467, 1);
INSERT INTO 'dancesstepsmap' VALUES (1355, 1469, 4);
INSERT INTO 'dancesstepsmap' VALUES (1356, 1470, 1);
INSERT INTO 'dancesstepsmap' VALUES (1357, 1471, 1);
INSERT INTO 'dancesstepsmap' VALUES (1358, 1472, 4);
INSERT INTO 'dancesstepsmap' VALUES (1359, 1473, 4);
INSERT INTO 'dancesstepsmap' VALUES (1360, 1474, 4);
INSERT INTO 'dancesstepsmap' VALUES (1361, 1475, 4);
INSERT INTO 'dancesstepsmap' VALUES (1362, 1476, 1);
INSERT INTO 'dancesstepsmap' VALUES (1363, 1477, 1);
INSERT INTO 'dancesstepsmap' VALUES (1364, 1478, 1);
INSERT INTO 'dancesstepsmap' VALUES (1365, 1479, 1);
INSERT INTO 'dancesstepsmap' VALUES (1366, 1480, 1);
INSERT INTO 'dancesstepsmap' VALUES (1367, 1481, 1);
INSERT INTO 'dancesstepsmap' VALUES (1368, 1482, 4);
INSERT INTO 'dancesstepsmap' VALUES (1369, 1483, 1);
INSERT INTO 'dancesstepsmap' VALUES (1370, 1485, 4);
INSERT INTO 'dancesstepsmap' VALUES (1371, 1486, 1);
INSERT INTO 'dancesstepsmap' VALUES (1372, 1487, 4);
INSERT INTO 'dancesstepsmap' VALUES (1373, 1488, 1);
INSERT INTO 'dancesstepsmap' VALUES (1374, 1489, 1);
INSERT INTO 'dancesstepsmap' VALUES (1375, 1490, 4);
INSERT INTO 'dancesstepsmap' VALUES (1376, 1491, 1);
INSERT INTO 'dancesstepsmap' VALUES (1377, 1492, 1);
INSERT INTO 'dancesstepsmap' VALUES (1378, 1493, 4);
INSERT INTO 'dancesstepsmap' VALUES (1379, 1494, 1);
INSERT INTO 'dancesstepsmap' VALUES (1380, 1495, 4);
INSERT INTO 'dancesstepsmap' VALUES (1381, 1496, 4);
INSERT INTO 'dancesstepsmap' VALUES (1382, 1497, 1);
INSERT INTO 'dancesstepsmap' VALUES (1383, 1498, 1);
INSERT INTO 'dancesstepsmap' VALUES (1384, 1499, 1);
INSERT INTO 'dancesstepsmap' VALUES (1385, 1500, 1);
INSERT INTO 'dancesstepsmap' VALUES (1386, 1501, 4);
INSERT INTO 'dancesstepsmap' VALUES (1387, 1502, 1);
INSERT INTO 'dancesstepsmap' VALUES (1388, 1503, 4);
INSERT INTO 'dancesstepsmap' VALUES (1389, 1504, 1);
INSERT INTO 'dancesstepsmap' VALUES (1390, 1505, 4);
INSERT INTO 'dancesstepsmap' VALUES (1391, 1506, 1);
INSERT INTO 'dancesstepsmap' VALUES (1392, 1507, 4);
INSERT INTO 'dancesstepsmap' VALUES (1393, 1508, 4);
INSERT INTO 'dancesstepsmap' VALUES (1394, 1509, 1);
INSERT INTO 'dancesstepsmap' VALUES (1395, 1510, 4);
INSERT INTO 'dancesstepsmap' VALUES (1396, 1511, 1);
INSERT INTO 'dancesstepsmap' VALUES (1397, 1512, 4);
INSERT INTO 'dancesstepsmap' VALUES (1398, 1513, 1);
INSERT INTO 'dancesstepsmap' VALUES (1399, 1514, 1);
INSERT INTO 'dancesstepsmap' VALUES (1400, 1516, 1);
INSERT INTO 'dancesstepsmap' VALUES (1401, 1517, 1);
INSERT INTO 'dancesstepsmap' VALUES (1402, 1518, 4);
INSERT INTO 'dancesstepsmap' VALUES (1403, 1520, 1);
INSERT INTO 'dancesstepsmap' VALUES (1404, 1521, 1);
INSERT INTO 'dancesstepsmap' VALUES (1405, 1522, 1);
INSERT INTO 'dancesstepsmap' VALUES (1406, 1523, 4);
INSERT INTO 'dancesstepsmap' VALUES (1407, 1524, 1);
INSERT INTO 'dancesstepsmap' VALUES (1408, 1525, 1);
INSERT INTO 'dancesstepsmap' VALUES (1409, 1526, 4);
INSERT INTO 'dancesstepsmap' VALUES (1410, 1527, 4);
INSERT INTO 'dancesstepsmap' VALUES (1411, 1528, 1);
INSERT INTO 'dancesstepsmap' VALUES (1412, 1529, 1);
INSERT INTO 'dancesstepsmap' VALUES (1413, 1530, 1);
INSERT INTO 'dancesstepsmap' VALUES (1414, 1531, 1);
INSERT INTO 'dancesstepsmap' VALUES (1415, 1532, 1);
INSERT INTO 'dancesstepsmap' VALUES (1416, 1534, 4);
INSERT INTO 'dancesstepsmap' VALUES (1417, 1535, 1);
INSERT INTO 'dancesstepsmap' VALUES (1418, 1536, 1);
INSERT INTO 'dancesstepsmap' VALUES (1419, 1537, 1);
INSERT INTO 'dancesstepsmap' VALUES (1420, 1538, 1);
INSERT INTO 'dancesstepsmap' VALUES (1421, 1539, 4);
INSERT INTO 'dancesstepsmap' VALUES (1422, 1540, 4);
INSERT INTO 'dancesstepsmap' VALUES (1423, 1541, 4);
INSERT INTO 'dancesstepsmap' VALUES (1424, 1542, 1);
INSERT INTO 'dancesstepsmap' VALUES (1425, 1543, 1);
INSERT INTO 'dancesstepsmap' VALUES (1426, 1544, 1);
INSERT INTO 'dancesstepsmap' VALUES (1427, 1545, 1);
INSERT INTO 'dancesstepsmap' VALUES (1428, 1546, 1);
INSERT INTO 'dancesstepsmap' VALUES (1429, 1547, 1);
INSERT INTO 'dancesstepsmap' VALUES (1430, 1548, 1);
INSERT INTO 'dancesstepsmap' VALUES (1431, 1549, 1);
INSERT INTO 'dancesstepsmap' VALUES (1432, 1550, 4);
INSERT INTO 'dancesstepsmap' VALUES (1433, 1551, 4);
INSERT INTO 'dancesstepsmap' VALUES (10479, 9732, 2);
INSERT INTO 'dancesstepsmap' VALUES (10480, 9733, 1);
INSERT INTO 'dancesstepsmap' VALUES (10481, 9734, 4);
INSERT INTO 'dancesstepsmap' VALUES (10482, 9736, 4);
INSERT INTO 'dancesstepsmap' VALUES (10483, 9737, 4);
INSERT INTO 'dancesstepsmap' VALUES (10484, 2641, 4);
INSERT INTO 'dancesstepsmap' VALUES (10485, 4799, 1);
INSERT INTO 'dancesstepsmap' VALUES (10486, 8965, 1);
INSERT INTO 'dancesstepsmap' VALUES (10487, 9352, 4);
INSERT INTO 'dancesstepsmap' VALUES (10488, 9352, 5);
INSERT INTO 'dancesstepsmap' VALUES (10489, 9738, 1);
INSERT INTO 'dancesstepsmap' VALUES (10490, 9738, 2);
INSERT INTO 'dancesstepsmap' VALUES (10491, 9738, 3);
INSERT INTO 'dancesstepsmap' VALUES (10492, 9739, 1);
INSERT INTO 'dancesstepsmap' VALUES (10493, 9744, 3);
INSERT INTO 'dancesstepsmap' VALUES (10494, 9744, 1);
INSERT INTO 'dancesstepsmap' VALUES (10495, 9745, 2);
INSERT INTO 'dancesstepsmap' VALUES (10496, 9746, 4);
INSERT INTO 'dancesstepsmap' VALUES (10497, 9747, 4);
INSERT INTO 'dancesstepsmap' VALUES (10498, 9747, 5);
INSERT INTO 'dancesstepsmap' VALUES (10499, 9748, 1);
INSERT INTO 'dancesstepsmap' VALUES (10500, 9749, 1);
INSERT INTO 'dancesstepsmap' VALUES (10501, 9749, 3);
INSERT INTO 'dancesstepsmap' VALUES (10502, 9751, 1);
INSERT INTO 'dancesstepsmap' VALUES (10503, 9751, 2);
INSERT INTO 'dancesstepsmap' VALUES (10504, 9752, 3);
INSERT INTO 'dancesstepsmap' VALUES (10505, 9752, 1);
INSERT INTO 'dancesstepsmap' VALUES (10506, 9753, 3);
INSERT INTO 'dancesstepsmap' VALUES (10507, 9754, 1);
INSERT INTO 'dancesstepsmap' VALUES (10508, 9755, 4);
INSERT INTO 'dancesstepsmap' VALUES (10509, 9755, 5);
INSERT INTO 'dancesstepsmap' VALUES (10510, 9756, 1);
INSERT INTO 'dancesstepsmap' VALUES (10511, 9756, 3);
INSERT INTO 'dancesstepsmap' VALUES (10512, 9757, 4);
INSERT INTO 'dancesstepsmap' VALUES (10513, 9758, 4);
INSERT INTO 'dancesstepsmap' VALUES (10514, 9758, 5);
INSERT INTO 'dancesstepsmap' VALUES (10515, 8780, 1);
INSERT INTO 'dancesstepsmap' VALUES (10516, 9771, 1);
INSERT INTO 'dancesstepsmap' VALUES (10517, 4691, 3);
INSERT INTO 'dancesstepsmap' VALUES (10518, 8741, 1);
INSERT INTO 'dancesstepsmap' VALUES (10519, 8741, 3);
INSERT INTO 'dancesstepsmap' VALUES (10520, 9189, 1);
INSERT INTO 'dancesstepsmap' VALUES (10521, 9189, 2);
INSERT INTO 'dancesstepsmap' VALUES (10522, 9773, 4);
INSERT INTO 'dancesstepsmap' VALUES (10523, 9773, 1);
INSERT INTO 'dancesstepsmap' VALUES (10524, 9773, 3);
INSERT INTO 'dancesstepsmap' VALUES (10525, 9774, 2);
INSERT INTO 'dancesstepsmap' VALUES (10526, 9774, 1);
INSERT INTO 'dancesstepsmap' VALUES (10527, 9775, 1);
INSERT INTO 'dancesstepsmap' VALUES (10528, 9776, 4);
INSERT INTO 'dancesstepsmap' VALUES (10529, 9777, 4);
INSERT INTO 'dancesstepsmap' VALUES (10530, 9707, 1);
INSERT INTO 'dancesstepsmap' VALUES (10531, 9802, 3);
INSERT INTO 'dancesstepsmap' VALUES (16990, 8385, 5);
INSERT INTO 'dancesstepsmap' VALUES (1434, 1552, 1);
INSERT INTO 'dancesstepsmap' VALUES (1435, 1553, 1);
INSERT INTO 'dancesstepsmap' VALUES (1436, 1554, 1);
INSERT INTO 'dancesstepsmap' VALUES (1437, 1555, 4);
INSERT INTO 'dancesstepsmap' VALUES (1438, 1556, 4);
INSERT INTO 'dancesstepsmap' VALUES (1439, 1558, 4);
INSERT INTO 'dancesstepsmap' VALUES (1440, 1559, 4);
INSERT INTO 'dancesstepsmap' VALUES (1441, 1560, 4);
INSERT INTO 'dancesstepsmap' VALUES (1442, 1561, 4);
INSERT INTO 'dancesstepsmap' VALUES (1443, 1562, 1);
INSERT INTO 'dancesstepsmap' VALUES (1444, 1563, 1);
INSERT INTO 'dancesstepsmap' VALUES (1445, 1564, 4);
INSERT INTO 'dancesstepsmap' VALUES (1446, 1565, 1);
INSERT INTO 'dancesstepsmap' VALUES (1447, 1567, 4);
INSERT INTO 'dancesstepsmap' VALUES (1448, 1568, 4);
INSERT INTO 'dancesstepsmap' VALUES (1449, 1569, 1);
INSERT INTO 'dancesstepsmap' VALUES (1450, 1570, 4);
INSERT INTO 'dancesstepsmap' VALUES (1451, 1571, 1);
INSERT INTO 'dancesstepsmap' VALUES (1452, 1572, 1);
INSERT INTO 'dancesstepsmap' VALUES (1453, 1573, 4);
INSERT INTO 'dancesstepsmap' VALUES (1454, 1574, 4);
INSERT INTO 'dancesstepsmap' VALUES (1455, 1575, 1);
INSERT INTO 'dancesstepsmap' VALUES (1456, 1576, 1);
INSERT INTO 'dancesstepsmap' VALUES (1457, 1577, 4);
INSERT INTO 'dancesstepsmap' VALUES (1458, 1578, 1);
INSERT INTO 'dancesstepsmap' VALUES (1459, 1579, 1);
INSERT INTO 'dancesstepsmap' VALUES (1460, 1580, 1);
INSERT INTO 'dancesstepsmap' VALUES (1461, 1581, 1);
INSERT INTO 'dancesstepsmap' VALUES (1462, 1582, 1);
INSERT INTO 'dancesstepsmap' VALUES (1463, 1583, 1);
INSERT INTO 'dancesstepsmap' VALUES (1464, 1584, 1);
INSERT INTO 'dancesstepsmap' VALUES (1465, 1585, 1);
INSERT INTO 'dancesstepsmap' VALUES (1466, 1586, 4);
INSERT INTO 'dancesstepsmap' VALUES (1467, 1587, 1);
INSERT INTO 'dancesstepsmap' VALUES (1468, 1588, 4);
INSERT INTO 'dancesstepsmap' VALUES (1469, 1589, 4);
INSERT INTO 'dancesstepsmap' VALUES (1470, 1590, 1);
INSERT INTO 'dancesstepsmap' VALUES (1471, 1591, 4);
INSERT INTO 'dancesstepsmap' VALUES (1472, 1592, 1);
INSERT INTO 'dancesstepsmap' VALUES (1473, 1593, 1);
INSERT INTO 'dancesstepsmap' VALUES (1474, 1594, 4);
INSERT INTO 'dancesstepsmap' VALUES (1475, 1595, 4);
INSERT INTO 'dancesstepsmap' VALUES (1476, 1596, 4);
INSERT INTO 'dancesstepsmap' VALUES (1477, 1597, 1);
INSERT INTO 'dancesstepsmap' VALUES (1478, 1598, 1);
INSERT INTO 'dancesstepsmap' VALUES (1479, 1599, 4);
INSERT INTO 'dancesstepsmap' VALUES (1480, 1600, 1);
INSERT INTO 'dancesstepsmap' VALUES (1481, 1601, 1);
INSERT INTO 'dancesstepsmap' VALUES (1482, 1602, 1);
INSERT INTO 'dancesstepsmap' VALUES (1483, 1603, 1);
INSERT INTO 'dancesstepsmap' VALUES (1484, 1604, 1);
INSERT INTO 'dancesstepsmap' VALUES (1485, 1605, 1);
INSERT INTO 'dancesstepsmap' VALUES (1486, 1606, 1);
INSERT INTO 'dancesstepsmap' VALUES (1487, 1608, 1);
INSERT INTO 'dancesstepsmap' VALUES (1488, 1610, 4);
INSERT INTO 'dancesstepsmap' VALUES (1489, 1611, 1);
INSERT INTO 'dancesstepsmap' VALUES (1490, 1612, 1);
INSERT INTO 'dancesstepsmap' VALUES (1491, 1613, 1);
INSERT INTO 'dancesstepsmap' VALUES (1492, 1614, 4);
INSERT INTO 'dancesstepsmap' VALUES (1493, 1615, 4);
INSERT INTO 'dancesstepsmap' VALUES (1494, 1616, 1);
INSERT INTO 'dancesstepsmap' VALUES (1495, 1617, 4);
INSERT INTO 'dancesstepsmap' VALUES (1496, 1618, 4);
INSERT INTO 'dancesstepsmap' VALUES (1497, 1619, 1);
INSERT INTO 'dancesstepsmap' VALUES (1498, 1620, 1);
INSERT INTO 'dancesstepsmap' VALUES (1499, 1621, 4);
INSERT INTO 'dancesstepsmap' VALUES (1500, 1622, 1);
INSERT INTO 'dancesstepsmap' VALUES (1501, 1623, 1);
INSERT INTO 'dancesstepsmap' VALUES (1502, 1624, 1);
INSERT INTO 'dancesstepsmap' VALUES (1503, 1625, 1);
INSERT INTO 'dancesstepsmap' VALUES (1504, 1626, 1);
INSERT INTO 'dancesstepsmap' VALUES (1505, 1627, 1);
INSERT INTO 'dancesstepsmap' VALUES (1506, 1628, 1);
INSERT INTO 'dancesstepsmap' VALUES (1507, 1629, 1);
INSERT INTO 'dancesstepsmap' VALUES (1508, 1631, 1);
INSERT INTO 'dancesstepsmap' VALUES (1509, 1632, 1);
INSERT INTO 'dancesstepsmap' VALUES (1510, 1634, 1);
INSERT INTO 'dancesstepsmap' VALUES (1511, 1635, 1);
INSERT INTO 'dancesstepsmap' VALUES (1512, 1636, 1);
INSERT INTO 'dancesstepsmap' VALUES (1513, 1637, 4);
INSERT INTO 'dancesstepsmap' VALUES (1514, 1638, 1);
INSERT INTO 'dancesstepsmap' VALUES (1515, 1639, 1);
INSERT INTO 'dancesstepsmap' VALUES (1516, 1640, 4);
INSERT INTO 'dancesstepsmap' VALUES (1517, 1641, 1);
INSERT INTO 'dancesstepsmap' VALUES (1518, 1642, 1);
INSERT INTO 'dancesstepsmap' VALUES (1519, 1643, 1);
INSERT INTO 'dancesstepsmap' VALUES (1520, 1644, 4);
INSERT INTO 'dancesstepsmap' VALUES (1521, 1645, 1);
INSERT INTO 'dancesstepsmap' VALUES (1522, 1647, 1);
INSERT INTO 'dancesstepsmap' VALUES (1523, 1648, 4);
INSERT INTO 'dancesstepsmap' VALUES (1524, 1649, 4);
INSERT INTO 'dancesstepsmap' VALUES (1525, 1650, 1);
INSERT INTO 'dancesstepsmap' VALUES (1526, 1651, 4);
INSERT INTO 'dancesstepsmap' VALUES (1527, 1652, 1);
INSERT INTO 'dancesstepsmap' VALUES (1528, 1653, 1);
INSERT INTO 'dancesstepsmap' VALUES (1529, 1654, 4);
INSERT INTO 'dancesstepsmap' VALUES (1530, 1655, 1);
INSERT INTO 'dancesstepsmap' VALUES (1531, 1656, 4);
INSERT INTO 'dancesstepsmap' VALUES (1532, 1657, 4);
INSERT INTO 'dancesstepsmap' VALUES (1533, 1658, 1);
INSERT INTO 'dancesstepsmap' VALUES (1534, 1659, 1);
INSERT INTO 'dancesstepsmap' VALUES (1535, 1660, 4);
INSERT INTO 'dancesstepsmap' VALUES (1536, 1661, 1);
INSERT INTO 'dancesstepsmap' VALUES (1537, 1662, 1);
INSERT INTO 'dancesstepsmap' VALUES (1538, 1663, 1);
INSERT INTO 'dancesstepsmap' VALUES (1539, 1664, 1);
INSERT INTO 'dancesstepsmap' VALUES (1540, 1666, 1);
INSERT INTO 'dancesstepsmap' VALUES (1541, 1667, 1);
INSERT INTO 'dancesstepsmap' VALUES (1542, 1668, 1);
INSERT INTO 'dancesstepsmap' VALUES (1543, 1669, 1);
INSERT INTO 'dancesstepsmap' VALUES (1544, 1672, 4);
INSERT INTO 'dancesstepsmap' VALUES (1545, 1673, 1);
INSERT INTO 'dancesstepsmap' VALUES (1546, 1674, 1);
INSERT INTO 'dancesstepsmap' VALUES (1547, 1675, 1);
INSERT INTO 'dancesstepsmap' VALUES (1548, 1676, 1);
INSERT INTO 'dancesstepsmap' VALUES (1549, 1677, 4);
INSERT INTO 'dancesstepsmap' VALUES (1550, 1678, 1);
INSERT INTO 'dancesstepsmap' VALUES (1551, 1679, 4);
INSERT INTO 'dancesstepsmap' VALUES (1552, 1680, 1);
INSERT INTO 'dancesstepsmap' VALUES (1553, 1681, 1);
INSERT INTO 'dancesstepsmap' VALUES (1554, 1682, 1);
INSERT INTO 'dancesstepsmap' VALUES (1555, 1683, 1);
INSERT INTO 'dancesstepsmap' VALUES (1556, 1684, 1);
INSERT INTO 'dancesstepsmap' VALUES (1557, 1685, 1);
INSERT INTO 'dancesstepsmap' VALUES (10532, 9803, 2);
INSERT INTO 'dancesstepsmap' VALUES (10533, 8932, 1);
INSERT INTO 'dancesstepsmap' VALUES (10534, 8932, 2);
INSERT INTO 'dancesstepsmap' VALUES (10535, 9804, 1);
INSERT INTO 'dancesstepsmap' VALUES (10536, 9805, 1);
INSERT INTO 'dancesstepsmap' VALUES (10537, 9806, 1);
INSERT INTO 'dancesstepsmap' VALUES (10538, 9808, 1);
INSERT INTO 'dancesstepsmap' VALUES (10539, 9809, 3);
INSERT INTO 'dancesstepsmap' VALUES (10540, 9810, 2);
INSERT INTO 'dancesstepsmap' VALUES (10541, 9811, 4);
INSERT INTO 'dancesstepsmap' VALUES (10542, 9811, 5);
INSERT INTO 'dancesstepsmap' VALUES (10543, 4813, 5);
INSERT INTO 'dancesstepsmap' VALUES (10544, 9812, 1);
INSERT INTO 'dancesstepsmap' VALUES (10545, 9812, 2);
INSERT INTO 'dancesstepsmap' VALUES (10546, 9813, 4);
INSERT INTO 'dancesstepsmap' VALUES (10547, 9557, 2);
INSERT INTO 'dancesstepsmap' VALUES (10548, 9547, 1);
INSERT INTO 'dancesstepsmap' VALUES (10549, 9820, 1);
INSERT INTO 'dancesstepsmap' VALUES (10550, 9820, 2);
INSERT INTO 'dancesstepsmap' VALUES (10551, 9821, 5);
INSERT INTO 'dancesstepsmap' VALUES (10552, 9821, 4);
INSERT INTO 'dancesstepsmap' VALUES (10553, 9823, 1);
INSERT INTO 'dancesstepsmap' VALUES (1558, 1686, 1);
INSERT INTO 'dancesstepsmap' VALUES (1559, 1687, 4);
INSERT INTO 'dancesstepsmap' VALUES (1560, 1688, 4);
INSERT INTO 'dancesstepsmap' VALUES (1561, 1689, 4);
INSERT INTO 'dancesstepsmap' VALUES (1562, 1690, 1);
INSERT INTO 'dancesstepsmap' VALUES (1563, 1692, 1);
INSERT INTO 'dancesstepsmap' VALUES (1564, 1693, 4);
INSERT INTO 'dancesstepsmap' VALUES (1565, 1694, 1);
INSERT INTO 'dancesstepsmap' VALUES (1566, 1695, 1);
INSERT INTO 'dancesstepsmap' VALUES (1567, 1696, 4);
INSERT INTO 'dancesstepsmap' VALUES (1568, 1697, 4);
INSERT INTO 'dancesstepsmap' VALUES (1569, 1698, 1);
INSERT INTO 'dancesstepsmap' VALUES (1570, 1699, 1);
INSERT INTO 'dancesstepsmap' VALUES (1571, 1700, 1);
INSERT INTO 'dancesstepsmap' VALUES (1572, 1701, 1);
INSERT INTO 'dancesstepsmap' VALUES (1573, 1702, 1);
INSERT INTO 'dancesstepsmap' VALUES (1574, 1703, 4);
INSERT INTO 'dancesstepsmap' VALUES (1575, 1704, 1);
INSERT INTO 'dancesstepsmap' VALUES (1576, 1705, 4);
INSERT INTO 'dancesstepsmap' VALUES (1577, 1706, 1);
INSERT INTO 'dancesstepsmap' VALUES (1578, 1707, 1);
INSERT INTO 'dancesstepsmap' VALUES (1579, 1708, 1);
INSERT INTO 'dancesstepsmap' VALUES (1580, 1709, 1);
INSERT INTO 'dancesstepsmap' VALUES (1581, 1710, 1);
INSERT INTO 'dancesstepsmap' VALUES (1582, 1711, 4);
INSERT INTO 'dancesstepsmap' VALUES (1583, 1712, 1);
INSERT INTO 'dancesstepsmap' VALUES (1584, 1713, 1);
INSERT INTO 'dancesstepsmap' VALUES (1585, 1714, 4);
INSERT INTO 'dancesstepsmap' VALUES (1586, 1715, 1);
INSERT INTO 'dancesstepsmap' VALUES (1587, 1716, 4);
INSERT INTO 'dancesstepsmap' VALUES (1588, 1717, 1);
INSERT INTO 'dancesstepsmap' VALUES (1589, 1718, 4);
INSERT INTO 'dancesstepsmap' VALUES (1590, 1719, 1);
INSERT INTO 'dancesstepsmap' VALUES (1591, 1720, 1);
INSERT INTO 'dancesstepsmap' VALUES (1592, 1721, 4);
INSERT INTO 'dancesstepsmap' VALUES (1593, 1722, 1);
INSERT INTO 'dancesstepsmap' VALUES (1594, 1723, 1);
INSERT INTO 'dancesstepsmap' VALUES (1595, 1724, 1);
INSERT INTO 'dancesstepsmap' VALUES (1596, 1725, 4);
INSERT INTO 'dancesstepsmap' VALUES (1597, 1726, 1);
INSERT INTO 'dancesstepsmap' VALUES (1598, 1727, 1);
INSERT INTO 'dancesstepsmap' VALUES (1599, 1728, 1);
INSERT INTO 'dancesstepsmap' VALUES (1600, 1729, 4);
INSERT INTO 'dancesstepsmap' VALUES (1601, 1730, 1);
INSERT INTO 'dancesstepsmap' VALUES (1602, 1731, 1);
INSERT INTO 'dancesstepsmap' VALUES (1603, 1732, 4);
INSERT INTO 'dancesstepsmap' VALUES (1604, 1733, 1);
INSERT INTO 'dancesstepsmap' VALUES (1605, 1734, 1);
INSERT INTO 'dancesstepsmap' VALUES (1606, 1736, 4);
INSERT INTO 'dancesstepsmap' VALUES (1607, 1737, 4);
INSERT INTO 'dancesstepsmap' VALUES (1608, 1738, 4);
INSERT INTO 'dancesstepsmap' VALUES (1609, 1739, 1);
INSERT INTO 'dancesstepsmap' VALUES (1610, 1740, 1);
INSERT INTO 'dancesstepsmap' VALUES (1611, 1741, 4);
INSERT INTO 'dancesstepsmap' VALUES (1612, 1742, 4);
INSERT INTO 'dancesstepsmap' VALUES (1613, 1743, 1);
INSERT INTO 'dancesstepsmap' VALUES (1614, 1745, 1);
INSERT INTO 'dancesstepsmap' VALUES (1615, 1746, 1);
INSERT INTO 'dancesstepsmap' VALUES (1616, 1747, 1);
INSERT INTO 'dancesstepsmap' VALUES (1617, 1751, 1);
INSERT INTO 'dancesstepsmap' VALUES (1618, 1752, 1);
INSERT INTO 'dancesstepsmap' VALUES (1619, 1753, 1);
INSERT INTO 'dancesstepsmap' VALUES (1620, 1754, 4);
INSERT INTO 'dancesstepsmap' VALUES (1621, 1755, 4);
INSERT INTO 'dancesstepsmap' VALUES (1622, 1756, 4);
INSERT INTO 'dancesstepsmap' VALUES (1623, 1757, 4);
INSERT INTO 'dancesstepsmap' VALUES (1624, 1758, 4);
INSERT INTO 'dancesstepsmap' VALUES (1625, 1759, 1);
INSERT INTO 'dancesstepsmap' VALUES (1626, 1760, 1);
INSERT INTO 'dancesstepsmap' VALUES (1627, 1761, 1);
INSERT INTO 'dancesstepsmap' VALUES (1628, 1762, 1);
INSERT INTO 'dancesstepsmap' VALUES (1629, 1763, 1);
INSERT INTO 'dancesstepsmap' VALUES (1630, 1764, 1);
INSERT INTO 'dancesstepsmap' VALUES (1631, 1765, 1);
INSERT INTO 'dancesstepsmap' VALUES (1632, 1766, 4);
INSERT INTO 'dancesstepsmap' VALUES (1633, 1767, 4);
INSERT INTO 'dancesstepsmap' VALUES (1634, 1768, 4);
INSERT INTO 'dancesstepsmap' VALUES (1635, 1769, 1);
INSERT INTO 'dancesstepsmap' VALUES (1636, 1770, 1);
INSERT INTO 'dancesstepsmap' VALUES (1637, 1773, 4);
INSERT INTO 'dancesstepsmap' VALUES (1638, 1774, 1);
INSERT INTO 'dancesstepsmap' VALUES (1639, 1775, 4);
INSERT INTO 'dancesstepsmap' VALUES (1640, 1776, 4);
INSERT INTO 'dancesstepsmap' VALUES (1641, 1777, 4);
INSERT INTO 'dancesstepsmap' VALUES (1642, 1778, 4);
INSERT INTO 'dancesstepsmap' VALUES (1643, 1780, 1);
INSERT INTO 'dancesstepsmap' VALUES (1644, 1781, 1);
INSERT INTO 'dancesstepsmap' VALUES (1645, 1782, 1);
INSERT INTO 'dancesstepsmap' VALUES (1646, 1783, 1);
INSERT INTO 'dancesstepsmap' VALUES (1647, 1785, 4);
INSERT INTO 'dancesstepsmap' VALUES (1648, 1786, 1);
INSERT INTO 'dancesstepsmap' VALUES (1649, 1787, 1);
INSERT INTO 'dancesstepsmap' VALUES (10554, 9823, 3);
INSERT INTO 'dancesstepsmap' VALUES (10555, 9824, 5);
INSERT INTO 'dancesstepsmap' VALUES (10556, 9824, 4);
INSERT INTO 'dancesstepsmap' VALUES (10557, 9824, 10);
INSERT INTO 'dancesstepsmap' VALUES (10558, 9824, 9);
INSERT INTO 'dancesstepsmap' VALUES (10559, 9824, 1);
INSERT INTO 'dancesstepsmap' VALUES (10560, 9824, 2);
INSERT INTO 'dancesstepsmap' VALUES (10561, 9825, 2);
INSERT INTO 'dancesstepsmap' VALUES (10562, 9825, 1);
INSERT INTO 'dancesstepsmap' VALUES (10563, 9826, 3);
INSERT INTO 'dancesstepsmap' VALUES (10564, 9826, 1);
INSERT INTO 'dancesstepsmap' VALUES (10565, 9827, 1);
INSERT INTO 'dancesstepsmap' VALUES (10566, 9828, 3);
INSERT INTO 'dancesstepsmap' VALUES (10567, 9828, 1);
INSERT INTO 'dancesstepsmap' VALUES (10568, 9829, 1);
INSERT INTO 'dancesstepsmap' VALUES (10569, 9829, 3);
INSERT INTO 'dancesstepsmap' VALUES (10570, 9830, 4);
INSERT INTO 'dancesstepsmap' VALUES (10571, 9831, 1);
INSERT INTO 'dancesstepsmap' VALUES (10572, 9832, 1);
INSERT INTO 'dancesstepsmap' VALUES (10573, 9833, 1);
INSERT INTO 'dancesstepsmap' VALUES (10574, 9833, 2);
INSERT INTO 'dancesstepsmap' VALUES (10575, 8962, 5);
INSERT INTO 'dancesstepsmap' VALUES (10577, 6910, 2);
INSERT INTO 'dancesstepsmap' VALUES (10578, 9834, 3);
INSERT INTO 'dancesstepsmap' VALUES (10579, 9834, 1);
INSERT INTO 'dancesstepsmap' VALUES (10580, 9835, 1);
INSERT INTO 'dancesstepsmap' VALUES (10581, 9835, 2);
INSERT INTO 'dancesstepsmap' VALUES (10582, 9837, 1);
INSERT INTO 'dancesstepsmap' VALUES (10583, 9837, 2);
INSERT INTO 'dancesstepsmap' VALUES (10584, 9838, 5);
INSERT INTO 'dancesstepsmap' VALUES (10585, 9838, 4);
INSERT INTO 'dancesstepsmap' VALUES (10586, 9839, 1);
INSERT INTO 'dancesstepsmap' VALUES (10587, 9840, 2);
INSERT INTO 'dancesstepsmap' VALUES (10588, 9840, 1);
INSERT INTO 'dancesstepsmap' VALUES (10589, 9840, 3);
INSERT INTO 'dancesstepsmap' VALUES (10590, 9170, 5);
INSERT INTO 'dancesstepsmap' VALUES (10591, 9170, 4);
INSERT INTO 'dancesstepsmap' VALUES (10592, 9842, 2);
INSERT INTO 'dancesstepsmap' VALUES (10593, 9842, 1);
INSERT INTO 'dancesstepsmap' VALUES (10594, 9843, 1);
INSERT INTO 'dancesstepsmap' VALUES (10595, 9844, 1);
INSERT INTO 'dancesstepsmap' VALUES (16996, 14429, 1);
INSERT INTO 'dancesstepsmap' VALUES (16997, 14429, 3);
INSERT INTO 'dancesstepsmap' VALUES (16998, 14429, 2);
INSERT INTO 'dancesstepsmap' VALUES (1650, 1788, 1);
INSERT INTO 'dancesstepsmap' VALUES (1652, 1790, 4);
INSERT INTO 'dancesstepsmap' VALUES (1653, 1792, 1);
INSERT INTO 'dancesstepsmap' VALUES (1654, 1793, 1);
INSERT INTO 'dancesstepsmap' VALUES (1655, 1795, 1);
INSERT INTO 'dancesstepsmap' VALUES (1656, 1796, 1);
INSERT INTO 'dancesstepsmap' VALUES (1657, 1797, 1);
INSERT INTO 'dancesstepsmap' VALUES (1658, 1798, 4);
INSERT INTO 'dancesstepsmap' VALUES (1659, 1799, 1);
INSERT INTO 'dancesstepsmap' VALUES (23133, 18246, 1);
INSERT INTO 'dancesstepsmap' VALUES (1661, 1801, 4);
INSERT INTO 'dancesstepsmap' VALUES (1662, 1803, 1);
INSERT INTO 'dancesstepsmap' VALUES (1663, 1804, 4);
INSERT INTO 'dancesstepsmap' VALUES (1664, 1806, 4);
INSERT INTO 'dancesstepsmap' VALUES (1665, 1807, 4);
INSERT INTO 'dancesstepsmap' VALUES (1666, 1808, 1);
INSERT INTO 'dancesstepsmap' VALUES (1667, 1809, 4);
INSERT INTO 'dancesstepsmap' VALUES (1668, 1810, 1);
INSERT INTO 'dancesstepsmap' VALUES (1669, 1811, 1);
INSERT INTO 'dancesstepsmap' VALUES (1670, 1812, 1);
INSERT INTO 'dancesstepsmap' VALUES (1671, 1814, 1);
INSERT INTO 'dancesstepsmap' VALUES (1672, 1815, 4);
INSERT INTO 'dancesstepsmap' VALUES (1673, 1816, 1);
INSERT INTO 'dancesstepsmap' VALUES (1674, 1817, 1);
INSERT INTO 'dancesstepsmap' VALUES (1675, 1818, 4);
INSERT INTO 'dancesstepsmap' VALUES (1676, 1819, 1);
INSERT INTO 'dancesstepsmap' VALUES (1677, 1820, 1);
INSERT INTO 'dancesstepsmap' VALUES (1678, 1821, 1);
INSERT INTO 'dancesstepsmap' VALUES (1679, 1822, 1);
INSERT INTO 'dancesstepsmap' VALUES (1680, 1824, 1);
INSERT INTO 'dancesstepsmap' VALUES (1681, 1825, 1);
INSERT INTO 'dancesstepsmap' VALUES (1682, 1826, 1);
INSERT INTO 'dancesstepsmap' VALUES (1683, 1827, 1);
INSERT INTO 'dancesstepsmap' VALUES (1684, 1828, 1);
INSERT INTO 'dancesstepsmap' VALUES (1685, 1829, 1);
INSERT INTO 'dancesstepsmap' VALUES (1686, 1830, 1);
INSERT INTO 'dancesstepsmap' VALUES (1687, 1831, 4);
INSERT INTO 'dancesstepsmap' VALUES (1688, 1832, 4);
INSERT INTO 'dancesstepsmap' VALUES (1689, 1833, 1);
INSERT INTO 'dancesstepsmap' VALUES (1690, 1834, 1);
INSERT INTO 'dancesstepsmap' VALUES (1691, 1835, 1);
INSERT INTO 'dancesstepsmap' VALUES (1692, 1836, 4);
INSERT INTO 'dancesstepsmap' VALUES (1693, 1837, 1);
INSERT INTO 'dancesstepsmap' VALUES (1694, 1838, 4);
INSERT INTO 'dancesstepsmap' VALUES (1695, 1839, 4);
INSERT INTO 'dancesstepsmap' VALUES (1696, 1840, 4);
INSERT INTO 'dancesstepsmap' VALUES (1697, 1841, 1);
INSERT INTO 'dancesstepsmap' VALUES (1698, 1842, 1);
INSERT INTO 'dancesstepsmap' VALUES (1699, 1843, 4);
INSERT INTO 'dancesstepsmap' VALUES (1700, 1844, 1);
INSERT INTO 'dancesstepsmap' VALUES (1701, 1845, 1);
INSERT INTO 'dancesstepsmap' VALUES (1702, 1846, 4);
INSERT INTO 'dancesstepsmap' VALUES (1703, 1847, 1);
INSERT INTO 'dancesstepsmap' VALUES (1704, 1848, 1);
INSERT INTO 'dancesstepsmap' VALUES (1705, 1849, 1);
INSERT INTO 'dancesstepsmap' VALUES (1706, 1850, 4);
INSERT INTO 'dancesstepsmap' VALUES (1707, 1851, 1);
INSERT INTO 'dancesstepsmap' VALUES (1708, 1852, 4);
INSERT INTO 'dancesstepsmap' VALUES (1709, 1853, 1);
INSERT INTO 'dancesstepsmap' VALUES (1710, 1854, 4);
INSERT INTO 'dancesstepsmap' VALUES (1711, 1855, 1);
INSERT INTO 'dancesstepsmap' VALUES (1712, 1856, 4);
INSERT INTO 'dancesstepsmap' VALUES (1713, 1857, 4);
INSERT INTO 'dancesstepsmap' VALUES (1714, 1858, 4);
INSERT INTO 'dancesstepsmap' VALUES (1715, 1859, 4);
INSERT INTO 'dancesstepsmap' VALUES (1716, 1860, 4);
INSERT INTO 'dancesstepsmap' VALUES (1717, 1861, 1);
INSERT INTO 'dancesstepsmap' VALUES (1718, 1863, 4);
INSERT INTO 'dancesstepsmap' VALUES (1719, 1864, 1);
INSERT INTO 'dancesstepsmap' VALUES (1720, 1865, 1);
INSERT INTO 'dancesstepsmap' VALUES (1721, 1866, 1);
INSERT INTO 'dancesstepsmap' VALUES (1722, 1868, 4);
INSERT INTO 'dancesstepsmap' VALUES (1723, 1869, 1);
INSERT INTO 'dancesstepsmap' VALUES (1724, 1870, 1);
INSERT INTO 'dancesstepsmap' VALUES (1725, 1871, 4);
INSERT INTO 'dancesstepsmap' VALUES (1726, 1873, 4);
INSERT INTO 'dancesstepsmap' VALUES (1727, 1874, 1);
INSERT INTO 'dancesstepsmap' VALUES (1728, 1875, 1);
INSERT INTO 'dancesstepsmap' VALUES (1729, 1876, 4);
INSERT INTO 'dancesstepsmap' VALUES (1730, 1877, 4);
INSERT INTO 'dancesstepsmap' VALUES (1731, 1878, 1);
INSERT INTO 'dancesstepsmap' VALUES (1732, 1879, 1);
INSERT INTO 'dancesstepsmap' VALUES (1733, 1880, 1);
INSERT INTO 'dancesstepsmap' VALUES (1734, 1881, 1);
INSERT INTO 'dancesstepsmap' VALUES (1735, 1882, 1);
INSERT INTO 'dancesstepsmap' VALUES (1736, 1883, 4);
INSERT INTO 'dancesstepsmap' VALUES (1737, 1884, 1);
INSERT INTO 'dancesstepsmap' VALUES (1738, 1885, 1);
INSERT INTO 'dancesstepsmap' VALUES (1739, 1886, 1);
INSERT INTO 'dancesstepsmap' VALUES (1740, 1887, 1);
INSERT INTO 'dancesstepsmap' VALUES (1741, 1889, 1);
INSERT INTO 'dancesstepsmap' VALUES (1742, 1890, 4);
INSERT INTO 'dancesstepsmap' VALUES (10596, 9845, 1);
INSERT INTO 'dancesstepsmap' VALUES (10597, 9845, 2);
INSERT INTO 'dancesstepsmap' VALUES (10600, 9847, 2);
INSERT INTO 'dancesstepsmap' VALUES (10601, 9847, 1);
INSERT INTO 'dancesstepsmap' VALUES (10602, 9848, 4);
INSERT INTO 'dancesstepsmap' VALUES (10603, 9849, 4);
INSERT INTO 'dancesstepsmap' VALUES (10604, 9850, 1);
INSERT INTO 'dancesstepsmap' VALUES (10605, 9852, 1);
INSERT INTO 'dancesstepsmap' VALUES (10606, 9852, 3);
INSERT INTO 'dancesstepsmap' VALUES (10607, 9853, 5);
INSERT INTO 'dancesstepsmap' VALUES (10608, 9853, 4);
INSERT INTO 'dancesstepsmap' VALUES (10609, 9854, 3);
INSERT INTO 'dancesstepsmap' VALUES (10610, 9854, 1);
INSERT INTO 'dancesstepsmap' VALUES (10611, 9855, 1);
INSERT INTO 'dancesstepsmap' VALUES (10612, 9855, 2);
INSERT INTO 'dancesstepsmap' VALUES (10613, 9856, 3);
INSERT INTO 'dancesstepsmap' VALUES (10614, 9856, 1);
INSERT INTO 'dancesstepsmap' VALUES (10617, 8515, 2);
INSERT INTO 'dancesstepsmap' VALUES (10618, 9858, 4);
INSERT INTO 'dancesstepsmap' VALUES (10619, 9859, 1);
INSERT INTO 'dancesstepsmap' VALUES (10620, 9860, 1);
INSERT INTO 'dancesstepsmap' VALUES (10622, 9863, 2);
INSERT INTO 'dancesstepsmap' VALUES (10623, 9863, 1);
INSERT INTO 'dancesstepsmap' VALUES (10624, 9864, 4);
INSERT INTO 'dancesstepsmap' VALUES (10625, 9866, 2);
INSERT INTO 'dancesstepsmap' VALUES (10626, 9866, 1);
INSERT INTO 'dancesstepsmap' VALUES (10627, 9866, 3);
INSERT INTO 'dancesstepsmap' VALUES (10628, 9867, 1);
INSERT INTO 'dancesstepsmap' VALUES (10629, 9869, 1);
INSERT INTO 'dancesstepsmap' VALUES (10630, 9869, 3);
INSERT INTO 'dancesstepsmap' VALUES (10631, 9870, 2);
INSERT INTO 'dancesstepsmap' VALUES (10632, 9870, 1);
INSERT INTO 'dancesstepsmap' VALUES (10633, 9871, 1);
INSERT INTO 'dancesstepsmap' VALUES (10634, 9871, 3);
INSERT INTO 'dancesstepsmap' VALUES (10635, 9872, 6);
INSERT INTO 'dancesstepsmap' VALUES (10636, 9872, 4);
INSERT INTO 'dancesstepsmap' VALUES (10637, 9753, 1);
INSERT INTO 'dancesstepsmap' VALUES (16999, 14430, 1);
INSERT INTO 'dancesstepsmap' VALUES (17000, 14430, 2);
INSERT INTO 'dancesstepsmap' VALUES (17004, 14432, 5);
INSERT INTO 'dancesstepsmap' VALUES (17005, 14432, 4);
INSERT INTO 'dancesstepsmap' VALUES (17006, 14432, 2);
INSERT INTO 'dancesstepsmap' VALUES (1743, 1891, 1);
INSERT INTO 'dancesstepsmap' VALUES (1744, 1892, 1);
INSERT INTO 'dancesstepsmap' VALUES (1745, 1893, 4);
INSERT INTO 'dancesstepsmap' VALUES (1746, 1894, 1);
INSERT INTO 'dancesstepsmap' VALUES (1747, 1895, 1);
INSERT INTO 'dancesstepsmap' VALUES (1748, 1896, 1);
INSERT INTO 'dancesstepsmap' VALUES (1749, 1897, 1);
INSERT INTO 'dancesstepsmap' VALUES (1750, 1898, 4);
INSERT INTO 'dancesstepsmap' VALUES (1751, 1899, 4);
INSERT INTO 'dancesstepsmap' VALUES (1752, 1900, 4);
INSERT INTO 'dancesstepsmap' VALUES (1753, 1902, 1);
INSERT INTO 'dancesstepsmap' VALUES (1754, 1903, 4);
INSERT INTO 'dancesstepsmap' VALUES (1755, 1904, 1);
INSERT INTO 'dancesstepsmap' VALUES (1756, 1905, 1);
INSERT INTO 'dancesstepsmap' VALUES (1757, 1906, 1);
INSERT INTO 'dancesstepsmap' VALUES (1758, 1907, 4);
INSERT INTO 'dancesstepsmap' VALUES (1759, 1908, 1);
INSERT INTO 'dancesstepsmap' VALUES (1760, 1909, 1);
INSERT INTO 'dancesstepsmap' VALUES (1761, 1910, 4);
INSERT INTO 'dancesstepsmap' VALUES (1762, 1912, 1);
INSERT INTO 'dancesstepsmap' VALUES (1763, 1915, 4);
INSERT INTO 'dancesstepsmap' VALUES (1764, 1916, 4);
INSERT INTO 'dancesstepsmap' VALUES (1765, 1917, 4);
INSERT INTO 'dancesstepsmap' VALUES (1766, 1918, 1);
INSERT INTO 'dancesstepsmap' VALUES (1767, 1919, 1);
INSERT INTO 'dancesstepsmap' VALUES (1768, 1920, 4);
INSERT INTO 'dancesstepsmap' VALUES (1769, 1921, 1);
INSERT INTO 'dancesstepsmap' VALUES (1770, 1922, 1);
INSERT INTO 'dancesstepsmap' VALUES (1771, 1923, 1);
INSERT INTO 'dancesstepsmap' VALUES (1772, 1924, 1);
INSERT INTO 'dancesstepsmap' VALUES (1773, 1925, 1);
INSERT INTO 'dancesstepsmap' VALUES (1774, 1926, 4);
INSERT INTO 'dancesstepsmap' VALUES (1775, 1927, 1);
INSERT INTO 'dancesstepsmap' VALUES (1776, 1928, 1);
INSERT INTO 'dancesstepsmap' VALUES (1777, 1929, 4);
INSERT INTO 'dancesstepsmap' VALUES (1778, 1930, 1);
INSERT INTO 'dancesstepsmap' VALUES (1779, 1931, 1);
INSERT INTO 'dancesstepsmap' VALUES (1780, 1932, 4);
INSERT INTO 'dancesstepsmap' VALUES (1781, 1933, 4);
INSERT INTO 'dancesstepsmap' VALUES (1782, 1934, 1);
INSERT INTO 'dancesstepsmap' VALUES (1783, 1935, 4);
INSERT INTO 'dancesstepsmap' VALUES (1784, 1937, 1);
INSERT INTO 'dancesstepsmap' VALUES (1786, 1939, 4);
INSERT INTO 'dancesstepsmap' VALUES (1787, 1940, 1);
INSERT INTO 'dancesstepsmap' VALUES (1788, 1941, 1);
INSERT INTO 'dancesstepsmap' VALUES (1789, 1943, 4);
INSERT INTO 'dancesstepsmap' VALUES (1790, 1944, 4);
INSERT INTO 'dancesstepsmap' VALUES (1791, 1945, 1);
INSERT INTO 'dancesstepsmap' VALUES (1792, 1946, 1);
INSERT INTO 'dancesstepsmap' VALUES (1793, 1947, 1);
INSERT INTO 'dancesstepsmap' VALUES (1794, 1948, 4);
INSERT INTO 'dancesstepsmap' VALUES (1795, 1949, 1);
INSERT INTO 'dancesstepsmap' VALUES (1796, 1950, 1);
INSERT INTO 'dancesstepsmap' VALUES (1797, 1951, 4);
INSERT INTO 'dancesstepsmap' VALUES (1798, 1952, 4);
INSERT INTO 'dancesstepsmap' VALUES (1799, 1953, 1);
INSERT INTO 'dancesstepsmap' VALUES (1800, 1954, 1);
INSERT INTO 'dancesstepsmap' VALUES (1801, 1955, 1);
INSERT INTO 'dancesstepsmap' VALUES (1802, 1956, 4);
INSERT INTO 'dancesstepsmap' VALUES (1803, 1957, 4);
INSERT INTO 'dancesstepsmap' VALUES (1804, 1958, 1);
INSERT INTO 'dancesstepsmap' VALUES (1805, 1959, 4);
INSERT INTO 'dancesstepsmap' VALUES (1806, 1960, 1);
INSERT INTO 'dancesstepsmap' VALUES (1807, 1961, 1);
INSERT INTO 'dancesstepsmap' VALUES (1808, 1963, 4);
INSERT INTO 'dancesstepsmap' VALUES (1809, 1964, 4);
INSERT INTO 'dancesstepsmap' VALUES (1810, 1965, 4);
INSERT INTO 'dancesstepsmap' VALUES (1811, 1966, 1);
INSERT INTO 'dancesstepsmap' VALUES (1812, 1967, 4);
INSERT INTO 'dancesstepsmap' VALUES (1813, 1968, 4);
INSERT INTO 'dancesstepsmap' VALUES (1814, 1969, 1);
INSERT INTO 'dancesstepsmap' VALUES (1815, 1970, 1);
INSERT INTO 'dancesstepsmap' VALUES (1816, 1971, 1);
INSERT INTO 'dancesstepsmap' VALUES (1817, 1972, 1);
INSERT INTO 'dancesstepsmap' VALUES (1818, 1973, 1);
INSERT INTO 'dancesstepsmap' VALUES (1819, 1974, 1);
INSERT INTO 'dancesstepsmap' VALUES (1820, 1975, 1);
INSERT INTO 'dancesstepsmap' VALUES (1821, 1976, 1);
INSERT INTO 'dancesstepsmap' VALUES (1822, 1977, 1);
INSERT INTO 'dancesstepsmap' VALUES (1823, 1978, 4);
INSERT INTO 'dancesstepsmap' VALUES (1824, 1979, 4);
INSERT INTO 'dancesstepsmap' VALUES (1825, 1980, 4);
INSERT INTO 'dancesstepsmap' VALUES (1826, 1981, 1);
INSERT INTO 'dancesstepsmap' VALUES (1827, 1982, 4);
INSERT INTO 'dancesstepsmap' VALUES (1828, 1983, 1);
INSERT INTO 'dancesstepsmap' VALUES (1829, 1984, 1);
INSERT INTO 'dancesstepsmap' VALUES (1830, 1985, 1);
INSERT INTO 'dancesstepsmap' VALUES (1831, 1986, 1);
INSERT INTO 'dancesstepsmap' VALUES (1832, 1987, 4);
INSERT INTO 'dancesstepsmap' VALUES (1833, 1988, 4);
INSERT INTO 'dancesstepsmap' VALUES (1834, 1989, 1);
INSERT INTO 'dancesstepsmap' VALUES (10638, 9873, 6);
INSERT INTO 'dancesstepsmap' VALUES (10639, 9873, 4);
INSERT INTO 'dancesstepsmap' VALUES (10640, 9874, 4);
INSERT INTO 'dancesstepsmap' VALUES (10641, 9875, 5);
INSERT INTO 'dancesstepsmap' VALUES (10642, 9875, 4);
INSERT INTO 'dancesstepsmap' VALUES (10643, 9876, 4);
INSERT INTO 'dancesstepsmap' VALUES (10644, 9877, 4);
INSERT INTO 'dancesstepsmap' VALUES (10645, 9878, 4);
INSERT INTO 'dancesstepsmap' VALUES (10646, 9880, 1);
INSERT INTO 'dancesstepsmap' VALUES (10647, 9881, 1);
INSERT INTO 'dancesstepsmap' VALUES (10648, 9881, 4);
INSERT INTO 'dancesstepsmap' VALUES (10649, 9881, 2);
INSERT INTO 'dancesstepsmap' VALUES (10650, 9882, 4);
INSERT INTO 'dancesstepsmap' VALUES (10651, 9883, 3);
INSERT INTO 'dancesstepsmap' VALUES (10652, 9884, 2);
INSERT INTO 'dancesstepsmap' VALUES (10653, 9884, 1);
INSERT INTO 'dancesstepsmap' VALUES (10654, 9884, 3);
INSERT INTO 'dancesstepsmap' VALUES (10655, 9885, 1);
INSERT INTO 'dancesstepsmap' VALUES (10656, 9885, 3);
INSERT INTO 'dancesstepsmap' VALUES (10657, 9886, 5);
INSERT INTO 'dancesstepsmap' VALUES (10658, 9886, 4);
INSERT INTO 'dancesstepsmap' VALUES (10659, 9887, 2);
INSERT INTO 'dancesstepsmap' VALUES (10660, 9887, 1);
INSERT INTO 'dancesstepsmap' VALUES (10661, 9888, 1);
INSERT INTO 'dancesstepsmap' VALUES (10662, 9889, 2);
INSERT INTO 'dancesstepsmap' VALUES (10663, 9889, 3);
INSERT INTO 'dancesstepsmap' VALUES (10664, 9889, 1);
INSERT INTO 'dancesstepsmap' VALUES (10665, 9890, 1);
INSERT INTO 'dancesstepsmap' VALUES (10666, 9891, 5);
INSERT INTO 'dancesstepsmap' VALUES (10667, 9891, 4);
INSERT INTO 'dancesstepsmap' VALUES (10668, 9892, 1);
INSERT INTO 'dancesstepsmap' VALUES (10669, 9893, 3);
INSERT INTO 'dancesstepsmap' VALUES (10670, 9893, 1);
INSERT INTO 'dancesstepsmap' VALUES (10671, 9894, 1);
INSERT INTO 'dancesstepsmap' VALUES (10672, 9896, 2);
INSERT INTO 'dancesstepsmap' VALUES (10673, 9896, 3);
INSERT INTO 'dancesstepsmap' VALUES (10674, 9896, 1);
INSERT INTO 'dancesstepsmap' VALUES (10675, 9897, 4);
INSERT INTO 'dancesstepsmap' VALUES (10676, 9897, 5);
INSERT INTO 'dancesstepsmap' VALUES (10677, 9899, 3);
INSERT INTO 'dancesstepsmap' VALUES (10678, 9900, 3);
INSERT INTO 'dancesstepsmap' VALUES (10679, 9900, 1);
INSERT INTO 'dancesstepsmap' VALUES (10680, 9900, 2);
INSERT INTO 'dancesstepsmap' VALUES (17001, 14431, 1);
INSERT INTO 'dancesstepsmap' VALUES (17002, 14431, 2);
INSERT INTO 'dancesstepsmap' VALUES (17003, 14431, 3);
INSERT INTO 'dancesstepsmap' VALUES (17007, 14432, 1);
INSERT INTO 'dancesstepsmap' VALUES (17008, 14432, 3);
INSERT INTO 'dancesstepsmap' VALUES (1785, 1938, 2);
INSERT INTO 'dancesstepsmap' VALUES (1835, 1990, 4);
INSERT INTO 'dancesstepsmap' VALUES (1836, 1991, 4);
INSERT INTO 'dancesstepsmap' VALUES (1837, 1992, 1);
INSERT INTO 'dancesstepsmap' VALUES (1838, 1993, 1);
INSERT INTO 'dancesstepsmap' VALUES (1839, 1994, 1);
INSERT INTO 'dancesstepsmap' VALUES (1840, 1995, 4);
INSERT INTO 'dancesstepsmap' VALUES (1841, 1996, 1);
INSERT INTO 'dancesstepsmap' VALUES (1842, 1997, 1);
INSERT INTO 'dancesstepsmap' VALUES (1843, 1998, 1);
INSERT INTO 'dancesstepsmap' VALUES (1844, 1999, 1);
INSERT INTO 'dancesstepsmap' VALUES (1845, 2000, 1);
INSERT INTO 'dancesstepsmap' VALUES (1846, 2002, 1);
INSERT INTO 'dancesstepsmap' VALUES (1847, 2003, 1);
INSERT INTO 'dancesstepsmap' VALUES (1848, 2004, 1);
INSERT INTO 'dancesstepsmap' VALUES (1849, 2005, 1);
INSERT INTO 'dancesstepsmap' VALUES (1850, 2006, 1);
INSERT INTO 'dancesstepsmap' VALUES (1851, 2007, 4);
INSERT INTO 'dancesstepsmap' VALUES (1852, 2008, 4);
INSERT INTO 'dancesstepsmap' VALUES (1853, 2009, 1);
INSERT INTO 'dancesstepsmap' VALUES (1854, 2010, 1);
INSERT INTO 'dancesstepsmap' VALUES (1855, 2011, 1);
INSERT INTO 'dancesstepsmap' VALUES (1856, 2012, 1);
INSERT INTO 'dancesstepsmap' VALUES (1857, 2013, 1);
INSERT INTO 'dancesstepsmap' VALUES (1858, 2014, 4);
INSERT INTO 'dancesstepsmap' VALUES (1859, 2015, 1);
INSERT INTO 'dancesstepsmap' VALUES (1860, 2016, 4);
INSERT INTO 'dancesstepsmap' VALUES (1861, 2017, 4);
INSERT INTO 'dancesstepsmap' VALUES (1862, 2018, 1);
INSERT INTO 'dancesstepsmap' VALUES (1863, 2019, 1);
INSERT INTO 'dancesstepsmap' VALUES (1864, 2020, 1);
INSERT INTO 'dancesstepsmap' VALUES (1865, 2021, 4);
INSERT INTO 'dancesstepsmap' VALUES (1866, 2022, 1);
INSERT INTO 'dancesstepsmap' VALUES (1867, 2023, 4);
INSERT INTO 'dancesstepsmap' VALUES (1868, 2024, 1);
INSERT INTO 'dancesstepsmap' VALUES (1869, 2026, 4);
INSERT INTO 'dancesstepsmap' VALUES (1870, 2028, 1);
INSERT INTO 'dancesstepsmap' VALUES (1871, 2029, 4);
INSERT INTO 'dancesstepsmap' VALUES (1872, 2030, 4);
INSERT INTO 'dancesstepsmap' VALUES (1873, 2031, 4);
INSERT INTO 'dancesstepsmap' VALUES (1874, 2032, 1);
INSERT INTO 'dancesstepsmap' VALUES (1875, 2033, 4);
INSERT INTO 'dancesstepsmap' VALUES (1876, 2034, 1);
INSERT INTO 'dancesstepsmap' VALUES (1877, 2035, 4);
INSERT INTO 'dancesstepsmap' VALUES (1878, 2037, 4);
INSERT INTO 'dancesstepsmap' VALUES (1879, 2038, 1);
INSERT INTO 'dancesstepsmap' VALUES (1880, 2039, 1);
INSERT INTO 'dancesstepsmap' VALUES (1881, 2040, 4);
INSERT INTO 'dancesstepsmap' VALUES (1882, 2041, 1);
INSERT INTO 'dancesstepsmap' VALUES (1883, 2042, 1);
INSERT INTO 'dancesstepsmap' VALUES (1884, 2043, 1);
INSERT INTO 'dancesstepsmap' VALUES (1885, 2044, 1);
INSERT INTO 'dancesstepsmap' VALUES (1886, 2045, 1);
INSERT INTO 'dancesstepsmap' VALUES (1887, 2046, 1);
INSERT INTO 'dancesstepsmap' VALUES (1888, 2047, 4);
INSERT INTO 'dancesstepsmap' VALUES (1889, 2048, 1);
INSERT INTO 'dancesstepsmap' VALUES (1890, 2049, 1);
INSERT INTO 'dancesstepsmap' VALUES (1891, 2051, 1);
INSERT INTO 'dancesstepsmap' VALUES (1892, 2052, 1);
INSERT INTO 'dancesstepsmap' VALUES (1893, 2053, 1);
INSERT INTO 'dancesstepsmap' VALUES (1894, 2054, 1);
INSERT INTO 'dancesstepsmap' VALUES (1895, 2055, 1);
INSERT INTO 'dancesstepsmap' VALUES (1896, 2056, 4);
INSERT INTO 'dancesstepsmap' VALUES (1897, 2057, 1);
INSERT INTO 'dancesstepsmap' VALUES (1898, 2058, 4);
INSERT INTO 'dancesstepsmap' VALUES (1899, 2059, 4);
INSERT INTO 'dancesstepsmap' VALUES (1900, 2060, 1);
INSERT INTO 'dancesstepsmap' VALUES (1901, 2061, 1);
INSERT INTO 'dancesstepsmap' VALUES (1902, 2062, 1);
INSERT INTO 'dancesstepsmap' VALUES (1903, 2063, 1);
INSERT INTO 'dancesstepsmap' VALUES (1904, 2064, 4);
INSERT INTO 'dancesstepsmap' VALUES (1905, 2065, 1);
INSERT INTO 'dancesstepsmap' VALUES (1906, 2066, 4);
INSERT INTO 'dancesstepsmap' VALUES (1907, 2067, 1);
INSERT INTO 'dancesstepsmap' VALUES (1908, 2068, 1);
INSERT INTO 'dancesstepsmap' VALUES (1909, 2069, 4);
INSERT INTO 'dancesstepsmap' VALUES (1910, 2070, 1);
INSERT INTO 'dancesstepsmap' VALUES (1911, 2071, 1);
INSERT INTO 'dancesstepsmap' VALUES (1912, 2072, 4);
INSERT INTO 'dancesstepsmap' VALUES (1913, 2073, 1);
INSERT INTO 'dancesstepsmap' VALUES (1914, 2074, 1);
INSERT INTO 'dancesstepsmap' VALUES (1915, 2075, 1);
INSERT INTO 'dancesstepsmap' VALUES (1916, 2076, 1);
INSERT INTO 'dancesstepsmap' VALUES (1917, 2077, 1);
INSERT INTO 'dancesstepsmap' VALUES (1918, 2078, 4);
INSERT INTO 'dancesstepsmap' VALUES (1919, 2079, 4);
INSERT INTO 'dancesstepsmap' VALUES (1920, 2080, 1);
INSERT INTO 'dancesstepsmap' VALUES (1921, 2081, 4);
INSERT INTO 'dancesstepsmap' VALUES (1922, 2082, 4);
INSERT INTO 'dancesstepsmap' VALUES (1923, 2083, 4);
INSERT INTO 'dancesstepsmap' VALUES (1924, 2084, 1);
INSERT INTO 'dancesstepsmap' VALUES (1925, 2085, 1);
INSERT INTO 'dancesstepsmap' VALUES (1926, 2086, 1);
INSERT INTO 'dancesstepsmap' VALUES (1927, 2087, 4);
INSERT INTO 'dancesstepsmap' VALUES (10681, 9901, 4);
INSERT INTO 'dancesstepsmap' VALUES (10682, 9902, 1);
INSERT INTO 'dancesstepsmap' VALUES (10683, 9904, 1);
INSERT INTO 'dancesstepsmap' VALUES (10684, 9904, 2);
INSERT INTO 'dancesstepsmap' VALUES (10685, 9905, 1);
INSERT INTO 'dancesstepsmap' VALUES (10686, 9906, 1);
INSERT INTO 'dancesstepsmap' VALUES (10687, 9909, 3);
INSERT INTO 'dancesstepsmap' VALUES (10688, 9909, 2);
INSERT INTO 'dancesstepsmap' VALUES (10689, 9909, 1);
INSERT INTO 'dancesstepsmap' VALUES (10690, 9910, 1);
INSERT INTO 'dancesstepsmap' VALUES (10691, 9911, 1);
INSERT INTO 'dancesstepsmap' VALUES (10692, 2375, 2);
INSERT INTO 'dancesstepsmap' VALUES (10693, 4094, 2);
INSERT INTO 'dancesstepsmap' VALUES (10694, 2443, 3);
INSERT INTO 'dancesstepsmap' VALUES (10695, 2346, 5);
INSERT INTO 'dancesstepsmap' VALUES (10696, 7101, 3);
INSERT INTO 'dancesstepsmap' VALUES (10697, 3130, 5);
INSERT INTO 'dancesstepsmap' VALUES (10698, 2481, 2);
INSERT INTO 'dancesstepsmap' VALUES (10699, 3180, 2);
INSERT INTO 'dancesstepsmap' VALUES (10700, 3180, 3);
INSERT INTO 'dancesstepsmap' VALUES (10701, 3180, 1);
INSERT INTO 'dancesstepsmap' VALUES (10702, 3180, 4);
INSERT INTO 'dancesstepsmap' VALUES (10703, 3180, 5);
INSERT INTO 'dancesstepsmap' VALUES (10704, 3180, 10);
INSERT INTO 'dancesstepsmap' VALUES (10705, 7561, 2);
INSERT INTO 'dancesstepsmap' VALUES (10706, 7738, 1);
INSERT INTO 'dancesstepsmap' VALUES (10707, 7738, 3);
INSERT INTO 'dancesstepsmap' VALUES (10708, 8722, 4);
INSERT INTO 'dancesstepsmap' VALUES (10709, 8722, 5);
INSERT INTO 'dancesstepsmap' VALUES (10710, 8830, 1);
INSERT INTO 'dancesstepsmap' VALUES (10711, 8830, 2);
INSERT INTO 'dancesstepsmap' VALUES (10712, 9913, 1);
INSERT INTO 'dancesstepsmap' VALUES (10713, 9914, 1);
INSERT INTO 'dancesstepsmap' VALUES (10714, 9921, 1);
INSERT INTO 'dancesstepsmap' VALUES (10715, 9921, 2);
INSERT INTO 'dancesstepsmap' VALUES (10716, 9922, 1);
INSERT INTO 'dancesstepsmap' VALUES (10717, 9922, 2);
INSERT INTO 'dancesstepsmap' VALUES (10718, 9923, 1);
INSERT INTO 'dancesstepsmap' VALUES (10719, 9923, 2);
INSERT INTO 'dancesstepsmap' VALUES (10720, 9925, 1);
INSERT INTO 'dancesstepsmap' VALUES (10721, 9865, 1);
INSERT INTO 'dancesstepsmap' VALUES (10722, 9944, 4);
INSERT INTO 'dancesstepsmap' VALUES (17009, 14433, 5);
INSERT INTO 'dancesstepsmap' VALUES (17010, 14433, 4);
INSERT INTO 'dancesstepsmap' VALUES (17011, 14433, 2);
INSERT INTO 'dancesstepsmap' VALUES (1928, 2088, 1);
INSERT INTO 'dancesstepsmap' VALUES (1929, 2089, 4);
INSERT INTO 'dancesstepsmap' VALUES (1930, 2090, 4);
INSERT INTO 'dancesstepsmap' VALUES (1931, 2091, 1);
INSERT INTO 'dancesstepsmap' VALUES (1932, 2092, 1);
INSERT INTO 'dancesstepsmap' VALUES (1933, 2094, 1);
INSERT INTO 'dancesstepsmap' VALUES (1934, 2095, 4);
INSERT INTO 'dancesstepsmap' VALUES (1935, 2096, 4);
INSERT INTO 'dancesstepsmap' VALUES (1936, 2097, 4);
INSERT INTO 'dancesstepsmap' VALUES (1937, 2098, 1);
INSERT INTO 'dancesstepsmap' VALUES (1938, 2099, 1);
INSERT INTO 'dancesstepsmap' VALUES (1939, 2100, 4);
INSERT INTO 'dancesstepsmap' VALUES (1940, 2102, 4);
INSERT INTO 'dancesstepsmap' VALUES (1941, 2103, 1);
INSERT INTO 'dancesstepsmap' VALUES (1942, 2104, 1);
INSERT INTO 'dancesstepsmap' VALUES (1943, 2105, 1);
INSERT INTO 'dancesstepsmap' VALUES (1944, 2106, 1);
INSERT INTO 'dancesstepsmap' VALUES (1945, 2107, 1);
INSERT INTO 'dancesstepsmap' VALUES (1946, 2108, 1);
INSERT INTO 'dancesstepsmap' VALUES (1947, 2109, 1);
INSERT INTO 'dancesstepsmap' VALUES (1948, 2110, 1);
INSERT INTO 'dancesstepsmap' VALUES (1949, 2111, 1);
INSERT INTO 'dancesstepsmap' VALUES (1950, 2112, 1);
INSERT INTO 'dancesstepsmap' VALUES (1951, 2113, 4);
INSERT INTO 'dancesstepsmap' VALUES (1952, 2114, 4);
INSERT INTO 'dancesstepsmap' VALUES (1953, 2115, 4);
INSERT INTO 'dancesstepsmap' VALUES (1954, 2116, 1);
INSERT INTO 'dancesstepsmap' VALUES (1955, 2117, 1);
INSERT INTO 'dancesstepsmap' VALUES (1956, 2118, 1);
INSERT INTO 'dancesstepsmap' VALUES (1957, 2119, 1);
INSERT INTO 'dancesstepsmap' VALUES (1958, 2120, 1);
INSERT INTO 'dancesstepsmap' VALUES (1959, 2122, 1);
INSERT INTO 'dancesstepsmap' VALUES (1960, 2123, 1);
INSERT INTO 'dancesstepsmap' VALUES (1961, 2124, 4);
INSERT INTO 'dancesstepsmap' VALUES (1962, 2125, 1);
INSERT INTO 'dancesstepsmap' VALUES (1963, 2126, 1);
INSERT INTO 'dancesstepsmap' VALUES (1964, 2127, 1);
INSERT INTO 'dancesstepsmap' VALUES (1965, 2128, 4);
INSERT INTO 'dancesstepsmap' VALUES (1966, 2129, 1);
INSERT INTO 'dancesstepsmap' VALUES (1967, 2130, 4);
INSERT INTO 'dancesstepsmap' VALUES (1968, 2131, 1);
INSERT INTO 'dancesstepsmap' VALUES (1969, 2132, 4);
INSERT INTO 'dancesstepsmap' VALUES (1970, 2133, 4);
INSERT INTO 'dancesstepsmap' VALUES (1971, 2134, 1);
INSERT INTO 'dancesstepsmap' VALUES (1972, 2135, 1);
INSERT INTO 'dancesstepsmap' VALUES (1973, 2136, 4);
INSERT INTO 'dancesstepsmap' VALUES (1974, 2137, 1);
INSERT INTO 'dancesstepsmap' VALUES (17012, 14433, 1);
INSERT INTO 'dancesstepsmap' VALUES (1976, 2139, 4);
INSERT INTO 'dancesstepsmap' VALUES (1977, 2140, 4);
INSERT INTO 'dancesstepsmap' VALUES (1978, 2141, 1);
INSERT INTO 'dancesstepsmap' VALUES (1979, 2143, 1);
INSERT INTO 'dancesstepsmap' VALUES (1980, 2145, 4);
INSERT INTO 'dancesstepsmap' VALUES (1981, 2146, 1);
INSERT INTO 'dancesstepsmap' VALUES (1982, 2147, 1);
INSERT INTO 'dancesstepsmap' VALUES (1983, 2148, 1);
INSERT INTO 'dancesstepsmap' VALUES (1984, 2149, 4);
INSERT INTO 'dancesstepsmap' VALUES (1985, 2150, 1);
INSERT INTO 'dancesstepsmap' VALUES (1986, 2151, 4);
INSERT INTO 'dancesstepsmap' VALUES (1987, 2152, 4);
INSERT INTO 'dancesstepsmap' VALUES (1988, 2153, 1);
INSERT INTO 'dancesstepsmap' VALUES (1989, 2154, 1);
INSERT INTO 'dancesstepsmap' VALUES (1990, 2155, 1);
INSERT INTO 'dancesstepsmap' VALUES (1991, 2156, 1);
INSERT INTO 'dancesstepsmap' VALUES (1992, 2157, 1);
INSERT INTO 'dancesstepsmap' VALUES (1993, 2158, 1);
INSERT INTO 'dancesstepsmap' VALUES (1994, 2160, 1);
INSERT INTO 'dancesstepsmap' VALUES (1995, 2161, 1);
INSERT INTO 'dancesstepsmap' VALUES (1996, 2162, 1);
INSERT INTO 'dancesstepsmap' VALUES (1997, 2163, 1);
INSERT INTO 'dancesstepsmap' VALUES (1998, 2164, 1);
INSERT INTO 'dancesstepsmap' VALUES (1999, 2165, 4);
INSERT INTO 'dancesstepsmap' VALUES (2000, 2166, 1);
INSERT INTO 'dancesstepsmap' VALUES (2001, 2167, 1);
INSERT INTO 'dancesstepsmap' VALUES (2002, 2168, 4);
INSERT INTO 'dancesstepsmap' VALUES (2003, 2169, 1);
INSERT INTO 'dancesstepsmap' VALUES (2004, 2171, 1);
INSERT INTO 'dancesstepsmap' VALUES (2005, 2172, 1);
INSERT INTO 'dancesstepsmap' VALUES (2006, 2173, 4);
INSERT INTO 'dancesstepsmap' VALUES (2007, 2174, 4);
INSERT INTO 'dancesstepsmap' VALUES (2008, 2175, 1);
INSERT INTO 'dancesstepsmap' VALUES (2009, 2176, 4);
INSERT INTO 'dancesstepsmap' VALUES (2010, 2177, 1);
INSERT INTO 'dancesstepsmap' VALUES (2011, 2178, 1);
INSERT INTO 'dancesstepsmap' VALUES (2012, 2179, 1);
INSERT INTO 'dancesstepsmap' VALUES (2013, 2180, 1);
INSERT INTO 'dancesstepsmap' VALUES (2014, 2181, 4);
INSERT INTO 'dancesstepsmap' VALUES (2015, 2183, 4);
INSERT INTO 'dancesstepsmap' VALUES (2016, 2184, 1);
INSERT INTO 'dancesstepsmap' VALUES (2017, 2185, 4);
INSERT INTO 'dancesstepsmap' VALUES (2018, 2186, 4);
INSERT INTO 'dancesstepsmap' VALUES (2019, 2187, 1);
INSERT INTO 'dancesstepsmap' VALUES (2020, 2188, 1);
INSERT INTO 'dancesstepsmap' VALUES (2021, 2189, 1);
INSERT INTO 'dancesstepsmap' VALUES (2022, 2190, 1);
INSERT INTO 'dancesstepsmap' VALUES (2023, 2191, 1);
INSERT INTO 'dancesstepsmap' VALUES (2024, 2192, 4);
INSERT INTO 'dancesstepsmap' VALUES (2025, 2193, 4);
INSERT INTO 'dancesstepsmap' VALUES (2026, 2194, 1);
INSERT INTO 'dancesstepsmap' VALUES (2027, 2195, 1);
INSERT INTO 'dancesstepsmap' VALUES (2028, 2196, 1);
INSERT INTO 'dancesstepsmap' VALUES (2029, 2197, 4);
INSERT INTO 'dancesstepsmap' VALUES (2030, 2198, 1);
INSERT INTO 'dancesstepsmap' VALUES (2031, 2199, 4);
INSERT INTO 'dancesstepsmap' VALUES (2032, 2200, 1);
INSERT INTO 'dancesstepsmap' VALUES (2033, 2201, 1);
INSERT INTO 'dancesstepsmap' VALUES (2034, 2202, 1);
INSERT INTO 'dancesstepsmap' VALUES (2035, 2203, 1);
INSERT INTO 'dancesstepsmap' VALUES (2036, 2204, 1);
INSERT INTO 'dancesstepsmap' VALUES (2037, 2205, 1);
INSERT INTO 'dancesstepsmap' VALUES (2038, 2206, 1);
INSERT INTO 'dancesstepsmap' VALUES (2039, 2207, 1);
INSERT INTO 'dancesstepsmap' VALUES (2040, 2208, 1);
INSERT INTO 'dancesstepsmap' VALUES (2041, 2209, 1);
INSERT INTO 'dancesstepsmap' VALUES (2042, 2210, 1);
INSERT INTO 'dancesstepsmap' VALUES (2043, 2211, 4);
INSERT INTO 'dancesstepsmap' VALUES (2044, 2212, 1);
INSERT INTO 'dancesstepsmap' VALUES (2045, 2213, 4);
INSERT INTO 'dancesstepsmap' VALUES (2046, 2215, 1);
INSERT INTO 'dancesstepsmap' VALUES (2047, 2218, 1);
INSERT INTO 'dancesstepsmap' VALUES (2048, 2219, 1);
INSERT INTO 'dancesstepsmap' VALUES (2049, 2220, 1);
INSERT INTO 'dancesstepsmap' VALUES (2050, 2221, 1);
INSERT INTO 'dancesstepsmap' VALUES (2051, 2222, 1);
INSERT INTO 'dancesstepsmap' VALUES (2052, 2223, 1);
INSERT INTO 'dancesstepsmap' VALUES (2053, 2224, 1);
INSERT INTO 'dancesstepsmap' VALUES (10723, 9950, 1);
INSERT INTO 'dancesstepsmap' VALUES (10724, 9950, 2);
INSERT INTO 'dancesstepsmap' VALUES (10725, 9950, 3);
INSERT INTO 'dancesstepsmap' VALUES (10726, 9951, 1);
INSERT INTO 'dancesstepsmap' VALUES (10727, 9952, 1);
INSERT INTO 'dancesstepsmap' VALUES (10728, 9952, 3);
INSERT INTO 'dancesstepsmap' VALUES (10729, 9953, 4);
INSERT INTO 'dancesstepsmap' VALUES (10730, 9954, 2);
INSERT INTO 'dancesstepsmap' VALUES (10731, 9954, 1);
INSERT INTO 'dancesstepsmap' VALUES (10732, 8491, 4);
INSERT INTO 'dancesstepsmap' VALUES (10733, 9955, 1);
INSERT INTO 'dancesstepsmap' VALUES (10734, 9956, 3);
INSERT INTO 'dancesstepsmap' VALUES (10735, 9956, 1);
INSERT INTO 'dancesstepsmap' VALUES (10736, 9957, 2);
INSERT INTO 'dancesstepsmap' VALUES (10737, 9957, 1);
INSERT INTO 'dancesstepsmap' VALUES (10738, 9958, 4);
INSERT INTO 'dancesstepsmap' VALUES (10739, 9960, 1);
INSERT INTO 'dancesstepsmap' VALUES (10740, 9960, 2);
INSERT INTO 'dancesstepsmap' VALUES (10741, 9961, 4);
INSERT INTO 'dancesstepsmap' VALUES (1975, 2138, 5);
INSERT INTO 'dancesstepsmap' VALUES (2054, 2225, 1);
INSERT INTO 'dancesstepsmap' VALUES (2055, 2228, 1);
INSERT INTO 'dancesstepsmap' VALUES (2056, 2229, 1);
INSERT INTO 'dancesstepsmap' VALUES (2057, 2230, 4);
INSERT INTO 'dancesstepsmap' VALUES (2058, 2231, 1);
INSERT INTO 'dancesstepsmap' VALUES (2059, 2232, 1);
INSERT INTO 'dancesstepsmap' VALUES (2060, 2233, 1);
INSERT INTO 'dancesstepsmap' VALUES (2061, 2234, 1);
INSERT INTO 'dancesstepsmap' VALUES (2062, 2235, 4);
INSERT INTO 'dancesstepsmap' VALUES (2063, 2236, 1);
INSERT INTO 'dancesstepsmap' VALUES (2064, 2237, 4);
INSERT INTO 'dancesstepsmap' VALUES (2065, 2238, 1);
INSERT INTO 'dancesstepsmap' VALUES (2066, 2240, 4);
INSERT INTO 'dancesstepsmap' VALUES (2067, 2241, 1);
INSERT INTO 'dancesstepsmap' VALUES (2068, 2242, 4);
INSERT INTO 'dancesstepsmap' VALUES (2069, 2243, 1);
INSERT INTO 'dancesstepsmap' VALUES (2070, 2244, 4);
INSERT INTO 'dancesstepsmap' VALUES (2071, 2245, 4);
INSERT INTO 'dancesstepsmap' VALUES (2072, 2246, 4);
INSERT INTO 'dancesstepsmap' VALUES (2073, 2247, 4);
INSERT INTO 'dancesstepsmap' VALUES (2074, 2248, 1);
INSERT INTO 'dancesstepsmap' VALUES (2075, 2249, 4);
INSERT INTO 'dancesstepsmap' VALUES (2076, 2250, 1);
INSERT INTO 'dancesstepsmap' VALUES (2077, 2251, 1);
INSERT INTO 'dancesstepsmap' VALUES (2078, 2252, 1);
INSERT INTO 'dancesstepsmap' VALUES (2079, 2253, 4);
INSERT INTO 'dancesstepsmap' VALUES (2080, 2254, 4);
INSERT INTO 'dancesstepsmap' VALUES (2081, 2255, 1);
INSERT INTO 'dancesstepsmap' VALUES (2082, 2256, 1);
INSERT INTO 'dancesstepsmap' VALUES (2083, 2257, 1);
INSERT INTO 'dancesstepsmap' VALUES (2084, 2258, 1);
INSERT INTO 'dancesstepsmap' VALUES (2085, 2259, 1);
INSERT INTO 'dancesstepsmap' VALUES (2086, 2260, 1);
INSERT INTO 'dancesstepsmap' VALUES (2087, 2262, 1);
INSERT INTO 'dancesstepsmap' VALUES (2088, 2263, 1);
INSERT INTO 'dancesstepsmap' VALUES (2089, 2264, 4);
INSERT INTO 'dancesstepsmap' VALUES (2090, 2265, 4);
INSERT INTO 'dancesstepsmap' VALUES (2091, 2266, 1);
INSERT INTO 'dancesstepsmap' VALUES (2092, 2267, 1);
INSERT INTO 'dancesstepsmap' VALUES (2093, 2268, 4);
INSERT INTO 'dancesstepsmap' VALUES (2094, 2269, 1);
INSERT INTO 'dancesstepsmap' VALUES (2095, 2270, 1);
INSERT INTO 'dancesstepsmap' VALUES (2096, 2271, 1);
INSERT INTO 'dancesstepsmap' VALUES (2097, 2272, 1);
INSERT INTO 'dancesstepsmap' VALUES (2098, 2273, 1);
INSERT INTO 'dancesstepsmap' VALUES (2099, 2274, 1);
INSERT INTO 'dancesstepsmap' VALUES (2100, 2275, 4);
INSERT INTO 'dancesstepsmap' VALUES (2101, 2276, 1);
INSERT INTO 'dancesstepsmap' VALUES (2102, 2277, 1);
INSERT INTO 'dancesstepsmap' VALUES (2103, 2278, 1);
INSERT INTO 'dancesstepsmap' VALUES (2104, 2279, 1);
INSERT INTO 'dancesstepsmap' VALUES (2105, 2280, 1);
INSERT INTO 'dancesstepsmap' VALUES (2106, 2281, 4);
INSERT INTO 'dancesstepsmap' VALUES (2107, 2282, 1);
INSERT INTO 'dancesstepsmap' VALUES (2108, 2283, 1);
INSERT INTO 'dancesstepsmap' VALUES (2109, 2284, 1);
INSERT INTO 'dancesstepsmap' VALUES (2110, 2285, 1);
INSERT INTO 'dancesstepsmap' VALUES (2111, 2286, 1);
INSERT INTO 'dancesstepsmap' VALUES (2112, 2287, 1);
INSERT INTO 'dancesstepsmap' VALUES (2113, 2288, 4);
INSERT INTO 'dancesstepsmap' VALUES (2114, 2289, 1);
INSERT INTO 'dancesstepsmap' VALUES (2115, 2290, 1);
INSERT INTO 'dancesstepsmap' VALUES (2116, 2291, 1);
INSERT INTO 'dancesstepsmap' VALUES (2117, 2292, 4);
INSERT INTO 'dancesstepsmap' VALUES (2118, 2293, 1);
INSERT INTO 'dancesstepsmap' VALUES (2119, 2294, 1);
INSERT INTO 'dancesstepsmap' VALUES (2120, 2295, 1);
INSERT INTO 'dancesstepsmap' VALUES (2121, 2296, 4);
INSERT INTO 'dancesstepsmap' VALUES (2122, 2297, 1);
INSERT INTO 'dancesstepsmap' VALUES (2123, 2298, 1);
INSERT INTO 'dancesstepsmap' VALUES (2124, 2299, 1);
INSERT INTO 'dancesstepsmap' VALUES (2125, 2300, 4);
INSERT INTO 'dancesstepsmap' VALUES (2126, 2301, 1);
INSERT INTO 'dancesstepsmap' VALUES (2127, 2303, 4);
INSERT INTO 'dancesstepsmap' VALUES (2128, 2304, 1);
INSERT INTO 'dancesstepsmap' VALUES (2129, 2305, 1);
INSERT INTO 'dancesstepsmap' VALUES (2130, 2306, 1);
INSERT INTO 'dancesstepsmap' VALUES (2131, 2307, 1);
INSERT INTO 'dancesstepsmap' VALUES (2132, 2308, 1);
INSERT INTO 'dancesstepsmap' VALUES (2133, 2309, 1);
INSERT INTO 'dancesstepsmap' VALUES (2134, 2310, 4);
INSERT INTO 'dancesstepsmap' VALUES (2135, 2311, 1);
INSERT INTO 'dancesstepsmap' VALUES (2136, 2312, 1);
INSERT INTO 'dancesstepsmap' VALUES (2137, 2313, 1);
INSERT INTO 'dancesstepsmap' VALUES (2138, 2314, 1);
INSERT INTO 'dancesstepsmap' VALUES (2139, 2315, 4);
INSERT INTO 'dancesstepsmap' VALUES (2140, 2316, 4);
INSERT INTO 'dancesstepsmap' VALUES (2141, 2318, 1);
INSERT INTO 'dancesstepsmap' VALUES (2142, 2319, 1);
INSERT INTO 'dancesstepsmap' VALUES (2143, 2320, 1);
INSERT INTO 'dancesstepsmap' VALUES (2144, 2321, 4);
INSERT INTO 'dancesstepsmap' VALUES (2145, 2322, 1);
INSERT INTO 'dancesstepsmap' VALUES (2146, 2324, 4);
INSERT INTO 'dancesstepsmap' VALUES (10742, 9962, 1);
INSERT INTO 'dancesstepsmap' VALUES (10743, 9962, 2);
INSERT INTO 'dancesstepsmap' VALUES (10744, 9962, 3);
INSERT INTO 'dancesstepsmap' VALUES (10745, 8711, 1);
INSERT INTO 'dancesstepsmap' VALUES (10746, 9964, 6);
INSERT INTO 'dancesstepsmap' VALUES (10747, 9964, 10);
INSERT INTO 'dancesstepsmap' VALUES (10748, 9964, 4);
INSERT INTO 'dancesstepsmap' VALUES (10749, 9965, 1);
INSERT INTO 'dancesstepsmap' VALUES (10750, 9966, 1);
INSERT INTO 'dancesstepsmap' VALUES (10751, 9966, 3);
INSERT INTO 'dancesstepsmap' VALUES (10752, 9967, 4);
INSERT INTO 'dancesstepsmap' VALUES (10753, 246, 5);
INSERT INTO 'dancesstepsmap' VALUES (10754, 9905, 2);
INSERT INTO 'dancesstepsmap' VALUES (10755, 9968, 4);
INSERT INTO 'dancesstepsmap' VALUES (10756, 9969, 4);
INSERT INTO 'dancesstepsmap' VALUES (10757, 9970, 3);
INSERT INTO 'dancesstepsmap' VALUES (10758, 9970, 2);
INSERT INTO 'dancesstepsmap' VALUES (10759, 9971, 1);
INSERT INTO 'dancesstepsmap' VALUES (10760, 9972, 1);
INSERT INTO 'dancesstepsmap' VALUES (10761, 9972, 2);
INSERT INTO 'dancesstepsmap' VALUES (10762, 9975, 4);
INSERT INTO 'dancesstepsmap' VALUES (10763, 9945, 4);
INSERT INTO 'dancesstepsmap' VALUES (10764, 9977, 1);
INSERT INTO 'dancesstepsmap' VALUES (10765, 9977, 2);
INSERT INTO 'dancesstepsmap' VALUES (10766, 9761, 4);
INSERT INTO 'dancesstepsmap' VALUES (10767, 9978, 4);
INSERT INTO 'dancesstepsmap' VALUES (10768, 9979, 4);
INSERT INTO 'dancesstepsmap' VALUES (23134, 3549, 5);
INSERT INTO 'dancesstepsmap' VALUES (10770, 9981, 4);
INSERT INTO 'dancesstepsmap' VALUES (10771, 9982, 1);
INSERT INTO 'dancesstepsmap' VALUES (10772, 9982, 2);
INSERT INTO 'dancesstepsmap' VALUES (10773, 9983, 4);
INSERT INTO 'dancesstepsmap' VALUES (10774, 9984, 4);
INSERT INTO 'dancesstepsmap' VALUES (10775, 9985, 4);
INSERT INTO 'dancesstepsmap' VALUES (10776, 9986, 1);
INSERT INTO 'dancesstepsmap' VALUES (10778, 9987, 5);
INSERT INTO 'dancesstepsmap' VALUES (10779, 9987, 4);
INSERT INTO 'dancesstepsmap' VALUES (10780, 9988, 1);
INSERT INTO 'dancesstepsmap' VALUES (10781, 9972, 3);
INSERT INTO 'dancesstepsmap' VALUES (10782, 9977, 3);
INSERT INTO 'dancesstepsmap' VALUES (10783, 9980, 4);
INSERT INTO 'dancesstepsmap' VALUES (17013, 14433, 3);
INSERT INTO 'dancesstepsmap' VALUES (2147, 2325, 4);
INSERT INTO 'dancesstepsmap' VALUES (2148, 2326, 1);
INSERT INTO 'dancesstepsmap' VALUES (2149, 2327, 4);
INSERT INTO 'dancesstepsmap' VALUES (2150, 2328, 4);
INSERT INTO 'dancesstepsmap' VALUES (2151, 2329, 4);
INSERT INTO 'dancesstepsmap' VALUES (2152, 2330, 4);
INSERT INTO 'dancesstepsmap' VALUES (2153, 2331, 1);
INSERT INTO 'dancesstepsmap' VALUES (2154, 2332, 1);
INSERT INTO 'dancesstepsmap' VALUES (2155, 2333, 1);
INSERT INTO 'dancesstepsmap' VALUES (2156, 2334, 1);
INSERT INTO 'dancesstepsmap' VALUES (2157, 2335, 1);
INSERT INTO 'dancesstepsmap' VALUES (2158, 2336, 4);
INSERT INTO 'dancesstepsmap' VALUES (2159, 2337, 4);
INSERT INTO 'dancesstepsmap' VALUES (2160, 2338, 4);
INSERT INTO 'dancesstepsmap' VALUES (2161, 2339, 1);
INSERT INTO 'dancesstepsmap' VALUES (2162, 2340, 1);
INSERT INTO 'dancesstepsmap' VALUES (2163, 2341, 1);
INSERT INTO 'dancesstepsmap' VALUES (2164, 2342, 4);
INSERT INTO 'dancesstepsmap' VALUES (2165, 2343, 1);
INSERT INTO 'dancesstepsmap' VALUES (2166, 2344, 1);
INSERT INTO 'dancesstepsmap' VALUES (2167, 2345, 4);
INSERT INTO 'dancesstepsmap' VALUES (2168, 2346, 4);
INSERT INTO 'dancesstepsmap' VALUES (2169, 2347, 1);
INSERT INTO 'dancesstepsmap' VALUES (2170, 2348, 1);
INSERT INTO 'dancesstepsmap' VALUES (2171, 2349, 1);
INSERT INTO 'dancesstepsmap' VALUES (2172, 2350, 1);
INSERT INTO 'dancesstepsmap' VALUES (2173, 2351, 1);
INSERT INTO 'dancesstepsmap' VALUES (2174, 2352, 4);
INSERT INTO 'dancesstepsmap' VALUES (2175, 2353, 4);
INSERT INTO 'dancesstepsmap' VALUES (2176, 2354, 4);
INSERT INTO 'dancesstepsmap' VALUES (2177, 2356, 4);
INSERT INTO 'dancesstepsmap' VALUES (2178, 2357, 4);
INSERT INTO 'dancesstepsmap' VALUES (2179, 2358, 1);
INSERT INTO 'dancesstepsmap' VALUES (2180, 2360, 1);
INSERT INTO 'dancesstepsmap' VALUES (2181, 2361, 1);
INSERT INTO 'dancesstepsmap' VALUES (2182, 2362, 1);
INSERT INTO 'dancesstepsmap' VALUES (2183, 2363, 1);
INSERT INTO 'dancesstepsmap' VALUES (2184, 2364, 5);
INSERT INTO 'dancesstepsmap' VALUES (2185, 2365, 1);
INSERT INTO 'dancesstepsmap' VALUES (2186, 2366, 1);
INSERT INTO 'dancesstepsmap' VALUES (2187, 2367, 1);
INSERT INTO 'dancesstepsmap' VALUES (2188, 2368, 4);
INSERT INTO 'dancesstepsmap' VALUES (2189, 2369, 1);
INSERT INTO 'dancesstepsmap' VALUES (2190, 2370, 1);
INSERT INTO 'dancesstepsmap' VALUES (2191, 2371, 4);
INSERT INTO 'dancesstepsmap' VALUES (2192, 2373, 4);
INSERT INTO 'dancesstepsmap' VALUES (2193, 2374, 1);
INSERT INTO 'dancesstepsmap' VALUES (2194, 2375, 1);
INSERT INTO 'dancesstepsmap' VALUES (2195, 2376, 4);
INSERT INTO 'dancesstepsmap' VALUES (2196, 2377, 1);
INSERT INTO 'dancesstepsmap' VALUES (2197, 2378, 4);
INSERT INTO 'dancesstepsmap' VALUES (2198, 2379, 1);
INSERT INTO 'dancesstepsmap' VALUES (2199, 2380, 4);
INSERT INTO 'dancesstepsmap' VALUES (2200, 2381, 1);
INSERT INTO 'dancesstepsmap' VALUES (2201, 2382, 1);
INSERT INTO 'dancesstepsmap' VALUES (2202, 2383, 1);
INSERT INTO 'dancesstepsmap' VALUES (2203, 2384, 4);
INSERT INTO 'dancesstepsmap' VALUES (2204, 2385, 1);
INSERT INTO 'dancesstepsmap' VALUES (2205, 2386, 1);
INSERT INTO 'dancesstepsmap' VALUES (2206, 2388, 1);
INSERT INTO 'dancesstepsmap' VALUES (2207, 2389, 1);
INSERT INTO 'dancesstepsmap' VALUES (2208, 2390, 1);
INSERT INTO 'dancesstepsmap' VALUES (2209, 2391, 1);
INSERT INTO 'dancesstepsmap' VALUES (2210, 2392, 1);
INSERT INTO 'dancesstepsmap' VALUES (2211, 2393, 4);
INSERT INTO 'dancesstepsmap' VALUES (2212, 2394, 4);
INSERT INTO 'dancesstepsmap' VALUES (2213, 2395, 4);
INSERT INTO 'dancesstepsmap' VALUES (2214, 2396, 1);
INSERT INTO 'dancesstepsmap' VALUES (2215, 2397, 1);
INSERT INTO 'dancesstepsmap' VALUES (2216, 2398, 1);
INSERT INTO 'dancesstepsmap' VALUES (2217, 2399, 4);
INSERT INTO 'dancesstepsmap' VALUES (2218, 2400, 4);
INSERT INTO 'dancesstepsmap' VALUES (2219, 2401, 5);
INSERT INTO 'dancesstepsmap' VALUES (2220, 2402, 1);
INSERT INTO 'dancesstepsmap' VALUES (2221, 2404, 4);
INSERT INTO 'dancesstepsmap' VALUES (2222, 2405, 1);
INSERT INTO 'dancesstepsmap' VALUES (2223, 2406, 4);
INSERT INTO 'dancesstepsmap' VALUES (2224, 2407, 1);
INSERT INTO 'dancesstepsmap' VALUES (2225, 2408, 1);
INSERT INTO 'dancesstepsmap' VALUES (2226, 2409, 4);
INSERT INTO 'dancesstepsmap' VALUES (2227, 2410, 4);
INSERT INTO 'dancesstepsmap' VALUES (2228, 2411, 4);
INSERT INTO 'dancesstepsmap' VALUES (2229, 2412, 1);
INSERT INTO 'dancesstepsmap' VALUES (2230, 2414, 1);
INSERT INTO 'dancesstepsmap' VALUES (2231, 2415, 1);
INSERT INTO 'dancesstepsmap' VALUES (2232, 2416, 1);
INSERT INTO 'dancesstepsmap' VALUES (2233, 2417, 4);
INSERT INTO 'dancesstepsmap' VALUES (2234, 2419, 1);
INSERT INTO 'dancesstepsmap' VALUES (2235, 2420, 1);
INSERT INTO 'dancesstepsmap' VALUES (2236, 2421, 1);
INSERT INTO 'dancesstepsmap' VALUES (2237, 2422, 1);
INSERT INTO 'dancesstepsmap' VALUES (2238, 2423, 1);
INSERT INTO 'dancesstepsmap' VALUES (10784, 7743, 5);
INSERT INTO 'dancesstepsmap' VALUES (10785, 2484, 3);
INSERT INTO 'dancesstepsmap' VALUES (10786, 2484, 1);
INSERT INTO 'dancesstepsmap' VALUES (10787, 9974, 4);
INSERT INTO 'dancesstepsmap' VALUES (10788, 9989, 4);
INSERT INTO 'dancesstepsmap' VALUES (10789, 9990, 2);
INSERT INTO 'dancesstepsmap' VALUES (10790, 9990, 1);
INSERT INTO 'dancesstepsmap' VALUES (10791, 9991, 1);
INSERT INTO 'dancesstepsmap' VALUES (10792, 9991, 2);
INSERT INTO 'dancesstepsmap' VALUES (10793, 9991, 3);
INSERT INTO 'dancesstepsmap' VALUES (10794, 9991, 4);
INSERT INTO 'dancesstepsmap' VALUES (10795, 9991, 5);
INSERT INTO 'dancesstepsmap' VALUES (10796, 9992, 5);
INSERT INTO 'dancesstepsmap' VALUES (10797, 9992, 4);
INSERT INTO 'dancesstepsmap' VALUES (10798, 9993, 1);
INSERT INTO 'dancesstepsmap' VALUES (10799, 9994, 4);
INSERT INTO 'dancesstepsmap' VALUES (10800, 9995, 4);
INSERT INTO 'dancesstepsmap' VALUES (10801, 9996, 8);
INSERT INTO 'dancesstepsmap' VALUES (10802, 9996, 1);
INSERT INTO 'dancesstepsmap' VALUES (10803, 9996, 3);
INSERT INTO 'dancesstepsmap' VALUES (10804, 9997, 2);
INSERT INTO 'dancesstepsmap' VALUES (10805, 9997, 1);
INSERT INTO 'dancesstepsmap' VALUES (10806, 9998, 5);
INSERT INTO 'dancesstepsmap' VALUES (10807, 9998, 4);
INSERT INTO 'dancesstepsmap' VALUES (10808, 9999, 2);
INSERT INTO 'dancesstepsmap' VALUES (10809, 9999, 1);
INSERT INTO 'dancesstepsmap' VALUES (10810, 10000, 1);
INSERT INTO 'dancesstepsmap' VALUES (10811, 10000, 3);
INSERT INTO 'dancesstepsmap' VALUES (10812, 10001, 1);
INSERT INTO 'dancesstepsmap' VALUES (10813, 10002, 1);
INSERT INTO 'dancesstepsmap' VALUES (10814, 10002, 3);
INSERT INTO 'dancesstepsmap' VALUES (10815, 10003, 2);
INSERT INTO 'dancesstepsmap' VALUES (10816, 10003, 1);
INSERT INTO 'dancesstepsmap' VALUES (10817, 10003, 3);
INSERT INTO 'dancesstepsmap' VALUES (10818, 10004, 1);
INSERT INTO 'dancesstepsmap' VALUES (10819, 10004, 3);
INSERT INTO 'dancesstepsmap' VALUES (10820, 640, 5);
INSERT INTO 'dancesstepsmap' VALUES (10821, 6135, 3);
INSERT INTO 'dancesstepsmap' VALUES (10823, 10007, 1);
INSERT INTO 'dancesstepsmap' VALUES (10824, 10007, 3);
INSERT INTO 'dancesstepsmap' VALUES (10825, 10008, 3);
INSERT INTO 'dancesstepsmap' VALUES (10826, 10008, 1);
INSERT INTO 'dancesstepsmap' VALUES (17014, 14434, 5);
INSERT INTO 'dancesstepsmap' VALUES (17015, 14434, 4);
INSERT INTO 'dancesstepsmap' VALUES (2239, 2424, 1);
INSERT INTO 'dancesstepsmap' VALUES (2240, 2425, 1);
INSERT INTO 'dancesstepsmap' VALUES (2241, 2426, 1);
INSERT INTO 'dancesstepsmap' VALUES (2242, 2427, 1);
INSERT INTO 'dancesstepsmap' VALUES (2243, 2428, 1);
INSERT INTO 'dancesstepsmap' VALUES (2244, 2429, 1);
INSERT INTO 'dancesstepsmap' VALUES (2245, 2430, 1);
INSERT INTO 'dancesstepsmap' VALUES (2246, 2431, 1);
INSERT INTO 'dancesstepsmap' VALUES (2247, 2432, 1);
INSERT INTO 'dancesstepsmap' VALUES (2248, 2433, 4);
INSERT INTO 'dancesstepsmap' VALUES (2249, 2434, 1);
INSERT INTO 'dancesstepsmap' VALUES (2250, 2435, 1);
INSERT INTO 'dancesstepsmap' VALUES (2251, 2436, 1);
INSERT INTO 'dancesstepsmap' VALUES (2252, 2437, 4);
INSERT INTO 'dancesstepsmap' VALUES (2253, 2438, 1);
INSERT INTO 'dancesstepsmap' VALUES (2254, 2439, 1);
INSERT INTO 'dancesstepsmap' VALUES (2255, 2440, 1);
INSERT INTO 'dancesstepsmap' VALUES (2256, 2441, 1);
INSERT INTO 'dancesstepsmap' VALUES (2257, 2442, 1);
INSERT INTO 'dancesstepsmap' VALUES (2258, 2443, 1);
INSERT INTO 'dancesstepsmap' VALUES (2259, 2444, 1);
INSERT INTO 'dancesstepsmap' VALUES (2260, 2445, 4);
INSERT INTO 'dancesstepsmap' VALUES (2261, 2446, 1);
INSERT INTO 'dancesstepsmap' VALUES (2262, 2447, 1);
INSERT INTO 'dancesstepsmap' VALUES (2263, 2448, 1);
INSERT INTO 'dancesstepsmap' VALUES (2264, 2449, 1);
INSERT INTO 'dancesstepsmap' VALUES (2265, 2450, 1);
INSERT INTO 'dancesstepsmap' VALUES (2266, 2451, 1);
INSERT INTO 'dancesstepsmap' VALUES (2267, 2452, 1);
INSERT INTO 'dancesstepsmap' VALUES (2268, 2453, 1);
INSERT INTO 'dancesstepsmap' VALUES (2269, 2454, 4);
INSERT INTO 'dancesstepsmap' VALUES (2270, 2455, 1);
INSERT INTO 'dancesstepsmap' VALUES (2271, 2456, 1);
INSERT INTO 'dancesstepsmap' VALUES (2272, 2457, 1);
INSERT INTO 'dancesstepsmap' VALUES (2273, 2458, 1);
INSERT INTO 'dancesstepsmap' VALUES (2274, 2459, 4);
INSERT INTO 'dancesstepsmap' VALUES (2275, 2460, 1);
INSERT INTO 'dancesstepsmap' VALUES (2276, 2461, 1);
INSERT INTO 'dancesstepsmap' VALUES (2277, 2462, 1);
INSERT INTO 'dancesstepsmap' VALUES (2278, 2464, 4);
INSERT INTO 'dancesstepsmap' VALUES (2279, 2465, 1);
INSERT INTO 'dancesstepsmap' VALUES (2280, 2466, 1);
INSERT INTO 'dancesstepsmap' VALUES (2281, 2467, 1);
INSERT INTO 'dancesstepsmap' VALUES (2282, 2468, 1);
INSERT INTO 'dancesstepsmap' VALUES (2283, 2469, 1);
INSERT INTO 'dancesstepsmap' VALUES (2284, 2470, 4);
INSERT INTO 'dancesstepsmap' VALUES (2285, 2471, 1);
INSERT INTO 'dancesstepsmap' VALUES (2286, 2472, 1);
INSERT INTO 'dancesstepsmap' VALUES (2287, 2473, 1);
INSERT INTO 'dancesstepsmap' VALUES (2288, 2474, 4);
INSERT INTO 'dancesstepsmap' VALUES (2289, 2475, 1);
INSERT INTO 'dancesstepsmap' VALUES (2290, 2476, 4);
INSERT INTO 'dancesstepsmap' VALUES (2291, 2477, 1);
INSERT INTO 'dancesstepsmap' VALUES (2292, 2478, 1);
INSERT INTO 'dancesstepsmap' VALUES (23135, 6169, 5);
INSERT INTO 'dancesstepsmap' VALUES (2294, 2480, 1);
INSERT INTO 'dancesstepsmap' VALUES (2295, 2481, 1);
INSERT INTO 'dancesstepsmap' VALUES (2296, 2482, 1);
INSERT INTO 'dancesstepsmap' VALUES (2297, 2483, 4);
INSERT INTO 'dancesstepsmap' VALUES (2298, 2485, 1);
INSERT INTO 'dancesstepsmap' VALUES (2299, 2486, 4);
INSERT INTO 'dancesstepsmap' VALUES (2300, 2489, 4);
INSERT INTO 'dancesstepsmap' VALUES (2301, 2490, 1);
INSERT INTO 'dancesstepsmap' VALUES (2302, 2491, 1);
INSERT INTO 'dancesstepsmap' VALUES (2303, 2495, 4);
INSERT INTO 'dancesstepsmap' VALUES (2304, 2496, 1);
INSERT INTO 'dancesstepsmap' VALUES (2305, 2497, 4);
INSERT INTO 'dancesstepsmap' VALUES (2306, 2498, 4);
INSERT INTO 'dancesstepsmap' VALUES (2307, 2499, 4);
INSERT INTO 'dancesstepsmap' VALUES (2308, 2500, 1);
INSERT INTO 'dancesstepsmap' VALUES (2309, 2501, 4);
INSERT INTO 'dancesstepsmap' VALUES (2310, 2502, 1);
INSERT INTO 'dancesstepsmap' VALUES (2311, 2503, 1);
INSERT INTO 'dancesstepsmap' VALUES (2312, 2504, 1);
INSERT INTO 'dancesstepsmap' VALUES (2313, 2505, 1);
INSERT INTO 'dancesstepsmap' VALUES (2314, 2506, 1);
INSERT INTO 'dancesstepsmap' VALUES (2315, 2507, 4);
INSERT INTO 'dancesstepsmap' VALUES (2316, 2508, 4);
INSERT INTO 'dancesstepsmap' VALUES (23136, 5679, 5);
INSERT INTO 'dancesstepsmap' VALUES (2318, 2510, 1);
INSERT INTO 'dancesstepsmap' VALUES (2319, 2511, 1);
INSERT INTO 'dancesstepsmap' VALUES (2320, 2512, 4);
INSERT INTO 'dancesstepsmap' VALUES (2321, 2513, 1);
INSERT INTO 'dancesstepsmap' VALUES (2322, 2514, 1);
INSERT INTO 'dancesstepsmap' VALUES (2323, 2515, 1);
INSERT INTO 'dancesstepsmap' VALUES (2324, 2516, 4);
INSERT INTO 'dancesstepsmap' VALUES (2325, 2517, 4);
INSERT INTO 'dancesstepsmap' VALUES (2326, 2518, 1);
INSERT INTO 'dancesstepsmap' VALUES (2327, 2519, 1);
INSERT INTO 'dancesstepsmap' VALUES (2328, 2520, 1);
INSERT INTO 'dancesstepsmap' VALUES (2329, 2521, 1);
INSERT INTO 'dancesstepsmap' VALUES (2330, 2522, 1);
INSERT INTO 'dancesstepsmap' VALUES (2331, 2523, 4);
INSERT INTO 'dancesstepsmap' VALUES (10827, 10010, 1);
INSERT INTO 'dancesstepsmap' VALUES (10828, 10010, 2);
INSERT INTO 'dancesstepsmap' VALUES (10829, 10010, 3);
INSERT INTO 'dancesstepsmap' VALUES (10830, 10012, 4);
INSERT INTO 'dancesstepsmap' VALUES (10831, 9497, 2);
INSERT INTO 'dancesstepsmap' VALUES (10832, 9500, 5);
INSERT INTO 'dancesstepsmap' VALUES (10833, 9501, 2);
INSERT INTO 'dancesstepsmap' VALUES (10834, 9502, 2);
INSERT INTO 'dancesstepsmap' VALUES (10835, 9502, 1);
INSERT INTO 'dancesstepsmap' VALUES (10836, 9504, 1);
INSERT INTO 'dancesstepsmap' VALUES (10837, 10013, 3);
INSERT INTO 'dancesstepsmap' VALUES (10838, 10013, 2);
INSERT INTO 'dancesstepsmap' VALUES (10839, 10014, 1);
INSERT INTO 'dancesstepsmap' VALUES (10840, 10014, 2);
INSERT INTO 'dancesstepsmap' VALUES (10841, 10015, 4);
INSERT INTO 'dancesstepsmap' VALUES (10842, 10005, 1);
INSERT INTO 'dancesstepsmap' VALUES (10843, 10016, 4);
INSERT INTO 'dancesstepsmap' VALUES (10844, 10016, 5);
INSERT INTO 'dancesstepsmap' VALUES (10845, 9406, 2);
INSERT INTO 'dancesstepsmap' VALUES (10846, 9406, 1);
INSERT INTO 'dancesstepsmap' VALUES (10847, 10017, 1);
INSERT INTO 'dancesstepsmap' VALUES (10848, 10018, 1);
INSERT INTO 'dancesstepsmap' VALUES (10849, 10019, 1);
INSERT INTO 'dancesstepsmap' VALUES (10850, 10020, 1);
INSERT INTO 'dancesstepsmap' VALUES (10851, 10021, 1);
INSERT INTO 'dancesstepsmap' VALUES (10852, 10022, 5);
INSERT INTO 'dancesstepsmap' VALUES (10853, 10022, 4);
INSERT INTO 'dancesstepsmap' VALUES (10854, 10023, 1);
INSERT INTO 'dancesstepsmap' VALUES (10855, 10024, 1);
INSERT INTO 'dancesstepsmap' VALUES (10856, 10025, 1);
INSERT INTO 'dancesstepsmap' VALUES (10857, 8524, 3);
INSERT INTO 'dancesstepsmap' VALUES (10858, 10043, 1);
INSERT INTO 'dancesstepsmap' VALUES (10859, 10043, 3);
INSERT INTO 'dancesstepsmap' VALUES (10860, 10043, 2);
INSERT INTO 'dancesstepsmap' VALUES (10861, 10044, 2);
INSERT INTO 'dancesstepsmap' VALUES (10862, 10044, 1);
INSERT INTO 'dancesstepsmap' VALUES (10863, 10045, 4);
INSERT INTO 'dancesstepsmap' VALUES (10864, 10046, 5);
INSERT INTO 'dancesstepsmap' VALUES (10865, 10046, 4);
INSERT INTO 'dancesstepsmap' VALUES (10866, 10047, 1);
INSERT INTO 'dancesstepsmap' VALUES (10867, 10047, 3);
INSERT INTO 'dancesstepsmap' VALUES (10868, 10049, 1);
INSERT INTO 'dancesstepsmap' VALUES (17016, 14435, 2);
INSERT INTO 'dancesstepsmap' VALUES (17017, 14435, 1);
INSERT INTO 'dancesstepsmap' VALUES (2332, 2524, 4);
INSERT INTO 'dancesstepsmap' VALUES (2333, 2525, 4);
INSERT INTO 'dancesstepsmap' VALUES (2334, 2526, 1);
INSERT INTO 'dancesstepsmap' VALUES (2335, 2527, 4);
INSERT INTO 'dancesstepsmap' VALUES (2336, 2528, 1);
INSERT INTO 'dancesstepsmap' VALUES (2337, 2529, 1);
INSERT INTO 'dancesstepsmap' VALUES (2338, 2530, 1);
INSERT INTO 'dancesstepsmap' VALUES (2339, 2531, 1);
INSERT INTO 'dancesstepsmap' VALUES (2340, 2532, 4);
INSERT INTO 'dancesstepsmap' VALUES (2341, 2533, 1);
INSERT INTO 'dancesstepsmap' VALUES (2342, 2534, 4);
INSERT INTO 'dancesstepsmap' VALUES (2343, 2535, 4);
INSERT INTO 'dancesstepsmap' VALUES (2344, 2536, 1);
INSERT INTO 'dancesstepsmap' VALUES (2345, 2537, 1);
INSERT INTO 'dancesstepsmap' VALUES (2346, 2538, 1);
INSERT INTO 'dancesstepsmap' VALUES (2347, 2539, 4);
INSERT INTO 'dancesstepsmap' VALUES (2348, 2541, 1);
INSERT INTO 'dancesstepsmap' VALUES (2349, 2543, 1);
INSERT INTO 'dancesstepsmap' VALUES (2350, 2544, 4);
INSERT INTO 'dancesstepsmap' VALUES (2351, 2545, 1);
INSERT INTO 'dancesstepsmap' VALUES (2352, 2546, 1);
INSERT INTO 'dancesstepsmap' VALUES (2353, 2547, 1);
INSERT INTO 'dancesstepsmap' VALUES (2354, 2548, 4);
INSERT INTO 'dancesstepsmap' VALUES (2355, 2549, 4);
INSERT INTO 'dancesstepsmap' VALUES (2356, 2550, 1);
INSERT INTO 'dancesstepsmap' VALUES (2357, 2551, 1);
INSERT INTO 'dancesstepsmap' VALUES (2358, 2552, 1);
INSERT INTO 'dancesstepsmap' VALUES (2359, 2553, 1);
INSERT INTO 'dancesstepsmap' VALUES (2360, 2554, 1);
INSERT INTO 'dancesstepsmap' VALUES (2361, 2555, 1);
INSERT INTO 'dancesstepsmap' VALUES (2362, 2556, 1);
INSERT INTO 'dancesstepsmap' VALUES (2363, 2557, 1);
INSERT INTO 'dancesstepsmap' VALUES (2364, 2558, 1);
INSERT INTO 'dancesstepsmap' VALUES (2365, 2560, 1);
INSERT INTO 'dancesstepsmap' VALUES (2366, 2561, 1);
INSERT INTO 'dancesstepsmap' VALUES (2367, 2562, 1);
INSERT INTO 'dancesstepsmap' VALUES (2368, 2563, 4);
INSERT INTO 'dancesstepsmap' VALUES (2369, 2564, 4);
INSERT INTO 'dancesstepsmap' VALUES (2370, 2565, 4);
INSERT INTO 'dancesstepsmap' VALUES (2371, 2566, 1);
INSERT INTO 'dancesstepsmap' VALUES (2372, 2567, 4);
INSERT INTO 'dancesstepsmap' VALUES (2373, 2568, 4);
INSERT INTO 'dancesstepsmap' VALUES (2374, 2569, 4);
INSERT INTO 'dancesstepsmap' VALUES (2375, 2570, 4);
INSERT INTO 'dancesstepsmap' VALUES (2376, 2572, 4);
INSERT INTO 'dancesstepsmap' VALUES (2377, 2573, 1);
INSERT INTO 'dancesstepsmap' VALUES (2378, 2574, 1);
INSERT INTO 'dancesstepsmap' VALUES (2379, 2575, 1);
INSERT INTO 'dancesstepsmap' VALUES (2380, 2576, 4);
INSERT INTO 'dancesstepsmap' VALUES (2381, 2577, 1);
INSERT INTO 'dancesstepsmap' VALUES (2382, 2578, 1);
INSERT INTO 'dancesstepsmap' VALUES (2383, 2579, 1);
INSERT INTO 'dancesstepsmap' VALUES (2384, 2581, 4);
INSERT INTO 'dancesstepsmap' VALUES (2385, 2582, 1);
INSERT INTO 'dancesstepsmap' VALUES (2386, 2583, 4);
INSERT INTO 'dancesstepsmap' VALUES (2387, 2584, 4);
INSERT INTO 'dancesstepsmap' VALUES (2388, 2585, 1);
INSERT INTO 'dancesstepsmap' VALUES (2389, 2586, 1);
INSERT INTO 'dancesstepsmap' VALUES (2390, 2587, 1);
INSERT INTO 'dancesstepsmap' VALUES (2391, 2588, 4);
INSERT INTO 'dancesstepsmap' VALUES (2392, 2589, 4);
INSERT INTO 'dancesstepsmap' VALUES (2393, 2590, 1);
INSERT INTO 'dancesstepsmap' VALUES (2394, 2591, 1);
INSERT INTO 'dancesstepsmap' VALUES (2395, 2592, 4);
INSERT INTO 'dancesstepsmap' VALUES (2396, 2593, 1);
INSERT INTO 'dancesstepsmap' VALUES (2397, 2594, 1);
INSERT INTO 'dancesstepsmap' VALUES (2398, 2595, 4);
INSERT INTO 'dancesstepsmap' VALUES (2399, 2596, 1);
INSERT INTO 'dancesstepsmap' VALUES (2400, 2597, 1);
INSERT INTO 'dancesstepsmap' VALUES (2401, 2598, 1);
INSERT INTO 'dancesstepsmap' VALUES (2402, 2599, 1);
INSERT INTO 'dancesstepsmap' VALUES (2403, 2600, 4);
INSERT INTO 'dancesstepsmap' VALUES (2404, 2601, 1);
INSERT INTO 'dancesstepsmap' VALUES (2405, 2602, 4);
INSERT INTO 'dancesstepsmap' VALUES (2406, 2603, 1);
INSERT INTO 'dancesstepsmap' VALUES (2407, 2604, 1);
INSERT INTO 'dancesstepsmap' VALUES (2408, 2605, 1);
INSERT INTO 'dancesstepsmap' VALUES (2409, 2606, 1);
INSERT INTO 'dancesstepsmap' VALUES (2410, 2607, 1);
INSERT INTO 'dancesstepsmap' VALUES (2411, 2608, 1);
INSERT INTO 'dancesstepsmap' VALUES (2412, 2609, 1);
INSERT INTO 'dancesstepsmap' VALUES (2413, 2610, 4);
INSERT INTO 'dancesstepsmap' VALUES (2414, 2611, 4);
INSERT INTO 'dancesstepsmap' VALUES (2415, 2612, 1);
INSERT INTO 'dancesstepsmap' VALUES (2416, 2613, 1);
INSERT INTO 'dancesstepsmap' VALUES (2417, 2615, 1);
INSERT INTO 'dancesstepsmap' VALUES (2418, 2616, 1);
INSERT INTO 'dancesstepsmap' VALUES (2419, 2617, 1);
INSERT INTO 'dancesstepsmap' VALUES (2420, 2618, 1);
INSERT INTO 'dancesstepsmap' VALUES (2421, 2619, 4);
INSERT INTO 'dancesstepsmap' VALUES (2422, 2620, 4);
INSERT INTO 'dancesstepsmap' VALUES (2423, 2621, 1);
INSERT INTO 'dancesstepsmap' VALUES (10869, 10051, 1);
INSERT INTO 'dancesstepsmap' VALUES (10870, 10053, 2);
INSERT INTO 'dancesstepsmap' VALUES (10871, 10053, 1);
INSERT INTO 'dancesstepsmap' VALUES (10872, 10054, 4);
INSERT INTO 'dancesstepsmap' VALUES (10873, 10055, 9);
INSERT INTO 'dancesstepsmap' VALUES (10874, 10055, 5);
INSERT INTO 'dancesstepsmap' VALUES (10875, 10055, 4);
INSERT INTO 'dancesstepsmap' VALUES (10876, 10056, 1);
INSERT INTO 'dancesstepsmap' VALUES (10877, 10057, 1);
INSERT INTO 'dancesstepsmap' VALUES (10878, 10058, 4);
INSERT INTO 'dancesstepsmap' VALUES (10879, 10059, 1);
INSERT INTO 'dancesstepsmap' VALUES (10880, 10061, 1);
INSERT INTO 'dancesstepsmap' VALUES (10881, 10062, 2);
INSERT INTO 'dancesstepsmap' VALUES (10882, 10062, 1);
INSERT INTO 'dancesstepsmap' VALUES (10883, 10064, 1);
INSERT INTO 'dancesstepsmap' VALUES (10884, 10064, 2);
INSERT INTO 'dancesstepsmap' VALUES (10885, 10065, 1);
INSERT INTO 'dancesstepsmap' VALUES (10886, 10066, 4);
INSERT INTO 'dancesstepsmap' VALUES (10887, 10067, 1);
INSERT INTO 'dancesstepsmap' VALUES (10888, 10068, 1);
INSERT INTO 'dancesstepsmap' VALUES (10889, 10057, 3);
INSERT INTO 'dancesstepsmap' VALUES (10890, 10064, 3);
INSERT INTO 'dancesstepsmap' VALUES (10891, 9760, 1);
INSERT INTO 'dancesstepsmap' VALUES (10892, 9760, 2);
INSERT INTO 'dancesstepsmap' VALUES (10893, 10069, 4);
INSERT INTO 'dancesstepsmap' VALUES (10894, 10070, 1);
INSERT INTO 'dancesstepsmap' VALUES (10895, 10070, 3);
INSERT INTO 'dancesstepsmap' VALUES (10896, 10071, 1);
INSERT INTO 'dancesstepsmap' VALUES (10897, 10072, 5);
INSERT INTO 'dancesstepsmap' VALUES (10898, 10072, 4);
INSERT INTO 'dancesstepsmap' VALUES (10899, 10073, 4);
INSERT INTO 'dancesstepsmap' VALUES (10900, 10073, 5);
INSERT INTO 'dancesstepsmap' VALUES (10902, 10075, 2);
INSERT INTO 'dancesstepsmap' VALUES (10903, 9541, 4);
INSERT INTO 'dancesstepsmap' VALUES (10904, 9541, 5);
INSERT INTO 'dancesstepsmap' VALUES (10905, 10076, 1);
INSERT INTO 'dancesstepsmap' VALUES (10906, 10076, 3);
INSERT INTO 'dancesstepsmap' VALUES (10907, 10077, 1);
INSERT INTO 'dancesstepsmap' VALUES (10908, 10011, 1);
INSERT INTO 'dancesstepsmap' VALUES (10909, 10078, 1);
INSERT INTO 'dancesstepsmap' VALUES (10910, 10078, 3);
INSERT INTO 'dancesstepsmap' VALUES (17018, 14436, 4);
INSERT INTO 'dancesstepsmap' VALUES (17019, 14436, 5);
INSERT INTO 'dancesstepsmap' VALUES (17020, 14436, 2);
INSERT INTO 'dancesstepsmap' VALUES (2424, 2622, 1);
INSERT INTO 'dancesstepsmap' VALUES (2425, 2623, 4);
INSERT INTO 'dancesstepsmap' VALUES (2426, 2624, 4);
INSERT INTO 'dancesstepsmap' VALUES (2427, 2626, 1);
INSERT INTO 'dancesstepsmap' VALUES (2428, 2627, 4);
INSERT INTO 'dancesstepsmap' VALUES (2429, 2628, 4);
INSERT INTO 'dancesstepsmap' VALUES (2430, 2629, 1);
INSERT INTO 'dancesstepsmap' VALUES (2431, 2630, 1);
INSERT INTO 'dancesstepsmap' VALUES (2432, 2631, 4);
INSERT INTO 'dancesstepsmap' VALUES (2433, 2632, 4);
INSERT INTO 'dancesstepsmap' VALUES (2434, 2633, 4);
INSERT INTO 'dancesstepsmap' VALUES (2435, 2634, 4);
INSERT INTO 'dancesstepsmap' VALUES (2436, 2635, 3);
INSERT INTO 'dancesstepsmap' VALUES (2437, 2636, 4);
INSERT INTO 'dancesstepsmap' VALUES (2438, 2637, 4);
INSERT INTO 'dancesstepsmap' VALUES (2439, 2638, 1);
INSERT INTO 'dancesstepsmap' VALUES (2440, 2639, 1);
INSERT INTO 'dancesstepsmap' VALUES (2441, 2640, 4);
INSERT INTO 'dancesstepsmap' VALUES (2442, 2642, 1);
INSERT INTO 'dancesstepsmap' VALUES (2443, 2643, 4);
INSERT INTO 'dancesstepsmap' VALUES (2444, 2644, 1);
INSERT INTO 'dancesstepsmap' VALUES (2445, 2645, 4);
INSERT INTO 'dancesstepsmap' VALUES (2446, 2646, 4);
INSERT INTO 'dancesstepsmap' VALUES (2447, 2647, 4);
INSERT INTO 'dancesstepsmap' VALUES (2448, 2648, 1);
INSERT INTO 'dancesstepsmap' VALUES (2449, 2649, 4);
INSERT INTO 'dancesstepsmap' VALUES (2450, 2650, 1);
INSERT INTO 'dancesstepsmap' VALUES (2451, 2651, 1);
INSERT INTO 'dancesstepsmap' VALUES (2452, 2652, 4);
INSERT INTO 'dancesstepsmap' VALUES (2453, 2653, 1);
INSERT INTO 'dancesstepsmap' VALUES (2454, 2654, 4);
INSERT INTO 'dancesstepsmap' VALUES (2455, 2655, 1);
INSERT INTO 'dancesstepsmap' VALUES (2456, 2656, 4);
INSERT INTO 'dancesstepsmap' VALUES (2457, 2657, 1);
INSERT INTO 'dancesstepsmap' VALUES (2458, 2658, 1);
INSERT INTO 'dancesstepsmap' VALUES (2459, 2660, 4);
INSERT INTO 'dancesstepsmap' VALUES (2460, 2661, 4);
INSERT INTO 'dancesstepsmap' VALUES (2461, 2662, 1);
INSERT INTO 'dancesstepsmap' VALUES (2462, 2663, 4);
INSERT INTO 'dancesstepsmap' VALUES (2463, 2665, 1);
INSERT INTO 'dancesstepsmap' VALUES (2464, 2666, 1);
INSERT INTO 'dancesstepsmap' VALUES (2465, 2667, 1);
INSERT INTO 'dancesstepsmap' VALUES (2466, 2669, 1);
INSERT INTO 'dancesstepsmap' VALUES (2467, 2670, 1);
INSERT INTO 'dancesstepsmap' VALUES (2468, 2671, 4);
INSERT INTO 'dancesstepsmap' VALUES (2469, 2672, 1);
INSERT INTO 'dancesstepsmap' VALUES (2470, 2673, 1);
INSERT INTO 'dancesstepsmap' VALUES (2471, 2674, 1);
INSERT INTO 'dancesstepsmap' VALUES (2472, 2675, 1);
INSERT INTO 'dancesstepsmap' VALUES (2473, 2676, 1);
INSERT INTO 'dancesstepsmap' VALUES (2474, 2677, 1);
INSERT INTO 'dancesstepsmap' VALUES (2475, 2678, 1);
INSERT INTO 'dancesstepsmap' VALUES (2476, 2679, 4);
INSERT INTO 'dancesstepsmap' VALUES (2477, 2680, 1);
INSERT INTO 'dancesstepsmap' VALUES (2478, 2681, 1);
INSERT INTO 'dancesstepsmap' VALUES (2479, 2682, 4);
INSERT INTO 'dancesstepsmap' VALUES (2480, 2683, 1);
INSERT INTO 'dancesstepsmap' VALUES (2481, 2684, 1);
INSERT INTO 'dancesstepsmap' VALUES (2482, 2685, 4);
INSERT INTO 'dancesstepsmap' VALUES (2483, 2686, 4);
INSERT INTO 'dancesstepsmap' VALUES (2484, 2687, 4);
INSERT INTO 'dancesstepsmap' VALUES (2485, 2688, 4);
INSERT INTO 'dancesstepsmap' VALUES (2486, 2689, 1);
INSERT INTO 'dancesstepsmap' VALUES (2487, 2690, 1);
INSERT INTO 'dancesstepsmap' VALUES (2488, 2691, 4);
INSERT INTO 'dancesstepsmap' VALUES (2489, 2692, 1);
INSERT INTO 'dancesstepsmap' VALUES (2490, 2693, 1);
INSERT INTO 'dancesstepsmap' VALUES (2491, 2694, 1);
INSERT INTO 'dancesstepsmap' VALUES (2492, 2695, 1);
INSERT INTO 'dancesstepsmap' VALUES (2493, 2696, 4);
INSERT INTO 'dancesstepsmap' VALUES (2494, 2697, 1);
INSERT INTO 'dancesstepsmap' VALUES (2495, 2698, 1);
INSERT INTO 'dancesstepsmap' VALUES (2496, 2699, 1);
INSERT INTO 'dancesstepsmap' VALUES (2497, 2700, 1);
INSERT INTO 'dancesstepsmap' VALUES (2498, 2701, 1);
INSERT INTO 'dancesstepsmap' VALUES (2499, 2702, 4);
INSERT INTO 'dancesstepsmap' VALUES (2500, 2703, 1);
INSERT INTO 'dancesstepsmap' VALUES (2501, 2704, 1);
INSERT INTO 'dancesstepsmap' VALUES (2502, 2705, 4);
INSERT INTO 'dancesstepsmap' VALUES (2503, 2706, 1);
INSERT INTO 'dancesstepsmap' VALUES (2504, 2707, 1);
INSERT INTO 'dancesstepsmap' VALUES (2505, 2708, 1);
INSERT INTO 'dancesstepsmap' VALUES (2506, 2709, 4);
INSERT INTO 'dancesstepsmap' VALUES (2507, 2710, 4);
INSERT INTO 'dancesstepsmap' VALUES (2508, 2711, 1);
INSERT INTO 'dancesstepsmap' VALUES (2509, 2712, 1);
INSERT INTO 'dancesstepsmap' VALUES (2510, 2713, 1);
INSERT INTO 'dancesstepsmap' VALUES (2511, 2714, 1);
INSERT INTO 'dancesstepsmap' VALUES (2512, 2715, 1);
INSERT INTO 'dancesstepsmap' VALUES (2513, 2716, 1);
INSERT INTO 'dancesstepsmap' VALUES (2514, 2717, 1);
INSERT INTO 'dancesstepsmap' VALUES (2515, 2718, 1);
INSERT INTO 'dancesstepsmap' VALUES (2516, 2719, 1);
INSERT INTO 'dancesstepsmap' VALUES (2517, 2720, 4);
INSERT INTO 'dancesstepsmap' VALUES (2519, 2724, 4);
INSERT INTO 'dancesstepsmap' VALUES (2520, 2725, 4);
INSERT INTO 'dancesstepsmap' VALUES (2521, 2726, 4);
INSERT INTO 'dancesstepsmap' VALUES (2522, 2727, 1);
INSERT INTO 'dancesstepsmap' VALUES (2523, 2728, 4);
INSERT INTO 'dancesstepsmap' VALUES (2524, 2729, 1);
INSERT INTO 'dancesstepsmap' VALUES (2525, 2730, 1);
INSERT INTO 'dancesstepsmap' VALUES (2526, 2731, 4);
INSERT INTO 'dancesstepsmap' VALUES (2527, 2732, 1);
INSERT INTO 'dancesstepsmap' VALUES (2528, 2733, 4);
INSERT INTO 'dancesstepsmap' VALUES (2529, 2734, 1);
INSERT INTO 'dancesstepsmap' VALUES (2530, 2735, 1);
INSERT INTO 'dancesstepsmap' VALUES (2531, 2736, 1);
INSERT INTO 'dancesstepsmap' VALUES (2532, 2737, 1);
INSERT INTO 'dancesstepsmap' VALUES (2533, 2738, 4);
INSERT INTO 'dancesstepsmap' VALUES (2534, 2739, 1);
INSERT INTO 'dancesstepsmap' VALUES (2535, 2740, 1);
INSERT INTO 'dancesstepsmap' VALUES (2536, 2741, 1);
INSERT INTO 'dancesstepsmap' VALUES (2537, 2742, 4);
INSERT INTO 'dancesstepsmap' VALUES (2538, 2744, 1);
INSERT INTO 'dancesstepsmap' VALUES (2539, 2746, 1);
INSERT INTO 'dancesstepsmap' VALUES (2540, 2747, 1);
INSERT INTO 'dancesstepsmap' VALUES (2541, 2748, 1);
INSERT INTO 'dancesstepsmap' VALUES (2542, 2749, 4);
INSERT INTO 'dancesstepsmap' VALUES (2543, 2750, 4);
INSERT INTO 'dancesstepsmap' VALUES (2544, 2751, 1);
INSERT INTO 'dancesstepsmap' VALUES (2545, 2752, 1);
INSERT INTO 'dancesstepsmap' VALUES (2546, 2753, 1);
INSERT INTO 'dancesstepsmap' VALUES (2547, 2755, 4);
INSERT INTO 'dancesstepsmap' VALUES (2548, 2756, 1);
INSERT INTO 'dancesstepsmap' VALUES (2549, 2758, 1);
INSERT INTO 'dancesstepsmap' VALUES (2550, 2759, 4);
INSERT INTO 'dancesstepsmap' VALUES (2551, 2760, 4);
INSERT INTO 'dancesstepsmap' VALUES (10911, 10079, 2);
INSERT INTO 'dancesstepsmap' VALUES (10912, 10079, 1);
INSERT INTO 'dancesstepsmap' VALUES (10913, 10080, 4);
INSERT INTO 'dancesstepsmap' VALUES (10914, 10081, 4);
INSERT INTO 'dancesstepsmap' VALUES (10915, 10081, 5);
INSERT INTO 'dancesstepsmap' VALUES (10916, 10082, 4);
INSERT INTO 'dancesstepsmap' VALUES (10917, 10083, 4);
INSERT INTO 'dancesstepsmap' VALUES (10918, 10084, 1);
INSERT INTO 'dancesstepsmap' VALUES (2518, 2723, 5);
INSERT INTO 'dancesstepsmap' VALUES (10919, 10084, 3);
INSERT INTO 'dancesstepsmap' VALUES (10920, 10085, 1);
INSERT INTO 'dancesstepsmap' VALUES (10921, 10086, 4);
INSERT INTO 'dancesstepsmap' VALUES (10922, 10087, 4);
INSERT INTO 'dancesstepsmap' VALUES (10923, 10088, 4);
INSERT INTO 'dancesstepsmap' VALUES (10924, 10088, 5);
INSERT INTO 'dancesstepsmap' VALUES (10925, 10090, 1);
INSERT INTO 'dancesstepsmap' VALUES (10926, 10091, 4);
INSERT INTO 'dancesstepsmap' VALUES (10927, 10092, 2);
INSERT INTO 'dancesstepsmap' VALUES (10928, 10092, 1);
INSERT INTO 'dancesstepsmap' VALUES (17021, 14436, 1);
INSERT INTO 'dancesstepsmap' VALUES (2552, 2761, 4);
INSERT INTO 'dancesstepsmap' VALUES (2553, 2762, 1);
INSERT INTO 'dancesstepsmap' VALUES (2554, 2763, 1);
INSERT INTO 'dancesstepsmap' VALUES (2555, 2764, 4);
INSERT INTO 'dancesstepsmap' VALUES (2556, 2766, 4);
INSERT INTO 'dancesstepsmap' VALUES (2557, 2767, 1);
INSERT INTO 'dancesstepsmap' VALUES (2558, 2768, 1);
INSERT INTO 'dancesstepsmap' VALUES (2559, 2770, 1);
INSERT INTO 'dancesstepsmap' VALUES (2560, 2771, 1);
INSERT INTO 'dancesstepsmap' VALUES (2561, 2772, 4);
INSERT INTO 'dancesstepsmap' VALUES (2562, 2773, 1);
INSERT INTO 'dancesstepsmap' VALUES (2563, 2774, 1);
INSERT INTO 'dancesstepsmap' VALUES (2564, 2775, 1);
INSERT INTO 'dancesstepsmap' VALUES (2565, 2776, 1);
INSERT INTO 'dancesstepsmap' VALUES (2566, 2777, 1);
INSERT INTO 'dancesstepsmap' VALUES (2567, 2778, 4);
INSERT INTO 'dancesstepsmap' VALUES (2568, 2779, 1);
INSERT INTO 'dancesstepsmap' VALUES (2569, 2780, 1);
INSERT INTO 'dancesstepsmap' VALUES (2570, 2781, 1);
INSERT INTO 'dancesstepsmap' VALUES (2571, 2782, 1);
INSERT INTO 'dancesstepsmap' VALUES (2572, 2783, 1);
INSERT INTO 'dancesstepsmap' VALUES (2573, 2784, 1);
INSERT INTO 'dancesstepsmap' VALUES (2574, 2785, 1);
INSERT INTO 'dancesstepsmap' VALUES (2575, 2787, 1);
INSERT INTO 'dancesstepsmap' VALUES (2576, 2788, 1);
INSERT INTO 'dancesstepsmap' VALUES (2577, 2789, 1);
INSERT INTO 'dancesstepsmap' VALUES (2578, 2790, 1);
INSERT INTO 'dancesstepsmap' VALUES (2579, 2791, 1);
INSERT INTO 'dancesstepsmap' VALUES (2580, 2792, 1);
INSERT INTO 'dancesstepsmap' VALUES (2581, 2793, 1);
INSERT INTO 'dancesstepsmap' VALUES (2582, 2794, 1);
INSERT INTO 'dancesstepsmap' VALUES (2583, 2795, 1);
INSERT INTO 'dancesstepsmap' VALUES (2584, 2796, 1);
INSERT INTO 'dancesstepsmap' VALUES (2585, 2797, 1);
INSERT INTO 'dancesstepsmap' VALUES (2586, 2799, 4);
INSERT INTO 'dancesstepsmap' VALUES (2587, 2800, 1);
INSERT INTO 'dancesstepsmap' VALUES (2588, 2801, 1);
INSERT INTO 'dancesstepsmap' VALUES (2589, 2802, 1);
INSERT INTO 'dancesstepsmap' VALUES (2590, 2803, 1);
INSERT INTO 'dancesstepsmap' VALUES (2591, 2804, 1);
INSERT INTO 'dancesstepsmap' VALUES (2592, 2805, 1);
INSERT INTO 'dancesstepsmap' VALUES (2593, 2806, 1);
INSERT INTO 'dancesstepsmap' VALUES (2594, 2807, 1);
INSERT INTO 'dancesstepsmap' VALUES (2595, 2808, 1);
INSERT INTO 'dancesstepsmap' VALUES (2596, 2809, 1);
INSERT INTO 'dancesstepsmap' VALUES (2597, 2811, 1);
INSERT INTO 'dancesstepsmap' VALUES (2598, 2812, 4);
INSERT INTO 'dancesstepsmap' VALUES (2599, 2813, 4);
INSERT INTO 'dancesstepsmap' VALUES (2600, 2814, 4);
INSERT INTO 'dancesstepsmap' VALUES (2601, 2816, 1);
INSERT INTO 'dancesstepsmap' VALUES (2602, 2817, 1);
INSERT INTO 'dancesstepsmap' VALUES (2603, 2818, 4);
INSERT INTO 'dancesstepsmap' VALUES (2604, 2819, 1);
INSERT INTO 'dancesstepsmap' VALUES (2605, 2821, 1);
INSERT INTO 'dancesstepsmap' VALUES (2606, 2822, 1);
INSERT INTO 'dancesstepsmap' VALUES (2607, 2823, 4);
INSERT INTO 'dancesstepsmap' VALUES (2608, 2824, 4);
INSERT INTO 'dancesstepsmap' VALUES (2609, 2825, 1);
INSERT INTO 'dancesstepsmap' VALUES (2610, 2826, 1);
INSERT INTO 'dancesstepsmap' VALUES (2611, 2827, 1);
INSERT INTO 'dancesstepsmap' VALUES (2612, 2828, 1);
INSERT INTO 'dancesstepsmap' VALUES (2613, 2829, 1);
INSERT INTO 'dancesstepsmap' VALUES (2614, 2830, 1);
INSERT INTO 'dancesstepsmap' VALUES (2615, 2831, 4);
INSERT INTO 'dancesstepsmap' VALUES (2616, 2832, 1);
INSERT INTO 'dancesstepsmap' VALUES (2617, 2833, 4);
INSERT INTO 'dancesstepsmap' VALUES (2618, 2834, 4);
INSERT INTO 'dancesstepsmap' VALUES (2619, 2835, 1);
INSERT INTO 'dancesstepsmap' VALUES (2620, 2836, 4);
INSERT INTO 'dancesstepsmap' VALUES (2621, 2837, 1);
INSERT INTO 'dancesstepsmap' VALUES (2622, 2838, 1);
INSERT INTO 'dancesstepsmap' VALUES (2623, 2839, 4);
INSERT INTO 'dancesstepsmap' VALUES (2624, 2840, 4);
INSERT INTO 'dancesstepsmap' VALUES (2625, 2841, 4);
INSERT INTO 'dancesstepsmap' VALUES (2626, 2842, 4);
INSERT INTO 'dancesstepsmap' VALUES (2627, 2843, 1);
INSERT INTO 'dancesstepsmap' VALUES (2628, 2844, 4);
INSERT INTO 'dancesstepsmap' VALUES (2629, 2847, 4);
INSERT INTO 'dancesstepsmap' VALUES (2630, 2848, 1);
INSERT INTO 'dancesstepsmap' VALUES (2631, 2849, 1);
INSERT INTO 'dancesstepsmap' VALUES (2632, 2850, 1);
INSERT INTO 'dancesstepsmap' VALUES (2633, 2851, 1);
INSERT INTO 'dancesstepsmap' VALUES (2634, 2853, 4);
INSERT INTO 'dancesstepsmap' VALUES (2635, 2854, 4);
INSERT INTO 'dancesstepsmap' VALUES (2636, 2855, 1);
INSERT INTO 'dancesstepsmap' VALUES (2637, 2856, 4);
INSERT INTO 'dancesstepsmap' VALUES (2638, 2857, 4);
INSERT INTO 'dancesstepsmap' VALUES (2639, 2858, 1);
INSERT INTO 'dancesstepsmap' VALUES (2640, 2859, 1);
INSERT INTO 'dancesstepsmap' VALUES (2641, 2860, 1);
INSERT INTO 'dancesstepsmap' VALUES (2642, 2861, 1);
INSERT INTO 'dancesstepsmap' VALUES (2643, 2862, 4);
INSERT INTO 'dancesstepsmap' VALUES (2644, 2863, 1);
INSERT INTO 'dancesstepsmap' VALUES (10929, 10093, 4);
INSERT INTO 'dancesstepsmap' VALUES (10930, 10094, 3);
INSERT INTO 'dancesstepsmap' VALUES (10931, 10094, 1);
INSERT INTO 'dancesstepsmap' VALUES (10932, 10095, 1);
INSERT INTO 'dancesstepsmap' VALUES (10933, 10095, 3);
INSERT INTO 'dancesstepsmap' VALUES (10934, 10096, 1);
INSERT INTO 'dancesstepsmap' VALUES (10935, 10097, 1);
INSERT INTO 'dancesstepsmap' VALUES (10936, 10098, 1);
INSERT INTO 'dancesstepsmap' VALUES (10937, 10098, 3);
INSERT INTO 'dancesstepsmap' VALUES (10938, 10099, 4);
INSERT INTO 'dancesstepsmap' VALUES (10940, 10103, 1);
INSERT INTO 'dancesstepsmap' VALUES (10941, 10103, 2);
INSERT INTO 'dancesstepsmap' VALUES (10942, 10104, 2);
INSERT INTO 'dancesstepsmap' VALUES (10943, 10104, 1);
INSERT INTO 'dancesstepsmap' VALUES (10944, 10105, 1);
INSERT INTO 'dancesstepsmap' VALUES (10945, 10106, 2);
INSERT INTO 'dancesstepsmap' VALUES (10946, 10106, 3);
INSERT INTO 'dancesstepsmap' VALUES (10947, 10106, 1);
INSERT INTO 'dancesstepsmap' VALUES (10948, 10108, 4);
INSERT INTO 'dancesstepsmap' VALUES (10949, 10109, 9);
INSERT INTO 'dancesstepsmap' VALUES (10950, 10109, 10);
INSERT INTO 'dancesstepsmap' VALUES (10952, 10111, 4);
INSERT INTO 'dancesstepsmap' VALUES (10953, 10112, 1);
INSERT INTO 'dancesstepsmap' VALUES (10954, 10113, 4);
INSERT INTO 'dancesstepsmap' VALUES (10955, 10114, 2);
INSERT INTO 'dancesstepsmap' VALUES (10956, 10114, 1);
INSERT INTO 'dancesstepsmap' VALUES (10957, 5009, 3);
INSERT INTO 'dancesstepsmap' VALUES (10958, 10115, 1);
INSERT INTO 'dancesstepsmap' VALUES (10959, 10115, 2);
INSERT INTO 'dancesstepsmap' VALUES (10960, 10116, 2);
INSERT INTO 'dancesstepsmap' VALUES (10961, 10116, 1);
INSERT INTO 'dancesstepsmap' VALUES (10962, 10117, 1);
INSERT INTO 'dancesstepsmap' VALUES (10963, 10119, 4);
INSERT INTO 'dancesstepsmap' VALUES (10964, 10120, 4);
INSERT INTO 'dancesstepsmap' VALUES (10965, 10121, 2);
INSERT INTO 'dancesstepsmap' VALUES (10966, 10122, 3);
INSERT INTO 'dancesstepsmap' VALUES (10967, 10123, 4);
INSERT INTO 'dancesstepsmap' VALUES (10968, 10124, 1);
INSERT INTO 'dancesstepsmap' VALUES (10969, 10124, 2);
INSERT INTO 'dancesstepsmap' VALUES (10970, 10125, 1);
INSERT INTO 'dancesstepsmap' VALUES (10971, 10125, 3);
INSERT INTO 'dancesstepsmap' VALUES (17022, 14436, 3);
INSERT INTO 'dancesstepsmap' VALUES (2645, 2864, 4);
INSERT INTO 'dancesstepsmap' VALUES (2646, 2865, 1);
INSERT INTO 'dancesstepsmap' VALUES (2647, 2866, 1);
INSERT INTO 'dancesstepsmap' VALUES (2648, 2869, 1);
INSERT INTO 'dancesstepsmap' VALUES (2649, 2870, 1);
INSERT INTO 'dancesstepsmap' VALUES (2650, 2871, 1);
INSERT INTO 'dancesstepsmap' VALUES (2651, 2872, 1);
INSERT INTO 'dancesstepsmap' VALUES (2652, 2873, 1);
INSERT INTO 'dancesstepsmap' VALUES (2653, 2874, 1);
INSERT INTO 'dancesstepsmap' VALUES (2654, 2875, 1);
INSERT INTO 'dancesstepsmap' VALUES (2655, 2876, 1);
INSERT INTO 'dancesstepsmap' VALUES (2656, 2877, 1);
INSERT INTO 'dancesstepsmap' VALUES (2657, 2878, 1);
INSERT INTO 'dancesstepsmap' VALUES (2658, 2879, 1);
INSERT INTO 'dancesstepsmap' VALUES (2659, 2880, 1);
INSERT INTO 'dancesstepsmap' VALUES (2660, 2881, 1);
INSERT INTO 'dancesstepsmap' VALUES (2661, 2882, 1);
INSERT INTO 'dancesstepsmap' VALUES (2662, 2883, 4);
INSERT INTO 'dancesstepsmap' VALUES (2663, 2884, 4);
INSERT INTO 'dancesstepsmap' VALUES (2664, 2885, 1);
INSERT INTO 'dancesstepsmap' VALUES (2665, 2886, 1);
INSERT INTO 'dancesstepsmap' VALUES (2666, 2887, 1);
INSERT INTO 'dancesstepsmap' VALUES (2667, 2888, 1);
INSERT INTO 'dancesstepsmap' VALUES (2668, 2889, 4);
INSERT INTO 'dancesstepsmap' VALUES (2669, 2890, 4);
INSERT INTO 'dancesstepsmap' VALUES (2670, 2891, 4);
INSERT INTO 'dancesstepsmap' VALUES (2671, 2892, 1);
INSERT INTO 'dancesstepsmap' VALUES (2672, 2893, 4);
INSERT INTO 'dancesstepsmap' VALUES (2673, 2894, 1);
INSERT INTO 'dancesstepsmap' VALUES (2674, 2895, 1);
INSERT INTO 'dancesstepsmap' VALUES (2675, 2896, 4);
INSERT INTO 'dancesstepsmap' VALUES (2676, 2897, 1);
INSERT INTO 'dancesstepsmap' VALUES (2677, 2898, 1);
INSERT INTO 'dancesstepsmap' VALUES (2678, 2899, 1);
INSERT INTO 'dancesstepsmap' VALUES (2679, 2900, 1);
INSERT INTO 'dancesstepsmap' VALUES (2680, 2901, 1);
INSERT INTO 'dancesstepsmap' VALUES (2681, 2902, 1);
INSERT INTO 'dancesstepsmap' VALUES (2682, 2903, 1);
INSERT INTO 'dancesstepsmap' VALUES (2683, 2904, 1);
INSERT INTO 'dancesstepsmap' VALUES (2684, 2905, 1);
INSERT INTO 'dancesstepsmap' VALUES (2685, 2906, 1);
INSERT INTO 'dancesstepsmap' VALUES (2686, 2908, 1);
INSERT INTO 'dancesstepsmap' VALUES (2687, 2909, 1);
INSERT INTO 'dancesstepsmap' VALUES (2688, 2910, 1);
INSERT INTO 'dancesstepsmap' VALUES (2689, 2911, 4);
INSERT INTO 'dancesstepsmap' VALUES (2690, 2913, 1);
INSERT INTO 'dancesstepsmap' VALUES (2691, 2915, 1);
INSERT INTO 'dancesstepsmap' VALUES (2692, 2916, 1);
INSERT INTO 'dancesstepsmap' VALUES (2693, 2917, 1);
INSERT INTO 'dancesstepsmap' VALUES (2694, 2918, 1);
INSERT INTO 'dancesstepsmap' VALUES (2695, 2919, 1);
INSERT INTO 'dancesstepsmap' VALUES (2696, 2920, 1);
INSERT INTO 'dancesstepsmap' VALUES (2697, 2921, 1);
INSERT INTO 'dancesstepsmap' VALUES (2698, 2924, 1);
INSERT INTO 'dancesstepsmap' VALUES (2699, 2925, 1);
INSERT INTO 'dancesstepsmap' VALUES (2700, 2926, 4);
INSERT INTO 'dancesstepsmap' VALUES (2701, 2927, 1);
INSERT INTO 'dancesstepsmap' VALUES (2702, 2928, 1);
INSERT INTO 'dancesstepsmap' VALUES (2703, 2929, 1);
INSERT INTO 'dancesstepsmap' VALUES (2704, 2930, 1);
INSERT INTO 'dancesstepsmap' VALUES (2705, 2931, 1);
INSERT INTO 'dancesstepsmap' VALUES (2706, 2932, 4);
INSERT INTO 'dancesstepsmap' VALUES (2707, 2933, 1);
INSERT INTO 'dancesstepsmap' VALUES (2708, 2934, 1);
INSERT INTO 'dancesstepsmap' VALUES (2709, 2935, 1);
INSERT INTO 'dancesstepsmap' VALUES (2710, 2936, 1);
INSERT INTO 'dancesstepsmap' VALUES (2711, 2937, 1);
INSERT INTO 'dancesstepsmap' VALUES (2713, 2939, 1);
INSERT INTO 'dancesstepsmap' VALUES (2714, 2940, 4);
INSERT INTO 'dancesstepsmap' VALUES (2715, 2941, 1);
INSERT INTO 'dancesstepsmap' VALUES (2716, 2942, 4);
INSERT INTO 'dancesstepsmap' VALUES (2717, 2943, 4);
INSERT INTO 'dancesstepsmap' VALUES (2718, 2944, 4);
INSERT INTO 'dancesstepsmap' VALUES (2719, 2945, 1);
INSERT INTO 'dancesstepsmap' VALUES (2720, 2946, 1);
INSERT INTO 'dancesstepsmap' VALUES (2721, 2947, 1);
INSERT INTO 'dancesstepsmap' VALUES (2722, 2948, 1);
INSERT INTO 'dancesstepsmap' VALUES (2723, 2950, 1);
INSERT INTO 'dancesstepsmap' VALUES (2724, 2951, 1);
INSERT INTO 'dancesstepsmap' VALUES (2725, 2952, 1);
INSERT INTO 'dancesstepsmap' VALUES (2726, 2953, 1);
INSERT INTO 'dancesstepsmap' VALUES (2727, 2954, 4);
INSERT INTO 'dancesstepsmap' VALUES (2728, 2955, 1);
INSERT INTO 'dancesstepsmap' VALUES (2729, 2956, 1);
INSERT INTO 'dancesstepsmap' VALUES (2730, 2957, 1);
INSERT INTO 'dancesstepsmap' VALUES (2731, 2959, 1);
INSERT INTO 'dancesstepsmap' VALUES (2732, 2960, 4);
INSERT INTO 'dancesstepsmap' VALUES (2733, 2961, 1);
INSERT INTO 'dancesstepsmap' VALUES (2734, 2962, 1);
INSERT INTO 'dancesstepsmap' VALUES (2735, 2963, 4);
INSERT INTO 'dancesstepsmap' VALUES (2736, 2964, 1);
INSERT INTO 'dancesstepsmap' VALUES (2737, 2965, 1);
INSERT INTO 'dancesstepsmap' VALUES (10972, 10127, 1);
INSERT INTO 'dancesstepsmap' VALUES (10973, 10128, 2);
INSERT INTO 'dancesstepsmap' VALUES (10974, 10128, 3);
INSERT INTO 'dancesstepsmap' VALUES (10975, 10129, 3);
INSERT INTO 'dancesstepsmap' VALUES (10976, 10130, 4);
INSERT INTO 'dancesstepsmap' VALUES (10977, 10130, 5);
INSERT INTO 'dancesstepsmap' VALUES (10978, 10132, 1);
INSERT INTO 'dancesstepsmap' VALUES (10979, 10132, 3);
INSERT INTO 'dancesstepsmap' VALUES (10980, 10133, 4);
INSERT INTO 'dancesstepsmap' VALUES (10981, 10133, 5);
INSERT INTO 'dancesstepsmap' VALUES (10982, 10134, 1);
INSERT INTO 'dancesstepsmap' VALUES (10983, 10135, 1);
INSERT INTO 'dancesstepsmap' VALUES (10984, 10135, 2);
INSERT INTO 'dancesstepsmap' VALUES (10985, 10136, 1);
INSERT INTO 'dancesstepsmap' VALUES (10986, 10136, 3);
INSERT INTO 'dancesstepsmap' VALUES (10987, 10137, 1);
INSERT INTO 'dancesstepsmap' VALUES (10988, 10138, 4);
INSERT INTO 'dancesstepsmap' VALUES (10989, 10139, 1);
INSERT INTO 'dancesstepsmap' VALUES (10990, 10140, 4);
INSERT INTO 'dancesstepsmap' VALUES (10991, 10140, 5);
INSERT INTO 'dancesstepsmap' VALUES (10992, 10089, 4);
INSERT INTO 'dancesstepsmap' VALUES (10993, 9814, 4);
INSERT INTO 'dancesstepsmap' VALUES (10994, 9815, 1);
INSERT INTO 'dancesstepsmap' VALUES (10995, 9816, 4);
INSERT INTO 'dancesstepsmap' VALUES (10996, 9816, 5);
INSERT INTO 'dancesstepsmap' VALUES (10997, 9817, 1);
INSERT INTO 'dancesstepsmap' VALUES (10998, 9022, 4);
INSERT INTO 'dancesstepsmap' VALUES (10999, 9022, 5);
INSERT INTO 'dancesstepsmap' VALUES (11000, 9819, 1);
INSERT INTO 'dancesstepsmap' VALUES (11001, 9819, 3);
INSERT INTO 'dancesstepsmap' VALUES (11003, 10186, 1);
INSERT INTO 'dancesstepsmap' VALUES (11004, 10186, 2);
INSERT INTO 'dancesstepsmap' VALUES (11005, 10186, 4);
INSERT INTO 'dancesstepsmap' VALUES (11006, 10186, 5);
INSERT INTO 'dancesstepsmap' VALUES (11007, 10187, 4);
INSERT INTO 'dancesstepsmap' VALUES (11008, 10187, 5);
INSERT INTO 'dancesstepsmap' VALUES (11009, 10188, 1);
INSERT INTO 'dancesstepsmap' VALUES (11010, 10188, 3);
INSERT INTO 'dancesstepsmap' VALUES (11011, 10188, 2);
INSERT INTO 'dancesstepsmap' VALUES (11012, 9844, 2);
INSERT INTO 'dancesstepsmap' VALUES (11013, 9848, 5);
INSERT INTO 'dancesstepsmap' VALUES (11014, 9851, 1);
INSERT INTO 'dancesstepsmap' VALUES (17023, 14437, 1);
INSERT INTO 'dancesstepsmap' VALUES (17024, 14437, 2);
INSERT INTO 'dancesstepsmap' VALUES (17025, 14437, 3);
INSERT INTO 'dancesstepsmap' VALUES (17030, 14440, 4);
INSERT INTO 'dancesstepsmap' VALUES (17031, 14440, 6);
INSERT INTO 'dancesstepsmap' VALUES (17032, 5474, 5);
INSERT INTO 'dancesstepsmap' VALUES (17033, 4890, 5);
INSERT INTO 'dancesstepsmap' VALUES (17034, 4411, 5);
INSERT INTO 'dancesstepsmap' VALUES (17035, 14482, 5);
INSERT INTO 'dancesstepsmap' VALUES (17036, 14482, 4);
INSERT INTO 'dancesstepsmap' VALUES (17037, 14482, 6);
INSERT INTO 'dancesstepsmap' VALUES (17038, 7090, 2);
INSERT INTO 'dancesstepsmap' VALUES (17039, 7090, 3);
INSERT INTO 'dancesstepsmap' VALUES (17040, 11949, 2);
INSERT INTO 'dancesstepsmap' VALUES (17045, 4619, 3);
INSERT INTO 'dancesstepsmap' VALUES (17046, 5908, 2);
INSERT INTO 'dancesstepsmap' VALUES (17048, 14485, 5);
INSERT INTO 'dancesstepsmap' VALUES (17049, 14485, 4);
INSERT INTO 'dancesstepsmap' VALUES (17054, 14487, 2);
INSERT INTO 'dancesstepsmap' VALUES (17055, 14487, 1);
INSERT INTO 'dancesstepsmap' VALUES (17056, 14487, 3);
INSERT INTO 'dancesstepsmap' VALUES (2738, 2966, 1);
INSERT INTO 'dancesstepsmap' VALUES (2739, 2967, 1);
INSERT INTO 'dancesstepsmap' VALUES (2740, 2968, 4);
INSERT INTO 'dancesstepsmap' VALUES (2741, 2970, 1);
INSERT INTO 'dancesstepsmap' VALUES (2742, 2971, 4);
INSERT INTO 'dancesstepsmap' VALUES (2743, 2972, 1);
INSERT INTO 'dancesstepsmap' VALUES (2744, 2973, 4);
INSERT INTO 'dancesstepsmap' VALUES (2745, 2974, 4);
INSERT INTO 'dancesstepsmap' VALUES (2746, 2975, 4);
INSERT INTO 'dancesstepsmap' VALUES (2747, 2977, 1);
INSERT INTO 'dancesstepsmap' VALUES (2748, 2978, 1);
INSERT INTO 'dancesstepsmap' VALUES (2749, 2979, 1);
INSERT INTO 'dancesstepsmap' VALUES (2750, 2980, 1);
INSERT INTO 'dancesstepsmap' VALUES (2751, 2981, 1);
INSERT INTO 'dancesstepsmap' VALUES (2752, 2982, 4);
INSERT INTO 'dancesstepsmap' VALUES (2753, 2983, 1);
INSERT INTO 'dancesstepsmap' VALUES (2754, 2984, 1);
INSERT INTO 'dancesstepsmap' VALUES (2755, 2985, 1);
INSERT INTO 'dancesstepsmap' VALUES (2756, 2986, 1);
INSERT INTO 'dancesstepsmap' VALUES (2757, 2987, 4);
INSERT INTO 'dancesstepsmap' VALUES (2758, 2990, 1);
INSERT INTO 'dancesstepsmap' VALUES (2759, 2991, 1);
INSERT INTO 'dancesstepsmap' VALUES (2760, 2992, 1);
INSERT INTO 'dancesstepsmap' VALUES (2761, 2993, 1);
INSERT INTO 'dancesstepsmap' VALUES (2762, 2994, 1);
INSERT INTO 'dancesstepsmap' VALUES (2763, 2995, 4);
INSERT INTO 'dancesstepsmap' VALUES (2764, 2996, 1);
INSERT INTO 'dancesstepsmap' VALUES (2765, 2997, 1);
INSERT INTO 'dancesstepsmap' VALUES (2766, 2998, 4);
INSERT INTO 'dancesstepsmap' VALUES (2767, 2999, 1);
INSERT INTO 'dancesstepsmap' VALUES (2768, 3000, 1);
INSERT INTO 'dancesstepsmap' VALUES (2769, 3001, 4);
INSERT INTO 'dancesstepsmap' VALUES (2770, 3002, 4);
INSERT INTO 'dancesstepsmap' VALUES (2771, 3003, 1);
INSERT INTO 'dancesstepsmap' VALUES (2772, 3004, 1);
INSERT INTO 'dancesstepsmap' VALUES (2773, 3005, 1);
INSERT INTO 'dancesstepsmap' VALUES (2774, 3006, 1);
INSERT INTO 'dancesstepsmap' VALUES (2775, 3007, 4);
INSERT INTO 'dancesstepsmap' VALUES (2776, 3009, 4);
INSERT INTO 'dancesstepsmap' VALUES (2777, 3010, 1);
INSERT INTO 'dancesstepsmap' VALUES (2778, 3011, 4);
INSERT INTO 'dancesstepsmap' VALUES (2779, 3012, 1);
INSERT INTO 'dancesstepsmap' VALUES (2780, 3013, 1);
INSERT INTO 'dancesstepsmap' VALUES (2781, 3014, 1);
INSERT INTO 'dancesstepsmap' VALUES (2782, 3015, 1);
INSERT INTO 'dancesstepsmap' VALUES (2783, 3016, 1);
INSERT INTO 'dancesstepsmap' VALUES (2784, 3017, 1);
INSERT INTO 'dancesstepsmap' VALUES (2785, 3018, 1);
INSERT INTO 'dancesstepsmap' VALUES (2786, 3019, 4);
INSERT INTO 'dancesstepsmap' VALUES (2787, 3021, 1);
INSERT INTO 'dancesstepsmap' VALUES (2788, 3022, 4);
INSERT INTO 'dancesstepsmap' VALUES (2789, 3023, 1);
INSERT INTO 'dancesstepsmap' VALUES (2790, 3024, 4);
INSERT INTO 'dancesstepsmap' VALUES (2791, 3025, 1);
INSERT INTO 'dancesstepsmap' VALUES (2792, 3026, 1);
INSERT INTO 'dancesstepsmap' VALUES (2793, 3027, 1);
INSERT INTO 'dancesstepsmap' VALUES (2794, 3028, 4);
INSERT INTO 'dancesstepsmap' VALUES (2795, 3029, 1);
INSERT INTO 'dancesstepsmap' VALUES (2796, 3031, 4);
INSERT INTO 'dancesstepsmap' VALUES (2797, 3032, 1);
INSERT INTO 'dancesstepsmap' VALUES (2798, 3033, 1);
INSERT INTO 'dancesstepsmap' VALUES (2799, 3034, 1);
INSERT INTO 'dancesstepsmap' VALUES (2800, 3035, 1);
INSERT INTO 'dancesstepsmap' VALUES (2801, 3036, 1);
INSERT INTO 'dancesstepsmap' VALUES (2802, 3037, 4);
INSERT INTO 'dancesstepsmap' VALUES (2803, 3038, 4);
INSERT INTO 'dancesstepsmap' VALUES (2804, 3039, 1);
INSERT INTO 'dancesstepsmap' VALUES (2805, 3040, 1);
INSERT INTO 'dancesstepsmap' VALUES (2806, 3041, 4);
INSERT INTO 'dancesstepsmap' VALUES (2807, 3042, 4);
INSERT INTO 'dancesstepsmap' VALUES (2808, 3044, 1);
INSERT INTO 'dancesstepsmap' VALUES (2809, 3045, 4);
INSERT INTO 'dancesstepsmap' VALUES (2810, 3046, 1);
INSERT INTO 'dancesstepsmap' VALUES (2811, 3047, 1);
INSERT INTO 'dancesstepsmap' VALUES (2812, 3048, 4);
INSERT INTO 'dancesstepsmap' VALUES (2813, 3049, 1);
INSERT INTO 'dancesstepsmap' VALUES (2814, 3050, 4);
INSERT INTO 'dancesstepsmap' VALUES (2815, 3051, 1);
INSERT INTO 'dancesstepsmap' VALUES (2816, 3052, 4);
INSERT INTO 'dancesstepsmap' VALUES (2817, 3053, 1);
INSERT INTO 'dancesstepsmap' VALUES (2818, 3054, 1);
INSERT INTO 'dancesstepsmap' VALUES (2819, 3055, 1);
INSERT INTO 'dancesstepsmap' VALUES (2820, 3056, 4);
INSERT INTO 'dancesstepsmap' VALUES (2821, 3057, 1);
INSERT INTO 'dancesstepsmap' VALUES (2824, 3060, 1);
INSERT INTO 'dancesstepsmap' VALUES (2825, 3061, 1);
INSERT INTO 'dancesstepsmap' VALUES (2826, 3062, 4);
INSERT INTO 'dancesstepsmap' VALUES (2827, 3063, 4);
INSERT INTO 'dancesstepsmap' VALUES (2828, 3064, 1);
INSERT INTO 'dancesstepsmap' VALUES (2829, 3065, 1);
INSERT INTO 'dancesstepsmap' VALUES (2830, 3066, 1);
INSERT INTO 'dancesstepsmap' VALUES (11015, 9851, 2);
INSERT INTO 'dancesstepsmap' VALUES (11017, 9857, 1);
INSERT INTO 'dancesstepsmap' VALUES (11018, 9899, 1);
INSERT INTO 'dancesstepsmap' VALUES (11019, 10052, 1);
INSERT INTO 'dancesstepsmap' VALUES (11020, 10189, 4);
INSERT INTO 'dancesstepsmap' VALUES (11021, 10190, 1);
INSERT INTO 'dancesstepsmap' VALUES (11022, 10190, 2);
INSERT INTO 'dancesstepsmap' VALUES (11023, 10192, 3);
INSERT INTO 'dancesstepsmap' VALUES (11024, 10192, 1);
INSERT INTO 'dancesstepsmap' VALUES (11025, 6104, 4);
INSERT INTO 'dancesstepsmap' VALUES (11026, 10195, 4);
INSERT INTO 'dancesstepsmap' VALUES (11027, 10195, 5);
INSERT INTO 'dancesstepsmap' VALUES (11028, 10151, 2);
INSERT INTO 'dancesstepsmap' VALUES (11029, 10151, 3);
INSERT INTO 'dancesstepsmap' VALUES (11030, 10153, 4);
INSERT INTO 'dancesstepsmap' VALUES (11031, 10230, 4);
INSERT INTO 'dancesstepsmap' VALUES (11032, 10231, 2);
INSERT INTO 'dancesstepsmap' VALUES (11033, 10231, 1);
INSERT INTO 'dancesstepsmap' VALUES (11034, 8853, 4);
INSERT INTO 'dancesstepsmap' VALUES (11035, 10232, 1);
INSERT INTO 'dancesstepsmap' VALUES (11036, 10232, 2);
INSERT INTO 'dancesstepsmap' VALUES (11037, 696, 3);
INSERT INTO 'dancesstepsmap' VALUES (11038, 5939, 3);
INSERT INTO 'dancesstepsmap' VALUES (11039, 10236, 1);
INSERT INTO 'dancesstepsmap' VALUES (11040, 10236, 2);
INSERT INTO 'dancesstepsmap' VALUES (11041, 10237, 4);
INSERT INTO 'dancesstepsmap' VALUES (11042, 10238, 1);
INSERT INTO 'dancesstepsmap' VALUES (11043, 10239, 4);
INSERT INTO 'dancesstepsmap' VALUES (11044, 10241, 4);
INSERT INTO 'dancesstepsmap' VALUES (11045, 10242, 4);
INSERT INTO 'dancesstepsmap' VALUES (11046, 10243, 1);
INSERT INTO 'dancesstepsmap' VALUES (11047, 10243, 2);
INSERT INTO 'dancesstepsmap' VALUES (11048, 10244, 1);
INSERT INTO 'dancesstepsmap' VALUES (11049, 10245, 1);
INSERT INTO 'dancesstepsmap' VALUES (11050, 10247, 4);
INSERT INTO 'dancesstepsmap' VALUES (11051, 10247, 5);
INSERT INTO 'dancesstepsmap' VALUES (11052, 10248, 1);
INSERT INTO 'dancesstepsmap' VALUES (11053, 10248, 2);
INSERT INTO 'dancesstepsmap' VALUES (11054, 10249, 1);
INSERT INTO 'dancesstepsmap' VALUES (11055, 10249, 2);
INSERT INTO 'dancesstepsmap' VALUES (11056, 10250, 1);
INSERT INTO 'dancesstepsmap' VALUES (17026, 14438, 5);
INSERT INTO 'dancesstepsmap' VALUES (17027, 14438, 4);
INSERT INTO 'dancesstepsmap' VALUES (17041, 5625, 2);
INSERT INTO 'dancesstepsmap' VALUES (17050, 14486, 1);
INSERT INTO 'dancesstepsmap' VALUES (17051, 14486, 2);
INSERT INTO 'dancesstepsmap' VALUES (17052, 14486, 5);
INSERT INTO 'dancesstepsmap' VALUES (17057, 14488, 1);
INSERT INTO 'dancesstepsmap' VALUES (17058, 14488, 2);
INSERT INTO 'dancesstepsmap' VALUES (17059, 14488, 3);
INSERT INTO 'dancesstepsmap' VALUES (2831, 3067, 4);
INSERT INTO 'dancesstepsmap' VALUES (2833, 3070, 4);
INSERT INTO 'dancesstepsmap' VALUES (2834, 3071, 1);
INSERT INTO 'dancesstepsmap' VALUES (2835, 3072, 1);
INSERT INTO 'dancesstepsmap' VALUES (2836, 3073, 1);
INSERT INTO 'dancesstepsmap' VALUES (2837, 3075, 4);
INSERT INTO 'dancesstepsmap' VALUES (2838, 3076, 4);
INSERT INTO 'dancesstepsmap' VALUES (2839, 3077, 1);
INSERT INTO 'dancesstepsmap' VALUES (2840, 3078, 4);
INSERT INTO 'dancesstepsmap' VALUES (2841, 3079, 4);
INSERT INTO 'dancesstepsmap' VALUES (2842, 3080, 4);
INSERT INTO 'dancesstepsmap' VALUES (2843, 3081, 4);
INSERT INTO 'dancesstepsmap' VALUES (2844, 3082, 4);
INSERT INTO 'dancesstepsmap' VALUES (2845, 3083, 1);
INSERT INTO 'dancesstepsmap' VALUES (2846, 3084, 4);
INSERT INTO 'dancesstepsmap' VALUES (2847, 3085, 1);
INSERT INTO 'dancesstepsmap' VALUES (2848, 3086, 1);
INSERT INTO 'dancesstepsmap' VALUES (2849, 3087, 1);
INSERT INTO 'dancesstepsmap' VALUES (2850, 3088, 1);
INSERT INTO 'dancesstepsmap' VALUES (2851, 3089, 1);
INSERT INTO 'dancesstepsmap' VALUES (2852, 3090, 1);
INSERT INTO 'dancesstepsmap' VALUES (2853, 3091, 4);
INSERT INTO 'dancesstepsmap' VALUES (2854, 3092, 1);
INSERT INTO 'dancesstepsmap' VALUES (2855, 3093, 4);
INSERT INTO 'dancesstepsmap' VALUES (2856, 3094, 4);
INSERT INTO 'dancesstepsmap' VALUES (2857, 3095, 1);
INSERT INTO 'dancesstepsmap' VALUES (2858, 3096, 1);
INSERT INTO 'dancesstepsmap' VALUES (2859, 3097, 4);
INSERT INTO 'dancesstepsmap' VALUES (2860, 3098, 1);
INSERT INTO 'dancesstepsmap' VALUES (2861, 3099, 1);
INSERT INTO 'dancesstepsmap' VALUES (2862, 3100, 4);
INSERT INTO 'dancesstepsmap' VALUES (2863, 3101, 1);
INSERT INTO 'dancesstepsmap' VALUES (2864, 3102, 1);
INSERT INTO 'dancesstepsmap' VALUES (2865, 3103, 1);
INSERT INTO 'dancesstepsmap' VALUES (2866, 3104, 4);
INSERT INTO 'dancesstepsmap' VALUES (2867, 3105, 4);
INSERT INTO 'dancesstepsmap' VALUES (2868, 3106, 4);
INSERT INTO 'dancesstepsmap' VALUES (2869, 3107, 1);
INSERT INTO 'dancesstepsmap' VALUES (2870, 3108, 1);
INSERT INTO 'dancesstepsmap' VALUES (2871, 3109, 1);
INSERT INTO 'dancesstepsmap' VALUES (2872, 3110, 1);
INSERT INTO 'dancesstepsmap' VALUES (2873, 3111, 1);
INSERT INTO 'dancesstepsmap' VALUES (2874, 3112, 4);
INSERT INTO 'dancesstepsmap' VALUES (2875, 3113, 4);
INSERT INTO 'dancesstepsmap' VALUES (2876, 3115, 1);
INSERT INTO 'dancesstepsmap' VALUES (2877, 3116, 4);
INSERT INTO 'dancesstepsmap' VALUES (2878, 3117, 4);
INSERT INTO 'dancesstepsmap' VALUES (2879, 3118, 4);
INSERT INTO 'dancesstepsmap' VALUES (2880, 3120, 1);
INSERT INTO 'dancesstepsmap' VALUES (2881, 3121, 4);
INSERT INTO 'dancesstepsmap' VALUES (2882, 3122, 1);
INSERT INTO 'dancesstepsmap' VALUES (2883, 3123, 4);
INSERT INTO 'dancesstepsmap' VALUES (2884, 3125, 1);
INSERT INTO 'dancesstepsmap' VALUES (2885, 3126, 4);
INSERT INTO 'dancesstepsmap' VALUES (2886, 3127, 1);
INSERT INTO 'dancesstepsmap' VALUES (2887, 3128, 1);
INSERT INTO 'dancesstepsmap' VALUES (2888, 3129, 1);
INSERT INTO 'dancesstepsmap' VALUES (2889, 3130, 4);
INSERT INTO 'dancesstepsmap' VALUES (2890, 3131, 1);
INSERT INTO 'dancesstepsmap' VALUES (2891, 3132, 4);
INSERT INTO 'dancesstepsmap' VALUES (2892, 3133, 4);
INSERT INTO 'dancesstepsmap' VALUES (2893, 3134, 4);
INSERT INTO 'dancesstepsmap' VALUES (2894, 3135, 1);
INSERT INTO 'dancesstepsmap' VALUES (2895, 3136, 1);
INSERT INTO 'dancesstepsmap' VALUES (2896, 3137, 4);
INSERT INTO 'dancesstepsmap' VALUES (2897, 3138, 1);
INSERT INTO 'dancesstepsmap' VALUES (2898, 3139, 1);
INSERT INTO 'dancesstepsmap' VALUES (2899, 3140, 1);
INSERT INTO 'dancesstepsmap' VALUES (2900, 3141, 1);
INSERT INTO 'dancesstepsmap' VALUES (2901, 3142, 1);
INSERT INTO 'dancesstepsmap' VALUES (2902, 3143, 1);
INSERT INTO 'dancesstepsmap' VALUES (2903, 3144, 1);
INSERT INTO 'dancesstepsmap' VALUES (2904, 3145, 4);
INSERT INTO 'dancesstepsmap' VALUES (2905, 3146, 1);
INSERT INTO 'dancesstepsmap' VALUES (2906, 3147, 4);
INSERT INTO 'dancesstepsmap' VALUES (2907, 3148, 4);
INSERT INTO 'dancesstepsmap' VALUES (2908, 3149, 4);
INSERT INTO 'dancesstepsmap' VALUES (2909, 3150, 4);
INSERT INTO 'dancesstepsmap' VALUES (2910, 3151, 4);
INSERT INTO 'dancesstepsmap' VALUES (2911, 3152, 1);
INSERT INTO 'dancesstepsmap' VALUES (2912, 3153, 4);
INSERT INTO 'dancesstepsmap' VALUES (2913, 3154, 1);
INSERT INTO 'dancesstepsmap' VALUES (2914, 3155, 4);
INSERT INTO 'dancesstepsmap' VALUES (2915, 3156, 1);
INSERT INTO 'dancesstepsmap' VALUES (2916, 3157, 4);
INSERT INTO 'dancesstepsmap' VALUES (2917, 3158, 4);
INSERT INTO 'dancesstepsmap' VALUES (2918, 3159, 1);
INSERT INTO 'dancesstepsmap' VALUES (2919, 3160, 1);
INSERT INTO 'dancesstepsmap' VALUES (2920, 3161, 1);
INSERT INTO 'dancesstepsmap' VALUES (2921, 3162, 4);
INSERT INTO 'dancesstepsmap' VALUES (2922, 3163, 1);
INSERT INTO 'dancesstepsmap' VALUES (11057, 10251, 4);
INSERT INTO 'dancesstepsmap' VALUES (11058, 10252, 2);
INSERT INTO 'dancesstepsmap' VALUES (11059, 10252, 1);
INSERT INTO 'dancesstepsmap' VALUES (11060, 10253, 4);
INSERT INTO 'dancesstepsmap' VALUES (11061, 10253, 5);
INSERT INTO 'dancesstepsmap' VALUES (11062, 10254, 1);
INSERT INTO 'dancesstepsmap' VALUES (11063, 10256, 1);
INSERT INTO 'dancesstepsmap' VALUES (11064, 10257, 2);
INSERT INTO 'dancesstepsmap' VALUES (11065, 10258, 4);
INSERT INTO 'dancesstepsmap' VALUES (11066, 10259, 4);
INSERT INTO 'dancesstepsmap' VALUES (11067, 10260, 1);
INSERT INTO 'dancesstepsmap' VALUES (11068, 10261, 1);
INSERT INTO 'dancesstepsmap' VALUES (11069, 10262, 1);
INSERT INTO 'dancesstepsmap' VALUES (11070, 10263, 4);
INSERT INTO 'dancesstepsmap' VALUES (11071, 10264, 1);
INSERT INTO 'dancesstepsmap' VALUES (11072, 10265, 1);
INSERT INTO 'dancesstepsmap' VALUES (11073, 10265, 2);
INSERT INTO 'dancesstepsmap' VALUES (11074, 10266, 4);
INSERT INTO 'dancesstepsmap' VALUES (23137, 6643, 2);
INSERT INTO 'dancesstepsmap' VALUES (11076, 10268, 1);
INSERT INTO 'dancesstepsmap' VALUES (2832, 3069, 4);
INSERT INTO 'dancesstepsmap' VALUES (11077, 10271, 1);
INSERT INTO 'dancesstepsmap' VALUES (11078, 10272, 4);
INSERT INTO 'dancesstepsmap' VALUES (11079, 8480, 2);
INSERT INTO 'dancesstepsmap' VALUES (11081, 10276, 1);
INSERT INTO 'dancesstepsmap' VALUES (11082, 10276, 2);
INSERT INTO 'dancesstepsmap' VALUES (11083, 10276, 3);
INSERT INTO 'dancesstepsmap' VALUES (11084, 10275, 4);
INSERT INTO 'dancesstepsmap' VALUES (11085, 10273, 1);
INSERT INTO 'dancesstepsmap' VALUES (11086, 10279, 2);
INSERT INTO 'dancesstepsmap' VALUES (11087, 10279, 1);
INSERT INTO 'dancesstepsmap' VALUES (11088, 10278, 1);
INSERT INTO 'dancesstepsmap' VALUES (11089, 10281, 4);
INSERT INTO 'dancesstepsmap' VALUES (11090, 10281, 5);
INSERT INTO 'dancesstepsmap' VALUES (11091, 10282, 1);
INSERT INTO 'dancesstepsmap' VALUES (11092, 10274, 1);
INSERT INTO 'dancesstepsmap' VALUES (11093, 10283, 5);
INSERT INTO 'dancesstepsmap' VALUES (11094, 10283, 4);
INSERT INTO 'dancesstepsmap' VALUES (11095, 10284, 2);
INSERT INTO 'dancesstepsmap' VALUES (11096, 10284, 1);
INSERT INTO 'dancesstepsmap' VALUES (11097, 10285, 3);
INSERT INTO 'dancesstepsmap' VALUES (11098, 10285, 1);
INSERT INTO 'dancesstepsmap' VALUES (11099, 10285, 2);
INSERT INTO 'dancesstepsmap' VALUES (17028, 14439, 1);
INSERT INTO 'dancesstepsmap' VALUES (17029, 14439, 2);
INSERT INTO 'dancesstepsmap' VALUES (17042, 1520, 2);
INSERT INTO 'dancesstepsmap' VALUES (17053, 14486, 4);
INSERT INTO 'dancesstepsmap' VALUES (17060, 14013, 4);
INSERT INTO 'dancesstepsmap' VALUES (17061, 14013, 5);
INSERT INTO 'dancesstepsmap' VALUES (17062, 14098, 2);
INSERT INTO 'dancesstepsmap' VALUES (17063, 14098, 1);
INSERT INTO 'dancesstepsmap' VALUES (17064, 14518, 2);
INSERT INTO 'dancesstepsmap' VALUES (17065, 14518, 1);
INSERT INTO 'dancesstepsmap' VALUES (17066, 14519, 1);
INSERT INTO 'dancesstepsmap' VALUES (17067, 14520, 1);
INSERT INTO 'dancesstepsmap' VALUES (17068, 14520, 2);
INSERT INTO 'dancesstepsmap' VALUES (17083, 14528, 1);
INSERT INTO 'dancesstepsmap' VALUES (17084, 14528, 3);
INSERT INTO 'dancesstepsmap' VALUES (17087, 14530, 1);
INSERT INTO 'dancesstepsmap' VALUES (17088, 14530, 2);
INSERT INTO 'dancesstepsmap' VALUES (17089, 9985, 5);
INSERT INTO 'dancesstepsmap' VALUES (17090, 5430, 5);
INSERT INTO 'dancesstepsmap' VALUES (17091, 2421, 2);
INSERT INTO 'dancesstepsmap' VALUES (2923, 3164, 1);
INSERT INTO 'dancesstepsmap' VALUES (2924, 3165, 1);
INSERT INTO 'dancesstepsmap' VALUES (2925, 3166, 1);
INSERT INTO 'dancesstepsmap' VALUES (2926, 3167, 1);
INSERT INTO 'dancesstepsmap' VALUES (2928, 3169, 4);
INSERT INTO 'dancesstepsmap' VALUES (2929, 3170, 4);
INSERT INTO 'dancesstepsmap' VALUES (2930, 3171, 4);
INSERT INTO 'dancesstepsmap' VALUES (2931, 3172, 1);
INSERT INTO 'dancesstepsmap' VALUES (2932, 3173, 4);
INSERT INTO 'dancesstepsmap' VALUES (2933, 3174, 1);
INSERT INTO 'dancesstepsmap' VALUES (2934, 3175, 4);
INSERT INTO 'dancesstepsmap' VALUES (2935, 3176, 1);
INSERT INTO 'dancesstepsmap' VALUES (2936, 3177, 4);
INSERT INTO 'dancesstepsmap' VALUES (2937, 3179, 1);
INSERT INTO 'dancesstepsmap' VALUES (2938, 3181, 1);
INSERT INTO 'dancesstepsmap' VALUES (2939, 3183, 1);
INSERT INTO 'dancesstepsmap' VALUES (2940, 3184, 1);
INSERT INTO 'dancesstepsmap' VALUES (2941, 3185, 1);
INSERT INTO 'dancesstepsmap' VALUES (2942, 3186, 1);
INSERT INTO 'dancesstepsmap' VALUES (2943, 3187, 1);
INSERT INTO 'dancesstepsmap' VALUES (2944, 3188, 1);
INSERT INTO 'dancesstepsmap' VALUES (2945, 3190, 1);
INSERT INTO 'dancesstepsmap' VALUES (2946, 3191, 1);
INSERT INTO 'dancesstepsmap' VALUES (2947, 3192, 4);
INSERT INTO 'dancesstepsmap' VALUES (2948, 3193, 4);
INSERT INTO 'dancesstepsmap' VALUES (2949, 3194, 1);
INSERT INTO 'dancesstepsmap' VALUES (2950, 3195, 1);
INSERT INTO 'dancesstepsmap' VALUES (2951, 3196, 1);
INSERT INTO 'dancesstepsmap' VALUES (2952, 3197, 1);
INSERT INTO 'dancesstepsmap' VALUES (2953, 3198, 4);
INSERT INTO 'dancesstepsmap' VALUES (2954, 3199, 1);
INSERT INTO 'dancesstepsmap' VALUES (2955, 3200, 1);
INSERT INTO 'dancesstepsmap' VALUES (2956, 3201, 1);
INSERT INTO 'dancesstepsmap' VALUES (2957, 3202, 1);
INSERT INTO 'dancesstepsmap' VALUES (2958, 3204, 1);
INSERT INTO 'dancesstepsmap' VALUES (2959, 3205, 4);
INSERT INTO 'dancesstepsmap' VALUES (2960, 3206, 4);
INSERT INTO 'dancesstepsmap' VALUES (2961, 3207, 1);
INSERT INTO 'dancesstepsmap' VALUES (2962, 3208, 4);
INSERT INTO 'dancesstepsmap' VALUES (2963, 3209, 1);
INSERT INTO 'dancesstepsmap' VALUES (2964, 3210, 4);
INSERT INTO 'dancesstepsmap' VALUES (2965, 3211, 1);
INSERT INTO 'dancesstepsmap' VALUES (2966, 3212, 4);
INSERT INTO 'dancesstepsmap' VALUES (2967, 3213, 1);
INSERT INTO 'dancesstepsmap' VALUES (2969, 3215, 1);
INSERT INTO 'dancesstepsmap' VALUES (2970, 3216, 1);
INSERT INTO 'dancesstepsmap' VALUES (2971, 3217, 4);
INSERT INTO 'dancesstepsmap' VALUES (2972, 3218, 1);
INSERT INTO 'dancesstepsmap' VALUES (2973, 3219, 1);
INSERT INTO 'dancesstepsmap' VALUES (2974, 3220, 1);
INSERT INTO 'dancesstepsmap' VALUES (2975, 3221, 4);
INSERT INTO 'dancesstepsmap' VALUES (2976, 3222, 1);
INSERT INTO 'dancesstepsmap' VALUES (2977, 3223, 4);
INSERT INTO 'dancesstepsmap' VALUES (2978, 3224, 1);
INSERT INTO 'dancesstepsmap' VALUES (2979, 3225, 1);
INSERT INTO 'dancesstepsmap' VALUES (2980, 3226, 4);
INSERT INTO 'dancesstepsmap' VALUES (2981, 3227, 1);
INSERT INTO 'dancesstepsmap' VALUES (2982, 3228, 1);
INSERT INTO 'dancesstepsmap' VALUES (2983, 3229, 4);
INSERT INTO 'dancesstepsmap' VALUES (2984, 3230, 1);
INSERT INTO 'dancesstepsmap' VALUES (2985, 3231, 1);
INSERT INTO 'dancesstepsmap' VALUES (2986, 3233, 1);
INSERT INTO 'dancesstepsmap' VALUES (2987, 3234, 4);
INSERT INTO 'dancesstepsmap' VALUES (2988, 3235, 1);
INSERT INTO 'dancesstepsmap' VALUES (2989, 3236, 4);
INSERT INTO 'dancesstepsmap' VALUES (2990, 3237, 1);
INSERT INTO 'dancesstepsmap' VALUES (2991, 3238, 4);
INSERT INTO 'dancesstepsmap' VALUES (2992, 3239, 1);
INSERT INTO 'dancesstepsmap' VALUES (2993, 3240, 4);
INSERT INTO 'dancesstepsmap' VALUES (2994, 3241, 4);
INSERT INTO 'dancesstepsmap' VALUES (2995, 3242, 4);
INSERT INTO 'dancesstepsmap' VALUES (2996, 3243, 1);
INSERT INTO 'dancesstepsmap' VALUES (2997, 3245, 1);
INSERT INTO 'dancesstepsmap' VALUES (2998, 3246, 1);
INSERT INTO 'dancesstepsmap' VALUES (2999, 3247, 4);
INSERT INTO 'dancesstepsmap' VALUES (3000, 3248, 1);
INSERT INTO 'dancesstepsmap' VALUES (3001, 3249, 1);
INSERT INTO 'dancesstepsmap' VALUES (3002, 3250, 1);
INSERT INTO 'dancesstepsmap' VALUES (3003, 3251, 1);
INSERT INTO 'dancesstepsmap' VALUES (3004, 3253, 1);
INSERT INTO 'dancesstepsmap' VALUES (3005, 3254, 1);
INSERT INTO 'dancesstepsmap' VALUES (3006, 3255, 1);
INSERT INTO 'dancesstepsmap' VALUES (3007, 3256, 1);
INSERT INTO 'dancesstepsmap' VALUES (3008, 3257, 1);
INSERT INTO 'dancesstepsmap' VALUES (3009, 3258, 1);
INSERT INTO 'dancesstepsmap' VALUES (3010, 3259, 1);
INSERT INTO 'dancesstepsmap' VALUES (3011, 3260, 1);
INSERT INTO 'dancesstepsmap' VALUES (3012, 3261, 1);
INSERT INTO 'dancesstepsmap' VALUES (3013, 3262, 1);
INSERT INTO 'dancesstepsmap' VALUES (3014, 3263, 1);
INSERT INTO 'dancesstepsmap' VALUES (3015, 3264, 1);
INSERT INTO 'dancesstepsmap' VALUES (3016, 3265, 1);
INSERT INTO 'dancesstepsmap' VALUES (3017, 3266, 1);
INSERT INTO 'dancesstepsmap' VALUES (3018, 3267, 1);
INSERT INTO 'dancesstepsmap' VALUES (3019, 3268, 1);
INSERT INTO 'dancesstepsmap' VALUES (3020, 3269, 1);
INSERT INTO 'dancesstepsmap' VALUES (3021, 3270, 4);
INSERT INTO 'dancesstepsmap' VALUES (3022, 3272, 1);
INSERT INTO 'dancesstepsmap' VALUES (3023, 3273, 1);
INSERT INTO 'dancesstepsmap' VALUES (3024, 3274, 1);
INSERT INTO 'dancesstepsmap' VALUES (3025, 3275, 1);
INSERT INTO 'dancesstepsmap' VALUES (3026, 3276, 1);
INSERT INTO 'dancesstepsmap' VALUES (3027, 3277, 4);
INSERT INTO 'dancesstepsmap' VALUES (3028, 3278, 4);
INSERT INTO 'dancesstepsmap' VALUES (3029, 3279, 1);
INSERT INTO 'dancesstepsmap' VALUES (3030, 3280, 1);
INSERT INTO 'dancesstepsmap' VALUES (3031, 3281, 4);
INSERT INTO 'dancesstepsmap' VALUES (3032, 3282, 1);
INSERT INTO 'dancesstepsmap' VALUES (3033, 3283, 4);
INSERT INTO 'dancesstepsmap' VALUES (3034, 3284, 4);
INSERT INTO 'dancesstepsmap' VALUES (3035, 3285, 1);
INSERT INTO 'dancesstepsmap' VALUES (3036, 3286, 1);
INSERT INTO 'dancesstepsmap' VALUES (3037, 3287, 1);
INSERT INTO 'dancesstepsmap' VALUES (3038, 3288, 1);
INSERT INTO 'dancesstepsmap' VALUES (3040, 3290, 1);
INSERT INTO 'dancesstepsmap' VALUES (3041, 3291, 1);
INSERT INTO 'dancesstepsmap' VALUES (3042, 3292, 4);
INSERT INTO 'dancesstepsmap' VALUES (3043, 3293, 1);
INSERT INTO 'dancesstepsmap' VALUES (3044, 3294, 1);
INSERT INTO 'dancesstepsmap' VALUES (3045, 3295, 4);
INSERT INTO 'dancesstepsmap' VALUES (3046, 3296, 1);
INSERT INTO 'dancesstepsmap' VALUES (3047, 3298, 1);
INSERT INTO 'dancesstepsmap' VALUES (3048, 3299, 1);
INSERT INTO 'dancesstepsmap' VALUES (3049, 3302, 4);
INSERT INTO 'dancesstepsmap' VALUES (3050, 3303, 1);
INSERT INTO 'dancesstepsmap' VALUES (3051, 3304, 1);
INSERT INTO 'dancesstepsmap' VALUES (11100, 10286, 1);
INSERT INTO 'dancesstepsmap' VALUES (11101, 9631, 1);
INSERT INTO 'dancesstepsmap' VALUES (23219, 18266, 2);
INSERT INTO 'dancesstepsmap' VALUES (23220, 18266, 1);
INSERT INTO 'dancesstepsmap' VALUES (11104, 9138, 1);
INSERT INTO 'dancesstepsmap' VALUES (11105, 9543, 2);
INSERT INTO 'dancesstepsmap' VALUES (11106, 9543, 1);
INSERT INTO 'dancesstepsmap' VALUES (11107, 9543, 3);
INSERT INTO 'dancesstepsmap' VALUES (11108, 9698, 1);
INSERT INTO 'dancesstepsmap' VALUES (11109, 9698, 3);
INSERT INTO 'dancesstepsmap' VALUES (11110, 380, 5);
INSERT INTO 'dancesstepsmap' VALUES (11111, 9138, 2);
INSERT INTO 'dancesstepsmap' VALUES (11112, 9698, 2);
INSERT INTO 'dancesstepsmap' VALUES (11113, 413, 3);
INSERT INTO 'dancesstepsmap' VALUES (11114, 9699, 4);
INSERT INTO 'dancesstepsmap' VALUES (11115, 9699, 5);
INSERT INTO 'dancesstepsmap' VALUES (11116, 10287, 1);
INSERT INTO 'dancesstepsmap' VALUES (3052, 3305, 1);
INSERT INTO 'dancesstepsmap' VALUES (3053, 3306, 1);
INSERT INTO 'dancesstepsmap' VALUES (3054, 3307, 1);
INSERT INTO 'dancesstepsmap' VALUES (3055, 3308, 1);
INSERT INTO 'dancesstepsmap' VALUES (3056, 3309, 1);
INSERT INTO 'dancesstepsmap' VALUES (3057, 3310, 1);
INSERT INTO 'dancesstepsmap' VALUES (3058, 3311, 1);
INSERT INTO 'dancesstepsmap' VALUES (3059, 3312, 4);
INSERT INTO 'dancesstepsmap' VALUES (3060, 3313, 4);
INSERT INTO 'dancesstepsmap' VALUES (3061, 3314, 1);
INSERT INTO 'dancesstepsmap' VALUES (3062, 3315, 4);
INSERT INTO 'dancesstepsmap' VALUES (3063, 3316, 1);
INSERT INTO 'dancesstepsmap' VALUES (3064, 3317, 4);
INSERT INTO 'dancesstepsmap' VALUES (3065, 3318, 1);
INSERT INTO 'dancesstepsmap' VALUES (3066, 3319, 1);
INSERT INTO 'dancesstepsmap' VALUES (3067, 3320, 1);
INSERT INTO 'dancesstepsmap' VALUES (3068, 3321, 1);
INSERT INTO 'dancesstepsmap' VALUES (3069, 3322, 4);
INSERT INTO 'dancesstepsmap' VALUES (3070, 3323, 4);
INSERT INTO 'dancesstepsmap' VALUES (3071, 3324, 1);
INSERT INTO 'dancesstepsmap' VALUES (3072, 3325, 4);
INSERT INTO 'dancesstepsmap' VALUES (3073, 3326, 1);
INSERT INTO 'dancesstepsmap' VALUES (3074, 3327, 1);
INSERT INTO 'dancesstepsmap' VALUES (3075, 3328, 1);
INSERT INTO 'dancesstepsmap' VALUES (3076, 3329, 1);
INSERT INTO 'dancesstepsmap' VALUES (3077, 3330, 1);
INSERT INTO 'dancesstepsmap' VALUES (3078, 3331, 4);
INSERT INTO 'dancesstepsmap' VALUES (3079, 3332, 4);
INSERT INTO 'dancesstepsmap' VALUES (3080, 3333, 4);
INSERT INTO 'dancesstepsmap' VALUES (3081, 3334, 1);
INSERT INTO 'dancesstepsmap' VALUES (3082, 3335, 1);
INSERT INTO 'dancesstepsmap' VALUES (3083, 3337, 1);
INSERT INTO 'dancesstepsmap' VALUES (3084, 3338, 1);
INSERT INTO 'dancesstepsmap' VALUES (3085, 3339, 1);
INSERT INTO 'dancesstepsmap' VALUES (3086, 3340, 1);
INSERT INTO 'dancesstepsmap' VALUES (3087, 3341, 1);
INSERT INTO 'dancesstepsmap' VALUES (3088, 3342, 1);
INSERT INTO 'dancesstepsmap' VALUES (3089, 3343, 1);
INSERT INTO 'dancesstepsmap' VALUES (3090, 3344, 1);
INSERT INTO 'dancesstepsmap' VALUES (3091, 3345, 1);
INSERT INTO 'dancesstepsmap' VALUES (3092, 3346, 1);
INSERT INTO 'dancesstepsmap' VALUES (3093, 3347, 1);
INSERT INTO 'dancesstepsmap' VALUES (3094, 3348, 1);
INSERT INTO 'dancesstepsmap' VALUES (3095, 3349, 1);
INSERT INTO 'dancesstepsmap' VALUES (3096, 3350, 4);
INSERT INTO 'dancesstepsmap' VALUES (3097, 3351, 4);
INSERT INTO 'dancesstepsmap' VALUES (3098, 3352, 1);
INSERT INTO 'dancesstepsmap' VALUES (3099, 3353, 1);
INSERT INTO 'dancesstepsmap' VALUES (3100, 3354, 1);
INSERT INTO 'dancesstepsmap' VALUES (3101, 3355, 1);
INSERT INTO 'dancesstepsmap' VALUES (3102, 3357, 1);
INSERT INTO 'dancesstepsmap' VALUES (3103, 3358, 1);
INSERT INTO 'dancesstepsmap' VALUES (3104, 3359, 1);
INSERT INTO 'dancesstepsmap' VALUES (3105, 3360, 4);
INSERT INTO 'dancesstepsmap' VALUES (3106, 3361, 1);
INSERT INTO 'dancesstepsmap' VALUES (3107, 3363, 1);
INSERT INTO 'dancesstepsmap' VALUES (3108, 3364, 4);
INSERT INTO 'dancesstepsmap' VALUES (3109, 3365, 1);
INSERT INTO 'dancesstepsmap' VALUES (3110, 3366, 1);
INSERT INTO 'dancesstepsmap' VALUES (3111, 3367, 1);
INSERT INTO 'dancesstepsmap' VALUES (3112, 3368, 1);
INSERT INTO 'dancesstepsmap' VALUES (3113, 3369, 1);
INSERT INTO 'dancesstepsmap' VALUES (3114, 3370, 4);
INSERT INTO 'dancesstepsmap' VALUES (3115, 3371, 1);
INSERT INTO 'dancesstepsmap' VALUES (3116, 3372, 1);
INSERT INTO 'dancesstepsmap' VALUES (3117, 3373, 1);
INSERT INTO 'dancesstepsmap' VALUES (3118, 3374, 1);
INSERT INTO 'dancesstepsmap' VALUES (3119, 3375, 1);
INSERT INTO 'dancesstepsmap' VALUES (3120, 3376, 4);
INSERT INTO 'dancesstepsmap' VALUES (3121, 3377, 1);
INSERT INTO 'dancesstepsmap' VALUES (3122, 3378, 1);
INSERT INTO 'dancesstepsmap' VALUES (3123, 3379, 1);
INSERT INTO 'dancesstepsmap' VALUES (3124, 3380, 1);
INSERT INTO 'dancesstepsmap' VALUES (3125, 3381, 1);
INSERT INTO 'dancesstepsmap' VALUES (3126, 3382, 1);
INSERT INTO 'dancesstepsmap' VALUES (3127, 3384, 4);
INSERT INTO 'dancesstepsmap' VALUES (3128, 3385, 1);
INSERT INTO 'dancesstepsmap' VALUES (3129, 3386, 1);
INSERT INTO 'dancesstepsmap' VALUES (3130, 3387, 1);
INSERT INTO 'dancesstepsmap' VALUES (3131, 3388, 1);
INSERT INTO 'dancesstepsmap' VALUES (3132, 3389, 4);
INSERT INTO 'dancesstepsmap' VALUES (3133, 3390, 1);
INSERT INTO 'dancesstepsmap' VALUES (3134, 3391, 4);
INSERT INTO 'dancesstepsmap' VALUES (3135, 3392, 4);
INSERT INTO 'dancesstepsmap' VALUES (3136, 3393, 4);
INSERT INTO 'dancesstepsmap' VALUES (3137, 3394, 1);
INSERT INTO 'dancesstepsmap' VALUES (3138, 3395, 1);
INSERT INTO 'dancesstepsmap' VALUES (3139, 3397, 4);
INSERT INTO 'dancesstepsmap' VALUES (3140, 3398, 1);
INSERT INTO 'dancesstepsmap' VALUES (3141, 3399, 4);
INSERT INTO 'dancesstepsmap' VALUES (3142, 3400, 4);
INSERT INTO 'dancesstepsmap' VALUES (3143, 3401, 1);
INSERT INTO 'dancesstepsmap' VALUES (3144, 3402, 4);
INSERT INTO 'dancesstepsmap' VALUES (11117, 10287, 3);
INSERT INTO 'dancesstepsmap' VALUES (11118, 10287, 2);
INSERT INTO 'dancesstepsmap' VALUES (11119, 9201, 1);
INSERT INTO 'dancesstepsmap' VALUES (11120, 700, 2);
INSERT INTO 'dancesstepsmap' VALUES (11121, 9455, 1);
INSERT INTO 'dancesstepsmap' VALUES (11122, 9455, 3);
INSERT INTO 'dancesstepsmap' VALUES (11123, 9455, 2);
INSERT INTO 'dancesstepsmap' VALUES (11124, 9191, 1);
INSERT INTO 'dancesstepsmap' VALUES (11125, 9191, 3);
INSERT INTO 'dancesstepsmap' VALUES (11126, 10288, 3);
INSERT INTO 'dancesstepsmap' VALUES (11127, 10288, 1);
INSERT INTO 'dancesstepsmap' VALUES (11128, 10289, 2);
INSERT INTO 'dancesstepsmap' VALUES (11129, 10289, 1);
INSERT INTO 'dancesstepsmap' VALUES (11130, 1074, 2);
INSERT INTO 'dancesstepsmap' VALUES (11131, 1167, 2);
INSERT INTO 'dancesstepsmap' VALUES (11132, 9459, 1);
INSERT INTO 'dancesstepsmap' VALUES (11133, 7575, 2);
INSERT INTO 'dancesstepsmap' VALUES (11134, 9003, 4);
INSERT INTO 'dancesstepsmap' VALUES (11135, 9003, 5);
INSERT INTO 'dancesstepsmap' VALUES (11136, 9222, 1);
INSERT INTO 'dancesstepsmap' VALUES (11137, 9469, 1);
INSERT INTO 'dancesstepsmap' VALUES (11138, 7696, 5);
INSERT INTO 'dancesstepsmap' VALUES (11139, 10290, 5);
INSERT INTO 'dancesstepsmap' VALUES (11140, 10290, 4);
INSERT INTO 'dancesstepsmap' VALUES (11141, 10291, 2);
INSERT INTO 'dancesstepsmap' VALUES (11142, 10291, 1);
INSERT INTO 'dancesstepsmap' VALUES (11143, 9005, 2);
INSERT INTO 'dancesstepsmap' VALUES (11144, 9005, 1);
INSERT INTO 'dancesstepsmap' VALUES (11145, 2020, 2);
INSERT INTO 'dancesstepsmap' VALUES (11146, 10292, 1);
INSERT INTO 'dancesstepsmap' VALUES (11147, 10292, 3);
INSERT INTO 'dancesstepsmap' VALUES (11148, 9463, 4);
INSERT INTO 'dancesstepsmap' VALUES (11149, 9463, 5);
INSERT INTO 'dancesstepsmap' VALUES (11150, 10293, 1);
INSERT INTO 'dancesstepsmap' VALUES (11151, 10293, 3);
INSERT INTO 'dancesstepsmap' VALUES (11152, 10294, 1);
INSERT INTO 'dancesstepsmap' VALUES (11153, 10294, 3);
INSERT INTO 'dancesstepsmap' VALUES (11154, 10294, 2);
INSERT INTO 'dancesstepsmap' VALUES (11155, 9205, 5);
INSERT INTO 'dancesstepsmap' VALUES (11156, 9205, 4);
INSERT INTO 'dancesstepsmap' VALUES (11157, 9465, 1);
INSERT INTO 'dancesstepsmap' VALUES (11158, 9007, 5);
INSERT INTO 'dancesstepsmap' VALUES (17043, 2857, 5);
INSERT INTO 'dancesstepsmap' VALUES (17069, 14521, 2);
INSERT INTO 'dancesstepsmap' VALUES (17070, 14521, 1);
INSERT INTO 'dancesstepsmap' VALUES (17071, 14521, 8);
INSERT INTO 'dancesstepsmap' VALUES (17092, 4805, 2);
INSERT INTO 'dancesstepsmap' VALUES (3145, 3403, 4);
INSERT INTO 'dancesstepsmap' VALUES (3146, 3404, 1);
INSERT INTO 'dancesstepsmap' VALUES (3147, 3405, 1);
INSERT INTO 'dancesstepsmap' VALUES (3148, 3406, 1);
INSERT INTO 'dancesstepsmap' VALUES (3149, 3407, 4);
INSERT INTO 'dancesstepsmap' VALUES (3150, 3408, 1);
INSERT INTO 'dancesstepsmap' VALUES (3151, 3409, 4);
INSERT INTO 'dancesstepsmap' VALUES (3152, 3410, 4);
INSERT INTO 'dancesstepsmap' VALUES (3153, 3411, 4);
INSERT INTO 'dancesstepsmap' VALUES (3154, 3412, 4);
INSERT INTO 'dancesstepsmap' VALUES (3155, 3413, 1);
INSERT INTO 'dancesstepsmap' VALUES (3156, 3414, 1);
INSERT INTO 'dancesstepsmap' VALUES (3157, 3415, 1);
INSERT INTO 'dancesstepsmap' VALUES (3158, 3416, 1);
INSERT INTO 'dancesstepsmap' VALUES (3159, 3417, 1);
INSERT INTO 'dancesstepsmap' VALUES (3160, 3418, 1);
INSERT INTO 'dancesstepsmap' VALUES (3161, 3419, 1);
INSERT INTO 'dancesstepsmap' VALUES (3162, 3420, 1);
INSERT INTO 'dancesstepsmap' VALUES (3163, 3421, 1);
INSERT INTO 'dancesstepsmap' VALUES (3164, 3422, 1);
INSERT INTO 'dancesstepsmap' VALUES (3165, 3423, 4);
INSERT INTO 'dancesstepsmap' VALUES (3166, 3424, 1);
INSERT INTO 'dancesstepsmap' VALUES (3167, 3425, 1);
INSERT INTO 'dancesstepsmap' VALUES (3168, 3426, 1);
INSERT INTO 'dancesstepsmap' VALUES (3169, 3427, 1);
INSERT INTO 'dancesstepsmap' VALUES (3170, 3428, 4);
INSERT INTO 'dancesstepsmap' VALUES (3171, 3429, 1);
INSERT INTO 'dancesstepsmap' VALUES (3172, 3430, 4);
INSERT INTO 'dancesstepsmap' VALUES (3173, 3431, 1);
INSERT INTO 'dancesstepsmap' VALUES (3174, 3432, 1);
INSERT INTO 'dancesstepsmap' VALUES (3175, 3433, 1);
INSERT INTO 'dancesstepsmap' VALUES (3176, 3434, 1);
INSERT INTO 'dancesstepsmap' VALUES (3177, 3435, 1);
INSERT INTO 'dancesstepsmap' VALUES (3178, 3436, 4);
INSERT INTO 'dancesstepsmap' VALUES (3179, 3437, 1);
INSERT INTO 'dancesstepsmap' VALUES (3180, 3438, 1);
INSERT INTO 'dancesstepsmap' VALUES (3181, 3439, 4);
INSERT INTO 'dancesstepsmap' VALUES (3182, 3440, 1);
INSERT INTO 'dancesstepsmap' VALUES (3183, 3441, 1);
INSERT INTO 'dancesstepsmap' VALUES (3184, 3442, 1);
INSERT INTO 'dancesstepsmap' VALUES (3185, 3443, 1);
INSERT INTO 'dancesstepsmap' VALUES (3186, 3444, 4);
INSERT INTO 'dancesstepsmap' VALUES (3187, 3445, 1);
INSERT INTO 'dancesstepsmap' VALUES (3188, 3446, 1);
INSERT INTO 'dancesstepsmap' VALUES (3189, 3447, 1);
INSERT INTO 'dancesstepsmap' VALUES (3190, 3448, 4);
INSERT INTO 'dancesstepsmap' VALUES (3191, 3449, 1);
INSERT INTO 'dancesstepsmap' VALUES (3192, 3450, 4);
INSERT INTO 'dancesstepsmap' VALUES (3193, 3451, 4);
INSERT INTO 'dancesstepsmap' VALUES (3194, 3452, 1);
INSERT INTO 'dancesstepsmap' VALUES (3195, 3453, 4);
INSERT INTO 'dancesstepsmap' VALUES (3196, 3454, 1);
INSERT INTO 'dancesstepsmap' VALUES (3197, 3456, 4);
INSERT INTO 'dancesstepsmap' VALUES (3198, 3457, 1);
INSERT INTO 'dancesstepsmap' VALUES (3199, 3458, 1);
INSERT INTO 'dancesstepsmap' VALUES (3200, 3459, 1);
INSERT INTO 'dancesstepsmap' VALUES (3201, 3461, 4);
INSERT INTO 'dancesstepsmap' VALUES (3202, 3462, 4);
INSERT INTO 'dancesstepsmap' VALUES (3203, 3463, 4);
INSERT INTO 'dancesstepsmap' VALUES (3204, 3464, 1);
INSERT INTO 'dancesstepsmap' VALUES (3205, 3465, 1);
INSERT INTO 'dancesstepsmap' VALUES (3206, 3466, 1);
INSERT INTO 'dancesstepsmap' VALUES (3207, 3467, 4);
INSERT INTO 'dancesstepsmap' VALUES (3208, 3468, 4);
INSERT INTO 'dancesstepsmap' VALUES (3209, 3469, 1);
INSERT INTO 'dancesstepsmap' VALUES (3210, 3470, 4);
INSERT INTO 'dancesstepsmap' VALUES (3211, 3471, 1);
INSERT INTO 'dancesstepsmap' VALUES (3212, 3472, 4);
INSERT INTO 'dancesstepsmap' VALUES (3213, 3473, 1);
INSERT INTO 'dancesstepsmap' VALUES (3214, 3475, 1);
INSERT INTO 'dancesstepsmap' VALUES (3215, 3476, 4);
INSERT INTO 'dancesstepsmap' VALUES (3216, 3477, 1);
INSERT INTO 'dancesstepsmap' VALUES (3217, 3478, 4);
INSERT INTO 'dancesstepsmap' VALUES (3218, 3479, 1);
INSERT INTO 'dancesstepsmap' VALUES (3219, 3480, 1);
INSERT INTO 'dancesstepsmap' VALUES (3220, 3481, 1);
INSERT INTO 'dancesstepsmap' VALUES (3221, 3482, 4);
INSERT INTO 'dancesstepsmap' VALUES (3222, 3483, 4);
INSERT INTO 'dancesstepsmap' VALUES (3223, 3485, 4);
INSERT INTO 'dancesstepsmap' VALUES (3224, 3486, 1);
INSERT INTO 'dancesstepsmap' VALUES (3225, 3488, 1);
INSERT INTO 'dancesstepsmap' VALUES (3226, 3489, 4);
INSERT INTO 'dancesstepsmap' VALUES (3227, 3490, 4);
INSERT INTO 'dancesstepsmap' VALUES (3228, 3491, 1);
INSERT INTO 'dancesstepsmap' VALUES (3229, 3492, 1);
INSERT INTO 'dancesstepsmap' VALUES (3230, 3493, 4);
INSERT INTO 'dancesstepsmap' VALUES (3231, 3494, 4);
INSERT INTO 'dancesstepsmap' VALUES (3232, 3495, 4);
INSERT INTO 'dancesstepsmap' VALUES (3233, 3496, 4);
INSERT INTO 'dancesstepsmap' VALUES (3234, 3497, 1);
INSERT INTO 'dancesstepsmap' VALUES (3235, 3499, 4);
INSERT INTO 'dancesstepsmap' VALUES (3236, 3500, 1);
INSERT INTO 'dancesstepsmap' VALUES (11159, 9007, 4);
INSERT INTO 'dancesstepsmap' VALUES (11160, 9466, 1);
INSERT INTO 'dancesstepsmap' VALUES (11161, 9635, 4);
INSERT INTO 'dancesstepsmap' VALUES (11162, 10295, 1);
INSERT INTO 'dancesstepsmap' VALUES (11163, 9025, 4);
INSERT INTO 'dancesstepsmap' VALUES (11164, 10296, 3);
INSERT INTO 'dancesstepsmap' VALUES (11165, 10296, 2);
INSERT INTO 'dancesstepsmap' VALUES (11166, 10297, 1);
INSERT INTO 'dancesstepsmap' VALUES (11167, 10298, 1);
INSERT INTO 'dancesstepsmap' VALUES (11168, 10299, 1);
INSERT INTO 'dancesstepsmap' VALUES (11169, 10299, 3);
INSERT INTO 'dancesstepsmap' VALUES (11170, 10300, 1);
INSERT INTO 'dancesstepsmap' VALUES (11171, 10301, 1);
INSERT INTO 'dancesstepsmap' VALUES (11172, 10301, 3);
INSERT INTO 'dancesstepsmap' VALUES (11173, 10302, 1);
INSERT INTO 'dancesstepsmap' VALUES (11174, 10302, 3);
INSERT INTO 'dancesstepsmap' VALUES (11175, 10303, 3);
INSERT INTO 'dancesstepsmap' VALUES (11176, 9911, 3);
INSERT INTO 'dancesstepsmap' VALUES (11177, 10304, 4);
INSERT INTO 'dancesstepsmap' VALUES (11178, 10304, 5);
INSERT INTO 'dancesstepsmap' VALUES (11179, 10305, 4);
INSERT INTO 'dancesstepsmap' VALUES (11180, 10306, 1);
INSERT INTO 'dancesstepsmap' VALUES (11181, 10307, 1);
INSERT INTO 'dancesstepsmap' VALUES (11182, 10309, 4);
INSERT INTO 'dancesstepsmap' VALUES (11183, 10308, 1);
INSERT INTO 'dancesstepsmap' VALUES (11184, 10310, 2);
INSERT INTO 'dancesstepsmap' VALUES (11185, 10310, 1);
INSERT INTO 'dancesstepsmap' VALUES (23138, 3170, 5);
INSERT INTO 'dancesstepsmap' VALUES (23139, 5506, 2);
INSERT INTO 'dancesstepsmap' VALUES (11190, 9636, 3);
INSERT INTO 'dancesstepsmap' VALUES (11191, 7763, 3);
INSERT INTO 'dancesstepsmap' VALUES (11192, 10313, 1);
INSERT INTO 'dancesstepsmap' VALUES (11193, 10313, 3);
INSERT INTO 'dancesstepsmap' VALUES (11194, 10314, 1);
INSERT INTO 'dancesstepsmap' VALUES (11195, 3520, 3);
INSERT INTO 'dancesstepsmap' VALUES (11196, 10315, 1);
INSERT INTO 'dancesstepsmap' VALUES (11197, 10163, 3);
INSERT INTO 'dancesstepsmap' VALUES (11198, 10163, 1);
INSERT INTO 'dancesstepsmap' VALUES (11199, 4111, 5);
INSERT INTO 'dancesstepsmap' VALUES (11200, 10316, 1);
INSERT INTO 'dancesstepsmap' VALUES (11201, 10316, 2);
INSERT INTO 'dancesstepsmap' VALUES (11202, 10317, 4);
INSERT INTO 'dancesstepsmap' VALUES (17044, 3426, 2);
INSERT INTO 'dancesstepsmap' VALUES (17072, 14522, 4);
INSERT INTO 'dancesstepsmap' VALUES (17073, 14522, 5);
INSERT INTO 'dancesstepsmap' VALUES (17093, 6205, 2);
INSERT INTO 'dancesstepsmap' VALUES (17094, 6205, 3);
INSERT INTO 'dancesstepsmap' VALUES (17096, 14531, 5);
INSERT INTO 'dancesstepsmap' VALUES (17097, 14531, 4);
INSERT INTO 'dancesstepsmap' VALUES (17098, 11617, 2);
INSERT INTO 'dancesstepsmap' VALUES (17099, 14532, 1);
INSERT INTO 'dancesstepsmap' VALUES (17100, 14532, 2);
INSERT INTO 'dancesstepsmap' VALUES (17101, 14533, 1);
INSERT INTO 'dancesstepsmap' VALUES (17102, 14533, 2);
INSERT INTO 'dancesstepsmap' VALUES (17111, 14538, 2);
INSERT INTO 'dancesstepsmap' VALUES (17112, 14538, 1);
INSERT INTO 'dancesstepsmap' VALUES (17113, 14539, 1);
INSERT INTO 'dancesstepsmap' VALUES (17114, 14539, 2);
INSERT INTO 'dancesstepsmap' VALUES (17115, 14539, 3);
INSERT INTO 'dancesstepsmap' VALUES (17116, 11628, 2);
INSERT INTO 'dancesstepsmap' VALUES (17117, 14542, 5);
INSERT INTO 'dancesstepsmap' VALUES (17118, 14542, 4);
INSERT INTO 'dancesstepsmap' VALUES (17119, 1480, 2);
INSERT INTO 'dancesstepsmap' VALUES (17120, 13405, 5);
INSERT INTO 'dancesstepsmap' VALUES (17121, 13405, 4);
INSERT INTO 'dancesstepsmap' VALUES (3237, 3501, 1);
INSERT INTO 'dancesstepsmap' VALUES (3238, 3502, 1);
INSERT INTO 'dancesstepsmap' VALUES (3239, 3503, 1);
INSERT INTO 'dancesstepsmap' VALUES (3240, 3504, 1);
INSERT INTO 'dancesstepsmap' VALUES (3241, 3505, 1);
INSERT INTO 'dancesstepsmap' VALUES (3242, 3506, 1);
INSERT INTO 'dancesstepsmap' VALUES (3243, 3507, 1);
INSERT INTO 'dancesstepsmap' VALUES (3244, 3508, 4);
INSERT INTO 'dancesstepsmap' VALUES (3245, 3509, 1);
INSERT INTO 'dancesstepsmap' VALUES (3246, 3510, 1);
INSERT INTO 'dancesstepsmap' VALUES (3247, 3511, 1);
INSERT INTO 'dancesstepsmap' VALUES (3248, 3512, 4);
INSERT INTO 'dancesstepsmap' VALUES (3249, 3513, 1);
INSERT INTO 'dancesstepsmap' VALUES (3250, 3515, 1);
INSERT INTO 'dancesstepsmap' VALUES (3251, 3516, 1);
INSERT INTO 'dancesstepsmap' VALUES (3252, 3517, 1);
INSERT INTO 'dancesstepsmap' VALUES (3253, 3518, 4);
INSERT INTO 'dancesstepsmap' VALUES (3254, 3519, 1);
INSERT INTO 'dancesstepsmap' VALUES (3255, 3520, 1);
INSERT INTO 'dancesstepsmap' VALUES (3256, 3521, 4);
INSERT INTO 'dancesstepsmap' VALUES (3257, 3522, 1);
INSERT INTO 'dancesstepsmap' VALUES (3258, 3523, 1);
INSERT INTO 'dancesstepsmap' VALUES (3259, 3525, 1);
INSERT INTO 'dancesstepsmap' VALUES (3260, 3526, 1);
INSERT INTO 'dancesstepsmap' VALUES (3261, 3527, 4);
INSERT INTO 'dancesstepsmap' VALUES (3262, 3528, 1);
INSERT INTO 'dancesstepsmap' VALUES (3263, 3529, 1);
INSERT INTO 'dancesstepsmap' VALUES (3264, 3533, 1);
INSERT INTO 'dancesstepsmap' VALUES (3265, 3534, 1);
INSERT INTO 'dancesstepsmap' VALUES (3266, 3535, 1);
INSERT INTO 'dancesstepsmap' VALUES (3267, 3536, 4);
INSERT INTO 'dancesstepsmap' VALUES (3268, 3537, 1);
INSERT INTO 'dancesstepsmap' VALUES (3269, 3538, 4);
INSERT INTO 'dancesstepsmap' VALUES (3270, 3539, 1);
INSERT INTO 'dancesstepsmap' VALUES (3271, 3540, 4);
INSERT INTO 'dancesstepsmap' VALUES (3272, 3541, 1);
INSERT INTO 'dancesstepsmap' VALUES (3273, 3542, 1);
INSERT INTO 'dancesstepsmap' VALUES (3274, 3543, 1);
INSERT INTO 'dancesstepsmap' VALUES (3275, 3544, 1);
INSERT INTO 'dancesstepsmap' VALUES (3276, 3545, 1);
INSERT INTO 'dancesstepsmap' VALUES (3277, 3546, 1);
INSERT INTO 'dancesstepsmap' VALUES (3278, 3547, 1);
INSERT INTO 'dancesstepsmap' VALUES (3279, 3548, 4);
INSERT INTO 'dancesstepsmap' VALUES (3280, 3549, 4);
INSERT INTO 'dancesstepsmap' VALUES (3281, 3550, 4);
INSERT INTO 'dancesstepsmap' VALUES (3282, 3551, 4);
INSERT INTO 'dancesstepsmap' VALUES (3283, 3552, 4);
INSERT INTO 'dancesstepsmap' VALUES (3284, 3553, 4);
INSERT INTO 'dancesstepsmap' VALUES (3285, 3554, 1);
INSERT INTO 'dancesstepsmap' VALUES (3286, 3555, 1);
INSERT INTO 'dancesstepsmap' VALUES (3287, 3556, 1);
INSERT INTO 'dancesstepsmap' VALUES (3288, 3557, 1);
INSERT INTO 'dancesstepsmap' VALUES (3289, 3558, 1);
INSERT INTO 'dancesstepsmap' VALUES (3290, 3559, 4);
INSERT INTO 'dancesstepsmap' VALUES (3291, 3560, 4);
INSERT INTO 'dancesstepsmap' VALUES (3292, 3561, 1);
INSERT INTO 'dancesstepsmap' VALUES (3293, 3562, 1);
INSERT INTO 'dancesstepsmap' VALUES (3294, 3563, 1);
INSERT INTO 'dancesstepsmap' VALUES (3295, 3564, 1);
INSERT INTO 'dancesstepsmap' VALUES (3296, 3565, 1);
INSERT INTO 'dancesstepsmap' VALUES (3297, 3566, 1);
INSERT INTO 'dancesstepsmap' VALUES (3298, 3567, 1);
INSERT INTO 'dancesstepsmap' VALUES (3299, 3568, 4);
INSERT INTO 'dancesstepsmap' VALUES (3300, 3569, 1);
INSERT INTO 'dancesstepsmap' VALUES (3301, 3570, 1);
INSERT INTO 'dancesstepsmap' VALUES (3302, 3571, 1);
INSERT INTO 'dancesstepsmap' VALUES (3303, 3572, 4);
INSERT INTO 'dancesstepsmap' VALUES (3304, 3573, 1);
INSERT INTO 'dancesstepsmap' VALUES (3305, 3574, 4);
INSERT INTO 'dancesstepsmap' VALUES (3306, 3575, 1);
INSERT INTO 'dancesstepsmap' VALUES (3307, 3576, 1);
INSERT INTO 'dancesstepsmap' VALUES (3308, 3577, 1);
INSERT INTO 'dancesstepsmap' VALUES (3309, 3578, 1);
INSERT INTO 'dancesstepsmap' VALUES (3310, 3579, 1);
INSERT INTO 'dancesstepsmap' VALUES (3311, 3580, 1);
INSERT INTO 'dancesstepsmap' VALUES (3312, 3581, 1);
INSERT INTO 'dancesstepsmap' VALUES (3313, 3582, 1);
INSERT INTO 'dancesstepsmap' VALUES (3314, 3583, 1);
INSERT INTO 'dancesstepsmap' VALUES (3315, 3584, 1);
INSERT INTO 'dancesstepsmap' VALUES (3316, 3585, 1);
INSERT INTO 'dancesstepsmap' VALUES (3317, 3586, 4);
INSERT INTO 'dancesstepsmap' VALUES (3318, 3588, 4);
INSERT INTO 'dancesstepsmap' VALUES (3319, 3589, 1);
INSERT INTO 'dancesstepsmap' VALUES (3320, 3590, 1);
INSERT INTO 'dancesstepsmap' VALUES (3321, 3591, 4);
INSERT INTO 'dancesstepsmap' VALUES (3322, 3592, 4);
INSERT INTO 'dancesstepsmap' VALUES (3323, 3593, 1);
INSERT INTO 'dancesstepsmap' VALUES (3324, 3594, 1);
INSERT INTO 'dancesstepsmap' VALUES (3325, 3595, 4);
INSERT INTO 'dancesstepsmap' VALUES (3326, 3596, 1);
INSERT INTO 'dancesstepsmap' VALUES (3327, 3597, 1);
INSERT INTO 'dancesstepsmap' VALUES (3328, 3598, 4);
INSERT INTO 'dancesstepsmap' VALUES (3329, 3599, 4);
INSERT INTO 'dancesstepsmap' VALUES (11203, 10317, 5);
INSERT INTO 'dancesstepsmap' VALUES (11204, 10318, 1);
INSERT INTO 'dancesstepsmap' VALUES (11205, 10319, 2);
INSERT INTO 'dancesstepsmap' VALUES (11206, 10319, 1);
INSERT INTO 'dancesstepsmap' VALUES (11207, 10319, 4);
INSERT INTO 'dancesstepsmap' VALUES (11208, 10319, 5);
INSERT INTO 'dancesstepsmap' VALUES (11209, 10320, 1);
INSERT INTO 'dancesstepsmap' VALUES (11210, 10320, 2);
INSERT INTO 'dancesstepsmap' VALUES (11211, 9008, 3);
INSERT INTO 'dancesstepsmap' VALUES (11212, 9008, 2);
INSERT INTO 'dancesstepsmap' VALUES (11213, 9008, 1);
INSERT INTO 'dancesstepsmap' VALUES (11214, 10321, 2);
INSERT INTO 'dancesstepsmap' VALUES (11215, 10321, 3);
INSERT INTO 'dancesstepsmap' VALUES (11216, 10322, 1);
INSERT INTO 'dancesstepsmap' VALUES (11217, 9009, 1);
INSERT INTO 'dancesstepsmap' VALUES (11218, 4618, 3);
INSERT INTO 'dancesstepsmap' VALUES (11219, 3244, 6);
INSERT INTO 'dancesstepsmap' VALUES (11220, 10323, 4);
INSERT INTO 'dancesstepsmap' VALUES (11221, 10323, 5);
INSERT INTO 'dancesstepsmap' VALUES (11222, 9010, 1);
INSERT INTO 'dancesstepsmap' VALUES (11223, 9473, 4);
INSERT INTO 'dancesstepsmap' VALUES (11224, 9473, 5);
INSERT INTO 'dancesstepsmap' VALUES (11225, 10324, 4);
INSERT INTO 'dancesstepsmap' VALUES (11226, 4495, 2);
INSERT INTO 'dancesstepsmap' VALUES (11227, 10326, 1);
INSERT INTO 'dancesstepsmap' VALUES (11228, 6052, 5);
INSERT INTO 'dancesstepsmap' VALUES (11229, 10328, 1);
INSERT INTO 'dancesstepsmap' VALUES (11230, 10329, 4);
INSERT INTO 'dancesstepsmap' VALUES (11231, 9215, 1);
INSERT INTO 'dancesstepsmap' VALUES (11232, 9215, 3);
INSERT INTO 'dancesstepsmap' VALUES (11233, 10330, 2);
INSERT INTO 'dancesstepsmap' VALUES (11234, 10330, 1);
INSERT INTO 'dancesstepsmap' VALUES (11235, 10330, 3);
INSERT INTO 'dancesstepsmap' VALUES (11236, 10331, 2);
INSERT INTO 'dancesstepsmap' VALUES (11237, 10331, 1);
INSERT INTO 'dancesstepsmap' VALUES (11238, 10331, 3);
INSERT INTO 'dancesstepsmap' VALUES (11239, 10332, 3);
INSERT INTO 'dancesstepsmap' VALUES (11240, 10332, 1);
INSERT INTO 'dancesstepsmap' VALUES (11241, 10333, 1);
INSERT INTO 'dancesstepsmap' VALUES (11242, 10333, 3);
INSERT INTO 'dancesstepsmap' VALUES (11243, 10334, 1);
INSERT INTO 'dancesstepsmap' VALUES (11244, 8033, 2);
INSERT INTO 'dancesstepsmap' VALUES (17074, 14523, 5);
INSERT INTO 'dancesstepsmap' VALUES (17075, 14523, 4);
INSERT INTO 'dancesstepsmap' VALUES (17095, 5860, 2);
INSERT INTO 'dancesstepsmap' VALUES (17103, 14534, 5);
INSERT INTO 'dancesstepsmap' VALUES (17104, 14534, 4);
INSERT INTO 'dancesstepsmap' VALUES (17122, 14543, 4);
INSERT INTO 'dancesstepsmap' VALUES (17123, 14543, 5);
INSERT INTO 'dancesstepsmap' VALUES (17124, 14543, 1);
INSERT INTO 'dancesstepsmap' VALUES (3330, 3600, 4);
INSERT INTO 'dancesstepsmap' VALUES (3331, 3601, 1);
INSERT INTO 'dancesstepsmap' VALUES (3332, 3602, 1);
INSERT INTO 'dancesstepsmap' VALUES (3333, 3603, 4);
INSERT INTO 'dancesstepsmap' VALUES (3334, 3604, 1);
INSERT INTO 'dancesstepsmap' VALUES (3335, 3605, 1);
INSERT INTO 'dancesstepsmap' VALUES (3336, 3606, 1);
INSERT INTO 'dancesstepsmap' VALUES (3337, 3607, 4);
INSERT INTO 'dancesstepsmap' VALUES (3338, 3608, 1);
INSERT INTO 'dancesstepsmap' VALUES (3339, 3609, 1);
INSERT INTO 'dancesstepsmap' VALUES (3340, 3610, 1);
INSERT INTO 'dancesstepsmap' VALUES (3341, 3611, 4);
INSERT INTO 'dancesstepsmap' VALUES (3342, 3612, 4);
INSERT INTO 'dancesstepsmap' VALUES (3343, 3613, 1);
INSERT INTO 'dancesstepsmap' VALUES (3344, 3615, 4);
INSERT INTO 'dancesstepsmap' VALUES (3345, 3616, 4);
INSERT INTO 'dancesstepsmap' VALUES (3346, 3617, 4);
INSERT INTO 'dancesstepsmap' VALUES (3347, 3618, 4);
INSERT INTO 'dancesstepsmap' VALUES (3348, 3619, 4);
INSERT INTO 'dancesstepsmap' VALUES (3349, 3620, 1);
INSERT INTO 'dancesstepsmap' VALUES (3350, 3621, 1);
INSERT INTO 'dancesstepsmap' VALUES (3351, 3622, 1);
INSERT INTO 'dancesstepsmap' VALUES (3352, 3623, 1);
INSERT INTO 'dancesstepsmap' VALUES (3353, 3624, 4);
INSERT INTO 'dancesstepsmap' VALUES (3354, 3626, 4);
INSERT INTO 'dancesstepsmap' VALUES (3355, 3628, 1);
INSERT INTO 'dancesstepsmap' VALUES (3356, 3629, 4);
INSERT INTO 'dancesstepsmap' VALUES (3357, 3630, 4);
INSERT INTO 'dancesstepsmap' VALUES (3358, 3631, 1);
INSERT INTO 'dancesstepsmap' VALUES (3359, 3632, 1);
INSERT INTO 'dancesstepsmap' VALUES (3360, 3633, 4);
INSERT INTO 'dancesstepsmap' VALUES (3361, 3634, 1);
INSERT INTO 'dancesstepsmap' VALUES (3362, 3635, 1);
INSERT INTO 'dancesstepsmap' VALUES (3363, 3636, 1);
INSERT INTO 'dancesstepsmap' VALUES (3364, 3637, 1);
INSERT INTO 'dancesstepsmap' VALUES (3365, 3638, 4);
INSERT INTO 'dancesstepsmap' VALUES (3366, 3639, 1);
INSERT INTO 'dancesstepsmap' VALUES (3367, 3640, 1);
INSERT INTO 'dancesstepsmap' VALUES (3368, 3642, 4);
INSERT INTO 'dancesstepsmap' VALUES (3369, 3643, 1);
INSERT INTO 'dancesstepsmap' VALUES (3370, 3644, 4);
INSERT INTO 'dancesstepsmap' VALUES (3371, 3645, 1);
INSERT INTO 'dancesstepsmap' VALUES (3372, 3646, 4);
INSERT INTO 'dancesstepsmap' VALUES (3373, 3647, 1);
INSERT INTO 'dancesstepsmap' VALUES (3374, 3648, 1);
INSERT INTO 'dancesstepsmap' VALUES (3375, 3650, 1);
INSERT INTO 'dancesstepsmap' VALUES (3376, 3651, 1);
INSERT INTO 'dancesstepsmap' VALUES (3377, 3652, 1);
INSERT INTO 'dancesstepsmap' VALUES (3378, 3653, 4);
INSERT INTO 'dancesstepsmap' VALUES (3379, 3654, 4);
INSERT INTO 'dancesstepsmap' VALUES (3380, 3655, 4);
INSERT INTO 'dancesstepsmap' VALUES (3381, 3656, 1);
INSERT INTO 'dancesstepsmap' VALUES (3382, 3657, 4);
INSERT INTO 'dancesstepsmap' VALUES (3383, 3658, 1);
INSERT INTO 'dancesstepsmap' VALUES (3384, 3659, 1);
INSERT INTO 'dancesstepsmap' VALUES (3385, 3660, 1);
INSERT INTO 'dancesstepsmap' VALUES (3386, 3661, 1);
INSERT INTO 'dancesstepsmap' VALUES (3387, 3663, 1);
INSERT INTO 'dancesstepsmap' VALUES (3388, 3664, 1);
INSERT INTO 'dancesstepsmap' VALUES (3389, 3665, 4);
INSERT INTO 'dancesstepsmap' VALUES (3390, 3666, 1);
INSERT INTO 'dancesstepsmap' VALUES (3391, 3667, 1);
INSERT INTO 'dancesstepsmap' VALUES (3392, 3668, 4);
INSERT INTO 'dancesstepsmap' VALUES (3393, 3669, 1);
INSERT INTO 'dancesstepsmap' VALUES (3394, 3670, 1);
INSERT INTO 'dancesstepsmap' VALUES (3395, 3671, 4);
INSERT INTO 'dancesstepsmap' VALUES (3396, 3672, 1);
INSERT INTO 'dancesstepsmap' VALUES (3397, 3673, 4);
INSERT INTO 'dancesstepsmap' VALUES (3398, 3674, 4);
INSERT INTO 'dancesstepsmap' VALUES (3399, 3675, 1);
INSERT INTO 'dancesstepsmap' VALUES (3400, 3676, 4);
INSERT INTO 'dancesstepsmap' VALUES (3401, 3677, 1);
INSERT INTO 'dancesstepsmap' VALUES (3402, 3678, 4);
INSERT INTO 'dancesstepsmap' VALUES (3403, 3679, 1);
INSERT INTO 'dancesstepsmap' VALUES (3404, 3680, 1);
INSERT INTO 'dancesstepsmap' VALUES (3405, 3681, 1);
INSERT INTO 'dancesstepsmap' VALUES (3406, 3682, 1);
INSERT INTO 'dancesstepsmap' VALUES (3407, 3683, 1);
INSERT INTO 'dancesstepsmap' VALUES (3408, 3684, 1);
INSERT INTO 'dancesstepsmap' VALUES (3409, 3685, 4);
INSERT INTO 'dancesstepsmap' VALUES (3410, 3686, 1);
INSERT INTO 'dancesstepsmap' VALUES (3411, 3687, 1);
INSERT INTO 'dancesstepsmap' VALUES (3412, 3689, 1);
INSERT INTO 'dancesstepsmap' VALUES (3413, 3690, 4);
INSERT INTO 'dancesstepsmap' VALUES (3414, 3691, 1);
INSERT INTO 'dancesstepsmap' VALUES (3415, 3692, 1);
INSERT INTO 'dancesstepsmap' VALUES (3416, 3694, 1);
INSERT INTO 'dancesstepsmap' VALUES (3417, 3695, 1);
INSERT INTO 'dancesstepsmap' VALUES (3418, 3696, 1);
INSERT INTO 'dancesstepsmap' VALUES (3419, 3697, 1);
INSERT INTO 'dancesstepsmap' VALUES (3420, 3698, 1);
INSERT INTO 'dancesstepsmap' VALUES (3421, 3699, 4);
INSERT INTO 'dancesstepsmap' VALUES (23140, 4304, 5);
INSERT INTO 'dancesstepsmap' VALUES (11246, 10335, 2);
INSERT INTO 'dancesstepsmap' VALUES (11247, 10335, 1);
INSERT INTO 'dancesstepsmap' VALUES (11248, 471, 3);
INSERT INTO 'dancesstepsmap' VALUES (11249, 9286, 2);
INSERT INTO 'dancesstepsmap' VALUES (11250, 9286, 1);
INSERT INTO 'dancesstepsmap' VALUES (11251, 8359, 3);
INSERT INTO 'dancesstepsmap' VALUES (11252, 8737, 4);
INSERT INTO 'dancesstepsmap' VALUES (11253, 8737, 5);
INSERT INTO 'dancesstepsmap' VALUES (11254, 10337, 1);
INSERT INTO 'dancesstepsmap' VALUES (11255, 10337, 3);
INSERT INTO 'dancesstepsmap' VALUES (11256, 10338, 1);
INSERT INTO 'dancesstepsmap' VALUES (11257, 9403, 2);
INSERT INTO 'dancesstepsmap' VALUES (11258, 9403, 3);
INSERT INTO 'dancesstepsmap' VALUES (11259, 9403, 1);
INSERT INTO 'dancesstepsmap' VALUES (11260, 10339, 1);
INSERT INTO 'dancesstepsmap' VALUES (11261, 10339, 2);
INSERT INTO 'dancesstepsmap' VALUES (11262, 10339, 4);
INSERT INTO 'dancesstepsmap' VALUES (11263, 10339, 5);
INSERT INTO 'dancesstepsmap' VALUES (11264, 9937, 4);
INSERT INTO 'dancesstepsmap' VALUES (11265, 9937, 5);
INSERT INTO 'dancesstepsmap' VALUES (11266, 9476, 1);
INSERT INTO 'dancesstepsmap' VALUES (11267, 6327, 5);
INSERT INTO 'dancesstepsmap' VALUES (11268, 10340, 4);
INSERT INTO 'dancesstepsmap' VALUES (11269, 10341, 1);
INSERT INTO 'dancesstepsmap' VALUES (11270, 10341, 3);
INSERT INTO 'dancesstepsmap' VALUES (11271, 10342, 4);
INSERT INTO 'dancesstepsmap' VALUES (11272, 9725, 1);
INSERT INTO 'dancesstepsmap' VALUES (11273, 8158, 3);
INSERT INTO 'dancesstepsmap' VALUES (11274, 9220, 1);
INSERT INTO 'dancesstepsmap' VALUES (11275, 9013, 5);
INSERT INTO 'dancesstepsmap' VALUES (11276, 9013, 4);
INSERT INTO 'dancesstepsmap' VALUES (11277, 10344, 4);
INSERT INTO 'dancesstepsmap' VALUES (11278, 10344, 5);
INSERT INTO 'dancesstepsmap' VALUES (11279, 10345, 1);
INSERT INTO 'dancesstepsmap' VALUES (11280, 10345, 2);
INSERT INTO 'dancesstepsmap' VALUES (11281, 10345, 3);
INSERT INTO 'dancesstepsmap' VALUES (11282, 10346, 2);
INSERT INTO 'dancesstepsmap' VALUES (11283, 10346, 1);
INSERT INTO 'dancesstepsmap' VALUES (11284, 10346, 3);
INSERT INTO 'dancesstepsmap' VALUES (11285, 6638, 2);
INSERT INTO 'dancesstepsmap' VALUES (11286, 6638, 3);
INSERT INTO 'dancesstepsmap' VALUES (11287, 7564, 2);
INSERT INTO 'dancesstepsmap' VALUES (17076, 14524, 4);
INSERT INTO 'dancesstepsmap' VALUES (17077, 14524, 5);
INSERT INTO 'dancesstepsmap' VALUES (17105, 14535, 2);
INSERT INTO 'dancesstepsmap' VALUES (17106, 14535, 1);
INSERT INTO 'dancesstepsmap' VALUES (17125, 14543, 3);
INSERT INTO 'dancesstepsmap' VALUES (17126, 14544, 1);
INSERT INTO 'dancesstepsmap' VALUES (17127, 12279, 1);
INSERT INTO 'dancesstepsmap' VALUES (17129, 3759, 5);
INSERT INTO 'dancesstepsmap' VALUES (17130, 9761, 5);
INSERT INTO 'dancesstepsmap' VALUES (17131, 3981, 2);
INSERT INTO 'dancesstepsmap' VALUES (17132, 3981, 3);
INSERT INTO 'dancesstepsmap' VALUES (17133, 5755, 5);
INSERT INTO 'dancesstepsmap' VALUES (17134, 3108, 2);
INSERT INTO 'dancesstepsmap' VALUES (17135, 14549, 1);
INSERT INTO 'dancesstepsmap' VALUES (17137, 14551, 1);
INSERT INTO 'dancesstepsmap' VALUES (17138, 14551, 2);
INSERT INTO 'dancesstepsmap' VALUES (17139, 14551, 3);
INSERT INTO 'dancesstepsmap' VALUES (17140, 14552, 2);
INSERT INTO 'dancesstepsmap' VALUES (17141, 14552, 1);
INSERT INTO 'dancesstepsmap' VALUES (17142, 14552, 3);
INSERT INTO 'dancesstepsmap' VALUES (17147, 14554, 4);
INSERT INTO 'dancesstepsmap' VALUES (3422, 3700, 4);
INSERT INTO 'dancesstepsmap' VALUES (3423, 3701, 1);
INSERT INTO 'dancesstepsmap' VALUES (3424, 3702, 1);
INSERT INTO 'dancesstepsmap' VALUES (3425, 3703, 1);
INSERT INTO 'dancesstepsmap' VALUES (3426, 3704, 1);
INSERT INTO 'dancesstepsmap' VALUES (3427, 3705, 1);
INSERT INTO 'dancesstepsmap' VALUES (3428, 3706, 4);
INSERT INTO 'dancesstepsmap' VALUES (3429, 3707, 1);
INSERT INTO 'dancesstepsmap' VALUES (3430, 3708, 4);
INSERT INTO 'dancesstepsmap' VALUES (3431, 3709, 1);
INSERT INTO 'dancesstepsmap' VALUES (3432, 3710, 4);
INSERT INTO 'dancesstepsmap' VALUES (3433, 3711, 4);
INSERT INTO 'dancesstepsmap' VALUES (3434, 3713, 1);
INSERT INTO 'dancesstepsmap' VALUES (3435, 3715, 1);
INSERT INTO 'dancesstepsmap' VALUES (3436, 3717, 1);
INSERT INTO 'dancesstepsmap' VALUES (3437, 3718, 4);
INSERT INTO 'dancesstepsmap' VALUES (3438, 3719, 1);
INSERT INTO 'dancesstepsmap' VALUES (3439, 3720, 4);
INSERT INTO 'dancesstepsmap' VALUES (3440, 3721, 1);
INSERT INTO 'dancesstepsmap' VALUES (3441, 3722, 1);
INSERT INTO 'dancesstepsmap' VALUES (3442, 3723, 4);
INSERT INTO 'dancesstepsmap' VALUES (3443, 3724, 1);
INSERT INTO 'dancesstepsmap' VALUES (3444, 3725, 1);
INSERT INTO 'dancesstepsmap' VALUES (3445, 3726, 4);
INSERT INTO 'dancesstepsmap' VALUES (3446, 3727, 1);
INSERT INTO 'dancesstepsmap' VALUES (3447, 3728, 4);
INSERT INTO 'dancesstepsmap' VALUES (3448, 3729, 99);
INSERT INTO 'dancesstepsmap' VALUES (3449, 3730, 1);
INSERT INTO 'dancesstepsmap' VALUES (3450, 3731, 1);
INSERT INTO 'dancesstepsmap' VALUES (3451, 3733, 1);
INSERT INTO 'dancesstepsmap' VALUES (3452, 3734, 1);
INSERT INTO 'dancesstepsmap' VALUES (3453, 3735, 1);
INSERT INTO 'dancesstepsmap' VALUES (3454, 3736, 1);
INSERT INTO 'dancesstepsmap' VALUES (3455, 3737, 1);
INSERT INTO 'dancesstepsmap' VALUES (3456, 3738, 1);
INSERT INTO 'dancesstepsmap' VALUES (3457, 3739, 1);
INSERT INTO 'dancesstepsmap' VALUES (3458, 3740, 1);
INSERT INTO 'dancesstepsmap' VALUES (3459, 3741, 1);
INSERT INTO 'dancesstepsmap' VALUES (3460, 3742, 1);
INSERT INTO 'dancesstepsmap' VALUES (3461, 3743, 1);
INSERT INTO 'dancesstepsmap' VALUES (3462, 3744, 4);
INSERT INTO 'dancesstepsmap' VALUES (3463, 3745, 1);
INSERT INTO 'dancesstepsmap' VALUES (3464, 3746, 1);
INSERT INTO 'dancesstepsmap' VALUES (3465, 3747, 1);
INSERT INTO 'dancesstepsmap' VALUES (3466, 3748, 1);
INSERT INTO 'dancesstepsmap' VALUES (3467, 3749, 1);
INSERT INTO 'dancesstepsmap' VALUES (3468, 3751, 1);
INSERT INTO 'dancesstepsmap' VALUES (3469, 3752, 4);
INSERT INTO 'dancesstepsmap' VALUES (3470, 3753, 1);
INSERT INTO 'dancesstepsmap' VALUES (3471, 3755, 4);
INSERT INTO 'dancesstepsmap' VALUES (3472, 3756, 4);
INSERT INTO 'dancesstepsmap' VALUES (3473, 3757, 1);
INSERT INTO 'dancesstepsmap' VALUES (3474, 3758, 4);
INSERT INTO 'dancesstepsmap' VALUES (3475, 3759, 4);
INSERT INTO 'dancesstepsmap' VALUES (3476, 3760, 1);
INSERT INTO 'dancesstepsmap' VALUES (3477, 3761, 1);
INSERT INTO 'dancesstepsmap' VALUES (3478, 3762, 1);
INSERT INTO 'dancesstepsmap' VALUES (3479, 3763, 1);
INSERT INTO 'dancesstepsmap' VALUES (3480, 3764, 1);
INSERT INTO 'dancesstepsmap' VALUES (3481, 3765, 4);
INSERT INTO 'dancesstepsmap' VALUES (3482, 3766, 4);
INSERT INTO 'dancesstepsmap' VALUES (3483, 3767, 1);
INSERT INTO 'dancesstepsmap' VALUES (3484, 3768, 1);
INSERT INTO 'dancesstepsmap' VALUES (3485, 3769, 1);
INSERT INTO 'dancesstepsmap' VALUES (3486, 3770, 1);
INSERT INTO 'dancesstepsmap' VALUES (3487, 3771, 1);
INSERT INTO 'dancesstepsmap' VALUES (3488, 3773, 1);
INSERT INTO 'dancesstepsmap' VALUES (3489, 3774, 1);
INSERT INTO 'dancesstepsmap' VALUES (3490, 3775, 4);
INSERT INTO 'dancesstepsmap' VALUES (3491, 3776, 1);
INSERT INTO 'dancesstepsmap' VALUES (3492, 3777, 4);
INSERT INTO 'dancesstepsmap' VALUES (3493, 3778, 1);
INSERT INTO 'dancesstepsmap' VALUES (3494, 3781, 4);
INSERT INTO 'dancesstepsmap' VALUES (3495, 3782, 1);
INSERT INTO 'dancesstepsmap' VALUES (3496, 3783, 1);
INSERT INTO 'dancesstepsmap' VALUES (3497, 3784, 4);
INSERT INTO 'dancesstepsmap' VALUES (3498, 3786, 1);
INSERT INTO 'dancesstepsmap' VALUES (3499, 3787, 1);
INSERT INTO 'dancesstepsmap' VALUES (3500, 3788, 4);
INSERT INTO 'dancesstepsmap' VALUES (3501, 3789, 4);
INSERT INTO 'dancesstepsmap' VALUES (3502, 3790, 1);
INSERT INTO 'dancesstepsmap' VALUES (3503, 3792, 1);
INSERT INTO 'dancesstepsmap' VALUES (3504, 3793, 1);
INSERT INTO 'dancesstepsmap' VALUES (3505, 3794, 1);
INSERT INTO 'dancesstepsmap' VALUES (3506, 3795, 1);
INSERT INTO 'dancesstepsmap' VALUES (3507, 3796, 1);
INSERT INTO 'dancesstepsmap' VALUES (3508, 3797, 4);
INSERT INTO 'dancesstepsmap' VALUES (3509, 3798, 1);
INSERT INTO 'dancesstepsmap' VALUES (3510, 3799, 1);
INSERT INTO 'dancesstepsmap' VALUES (3511, 3800, 1);
INSERT INTO 'dancesstepsmap' VALUES (3512, 3801, 4);
INSERT INTO 'dancesstepsmap' VALUES (3513, 3802, 1);
INSERT INTO 'dancesstepsmap' VALUES (3514, 3803, 4);
INSERT INTO 'dancesstepsmap' VALUES (3515, 3804, 4);
INSERT INTO 'dancesstepsmap' VALUES (3516, 3805, 1);
INSERT INTO 'dancesstepsmap' VALUES (3517, 3806, 1);
INSERT INTO 'dancesstepsmap' VALUES (3518, 3807, 4);
INSERT INTO 'dancesstepsmap' VALUES (3519, 3808, 4);
INSERT INTO 'dancesstepsmap' VALUES (3520, 3809, 1);
INSERT INTO 'dancesstepsmap' VALUES (3521, 3810, 4);
INSERT INTO 'dancesstepsmap' VALUES (3522, 3811, 4);
INSERT INTO 'dancesstepsmap' VALUES (3523, 3812, 4);
INSERT INTO 'dancesstepsmap' VALUES (3524, 3813, 1);
INSERT INTO 'dancesstepsmap' VALUES (3525, 3814, 4);
INSERT INTO 'dancesstepsmap' VALUES (3526, 3816, 1);
INSERT INTO 'dancesstepsmap' VALUES (3527, 3817, 1);
INSERT INTO 'dancesstepsmap' VALUES (3528, 3818, 1);
INSERT INTO 'dancesstepsmap' VALUES (3529, 3819, 1);
INSERT INTO 'dancesstepsmap' VALUES (3530, 3820, 4);
INSERT INTO 'dancesstepsmap' VALUES (3531, 3821, 1);
INSERT INTO 'dancesstepsmap' VALUES (3532, 3822, 4);
INSERT INTO 'dancesstepsmap' VALUES (3533, 3824, 1);
INSERT INTO 'dancesstepsmap' VALUES (3534, 3825, 1);
INSERT INTO 'dancesstepsmap' VALUES (3535, 3826, 1);
INSERT INTO 'dancesstepsmap' VALUES (3536, 3827, 4);
INSERT INTO 'dancesstepsmap' VALUES (3537, 3828, 1);
INSERT INTO 'dancesstepsmap' VALUES (3538, 3829, 1);
INSERT INTO 'dancesstepsmap' VALUES (3539, 3830, 1);
INSERT INTO 'dancesstepsmap' VALUES (3540, 3831, 4);
INSERT INTO 'dancesstepsmap' VALUES (3541, 3834, 1);
INSERT INTO 'dancesstepsmap' VALUES (3542, 3835, 4);
INSERT INTO 'dancesstepsmap' VALUES (3543, 3836, 1);
INSERT INTO 'dancesstepsmap' VALUES (3544, 3837, 1);
INSERT INTO 'dancesstepsmap' VALUES (3545, 3838, 1);
INSERT INTO 'dancesstepsmap' VALUES (3546, 3840, 4);
INSERT INTO 'dancesstepsmap' VALUES (3547, 3841, 1);
INSERT INTO 'dancesstepsmap' VALUES (3548, 3842, 1);
INSERT INTO 'dancesstepsmap' VALUES (3549, 3843, 1);
INSERT INTO 'dancesstepsmap' VALUES (3550, 3844, 1);
INSERT INTO 'dancesstepsmap' VALUES (3551, 3845, 1);
INSERT INTO 'dancesstepsmap' VALUES (11288, 7989, 3);
INSERT INTO 'dancesstepsmap' VALUES (11289, 7989, 2);
INSERT INTO 'dancesstepsmap' VALUES (11290, 10347, 4);
INSERT INTO 'dancesstepsmap' VALUES (11291, 10348, 1);
INSERT INTO 'dancesstepsmap' VALUES (11292, 10348, 3);
INSERT INTO 'dancesstepsmap' VALUES (11293, 10349, 2);
INSERT INTO 'dancesstepsmap' VALUES (11294, 10349, 1);
INSERT INTO 'dancesstepsmap' VALUES (11295, 10349, 4);
INSERT INTO 'dancesstepsmap' VALUES (11296, 10349, 5);
INSERT INTO 'dancesstepsmap' VALUES (11297, 7031, 2);
INSERT INTO 'dancesstepsmap' VALUES (11298, 7031, 3);
INSERT INTO 'dancesstepsmap' VALUES (11299, 7085, 6);
INSERT INTO 'dancesstepsmap' VALUES (11300, 9903, 5);
INSERT INTO 'dancesstepsmap' VALUES (11301, 9903, 4);
INSERT INTO 'dancesstepsmap' VALUES (11302, 10170, 1);
INSERT INTO 'dancesstepsmap' VALUES (11303, 10350, 1);
INSERT INTO 'dancesstepsmap' VALUES (3552, 3846, 4);
INSERT INTO 'dancesstepsmap' VALUES (3553, 3847, 4);
INSERT INTO 'dancesstepsmap' VALUES (3554, 3848, 1);
INSERT INTO 'dancesstepsmap' VALUES (3555, 3849, 1);
INSERT INTO 'dancesstepsmap' VALUES (3556, 3850, 4);
INSERT INTO 'dancesstepsmap' VALUES (3557, 3851, 1);
INSERT INTO 'dancesstepsmap' VALUES (3558, 3852, 1);
INSERT INTO 'dancesstepsmap' VALUES (3559, 3853, 1);
INSERT INTO 'dancesstepsmap' VALUES (3560, 3854, 1);
INSERT INTO 'dancesstepsmap' VALUES (3561, 3855, 1);
INSERT INTO 'dancesstepsmap' VALUES (3562, 3856, 1);
INSERT INTO 'dancesstepsmap' VALUES (3563, 3857, 4);
INSERT INTO 'dancesstepsmap' VALUES (3564, 3858, 1);
INSERT INTO 'dancesstepsmap' VALUES (3565, 3859, 4);
INSERT INTO 'dancesstepsmap' VALUES (3566, 3860, 4);
INSERT INTO 'dancesstepsmap' VALUES (3567, 3861, 1);
INSERT INTO 'dancesstepsmap' VALUES (3568, 3862, 1);
INSERT INTO 'dancesstepsmap' VALUES (3569, 3863, 4);
INSERT INTO 'dancesstepsmap' VALUES (3570, 3864, 4);
INSERT INTO 'dancesstepsmap' VALUES (3571, 3865, 4);
INSERT INTO 'dancesstepsmap' VALUES (3572, 3866, 1);
INSERT INTO 'dancesstepsmap' VALUES (3573, 3867, 4);
INSERT INTO 'dancesstepsmap' VALUES (3574, 3868, 1);
INSERT INTO 'dancesstepsmap' VALUES (3575, 3869, 4);
INSERT INTO 'dancesstepsmap' VALUES (3576, 3870, 1);
INSERT INTO 'dancesstepsmap' VALUES (3577, 3871, 4);
INSERT INTO 'dancesstepsmap' VALUES (3578, 3872, 1);
INSERT INTO 'dancesstepsmap' VALUES (3579, 3873, 1);
INSERT INTO 'dancesstepsmap' VALUES (3580, 3874, 4);
INSERT INTO 'dancesstepsmap' VALUES (3581, 3875, 4);
INSERT INTO 'dancesstepsmap' VALUES (3582, 3876, 1);
INSERT INTO 'dancesstepsmap' VALUES (3583, 3877, 1);
INSERT INTO 'dancesstepsmap' VALUES (3585, 3879, 4);
INSERT INTO 'dancesstepsmap' VALUES (3586, 3880, 4);
INSERT INTO 'dancesstepsmap' VALUES (3587, 3881, 1);
INSERT INTO 'dancesstepsmap' VALUES (3588, 3882, 4);
INSERT INTO 'dancesstepsmap' VALUES (3589, 3884, 4);
INSERT INTO 'dancesstepsmap' VALUES (3590, 3885, 4);
INSERT INTO 'dancesstepsmap' VALUES (3591, 3886, 1);
INSERT INTO 'dancesstepsmap' VALUES (3592, 3887, 4);
INSERT INTO 'dancesstepsmap' VALUES (3593, 3888, 4);
INSERT INTO 'dancesstepsmap' VALUES (3594, 3889, 1);
INSERT INTO 'dancesstepsmap' VALUES (3595, 3890, 1);
INSERT INTO 'dancesstepsmap' VALUES (3596, 3891, 1);
INSERT INTO 'dancesstepsmap' VALUES (3597, 3892, 4);
INSERT INTO 'dancesstepsmap' VALUES (3598, 3893, 1);
INSERT INTO 'dancesstepsmap' VALUES (3599, 3894, 4);
INSERT INTO 'dancesstepsmap' VALUES (3600, 3895, 1);
INSERT INTO 'dancesstepsmap' VALUES (3601, 3896, 1);
INSERT INTO 'dancesstepsmap' VALUES (3602, 3897, 4);
INSERT INTO 'dancesstepsmap' VALUES (3603, 3899, 1);
INSERT INTO 'dancesstepsmap' VALUES (3604, 3900, 4);
INSERT INTO 'dancesstepsmap' VALUES (3605, 3901, 4);
INSERT INTO 'dancesstepsmap' VALUES (3606, 3902, 1);
INSERT INTO 'dancesstepsmap' VALUES (3607, 3904, 4);
INSERT INTO 'dancesstepsmap' VALUES (3608, 3905, 4);
INSERT INTO 'dancesstepsmap' VALUES (3609, 3906, 1);
INSERT INTO 'dancesstepsmap' VALUES (3610, 3907, 1);
INSERT INTO 'dancesstepsmap' VALUES (3611, 3908, 4);
INSERT INTO 'dancesstepsmap' VALUES (3612, 3909, 1);
INSERT INTO 'dancesstepsmap' VALUES (3613, 3910, 4);
INSERT INTO 'dancesstepsmap' VALUES (3614, 3911, 1);
INSERT INTO 'dancesstepsmap' VALUES (3615, 3912, 1);
INSERT INTO 'dancesstepsmap' VALUES (3616, 3913, 1);
INSERT INTO 'dancesstepsmap' VALUES (3617, 3914, 1);
INSERT INTO 'dancesstepsmap' VALUES (3618, 3915, 1);
INSERT INTO 'dancesstepsmap' VALUES (3619, 3916, 1);
INSERT INTO 'dancesstepsmap' VALUES (3620, 3917, 4);
INSERT INTO 'dancesstepsmap' VALUES (3621, 3918, 4);
INSERT INTO 'dancesstepsmap' VALUES (3622, 3919, 1);
INSERT INTO 'dancesstepsmap' VALUES (3623, 3920, 4);
INSERT INTO 'dancesstepsmap' VALUES (3624, 3922, 1);
INSERT INTO 'dancesstepsmap' VALUES (3625, 3923, 1);
INSERT INTO 'dancesstepsmap' VALUES (3626, 3924, 1);
INSERT INTO 'dancesstepsmap' VALUES (3627, 3925, 1);
INSERT INTO 'dancesstepsmap' VALUES (3628, 3926, 4);
INSERT INTO 'dancesstepsmap' VALUES (3629, 3927, 1);
INSERT INTO 'dancesstepsmap' VALUES (3630, 3928, 1);
INSERT INTO 'dancesstepsmap' VALUES (3631, 3930, 1);
INSERT INTO 'dancesstepsmap' VALUES (3632, 3931, 1);
INSERT INTO 'dancesstepsmap' VALUES (3633, 3932, 4);
INSERT INTO 'dancesstepsmap' VALUES (3634, 3933, 1);
INSERT INTO 'dancesstepsmap' VALUES (3635, 3934, 4);
INSERT INTO 'dancesstepsmap' VALUES (3636, 3935, 1);
INSERT INTO 'dancesstepsmap' VALUES (3637, 3936, 4);
INSERT INTO 'dancesstepsmap' VALUES (3638, 3937, 1);
INSERT INTO 'dancesstepsmap' VALUES (3639, 3938, 1);
INSERT INTO 'dancesstepsmap' VALUES (3640, 3939, 4);
INSERT INTO 'dancesstepsmap' VALUES (3641, 3940, 1);
INSERT INTO 'dancesstepsmap' VALUES (3642, 3941, 1);
INSERT INTO 'dancesstepsmap' VALUES (3643, 3942, 1);
INSERT INTO 'dancesstepsmap' VALUES (3644, 3943, 1);
INSERT INTO 'dancesstepsmap' VALUES (11304, 10351, 4);
INSERT INTO 'dancesstepsmap' VALUES (11305, 10351, 5);
INSERT INTO 'dancesstepsmap' VALUES (11306, 10352, 5);
INSERT INTO 'dancesstepsmap' VALUES (11307, 10352, 4);
INSERT INTO 'dancesstepsmap' VALUES (11308, 10353, 1);
INSERT INTO 'dancesstepsmap' VALUES (11309, 7517, 5);
INSERT INTO 'dancesstepsmap' VALUES (11310, 10013, 1);
INSERT INTO 'dancesstepsmap' VALUES (11311, 3310, 3);
INSERT INTO 'dancesstepsmap' VALUES (11312, 10357, 1);
INSERT INTO 'dancesstepsmap' VALUES (11313, 10358, 1);
INSERT INTO 'dancesstepsmap' VALUES (11314, 8564, 2);
INSERT INTO 'dancesstepsmap' VALUES (11315, 10360, 4);
INSERT INTO 'dancesstepsmap' VALUES (11316, 10360, 5);
INSERT INTO 'dancesstepsmap' VALUES (11317, 7545, 2);
INSERT INTO 'dancesstepsmap' VALUES (11318, 5504, 6);
INSERT INTO 'dancesstepsmap' VALUES (11319, 5504, 5);
INSERT INTO 'dancesstepsmap' VALUES (11320, 5745, 2);
INSERT INTO 'dancesstepsmap' VALUES (11321, 10361, 4);
INSERT INTO 'dancesstepsmap' VALUES (11322, 10361, 5);
INSERT INTO 'dancesstepsmap' VALUES (11323, 157, 1);
INSERT INTO 'dancesstepsmap' VALUES (11324, 197, 8);
INSERT INTO 'dancesstepsmap' VALUES (11325, 228, 3);
INSERT INTO 'dancesstepsmap' VALUES (11326, 3791, 5);
INSERT INTO 'dancesstepsmap' VALUES (11327, 300, 5);
INSERT INTO 'dancesstepsmap' VALUES (11328, 1358, 2);
INSERT INTO 'dancesstepsmap' VALUES (11329, 2203, 3);
INSERT INTO 'dancesstepsmap' VALUES (11330, 5703, 3);
INSERT INTO 'dancesstepsmap' VALUES (11331, 5713, 3);
INSERT INTO 'dancesstepsmap' VALUES (11332, 9226, 3);
INSERT INTO 'dancesstepsmap' VALUES (11333, 9237, 3);
INSERT INTO 'dancesstepsmap' VALUES (11334, 9242, 3);
INSERT INTO 'dancesstepsmap' VALUES (11335, 5438, 3);
INSERT INTO 'dancesstepsmap' VALUES (11336, 8042, 3);
INSERT INTO 'dancesstepsmap' VALUES (11337, 6229, 3);
INSERT INTO 'dancesstepsmap' VALUES (11338, 7262, 3);
INSERT INTO 'dancesstepsmap' VALUES (11339, 10357, 3);
INSERT INTO 'dancesstepsmap' VALUES (11340, 9047, 2);
INSERT INTO 'dancesstepsmap' VALUES (11341, 9047, 1);
INSERT INTO 'dancesstepsmap' VALUES (11342, 9047, 3);
INSERT INTO 'dancesstepsmap' VALUES (11343, 9289, 1);
INSERT INTO 'dancesstepsmap' VALUES (11344, 9289, 2);
INSERT INTO 'dancesstepsmap' VALUES (11345, 8328, 2);
INSERT INTO 'dancesstepsmap' VALUES (17078, 14525, 4);
INSERT INTO 'dancesstepsmap' VALUES (17079, 14525, 5);
INSERT INTO 'dancesstepsmap' VALUES (17107, 14536, 4);
INSERT INTO 'dancesstepsmap' VALUES (17108, 14536, 5);
INSERT INTO 'dancesstepsmap' VALUES (17136, 14550, 1);
INSERT INTO 'dancesstepsmap' VALUES (17143, 14553, 2);
INSERT INTO 'dancesstepsmap' VALUES (17144, 14553, 1);
INSERT INTO 'dancesstepsmap' VALUES (17148, 14557, 4);
INSERT INTO 'dancesstepsmap' VALUES (17149, 14557, 5);
INSERT INTO 'dancesstepsmap' VALUES (3645, 3944, 1);
INSERT INTO 'dancesstepsmap' VALUES (3646, 3945, 1);
INSERT INTO 'dancesstepsmap' VALUES (3647, 3946, 4);
INSERT INTO 'dancesstepsmap' VALUES (3648, 3947, 1);
INSERT INTO 'dancesstepsmap' VALUES (3649, 3948, 4);
INSERT INTO 'dancesstepsmap' VALUES (3650, 3949, 4);
INSERT INTO 'dancesstepsmap' VALUES (3651, 3950, 1);
INSERT INTO 'dancesstepsmap' VALUES (3652, 3951, 1);
INSERT INTO 'dancesstepsmap' VALUES (3653, 3952, 1);
INSERT INTO 'dancesstepsmap' VALUES (3654, 3953, 1);
INSERT INTO 'dancesstepsmap' VALUES (3655, 3954, 1);
INSERT INTO 'dancesstepsmap' VALUES (3656, 3955, 1);
INSERT INTO 'dancesstepsmap' VALUES (3657, 3956, 1);
INSERT INTO 'dancesstepsmap' VALUES (3658, 3957, 1);
INSERT INTO 'dancesstepsmap' VALUES (3659, 3958, 1);
INSERT INTO 'dancesstepsmap' VALUES (3660, 3959, 4);
INSERT INTO 'dancesstepsmap' VALUES (3661, 3960, 4);
INSERT INTO 'dancesstepsmap' VALUES (3662, 3961, 4);
INSERT INTO 'dancesstepsmap' VALUES (3663, 3962, 1);
INSERT INTO 'dancesstepsmap' VALUES (3664, 3963, 1);
INSERT INTO 'dancesstepsmap' VALUES (3665, 3964, 1);
INSERT INTO 'dancesstepsmap' VALUES (3666, 3965, 4);
INSERT INTO 'dancesstepsmap' VALUES (3667, 3966, 4);
INSERT INTO 'dancesstepsmap' VALUES (3668, 3968, 1);
INSERT INTO 'dancesstepsmap' VALUES (3669, 3969, 1);
INSERT INTO 'dancesstepsmap' VALUES (3670, 3970, 1);
INSERT INTO 'dancesstepsmap' VALUES (3671, 3971, 4);
INSERT INTO 'dancesstepsmap' VALUES (3672, 3972, 4);
INSERT INTO 'dancesstepsmap' VALUES (3673, 3973, 1);
INSERT INTO 'dancesstepsmap' VALUES (3674, 3974, 1);
INSERT INTO 'dancesstepsmap' VALUES (3675, 3975, 1);
INSERT INTO 'dancesstepsmap' VALUES (3676, 3976, 4);
INSERT INTO 'dancesstepsmap' VALUES (3677, 3977, 1);
INSERT INTO 'dancesstepsmap' VALUES (3678, 3978, 4);
INSERT INTO 'dancesstepsmap' VALUES (3679, 3979, 1);
INSERT INTO 'dancesstepsmap' VALUES (3680, 3980, 1);
INSERT INTO 'dancesstepsmap' VALUES (3681, 3981, 1);
INSERT INTO 'dancesstepsmap' VALUES (3682, 3982, 1);
INSERT INTO 'dancesstepsmap' VALUES (3683, 3983, 1);
INSERT INTO 'dancesstepsmap' VALUES (3684, 3984, 4);
INSERT INTO 'dancesstepsmap' VALUES (3685, 3985, 1);
INSERT INTO 'dancesstepsmap' VALUES (3686, 3986, 1);
INSERT INTO 'dancesstepsmap' VALUES (3687, 3987, 4);
INSERT INTO 'dancesstepsmap' VALUES (3688, 3988, 4);
INSERT INTO 'dancesstepsmap' VALUES (3689, 3989, 1);
INSERT INTO 'dancesstepsmap' VALUES (3690, 3990, 1);
INSERT INTO 'dancesstepsmap' VALUES (3691, 3991, 1);
INSERT INTO 'dancesstepsmap' VALUES (3692, 3992, 4);
INSERT INTO 'dancesstepsmap' VALUES (3693, 3994, 4);
INSERT INTO 'dancesstepsmap' VALUES (3694, 3995, 4);
INSERT INTO 'dancesstepsmap' VALUES (3695, 3997, 4);
INSERT INTO 'dancesstepsmap' VALUES (3696, 3998, 4);
INSERT INTO 'dancesstepsmap' VALUES (3697, 3999, 4);
INSERT INTO 'dancesstepsmap' VALUES (3698, 4000, 4);
INSERT INTO 'dancesstepsmap' VALUES (3699, 4001, 1);
INSERT INTO 'dancesstepsmap' VALUES (3700, 4002, 1);
INSERT INTO 'dancesstepsmap' VALUES (3701, 4003, 1);
INSERT INTO 'dancesstepsmap' VALUES (3702, 4004, 1);
INSERT INTO 'dancesstepsmap' VALUES (3703, 4005, 1);
INSERT INTO 'dancesstepsmap' VALUES (3704, 4006, 1);
INSERT INTO 'dancesstepsmap' VALUES (3705, 4007, 4);
INSERT INTO 'dancesstepsmap' VALUES (3706, 4008, 1);
INSERT INTO 'dancesstepsmap' VALUES (3707, 4009, 4);
INSERT INTO 'dancesstepsmap' VALUES (23141, 2038, 2);
INSERT INTO 'dancesstepsmap' VALUES (3709, 4011, 4);
INSERT INTO 'dancesstepsmap' VALUES (3710, 4012, 4);
INSERT INTO 'dancesstepsmap' VALUES (3711, 4014, 1);
INSERT INTO 'dancesstepsmap' VALUES (3712, 4015, 4);
INSERT INTO 'dancesstepsmap' VALUES (3713, 4016, 1);
INSERT INTO 'dancesstepsmap' VALUES (3714, 4017, 1);
INSERT INTO 'dancesstepsmap' VALUES (3715, 4018, 4);
INSERT INTO 'dancesstepsmap' VALUES (3716, 4019, 4);
INSERT INTO 'dancesstepsmap' VALUES (3717, 4020, 1);
INSERT INTO 'dancesstepsmap' VALUES (3718, 4021, 4);
INSERT INTO 'dancesstepsmap' VALUES (3719, 4022, 1);
INSERT INTO 'dancesstepsmap' VALUES (3720, 4023, 4);
INSERT INTO 'dancesstepsmap' VALUES (3721, 4024, 4);
INSERT INTO 'dancesstepsmap' VALUES (3722, 4026, 4);
INSERT INTO 'dancesstepsmap' VALUES (3723, 4027, 1);
INSERT INTO 'dancesstepsmap' VALUES (3724, 4028, 4);
INSERT INTO 'dancesstepsmap' VALUES (3725, 4029, 1);
INSERT INTO 'dancesstepsmap' VALUES (3726, 4030, 1);
INSERT INTO 'dancesstepsmap' VALUES (3727, 4031, 1);
INSERT INTO 'dancesstepsmap' VALUES (3728, 4032, 1);
INSERT INTO 'dancesstepsmap' VALUES (3729, 4033, 4);
INSERT INTO 'dancesstepsmap' VALUES (3730, 4034, 1);
INSERT INTO 'dancesstepsmap' VALUES (3731, 4035, 1);
INSERT INTO 'dancesstepsmap' VALUES (3732, 4036, 1);
INSERT INTO 'dancesstepsmap' VALUES (3733, 4037, 1);
INSERT INTO 'dancesstepsmap' VALUES (3734, 4038, 1);
INSERT INTO 'dancesstepsmap' VALUES (3735, 4039, 4);
INSERT INTO 'dancesstepsmap' VALUES (3736, 4041, 1);
INSERT INTO 'dancesstepsmap' VALUES (3737, 4042, 1);
INSERT INTO 'dancesstepsmap' VALUES (11346, 9454, 1);
INSERT INTO 'dancesstepsmap' VALUES (11347, 9456, 1);
INSERT INTO 'dancesstepsmap' VALUES (11348, 9456, 3);
INSERT INTO 'dancesstepsmap' VALUES (11349, 8501, 2);
INSERT INTO 'dancesstepsmap' VALUES (11350, 860, 3);
INSERT INTO 'dancesstepsmap' VALUES (11351, 5656, 2);
INSERT INTO 'dancesstepsmap' VALUES (11352, 4274, 3);
INSERT INTO 'dancesstepsmap' VALUES (11353, 1604, 2);
INSERT INTO 'dancesstepsmap' VALUES (11354, 1191, 3);
INSERT INTO 'dancesstepsmap' VALUES (11355, 4276, 2);
INSERT INTO 'dancesstepsmap' VALUES (11356, 5382, 2);
INSERT INTO 'dancesstepsmap' VALUES (11357, 5496, 2);
INSERT INTO 'dancesstepsmap' VALUES (11358, 4045, 6);
INSERT INTO 'dancesstepsmap' VALUES (11359, 21, 2);
INSERT INTO 'dancesstepsmap' VALUES (11360, 21, 3);
INSERT INTO 'dancesstepsmap' VALUES (11361, 735, 3);
INSERT INTO 'dancesstepsmap' VALUES (11362, 3687, 3);
INSERT INTO 'dancesstepsmap' VALUES (11363, 5657, 3);
INSERT INTO 'dancesstepsmap' VALUES (11364, 537, 2);
INSERT INTO 'dancesstepsmap' VALUES (11365, 8568, 2);
INSERT INTO 'dancesstepsmap' VALUES (11366, 8513, 3);
INSERT INTO 'dancesstepsmap' VALUES (11367, 9058, 4);
INSERT INTO 'dancesstepsmap' VALUES (11368, 9632, 4);
INSERT INTO 'dancesstepsmap' VALUES (11369, 7645, 5);
INSERT INTO 'dancesstepsmap' VALUES (11370, 9542, 4);
INSERT INTO 'dancesstepsmap' VALUES (11371, 1058, 3);
INSERT INTO 'dancesstepsmap' VALUES (11372, 1204, 3);
INSERT INTO 'dancesstepsmap' VALUES (11373, 1814, 3);
INSERT INTO 'dancesstepsmap' VALUES (11374, 1897, 3);
INSERT INTO 'dancesstepsmap' VALUES (11375, 2110, 3);
INSERT INTO 'dancesstepsmap' VALUES (11376, 8557, 3);
INSERT INTO 'dancesstepsmap' VALUES (11377, 4048, 3);
INSERT INTO 'dancesstepsmap' VALUES (11378, 5355, 3);
INSERT INTO 'dancesstepsmap' VALUES (11379, 5444, 3);
INSERT INTO 'dancesstepsmap' VALUES (11380, 5480, 3);
INSERT INTO 'dancesstepsmap' VALUES (11381, 7911, 3);
INSERT INTO 'dancesstepsmap' VALUES (11382, 5872, 3);
INSERT INTO 'dancesstepsmap' VALUES (11383, 9571, 3);
INSERT INTO 'dancesstepsmap' VALUES (11384, 7539, 3);
INSERT INTO 'dancesstepsmap' VALUES (11385, 10362, 4);
INSERT INTO 'dancesstepsmap' VALUES (11386, 8383, 1);
INSERT INTO 'dancesstepsmap' VALUES (11387, 8383, 2);
INSERT INTO 'dancesstepsmap' VALUES (17080, 14526, 5);
INSERT INTO 'dancesstepsmap' VALUES (17081, 14526, 4);
INSERT INTO 'dancesstepsmap' VALUES (17109, 14537, 9);
INSERT INTO 'dancesstepsmap' VALUES (17110, 14537, 4);
INSERT INTO 'dancesstepsmap' VALUES (17145, 5374, 5);
INSERT INTO 'dancesstepsmap' VALUES (23142, 5037, 5);
INSERT INTO 'dancesstepsmap' VALUES (17159, 1647, 2);
INSERT INTO 'dancesstepsmap' VALUES (17160, 2935, 2);
INSERT INTO 'dancesstepsmap' VALUES (17161, 13622, 1);
INSERT INTO 'dancesstepsmap' VALUES (17162, 13622, 2);
INSERT INTO 'dancesstepsmap' VALUES (17163, 13622, 3);
INSERT INTO 'dancesstepsmap' VALUES (17164, 14564, 4);
INSERT INTO 'dancesstepsmap' VALUES (17166, 14569, 1);
INSERT INTO 'dancesstepsmap' VALUES (17165, 14568, 1);
INSERT INTO 'dancesstepsmap' VALUES (17167, 11896, 2);
INSERT INTO 'dancesstepsmap' VALUES (17168, 3019, 5);
INSERT INTO 'dancesstepsmap' VALUES (17169, 14241, 1);
INSERT INTO 'dancesstepsmap' VALUES (17170, 14241, 2);
INSERT INTO 'dancesstepsmap' VALUES (17171, 14577, 2);
INSERT INTO 'dancesstepsmap' VALUES (17172, 14577, 1);
INSERT INTO 'dancesstepsmap' VALUES (17173, 14369, 3);
INSERT INTO 'dancesstepsmap' VALUES (17174, 14575, 1);
INSERT INTO 'dancesstepsmap' VALUES (3738, 4043, 1);
INSERT INTO 'dancesstepsmap' VALUES (3739, 4044, 1);
INSERT INTO 'dancesstepsmap' VALUES (3740, 4046, 1);
INSERT INTO 'dancesstepsmap' VALUES (3741, 4047, 1);
INSERT INTO 'dancesstepsmap' VALUES (3742, 4048, 1);
INSERT INTO 'dancesstepsmap' VALUES (3743, 4049, 1);
INSERT INTO 'dancesstepsmap' VALUES (3744, 4050, 4);
INSERT INTO 'dancesstepsmap' VALUES (3745, 4051, 4);
INSERT INTO 'dancesstepsmap' VALUES (3746, 4052, 1);
INSERT INTO 'dancesstepsmap' VALUES (3747, 4053, 4);
INSERT INTO 'dancesstepsmap' VALUES (3748, 4054, 1);
INSERT INTO 'dancesstepsmap' VALUES (3749, 4055, 4);
INSERT INTO 'dancesstepsmap' VALUES (3750, 4056, 1);
INSERT INTO 'dancesstepsmap' VALUES (3751, 4057, 1);
INSERT INTO 'dancesstepsmap' VALUES (3752, 4058, 1);
INSERT INTO 'dancesstepsmap' VALUES (3753, 4059, 1);
INSERT INTO 'dancesstepsmap' VALUES (3754, 4060, 1);
INSERT INTO 'dancesstepsmap' VALUES (3755, 4061, 1);
INSERT INTO 'dancesstepsmap' VALUES (3756, 4062, 1);
INSERT INTO 'dancesstepsmap' VALUES (3757, 4063, 4);
INSERT INTO 'dancesstepsmap' VALUES (3758, 4064, 4);
INSERT INTO 'dancesstepsmap' VALUES (3759, 4065, 1);
INSERT INTO 'dancesstepsmap' VALUES (3760, 4066, 4);
INSERT INTO 'dancesstepsmap' VALUES (3761, 4067, 4);
INSERT INTO 'dancesstepsmap' VALUES (3762, 4068, 4);
INSERT INTO 'dancesstepsmap' VALUES (3763, 4069, 4);
INSERT INTO 'dancesstepsmap' VALUES (3764, 4070, 4);
INSERT INTO 'dancesstepsmap' VALUES (3765, 4071, 1);
INSERT INTO 'dancesstepsmap' VALUES (3766, 4072, 4);
INSERT INTO 'dancesstepsmap' VALUES (3767, 4073, 4);
INSERT INTO 'dancesstepsmap' VALUES (3768, 4075, 1);
INSERT INTO 'dancesstepsmap' VALUES (3769, 4076, 1);
INSERT INTO 'dancesstepsmap' VALUES (3770, 4077, 1);
INSERT INTO 'dancesstepsmap' VALUES (3771, 4078, 4);
INSERT INTO 'dancesstepsmap' VALUES (3772, 4079, 4);
INSERT INTO 'dancesstepsmap' VALUES (3773, 4080, 1);
INSERT INTO 'dancesstepsmap' VALUES (3774, 4081, 4);
INSERT INTO 'dancesstepsmap' VALUES (3775, 4082, 4);
INSERT INTO 'dancesstepsmap' VALUES (3776, 4083, 4);
INSERT INTO 'dancesstepsmap' VALUES (3777, 4084, 1);
INSERT INTO 'dancesstepsmap' VALUES (3778, 4085, 1);
INSERT INTO 'dancesstepsmap' VALUES (3779, 4086, 1);
INSERT INTO 'dancesstepsmap' VALUES (3780, 4087, 4);
INSERT INTO 'dancesstepsmap' VALUES (3781, 4088, 1);
INSERT INTO 'dancesstepsmap' VALUES (3782, 4089, 1);
INSERT INTO 'dancesstepsmap' VALUES (3783, 4090, 1);
INSERT INTO 'dancesstepsmap' VALUES (3784, 4091, 1);
INSERT INTO 'dancesstepsmap' VALUES (3785, 4092, 1);
INSERT INTO 'dancesstepsmap' VALUES (3786, 4093, 1);
INSERT INTO 'dancesstepsmap' VALUES (3787, 4094, 1);
INSERT INTO 'dancesstepsmap' VALUES (3788, 4095, 1);
INSERT INTO 'dancesstepsmap' VALUES (3789, 4096, 1);
INSERT INTO 'dancesstepsmap' VALUES (3790, 4097, 1);
INSERT INTO 'dancesstepsmap' VALUES (3791, 4098, 1);
INSERT INTO 'dancesstepsmap' VALUES (3792, 4100, 4);
INSERT INTO 'dancesstepsmap' VALUES (3793, 4101, 1);
INSERT INTO 'dancesstepsmap' VALUES (3794, 4102, 1);
INSERT INTO 'dancesstepsmap' VALUES (3795, 4103, 1);
INSERT INTO 'dancesstepsmap' VALUES (3796, 4104, 1);
INSERT INTO 'dancesstepsmap' VALUES (3797, 4105, 4);
INSERT INTO 'dancesstepsmap' VALUES (3798, 4106, 1);
INSERT INTO 'dancesstepsmap' VALUES (3799, 4107, 1);
INSERT INTO 'dancesstepsmap' VALUES (3800, 4108, 1);
INSERT INTO 'dancesstepsmap' VALUES (3801, 4109, 4);
INSERT INTO 'dancesstepsmap' VALUES (3802, 4110, 4);
INSERT INTO 'dancesstepsmap' VALUES (3803, 4111, 4);
INSERT INTO 'dancesstepsmap' VALUES (3804, 4112, 1);
INSERT INTO 'dancesstepsmap' VALUES (3805, 4113, 1);
INSERT INTO 'dancesstepsmap' VALUES (3806, 4114, 1);
INSERT INTO 'dancesstepsmap' VALUES (3807, 4115, 4);
INSERT INTO 'dancesstepsmap' VALUES (3808, 4116, 1);
INSERT INTO 'dancesstepsmap' VALUES (3809, 4119, 1);
INSERT INTO 'dancesstepsmap' VALUES (3810, 4120, 1);
INSERT INTO 'dancesstepsmap' VALUES (3811, 4122, 4);
INSERT INTO 'dancesstepsmap' VALUES (3812, 4123, 1);
INSERT INTO 'dancesstepsmap' VALUES (3813, 4124, 1);
INSERT INTO 'dancesstepsmap' VALUES (3814, 4125, 4);
INSERT INTO 'dancesstepsmap' VALUES (3815, 4126, 4);
INSERT INTO 'dancesstepsmap' VALUES (3816, 4127, 4);
INSERT INTO 'dancesstepsmap' VALUES (3817, 4128, 4);
INSERT INTO 'dancesstepsmap' VALUES (3818, 4129, 4);
INSERT INTO 'dancesstepsmap' VALUES (3819, 4130, 4);
INSERT INTO 'dancesstepsmap' VALUES (3820, 4131, 4);
INSERT INTO 'dancesstepsmap' VALUES (3821, 4132, 1);
INSERT INTO 'dancesstepsmap' VALUES (3822, 4133, 1);
INSERT INTO 'dancesstepsmap' VALUES (3823, 4134, 1);
INSERT INTO 'dancesstepsmap' VALUES (3824, 4136, 4);
INSERT INTO 'dancesstepsmap' VALUES (3825, 4137, 1);
INSERT INTO 'dancesstepsmap' VALUES (3826, 4139, 4);
INSERT INTO 'dancesstepsmap' VALUES (3827, 4140, 1);
INSERT INTO 'dancesstepsmap' VALUES (3828, 4141, 1);
INSERT INTO 'dancesstepsmap' VALUES (3829, 4142, 1);
INSERT INTO 'dancesstepsmap' VALUES (11388, 8383, 4);
INSERT INTO 'dancesstepsmap' VALUES (11389, 8383, 5);
INSERT INTO 'dancesstepsmap' VALUES (11390, 10363, 1);
INSERT INTO 'dancesstepsmap' VALUES (11391, 10364, 4);
INSERT INTO 'dancesstepsmap' VALUES (11392, 8569, 3);
INSERT INTO 'dancesstepsmap' VALUES (11393, 10365, 1);
INSERT INTO 'dancesstepsmap' VALUES (11394, 10365, 3);
INSERT INTO 'dancesstepsmap' VALUES (11395, 9157, 2);
INSERT INTO 'dancesstepsmap' VALUES (11396, 9056, 2);
INSERT INTO 'dancesstepsmap' VALUES (11397, 8858, 4);
INSERT INTO 'dancesstepsmap' VALUES (11398, 8858, 5);
INSERT INTO 'dancesstepsmap' VALUES (11399, 9204, 1);
INSERT INTO 'dancesstepsmap' VALUES (11400, 10369, 4);
INSERT INTO 'dancesstepsmap' VALUES (11401, 10369, 5);
INSERT INTO 'dancesstepsmap' VALUES (23143, 6567, 5);
INSERT INTO 'dancesstepsmap' VALUES (23221, 18266, 3);
INSERT INTO 'dancesstepsmap' VALUES (23243, 12095, 4);
INSERT INTO 'dancesstepsmap' VALUES (11405, 10371, 4);
INSERT INTO 'dancesstepsmap' VALUES (11406, 10370, 4);
INSERT INTO 'dancesstepsmap' VALUES (11407, 10372, 1);
INSERT INTO 'dancesstepsmap' VALUES (11408, 10373, 1);
INSERT INTO 'dancesstepsmap' VALUES (11409, 10373, 3);
INSERT INTO 'dancesstepsmap' VALUES (11410, 10374, 4);
INSERT INTO 'dancesstepsmap' VALUES (11411, 10375, 1);
INSERT INTO 'dancesstepsmap' VALUES (11412, 10376, 1);
INSERT INTO 'dancesstepsmap' VALUES (11413, 10376, 2);
INSERT INTO 'dancesstepsmap' VALUES (11414, 10377, 1);
INSERT INTO 'dancesstepsmap' VALUES (11415, 10378, 4);
INSERT INTO 'dancesstepsmap' VALUES (11416, 10379, 1);
INSERT INTO 'dancesstepsmap' VALUES (11417, 10380, 4);
INSERT INTO 'dancesstepsmap' VALUES (11418, 10380, 5);
INSERT INTO 'dancesstepsmap' VALUES (11419, 10381, 4);
INSERT INTO 'dancesstepsmap' VALUES (11420, 10381, 5);
INSERT INTO 'dancesstepsmap' VALUES (11421, 10382, 4);
INSERT INTO 'dancesstepsmap' VALUES (11422, 10383, 5);
INSERT INTO 'dancesstepsmap' VALUES (11423, 10383, 4);
INSERT INTO 'dancesstepsmap' VALUES (11424, 10384, 4);
INSERT INTO 'dancesstepsmap' VALUES (11425, 10385, 1);
INSERT INTO 'dancesstepsmap' VALUES (11426, 8975, 1);
INSERT INTO 'dancesstepsmap' VALUES (11427, 10356, 4);
INSERT INTO 'dancesstepsmap' VALUES (11428, 10386, 4);
INSERT INTO 'dancesstepsmap' VALUES (11429, 10387, 4);
INSERT INTO 'dancesstepsmap' VALUES (11430, 10388, 1);
INSERT INTO 'dancesstepsmap' VALUES (17082, 14527, 1);
INSERT INTO 'dancesstepsmap' VALUES (17146, 9194, 2);
INSERT INTO 'dancesstepsmap' VALUES (17151, 14559, 2);
INSERT INTO 'dancesstepsmap' VALUES (17152, 14559, 1);
INSERT INTO 'dancesstepsmap' VALUES (17175, 14575, 2);
INSERT INTO 'dancesstepsmap' VALUES (17176, 14575, 3);
INSERT INTO 'dancesstepsmap' VALUES (3830, 4143, 1);
INSERT INTO 'dancesstepsmap' VALUES (3831, 4144, 1);
INSERT INTO 'dancesstepsmap' VALUES (3832, 4145, 1);
INSERT INTO 'dancesstepsmap' VALUES (3833, 4146, 4);
INSERT INTO 'dancesstepsmap' VALUES (3834, 4147, 1);
INSERT INTO 'dancesstepsmap' VALUES (3835, 4148, 4);
INSERT INTO 'dancesstepsmap' VALUES (3836, 4149, 1);
INSERT INTO 'dancesstepsmap' VALUES (3837, 4150, 4);
INSERT INTO 'dancesstepsmap' VALUES (3838, 4151, 1);
INSERT INTO 'dancesstepsmap' VALUES (3839, 4152, 4);
INSERT INTO 'dancesstepsmap' VALUES (3840, 4153, 1);
INSERT INTO 'dancesstepsmap' VALUES (3841, 4154, 1);
INSERT INTO 'dancesstepsmap' VALUES (3842, 4155, 4);
INSERT INTO 'dancesstepsmap' VALUES (3843, 4156, 1);
INSERT INTO 'dancesstepsmap' VALUES (3844, 4157, 1);
INSERT INTO 'dancesstepsmap' VALUES (3845, 4158, 4);
INSERT INTO 'dancesstepsmap' VALUES (3846, 4159, 1);
INSERT INTO 'dancesstepsmap' VALUES (3847, 4160, 4);
INSERT INTO 'dancesstepsmap' VALUES (3848, 4161, 4);
INSERT INTO 'dancesstepsmap' VALUES (3849, 4162, 4);
INSERT INTO 'dancesstepsmap' VALUES (3850, 4164, 4);
INSERT INTO 'dancesstepsmap' VALUES (3851, 4165, 1);
INSERT INTO 'dancesstepsmap' VALUES (3852, 4167, 4);
INSERT INTO 'dancesstepsmap' VALUES (3853, 4168, 4);
INSERT INTO 'dancesstepsmap' VALUES (3854, 4169, 4);
INSERT INTO 'dancesstepsmap' VALUES (3855, 4170, 1);
INSERT INTO 'dancesstepsmap' VALUES (3856, 4171, 1);
INSERT INTO 'dancesstepsmap' VALUES (3857, 4172, 1);
INSERT INTO 'dancesstepsmap' VALUES (3858, 4173, 1);
INSERT INTO 'dancesstepsmap' VALUES (3859, 4174, 1);
INSERT INTO 'dancesstepsmap' VALUES (3860, 4175, 1);
INSERT INTO 'dancesstepsmap' VALUES (3861, 4176, 1);
INSERT INTO 'dancesstepsmap' VALUES (3862, 4177, 4);
INSERT INTO 'dancesstepsmap' VALUES (3863, 4178, 1);
INSERT INTO 'dancesstepsmap' VALUES (3864, 4179, 1);
INSERT INTO 'dancesstepsmap' VALUES (3865, 4180, 1);
INSERT INTO 'dancesstepsmap' VALUES (3866, 4181, 1);
INSERT INTO 'dancesstepsmap' VALUES (3867, 4182, 1);
INSERT INTO 'dancesstepsmap' VALUES (3868, 4183, 1);
INSERT INTO 'dancesstepsmap' VALUES (3869, 4184, 1);
INSERT INTO 'dancesstepsmap' VALUES (3870, 4185, 1);
INSERT INTO 'dancesstepsmap' VALUES (3871, 4186, 1);
INSERT INTO 'dancesstepsmap' VALUES (3872, 4187, 4);
INSERT INTO 'dancesstepsmap' VALUES (3873, 4188, 4);
INSERT INTO 'dancesstepsmap' VALUES (3874, 4189, 1);
INSERT INTO 'dancesstepsmap' VALUES (3875, 4190, 4);
INSERT INTO 'dancesstepsmap' VALUES (3876, 4191, 4);
INSERT INTO 'dancesstepsmap' VALUES (3877, 4192, 4);
INSERT INTO 'dancesstepsmap' VALUES (3878, 4193, 4);
INSERT INTO 'dancesstepsmap' VALUES (3879, 4194, 4);
INSERT INTO 'dancesstepsmap' VALUES (3880, 4195, 4);
INSERT INTO 'dancesstepsmap' VALUES (3881, 4196, 4);
INSERT INTO 'dancesstepsmap' VALUES (3882, 4197, 1);
INSERT INTO 'dancesstepsmap' VALUES (3883, 4198, 4);
INSERT INTO 'dancesstepsmap' VALUES (3884, 4199, 1);
INSERT INTO 'dancesstepsmap' VALUES (3885, 4200, 4);
INSERT INTO 'dancesstepsmap' VALUES (3886, 4201, 4);
INSERT INTO 'dancesstepsmap' VALUES (3887, 4203, 1);
INSERT INTO 'dancesstepsmap' VALUES (3888, 4204, 1);
INSERT INTO 'dancesstepsmap' VALUES (3889, 4205, 1);
INSERT INTO 'dancesstepsmap' VALUES (3890, 4206, 4);
INSERT INTO 'dancesstepsmap' VALUES (3891, 4207, 1);
INSERT INTO 'dancesstepsmap' VALUES (3892, 4208, 1);
INSERT INTO 'dancesstepsmap' VALUES (3893, 4209, 4);
INSERT INTO 'dancesstepsmap' VALUES (3894, 4211, 4);
INSERT INTO 'dancesstepsmap' VALUES (3895, 4212, 1);
INSERT INTO 'dancesstepsmap' VALUES (3896, 4213, 4);
INSERT INTO 'dancesstepsmap' VALUES (3897, 4214, 1);
INSERT INTO 'dancesstepsmap' VALUES (3898, 4215, 1);
INSERT INTO 'dancesstepsmap' VALUES (3899, 4216, 1);
INSERT INTO 'dancesstepsmap' VALUES (3900, 4217, 4);
INSERT INTO 'dancesstepsmap' VALUES (3901, 4218, 1);
INSERT INTO 'dancesstepsmap' VALUES (3902, 4220, 4);
INSERT INTO 'dancesstepsmap' VALUES (3903, 4221, 1);
INSERT INTO 'dancesstepsmap' VALUES (3904, 4222, 4);
INSERT INTO 'dancesstepsmap' VALUES (3905, 4223, 4);
INSERT INTO 'dancesstepsmap' VALUES (3906, 4224, 1);
INSERT INTO 'dancesstepsmap' VALUES (3907, 4225, 1);
INSERT INTO 'dancesstepsmap' VALUES (3908, 4227, 1);
INSERT INTO 'dancesstepsmap' VALUES (3909, 4228, 1);
INSERT INTO 'dancesstepsmap' VALUES (3910, 4229, 1);
INSERT INTO 'dancesstepsmap' VALUES (3911, 4230, 1);
INSERT INTO 'dancesstepsmap' VALUES (3912, 4231, 4);
INSERT INTO 'dancesstepsmap' VALUES (3913, 4232, 1);
INSERT INTO 'dancesstepsmap' VALUES (3914, 4233, 1);
INSERT INTO 'dancesstepsmap' VALUES (3915, 4234, 1);
INSERT INTO 'dancesstepsmap' VALUES (3916, 4236, 1);
INSERT INTO 'dancesstepsmap' VALUES (3917, 4237, 4);
INSERT INTO 'dancesstepsmap' VALUES (3918, 4238, 1);
INSERT INTO 'dancesstepsmap' VALUES (3919, 4239, 1);
INSERT INTO 'dancesstepsmap' VALUES (3920, 4240, 4);
INSERT INTO 'dancesstepsmap' VALUES (3921, 4241, 4);
INSERT INTO 'dancesstepsmap' VALUES (3922, 4242, 1);
INSERT INTO 'dancesstepsmap' VALUES (11431, 7694, 5);
INSERT INTO 'dancesstepsmap' VALUES (11432, 1905, 3);
INSERT INTO 'dancesstepsmap' VALUES (11433, 8503, 3);
INSERT INTO 'dancesstepsmap' VALUES (11434, 10390, 4);
INSERT INTO 'dancesstepsmap' VALUES (11435, 10390, 5);
INSERT INTO 'dancesstepsmap' VALUES (11436, 9105, 1);
INSERT INTO 'dancesstepsmap' VALUES (11437, 8977, 1);
INSERT INTO 'dancesstepsmap' VALUES (11438, 8516, 2);
INSERT INTO 'dancesstepsmap' VALUES (11439, 9061, 4);
INSERT INTO 'dancesstepsmap' VALUES (11440, 9061, 5);
INSERT INTO 'dancesstepsmap' VALUES (11441, 8517, 2);
INSERT INTO 'dancesstepsmap' VALUES (11442, 8504, 2);
INSERT INTO 'dancesstepsmap' VALUES (11443, 9233, 4);
INSERT INTO 'dancesstepsmap' VALUES (11444, 9233, 5);
INSERT INTO 'dancesstepsmap' VALUES (11445, 8947, 4);
INSERT INTO 'dancesstepsmap' VALUES (11446, 8947, 5);
INSERT INTO 'dancesstepsmap' VALUES (11447, 2861, 2);
INSERT INTO 'dancesstepsmap' VALUES (11448, 9234, 1);
INSERT INTO 'dancesstepsmap' VALUES (11449, 9234, 3);
INSERT INTO 'dancesstepsmap' VALUES (11450, 8029, 5);
INSERT INTO 'dancesstepsmap' VALUES (11451, 7576, 2);
INSERT INTO 'dancesstepsmap' VALUES (11452, 7576, 3);
INSERT INTO 'dancesstepsmap' VALUES (11453, 9467, 1);
INSERT INTO 'dancesstepsmap' VALUES (11454, 8556, 2);
INSERT INTO 'dancesstepsmap' VALUES (11455, 8556, 3);
INSERT INTO 'dancesstepsmap' VALUES (11456, 10391, 4);
INSERT INTO 'dancesstepsmap' VALUES (11457, 3343, 3);
INSERT INTO 'dancesstepsmap' VALUES (11458, 3393, 6);
INSERT INTO 'dancesstepsmap' VALUES (11459, 8557, 2);
INSERT INTO 'dancesstepsmap' VALUES (11460, 9868, 1);
INSERT INTO 'dancesstepsmap' VALUES (11461, 9868, 3);
INSERT INTO 'dancesstepsmap' VALUES (11462, 9160, 1);
INSERT INTO 'dancesstepsmap' VALUES (11463, 8336, 2);
INSERT INTO 'dancesstepsmap' VALUES (11464, 10392, 3);
INSERT INTO 'dancesstepsmap' VALUES (11465, 10392, 1);
INSERT INTO 'dancesstepsmap' VALUES (11466, 8533, 2);
INSERT INTO 'dancesstepsmap' VALUES (11467, 3691, 3);
INSERT INTO 'dancesstepsmap' VALUES (11468, 8518, 2);
INSERT INTO 'dancesstepsmap' VALUES (11469, 3847, 5);
INSERT INTO 'dancesstepsmap' VALUES (11470, 8951, 1);
INSERT INTO 'dancesstepsmap' VALUES (11471, 8951, 3);
INSERT INTO 'dancesstepsmap' VALUES (11472, 8851, 1);
INSERT INTO 'dancesstepsmap' VALUES (17153, 14560, 1);
INSERT INTO 'dancesstepsmap' VALUES (17177, 14574, 5);
INSERT INTO 'dancesstepsmap' VALUES (17178, 14574, 4);
INSERT INTO 'dancesstepsmap' VALUES (3923, 4243, 1);
INSERT INTO 'dancesstepsmap' VALUES (3924, 4244, 4);
INSERT INTO 'dancesstepsmap' VALUES (3925, 4245, 1);
INSERT INTO 'dancesstepsmap' VALUES (3926, 4246, 1);
INSERT INTO 'dancesstepsmap' VALUES (3927, 4247, 4);
INSERT INTO 'dancesstepsmap' VALUES (3928, 4248, 1);
INSERT INTO 'dancesstepsmap' VALUES (3929, 4249, 1);
INSERT INTO 'dancesstepsmap' VALUES (3930, 4250, 1);
INSERT INTO 'dancesstepsmap' VALUES (3931, 4251, 4);
INSERT INTO 'dancesstepsmap' VALUES (3932, 4252, 1);
INSERT INTO 'dancesstepsmap' VALUES (3933, 4253, 1);
INSERT INTO 'dancesstepsmap' VALUES (3934, 4254, 1);
INSERT INTO 'dancesstepsmap' VALUES (3935, 4256, 4);
INSERT INTO 'dancesstepsmap' VALUES (3936, 4257, 1);
INSERT INTO 'dancesstepsmap' VALUES (3937, 4258, 1);
INSERT INTO 'dancesstepsmap' VALUES (3938, 4259, 1);
INSERT INTO 'dancesstepsmap' VALUES (3939, 4260, 4);
INSERT INTO 'dancesstepsmap' VALUES (3940, 4261, 4);
INSERT INTO 'dancesstepsmap' VALUES (3941, 4262, 1);
INSERT INTO 'dancesstepsmap' VALUES (3942, 4263, 4);
INSERT INTO 'dancesstepsmap' VALUES (3943, 4264, 1);
INSERT INTO 'dancesstepsmap' VALUES (3944, 4265, 4);
INSERT INTO 'dancesstepsmap' VALUES (3945, 4266, 4);
INSERT INTO 'dancesstepsmap' VALUES (3946, 4268, 1);
INSERT INTO 'dancesstepsmap' VALUES (3947, 4269, 1);
INSERT INTO 'dancesstepsmap' VALUES (3948, 4270, 4);
INSERT INTO 'dancesstepsmap' VALUES (3949, 4271, 1);
INSERT INTO 'dancesstepsmap' VALUES (3951, 4273, 1);
INSERT INTO 'dancesstepsmap' VALUES (3952, 4274, 1);
INSERT INTO 'dancesstepsmap' VALUES (3953, 4275, 4);
INSERT INTO 'dancesstepsmap' VALUES (3954, 4276, 1);
INSERT INTO 'dancesstepsmap' VALUES (3955, 4277, 4);
INSERT INTO 'dancesstepsmap' VALUES (3956, 4278, 1);
INSERT INTO 'dancesstepsmap' VALUES (3957, 4280, 4);
INSERT INTO 'dancesstepsmap' VALUES (3958, 4281, 1);
INSERT INTO 'dancesstepsmap' VALUES (3959, 4283, 1);
INSERT INTO 'dancesstepsmap' VALUES (3960, 4284, 4);
INSERT INTO 'dancesstepsmap' VALUES (3961, 4285, 1);
INSERT INTO 'dancesstepsmap' VALUES (3962, 4286, 4);
INSERT INTO 'dancesstepsmap' VALUES (3963, 4287, 4);
INSERT INTO 'dancesstepsmap' VALUES (3964, 4290, 4);
INSERT INTO 'dancesstepsmap' VALUES (3965, 4291, 1);
INSERT INTO 'dancesstepsmap' VALUES (3966, 4293, 1);
INSERT INTO 'dancesstepsmap' VALUES (3967, 4294, 1);
INSERT INTO 'dancesstepsmap' VALUES (3968, 4295, 1);
INSERT INTO 'dancesstepsmap' VALUES (3969, 4296, 1);
INSERT INTO 'dancesstepsmap' VALUES (3970, 4297, 4);
INSERT INTO 'dancesstepsmap' VALUES (3971, 4298, 4);
INSERT INTO 'dancesstepsmap' VALUES (3972, 4299, 4);
INSERT INTO 'dancesstepsmap' VALUES (3973, 4300, 1);
INSERT INTO 'dancesstepsmap' VALUES (3974, 4301, 1);
INSERT INTO 'dancesstepsmap' VALUES (3975, 4302, 4);
INSERT INTO 'dancesstepsmap' VALUES (3976, 4303, 1);
INSERT INTO 'dancesstepsmap' VALUES (3977, 4304, 4);
INSERT INTO 'dancesstepsmap' VALUES (3978, 4306, 1);
INSERT INTO 'dancesstepsmap' VALUES (3979, 4307, 1);
INSERT INTO 'dancesstepsmap' VALUES (3980, 4309, 1);
INSERT INTO 'dancesstepsmap' VALUES (3981, 4310, 1);
INSERT INTO 'dancesstepsmap' VALUES (3982, 4311, 1);
INSERT INTO 'dancesstepsmap' VALUES (3983, 4312, 4);
INSERT INTO 'dancesstepsmap' VALUES (3984, 4313, 1);
INSERT INTO 'dancesstepsmap' VALUES (3985, 4314, 1);
INSERT INTO 'dancesstepsmap' VALUES (3986, 4315, 1);
INSERT INTO 'dancesstepsmap' VALUES (3987, 4316, 4);
INSERT INTO 'dancesstepsmap' VALUES (3988, 4318, 1);
INSERT INTO 'dancesstepsmap' VALUES (3989, 4319, 1);
INSERT INTO 'dancesstepsmap' VALUES (3990, 4320, 1);
INSERT INTO 'dancesstepsmap' VALUES (3991, 4321, 1);
INSERT INTO 'dancesstepsmap' VALUES (3992, 4322, 1);
INSERT INTO 'dancesstepsmap' VALUES (3993, 4323, 1);
INSERT INTO 'dancesstepsmap' VALUES (3994, 4324, 1);
INSERT INTO 'dancesstepsmap' VALUES (3995, 4325, 1);
INSERT INTO 'dancesstepsmap' VALUES (3996, 4326, 1);
INSERT INTO 'dancesstepsmap' VALUES (3997, 4327, 1);
INSERT INTO 'dancesstepsmap' VALUES (3998, 4329, 1);
INSERT INTO 'dancesstepsmap' VALUES (3999, 4330, 4);
INSERT INTO 'dancesstepsmap' VALUES (4000, 4331, 1);
INSERT INTO 'dancesstepsmap' VALUES (4001, 4332, 1);
INSERT INTO 'dancesstepsmap' VALUES (4002, 4333, 1);
INSERT INTO 'dancesstepsmap' VALUES (4003, 4334, 1);
INSERT INTO 'dancesstepsmap' VALUES (4004, 4336, 1);
INSERT INTO 'dancesstepsmap' VALUES (4005, 4337, 1);
INSERT INTO 'dancesstepsmap' VALUES (4006, 4338, 1);
INSERT INTO 'dancesstepsmap' VALUES (4007, 4339, 1);
INSERT INTO 'dancesstepsmap' VALUES (4008, 4340, 4);
INSERT INTO 'dancesstepsmap' VALUES (4009, 4341, 1);
INSERT INTO 'dancesstepsmap' VALUES (4010, 4342, 1);
INSERT INTO 'dancesstepsmap' VALUES (4011, 4343, 1);
INSERT INTO 'dancesstepsmap' VALUES (4012, 4344, 1);
INSERT INTO 'dancesstepsmap' VALUES (4013, 4345, 1);
INSERT INTO 'dancesstepsmap' VALUES (4014, 4346, 1);
INSERT INTO 'dancesstepsmap' VALUES (4015, 4347, 1);
INSERT INTO 'dancesstepsmap' VALUES (4016, 4348, 4);
INSERT INTO 'dancesstepsmap' VALUES (4017, 4349, 1);
INSERT INTO 'dancesstepsmap' VALUES (4018, 4350, 1);
INSERT INTO 'dancesstepsmap' VALUES (4019, 4351, 4);
INSERT INTO 'dancesstepsmap' VALUES (4020, 4352, 1);
INSERT INTO 'dancesstepsmap' VALUES (4021, 4353, 4);
INSERT INTO 'dancesstepsmap' VALUES (4022, 4354, 1);
INSERT INTO 'dancesstepsmap' VALUES (4023, 4355, 4);
INSERT INTO 'dancesstepsmap' VALUES (4024, 4356, 1);
INSERT INTO 'dancesstepsmap' VALUES (4025, 4357, 4);
INSERT INTO 'dancesstepsmap' VALUES (4026, 4359, 1);
INSERT INTO 'dancesstepsmap' VALUES (4027, 4360, 1);
INSERT INTO 'dancesstepsmap' VALUES (4028, 4361, 1);
INSERT INTO 'dancesstepsmap' VALUES (4029, 4362, 1);
INSERT INTO 'dancesstepsmap' VALUES (4030, 4364, 1);
INSERT INTO 'dancesstepsmap' VALUES (4031, 4365, 1);
INSERT INTO 'dancesstepsmap' VALUES (4032, 4366, 2);
INSERT INTO 'dancesstepsmap' VALUES (4033, 4367, 4);
INSERT INTO 'dancesstepsmap' VALUES (4034, 4368, 1);
INSERT INTO 'dancesstepsmap' VALUES (4035, 4369, 1);
INSERT INTO 'dancesstepsmap' VALUES (4036, 4370, 1);
INSERT INTO 'dancesstepsmap' VALUES (4037, 4371, 1);
INSERT INTO 'dancesstepsmap' VALUES (4038, 4372, 4);
INSERT INTO 'dancesstepsmap' VALUES (4039, 4373, 4);
INSERT INTO 'dancesstepsmap' VALUES (4040, 4374, 4);
INSERT INTO 'dancesstepsmap' VALUES (4041, 4375, 1);
INSERT INTO 'dancesstepsmap' VALUES (4042, 4376, 1);
INSERT INTO 'dancesstepsmap' VALUES (4043, 4377, 1);
INSERT INTO 'dancesstepsmap' VALUES (4044, 4378, 1);
INSERT INTO 'dancesstepsmap' VALUES (4045, 4379, 1);
INSERT INTO 'dancesstepsmap' VALUES (4046, 4381, 4);
INSERT INTO 'dancesstepsmap' VALUES (4047, 4382, 1);
INSERT INTO 'dancesstepsmap' VALUES (4048, 4383, 1);
INSERT INTO 'dancesstepsmap' VALUES (4049, 4384, 1);
INSERT INTO 'dancesstepsmap' VALUES (4050, 4385, 4);
INSERT INTO 'dancesstepsmap' VALUES (4051, 4386, 1);
INSERT INTO 'dancesstepsmap' VALUES (4052, 4387, 4);
INSERT INTO 'dancesstepsmap' VALUES (11473, 8851, 3);
INSERT INTO 'dancesstepsmap' VALUES (11474, 3933, 2);
INSERT INTO 'dancesstepsmap' VALUES (11475, 3933, 3);
INSERT INTO 'dancesstepsmap' VALUES (11476, 3994, 5);
INSERT INTO 'dancesstepsmap' VALUES (11477, 6463, 2);
INSERT INTO 'dancesstepsmap' VALUES (11478, 927, 2);
INSERT INTO 'dancesstepsmap' VALUES (11479, 996, 2);
INSERT INTO 'dancesstepsmap' VALUES (11480, 293, 2);
INSERT INTO 'dancesstepsmap' VALUES (11481, 6789, 2);
INSERT INTO 'dancesstepsmap' VALUES (11482, 7003, 2);
INSERT INTO 'dancesstepsmap' VALUES (11483, 6065, 2);
INSERT INTO 'dancesstepsmap' VALUES (11484, 3427, 2);
INSERT INTO 'dancesstepsmap' VALUES (11485, 5561, 6);
INSERT INTO 'dancesstepsmap' VALUES (11486, 517, 5);
INSERT INTO 'dancesstepsmap' VALUES (11487, 4460, 5);
INSERT INTO 'dancesstepsmap' VALUES (4053, 4388, 4);
INSERT INTO 'dancesstepsmap' VALUES (4054, 4389, 1);
INSERT INTO 'dancesstepsmap' VALUES (4055, 4390, 4);
INSERT INTO 'dancesstepsmap' VALUES (4056, 4391, 1);
INSERT INTO 'dancesstepsmap' VALUES (4057, 4392, 4);
INSERT INTO 'dancesstepsmap' VALUES (4058, 4393, 4);
INSERT INTO 'dancesstepsmap' VALUES (4059, 4394, 4);
INSERT INTO 'dancesstepsmap' VALUES (4060, 4395, 1);
INSERT INTO 'dancesstepsmap' VALUES (4061, 4396, 1);
INSERT INTO 'dancesstepsmap' VALUES (4062, 4398, 4);
INSERT INTO 'dancesstepsmap' VALUES (4063, 4399, 4);
INSERT INTO 'dancesstepsmap' VALUES (4064, 4400, 1);
INSERT INTO 'dancesstepsmap' VALUES (4065, 4401, 4);
INSERT INTO 'dancesstepsmap' VALUES (4066, 4402, 1);
INSERT INTO 'dancesstepsmap' VALUES (4067, 4404, 1);
INSERT INTO 'dancesstepsmap' VALUES (4068, 4405, 1);
INSERT INTO 'dancesstepsmap' VALUES (4069, 4406, 1);
INSERT INTO 'dancesstepsmap' VALUES (4070, 4407, 1);
INSERT INTO 'dancesstepsmap' VALUES (4071, 4408, 1);
INSERT INTO 'dancesstepsmap' VALUES (4072, 4409, 1);
INSERT INTO 'dancesstepsmap' VALUES (4073, 4410, 4);
INSERT INTO 'dancesstepsmap' VALUES (4074, 4411, 4);
INSERT INTO 'dancesstepsmap' VALUES (4075, 4412, 1);
INSERT INTO 'dancesstepsmap' VALUES (4076, 4413, 1);
INSERT INTO 'dancesstepsmap' VALUES (4077, 4414, 1);
INSERT INTO 'dancesstepsmap' VALUES (4078, 4415, 1);
INSERT INTO 'dancesstepsmap' VALUES (4079, 4416, 1);
INSERT INTO 'dancesstepsmap' VALUES (4080, 4417, 1);
INSERT INTO 'dancesstepsmap' VALUES (4081, 4418, 4);
INSERT INTO 'dancesstepsmap' VALUES (4082, 4420, 4);
INSERT INTO 'dancesstepsmap' VALUES (4083, 4421, 4);
INSERT INTO 'dancesstepsmap' VALUES (4084, 4422, 1);
INSERT INTO 'dancesstepsmap' VALUES (4085, 4423, 4);
INSERT INTO 'dancesstepsmap' VALUES (4086, 4424, 1);
INSERT INTO 'dancesstepsmap' VALUES (4087, 4425, 1);
INSERT INTO 'dancesstepsmap' VALUES (4088, 4426, 1);
INSERT INTO 'dancesstepsmap' VALUES (4089, 4427, 4);
INSERT INTO 'dancesstepsmap' VALUES (4090, 4428, 1);
INSERT INTO 'dancesstepsmap' VALUES (4091, 4429, 4);
INSERT INTO 'dancesstepsmap' VALUES (4092, 4430, 4);
INSERT INTO 'dancesstepsmap' VALUES (4093, 4431, 1);
INSERT INTO 'dancesstepsmap' VALUES (4094, 4432, 4);
INSERT INTO 'dancesstepsmap' VALUES (4095, 4433, 1);
INSERT INTO 'dancesstepsmap' VALUES (4096, 4434, 4);
INSERT INTO 'dancesstepsmap' VALUES (4097, 4436, 4);
INSERT INTO 'dancesstepsmap' VALUES (4098, 4437, 4);
INSERT INTO 'dancesstepsmap' VALUES (4099, 4438, 1);
INSERT INTO 'dancesstepsmap' VALUES (4100, 4439, 4);
INSERT INTO 'dancesstepsmap' VALUES (4101, 4440, 1);
INSERT INTO 'dancesstepsmap' VALUES (4102, 4441, 1);
INSERT INTO 'dancesstepsmap' VALUES (4103, 4442, 1);
INSERT INTO 'dancesstepsmap' VALUES (4104, 4443, 4);
INSERT INTO 'dancesstepsmap' VALUES (4105, 4444, 4);
INSERT INTO 'dancesstepsmap' VALUES (4106, 4445, 1);
INSERT INTO 'dancesstepsmap' VALUES (4107, 4446, 1);
INSERT INTO 'dancesstepsmap' VALUES (4108, 4447, 1);
INSERT INTO 'dancesstepsmap' VALUES (4109, 4448, 1);
INSERT INTO 'dancesstepsmap' VALUES (4110, 4449, 1);
INSERT INTO 'dancesstepsmap' VALUES (4111, 4450, 1);
INSERT INTO 'dancesstepsmap' VALUES (4112, 4451, 4);
INSERT INTO 'dancesstepsmap' VALUES (4113, 4452, 1);
INSERT INTO 'dancesstepsmap' VALUES (4114, 4453, 4);
INSERT INTO 'dancesstepsmap' VALUES (4115, 4454, 1);
INSERT INTO 'dancesstepsmap' VALUES (4116, 4455, 4);
INSERT INTO 'dancesstepsmap' VALUES (4117, 4456, 1);
INSERT INTO 'dancesstepsmap' VALUES (4118, 4457, 1);
INSERT INTO 'dancesstepsmap' VALUES (4119, 4458, 1);
INSERT INTO 'dancesstepsmap' VALUES (4120, 4459, 4);
INSERT INTO 'dancesstepsmap' VALUES (4121, 4460, 4);
INSERT INTO 'dancesstepsmap' VALUES (4122, 4461, 1);
INSERT INTO 'dancesstepsmap' VALUES (4123, 4462, 1);
INSERT INTO 'dancesstepsmap' VALUES (4124, 4463, 4);
INSERT INTO 'dancesstepsmap' VALUES (4125, 4464, 1);
INSERT INTO 'dancesstepsmap' VALUES (4126, 4465, 1);
INSERT INTO 'dancesstepsmap' VALUES (4127, 4466, 1);
INSERT INTO 'dancesstepsmap' VALUES (4128, 4467, 4);
INSERT INTO 'dancesstepsmap' VALUES (4129, 4468, 4);
INSERT INTO 'dancesstepsmap' VALUES (4130, 4469, 1);
INSERT INTO 'dancesstepsmap' VALUES (4131, 4470, 4);
INSERT INTO 'dancesstepsmap' VALUES (4132, 4471, 1);
INSERT INTO 'dancesstepsmap' VALUES (4133, 4473, 1);
INSERT INTO 'dancesstepsmap' VALUES (4134, 4474, 4);
INSERT INTO 'dancesstepsmap' VALUES (4135, 4475, 1);
INSERT INTO 'dancesstepsmap' VALUES (4136, 4476, 1);
INSERT INTO 'dancesstepsmap' VALUES (4137, 4477, 4);
INSERT INTO 'dancesstepsmap' VALUES (4138, 4478, 1);
INSERT INTO 'dancesstepsmap' VALUES (4139, 4479, 1);
INSERT INTO 'dancesstepsmap' VALUES (4140, 4480, 1);
INSERT INTO 'dancesstepsmap' VALUES (4141, 4481, 4);
INSERT INTO 'dancesstepsmap' VALUES (4142, 4482, 1);
INSERT INTO 'dancesstepsmap' VALUES (4143, 4483, 4);
INSERT INTO 'dancesstepsmap' VALUES (4144, 4484, 4);
INSERT INTO 'dancesstepsmap' VALUES (11488, 3283, 5);
INSERT INTO 'dancesstepsmap' VALUES (11489, 180, 6);
INSERT INTO 'dancesstepsmap' VALUES (11490, 180, 5);
INSERT INTO 'dancesstepsmap' VALUES (11491, 180, 4);
INSERT INTO 'dancesstepsmap' VALUES (11492, 180, 1);
INSERT INTO 'dancesstepsmap' VALUES (11493, 180, 2);
INSERT INTO 'dancesstepsmap' VALUES (11494, 180, 10);
INSERT INTO 'dancesstepsmap' VALUES (11495, 8116, 2);
INSERT INTO 'dancesstepsmap' VALUES (11496, 8117, 2);
INSERT INTO 'dancesstepsmap' VALUES (11497, 10393, 3);
INSERT INTO 'dancesstepsmap' VALUES (11498, 10393, 2);
INSERT INTO 'dancesstepsmap' VALUES (11499, 10393, 1);
INSERT INTO 'dancesstepsmap' VALUES (11501, 10395, 1);
INSERT INTO 'dancesstepsmap' VALUES (11502, 10396, 1);
INSERT INTO 'dancesstepsmap' VALUES (11503, 10396, 2);
INSERT INTO 'dancesstepsmap' VALUES (11504, 10396, 4);
INSERT INTO 'dancesstepsmap' VALUES (11505, 10396, 5);
INSERT INTO 'dancesstepsmap' VALUES (11506, 10397, 4);
INSERT INTO 'dancesstepsmap' VALUES (11507, 10399, 2);
INSERT INTO 'dancesstepsmap' VALUES (11508, 10399, 1);
INSERT INTO 'dancesstepsmap' VALUES (11509, 10399, 3);
INSERT INTO 'dancesstepsmap' VALUES (11510, 10400, 3);
INSERT INTO 'dancesstepsmap' VALUES (11511, 10402, 4);
INSERT INTO 'dancesstepsmap' VALUES (11512, 10403, 1);
INSERT INTO 'dancesstepsmap' VALUES (11513, 10404, 1);
INSERT INTO 'dancesstepsmap' VALUES (11514, 10406, 4);
INSERT INTO 'dancesstepsmap' VALUES (11515, 10405, 1);
INSERT INTO 'dancesstepsmap' VALUES (11516, 10405, 2);
INSERT INTO 'dancesstepsmap' VALUES (11517, 9376, 2);
INSERT INTO 'dancesstepsmap' VALUES (11518, 10407, 1);
INSERT INTO 'dancesstepsmap' VALUES (11519, 10408, 1);
INSERT INTO 'dancesstepsmap' VALUES (11520, 10408, 3);
INSERT INTO 'dancesstepsmap' VALUES (11521, 10412, 2);
INSERT INTO 'dancesstepsmap' VALUES (11522, 10412, 1);
INSERT INTO 'dancesstepsmap' VALUES (11523, 10414, 2);
INSERT INTO 'dancesstepsmap' VALUES (11524, 10414, 1);
INSERT INTO 'dancesstepsmap' VALUES (11525, 10414, 3);
INSERT INTO 'dancesstepsmap' VALUES (11528, 10423, 1);
INSERT INTO 'dancesstepsmap' VALUES (11529, 10424, 4);
INSERT INTO 'dancesstepsmap' VALUES (11530, 10424, 5);
INSERT INTO 'dancesstepsmap' VALUES (11531, 644, 3);
INSERT INTO 'dancesstepsmap' VALUES (11532, 10428, 1);
INSERT INTO 'dancesstepsmap' VALUES (11533, 10438, 2);
INSERT INTO 'dancesstepsmap' VALUES (11534, 10438, 3);
INSERT INTO 'dancesstepsmap' VALUES (11535, 9759, 1);
INSERT INTO 'dancesstepsmap' VALUES (11536, 9759, 2);
INSERT INTO 'dancesstepsmap' VALUES (11537, 9762, 2);
INSERT INTO 'dancesstepsmap' VALUES (11538, 9762, 1);
INSERT INTO 'dancesstepsmap' VALUES (11539, 7570, 2);
INSERT INTO 'dancesstepsmap' VALUES (11540, 9764, 2);
INSERT INTO 'dancesstepsmap' VALUES (11541, 9764, 1);
INSERT INTO 'dancesstepsmap' VALUES (4145, 4485, 1);
INSERT INTO 'dancesstepsmap' VALUES (4146, 4486, 4);
INSERT INTO 'dancesstepsmap' VALUES (4147, 4487, 1);
INSERT INTO 'dancesstepsmap' VALUES (4148, 4488, 4);
INSERT INTO 'dancesstepsmap' VALUES (4149, 4489, 4);
INSERT INTO 'dancesstepsmap' VALUES (4150, 4490, 4);
INSERT INTO 'dancesstepsmap' VALUES (4151, 4491, 1);
INSERT INTO 'dancesstepsmap' VALUES (4152, 4492, 1);
INSERT INTO 'dancesstepsmap' VALUES (4153, 4493, 1);
INSERT INTO 'dancesstepsmap' VALUES (4154, 4494, 4);
INSERT INTO 'dancesstepsmap' VALUES (4155, 4495, 1);
INSERT INTO 'dancesstepsmap' VALUES (4156, 4496, 4);
INSERT INTO 'dancesstepsmap' VALUES (4157, 4498, 1);
INSERT INTO 'dancesstepsmap' VALUES (4158, 4499, 4);
INSERT INTO 'dancesstepsmap' VALUES (4159, 4500, 1);
INSERT INTO 'dancesstepsmap' VALUES (4160, 4501, 4);
INSERT INTO 'dancesstepsmap' VALUES (4161, 4502, 4);
INSERT INTO 'dancesstepsmap' VALUES (4162, 4503, 4);
INSERT INTO 'dancesstepsmap' VALUES (4163, 4504, 1);
INSERT INTO 'dancesstepsmap' VALUES (4164, 4505, 4);
INSERT INTO 'dancesstepsmap' VALUES (4165, 4506, 4);
INSERT INTO 'dancesstepsmap' VALUES (4166, 4507, 1);
INSERT INTO 'dancesstepsmap' VALUES (4167, 4508, 1);
INSERT INTO 'dancesstepsmap' VALUES (4168, 4509, 4);
INSERT INTO 'dancesstepsmap' VALUES (4169, 4510, 1);
INSERT INTO 'dancesstepsmap' VALUES (4170, 4511, 4);
INSERT INTO 'dancesstepsmap' VALUES (4171, 4512, 1);
INSERT INTO 'dancesstepsmap' VALUES (4172, 4514, 4);
INSERT INTO 'dancesstepsmap' VALUES (4173, 4515, 1);
INSERT INTO 'dancesstepsmap' VALUES (4174, 4516, 1);
INSERT INTO 'dancesstepsmap' VALUES (4175, 4518, 1);
INSERT INTO 'dancesstepsmap' VALUES (4176, 4519, 1);
INSERT INTO 'dancesstepsmap' VALUES (4177, 4520, 1);
INSERT INTO 'dancesstepsmap' VALUES (4178, 4521, 1);
INSERT INTO 'dancesstepsmap' VALUES (4179, 4522, 1);
INSERT INTO 'dancesstepsmap' VALUES (4180, 4523, 1);
INSERT INTO 'dancesstepsmap' VALUES (4181, 4524, 1);
INSERT INTO 'dancesstepsmap' VALUES (4182, 4525, 1);
INSERT INTO 'dancesstepsmap' VALUES (4183, 4526, 1);
INSERT INTO 'dancesstepsmap' VALUES (4184, 4527, 4);
INSERT INTO 'dancesstepsmap' VALUES (4185, 4528, 1);
INSERT INTO 'dancesstepsmap' VALUES (4186, 4529, 1);
INSERT INTO 'dancesstepsmap' VALUES (4187, 4530, 1);
INSERT INTO 'dancesstepsmap' VALUES (11500, 10395, 2);
INSERT INTO 'dancesstepsmap' VALUES (4189, 4532, 4);
INSERT INTO 'dancesstepsmap' VALUES (4190, 4533, 4);
INSERT INTO 'dancesstepsmap' VALUES (4191, 4534, 4);
INSERT INTO 'dancesstepsmap' VALUES (4192, 4535, 1);
INSERT INTO 'dancesstepsmap' VALUES (4193, 4536, 1);
INSERT INTO 'dancesstepsmap' VALUES (4194, 4537, 4);
INSERT INTO 'dancesstepsmap' VALUES (4195, 4538, 4);
INSERT INTO 'dancesstepsmap' VALUES (4196, 4539, 1);
INSERT INTO 'dancesstepsmap' VALUES (4197, 4540, 4);
INSERT INTO 'dancesstepsmap' VALUES (4198, 4541, 4);
INSERT INTO 'dancesstepsmap' VALUES (4199, 4542, 1);
INSERT INTO 'dancesstepsmap' VALUES (4200, 4543, 1);
INSERT INTO 'dancesstepsmap' VALUES (4201, 4544, 4);
INSERT INTO 'dancesstepsmap' VALUES (4202, 4545, 1);
INSERT INTO 'dancesstepsmap' VALUES (4203, 4546, 4);
INSERT INTO 'dancesstepsmap' VALUES (4204, 4547, 4);
INSERT INTO 'dancesstepsmap' VALUES (4205, 4548, 1);
INSERT INTO 'dancesstepsmap' VALUES (4206, 4549, 1);
INSERT INTO 'dancesstepsmap' VALUES (4207, 4550, 1);
INSERT INTO 'dancesstepsmap' VALUES (4208, 4551, 4);
INSERT INTO 'dancesstepsmap' VALUES (4209, 4552, 4);
INSERT INTO 'dancesstepsmap' VALUES (4210, 4553, 1);
INSERT INTO 'dancesstepsmap' VALUES (4211, 4554, 1);
INSERT INTO 'dancesstepsmap' VALUES (4212, 4555, 4);
INSERT INTO 'dancesstepsmap' VALUES (4213, 4556, 1);
INSERT INTO 'dancesstepsmap' VALUES (4214, 4557, 1);
INSERT INTO 'dancesstepsmap' VALUES (4215, 4558, 1);
INSERT INTO 'dancesstepsmap' VALUES (4216, 4559, 1);
INSERT INTO 'dancesstepsmap' VALUES (4217, 4560, 4);
INSERT INTO 'dancesstepsmap' VALUES (4218, 4561, 4);
INSERT INTO 'dancesstepsmap' VALUES (4219, 4562, 1);
INSERT INTO 'dancesstepsmap' VALUES (4220, 4563, 1);
INSERT INTO 'dancesstepsmap' VALUES (4221, 4564, 1);
INSERT INTO 'dancesstepsmap' VALUES (4222, 4565, 4);
INSERT INTO 'dancesstepsmap' VALUES (4223, 4566, 1);
INSERT INTO 'dancesstepsmap' VALUES (4224, 4567, 4);
INSERT INTO 'dancesstepsmap' VALUES (4225, 4568, 4);
INSERT INTO 'dancesstepsmap' VALUES (4226, 4569, 1);
INSERT INTO 'dancesstepsmap' VALUES (4227, 4570, 1);
INSERT INTO 'dancesstepsmap' VALUES (4228, 4571, 1);
INSERT INTO 'dancesstepsmap' VALUES (4229, 4572, 1);
INSERT INTO 'dancesstepsmap' VALUES (4230, 4573, 1);
INSERT INTO 'dancesstepsmap' VALUES (4231, 4574, 1);
INSERT INTO 'dancesstepsmap' VALUES (4232, 4575, 4);
INSERT INTO 'dancesstepsmap' VALUES (4233, 4576, 1);
INSERT INTO 'dancesstepsmap' VALUES (4234, 4577, 1);
INSERT INTO 'dancesstepsmap' VALUES (4235, 4578, 1);
INSERT INTO 'dancesstepsmap' VALUES (4236, 4579, 4);
INSERT INTO 'dancesstepsmap' VALUES (4237, 4580, 1);
INSERT INTO 'dancesstepsmap' VALUES (11542, 9765, 1);
INSERT INTO 'dancesstepsmap' VALUES (11543, 9765, 2);
INSERT INTO 'dancesstepsmap' VALUES (11544, 9765, 4);
INSERT INTO 'dancesstepsmap' VALUES (11545, 9765, 5);
INSERT INTO 'dancesstepsmap' VALUES (11546, 10456, 2);
INSERT INTO 'dancesstepsmap' VALUES (11547, 10456, 1);
INSERT INTO 'dancesstepsmap' VALUES (11548, 10427, 4);
INSERT INTO 'dancesstepsmap' VALUES (11549, 10427, 5);
INSERT INTO 'dancesstepsmap' VALUES (11550, 1911, 2);
INSERT INTO 'dancesstepsmap' VALUES (11551, 1911, 1);
INSERT INTO 'dancesstepsmap' VALUES (11552, 10429, 3);
INSERT INTO 'dancesstepsmap' VALUES (11553, 10429, 1);
INSERT INTO 'dancesstepsmap' VALUES (11554, 10429, 2);
INSERT INTO 'dancesstepsmap' VALUES (11555, 10430, 4);
INSERT INTO 'dancesstepsmap' VALUES (11556, 10431, 1);
INSERT INTO 'dancesstepsmap' VALUES (11557, 10431, 3);
INSERT INTO 'dancesstepsmap' VALUES (11558, 9766, 1);
INSERT INTO 'dancesstepsmap' VALUES (11559, 9766, 2);
INSERT INTO 'dancesstepsmap' VALUES (11560, 9766, 3);
INSERT INTO 'dancesstepsmap' VALUES (11561, 9767, 8);
INSERT INTO 'dancesstepsmap' VALUES (11562, 9767, 3);
INSERT INTO 'dancesstepsmap' VALUES (11563, 9767, 1);
INSERT INTO 'dancesstepsmap' VALUES (11564, 9768, 4);
INSERT INTO 'dancesstepsmap' VALUES (11565, 9768, 5);
INSERT INTO 'dancesstepsmap' VALUES (11566, 9769, 1);
INSERT INTO 'dancesstepsmap' VALUES (11567, 9769, 3);
INSERT INTO 'dancesstepsmap' VALUES (11568, 10457, 1);
INSERT INTO 'dancesstepsmap' VALUES (11569, 10432, 2);
INSERT INTO 'dancesstepsmap' VALUES (11570, 10432, 1);
INSERT INTO 'dancesstepsmap' VALUES (11571, 10432, 3);
INSERT INTO 'dancesstepsmap' VALUES (11572, 10433, 5);
INSERT INTO 'dancesstepsmap' VALUES (11573, 10433, 4);
INSERT INTO 'dancesstepsmap' VALUES (11574, 10458, 4);
INSERT INTO 'dancesstepsmap' VALUES (11575, 10458, 5);
INSERT INTO 'dancesstepsmap' VALUES (11576, 10459, 4);
INSERT INTO 'dancesstepsmap' VALUES (11577, 10460, 1);
INSERT INTO 'dancesstepsmap' VALUES (11578, 10109, 4);
INSERT INTO 'dancesstepsmap' VALUES (11579, 9214, 4);
INSERT INTO 'dancesstepsmap' VALUES (11580, 10462, 4);
INSERT INTO 'dancesstepsmap' VALUES (11581, 9684, 1);
INSERT INTO 'dancesstepsmap' VALUES (11582, 9684, 2);
INSERT INTO 'dancesstepsmap' VALUES (11583, 9684, 4);
INSERT INTO 'dancesstepsmap' VALUES (17155, 14561, 1);
INSERT INTO 'dancesstepsmap' VALUES (17156, 14561, 3);
INSERT INTO 'dancesstepsmap' VALUES (17179, 14573, 1);
INSERT INTO 'dancesstepsmap' VALUES (17180, 14573, 2);
INSERT INTO 'dancesstepsmap' VALUES (17181, 14573, 3);
INSERT INTO 'dancesstepsmap' VALUES (4238, 4581, 1);
INSERT INTO 'dancesstepsmap' VALUES (4239, 4582, 1);
INSERT INTO 'dancesstepsmap' VALUES (4240, 4583, 1);
INSERT INTO 'dancesstepsmap' VALUES (4241, 4584, 1);
INSERT INTO 'dancesstepsmap' VALUES (4242, 4585, 1);
INSERT INTO 'dancesstepsmap' VALUES (4243, 4586, 4);
INSERT INTO 'dancesstepsmap' VALUES (4244, 4587, 4);
INSERT INTO 'dancesstepsmap' VALUES (4245, 4588, 4);
INSERT INTO 'dancesstepsmap' VALUES (4246, 4589, 4);
INSERT INTO 'dancesstepsmap' VALUES (4247, 4590, 1);
INSERT INTO 'dancesstepsmap' VALUES (4248, 4591, 1);
INSERT INTO 'dancesstepsmap' VALUES (4249, 4592, 1);
INSERT INTO 'dancesstepsmap' VALUES (4250, 4593, 4);
INSERT INTO 'dancesstepsmap' VALUES (4251, 4594, 1);
INSERT INTO 'dancesstepsmap' VALUES (4252, 4595, 1);
INSERT INTO 'dancesstepsmap' VALUES (4253, 4596, 1);
INSERT INTO 'dancesstepsmap' VALUES (4254, 4597, 1);
INSERT INTO 'dancesstepsmap' VALUES (4255, 4598, 4);
INSERT INTO 'dancesstepsmap' VALUES (4256, 4599, 1);
INSERT INTO 'dancesstepsmap' VALUES (4257, 4600, 4);
INSERT INTO 'dancesstepsmap' VALUES (4258, 4601, 1);
INSERT INTO 'dancesstepsmap' VALUES (4259, 4602, 4);
INSERT INTO 'dancesstepsmap' VALUES (4260, 4603, 1);
INSERT INTO 'dancesstepsmap' VALUES (4261, 4604, 4);
INSERT INTO 'dancesstepsmap' VALUES (4262, 4605, 4);
INSERT INTO 'dancesstepsmap' VALUES (4263, 4606, 1);
INSERT INTO 'dancesstepsmap' VALUES (4264, 4607, 4);
INSERT INTO 'dancesstepsmap' VALUES (4265, 4608, 1);
INSERT INTO 'dancesstepsmap' VALUES (4266, 4609, 4);
INSERT INTO 'dancesstepsmap' VALUES (4267, 4610, 4);
INSERT INTO 'dancesstepsmap' VALUES (4268, 4611, 4);
INSERT INTO 'dancesstepsmap' VALUES (4269, 4612, 4);
INSERT INTO 'dancesstepsmap' VALUES (4270, 4613, 1);
INSERT INTO 'dancesstepsmap' VALUES (4271, 4614, 1);
INSERT INTO 'dancesstepsmap' VALUES (4272, 4615, 1);
INSERT INTO 'dancesstepsmap' VALUES (4273, 4616, 1);
INSERT INTO 'dancesstepsmap' VALUES (4274, 4617, 1);
INSERT INTO 'dancesstepsmap' VALUES (4275, 4618, 1);
INSERT INTO 'dancesstepsmap' VALUES (4276, 4619, 1);
INSERT INTO 'dancesstepsmap' VALUES (4277, 4620, 1);
INSERT INTO 'dancesstepsmap' VALUES (4278, 4622, 4);
INSERT INTO 'dancesstepsmap' VALUES (4279, 4623, 1);
INSERT INTO 'dancesstepsmap' VALUES (4280, 4625, 1);
INSERT INTO 'dancesstepsmap' VALUES (4281, 4626, 1);
INSERT INTO 'dancesstepsmap' VALUES (4282, 4627, 1);
INSERT INTO 'dancesstepsmap' VALUES (4283, 4628, 1);
INSERT INTO 'dancesstepsmap' VALUES (4284, 4629, 4);
INSERT INTO 'dancesstepsmap' VALUES (4285, 4630, 4);
INSERT INTO 'dancesstepsmap' VALUES (4286, 4632, 1);
INSERT INTO 'dancesstepsmap' VALUES (4287, 4634, 1);
INSERT INTO 'dancesstepsmap' VALUES (4288, 4635, 1);
INSERT INTO 'dancesstepsmap' VALUES (4289, 4636, 1);
INSERT INTO 'dancesstepsmap' VALUES (4290, 4637, 1);
INSERT INTO 'dancesstepsmap' VALUES (4291, 4638, 1);
INSERT INTO 'dancesstepsmap' VALUES (4292, 4639, 1);
INSERT INTO 'dancesstepsmap' VALUES (4293, 4640, 1);
INSERT INTO 'dancesstepsmap' VALUES (4294, 4641, 1);
INSERT INTO 'dancesstepsmap' VALUES (4295, 4643, 4);
INSERT INTO 'dancesstepsmap' VALUES (4296, 4644, 1);
INSERT INTO 'dancesstepsmap' VALUES (4297, 4645, 1);
INSERT INTO 'dancesstepsmap' VALUES (4298, 4646, 4);
INSERT INTO 'dancesstepsmap' VALUES (4299, 4647, 1);
INSERT INTO 'dancesstepsmap' VALUES (4300, 4648, 4);
INSERT INTO 'dancesstepsmap' VALUES (4301, 4649, 1);
INSERT INTO 'dancesstepsmap' VALUES (4302, 4651, 1);
INSERT INTO 'dancesstepsmap' VALUES (4303, 4652, 4);
INSERT INTO 'dancesstepsmap' VALUES (4304, 4653, 1);
INSERT INTO 'dancesstepsmap' VALUES (4305, 4654, 4);
INSERT INTO 'dancesstepsmap' VALUES (4306, 4655, 4);
INSERT INTO 'dancesstepsmap' VALUES (4307, 4656, 4);
INSERT INTO 'dancesstepsmap' VALUES (4308, 4657, 4);
INSERT INTO 'dancesstepsmap' VALUES (4309, 4658, 4);
INSERT INTO 'dancesstepsmap' VALUES (4310, 4659, 4);
INSERT INTO 'dancesstepsmap' VALUES (4311, 4660, 1);
INSERT INTO 'dancesstepsmap' VALUES (4312, 4661, 1);
INSERT INTO 'dancesstepsmap' VALUES (4313, 4662, 4);
INSERT INTO 'dancesstepsmap' VALUES (4314, 4663, 1);
INSERT INTO 'dancesstepsmap' VALUES (4315, 4664, 1);
INSERT INTO 'dancesstepsmap' VALUES (4316, 4665, 1);
INSERT INTO 'dancesstepsmap' VALUES (4317, 4666, 1);
INSERT INTO 'dancesstepsmap' VALUES (4318, 4667, 1);
INSERT INTO 'dancesstepsmap' VALUES (4319, 4668, 1);
INSERT INTO 'dancesstepsmap' VALUES (4320, 4669, 1);
INSERT INTO 'dancesstepsmap' VALUES (4321, 4670, 4);
INSERT INTO 'dancesstepsmap' VALUES (4322, 4671, 4);
INSERT INTO 'dancesstepsmap' VALUES (4323, 4672, 4);
INSERT INTO 'dancesstepsmap' VALUES (4324, 4673, 1);
INSERT INTO 'dancesstepsmap' VALUES (4325, 4674, 1);
INSERT INTO 'dancesstepsmap' VALUES (4326, 4675, 4);
INSERT INTO 'dancesstepsmap' VALUES (4327, 4676, 1);
INSERT INTO 'dancesstepsmap' VALUES (4328, 4677, 4);
INSERT INTO 'dancesstepsmap' VALUES (4329, 4678, 1);
INSERT INTO 'dancesstepsmap' VALUES (11584, 9684, 5);
INSERT INTO 'dancesstepsmap' VALUES (11585, 9475, 4);
INSERT INTO 'dancesstepsmap' VALUES (11587, 5261, 5);
INSERT INTO 'dancesstepsmap' VALUES (11588, 8522, 3);
INSERT INTO 'dancesstepsmap' VALUES (11589, 8508, 2);
INSERT INTO 'dancesstepsmap' VALUES (11590, 7563, 2);
INSERT INTO 'dancesstepsmap' VALUES (11591, 8509, 3);
INSERT INTO 'dancesstepsmap' VALUES (11592, 8140, 3);
INSERT INTO 'dancesstepsmap' VALUES (11593, 2085, 2);
INSERT INTO 'dancesstepsmap' VALUES (11594, 9634, 1);
INSERT INTO 'dancesstepsmap' VALUES (11595, 9634, 3);
INSERT INTO 'dancesstepsmap' VALUES (11596, 10463, 1);
INSERT INTO 'dancesstepsmap' VALUES (11597, 10467, 1);
INSERT INTO 'dancesstepsmap' VALUES (11598, 10467, 2);
INSERT INTO 'dancesstepsmap' VALUES (11599, 10467, 4);
INSERT INTO 'dancesstepsmap' VALUES (11600, 10467, 5);
INSERT INTO 'dancesstepsmap' VALUES (11601, 10468, 4);
INSERT INTO 'dancesstepsmap' VALUES (11602, 10468, 5);
INSERT INTO 'dancesstepsmap' VALUES (11603, 7035, 3);
INSERT INTO 'dancesstepsmap' VALUES (11604, 10469, 4);
INSERT INTO 'dancesstepsmap' VALUES (11605, 10470, 4);
INSERT INTO 'dancesstepsmap' VALUES (11606, 10470, 5);
INSERT INTO 'dancesstepsmap' VALUES (11607, 8511, 3);
INSERT INTO 'dancesstepsmap' VALUES (11608, 9219, 4);
INSERT INTO 'dancesstepsmap' VALUES (11609, 9219, 5);
INSERT INTO 'dancesstepsmap' VALUES (11610, 7944, 5);
INSERT INTO 'dancesstepsmap' VALUES (11611, 8525, 3);
INSERT INTO 'dancesstepsmap' VALUES (11612, 9895, 4);
INSERT INTO 'dancesstepsmap' VALUES (11613, 10472, 1);
INSERT INTO 'dancesstepsmap' VALUES (11614, 6472, 2);
INSERT INTO 'dancesstepsmap' VALUES (11615, 10473, 2);
INSERT INTO 'dancesstepsmap' VALUES (11616, 9478, 1);
INSERT INTO 'dancesstepsmap' VALUES (11617, 9478, 3);
INSERT INTO 'dancesstepsmap' VALUES (11618, 6687, 2);
INSERT INTO 'dancesstepsmap' VALUES (11619, 8558, 2);
INSERT INTO 'dancesstepsmap' VALUES (11620, 6764, 8);
INSERT INTO 'dancesstepsmap' VALUES (11621, 6764, 5);
INSERT INTO 'dancesstepsmap' VALUES (11622, 6764, 4);
INSERT INTO 'dancesstepsmap' VALUES (11623, 6764, 1);
INSERT INTO 'dancesstepsmap' VALUES (11624, 6764, 2);
INSERT INTO 'dancesstepsmap' VALUES (11625, 6853, 3);
INSERT INTO 'dancesstepsmap' VALUES (17158, 14560, 3);
INSERT INTO 'dancesstepsmap' VALUES (17182, 14576, 5);
INSERT INTO 'dancesstepsmap' VALUES (17183, 14576, 4);
INSERT INTO 'dancesstepsmap' VALUES (17186, 13081, 2);
INSERT INTO 'dancesstepsmap' VALUES (17187, 8654, 2);
INSERT INTO 'dancesstepsmap' VALUES (17190, 1938, 1);
INSERT INTO 'dancesstepsmap' VALUES (17191, 306, 5);
INSERT INTO 'dancesstepsmap' VALUES (17192, 14593, 4);
INSERT INTO 'dancesstepsmap' VALUES (17193, 14593, 6);
INSERT INTO 'dancesstepsmap' VALUES (17194, 14593, 5);
INSERT INTO 'dancesstepsmap' VALUES (17195, 14593, 10);
INSERT INTO 'dancesstepsmap' VALUES (17196, 14593, 1);
INSERT INTO 'dancesstepsmap' VALUES (17197, 14593, 2);
INSERT INTO 'dancesstepsmap' VALUES (17198, 7286, 2);
INSERT INTO 'dancesstepsmap' VALUES (17199, 14594, 1);
INSERT INTO 'dancesstepsmap' VALUES (17200, 14594, 2);
INSERT INTO 'dancesstepsmap' VALUES (17201, 14596, 1);
INSERT INTO 'dancesstepsmap' VALUES (17202, 8684, 99);
INSERT INTO 'dancesstepsmap' VALUES (17203, 8091, 5);
INSERT INTO 'dancesstepsmap' VALUES (17204, 8091, 4);
INSERT INTO 'dancesstepsmap' VALUES (17205, 8091, 1);
INSERT INTO 'dancesstepsmap' VALUES (4330, 4679, 1);
INSERT INTO 'dancesstepsmap' VALUES (4331, 4681, 1);
INSERT INTO 'dancesstepsmap' VALUES (4332, 4682, 4);
INSERT INTO 'dancesstepsmap' VALUES (4333, 4683, 1);
INSERT INTO 'dancesstepsmap' VALUES (4334, 4685, 1);
INSERT INTO 'dancesstepsmap' VALUES (4335, 4686, 1);
INSERT INTO 'dancesstepsmap' VALUES (4336, 4687, 1);
INSERT INTO 'dancesstepsmap' VALUES (4337, 4688, 1);
INSERT INTO 'dancesstepsmap' VALUES (4338, 4689, 1);
INSERT INTO 'dancesstepsmap' VALUES (4339, 4690, 4);
INSERT INTO 'dancesstepsmap' VALUES (4340, 4691, 1);
INSERT INTO 'dancesstepsmap' VALUES (4341, 4692, 1);
INSERT INTO 'dancesstepsmap' VALUES (4342, 4693, 1);
INSERT INTO 'dancesstepsmap' VALUES (4343, 4694, 4);
INSERT INTO 'dancesstepsmap' VALUES (4344, 4695, 1);
INSERT INTO 'dancesstepsmap' VALUES (4345, 4696, 1);
INSERT INTO 'dancesstepsmap' VALUES (4346, 4697, 1);
INSERT INTO 'dancesstepsmap' VALUES (4347, 4698, 1);
INSERT INTO 'dancesstepsmap' VALUES (4348, 4699, 4);
INSERT INTO 'dancesstepsmap' VALUES (4349, 4700, 1);
INSERT INTO 'dancesstepsmap' VALUES (4350, 4701, 1);
INSERT INTO 'dancesstepsmap' VALUES (4351, 4703, 1);
INSERT INTO 'dancesstepsmap' VALUES (4352, 4704, 1);
INSERT INTO 'dancesstepsmap' VALUES (4353, 4705, 1);
INSERT INTO 'dancesstepsmap' VALUES (4354, 4707, 1);
INSERT INTO 'dancesstepsmap' VALUES (4355, 4708, 4);
INSERT INTO 'dancesstepsmap' VALUES (4356, 4709, 1);
INSERT INTO 'dancesstepsmap' VALUES (4357, 4710, 1);
INSERT INTO 'dancesstepsmap' VALUES (4358, 4711, 1);
INSERT INTO 'dancesstepsmap' VALUES (4359, 4712, 1);
INSERT INTO 'dancesstepsmap' VALUES (4360, 4713, 1);
INSERT INTO 'dancesstepsmap' VALUES (4361, 4714, 4);
INSERT INTO 'dancesstepsmap' VALUES (4362, 4715, 1);
INSERT INTO 'dancesstepsmap' VALUES (4363, 4716, 1);
INSERT INTO 'dancesstepsmap' VALUES (4364, 4717, 1);
INSERT INTO 'dancesstepsmap' VALUES (4365, 4718, 1);
INSERT INTO 'dancesstepsmap' VALUES (4366, 4719, 4);
INSERT INTO 'dancesstepsmap' VALUES (4367, 4720, 4);
INSERT INTO 'dancesstepsmap' VALUES (4368, 4722, 1);
INSERT INTO 'dancesstepsmap' VALUES (4369, 4723, 1);
INSERT INTO 'dancesstepsmap' VALUES (4370, 4724, 4);
INSERT INTO 'dancesstepsmap' VALUES (4371, 4725, 1);
INSERT INTO 'dancesstepsmap' VALUES (4372, 4726, 1);
INSERT INTO 'dancesstepsmap' VALUES (4373, 4728, 1);
INSERT INTO 'dancesstepsmap' VALUES (4374, 4729, 4);
INSERT INTO 'dancesstepsmap' VALUES (4375, 4730, 1);
INSERT INTO 'dancesstepsmap' VALUES (4376, 4731, 4);
INSERT INTO 'dancesstepsmap' VALUES (4377, 4732, 1);
INSERT INTO 'dancesstepsmap' VALUES (4378, 4733, 1);
INSERT INTO 'dancesstepsmap' VALUES (4379, 4734, 1);
INSERT INTO 'dancesstepsmap' VALUES (4380, 4735, 4);
INSERT INTO 'dancesstepsmap' VALUES (4381, 4736, 4);
INSERT INTO 'dancesstepsmap' VALUES (4382, 4737, 4);
INSERT INTO 'dancesstepsmap' VALUES (4383, 4738, 1);
INSERT INTO 'dancesstepsmap' VALUES (4384, 4739, 1);
INSERT INTO 'dancesstepsmap' VALUES (4385, 4741, 4);
INSERT INTO 'dancesstepsmap' VALUES (4386, 4742, 4);
INSERT INTO 'dancesstepsmap' VALUES (4387, 4744, 1);
INSERT INTO 'dancesstepsmap' VALUES (4388, 4745, 1);
INSERT INTO 'dancesstepsmap' VALUES (4389, 4746, 4);
INSERT INTO 'dancesstepsmap' VALUES (4390, 4747, 1);
INSERT INTO 'dancesstepsmap' VALUES (4391, 4748, 4);
INSERT INTO 'dancesstepsmap' VALUES (4392, 4749, 1);
INSERT INTO 'dancesstepsmap' VALUES (4393, 4750, 4);
INSERT INTO 'dancesstepsmap' VALUES (4394, 4751, 4);
INSERT INTO 'dancesstepsmap' VALUES (4395, 4752, 4);
INSERT INTO 'dancesstepsmap' VALUES (4396, 4753, 4);
INSERT INTO 'dancesstepsmap' VALUES (4397, 4754, 1);
INSERT INTO 'dancesstepsmap' VALUES (4398, 4755, 4);
INSERT INTO 'dancesstepsmap' VALUES (4399, 4756, 4);
INSERT INTO 'dancesstepsmap' VALUES (4400, 4757, 4);
INSERT INTO 'dancesstepsmap' VALUES (4401, 4758, 4);
INSERT INTO 'dancesstepsmap' VALUES (4402, 4759, 4);
INSERT INTO 'dancesstepsmap' VALUES (4403, 4760, 1);
INSERT INTO 'dancesstepsmap' VALUES (4404, 4761, 4);
INSERT INTO 'dancesstepsmap' VALUES (4405, 4762, 4);
INSERT INTO 'dancesstepsmap' VALUES (4406, 4763, 4);
INSERT INTO 'dancesstepsmap' VALUES (4407, 4764, 1);
INSERT INTO 'dancesstepsmap' VALUES (4408, 4765, 1);
INSERT INTO 'dancesstepsmap' VALUES (4409, 4766, 1);
INSERT INTO 'dancesstepsmap' VALUES (4410, 4767, 1);
INSERT INTO 'dancesstepsmap' VALUES (4411, 4768, 4);
INSERT INTO 'dancesstepsmap' VALUES (4412, 4769, 4);
INSERT INTO 'dancesstepsmap' VALUES (4413, 4770, 4);
INSERT INTO 'dancesstepsmap' VALUES (4414, 4771, 4);
INSERT INTO 'dancesstepsmap' VALUES (4415, 4772, 1);
INSERT INTO 'dancesstepsmap' VALUES (4416, 4773, 4);
INSERT INTO 'dancesstepsmap' VALUES (4417, 4774, 1);
INSERT INTO 'dancesstepsmap' VALUES (4418, 4775, 4);
INSERT INTO 'dancesstepsmap' VALUES (4419, 4776, 1);
INSERT INTO 'dancesstepsmap' VALUES (4420, 4777, 1);
INSERT INTO 'dancesstepsmap' VALUES (4421, 4778, 1);
INSERT INTO 'dancesstepsmap' VALUES (4422, 4779, 4);
INSERT INTO 'dancesstepsmap' VALUES (11626, 7533, 3);
INSERT INTO 'dancesstepsmap' VALUES (11627, 6961, 5);
INSERT INTO 'dancesstepsmap' VALUES (11628, 7121, 5);
INSERT INTO 'dancesstepsmap' VALUES (11629, 10474, 1);
INSERT INTO 'dancesstepsmap' VALUES (11630, 7252, 5);
INSERT INTO 'dancesstepsmap' VALUES (11631, 8816, 5);
INSERT INTO 'dancesstepsmap' VALUES (11632, 8816, 4);
INSERT INTO 'dancesstepsmap' VALUES (11633, 674, 5);
INSERT INTO 'dancesstepsmap' VALUES (11634, 80, 2);
INSERT INTO 'dancesstepsmap' VALUES (11635, 3715, 10);
INSERT INTO 'dancesstepsmap' VALUES (11636, 95, 5);
INSERT INTO 'dancesstepsmap' VALUES (11637, 1959, 5);
INSERT INTO 'dancesstepsmap' VALUES (11638, 1945, 2);
INSERT INTO 'dancesstepsmap' VALUES (11639, 2626, 2);
INSERT INTO 'dancesstepsmap' VALUES (11640, 2626, 3);
INSERT INTO 'dancesstepsmap' VALUES (11641, 5395, 2);
INSERT INTO 'dancesstepsmap' VALUES (11642, 10475, 2);
INSERT INTO 'dancesstepsmap' VALUES (11643, 10475, 1);
INSERT INTO 'dancesstepsmap' VALUES (11644, 10476, 1);
INSERT INTO 'dancesstepsmap' VALUES (11645, 10477, 1);
INSERT INTO 'dancesstepsmap' VALUES (11646, 10478, 1);
INSERT INTO 'dancesstepsmap' VALUES (11647, 10478, 2);
INSERT INTO 'dancesstepsmap' VALUES (11648, 10479, 5);
INSERT INTO 'dancesstepsmap' VALUES (11649, 10479, 4);
INSERT INTO 'dancesstepsmap' VALUES (11650, 10480, 2);
INSERT INTO 'dancesstepsmap' VALUES (11651, 10480, 1);
INSERT INTO 'dancesstepsmap' VALUES (11652, 10481, 4);
INSERT INTO 'dancesstepsmap' VALUES (11653, 10482, 1);
INSERT INTO 'dancesstepsmap' VALUES (11654, 10483, 4);
INSERT INTO 'dancesstepsmap' VALUES (11655, 10484, 1);
INSERT INTO 'dancesstepsmap' VALUES (11656, 10485, 1);
INSERT INTO 'dancesstepsmap' VALUES (11657, 10486, 4);
INSERT INTO 'dancesstepsmap' VALUES (11658, 10486, 5);
INSERT INTO 'dancesstepsmap' VALUES (11659, 10487, 1);
INSERT INTO 'dancesstepsmap' VALUES (11660, 10488, 4);
INSERT INTO 'dancesstepsmap' VALUES (11661, 10488, 5);
INSERT INTO 'dancesstepsmap' VALUES (11662, 10489, 4);
INSERT INTO 'dancesstepsmap' VALUES (11663, 10490, 1);
INSERT INTO 'dancesstepsmap' VALUES (11664, 10455, 4);
INSERT INTO 'dancesstepsmap' VALUES (11665, 10491, 2);
INSERT INTO 'dancesstepsmap' VALUES (11666, 10491, 1);
INSERT INTO 'dancesstepsmap' VALUES (11667, 10491, 3);
INSERT INTO 'dancesstepsmap' VALUES (17184, 14570, 1);
INSERT INTO 'dancesstepsmap' VALUES (17185, 14570, 2);
INSERT INTO 'dancesstepsmap' VALUES (17206, 8091, 2);
INSERT INTO 'dancesstepsmap' VALUES (17207, 8091, 10);
INSERT INTO 'dancesstepsmap' VALUES (17208, 14477, 99);
INSERT INTO 'dancesstepsmap' VALUES (4423, 4780, 1);
INSERT INTO 'dancesstepsmap' VALUES (4424, 4782, 1);
INSERT INTO 'dancesstepsmap' VALUES (4425, 4783, 1);
INSERT INTO 'dancesstepsmap' VALUES (4426, 4784, 1);
INSERT INTO 'dancesstepsmap' VALUES (4427, 4785, 1);
INSERT INTO 'dancesstepsmap' VALUES (4428, 4786, 4);
INSERT INTO 'dancesstepsmap' VALUES (4429, 4787, 1);
INSERT INTO 'dancesstepsmap' VALUES (4430, 4789, 4);
INSERT INTO 'dancesstepsmap' VALUES (4431, 4790, 1);
INSERT INTO 'dancesstepsmap' VALUES (4432, 4791, 4);
INSERT INTO 'dancesstepsmap' VALUES (4433, 4792, 4);
INSERT INTO 'dancesstepsmap' VALUES (4434, 4793, 1);
INSERT INTO 'dancesstepsmap' VALUES (4435, 4794, 4);
INSERT INTO 'dancesstepsmap' VALUES (4436, 4795, 4);
INSERT INTO 'dancesstepsmap' VALUES (4437, 4796, 4);
INSERT INTO 'dancesstepsmap' VALUES (4438, 4797, 1);
INSERT INTO 'dancesstepsmap' VALUES (4439, 4800, 4);
INSERT INTO 'dancesstepsmap' VALUES (4440, 4801, 4);
INSERT INTO 'dancesstepsmap' VALUES (4441, 4802, 4);
INSERT INTO 'dancesstepsmap' VALUES (4442, 4803, 1);
INSERT INTO 'dancesstepsmap' VALUES (4443, 4804, 1);
INSERT INTO 'dancesstepsmap' VALUES (4444, 4805, 1);
INSERT INTO 'dancesstepsmap' VALUES (4445, 4806, 4);
INSERT INTO 'dancesstepsmap' VALUES (4446, 4807, 1);
INSERT INTO 'dancesstepsmap' VALUES (4447, 4808, 1);
INSERT INTO 'dancesstepsmap' VALUES (4448, 4809, 4);
INSERT INTO 'dancesstepsmap' VALUES (4450, 4811, 1);
INSERT INTO 'dancesstepsmap' VALUES (4451, 4812, 1);
INSERT INTO 'dancesstepsmap' VALUES (4452, 4813, 4);
INSERT INTO 'dancesstepsmap' VALUES (4453, 4814, 4);
INSERT INTO 'dancesstepsmap' VALUES (4454, 4815, 1);
INSERT INTO 'dancesstepsmap' VALUES (4455, 4816, 4);
INSERT INTO 'dancesstepsmap' VALUES (4456, 4817, 1);
INSERT INTO 'dancesstepsmap' VALUES (4457, 4818, 1);
INSERT INTO 'dancesstepsmap' VALUES (4458, 4820, 4);
INSERT INTO 'dancesstepsmap' VALUES (4459, 4821, 4);
INSERT INTO 'dancesstepsmap' VALUES (4460, 4822, 1);
INSERT INTO 'dancesstepsmap' VALUES (4461, 4823, 4);
INSERT INTO 'dancesstepsmap' VALUES (4462, 4824, 1);
INSERT INTO 'dancesstepsmap' VALUES (4463, 4825, 1);
INSERT INTO 'dancesstepsmap' VALUES (4464, 4826, 1);
INSERT INTO 'dancesstepsmap' VALUES (4465, 4827, 1);
INSERT INTO 'dancesstepsmap' VALUES (4466, 4828, 4);
INSERT INTO 'dancesstepsmap' VALUES (4467, 4830, 4);
INSERT INTO 'dancesstepsmap' VALUES (4468, 4831, 4);
INSERT INTO 'dancesstepsmap' VALUES (4469, 4832, 1);
INSERT INTO 'dancesstepsmap' VALUES (4470, 4833, 4);
INSERT INTO 'dancesstepsmap' VALUES (4471, 4834, 4);
INSERT INTO 'dancesstepsmap' VALUES (4472, 4835, 1);
INSERT INTO 'dancesstepsmap' VALUES (23144, 2725, 5);
INSERT INTO 'dancesstepsmap' VALUES (4474, 4837, 1);
INSERT INTO 'dancesstepsmap' VALUES (4475, 4838, 1);
INSERT INTO 'dancesstepsmap' VALUES (4476, 4839, 1);
INSERT INTO 'dancesstepsmap' VALUES (4477, 4840, 1);
INSERT INTO 'dancesstepsmap' VALUES (4478, 4841, 1);
INSERT INTO 'dancesstepsmap' VALUES (4479, 4843, 1);
INSERT INTO 'dancesstepsmap' VALUES (4480, 4844, 1);
INSERT INTO 'dancesstepsmap' VALUES (4481, 4845, 4);
INSERT INTO 'dancesstepsmap' VALUES (4482, 4846, 4);
INSERT INTO 'dancesstepsmap' VALUES (4483, 4848, 1);
INSERT INTO 'dancesstepsmap' VALUES (4484, 4849, 4);
INSERT INTO 'dancesstepsmap' VALUES (4485, 4850, 1);
INSERT INTO 'dancesstepsmap' VALUES (4486, 4851, 4);
INSERT INTO 'dancesstepsmap' VALUES (4487, 4852, 1);
INSERT INTO 'dancesstepsmap' VALUES (4488, 4853, 4);
INSERT INTO 'dancesstepsmap' VALUES (4489, 4854, 1);
INSERT INTO 'dancesstepsmap' VALUES (4490, 4855, 1);
INSERT INTO 'dancesstepsmap' VALUES (4491, 4856, 1);
INSERT INTO 'dancesstepsmap' VALUES (4492, 4857, 4);
INSERT INTO 'dancesstepsmap' VALUES (4493, 4858, 1);
INSERT INTO 'dancesstepsmap' VALUES (4494, 4860, 1);
INSERT INTO 'dancesstepsmap' VALUES (4495, 4861, 1);
INSERT INTO 'dancesstepsmap' VALUES (4496, 4862, 1);
INSERT INTO 'dancesstepsmap' VALUES (4497, 4863, 1);
INSERT INTO 'dancesstepsmap' VALUES (4498, 4864, 1);
INSERT INTO 'dancesstepsmap' VALUES (4499, 4865, 4);
INSERT INTO 'dancesstepsmap' VALUES (4500, 4866, 4);
INSERT INTO 'dancesstepsmap' VALUES (4501, 4867, 1);
INSERT INTO 'dancesstepsmap' VALUES (4502, 4868, 1);
INSERT INTO 'dancesstepsmap' VALUES (4503, 4869, 4);
INSERT INTO 'dancesstepsmap' VALUES (4504, 4870, 1);
INSERT INTO 'dancesstepsmap' VALUES (4505, 4871, 1);
INSERT INTO 'dancesstepsmap' VALUES (4506, 4872, 1);
INSERT INTO 'dancesstepsmap' VALUES (4507, 4873, 1);
INSERT INTO 'dancesstepsmap' VALUES (4508, 4874, 1);
INSERT INTO 'dancesstepsmap' VALUES (4509, 4875, 1);
INSERT INTO 'dancesstepsmap' VALUES (4510, 4876, 4);
INSERT INTO 'dancesstepsmap' VALUES (4511, 4877, 1);
INSERT INTO 'dancesstepsmap' VALUES (4512, 4878, 1);
INSERT INTO 'dancesstepsmap' VALUES (4513, 4879, 1);
INSERT INTO 'dancesstepsmap' VALUES (4514, 4880, 1);
INSERT INTO 'dancesstepsmap' VALUES (4515, 4881, 1);
INSERT INTO 'dancesstepsmap' VALUES (4516, 4882, 1);
INSERT INTO 'dancesstepsmap' VALUES (4517, 4883, 4);
INSERT INTO 'dancesstepsmap' VALUES (4518, 4884, 1);
INSERT INTO 'dancesstepsmap' VALUES (4519, 4885, 4);
INSERT INTO 'dancesstepsmap' VALUES (4520, 4886, 1);
INSERT INTO 'dancesstepsmap' VALUES (4521, 4887, 4);
INSERT INTO 'dancesstepsmap' VALUES (4522, 4888, 1);
INSERT INTO 'dancesstepsmap' VALUES (4523, 4889, 1);
INSERT INTO 'dancesstepsmap' VALUES (4524, 4890, 4);
INSERT INTO 'dancesstepsmap' VALUES (4525, 4891, 4);
INSERT INTO 'dancesstepsmap' VALUES (4526, 4892, 1);
INSERT INTO 'dancesstepsmap' VALUES (4527, 4893, 1);
INSERT INTO 'dancesstepsmap' VALUES (4528, 4894, 1);
INSERT INTO 'dancesstepsmap' VALUES (4529, 4895, 4);
INSERT INTO 'dancesstepsmap' VALUES (4530, 4896, 4);
INSERT INTO 'dancesstepsmap' VALUES (4531, 4897, 1);
INSERT INTO 'dancesstepsmap' VALUES (4532, 4898, 4);
INSERT INTO 'dancesstepsmap' VALUES (4533, 4899, 4);
INSERT INTO 'dancesstepsmap' VALUES (4534, 4900, 1);
INSERT INTO 'dancesstepsmap' VALUES (4535, 4901, 1);
INSERT INTO 'dancesstepsmap' VALUES (4536, 4902, 1);
INSERT INTO 'dancesstepsmap' VALUES (4537, 4903, 1);
INSERT INTO 'dancesstepsmap' VALUES (4538, 4905, 1);
INSERT INTO 'dancesstepsmap' VALUES (4539, 4906, 1);
INSERT INTO 'dancesstepsmap' VALUES (4540, 4907, 4);
INSERT INTO 'dancesstepsmap' VALUES (4541, 4908, 1);
INSERT INTO 'dancesstepsmap' VALUES (4542, 4909, 1);
INSERT INTO 'dancesstepsmap' VALUES (4543, 4910, 1);
INSERT INTO 'dancesstepsmap' VALUES (4544, 4911, 1);
INSERT INTO 'dancesstepsmap' VALUES (4545, 4912, 1);
INSERT INTO 'dancesstepsmap' VALUES (4546, 4913, 1);
INSERT INTO 'dancesstepsmap' VALUES (4547, 4915, 1);
INSERT INTO 'dancesstepsmap' VALUES (4548, 4916, 4);
INSERT INTO 'dancesstepsmap' VALUES (4549, 4917, 1);
INSERT INTO 'dancesstepsmap' VALUES (4550, 4918, 1);
INSERT INTO 'dancesstepsmap' VALUES (4551, 4919, 1);
INSERT INTO 'dancesstepsmap' VALUES (4552, 4920, 1);
INSERT INTO 'dancesstepsmap' VALUES (11668, 10492, 4);
INSERT INTO 'dancesstepsmap' VALUES (11669, 10494, 2);
INSERT INTO 'dancesstepsmap' VALUES (11670, 10494, 1);
INSERT INTO 'dancesstepsmap' VALUES (11671, 9440, 1);
INSERT INTO 'dancesstepsmap' VALUES (11672, 9437, 2);
INSERT INTO 'dancesstepsmap' VALUES (11673, 9437, 1);
INSERT INTO 'dancesstepsmap' VALUES (11674, 9442, 5);
INSERT INTO 'dancesstepsmap' VALUES (11675, 9442, 4);
INSERT INTO 'dancesstepsmap' VALUES (11676, 9444, 1);
INSERT INTO 'dancesstepsmap' VALUES (11677, 9444, 3);
INSERT INTO 'dancesstepsmap' VALUES (11678, 9445, 4);
INSERT INTO 'dancesstepsmap' VALUES (11679, 9445, 5);
INSERT INTO 'dancesstepsmap' VALUES (11680, 9451, 5);
INSERT INTO 'dancesstepsmap' VALUES (11681, 9451, 4);
INSERT INTO 'dancesstepsmap' VALUES (11682, 10496, 4);
INSERT INTO 'dancesstepsmap' VALUES (11683, 10498, 4);
INSERT INTO 'dancesstepsmap' VALUES (4553, 4921, 1);
INSERT INTO 'dancesstepsmap' VALUES (4554, 4922, 1);
INSERT INTO 'dancesstepsmap' VALUES (4555, 4923, 1);
INSERT INTO 'dancesstepsmap' VALUES (4556, 4924, 1);
INSERT INTO 'dancesstepsmap' VALUES (4557, 4925, 4);
INSERT INTO 'dancesstepsmap' VALUES (4558, 4926, 1);
INSERT INTO 'dancesstepsmap' VALUES (4559, 4927, 1);
INSERT INTO 'dancesstepsmap' VALUES (4560, 4928, 1);
INSERT INTO 'dancesstepsmap' VALUES (4561, 4929, 1);
INSERT INTO 'dancesstepsmap' VALUES (4562, 4930, 1);
INSERT INTO 'dancesstepsmap' VALUES (4563, 4931, 4);
INSERT INTO 'dancesstepsmap' VALUES (4564, 4932, 4);
INSERT INTO 'dancesstepsmap' VALUES (4565, 4933, 1);
INSERT INTO 'dancesstepsmap' VALUES (4566, 4934, 1);
INSERT INTO 'dancesstepsmap' VALUES (4567, 4935, 1);
INSERT INTO 'dancesstepsmap' VALUES (4568, 4938, 1);
INSERT INTO 'dancesstepsmap' VALUES (4569, 4939, 4);
INSERT INTO 'dancesstepsmap' VALUES (4570, 4940, 1);
INSERT INTO 'dancesstepsmap' VALUES (4571, 4941, 1);
INSERT INTO 'dancesstepsmap' VALUES (4572, 4942, 1);
INSERT INTO 'dancesstepsmap' VALUES (4573, 4943, 1);
INSERT INTO 'dancesstepsmap' VALUES (4574, 4944, 1);
INSERT INTO 'dancesstepsmap' VALUES (4575, 4945, 4);
INSERT INTO 'dancesstepsmap' VALUES (4576, 4946, 1);
INSERT INTO 'dancesstepsmap' VALUES (4577, 4947, 1);
INSERT INTO 'dancesstepsmap' VALUES (4578, 4948, 1);
INSERT INTO 'dancesstepsmap' VALUES (4579, 4949, 1);
INSERT INTO 'dancesstepsmap' VALUES (4580, 4950, 4);
INSERT INTO 'dancesstepsmap' VALUES (4581, 4951, 1);
INSERT INTO 'dancesstepsmap' VALUES (4582, 4952, 1);
INSERT INTO 'dancesstepsmap' VALUES (4583, 4953, 1);
INSERT INTO 'dancesstepsmap' VALUES (4584, 4954, 1);
INSERT INTO 'dancesstepsmap' VALUES (4585, 4955, 1);
INSERT INTO 'dancesstepsmap' VALUES (4586, 4956, 1);
INSERT INTO 'dancesstepsmap' VALUES (4587, 4959, 1);
INSERT INTO 'dancesstepsmap' VALUES (4588, 4960, 4);
INSERT INTO 'dancesstepsmap' VALUES (4589, 4961, 1);
INSERT INTO 'dancesstepsmap' VALUES (4590, 4962, 1);
INSERT INTO 'dancesstepsmap' VALUES (4591, 4963, 1);
INSERT INTO 'dancesstepsmap' VALUES (4592, 4964, 1);
INSERT INTO 'dancesstepsmap' VALUES (4593, 4965, 1);
INSERT INTO 'dancesstepsmap' VALUES (4594, 4966, 4);
INSERT INTO 'dancesstepsmap' VALUES (4595, 4968, 1);
INSERT INTO 'dancesstepsmap' VALUES (4596, 4969, 1);
INSERT INTO 'dancesstepsmap' VALUES (4597, 4970, 1);
INSERT INTO 'dancesstepsmap' VALUES (4598, 4971, 4);
INSERT INTO 'dancesstepsmap' VALUES (4599, 4972, 4);
INSERT INTO 'dancesstepsmap' VALUES (4600, 4973, 4);
INSERT INTO 'dancesstepsmap' VALUES (4601, 4974, 1);
INSERT INTO 'dancesstepsmap' VALUES (4602, 4975, 1);
INSERT INTO 'dancesstepsmap' VALUES (4603, 4976, 4);
INSERT INTO 'dancesstepsmap' VALUES (4604, 4977, 1);
INSERT INTO 'dancesstepsmap' VALUES (4605, 4978, 1);
INSERT INTO 'dancesstepsmap' VALUES (4606, 4979, 1);
INSERT INTO 'dancesstepsmap' VALUES (4607, 4981, 1);
INSERT INTO 'dancesstepsmap' VALUES (4608, 4982, 1);
INSERT INTO 'dancesstepsmap' VALUES (4609, 4983, 4);
INSERT INTO 'dancesstepsmap' VALUES (4610, 4984, 4);
INSERT INTO 'dancesstepsmap' VALUES (4611, 4985, 1);
INSERT INTO 'dancesstepsmap' VALUES (4612, 4986, 4);
INSERT INTO 'dancesstepsmap' VALUES (4613, 4988, 4);
INSERT INTO 'dancesstepsmap' VALUES (4614, 4989, 1);
INSERT INTO 'dancesstepsmap' VALUES (4615, 4990, 4);
INSERT INTO 'dancesstepsmap' VALUES (4616, 4991, 4);
INSERT INTO 'dancesstepsmap' VALUES (4617, 4992, 4);
INSERT INTO 'dancesstepsmap' VALUES (4618, 4993, 1);
INSERT INTO 'dancesstepsmap' VALUES (4619, 4994, 4);
INSERT INTO 'dancesstepsmap' VALUES (4620, 4995, 1);
INSERT INTO 'dancesstepsmap' VALUES (4621, 4996, 1);
INSERT INTO 'dancesstepsmap' VALUES (4622, 4997, 4);
INSERT INTO 'dancesstepsmap' VALUES (4623, 4998, 1);
INSERT INTO 'dancesstepsmap' VALUES (4624, 4999, 1);
INSERT INTO 'dancesstepsmap' VALUES (4625, 5000, 4);
INSERT INTO 'dancesstepsmap' VALUES (4626, 5001, 4);
INSERT INTO 'dancesstepsmap' VALUES (4627, 5002, 4);
INSERT INTO 'dancesstepsmap' VALUES (4628, 5003, 4);
INSERT INTO 'dancesstepsmap' VALUES (4629, 5004, 1);
INSERT INTO 'dancesstepsmap' VALUES (4630, 5005, 2);
INSERT INTO 'dancesstepsmap' VALUES (4631, 5006, 1);
INSERT INTO 'dancesstepsmap' VALUES (4632, 5007, 1);
INSERT INTO 'dancesstepsmap' VALUES (4633, 5008, 1);
INSERT INTO 'dancesstepsmap' VALUES (4634, 5009, 1);
INSERT INTO 'dancesstepsmap' VALUES (4635, 5010, 1);
INSERT INTO 'dancesstepsmap' VALUES (4636, 5011, 4);
INSERT INTO 'dancesstepsmap' VALUES (4637, 5012, 1);
INSERT INTO 'dancesstepsmap' VALUES (4638, 5013, 1);
INSERT INTO 'dancesstepsmap' VALUES (4639, 5014, 1);
INSERT INTO 'dancesstepsmap' VALUES (4640, 5015, 1);
INSERT INTO 'dancesstepsmap' VALUES (4641, 5016, 1);
INSERT INTO 'dancesstepsmap' VALUES (4642, 5017, 1);
INSERT INTO 'dancesstepsmap' VALUES (4643, 5018, 1);
INSERT INTO 'dancesstepsmap' VALUES (4644, 5019, 4);
INSERT INTO 'dancesstepsmap' VALUES (11684, 10498, 5);
INSERT INTO 'dancesstepsmap' VALUES (11685, 10499, 1);
INSERT INTO 'dancesstepsmap' VALUES (11686, 7671, 1);
INSERT INTO 'dancesstepsmap' VALUES (11687, 8671, 1);
INSERT INTO 'dancesstepsmap' VALUES (11688, 8671, 2);
INSERT INTO 'dancesstepsmap' VALUES (11689, 10367, 2);
INSERT INTO 'dancesstepsmap' VALUES (11690, 10367, 1);
INSERT INTO 'dancesstepsmap' VALUES (11691, 10367, 3);
INSERT INTO 'dancesstepsmap' VALUES (11692, 8702, 5);
INSERT INTO 'dancesstepsmap' VALUES (11693, 9200, 1);
INSERT INTO 'dancesstepsmap' VALUES (11694, 9200, 2);
INSERT INTO 'dancesstepsmap' VALUES (11695, 10308, 2);
INSERT INTO 'dancesstepsmap' VALUES (11696, 10500, 4);
INSERT INTO 'dancesstepsmap' VALUES (11697, 10166, 1);
INSERT INTO 'dancesstepsmap' VALUES (11698, 359, 1);
INSERT INTO 'dancesstepsmap' VALUES (11699, 10501, 1);
INSERT INTO 'dancesstepsmap' VALUES (11700, 10501, 3);
INSERT INTO 'dancesstepsmap' VALUES (11701, 8842, 1);
INSERT INTO 'dancesstepsmap' VALUES (11702, 10300, 2);
INSERT INTO 'dancesstepsmap' VALUES (11703, 10300, 3);
INSERT INTO 'dancesstepsmap' VALUES (11704, 6259, 2);
INSERT INTO 'dancesstepsmap' VALUES (11705, 1873, 5);
INSERT INTO 'dancesstepsmap' VALUES (11706, 10502, 1);
INSERT INTO 'dancesstepsmap' VALUES (11709, 10504, 4);
INSERT INTO 'dancesstepsmap' VALUES (11710, 10505, 3);
INSERT INTO 'dancesstepsmap' VALUES (11711, 10505, 1);
INSERT INTO 'dancesstepsmap' VALUES (11712, 10506, 1);
INSERT INTO 'dancesstepsmap' VALUES (11713, 10506, 2);
INSERT INTO 'dancesstepsmap' VALUES (11714, 10507, 1);
INSERT INTO 'dancesstepsmap' VALUES (11715, 8386, 3);
INSERT INTO 'dancesstepsmap' VALUES (11716, 10508, 4);
INSERT INTO 'dancesstepsmap' VALUES (11717, 8846, 1);
INSERT INTO 'dancesstepsmap' VALUES (11718, 10509, 1);
INSERT INTO 'dancesstepsmap' VALUES (11719, 9231, 3);
INSERT INTO 'dancesstepsmap' VALUES (11720, 9231, 1);
INSERT INTO 'dancesstepsmap' VALUES (11721, 7657, 3);
INSERT INTO 'dancesstepsmap' VALUES (11722, 1390, 3);
INSERT INTO 'dancesstepsmap' VALUES (11723, 8946, 1);
INSERT INTO 'dancesstepsmap' VALUES (11724, 8946, 2);
INSERT INTO 'dancesstepsmap' VALUES (11725, 10510, 3);
INSERT INTO 'dancesstepsmap' VALUES (17209, 902, 2);
INSERT INTO 'dancesstepsmap' VALUES (17210, 7173, 2);
INSERT INTO 'dancesstepsmap' VALUES (17211, 10796, 5);
INSERT INTO 'dancesstepsmap' VALUES (17212, 14597, 2);
INSERT INTO 'dancesstepsmap' VALUES (17213, 14597, 1);
INSERT INTO 'dancesstepsmap' VALUES (17214, 14597, 3);
INSERT INTO 'dancesstepsmap' VALUES (17215, 14597, 5);
INSERT INTO 'dancesstepsmap' VALUES (17216, 14597, 4);
INSERT INTO 'dancesstepsmap' VALUES (17217, 9124, 2);
INSERT INTO 'dancesstepsmap' VALUES (17218, 11797, 1);
INSERT INTO 'dancesstepsmap' VALUES (17219, 2645, 5);
INSERT INTO 'dancesstepsmap' VALUES (17220, 14598, 4);
INSERT INTO 'dancesstepsmap' VALUES (17221, 14598, 5);
INSERT INTO 'dancesstepsmap' VALUES (17222, 14599, 5);
INSERT INTO 'dancesstepsmap' VALUES (17223, 14599, 4);
INSERT INTO 'dancesstepsmap' VALUES (17224, 14458, 1);
INSERT INTO 'dancesstepsmap' VALUES (17225, 14458, 2);
INSERT INTO 'dancesstepsmap' VALUES (17226, 12309, 1);
INSERT INTO 'dancesstepsmap' VALUES (17227, 12309, 2);
INSERT INTO 'dancesstepsmap' VALUES (17228, 7045, 2);
INSERT INTO 'dancesstepsmap' VALUES (17229, 10655, 5);
INSERT INTO 'dancesstepsmap' VALUES (17230, 14602, 2);
INSERT INTO 'dancesstepsmap' VALUES (17231, 14602, 1);
INSERT INTO 'dancesstepsmap' VALUES (4645, 5020, 1);
INSERT INTO 'dancesstepsmap' VALUES (4646, 5021, 4);
INSERT INTO 'dancesstepsmap' VALUES (4647, 5022, 4);
INSERT INTO 'dancesstepsmap' VALUES (4648, 5023, 1);
INSERT INTO 'dancesstepsmap' VALUES (4649, 5024, 1);
INSERT INTO 'dancesstepsmap' VALUES (4650, 5026, 1);
INSERT INTO 'dancesstepsmap' VALUES (4651, 5027, 4);
INSERT INTO 'dancesstepsmap' VALUES (4652, 5028, 4);
INSERT INTO 'dancesstepsmap' VALUES (4653, 5029, 4);
INSERT INTO 'dancesstepsmap' VALUES (4654, 5030, 4);
INSERT INTO 'dancesstepsmap' VALUES (4655, 5031, 1);
INSERT INTO 'dancesstepsmap' VALUES (4656, 5032, 1);
INSERT INTO 'dancesstepsmap' VALUES (4657, 5033, 1);
INSERT INTO 'dancesstepsmap' VALUES (4658, 5034, 1);
INSERT INTO 'dancesstepsmap' VALUES (4659, 5035, 1);
INSERT INTO 'dancesstepsmap' VALUES (4660, 5037, 4);
INSERT INTO 'dancesstepsmap' VALUES (4661, 5038, 1);
INSERT INTO 'dancesstepsmap' VALUES (4662, 5039, 4);
INSERT INTO 'dancesstepsmap' VALUES (4663, 5040, 1);
INSERT INTO 'dancesstepsmap' VALUES (4664, 5041, 4);
INSERT INTO 'dancesstepsmap' VALUES (4665, 5042, 1);
INSERT INTO 'dancesstepsmap' VALUES (4666, 5043, 1);
INSERT INTO 'dancesstepsmap' VALUES (4667, 5044, 4);
INSERT INTO 'dancesstepsmap' VALUES (4668, 5045, 4);
INSERT INTO 'dancesstepsmap' VALUES (4669, 5046, 1);
INSERT INTO 'dancesstepsmap' VALUES (4670, 5047, 4);
INSERT INTO 'dancesstepsmap' VALUES (4671, 5048, 1);
INSERT INTO 'dancesstepsmap' VALUES (4672, 5050, 1);
INSERT INTO 'dancesstepsmap' VALUES (4673, 5051, 1);
INSERT INTO 'dancesstepsmap' VALUES (4674, 5052, 4);
INSERT INTO 'dancesstepsmap' VALUES (4675, 5053, 1);
INSERT INTO 'dancesstepsmap' VALUES (4676, 5054, 1);
INSERT INTO 'dancesstepsmap' VALUES (4677, 5057, 1);
INSERT INTO 'dancesstepsmap' VALUES (4678, 5058, 1);
INSERT INTO 'dancesstepsmap' VALUES (4679, 5059, 1);
INSERT INTO 'dancesstepsmap' VALUES (4680, 5060, 4);
INSERT INTO 'dancesstepsmap' VALUES (4681, 5061, 1);
INSERT INTO 'dancesstepsmap' VALUES (4682, 5062, 1);
INSERT INTO 'dancesstepsmap' VALUES (4683, 5063, 1);
INSERT INTO 'dancesstepsmap' VALUES (4684, 5064, 1);
INSERT INTO 'dancesstepsmap' VALUES (4685, 5065, 1);
INSERT INTO 'dancesstepsmap' VALUES (4686, 5066, 1);
INSERT INTO 'dancesstepsmap' VALUES (4687, 5067, 4);
INSERT INTO 'dancesstepsmap' VALUES (4688, 5068, 1);
INSERT INTO 'dancesstepsmap' VALUES (4689, 5069, 1);
INSERT INTO 'dancesstepsmap' VALUES (4690, 5070, 4);
INSERT INTO 'dancesstepsmap' VALUES (4691, 5071, 1);
INSERT INTO 'dancesstepsmap' VALUES (4692, 5072, 1);
INSERT INTO 'dancesstepsmap' VALUES (4693, 5073, 4);
INSERT INTO 'dancesstepsmap' VALUES (4694, 5074, 4);
INSERT INTO 'dancesstepsmap' VALUES (4695, 5075, 4);
INSERT INTO 'dancesstepsmap' VALUES (4696, 5077, 1);
INSERT INTO 'dancesstepsmap' VALUES (4697, 5078, 4);
INSERT INTO 'dancesstepsmap' VALUES (4698, 5079, 1);
INSERT INTO 'dancesstepsmap' VALUES (4699, 5080, 1);
INSERT INTO 'dancesstepsmap' VALUES (4700, 5082, 1);
INSERT INTO 'dancesstepsmap' VALUES (4701, 5083, 1);
INSERT INTO 'dancesstepsmap' VALUES (4702, 5084, 1);
INSERT INTO 'dancesstepsmap' VALUES (4703, 5085, 1);
INSERT INTO 'dancesstepsmap' VALUES (4704, 5086, 4);
INSERT INTO 'dancesstepsmap' VALUES (4705, 5087, 1);
INSERT INTO 'dancesstepsmap' VALUES (4706, 5088, 1);
INSERT INTO 'dancesstepsmap' VALUES (4707, 5089, 4);
INSERT INTO 'dancesstepsmap' VALUES (4708, 5090, 1);
INSERT INTO 'dancesstepsmap' VALUES (4709, 5091, 1);
INSERT INTO 'dancesstepsmap' VALUES (4710, 5092, 1);
INSERT INTO 'dancesstepsmap' VALUES (4711, 5093, 1);
INSERT INTO 'dancesstepsmap' VALUES (4712, 5094, 1);
INSERT INTO 'dancesstepsmap' VALUES (4713, 5095, 1);
INSERT INTO 'dancesstepsmap' VALUES (4714, 5096, 1);
INSERT INTO 'dancesstepsmap' VALUES (4715, 5097, 1);
INSERT INTO 'dancesstepsmap' VALUES (4716, 5098, 1);
INSERT INTO 'dancesstepsmap' VALUES (4717, 5099, 1);
INSERT INTO 'dancesstepsmap' VALUES (4718, 5101, 1);
INSERT INTO 'dancesstepsmap' VALUES (4719, 5102, 1);
INSERT INTO 'dancesstepsmap' VALUES (4720, 5103, 4);
INSERT INTO 'dancesstepsmap' VALUES (4721, 5104, 4);
INSERT INTO 'dancesstepsmap' VALUES (4722, 5105, 4);
INSERT INTO 'dancesstepsmap' VALUES (4723, 5106, 1);
INSERT INTO 'dancesstepsmap' VALUES (4724, 5107, 1);
INSERT INTO 'dancesstepsmap' VALUES (4725, 5108, 1);
INSERT INTO 'dancesstepsmap' VALUES (4726, 5110, 4);
INSERT INTO 'dancesstepsmap' VALUES (4727, 5111, 4);
INSERT INTO 'dancesstepsmap' VALUES (4728, 5113, 1);
INSERT INTO 'dancesstepsmap' VALUES (4729, 5114, 4);
INSERT INTO 'dancesstepsmap' VALUES (4730, 5115, 1);
INSERT INTO 'dancesstepsmap' VALUES (4731, 5116, 1);
INSERT INTO 'dancesstepsmap' VALUES (4732, 5117, 4);
INSERT INTO 'dancesstepsmap' VALUES (4733, 5118, 1);
INSERT INTO 'dancesstepsmap' VALUES (4734, 5119, 1);
INSERT INTO 'dancesstepsmap' VALUES (4735, 5120, 4);
INSERT INTO 'dancesstepsmap' VALUES (4736, 5121, 1);
INSERT INTO 'dancesstepsmap' VALUES (4737, 5122, 4);
INSERT INTO 'dancesstepsmap' VALUES (11726, 10511, 2);
INSERT INTO 'dancesstepsmap' VALUES (11727, 10512, 1);
INSERT INTO 'dancesstepsmap' VALUES (11728, 3866, 3);
INSERT INTO 'dancesstepsmap' VALUES (11729, 10513, 1);
INSERT INTO 'dancesstepsmap' VALUES (11730, 10513, 2);
INSERT INTO 'dancesstepsmap' VALUES (11731, 9343, 4);
INSERT INTO 'dancesstepsmap' VALUES (11732, 10514, 1);
INSERT INTO 'dancesstepsmap' VALUES (11733, 10515, 1);
INSERT INTO 'dancesstepsmap' VALUES (11734, 8929, 4);
INSERT INTO 'dancesstepsmap' VALUES (11735, 8929, 5);
INSERT INTO 'dancesstepsmap' VALUES (11736, 8937, 1);
INSERT INTO 'dancesstepsmap' VALUES (11737, 8928, 3);
INSERT INTO 'dancesstepsmap' VALUES (11738, 8928, 1);
INSERT INTO 'dancesstepsmap' VALUES (11739, 8941, 1);
INSERT INTO 'dancesstepsmap' VALUES (11740, 8941, 2);
INSERT INTO 'dancesstepsmap' VALUES (11741, 8923, 2);
INSERT INTO 'dancesstepsmap' VALUES (11742, 8923, 1);
INSERT INTO 'dancesstepsmap' VALUES (11743, 8925, 4);
INSERT INTO 'dancesstepsmap' VALUES (11744, 8925, 5);
INSERT INTO 'dancesstepsmap' VALUES (11745, 10516, 1);
INSERT INTO 'dancesstepsmap' VALUES (11746, 10517, 1);
INSERT INTO 'dancesstepsmap' VALUES (11747, 10517, 2);
INSERT INTO 'dancesstepsmap' VALUES (11748, 10518, 4);
INSERT INTO 'dancesstepsmap' VALUES (11749, 10519, 1);
INSERT INTO 'dancesstepsmap' VALUES (11750, 7946, 3);
INSERT INTO 'dancesstepsmap' VALUES (11751, 10520, 1);
INSERT INTO 'dancesstepsmap' VALUES (11752, 10520, 2);
INSERT INTO 'dancesstepsmap' VALUES (11753, 10147, 1);
INSERT INTO 'dancesstepsmap' VALUES (11754, 10147, 3);
INSERT INTO 'dancesstepsmap' VALUES (11755, 10521, 1);
INSERT INTO 'dancesstepsmap' VALUES (11756, 10521, 2);
INSERT INTO 'dancesstepsmap' VALUES (11757, 10522, 4);
INSERT INTO 'dancesstepsmap' VALUES (11758, 10523, 4);
INSERT INTO 'dancesstepsmap' VALUES (11759, 10524, 1);
INSERT INTO 'dancesstepsmap' VALUES (11760, 10524, 3);
INSERT INTO 'dancesstepsmap' VALUES (11761, 10525, 4);
INSERT INTO 'dancesstepsmap' VALUES (11762, 10525, 5);
INSERT INTO 'dancesstepsmap' VALUES (11763, 9975, 5);
INSERT INTO 'dancesstepsmap' VALUES (11764, 10526, 1);
INSERT INTO 'dancesstepsmap' VALUES (11765, 10526, 3);
INSERT INTO 'dancesstepsmap' VALUES (11766, 10527, 1);
INSERT INTO 'dancesstepsmap' VALUES (11767, 10527, 3);
INSERT INTO 'dancesstepsmap' VALUES (17232, 14602, 3);
INSERT INTO 'dancesstepsmap' VALUES (4738, 5123, 1);
INSERT INTO 'dancesstepsmap' VALUES (4739, 5124, 1);
INSERT INTO 'dancesstepsmap' VALUES (4740, 5125, 4);
INSERT INTO 'dancesstepsmap' VALUES (4741, 5126, 1);
INSERT INTO 'dancesstepsmap' VALUES (4742, 5127, 1);
INSERT INTO 'dancesstepsmap' VALUES (4743, 5128, 1);
INSERT INTO 'dancesstepsmap' VALUES (4744, 5129, 1);
INSERT INTO 'dancesstepsmap' VALUES (4745, 5130, 1);
INSERT INTO 'dancesstepsmap' VALUES (4746, 5131, 1);
INSERT INTO 'dancesstepsmap' VALUES (4747, 5132, 1);
INSERT INTO 'dancesstepsmap' VALUES (4748, 5133, 1);
INSERT INTO 'dancesstepsmap' VALUES (4749, 5134, 4);
INSERT INTO 'dancesstepsmap' VALUES (4750, 5135, 1);
INSERT INTO 'dancesstepsmap' VALUES (4751, 5136, 1);
INSERT INTO 'dancesstepsmap' VALUES (4752, 5137, 4);
INSERT INTO 'dancesstepsmap' VALUES (4753, 5138, 1);
INSERT INTO 'dancesstepsmap' VALUES (4754, 5139, 1);
INSERT INTO 'dancesstepsmap' VALUES (4755, 5140, 4);
INSERT INTO 'dancesstepsmap' VALUES (4756, 5141, 4);
INSERT INTO 'dancesstepsmap' VALUES (4757, 5142, 1);
INSERT INTO 'dancesstepsmap' VALUES (4758, 5143, 1);
INSERT INTO 'dancesstepsmap' VALUES (4759, 5144, 1);
INSERT INTO 'dancesstepsmap' VALUES (4760, 5146, 1);
INSERT INTO 'dancesstepsmap' VALUES (4761, 5147, 1);
INSERT INTO 'dancesstepsmap' VALUES (4762, 5148, 1);
INSERT INTO 'dancesstepsmap' VALUES (4763, 5149, 1);
INSERT INTO 'dancesstepsmap' VALUES (4764, 5150, 1);
INSERT INTO 'dancesstepsmap' VALUES (4765, 5151, 1);
INSERT INTO 'dancesstepsmap' VALUES (4766, 5152, 4);
INSERT INTO 'dancesstepsmap' VALUES (4767, 5153, 1);
INSERT INTO 'dancesstepsmap' VALUES (4768, 5154, 1);
INSERT INTO 'dancesstepsmap' VALUES (4769, 5155, 1);
INSERT INTO 'dancesstepsmap' VALUES (4770, 5157, 1);
INSERT INTO 'dancesstepsmap' VALUES (4771, 5158, 4);
INSERT INTO 'dancesstepsmap' VALUES (4772, 5159, 4);
INSERT INTO 'dancesstepsmap' VALUES (4773, 5160, 1);
INSERT INTO 'dancesstepsmap' VALUES (4774, 5161, 1);
INSERT INTO 'dancesstepsmap' VALUES (4775, 5162, 1);
INSERT INTO 'dancesstepsmap' VALUES (4776, 5163, 1);
INSERT INTO 'dancesstepsmap' VALUES (4777, 5164, 1);
INSERT INTO 'dancesstepsmap' VALUES (4778, 5165, 4);
INSERT INTO 'dancesstepsmap' VALUES (4779, 5166, 1);
INSERT INTO 'dancesstepsmap' VALUES (4780, 5167, 4);
INSERT INTO 'dancesstepsmap' VALUES (4781, 5168, 4);
INSERT INTO 'dancesstepsmap' VALUES (4782, 5169, 4);
INSERT INTO 'dancesstepsmap' VALUES (4783, 5170, 4);
INSERT INTO 'dancesstepsmap' VALUES (4784, 5172, 1);
INSERT INTO 'dancesstepsmap' VALUES (4785, 5173, 1);
INSERT INTO 'dancesstepsmap' VALUES (4786, 5174, 1);
INSERT INTO 'dancesstepsmap' VALUES (4787, 5175, 1);
INSERT INTO 'dancesstepsmap' VALUES (4788, 5176, 4);
INSERT INTO 'dancesstepsmap' VALUES (4789, 5177, 1);
INSERT INTO 'dancesstepsmap' VALUES (4790, 5178, 1);
INSERT INTO 'dancesstepsmap' VALUES (4791, 5179, 1);
INSERT INTO 'dancesstepsmap' VALUES (4792, 5180, 1);
INSERT INTO 'dancesstepsmap' VALUES (4793, 5181, 1);
INSERT INTO 'dancesstepsmap' VALUES (4794, 5182, 1);
INSERT INTO 'dancesstepsmap' VALUES (4795, 5183, 1);
INSERT INTO 'dancesstepsmap' VALUES (4796, 5184, 4);
INSERT INTO 'dancesstepsmap' VALUES (4797, 5186, 1);
INSERT INTO 'dancesstepsmap' VALUES (4798, 5187, 1);
INSERT INTO 'dancesstepsmap' VALUES (4799, 5188, 1);
INSERT INTO 'dancesstepsmap' VALUES (4800, 5189, 1);
INSERT INTO 'dancesstepsmap' VALUES (4801, 5190, 4);
INSERT INTO 'dancesstepsmap' VALUES (4802, 5191, 1);
INSERT INTO 'dancesstepsmap' VALUES (4803, 5192, 4);
INSERT INTO 'dancesstepsmap' VALUES (4804, 5194, 1);
INSERT INTO 'dancesstepsmap' VALUES (4805, 5195, 4);
INSERT INTO 'dancesstepsmap' VALUES (4806, 5196, 4);
INSERT INTO 'dancesstepsmap' VALUES (4807, 5197, 1);
INSERT INTO 'dancesstepsmap' VALUES (4808, 5198, 1);
INSERT INTO 'dancesstepsmap' VALUES (4809, 5199, 1);
INSERT INTO 'dancesstepsmap' VALUES (4810, 5200, 1);
INSERT INTO 'dancesstepsmap' VALUES (4811, 5201, 1);
INSERT INTO 'dancesstepsmap' VALUES (4812, 5202, 4);
INSERT INTO 'dancesstepsmap' VALUES (4813, 5203, 1);
INSERT INTO 'dancesstepsmap' VALUES (4814, 5204, 1);
INSERT INTO 'dancesstepsmap' VALUES (4815, 5205, 1);
INSERT INTO 'dancesstepsmap' VALUES (4816, 5206, 4);
INSERT INTO 'dancesstepsmap' VALUES (4817, 5207, 4);
INSERT INTO 'dancesstepsmap' VALUES (4818, 5208, 1);
INSERT INTO 'dancesstepsmap' VALUES (4819, 5209, 1);
INSERT INTO 'dancesstepsmap' VALUES (4820, 5210, 1);
INSERT INTO 'dancesstepsmap' VALUES (4821, 5211, 1);
INSERT INTO 'dancesstepsmap' VALUES (4822, 5212, 1);
INSERT INTO 'dancesstepsmap' VALUES (4823, 5213, 1);
INSERT INTO 'dancesstepsmap' VALUES (4824, 5214, 4);
INSERT INTO 'dancesstepsmap' VALUES (4825, 5215, 1);
INSERT INTO 'dancesstepsmap' VALUES (4826, 5216, 1);
INSERT INTO 'dancesstepsmap' VALUES (4827, 5217, 1);
INSERT INTO 'dancesstepsmap' VALUES (4828, 5218, 1);
INSERT INTO 'dancesstepsmap' VALUES (4829, 5219, 1);
INSERT INTO 'dancesstepsmap' VALUES (11768, 10528, 2);
INSERT INTO 'dancesstepsmap' VALUES (11769, 2359, 5);
INSERT INTO 'dancesstepsmap' VALUES (11770, 10529, 1);
INSERT INTO 'dancesstepsmap' VALUES (11771, 10529, 2);
INSERT INTO 'dancesstepsmap' VALUES (11772, 10529, 4);
INSERT INTO 'dancesstepsmap' VALUES (11773, 10529, 5);
INSERT INTO 'dancesstepsmap' VALUES (11774, 10530, 2);
INSERT INTO 'dancesstepsmap' VALUES (11775, 2580, 2);
INSERT INTO 'dancesstepsmap' VALUES (11776, 10537, 4);
INSERT INTO 'dancesstepsmap' VALUES (11777, 10537, 5);
INSERT INTO 'dancesstepsmap' VALUES (11778, 10538, 1);
INSERT INTO 'dancesstepsmap' VALUES (11779, 10539, 1);
INSERT INTO 'dancesstepsmap' VALUES (11780, 10540, 1);
INSERT INTO 'dancesstepsmap' VALUES (11781, 10540, 2);
INSERT INTO 'dancesstepsmap' VALUES (11782, 10541, 4);
INSERT INTO 'dancesstepsmap' VALUES (11783, 10541, 5);
INSERT INTO 'dancesstepsmap' VALUES (11784, 10542, 1);
INSERT INTO 'dancesstepsmap' VALUES (11785, 10542, 2);
INSERT INTO 'dancesstepsmap' VALUES (11786, 10543, 4);
INSERT INTO 'dancesstepsmap' VALUES (11787, 10545, 4);
INSERT INTO 'dancesstepsmap' VALUES (11788, 9564, 2);
INSERT INTO 'dancesstepsmap' VALUES (11789, 10553, 1);
INSERT INTO 'dancesstepsmap' VALUES (11790, 10555, 2);
INSERT INTO 'dancesstepsmap' VALUES (11791, 10555, 1);
INSERT INTO 'dancesstepsmap' VALUES (11792, 10556, 2);
INSERT INTO 'dancesstepsmap' VALUES (11793, 10556, 3);
INSERT INTO 'dancesstepsmap' VALUES (11794, 10556, 1);
INSERT INTO 'dancesstepsmap' VALUES (11795, 10557, 1);
INSERT INTO 'dancesstepsmap' VALUES (11796, 10557, 2);
INSERT INTO 'dancesstepsmap' VALUES (11797, 10557, 3);
INSERT INTO 'dancesstepsmap' VALUES (11798, 10558, 4);
INSERT INTO 'dancesstepsmap' VALUES (11801, 10560, 1);
INSERT INTO 'dancesstepsmap' VALUES (11802, 10561, 1);
INSERT INTO 'dancesstepsmap' VALUES (11803, 10562, 1);
INSERT INTO 'dancesstepsmap' VALUES (11804, 10563, 1);
INSERT INTO 'dancesstepsmap' VALUES (11805, 10563, 3);
INSERT INTO 'dancesstepsmap' VALUES (11806, 10564, 1);
INSERT INTO 'dancesstepsmap' VALUES (11807, 10564, 2);
INSERT INTO 'dancesstepsmap' VALUES (11808, 10565, 1);
INSERT INTO 'dancesstepsmap' VALUES (11809, 10565, 2);
INSERT INTO 'dancesstepsmap' VALUES (11810, 10566, 4);
INSERT INTO 'dancesstepsmap' VALUES (11811, 10567, 1);
INSERT INTO 'dancesstepsmap' VALUES (11812, 10568, 1);
INSERT INTO 'dancesstepsmap' VALUES (17233, 7457, 2);
INSERT INTO 'dancesstepsmap' VALUES (17234, 7457, 3);
INSERT INTO 'dancesstepsmap' VALUES (17235, 14603, 1);
INSERT INTO 'dancesstepsmap' VALUES (17236, 14603, 2);
INSERT INTO 'dancesstepsmap' VALUES (17237, 13613, 4);
INSERT INTO 'dancesstepsmap' VALUES (17238, 13613, 5);
INSERT INTO 'dancesstepsmap' VALUES (17239, 12243, 2);
INSERT INTO 'dancesstepsmap' VALUES (17240, 14604, 1);
INSERT INTO 'dancesstepsmap' VALUES (17241, 14604, 2);
INSERT INTO 'dancesstepsmap' VALUES (17242, 14604, 3);
INSERT INTO 'dancesstepsmap' VALUES (17243, 7629, 5);
INSERT INTO 'dancesstepsmap' VALUES (17244, 14605, 4);
INSERT INTO 'dancesstepsmap' VALUES (17245, 14605, 5);
INSERT INTO 'dancesstepsmap' VALUES (17246, 14606, 1);
INSERT INTO 'dancesstepsmap' VALUES (17247, 14606, 2);
INSERT INTO 'dancesstepsmap' VALUES (17248, 14606, 3);
INSERT INTO 'dancesstepsmap' VALUES (17249, 14607, 2);
INSERT INTO 'dancesstepsmap' VALUES (17250, 14607, 1);
INSERT INTO 'dancesstepsmap' VALUES (17251, 14621, 1);
INSERT INTO 'dancesstepsmap' VALUES (17252, 14621, 2);
INSERT INTO 'dancesstepsmap' VALUES (17253, 14621, 3);
INSERT INTO 'dancesstepsmap' VALUES (17256, 13149, 5);
INSERT INTO 'dancesstepsmap' VALUES (4830, 5220, 1);
INSERT INTO 'dancesstepsmap' VALUES (4831, 5221, 1);
INSERT INTO 'dancesstepsmap' VALUES (4832, 5223, 4);
INSERT INTO 'dancesstepsmap' VALUES (4833, 5224, 4);
INSERT INTO 'dancesstepsmap' VALUES (4834, 5225, 1);
INSERT INTO 'dancesstepsmap' VALUES (4835, 5227, 4);
INSERT INTO 'dancesstepsmap' VALUES (4836, 5228, 1);
INSERT INTO 'dancesstepsmap' VALUES (4837, 5229, 1);
INSERT INTO 'dancesstepsmap' VALUES (4838, 5230, 1);
INSERT INTO 'dancesstepsmap' VALUES (4839, 5231, 1);
INSERT INTO 'dancesstepsmap' VALUES (4840, 5232, 4);
INSERT INTO 'dancesstepsmap' VALUES (4841, 5234, 1);
INSERT INTO 'dancesstepsmap' VALUES (4842, 5235, 1);
INSERT INTO 'dancesstepsmap' VALUES (4843, 5236, 1);
INSERT INTO 'dancesstepsmap' VALUES (4844, 5237, 1);
INSERT INTO 'dancesstepsmap' VALUES (4845, 5238, 1);
INSERT INTO 'dancesstepsmap' VALUES (4846, 5239, 1);
INSERT INTO 'dancesstepsmap' VALUES (4847, 5240, 1);
INSERT INTO 'dancesstepsmap' VALUES (4848, 5241, 1);
INSERT INTO 'dancesstepsmap' VALUES (4849, 5242, 1);
INSERT INTO 'dancesstepsmap' VALUES (4850, 5243, 1);
INSERT INTO 'dancesstepsmap' VALUES (4851, 5244, 4);
INSERT INTO 'dancesstepsmap' VALUES (4852, 5245, 4);
INSERT INTO 'dancesstepsmap' VALUES (4853, 5246, 1);
INSERT INTO 'dancesstepsmap' VALUES (4854, 5247, 1);
INSERT INTO 'dancesstepsmap' VALUES (4855, 5248, 4);
INSERT INTO 'dancesstepsmap' VALUES (4856, 5249, 4);
INSERT INTO 'dancesstepsmap' VALUES (4857, 5250, 4);
INSERT INTO 'dancesstepsmap' VALUES (4858, 5251, 4);
INSERT INTO 'dancesstepsmap' VALUES (4859, 5252, 1);
INSERT INTO 'dancesstepsmap' VALUES (4860, 5253, 1);
INSERT INTO 'dancesstepsmap' VALUES (4861, 5254, 1);
INSERT INTO 'dancesstepsmap' VALUES (4862, 5255, 1);
INSERT INTO 'dancesstepsmap' VALUES (4863, 5256, 1);
INSERT INTO 'dancesstepsmap' VALUES (4864, 5257, 1);
INSERT INTO 'dancesstepsmap' VALUES (4865, 5258, 1);
INSERT INTO 'dancesstepsmap' VALUES (4866, 5259, 4);
INSERT INTO 'dancesstepsmap' VALUES (4867, 5260, 1);
INSERT INTO 'dancesstepsmap' VALUES (4868, 5261, 4);
INSERT INTO 'dancesstepsmap' VALUES (4869, 5262, 1);
INSERT INTO 'dancesstepsmap' VALUES (4870, 5263, 4);
INSERT INTO 'dancesstepsmap' VALUES (4871, 5264, 1);
INSERT INTO 'dancesstepsmap' VALUES (4872, 5265, 1);
INSERT INTO 'dancesstepsmap' VALUES (4873, 5266, 1);
INSERT INTO 'dancesstepsmap' VALUES (4874, 5267, 1);
INSERT INTO 'dancesstepsmap' VALUES (4875, 5268, 1);
INSERT INTO 'dancesstepsmap' VALUES (4876, 5269, 1);
INSERT INTO 'dancesstepsmap' VALUES (4877, 5270, 1);
INSERT INTO 'dancesstepsmap' VALUES (4878, 5271, 4);
INSERT INTO 'dancesstepsmap' VALUES (4879, 5272, 4);
INSERT INTO 'dancesstepsmap' VALUES (4880, 5273, 4);
INSERT INTO 'dancesstepsmap' VALUES (4881, 5274, 1);
INSERT INTO 'dancesstepsmap' VALUES (4882, 5275, 1);
INSERT INTO 'dancesstepsmap' VALUES (4883, 5276, 4);
INSERT INTO 'dancesstepsmap' VALUES (4884, 5277, 4);
INSERT INTO 'dancesstepsmap' VALUES (4885, 5278, 1);
INSERT INTO 'dancesstepsmap' VALUES (4886, 5279, 4);
INSERT INTO 'dancesstepsmap' VALUES (4887, 5280, 1);
INSERT INTO 'dancesstepsmap' VALUES (4888, 5281, 1);
INSERT INTO 'dancesstepsmap' VALUES (4889, 5282, 1);
INSERT INTO 'dancesstepsmap' VALUES (4890, 5284, 1);
INSERT INTO 'dancesstepsmap' VALUES (4891, 5285, 4);
INSERT INTO 'dancesstepsmap' VALUES (4892, 5287, 1);
INSERT INTO 'dancesstepsmap' VALUES (4893, 5288, 1);
INSERT INTO 'dancesstepsmap' VALUES (4894, 5289, 1);
INSERT INTO 'dancesstepsmap' VALUES (4895, 5290, 4);
INSERT INTO 'dancesstepsmap' VALUES (4896, 5291, 1);
INSERT INTO 'dancesstepsmap' VALUES (4897, 5293, 4);
INSERT INTO 'dancesstepsmap' VALUES (4898, 5294, 4);
INSERT INTO 'dancesstepsmap' VALUES (4899, 5295, 1);
INSERT INTO 'dancesstepsmap' VALUES (4900, 5296, 1);
INSERT INTO 'dancesstepsmap' VALUES (4901, 5297, 1);
INSERT INTO 'dancesstepsmap' VALUES (4902, 5298, 1);
INSERT INTO 'dancesstepsmap' VALUES (4903, 5299, 1);
INSERT INTO 'dancesstepsmap' VALUES (4904, 5300, 1);
INSERT INTO 'dancesstepsmap' VALUES (4905, 5301, 4);
INSERT INTO 'dancesstepsmap' VALUES (4906, 5302, 1);
INSERT INTO 'dancesstepsmap' VALUES (4907, 5303, 4);
INSERT INTO 'dancesstepsmap' VALUES (4908, 5304, 1);
INSERT INTO 'dancesstepsmap' VALUES (4909, 5305, 1);
INSERT INTO 'dancesstepsmap' VALUES (4910, 5306, 1);
INSERT INTO 'dancesstepsmap' VALUES (4911, 5307, 4);
INSERT INTO 'dancesstepsmap' VALUES (4912, 5308, 1);
INSERT INTO 'dancesstepsmap' VALUES (4913, 5309, 4);
INSERT INTO 'dancesstepsmap' VALUES (4914, 5310, 1);
INSERT INTO 'dancesstepsmap' VALUES (4915, 5311, 1);
INSERT INTO 'dancesstepsmap' VALUES (4916, 5312, 1);
INSERT INTO 'dancesstepsmap' VALUES (4917, 5313, 4);
INSERT INTO 'dancesstepsmap' VALUES (4918, 5314, 4);
INSERT INTO 'dancesstepsmap' VALUES (4919, 5315, 1);
INSERT INTO 'dancesstepsmap' VALUES (4920, 5316, 4);
INSERT INTO 'dancesstepsmap' VALUES (4921, 5317, 1);
INSERT INTO 'dancesstepsmap' VALUES (4922, 5318, 4);
INSERT INTO 'dancesstepsmap' VALUES (11813, 9539, 10);
INSERT INTO 'dancesstepsmap' VALUES (11814, 9539, 1);
INSERT INTO 'dancesstepsmap' VALUES (11815, 10569, 1);
INSERT INTO 'dancesstepsmap' VALUES (11816, 10569, 2);
INSERT INTO 'dancesstepsmap' VALUES (11817, 10570, 10);
INSERT INTO 'dancesstepsmap' VALUES (11818, 10570, 1);
INSERT INTO 'dancesstepsmap' VALUES (11819, 10570, 2);
INSERT INTO 'dancesstepsmap' VALUES (11820, 10570, 3);
INSERT INTO 'dancesstepsmap' VALUES (11821, 10571, 2);
INSERT INTO 'dancesstepsmap' VALUES (11822, 10571, 3);
INSERT INTO 'dancesstepsmap' VALUES (11823, 10572, 3);
INSERT INTO 'dancesstepsmap' VALUES (11824, 10572, 1);
INSERT INTO 'dancesstepsmap' VALUES (11828, 10574, 1);
INSERT INTO 'dancesstepsmap' VALUES (11829, 10575, 1);
INSERT INTO 'dancesstepsmap' VALUES (11830, 10575, 2);
INSERT INTO 'dancesstepsmap' VALUES (11831, 10576, 1);
INSERT INTO 'dancesstepsmap' VALUES (11832, 10577, 2);
INSERT INTO 'dancesstepsmap' VALUES (11833, 10578, 5);
INSERT INTO 'dancesstepsmap' VALUES (11834, 10578, 4);
INSERT INTO 'dancesstepsmap' VALUES (11835, 10579, 1);
INSERT INTO 'dancesstepsmap' VALUES (11836, 10580, 5);
INSERT INTO 'dancesstepsmap' VALUES (11838, 10580, 4);
INSERT INTO 'dancesstepsmap' VALUES (11839, 10580, 1);
INSERT INTO 'dancesstepsmap' VALUES (11840, 10581, 4);
INSERT INTO 'dancesstepsmap' VALUES (11841, 6678, 5);
INSERT INTO 'dancesstepsmap' VALUES (11842, 10582, 1);
INSERT INTO 'dancesstepsmap' VALUES (11843, 10582, 2);
INSERT INTO 'dancesstepsmap' VALUES (11844, 10583, 4);
INSERT INTO 'dancesstepsmap' VALUES (11845, 10583, 5);
INSERT INTO 'dancesstepsmap' VALUES (11846, 10585, 1);
INSERT INTO 'dancesstepsmap' VALUES (11847, 10585, 2);
INSERT INTO 'dancesstepsmap' VALUES (11848, 7970, 5);
INSERT INTO 'dancesstepsmap' VALUES (11849, 10586, 1);
INSERT INTO 'dancesstepsmap' VALUES (11850, 10586, 2);
INSERT INTO 'dancesstepsmap' VALUES (11851, 8345, 5);
INSERT INTO 'dancesstepsmap' VALUES (11852, 8347, 2);
INSERT INTO 'dancesstepsmap' VALUES (11853, 8349, 2);
INSERT INTO 'dancesstepsmap' VALUES (11854, 8351, 2);
INSERT INTO 'dancesstepsmap' VALUES (11855, 8351, 3);
INSERT INTO 'dancesstepsmap' VALUES (11856, 8356, 3);
INSERT INTO 'dancesstepsmap' VALUES (11857, 8356, 2);
INSERT INTO 'dancesstepsmap' VALUES (17254, 14621, 4);
INSERT INTO 'dancesstepsmap' VALUES (17255, 14621, 5);
INSERT INTO 'dancesstepsmap' VALUES (17257, 14622, 4);
INSERT INTO 'dancesstepsmap' VALUES (17258, 14622, 5);
INSERT INTO 'dancesstepsmap' VALUES (4923, 5319, 1);
INSERT INTO 'dancesstepsmap' VALUES (4924, 5320, 4);
INSERT INTO 'dancesstepsmap' VALUES (4925, 5321, 1);
INSERT INTO 'dancesstepsmap' VALUES (4926, 5322, 4);
INSERT INTO 'dancesstepsmap' VALUES (4927, 5323, 4);
INSERT INTO 'dancesstepsmap' VALUES (4928, 5325, 4);
INSERT INTO 'dancesstepsmap' VALUES (4929, 5326, 1);
INSERT INTO 'dancesstepsmap' VALUES (4930, 5327, 2);
INSERT INTO 'dancesstepsmap' VALUES (4931, 5328, 1);
INSERT INTO 'dancesstepsmap' VALUES (4932, 5329, 1);
INSERT INTO 'dancesstepsmap' VALUES (4933, 5330, 1);
INSERT INTO 'dancesstepsmap' VALUES (4934, 5331, 1);
INSERT INTO 'dancesstepsmap' VALUES (4935, 5333, 4);
INSERT INTO 'dancesstepsmap' VALUES (4936, 5334, 1);
INSERT INTO 'dancesstepsmap' VALUES (4937, 5335, 1);
INSERT INTO 'dancesstepsmap' VALUES (4938, 5336, 1);
INSERT INTO 'dancesstepsmap' VALUES (4939, 5337, 1);
INSERT INTO 'dancesstepsmap' VALUES (4940, 5338, 1);
INSERT INTO 'dancesstepsmap' VALUES (4941, 5339, 1);
INSERT INTO 'dancesstepsmap' VALUES (4942, 5340, 4);
INSERT INTO 'dancesstepsmap' VALUES (4943, 5342, 1);
INSERT INTO 'dancesstepsmap' VALUES (4944, 5343, 1);
INSERT INTO 'dancesstepsmap' VALUES (4945, 5344, 1);
INSERT INTO 'dancesstepsmap' VALUES (4946, 5345, 4);
INSERT INTO 'dancesstepsmap' VALUES (4947, 5346, 1);
INSERT INTO 'dancesstepsmap' VALUES (4948, 5347, 4);
INSERT INTO 'dancesstepsmap' VALUES (4949, 5348, 1);
INSERT INTO 'dancesstepsmap' VALUES (4950, 5349, 4);
INSERT INTO 'dancesstepsmap' VALUES (4951, 5350, 1);
INSERT INTO 'dancesstepsmap' VALUES (4952, 5351, 1);
INSERT INTO 'dancesstepsmap' VALUES (4953, 5353, 4);
INSERT INTO 'dancesstepsmap' VALUES (4954, 5354, 1);
INSERT INTO 'dancesstepsmap' VALUES (4955, 5355, 1);
INSERT INTO 'dancesstepsmap' VALUES (4956, 5356, 1);
INSERT INTO 'dancesstepsmap' VALUES (4957, 5357, 1);
INSERT INTO 'dancesstepsmap' VALUES (4958, 5358, 1);
INSERT INTO 'dancesstepsmap' VALUES (4959, 5359, 4);
INSERT INTO 'dancesstepsmap' VALUES (4960, 5360, 1);
INSERT INTO 'dancesstepsmap' VALUES (4961, 5362, 1);
INSERT INTO 'dancesstepsmap' VALUES (4962, 5363, 1);
INSERT INTO 'dancesstepsmap' VALUES (4963, 5364, 4);
INSERT INTO 'dancesstepsmap' VALUES (4964, 5366, 4);
INSERT INTO 'dancesstepsmap' VALUES (4965, 5367, 1);
INSERT INTO 'dancesstepsmap' VALUES (4966, 5369, 1);
INSERT INTO 'dancesstepsmap' VALUES (4967, 5370, 4);
INSERT INTO 'dancesstepsmap' VALUES (4968, 5372, 1);
INSERT INTO 'dancesstepsmap' VALUES (4969, 5373, 1);
INSERT INTO 'dancesstepsmap' VALUES (4970, 5374, 4);
INSERT INTO 'dancesstepsmap' VALUES (4972, 5376, 1);
INSERT INTO 'dancesstepsmap' VALUES (4973, 5377, 1);
INSERT INTO 'dancesstepsmap' VALUES (4974, 5378, 4);
INSERT INTO 'dancesstepsmap' VALUES (4975, 5379, 4);
INSERT INTO 'dancesstepsmap' VALUES (4976, 5380, 4);
INSERT INTO 'dancesstepsmap' VALUES (4977, 5381, 1);
INSERT INTO 'dancesstepsmap' VALUES (4978, 5382, 1);
INSERT INTO 'dancesstepsmap' VALUES (4979, 5384, 1);
INSERT INTO 'dancesstepsmap' VALUES (4980, 5385, 1);
INSERT INTO 'dancesstepsmap' VALUES (4981, 5386, 1);
INSERT INTO 'dancesstepsmap' VALUES (4982, 5387, 4);
INSERT INTO 'dancesstepsmap' VALUES (4983, 5388, 4);
INSERT INTO 'dancesstepsmap' VALUES (4984, 5389, 1);
INSERT INTO 'dancesstepsmap' VALUES (4985, 5390, 1);
INSERT INTO 'dancesstepsmap' VALUES (4986, 5392, 1);
INSERT INTO 'dancesstepsmap' VALUES (4987, 5393, 4);
INSERT INTO 'dancesstepsmap' VALUES (4988, 5394, 1);
INSERT INTO 'dancesstepsmap' VALUES (4989, 5395, 1);
INSERT INTO 'dancesstepsmap' VALUES (4990, 5396, 1);
INSERT INTO 'dancesstepsmap' VALUES (4991, 5397, 1);
INSERT INTO 'dancesstepsmap' VALUES (4992, 5398, 1);
INSERT INTO 'dancesstepsmap' VALUES (4993, 5399, 1);
INSERT INTO 'dancesstepsmap' VALUES (4994, 5400, 1);
INSERT INTO 'dancesstepsmap' VALUES (4995, 5401, 4);
INSERT INTO 'dancesstepsmap' VALUES (4996, 5402, 1);
INSERT INTO 'dancesstepsmap' VALUES (4997, 5403, 4);
INSERT INTO 'dancesstepsmap' VALUES (4998, 5404, 1);
INSERT INTO 'dancesstepsmap' VALUES (4999, 5405, 1);
INSERT INTO 'dancesstepsmap' VALUES (5000, 5406, 1);
INSERT INTO 'dancesstepsmap' VALUES (5001, 5407, 1);
INSERT INTO 'dancesstepsmap' VALUES (5002, 5408, 1);
INSERT INTO 'dancesstepsmap' VALUES (5003, 5409, 1);
INSERT INTO 'dancesstepsmap' VALUES (5004, 5410, 4);
INSERT INTO 'dancesstepsmap' VALUES (5005, 5411, 1);
INSERT INTO 'dancesstepsmap' VALUES (5006, 5413, 4);
INSERT INTO 'dancesstepsmap' VALUES (5007, 5414, 4);
INSERT INTO 'dancesstepsmap' VALUES (5008, 5416, 4);
INSERT INTO 'dancesstepsmap' VALUES (5009, 5418, 4);
INSERT INTO 'dancesstepsmap' VALUES (5010, 5419, 1);
INSERT INTO 'dancesstepsmap' VALUES (5011, 5420, 1);
INSERT INTO 'dancesstepsmap' VALUES (5012, 5421, 1);
INSERT INTO 'dancesstepsmap' VALUES (5013, 5423, 4);
INSERT INTO 'dancesstepsmap' VALUES (5014, 5424, 1);
INSERT INTO 'dancesstepsmap' VALUES (5015, 5425, 1);
INSERT INTO 'dancesstepsmap' VALUES (5016, 5426, 1);
INSERT INTO 'dancesstepsmap' VALUES (5017, 5427, 1);
INSERT INTO 'dancesstepsmap' VALUES (5018, 5428, 1);
INSERT INTO 'dancesstepsmap' VALUES (5019, 5430, 4);
INSERT INTO 'dancesstepsmap' VALUES (5020, 5431, 1);
INSERT INTO 'dancesstepsmap' VALUES (5021, 5432, 4);
INSERT INTO 'dancesstepsmap' VALUES (5022, 5434, 1);
INSERT INTO 'dancesstepsmap' VALUES (5023, 5435, 4);
INSERT INTO 'dancesstepsmap' VALUES (5024, 5436, 1);
INSERT INTO 'dancesstepsmap' VALUES (5025, 5437, 4);
INSERT INTO 'dancesstepsmap' VALUES (5026, 5438, 1);
INSERT INTO 'dancesstepsmap' VALUES (5027, 5439, 1);
INSERT INTO 'dancesstepsmap' VALUES (5028, 5441, 4);
INSERT INTO 'dancesstepsmap' VALUES (5029, 5442, 4);
INSERT INTO 'dancesstepsmap' VALUES (5030, 5443, 1);
INSERT INTO 'dancesstepsmap' VALUES (5031, 5444, 1);
INSERT INTO 'dancesstepsmap' VALUES (5032, 5445, 4);
INSERT INTO 'dancesstepsmap' VALUES (5033, 5446, 1);
INSERT INTO 'dancesstepsmap' VALUES (5034, 5447, 1);
INSERT INTO 'dancesstepsmap' VALUES (5035, 5448, 1);
INSERT INTO 'dancesstepsmap' VALUES (5036, 5449, 1);
INSERT INTO 'dancesstepsmap' VALUES (5037, 5450, 1);
INSERT INTO 'dancesstepsmap' VALUES (5038, 5452, 1);
INSERT INTO 'dancesstepsmap' VALUES (5039, 5453, 4);
INSERT INTO 'dancesstepsmap' VALUES (5040, 5454, 1);
INSERT INTO 'dancesstepsmap' VALUES (5041, 5455, 4);
INSERT INTO 'dancesstepsmap' VALUES (5042, 5456, 4);
INSERT INTO 'dancesstepsmap' VALUES (5043, 5457, 1);
INSERT INTO 'dancesstepsmap' VALUES (5044, 5460, 4);
INSERT INTO 'dancesstepsmap' VALUES (5045, 5461, 1);
INSERT INTO 'dancesstepsmap' VALUES (5046, 5462, 4);
INSERT INTO 'dancesstepsmap' VALUES (5047, 5463, 1);
INSERT INTO 'dancesstepsmap' VALUES (5048, 5464, 4);
INSERT INTO 'dancesstepsmap' VALUES (5049, 5465, 1);
INSERT INTO 'dancesstepsmap' VALUES (5050, 5466, 1);
INSERT INTO 'dancesstepsmap' VALUES (5051, 5467, 4);
INSERT INTO 'dancesstepsmap' VALUES (5052, 5468, 1);
INSERT INTO 'dancesstepsmap' VALUES (11858, 8357, 5);
INSERT INTO 'dancesstepsmap' VALUES (11859, 8361, 6);
INSERT INTO 'dancesstepsmap' VALUES (11860, 8362, 6);
INSERT INTO 'dancesstepsmap' VALUES (11861, 8362, 5);
INSERT INTO 'dancesstepsmap' VALUES (11862, 8364, 3);
INSERT INTO 'dancesstepsmap' VALUES (11863, 8369, 5);
INSERT INTO 'dancesstepsmap' VALUES (11864, 8352, 6);
INSERT INTO 'dancesstepsmap' VALUES (11865, 10600, 1);
INSERT INTO 'dancesstepsmap' VALUES (11866, 10600, 3);
INSERT INTO 'dancesstepsmap' VALUES (11867, 10601, 4);
INSERT INTO 'dancesstepsmap' VALUES (11868, 10602, 3);
INSERT INTO 'dancesstepsmap' VALUES (11869, 10602, 1);
INSERT INTO 'dancesstepsmap' VALUES (11870, 10640, 2);
INSERT INTO 'dancesstepsmap' VALUES (11871, 10640, 1);
INSERT INTO 'dancesstepsmap' VALUES (11872, 9193, 1);
INSERT INTO 'dancesstepsmap' VALUES (17259, 14623, 1);
INSERT INTO 'dancesstepsmap' VALUES (5053, 5469, 4);
INSERT INTO 'dancesstepsmap' VALUES (5054, 5471, 1);
INSERT INTO 'dancesstepsmap' VALUES (5055, 5472, 4);
INSERT INTO 'dancesstepsmap' VALUES (5056, 5473, 4);
INSERT INTO 'dancesstepsmap' VALUES (5057, 5474, 4);
INSERT INTO 'dancesstepsmap' VALUES (5058, 5475, 1);
INSERT INTO 'dancesstepsmap' VALUES (5059, 5476, 1);
INSERT INTO 'dancesstepsmap' VALUES (5060, 5477, 1);
INSERT INTO 'dancesstepsmap' VALUES (5061, 5478, 4);
INSERT INTO 'dancesstepsmap' VALUES (5062, 5479, 1);
INSERT INTO 'dancesstepsmap' VALUES (5063, 5480, 1);
INSERT INTO 'dancesstepsmap' VALUES (5064, 5482, 1);
INSERT INTO 'dancesstepsmap' VALUES (5065, 5483, 4);
INSERT INTO 'dancesstepsmap' VALUES (5066, 5486, 1);
INSERT INTO 'dancesstepsmap' VALUES (5067, 5488, 1);
INSERT INTO 'dancesstepsmap' VALUES (5068, 5489, 1);
INSERT INTO 'dancesstepsmap' VALUES (5069, 5491, 1);
INSERT INTO 'dancesstepsmap' VALUES (5070, 5492, 1);
INSERT INTO 'dancesstepsmap' VALUES (5071, 5493, 1);
INSERT INTO 'dancesstepsmap' VALUES (5072, 5494, 1);
INSERT INTO 'dancesstepsmap' VALUES (5073, 5495, 4);
INSERT INTO 'dancesstepsmap' VALUES (5074, 5496, 1);
INSERT INTO 'dancesstepsmap' VALUES (5075, 5497, 1);
INSERT INTO 'dancesstepsmap' VALUES (5076, 5498, 1);
INSERT INTO 'dancesstepsmap' VALUES (5077, 5499, 1);
INSERT INTO 'dancesstepsmap' VALUES (5078, 5500, 4);
INSERT INTO 'dancesstepsmap' VALUES (5079, 5501, 4);
INSERT INTO 'dancesstepsmap' VALUES (5080, 5502, 1);
INSERT INTO 'dancesstepsmap' VALUES (5081, 5503, 1);
INSERT INTO 'dancesstepsmap' VALUES (5082, 5504, 4);
INSERT INTO 'dancesstepsmap' VALUES (5083, 5505, 1);
INSERT INTO 'dancesstepsmap' VALUES (5084, 5506, 1);
INSERT INTO 'dancesstepsmap' VALUES (5085, 5507, 4);
INSERT INTO 'dancesstepsmap' VALUES (5086, 5508, 1);
INSERT INTO 'dancesstepsmap' VALUES (5087, 5509, 1);
INSERT INTO 'dancesstepsmap' VALUES (5088, 5510, 1);
INSERT INTO 'dancesstepsmap' VALUES (5089, 5511, 1);
INSERT INTO 'dancesstepsmap' VALUES (5090, 5512, 1);
INSERT INTO 'dancesstepsmap' VALUES (5091, 5513, 1);
INSERT INTO 'dancesstepsmap' VALUES (5092, 5514, 1);
INSERT INTO 'dancesstepsmap' VALUES (5093, 5515, 1);
INSERT INTO 'dancesstepsmap' VALUES (5094, 5516, 1);
INSERT INTO 'dancesstepsmap' VALUES (5095, 5517, 1);
INSERT INTO 'dancesstepsmap' VALUES (5096, 5518, 1);
INSERT INTO 'dancesstepsmap' VALUES (5097, 5520, 4);
INSERT INTO 'dancesstepsmap' VALUES (5098, 5521, 1);
INSERT INTO 'dancesstepsmap' VALUES (5099, 5522, 1);
INSERT INTO 'dancesstepsmap' VALUES (5100, 5523, 1);
INSERT INTO 'dancesstepsmap' VALUES (5101, 5525, 1);
INSERT INTO 'dancesstepsmap' VALUES (5102, 5526, 1);
INSERT INTO 'dancesstepsmap' VALUES (5103, 5528, 1);
INSERT INTO 'dancesstepsmap' VALUES (5104, 5529, 1);
INSERT INTO 'dancesstepsmap' VALUES (5105, 5530, 1);
INSERT INTO 'dancesstepsmap' VALUES (5106, 5531, 1);
INSERT INTO 'dancesstepsmap' VALUES (5107, 5533, 1);
INSERT INTO 'dancesstepsmap' VALUES (5108, 5534, 1);
INSERT INTO 'dancesstepsmap' VALUES (5109, 5535, 1);
INSERT INTO 'dancesstepsmap' VALUES (5110, 5536, 4);
INSERT INTO 'dancesstepsmap' VALUES (5111, 5537, 1);
INSERT INTO 'dancesstepsmap' VALUES (5112, 5538, 1);
INSERT INTO 'dancesstepsmap' VALUES (5113, 5539, 1);
INSERT INTO 'dancesstepsmap' VALUES (5114, 5540, 1);
INSERT INTO 'dancesstepsmap' VALUES (5115, 5541, 1);
INSERT INTO 'dancesstepsmap' VALUES (5116, 5542, 1);
INSERT INTO 'dancesstepsmap' VALUES (5117, 5543, 1);
INSERT INTO 'dancesstepsmap' VALUES (5118, 5544, 1);
INSERT INTO 'dancesstepsmap' VALUES (5119, 5545, 1);
INSERT INTO 'dancesstepsmap' VALUES (5120, 5546, 1);
INSERT INTO 'dancesstepsmap' VALUES (5121, 5547, 1);
INSERT INTO 'dancesstepsmap' VALUES (5122, 5548, 1);
INSERT INTO 'dancesstepsmap' VALUES (5123, 5549, 1);
INSERT INTO 'dancesstepsmap' VALUES (5124, 5550, 1);
INSERT INTO 'dancesstepsmap' VALUES (5125, 5551, 1);
INSERT INTO 'dancesstepsmap' VALUES (5126, 5552, 1);
INSERT INTO 'dancesstepsmap' VALUES (5127, 5553, 1);
INSERT INTO 'dancesstepsmap' VALUES (5128, 5554, 1);
INSERT INTO 'dancesstepsmap' VALUES (5129, 5555, 1);
INSERT INTO 'dancesstepsmap' VALUES (5130, 5556, 4);
INSERT INTO 'dancesstepsmap' VALUES (5131, 5557, 1);
INSERT INTO 'dancesstepsmap' VALUES (5132, 5558, 1);
INSERT INTO 'dancesstepsmap' VALUES (5133, 5559, 1);
INSERT INTO 'dancesstepsmap' VALUES (5134, 5560, 4);
INSERT INTO 'dancesstepsmap' VALUES (5135, 5561, 4);
INSERT INTO 'dancesstepsmap' VALUES (5136, 5562, 1);
INSERT INTO 'dancesstepsmap' VALUES (5137, 5563, 4);
INSERT INTO 'dancesstepsmap' VALUES (5138, 5564, 1);
INSERT INTO 'dancesstepsmap' VALUES (5139, 5566, 1);
INSERT INTO 'dancesstepsmap' VALUES (5140, 5567, 1);
INSERT INTO 'dancesstepsmap' VALUES (5141, 5568, 1);
INSERT INTO 'dancesstepsmap' VALUES (5142, 5569, 1);
INSERT INTO 'dancesstepsmap' VALUES (5143, 5570, 4);
INSERT INTO 'dancesstepsmap' VALUES (5144, 5571, 4);
INSERT INTO 'dancesstepsmap' VALUES (11873, 9193, 3);
INSERT INTO 'dancesstepsmap' VALUES (11874, 10642, 1);
INSERT INTO 'dancesstepsmap' VALUES (11875, 10642, 2);
INSERT INTO 'dancesstepsmap' VALUES (11876, 10643, 1);
INSERT INTO 'dancesstepsmap' VALUES (11877, 10643, 3);
INSERT INTO 'dancesstepsmap' VALUES (11878, 10644, 4);
INSERT INTO 'dancesstepsmap' VALUES (11879, 10645, 1);
INSERT INTO 'dancesstepsmap' VALUES (11880, 10646, 4);
INSERT INTO 'dancesstepsmap' VALUES (11881, 9192, 1);
INSERT INTO 'dancesstepsmap' VALUES (11882, 10648, 1);
INSERT INTO 'dancesstepsmap' VALUES (11883, 10648, 3);
INSERT INTO 'dancesstepsmap' VALUES (11884, 9194, 1);
INSERT INTO 'dancesstepsmap' VALUES (11885, 9449, 5);
INSERT INTO 'dancesstepsmap' VALUES (11886, 9447, 2);
INSERT INTO 'dancesstepsmap' VALUES (11887, 10665, 1);
INSERT INTO 'dancesstepsmap' VALUES (11888, 10665, 2);
INSERT INTO 'dancesstepsmap' VALUES (11889, 10670, 1);
INSERT INTO 'dancesstepsmap' VALUES (11890, 10670, 2);
INSERT INTO 'dancesstepsmap' VALUES (11891, 10684, 1);
INSERT INTO 'dancesstepsmap' VALUES (11892, 10684, 2);
INSERT INTO 'dancesstepsmap' VALUES (23145, 6030, 3);
INSERT INTO 'dancesstepsmap' VALUES (23222, 18262, 2);
INSERT INTO 'dancesstepsmap' VALUES (11895, 10669, 4);
INSERT INTO 'dancesstepsmap' VALUES (11896, 10669, 5);
INSERT INTO 'dancesstepsmap' VALUES (11897, 10675, 2);
INSERT INTO 'dancesstepsmap' VALUES (11898, 10676, 2);
INSERT INTO 'dancesstepsmap' VALUES (11899, 10717, 1);
INSERT INTO 'dancesstepsmap' VALUES (11900, 10717, 2);
INSERT INTO 'dancesstepsmap' VALUES (11901, 10717, 5);
INSERT INTO 'dancesstepsmap' VALUES (11902, 10717, 4);
INSERT INTO 'dancesstepsmap' VALUES (11903, 10717, 3);
INSERT INTO 'dancesstepsmap' VALUES (11904, 10718, 3);
INSERT INTO 'dancesstepsmap' VALUES (11905, 10718, 1);
INSERT INTO 'dancesstepsmap' VALUES (11906, 10672, 2);
INSERT INTO 'dancesstepsmap' VALUES (11907, 10768, 5);
INSERT INTO 'dancesstepsmap' VALUES (11908, 10768, 4);
INSERT INTO 'dancesstepsmap' VALUES (11909, 10544, 2);
INSERT INTO 'dancesstepsmap' VALUES (11910, 10544, 1);
INSERT INTO 'dancesstepsmap' VALUES (11911, 10546, 4);
INSERT INTO 'dancesstepsmap' VALUES (11912, 10546, 1);
INSERT INTO 'dancesstepsmap' VALUES (11913, 10546, 3);
INSERT INTO 'dancesstepsmap' VALUES (11914, 10547, 4);
INSERT INTO 'dancesstepsmap' VALUES (11915, 10428, 2);
INSERT INTO 'dancesstepsmap' VALUES (17260, 14624, 2);
INSERT INTO 'dancesstepsmap' VALUES (17261, 14624, 1);
INSERT INTO 'dancesstepsmap' VALUES (5145, 5572, 1);
INSERT INTO 'dancesstepsmap' VALUES (5146, 5573, 1);
INSERT INTO 'dancesstepsmap' VALUES (5147, 5574, 1);
INSERT INTO 'dancesstepsmap' VALUES (5148, 5575, 1);
INSERT INTO 'dancesstepsmap' VALUES (5149, 5576, 1);
INSERT INTO 'dancesstepsmap' VALUES (5150, 5577, 1);
INSERT INTO 'dancesstepsmap' VALUES (5151, 5578, 1);
INSERT INTO 'dancesstepsmap' VALUES (5152, 5579, 1);
INSERT INTO 'dancesstepsmap' VALUES (5153, 5580, 4);
INSERT INTO 'dancesstepsmap' VALUES (5154, 5581, 1);
INSERT INTO 'dancesstepsmap' VALUES (5155, 5582, 4);
INSERT INTO 'dancesstepsmap' VALUES (5156, 5583, 1);
INSERT INTO 'dancesstepsmap' VALUES (5157, 5584, 1);
INSERT INTO 'dancesstepsmap' VALUES (5158, 5585, 1);
INSERT INTO 'dancesstepsmap' VALUES (5159, 5586, 4);
INSERT INTO 'dancesstepsmap' VALUES (5160, 5587, 1);
INSERT INTO 'dancesstepsmap' VALUES (5161, 5589, 1);
INSERT INTO 'dancesstepsmap' VALUES (5162, 5590, 4);
INSERT INTO 'dancesstepsmap' VALUES (5163, 5591, 1);
INSERT INTO 'dancesstepsmap' VALUES (5164, 5592, 4);
INSERT INTO 'dancesstepsmap' VALUES (5165, 5593, 4);
INSERT INTO 'dancesstepsmap' VALUES (5166, 5594, 4);
INSERT INTO 'dancesstepsmap' VALUES (5167, 5595, 1);
INSERT INTO 'dancesstepsmap' VALUES (5168, 5596, 1);
INSERT INTO 'dancesstepsmap' VALUES (5169, 5597, 4);
INSERT INTO 'dancesstepsmap' VALUES (5170, 5598, 4);
INSERT INTO 'dancesstepsmap' VALUES (5171, 5599, 4);
INSERT INTO 'dancesstepsmap' VALUES (5172, 5600, 4);
INSERT INTO 'dancesstepsmap' VALUES (5173, 5601, 1);
INSERT INTO 'dancesstepsmap' VALUES (5174, 5602, 1);
INSERT INTO 'dancesstepsmap' VALUES (5175, 5603, 1);
INSERT INTO 'dancesstepsmap' VALUES (5176, 5604, 1);
INSERT INTO 'dancesstepsmap' VALUES (5177, 5605, 4);
INSERT INTO 'dancesstepsmap' VALUES (5178, 5606, 4);
INSERT INTO 'dancesstepsmap' VALUES (5179, 5607, 1);
INSERT INTO 'dancesstepsmap' VALUES (5180, 5608, 4);
INSERT INTO 'dancesstepsmap' VALUES (5181, 5609, 4);
INSERT INTO 'dancesstepsmap' VALUES (5182, 5610, 4);
INSERT INTO 'dancesstepsmap' VALUES (5183, 5611, 1);
INSERT INTO 'dancesstepsmap' VALUES (5184, 5612, 4);
INSERT INTO 'dancesstepsmap' VALUES (5185, 5613, 1);
INSERT INTO 'dancesstepsmap' VALUES (5186, 5614, 1);
INSERT INTO 'dancesstepsmap' VALUES (5187, 5615, 1);
INSERT INTO 'dancesstepsmap' VALUES (5188, 5616, 4);
INSERT INTO 'dancesstepsmap' VALUES (5189, 5617, 1);
INSERT INTO 'dancesstepsmap' VALUES (5190, 5618, 4);
INSERT INTO 'dancesstepsmap' VALUES (5191, 5619, 1);
INSERT INTO 'dancesstepsmap' VALUES (5192, 5620, 4);
INSERT INTO 'dancesstepsmap' VALUES (5193, 5621, 1);
INSERT INTO 'dancesstepsmap' VALUES (5194, 5623, 1);
INSERT INTO 'dancesstepsmap' VALUES (5195, 5624, 4);
INSERT INTO 'dancesstepsmap' VALUES (5196, 5625, 1);
INSERT INTO 'dancesstepsmap' VALUES (5197, 5626, 1);
INSERT INTO 'dancesstepsmap' VALUES (5198, 5627, 1);
INSERT INTO 'dancesstepsmap' VALUES (5199, 5628, 1);
INSERT INTO 'dancesstepsmap' VALUES (5200, 5629, 4);
INSERT INTO 'dancesstepsmap' VALUES (5201, 5630, 4);
INSERT INTO 'dancesstepsmap' VALUES (5202, 5631, 4);
INSERT INTO 'dancesstepsmap' VALUES (5203, 5632, 4);
INSERT INTO 'dancesstepsmap' VALUES (5204, 5633, 1);
INSERT INTO 'dancesstepsmap' VALUES (5205, 5634, 1);
INSERT INTO 'dancesstepsmap' VALUES (5206, 5636, 1);
INSERT INTO 'dancesstepsmap' VALUES (5207, 5637, 4);
INSERT INTO 'dancesstepsmap' VALUES (5208, 5638, 4);
INSERT INTO 'dancesstepsmap' VALUES (5209, 5639, 4);
INSERT INTO 'dancesstepsmap' VALUES (5210, 5640, 4);
INSERT INTO 'dancesstepsmap' VALUES (5211, 5641, 1);
INSERT INTO 'dancesstepsmap' VALUES (5212, 5642, 1);
INSERT INTO 'dancesstepsmap' VALUES (5213, 5643, 1);
INSERT INTO 'dancesstepsmap' VALUES (5214, 5644, 4);
INSERT INTO 'dancesstepsmap' VALUES (5215, 5645, 1);
INSERT INTO 'dancesstepsmap' VALUES (5216, 5646, 1);
INSERT INTO 'dancesstepsmap' VALUES (5217, 5647, 1);
INSERT INTO 'dancesstepsmap' VALUES (5218, 5648, 1);
INSERT INTO 'dancesstepsmap' VALUES (5219, 5649, 1);
INSERT INTO 'dancesstepsmap' VALUES (5220, 5650, 1);
INSERT INTO 'dancesstepsmap' VALUES (5221, 5651, 1);
INSERT INTO 'dancesstepsmap' VALUES (5222, 5652, 1);
INSERT INTO 'dancesstepsmap' VALUES (5223, 5653, 1);
INSERT INTO 'dancesstepsmap' VALUES (5224, 5654, 4);
INSERT INTO 'dancesstepsmap' VALUES (5225, 5655, 1);
INSERT INTO 'dancesstepsmap' VALUES (5226, 5656, 1);
INSERT INTO 'dancesstepsmap' VALUES (5227, 5657, 1);
INSERT INTO 'dancesstepsmap' VALUES (5228, 5658, 1);
INSERT INTO 'dancesstepsmap' VALUES (5229, 5659, 1);
INSERT INTO 'dancesstepsmap' VALUES (5230, 5660, 4);
INSERT INTO 'dancesstepsmap' VALUES (5231, 5661, 1);
INSERT INTO 'dancesstepsmap' VALUES (5232, 5663, 1);
INSERT INTO 'dancesstepsmap' VALUES (5233, 5664, 1);
INSERT INTO 'dancesstepsmap' VALUES (5234, 5665, 4);
INSERT INTO 'dancesstepsmap' VALUES (5235, 5666, 4);
INSERT INTO 'dancesstepsmap' VALUES (5236, 5668, 1);
INSERT INTO 'dancesstepsmap' VALUES (5237, 5669, 4);
INSERT INTO 'dancesstepsmap' VALUES (11916, 10548, 2);
INSERT INTO 'dancesstepsmap' VALUES (11917, 10548, 1);
INSERT INTO 'dancesstepsmap' VALUES (11918, 10549, 5);
INSERT INTO 'dancesstepsmap' VALUES (11919, 10549, 4);
INSERT INTO 'dancesstepsmap' VALUES (11920, 10769, 5);
INSERT INTO 'dancesstepsmap' VALUES (11921, 10769, 4);
INSERT INTO 'dancesstepsmap' VALUES (11922, 10770, 1);
INSERT INTO 'dancesstepsmap' VALUES (11923, 10771, 4);
INSERT INTO 'dancesstepsmap' VALUES (11924, 10771, 5);
INSERT INTO 'dancesstepsmap' VALUES (11925, 10772, 1);
INSERT INTO 'dancesstepsmap' VALUES (11926, 10773, 1);
INSERT INTO 'dancesstepsmap' VALUES (11927, 10774, 4);
INSERT INTO 'dancesstepsmap' VALUES (11928, 10775, 2);
INSERT INTO 'dancesstepsmap' VALUES (11929, 10775, 1);
INSERT INTO 'dancesstepsmap' VALUES (11930, 10776, 4);
INSERT INTO 'dancesstepsmap' VALUES (11931, 10777, 2);
INSERT INTO 'dancesstepsmap' VALUES (11932, 10778, 3);
INSERT INTO 'dancesstepsmap' VALUES (11933, 10778, 4);
INSERT INTO 'dancesstepsmap' VALUES (11934, 10778, 1);
INSERT INTO 'dancesstepsmap' VALUES (11935, 10779, 5);
INSERT INTO 'dancesstepsmap' VALUES (11936, 10779, 4);
INSERT INTO 'dancesstepsmap' VALUES (11937, 10780, 5);
INSERT INTO 'dancesstepsmap' VALUES (11938, 10780, 4);
INSERT INTO 'dancesstepsmap' VALUES (11939, 10781, 1);
INSERT INTO 'dancesstepsmap' VALUES (11940, 10781, 2);
INSERT INTO 'dancesstepsmap' VALUES (11941, 10760, 2);
INSERT INTO 'dancesstepsmap' VALUES (11942, 10760, 1);
INSERT INTO 'dancesstepsmap' VALUES (11943, 10782, 1);
INSERT INTO 'dancesstepsmap' VALUES (11944, 10782, 3);
INSERT INTO 'dancesstepsmap' VALUES (11945, 9907, 1);
INSERT INTO 'dancesstepsmap' VALUES (11946, 9883, 2);
INSERT INTO 'dancesstepsmap' VALUES (11947, 9883, 1);
INSERT INTO 'dancesstepsmap' VALUES (11948, 10783, 4);
INSERT INTO 'dancesstepsmap' VALUES (11949, 10784, 1);
INSERT INTO 'dancesstepsmap' VALUES (11950, 10785, 2);
INSERT INTO 'dancesstepsmap' VALUES (11951, 10785, 1);
INSERT INTO 'dancesstepsmap' VALUES (11952, 10786, 1);
INSERT INTO 'dancesstepsmap' VALUES (11953, 10786, 3);
INSERT INTO 'dancesstepsmap' VALUES (11954, 10787, 1);
INSERT INTO 'dancesstepsmap' VALUES (11955, 10787, 2);
INSERT INTO 'dancesstepsmap' VALUES (11956, 10653, 2);
INSERT INTO 'dancesstepsmap' VALUES (11957, 10653, 1);
INSERT INTO 'dancesstepsmap' VALUES (17262, 14625, 1);
INSERT INTO 'dancesstepsmap' VALUES (17263, 14625, 2);
INSERT INTO 'dancesstepsmap' VALUES (5238, 5670, 4);
INSERT INTO 'dancesstepsmap' VALUES (5239, 5671, 4);
INSERT INTO 'dancesstepsmap' VALUES (5240, 5672, 1);
INSERT INTO 'dancesstepsmap' VALUES (5241, 5673, 1);
INSERT INTO 'dancesstepsmap' VALUES (5242, 5674, 1);
INSERT INTO 'dancesstepsmap' VALUES (5243, 5676, 4);
INSERT INTO 'dancesstepsmap' VALUES (5244, 5677, 1);
INSERT INTO 'dancesstepsmap' VALUES (5245, 5678, 1);
INSERT INTO 'dancesstepsmap' VALUES (5246, 5679, 4);
INSERT INTO 'dancesstepsmap' VALUES (5247, 5680, 1);
INSERT INTO 'dancesstepsmap' VALUES (5248, 5681, 1);
INSERT INTO 'dancesstepsmap' VALUES (5249, 5682, 4);
INSERT INTO 'dancesstepsmap' VALUES (5250, 5683, 4);
INSERT INTO 'dancesstepsmap' VALUES (5251, 5684, 1);
INSERT INTO 'dancesstepsmap' VALUES (5252, 5685, 4);
INSERT INTO 'dancesstepsmap' VALUES (5253, 5687, 1);
INSERT INTO 'dancesstepsmap' VALUES (5254, 5688, 1);
INSERT INTO 'dancesstepsmap' VALUES (5255, 5689, 1);
INSERT INTO 'dancesstepsmap' VALUES (5256, 5690, 1);
INSERT INTO 'dancesstepsmap' VALUES (5257, 5691, 4);
INSERT INTO 'dancesstepsmap' VALUES (5258, 5692, 1);
INSERT INTO 'dancesstepsmap' VALUES (5259, 5695, 1);
INSERT INTO 'dancesstepsmap' VALUES (5260, 5696, 4);
INSERT INTO 'dancesstepsmap' VALUES (5261, 5697, 1);
INSERT INTO 'dancesstepsmap' VALUES (5262, 5698, 1);
INSERT INTO 'dancesstepsmap' VALUES (5263, 5699, 1);
INSERT INTO 'dancesstepsmap' VALUES (5264, 5700, 4);
INSERT INTO 'dancesstepsmap' VALUES (5265, 5702, 1);
INSERT INTO 'dancesstepsmap' VALUES (5266, 5703, 1);
INSERT INTO 'dancesstepsmap' VALUES (5267, 5704, 4);
INSERT INTO 'dancesstepsmap' VALUES (5268, 5705, 1);
INSERT INTO 'dancesstepsmap' VALUES (5269, 5706, 1);
INSERT INTO 'dancesstepsmap' VALUES (5270, 5707, 4);
INSERT INTO 'dancesstepsmap' VALUES (5271, 5710, 1);
INSERT INTO 'dancesstepsmap' VALUES (5272, 5711, 1);
INSERT INTO 'dancesstepsmap' VALUES (5273, 5712, 1);
INSERT INTO 'dancesstepsmap' VALUES (5274, 5713, 1);
INSERT INTO 'dancesstepsmap' VALUES (5275, 5714, 4);
INSERT INTO 'dancesstepsmap' VALUES (5276, 5715, 4);
INSERT INTO 'dancesstepsmap' VALUES (5277, 5716, 1);
INSERT INTO 'dancesstepsmap' VALUES (5278, 5717, 1);
INSERT INTO 'dancesstepsmap' VALUES (5279, 5718, 1);
INSERT INTO 'dancesstepsmap' VALUES (5280, 5719, 1);
INSERT INTO 'dancesstepsmap' VALUES (5281, 5720, 1);
INSERT INTO 'dancesstepsmap' VALUES (5282, 5721, 1);
INSERT INTO 'dancesstepsmap' VALUES (5283, 5722, 1);
INSERT INTO 'dancesstepsmap' VALUES (5284, 5723, 1);
INSERT INTO 'dancesstepsmap' VALUES (5285, 5725, 1);
INSERT INTO 'dancesstepsmap' VALUES (5286, 5726, 4);
INSERT INTO 'dancesstepsmap' VALUES (5287, 5727, 4);
INSERT INTO 'dancesstepsmap' VALUES (5288, 5728, 4);
INSERT INTO 'dancesstepsmap' VALUES (5289, 5729, 1);
INSERT INTO 'dancesstepsmap' VALUES (5290, 5730, 4);
INSERT INTO 'dancesstepsmap' VALUES (5291, 5731, 1);
INSERT INTO 'dancesstepsmap' VALUES (5292, 5732, 1);
INSERT INTO 'dancesstepsmap' VALUES (5293, 5733, 4);
INSERT INTO 'dancesstepsmap' VALUES (5294, 5734, 1);
INSERT INTO 'dancesstepsmap' VALUES (5295, 5735, 1);
INSERT INTO 'dancesstepsmap' VALUES (5296, 5736, 1);
INSERT INTO 'dancesstepsmap' VALUES (5297, 5737, 1);
INSERT INTO 'dancesstepsmap' VALUES (5298, 5738, 4);
INSERT INTO 'dancesstepsmap' VALUES (5299, 5739, 1);
INSERT INTO 'dancesstepsmap' VALUES (5300, 5740, 4);
INSERT INTO 'dancesstepsmap' VALUES (5301, 5741, 1);
INSERT INTO 'dancesstepsmap' VALUES (5302, 5743, 4);
INSERT INTO 'dancesstepsmap' VALUES (5303, 5744, 1);
INSERT INTO 'dancesstepsmap' VALUES (5304, 5746, 1);
INSERT INTO 'dancesstepsmap' VALUES (5305, 5747, 1);
INSERT INTO 'dancesstepsmap' VALUES (5306, 5748, 4);
INSERT INTO 'dancesstepsmap' VALUES (5307, 5749, 1);
INSERT INTO 'dancesstepsmap' VALUES (5308, 5750, 1);
INSERT INTO 'dancesstepsmap' VALUES (5309, 5751, 1);
INSERT INTO 'dancesstepsmap' VALUES (5310, 5752, 1);
INSERT INTO 'dancesstepsmap' VALUES (5311, 5753, 1);
INSERT INTO 'dancesstepsmap' VALUES (5312, 5754, 1);
INSERT INTO 'dancesstepsmap' VALUES (5313, 5755, 4);
INSERT INTO 'dancesstepsmap' VALUES (5314, 5756, 4);
INSERT INTO 'dancesstepsmap' VALUES (5315, 5757, 1);
INSERT INTO 'dancesstepsmap' VALUES (5316, 5758, 4);
INSERT INTO 'dancesstepsmap' VALUES (5317, 5759, 1);
INSERT INTO 'dancesstepsmap' VALUES (5318, 5760, 1);
INSERT INTO 'dancesstepsmap' VALUES (5319, 5761, 1);
INSERT INTO 'dancesstepsmap' VALUES (5320, 5762, 1);
INSERT INTO 'dancesstepsmap' VALUES (5321, 5763, 1);
INSERT INTO 'dancesstepsmap' VALUES (5322, 5764, 4);
INSERT INTO 'dancesstepsmap' VALUES (5323, 5765, 1);
INSERT INTO 'dancesstepsmap' VALUES (5324, 5766, 4);
INSERT INTO 'dancesstepsmap' VALUES (5325, 5767, 1);
INSERT INTO 'dancesstepsmap' VALUES (5326, 5768, 1);
INSERT INTO 'dancesstepsmap' VALUES (5327, 5769, 1);
INSERT INTO 'dancesstepsmap' VALUES (5328, 5770, 1);
INSERT INTO 'dancesstepsmap' VALUES (5329, 5771, 1);
INSERT INTO 'dancesstepsmap' VALUES (11958, 10788, 1);
INSERT INTO 'dancesstepsmap' VALUES (11959, 10788, 3);
INSERT INTO 'dancesstepsmap' VALUES (11960, 10788, 2);
INSERT INTO 'dancesstepsmap' VALUES (11961, 10789, 4);
INSERT INTO 'dancesstepsmap' VALUES (11962, 10790, 2);
INSERT INTO 'dancesstepsmap' VALUES (11963, 10790, 1);
INSERT INTO 'dancesstepsmap' VALUES (11964, 10791, 1);
INSERT INTO 'dancesstepsmap' VALUES (11965, 10792, 4);
INSERT INTO 'dancesstepsmap' VALUES (11966, 10792, 5);
INSERT INTO 'dancesstepsmap' VALUES (11967, 10793, 2);
INSERT INTO 'dancesstepsmap' VALUES (11968, 10793, 1);
INSERT INTO 'dancesstepsmap' VALUES (11969, 10794, 1);
INSERT INTO 'dancesstepsmap' VALUES (11970, 10795, 1);
INSERT INTO 'dancesstepsmap' VALUES (11971, 10795, 2);
INSERT INTO 'dancesstepsmap' VALUES (11972, 10796, 4);
INSERT INTO 'dancesstepsmap' VALUES (11973, 10797, 1);
INSERT INTO 'dancesstepsmap' VALUES (11974, 10797, 2);
INSERT INTO 'dancesstepsmap' VALUES (11976, 9888, 2);
INSERT INTO 'dancesstepsmap' VALUES (11977, 9888, 3);
INSERT INTO 'dancesstepsmap' VALUES (11978, 9888, 4);
INSERT INTO 'dancesstepsmap' VALUES (11979, 9888, 5);
INSERT INTO 'dancesstepsmap' VALUES (11980, 10798, 1);
INSERT INTO 'dancesstepsmap' VALUES (11981, 10798, 2);
INSERT INTO 'dancesstepsmap' VALUES (11982, 10798, 3);
INSERT INTO 'dancesstepsmap' VALUES (11983, 5952, 5);
INSERT INTO 'dancesstepsmap' VALUES (11984, 10799, 1);
INSERT INTO 'dancesstepsmap' VALUES (11985, 10799, 3);
INSERT INTO 'dancesstepsmap' VALUES (11986, 10800, 4);
INSERT INTO 'dancesstepsmap' VALUES (11987, 10800, 5);
INSERT INTO 'dancesstepsmap' VALUES (11988, 10801, 4);
INSERT INTO 'dancesstepsmap' VALUES (11989, 10801, 5);
INSERT INTO 'dancesstepsmap' VALUES (11990, 157, 3);
INSERT INTO 'dancesstepsmap' VALUES (11991, 8998, 2);
INSERT INTO 'dancesstepsmap' VALUES (11992, 8998, 1);
INSERT INTO 'dancesstepsmap' VALUES (11993, 1223, 2);
INSERT INTO 'dancesstepsmap' VALUES (11994, 9482, 2);
INSERT INTO 'dancesstepsmap' VALUES (23146, 17677, 2);
INSERT INTO 'dancesstepsmap' VALUES (11996, 9831, 2);
INSERT INTO 'dancesstepsmap' VALUES (11997, 9740, 2);
INSERT INTO 'dancesstepsmap' VALUES (11998, 9740, 1);
INSERT INTO 'dancesstepsmap' VALUES (17264, 14626, 2);
INSERT INTO 'dancesstepsmap' VALUES (17265, 14626, 1);
INSERT INTO 'dancesstepsmap' VALUES (17266, 14626, 3);
INSERT INTO 'dancesstepsmap' VALUES (5330, 5772, 1);
INSERT INTO 'dancesstepsmap' VALUES (5331, 5773, 1);
INSERT INTO 'dancesstepsmap' VALUES (5332, 5774, 1);
INSERT INTO 'dancesstepsmap' VALUES (5333, 5775, 4);
INSERT INTO 'dancesstepsmap' VALUES (5334, 5776, 1);
INSERT INTO 'dancesstepsmap' VALUES (5335, 5777, 1);
INSERT INTO 'dancesstepsmap' VALUES (5336, 5778, 1);
INSERT INTO 'dancesstepsmap' VALUES (5337, 5779, 1);
INSERT INTO 'dancesstepsmap' VALUES (5338, 5781, 1);
INSERT INTO 'dancesstepsmap' VALUES (5339, 5782, 4);
INSERT INTO 'dancesstepsmap' VALUES (5340, 5783, 4);
INSERT INTO 'dancesstepsmap' VALUES (5341, 5784, 1);
INSERT INTO 'dancesstepsmap' VALUES (5342, 5785, 1);
INSERT INTO 'dancesstepsmap' VALUES (5343, 5786, 4);
INSERT INTO 'dancesstepsmap' VALUES (5344, 5787, 1);
INSERT INTO 'dancesstepsmap' VALUES (5345, 5788, 1);
INSERT INTO 'dancesstepsmap' VALUES (5346, 5789, 1);
INSERT INTO 'dancesstepsmap' VALUES (5347, 5790, 4);
INSERT INTO 'dancesstepsmap' VALUES (5348, 5791, 1);
INSERT INTO 'dancesstepsmap' VALUES (5349, 5792, 4);
INSERT INTO 'dancesstepsmap' VALUES (5350, 5793, 1);
INSERT INTO 'dancesstepsmap' VALUES (5351, 5794, 1);
INSERT INTO 'dancesstepsmap' VALUES (5352, 5795, 1);
INSERT INTO 'dancesstepsmap' VALUES (5353, 5796, 4);
INSERT INTO 'dancesstepsmap' VALUES (5354, 5797, 4);
INSERT INTO 'dancesstepsmap' VALUES (5355, 5798, 1);
INSERT INTO 'dancesstepsmap' VALUES (5356, 5799, 1);
INSERT INTO 'dancesstepsmap' VALUES (5357, 5800, 1);
INSERT INTO 'dancesstepsmap' VALUES (5358, 5802, 1);
INSERT INTO 'dancesstepsmap' VALUES (5359, 5803, 1);
INSERT INTO 'dancesstepsmap' VALUES (5360, 5804, 1);
INSERT INTO 'dancesstepsmap' VALUES (5361, 5805, 1);
INSERT INTO 'dancesstepsmap' VALUES (5362, 5807, 1);
INSERT INTO 'dancesstepsmap' VALUES (5363, 5808, 1);
INSERT INTO 'dancesstepsmap' VALUES (5364, 5809, 1);
INSERT INTO 'dancesstepsmap' VALUES (5365, 5811, 1);
INSERT INTO 'dancesstepsmap' VALUES (5366, 5813, 4);
INSERT INTO 'dancesstepsmap' VALUES (5367, 5814, 1);
INSERT INTO 'dancesstepsmap' VALUES (5368, 5815, 4);
INSERT INTO 'dancesstepsmap' VALUES (5369, 5817, 1);
INSERT INTO 'dancesstepsmap' VALUES (5370, 5818, 4);
INSERT INTO 'dancesstepsmap' VALUES (5371, 5819, 1);
INSERT INTO 'dancesstepsmap' VALUES (5372, 5820, 1);
INSERT INTO 'dancesstepsmap' VALUES (5373, 5821, 1);
INSERT INTO 'dancesstepsmap' VALUES (5374, 5824, 1);
INSERT INTO 'dancesstepsmap' VALUES (5375, 5825, 4);
INSERT INTO 'dancesstepsmap' VALUES (5376, 5826, 4);
INSERT INTO 'dancesstepsmap' VALUES (5377, 5827, 4);
INSERT INTO 'dancesstepsmap' VALUES (5378, 5828, 1);
INSERT INTO 'dancesstepsmap' VALUES (5379, 5829, 4);
INSERT INTO 'dancesstepsmap' VALUES (5380, 5830, 1);
INSERT INTO 'dancesstepsmap' VALUES (5381, 5831, 4);
INSERT INTO 'dancesstepsmap' VALUES (5382, 5832, 1);
INSERT INTO 'dancesstepsmap' VALUES (5383, 5833, 4);
INSERT INTO 'dancesstepsmap' VALUES (5384, 5834, 4);
INSERT INTO 'dancesstepsmap' VALUES (5385, 5835, 1);
INSERT INTO 'dancesstepsmap' VALUES (5386, 5836, 1);
INSERT INTO 'dancesstepsmap' VALUES (5387, 5838, 1);
INSERT INTO 'dancesstepsmap' VALUES (5388, 5839, 4);
INSERT INTO 'dancesstepsmap' VALUES (5389, 5840, 1);
INSERT INTO 'dancesstepsmap' VALUES (5390, 5841, 1);
INSERT INTO 'dancesstepsmap' VALUES (5391, 5842, 4);
INSERT INTO 'dancesstepsmap' VALUES (5392, 5843, 1);
INSERT INTO 'dancesstepsmap' VALUES (5393, 5844, 1);
INSERT INTO 'dancesstepsmap' VALUES (5394, 5845, 4);
INSERT INTO 'dancesstepsmap' VALUES (5395, 5846, 1);
INSERT INTO 'dancesstepsmap' VALUES (5396, 5847, 1);
INSERT INTO 'dancesstepsmap' VALUES (5397, 5848, 1);
INSERT INTO 'dancesstepsmap' VALUES (5398, 5850, 4);
INSERT INTO 'dancesstepsmap' VALUES (5399, 5851, 4);
INSERT INTO 'dancesstepsmap' VALUES (5400, 5852, 1);
INSERT INTO 'dancesstepsmap' VALUES (5401, 5854, 4);
INSERT INTO 'dancesstepsmap' VALUES (5402, 5855, 4);
INSERT INTO 'dancesstepsmap' VALUES (5403, 5857, 4);
INSERT INTO 'dancesstepsmap' VALUES (5404, 5858, 4);
INSERT INTO 'dancesstepsmap' VALUES (5405, 5859, 1);
INSERT INTO 'dancesstepsmap' VALUES (5406, 5860, 1);
INSERT INTO 'dancesstepsmap' VALUES (5407, 5861, 1);
INSERT INTO 'dancesstepsmap' VALUES (5408, 5863, 1);
INSERT INTO 'dancesstepsmap' VALUES (5409, 5864, 1);
INSERT INTO 'dancesstepsmap' VALUES (5410, 5865, 1);
INSERT INTO 'dancesstepsmap' VALUES (5411, 5866, 1);
INSERT INTO 'dancesstepsmap' VALUES (5412, 5867, 1);
INSERT INTO 'dancesstepsmap' VALUES (5413, 5868, 1);
INSERT INTO 'dancesstepsmap' VALUES (5414, 5869, 4);
INSERT INTO 'dancesstepsmap' VALUES (5415, 5870, 1);
INSERT INTO 'dancesstepsmap' VALUES (5416, 5871, 1);
INSERT INTO 'dancesstepsmap' VALUES (5417, 5872, 1);
INSERT INTO 'dancesstepsmap' VALUES (5418, 5873, 4);
INSERT INTO 'dancesstepsmap' VALUES (5419, 5874, 4);
INSERT INTO 'dancesstepsmap' VALUES (5420, 5875, 4);
INSERT INTO 'dancesstepsmap' VALUES (5421, 5876, 1);
INSERT INTO 'dancesstepsmap' VALUES (5422, 5877, 1);
INSERT INTO 'dancesstepsmap' VALUES (12000, 9742, 2);
INSERT INTO 'dancesstepsmap' VALUES (12001, 9742, 1);
INSERT INTO 'dancesstepsmap' VALUES (12002, 9000, 3);
INSERT INTO 'dancesstepsmap' VALUES (12003, 9125, 2);
INSERT INTO 'dancesstepsmap' VALUES (12004, 10514, 2);
INSERT INTO 'dancesstepsmap' VALUES (12005, 10802, 1);
INSERT INTO 'dancesstepsmap' VALUES (12006, 10805, 4);
INSERT INTO 'dancesstepsmap' VALUES (12007, 10806, 1);
INSERT INTO 'dancesstepsmap' VALUES (12008, 10806, 2);
INSERT INTO 'dancesstepsmap' VALUES (12009, 10808, 1);
INSERT INTO 'dancesstepsmap' VALUES (12010, 10809, 4);
INSERT INTO 'dancesstepsmap' VALUES (12011, 10811, 4);
INSERT INTO 'dancesstepsmap' VALUES (12012, 10812, 4);
INSERT INTO 'dancesstepsmap' VALUES (12013, 10813, 4);
INSERT INTO 'dancesstepsmap' VALUES (12014, 10814, 4);
INSERT INTO 'dancesstepsmap' VALUES (12015, 10814, 5);
INSERT INTO 'dancesstepsmap' VALUES (12016, 10815, 10);
INSERT INTO 'dancesstepsmap' VALUES (12017, 10815, 1);
INSERT INTO 'dancesstepsmap' VALUES (12018, 10817, 5);
INSERT INTO 'dancesstepsmap' VALUES (12019, 10817, 4);
INSERT INTO 'dancesstepsmap' VALUES (12020, 10818, 1);
INSERT INTO 'dancesstepsmap' VALUES (12021, 10819, 1);
INSERT INTO 'dancesstepsmap' VALUES (12022, 10819, 3);
INSERT INTO 'dancesstepsmap' VALUES (12023, 10820, 2);
INSERT INTO 'dancesstepsmap' VALUES (12024, 10820, 1);
INSERT INTO 'dancesstepsmap' VALUES (12025, 10820, 3);
INSERT INTO 'dancesstepsmap' VALUES (12026, 10051, 2);
INSERT INTO 'dancesstepsmap' VALUES (12027, 10821, 4);
INSERT INTO 'dancesstepsmap' VALUES (12028, 10821, 5);
INSERT INTO 'dancesstepsmap' VALUES (12029, 10822, 4);
INSERT INTO 'dancesstepsmap' VALUES (12030, 10822, 5);
INSERT INTO 'dancesstepsmap' VALUES (12031, 10823, 2);
INSERT INTO 'dancesstepsmap' VALUES (12032, 4774, 3);
INSERT INTO 'dancesstepsmap' VALUES (12033, 10824, 5);
INSERT INTO 'dancesstepsmap' VALUES (12034, 10824, 4);
INSERT INTO 'dancesstepsmap' VALUES (12035, 10842, 6);
INSERT INTO 'dancesstepsmap' VALUES (12036, 10842, 4);
INSERT INTO 'dancesstepsmap' VALUES (12037, 10843, 1);
INSERT INTO 'dancesstepsmap' VALUES (12038, 10843, 3);
INSERT INTO 'dancesstepsmap' VALUES (12039, 10844, 4);
INSERT INTO 'dancesstepsmap' VALUES (12040, 10844, 5);
INSERT INTO 'dancesstepsmap' VALUES (12041, 10845, 3);
INSERT INTO 'dancesstepsmap' VALUES (12042, 10845, 2);
INSERT INTO 'dancesstepsmap' VALUES (12043, 10845, 1);
INSERT INTO 'dancesstepsmap' VALUES (12044, 10846, 1);
INSERT INTO 'dancesstepsmap' VALUES (12045, 10846, 2);
INSERT INTO 'dancesstepsmap' VALUES (12046, 10847, 1);
INSERT INTO 'dancesstepsmap' VALUES (12047, 10847, 2);
INSERT INTO 'dancesstepsmap' VALUES (12048, 10848, 2);
INSERT INTO 'dancesstepsmap' VALUES (12049, 10848, 1);
INSERT INTO 'dancesstepsmap' VALUES (12050, 10849, 1);
INSERT INTO 'dancesstepsmap' VALUES (12051, 10850, 1);
INSERT INTO 'dancesstepsmap' VALUES (17267, 14627, 4);
INSERT INTO 'dancesstepsmap' VALUES (17268, 14627, 5);
INSERT INTO 'dancesstepsmap' VALUES (5423, 5878, 1);
INSERT INTO 'dancesstepsmap' VALUES (5424, 5879, 1);
INSERT INTO 'dancesstepsmap' VALUES (5425, 5880, 1);
INSERT INTO 'dancesstepsmap' VALUES (5426, 5881, 1);
INSERT INTO 'dancesstepsmap' VALUES (5427, 5882, 4);
INSERT INTO 'dancesstepsmap' VALUES (5428, 5883, 1);
INSERT INTO 'dancesstepsmap' VALUES (5429, 5885, 4);
INSERT INTO 'dancesstepsmap' VALUES (5430, 5886, 1);
INSERT INTO 'dancesstepsmap' VALUES (5431, 5887, 1);
INSERT INTO 'dancesstepsmap' VALUES (5432, 5888, 1);
INSERT INTO 'dancesstepsmap' VALUES (5433, 5889, 4);
INSERT INTO 'dancesstepsmap' VALUES (5434, 5890, 4);
INSERT INTO 'dancesstepsmap' VALUES (5435, 5891, 4);
INSERT INTO 'dancesstepsmap' VALUES (5436, 5892, 1);
INSERT INTO 'dancesstepsmap' VALUES (5437, 5893, 1);
INSERT INTO 'dancesstepsmap' VALUES (5438, 5894, 1);
INSERT INTO 'dancesstepsmap' VALUES (5439, 5895, 4);
INSERT INTO 'dancesstepsmap' VALUES (5440, 5896, 1);
INSERT INTO 'dancesstepsmap' VALUES (5441, 5897, 4);
INSERT INTO 'dancesstepsmap' VALUES (5442, 5898, 4);
INSERT INTO 'dancesstepsmap' VALUES (5443, 5899, 1);
INSERT INTO 'dancesstepsmap' VALUES (5444, 5900, 1);
INSERT INTO 'dancesstepsmap' VALUES (5445, 5901, 1);
INSERT INTO 'dancesstepsmap' VALUES (5446, 5902, 1);
INSERT INTO 'dancesstepsmap' VALUES (5447, 5903, 4);
INSERT INTO 'dancesstepsmap' VALUES (5448, 5904, 4);
INSERT INTO 'dancesstepsmap' VALUES (5449, 5905, 1);
INSERT INTO 'dancesstepsmap' VALUES (5450, 5906, 1);
INSERT INTO 'dancesstepsmap' VALUES (5451, 5907, 1);
INSERT INTO 'dancesstepsmap' VALUES (5452, 5908, 1);
INSERT INTO 'dancesstepsmap' VALUES (5453, 5909, 1);
INSERT INTO 'dancesstepsmap' VALUES (5454, 5910, 1);
INSERT INTO 'dancesstepsmap' VALUES (5455, 5911, 1);
INSERT INTO 'dancesstepsmap' VALUES (5456, 5912, 4);
INSERT INTO 'dancesstepsmap' VALUES (5457, 5913, 1);
INSERT INTO 'dancesstepsmap' VALUES (5458, 5914, 1);
INSERT INTO 'dancesstepsmap' VALUES (5459, 5916, 1);
INSERT INTO 'dancesstepsmap' VALUES (5460, 5917, 1);
INSERT INTO 'dancesstepsmap' VALUES (5461, 5918, 4);
INSERT INTO 'dancesstepsmap' VALUES (5463, 5920, 1);
INSERT INTO 'dancesstepsmap' VALUES (5464, 5921, 1);
INSERT INTO 'dancesstepsmap' VALUES (5465, 5922, 1);
INSERT INTO 'dancesstepsmap' VALUES (5466, 5923, 1);
INSERT INTO 'dancesstepsmap' VALUES (5467, 5924, 1);
INSERT INTO 'dancesstepsmap' VALUES (5468, 5925, 1);
INSERT INTO 'dancesstepsmap' VALUES (5469, 5927, 4);
INSERT INTO 'dancesstepsmap' VALUES (5470, 5928, 1);
INSERT INTO 'dancesstepsmap' VALUES (5471, 5929, 1);
INSERT INTO 'dancesstepsmap' VALUES (5472, 5930, 4);
INSERT INTO 'dancesstepsmap' VALUES (5473, 5931, 1);
INSERT INTO 'dancesstepsmap' VALUES (5474, 5932, 1);
INSERT INTO 'dancesstepsmap' VALUES (5475, 5933, 1);
INSERT INTO 'dancesstepsmap' VALUES (5476, 5934, 1);
INSERT INTO 'dancesstepsmap' VALUES (5477, 5935, 1);
INSERT INTO 'dancesstepsmap' VALUES (5478, 5936, 1);
INSERT INTO 'dancesstepsmap' VALUES (5479, 5937, 1);
INSERT INTO 'dancesstepsmap' VALUES (5480, 5939, 1);
INSERT INTO 'dancesstepsmap' VALUES (5481, 5940, 1);
INSERT INTO 'dancesstepsmap' VALUES (5482, 5941, 1);
INSERT INTO 'dancesstepsmap' VALUES (5483, 5943, 4);
INSERT INTO 'dancesstepsmap' VALUES (5484, 5944, 1);
INSERT INTO 'dancesstepsmap' VALUES (5485, 5945, 4);
INSERT INTO 'dancesstepsmap' VALUES (5486, 5946, 1);
INSERT INTO 'dancesstepsmap' VALUES (5487, 5947, 1);
INSERT INTO 'dancesstepsmap' VALUES (5488, 5948, 1);
INSERT INTO 'dancesstepsmap' VALUES (5489, 5950, 4);
INSERT INTO 'dancesstepsmap' VALUES (5490, 5951, 1);
INSERT INTO 'dancesstepsmap' VALUES (5491, 5952, 4);
INSERT INTO 'dancesstepsmap' VALUES (5492, 5953, 1);
INSERT INTO 'dancesstepsmap' VALUES (5493, 5954, 4);
INSERT INTO 'dancesstepsmap' VALUES (5494, 5955, 1);
INSERT INTO 'dancesstepsmap' VALUES (5495, 5956, 1);
INSERT INTO 'dancesstepsmap' VALUES (5496, 5957, 1);
INSERT INTO 'dancesstepsmap' VALUES (5497, 5958, 4);
INSERT INTO 'dancesstepsmap' VALUES (5498, 5959, 1);
INSERT INTO 'dancesstepsmap' VALUES (5499, 5960, 1);
INSERT INTO 'dancesstepsmap' VALUES (5500, 5961, 1);
INSERT INTO 'dancesstepsmap' VALUES (5501, 5962, 1);
INSERT INTO 'dancesstepsmap' VALUES (5502, 5963, 4);
INSERT INTO 'dancesstepsmap' VALUES (5503, 5965, 1);
INSERT INTO 'dancesstepsmap' VALUES (5504, 5966, 1);
INSERT INTO 'dancesstepsmap' VALUES (5505, 5967, 1);
INSERT INTO 'dancesstepsmap' VALUES (5506, 5968, 1);
INSERT INTO 'dancesstepsmap' VALUES (5507, 5969, 4);
INSERT INTO 'dancesstepsmap' VALUES (5508, 5971, 4);
INSERT INTO 'dancesstepsmap' VALUES (5509, 5972, 1);
INSERT INTO 'dancesstepsmap' VALUES (5510, 5973, 1);
INSERT INTO 'dancesstepsmap' VALUES (5511, 5974, 4);
INSERT INTO 'dancesstepsmap' VALUES (5513, 5976, 4);
INSERT INTO 'dancesstepsmap' VALUES (5514, 5977, 1);
INSERT INTO 'dancesstepsmap' VALUES (5515, 5978, 1);
INSERT INTO 'dancesstepsmap' VALUES (5516, 5979, 1);
INSERT INTO 'dancesstepsmap' VALUES (5517, 5980, 4);
INSERT INTO 'dancesstepsmap' VALUES (5518, 5981, 1);
INSERT INTO 'dancesstepsmap' VALUES (5519, 5982, 4);
INSERT INTO 'dancesstepsmap' VALUES (5520, 5983, 1);
INSERT INTO 'dancesstepsmap' VALUES (5521, 5984, 1);
INSERT INTO 'dancesstepsmap' VALUES (5522, 5985, 1);
INSERT INTO 'dancesstepsmap' VALUES (5523, 5986, 1);
INSERT INTO 'dancesstepsmap' VALUES (5524, 5987, 4);
INSERT INTO 'dancesstepsmap' VALUES (5525, 5989, 1);
INSERT INTO 'dancesstepsmap' VALUES (5526, 5991, 4);
INSERT INTO 'dancesstepsmap' VALUES (5527, 5992, 4);
INSERT INTO 'dancesstepsmap' VALUES (5528, 5993, 1);
INSERT INTO 'dancesstepsmap' VALUES (5529, 5994, 1);
INSERT INTO 'dancesstepsmap' VALUES (5530, 5995, 1);
INSERT INTO 'dancesstepsmap' VALUES (5531, 5996, 1);
INSERT INTO 'dancesstepsmap' VALUES (5533, 5999, 1);
INSERT INTO 'dancesstepsmap' VALUES (5534, 6001, 4);
INSERT INTO 'dancesstepsmap' VALUES (5535, 6002, 1);
INSERT INTO 'dancesstepsmap' VALUES (5536, 6003, 4);
INSERT INTO 'dancesstepsmap' VALUES (5537, 6004, 1);
INSERT INTO 'dancesstepsmap' VALUES (5538, 6005, 4);
INSERT INTO 'dancesstepsmap' VALUES (5539, 6006, 1);
INSERT INTO 'dancesstepsmap' VALUES (5540, 6007, 1);
INSERT INTO 'dancesstepsmap' VALUES (5541, 6008, 4);
INSERT INTO 'dancesstepsmap' VALUES (5542, 6009, 1);
INSERT INTO 'dancesstepsmap' VALUES (5543, 6010, 1);
INSERT INTO 'dancesstepsmap' VALUES (5544, 6011, 1);
INSERT INTO 'dancesstepsmap' VALUES (5545, 6012, 1);
INSERT INTO 'dancesstepsmap' VALUES (5546, 6013, 4);
INSERT INTO 'dancesstepsmap' VALUES (5547, 6014, 4);
INSERT INTO 'dancesstepsmap' VALUES (5548, 6015, 1);
INSERT INTO 'dancesstepsmap' VALUES (5549, 6016, 1);
INSERT INTO 'dancesstepsmap' VALUES (5550, 6017, 1);
INSERT INTO 'dancesstepsmap' VALUES (5551, 6018, 1);
INSERT INTO 'dancesstepsmap' VALUES (5552, 6019, 1);
INSERT INTO 'dancesstepsmap' VALUES (12052, 10851, 6);
INSERT INTO 'dancesstepsmap' VALUES (12053, 10851, 5);
INSERT INTO 'dancesstepsmap' VALUES (12054, 10851, 4);
INSERT INTO 'dancesstepsmap' VALUES (12055, 9059, 2);
INSERT INTO 'dancesstepsmap' VALUES (12056, 9059, 1);
INSERT INTO 'dancesstepsmap' VALUES (12057, 6964, 5);
INSERT INTO 'dancesstepsmap' VALUES (12058, 10862, 3);
INSERT INTO 'dancesstepsmap' VALUES (12059, 10863, 5);
INSERT INTO 'dancesstepsmap' VALUES (12060, 10863, 4);
INSERT INTO 'dancesstepsmap' VALUES (12061, 10864, 1);
INSERT INTO 'dancesstepsmap' VALUES (12062, 10864, 2);
INSERT INTO 'dancesstepsmap' VALUES (12063, 10866, 2);
INSERT INTO 'dancesstepsmap' VALUES (12064, 10866, 1);
INSERT INTO 'dancesstepsmap' VALUES (12065, 10778, 2);
INSERT INTO 'dancesstepsmap' VALUES (12066, 10867, 4);
INSERT INTO 'dancesstepsmap' VALUES (12067, 10878, 2);
INSERT INTO 'dancesstepsmap' VALUES (5553, 6020, 4);
INSERT INTO 'dancesstepsmap' VALUES (5554, 6021, 1);
INSERT INTO 'dancesstepsmap' VALUES (5555, 6022, 4);
INSERT INTO 'dancesstepsmap' VALUES (5556, 6023, 4);
INSERT INTO 'dancesstepsmap' VALUES (5557, 6025, 1);
INSERT INTO 'dancesstepsmap' VALUES (5558, 6026, 1);
INSERT INTO 'dancesstepsmap' VALUES (5559, 6027, 1);
INSERT INTO 'dancesstepsmap' VALUES (5560, 6028, 1);
INSERT INTO 'dancesstepsmap' VALUES (5561, 6029, 4);
INSERT INTO 'dancesstepsmap' VALUES (5562, 6030, 1);
INSERT INTO 'dancesstepsmap' VALUES (5563, 6031, 1);
INSERT INTO 'dancesstepsmap' VALUES (5564, 6032, 1);
INSERT INTO 'dancesstepsmap' VALUES (5565, 6033, 4);
INSERT INTO 'dancesstepsmap' VALUES (5566, 6034, 4);
INSERT INTO 'dancesstepsmap' VALUES (5567, 6035, 1);
INSERT INTO 'dancesstepsmap' VALUES (5568, 6036, 4);
INSERT INTO 'dancesstepsmap' VALUES (5569, 6037, 4);
INSERT INTO 'dancesstepsmap' VALUES (5570, 6038, 1);
INSERT INTO 'dancesstepsmap' VALUES (5571, 6039, 1);
INSERT INTO 'dancesstepsmap' VALUES (5572, 6040, 1);
INSERT INTO 'dancesstepsmap' VALUES (5573, 6041, 4);
INSERT INTO 'dancesstepsmap' VALUES (5574, 6042, 1);
INSERT INTO 'dancesstepsmap' VALUES (5575, 6043, 1);
INSERT INTO 'dancesstepsmap' VALUES (5576, 6044, 1);
INSERT INTO 'dancesstepsmap' VALUES (5577, 6045, 4);
INSERT INTO 'dancesstepsmap' VALUES (5578, 6046, 4);
INSERT INTO 'dancesstepsmap' VALUES (5579, 6047, 4);
INSERT INTO 'dancesstepsmap' VALUES (5580, 6048, 1);
INSERT INTO 'dancesstepsmap' VALUES (5581, 6049, 4);
INSERT INTO 'dancesstepsmap' VALUES (5582, 6050, 4);
INSERT INTO 'dancesstepsmap' VALUES (5583, 6051, 1);
INSERT INTO 'dancesstepsmap' VALUES (5584, 6052, 4);
INSERT INTO 'dancesstepsmap' VALUES (5585, 6053, 1);
INSERT INTO 'dancesstepsmap' VALUES (5586, 6054, 1);
INSERT INTO 'dancesstepsmap' VALUES (5587, 6055, 1);
INSERT INTO 'dancesstepsmap' VALUES (23147, 17753, 1);
INSERT INTO 'dancesstepsmap' VALUES (5589, 6057, 4);
INSERT INTO 'dancesstepsmap' VALUES (5590, 6058, 1);
INSERT INTO 'dancesstepsmap' VALUES (5591, 6059, 1);
INSERT INTO 'dancesstepsmap' VALUES (5592, 6060, 4);
INSERT INTO 'dancesstepsmap' VALUES (5593, 6061, 1);
INSERT INTO 'dancesstepsmap' VALUES (5594, 6062, 1);
INSERT INTO 'dancesstepsmap' VALUES (5595, 6063, 1);
INSERT INTO 'dancesstepsmap' VALUES (5596, 6064, 1);
INSERT INTO 'dancesstepsmap' VALUES (5597, 6065, 1);
INSERT INTO 'dancesstepsmap' VALUES (5598, 6066, 4);
INSERT INTO 'dancesstepsmap' VALUES (5599, 6067, 1);
INSERT INTO 'dancesstepsmap' VALUES (5600, 6068, 4);
INSERT INTO 'dancesstepsmap' VALUES (5601, 6069, 1);
INSERT INTO 'dancesstepsmap' VALUES (5602, 6070, 4);
INSERT INTO 'dancesstepsmap' VALUES (5603, 6071, 4);
INSERT INTO 'dancesstepsmap' VALUES (5604, 6072, 4);
INSERT INTO 'dancesstepsmap' VALUES (5605, 6073, 1);
INSERT INTO 'dancesstepsmap' VALUES (5606, 6074, 4);
INSERT INTO 'dancesstepsmap' VALUES (5607, 6075, 4);
INSERT INTO 'dancesstepsmap' VALUES (5608, 6077, 4);
INSERT INTO 'dancesstepsmap' VALUES (5609, 6078, 4);
INSERT INTO 'dancesstepsmap' VALUES (5610, 6079, 1);
INSERT INTO 'dancesstepsmap' VALUES (5611, 6080, 1);
INSERT INTO 'dancesstepsmap' VALUES (5612, 6081, 4);
INSERT INTO 'dancesstepsmap' VALUES (5613, 6084, 1);
INSERT INTO 'dancesstepsmap' VALUES (5614, 6085, 4);
INSERT INTO 'dancesstepsmap' VALUES (5615, 6086, 1);
INSERT INTO 'dancesstepsmap' VALUES (5616, 6087, 4);
INSERT INTO 'dancesstepsmap' VALUES (5617, 6088, 1);
INSERT INTO 'dancesstepsmap' VALUES (5618, 6089, 4);
INSERT INTO 'dancesstepsmap' VALUES (5619, 6090, 4);
INSERT INTO 'dancesstepsmap' VALUES (5620, 6091, 4);
INSERT INTO 'dancesstepsmap' VALUES (5621, 6092, 4);
INSERT INTO 'dancesstepsmap' VALUES (5622, 6093, 4);
INSERT INTO 'dancesstepsmap' VALUES (5623, 6094, 1);
INSERT INTO 'dancesstepsmap' VALUES (5624, 6095, 1);
INSERT INTO 'dancesstepsmap' VALUES (5625, 6097, 1);
INSERT INTO 'dancesstepsmap' VALUES (5626, 6098, 4);
INSERT INTO 'dancesstepsmap' VALUES (5627, 6099, 4);
INSERT INTO 'dancesstepsmap' VALUES (5628, 6100, 1);
INSERT INTO 'dancesstepsmap' VALUES (5629, 6101, 1);
INSERT INTO 'dancesstepsmap' VALUES (5630, 6102, 4);
INSERT INTO 'dancesstepsmap' VALUES (5631, 6104, 5);
INSERT INTO 'dancesstepsmap' VALUES (5632, 6105, 1);
INSERT INTO 'dancesstepsmap' VALUES (5633, 6106, 4);
INSERT INTO 'dancesstepsmap' VALUES (5634, 6107, 1);
INSERT INTO 'dancesstepsmap' VALUES (5635, 6108, 1);
INSERT INTO 'dancesstepsmap' VALUES (5636, 6109, 4);
INSERT INTO 'dancesstepsmap' VALUES (5637, 6110, 1);
INSERT INTO 'dancesstepsmap' VALUES (5638, 6111, 4);
INSERT INTO 'dancesstepsmap' VALUES (5639, 6112, 4);
INSERT INTO 'dancesstepsmap' VALUES (5640, 6113, 1);
INSERT INTO 'dancesstepsmap' VALUES (5641, 6114, 1);
INSERT INTO 'dancesstepsmap' VALUES (5642, 6115, 1);
INSERT INTO 'dancesstepsmap' VALUES (5643, 6116, 4);
INSERT INTO 'dancesstepsmap' VALUES (5644, 6117, 1);
INSERT INTO 'dancesstepsmap' VALUES (12068, 10878, 1);
INSERT INTO 'dancesstepsmap' VALUES (12069, 2597, 3);
INSERT INTO 'dancesstepsmap' VALUES (12070, 2253, 5);
INSERT INTO 'dancesstepsmap' VALUES (12071, 10535, 2);
INSERT INTO 'dancesstepsmap' VALUES (12072, 10535, 1);
INSERT INTO 'dancesstepsmap' VALUES (12073, 10531, 2);
INSERT INTO 'dancesstepsmap' VALUES (12074, 10531, 1);
INSERT INTO 'dancesstepsmap' VALUES (12075, 10885, 4);
INSERT INTO 'dancesstepsmap' VALUES (12076, 10885, 5);
INSERT INTO 'dancesstepsmap' VALUES (12077, 10886, 1);
INSERT INTO 'dancesstepsmap' VALUES (12078, 10886, 2);
INSERT INTO 'dancesstepsmap' VALUES (12079, 10887, 1);
INSERT INTO 'dancesstepsmap' VALUES (12080, 10887, 3);
INSERT INTO 'dancesstepsmap' VALUES (12081, 10888, 5);
INSERT INTO 'dancesstepsmap' VALUES (12082, 10888, 4);
INSERT INTO 'dancesstepsmap' VALUES (12083, 10889, 4);
INSERT INTO 'dancesstepsmap' VALUES (12084, 10889, 5);
INSERT INTO 'dancesstepsmap' VALUES (12085, 10890, 1);
INSERT INTO 'dancesstepsmap' VALUES (12086, 10891, 5);
INSERT INTO 'dancesstepsmap' VALUES (12087, 10891, 4);
INSERT INTO 'dancesstepsmap' VALUES (12088, 10892, 3);
INSERT INTO 'dancesstepsmap' VALUES (12089, 10892, 1);
INSERT INTO 'dancesstepsmap' VALUES (12090, 10892, 2);
INSERT INTO 'dancesstepsmap' VALUES (12091, 10893, 1);
INSERT INTO 'dancesstepsmap' VALUES (12092, 10893, 3);
INSERT INTO 'dancesstepsmap' VALUES (12093, 10894, 3);
INSERT INTO 'dancesstepsmap' VALUES (12094, 10894, 1);
INSERT INTO 'dancesstepsmap' VALUES (12095, 10895, 1);
INSERT INTO 'dancesstepsmap' VALUES (12096, 10896, 2);
INSERT INTO 'dancesstepsmap' VALUES (12097, 10896, 3);
INSERT INTO 'dancesstepsmap' VALUES (12098, 10898, 1);
INSERT INTO 'dancesstepsmap' VALUES (12099, 10898, 2);
INSERT INTO 'dancesstepsmap' VALUES (12100, 10899, 2);
INSERT INTO 'dancesstepsmap' VALUES (12101, 10899, 1);
INSERT INTO 'dancesstepsmap' VALUES (12102, 10900, 1);
INSERT INTO 'dancesstepsmap' VALUES (12103, 10879, 1);
INSERT INTO 'dancesstepsmap' VALUES (12104, 10882, 1);
INSERT INTO 'dancesstepsmap' VALUES (12105, 10883, 1);
INSERT INTO 'dancesstepsmap' VALUES (23148, 17753, 2);
INSERT INTO 'dancesstepsmap' VALUES (12107, 10884, 1);
INSERT INTO 'dancesstepsmap' VALUES (12108, 10901, 3);
INSERT INTO 'dancesstepsmap' VALUES (12109, 10901, 1);
INSERT INTO 'dancesstepsmap' VALUES (17269, 14628, 4);
INSERT INTO 'dancesstepsmap' VALUES (17270, 14628, 5);
INSERT INTO 'dancesstepsmap' VALUES (5645, 6118, 4);
INSERT INTO 'dancesstepsmap' VALUES (5646, 6119, 1);
INSERT INTO 'dancesstepsmap' VALUES (5647, 6120, 1);
INSERT INTO 'dancesstepsmap' VALUES (5648, 6121, 1);
INSERT INTO 'dancesstepsmap' VALUES (5649, 6122, 4);
INSERT INTO 'dancesstepsmap' VALUES (5650, 6123, 1);
INSERT INTO 'dancesstepsmap' VALUES (5651, 6125, 1);
INSERT INTO 'dancesstepsmap' VALUES (5652, 6126, 1);
INSERT INTO 'dancesstepsmap' VALUES (5653, 6127, 4);
INSERT INTO 'dancesstepsmap' VALUES (5654, 6130, 1);
INSERT INTO 'dancesstepsmap' VALUES (5655, 6132, 1);
INSERT INTO 'dancesstepsmap' VALUES (5656, 6133, 1);
INSERT INTO 'dancesstepsmap' VALUES (5657, 6135, 1);
INSERT INTO 'dancesstepsmap' VALUES (5658, 6136, 1);
INSERT INTO 'dancesstepsmap' VALUES (5659, 6137, 1);
INSERT INTO 'dancesstepsmap' VALUES (5660, 6139, 1);
INSERT INTO 'dancesstepsmap' VALUES (5661, 6140, 1);
INSERT INTO 'dancesstepsmap' VALUES (5662, 6141, 4);
INSERT INTO 'dancesstepsmap' VALUES (5663, 6142, 1);
INSERT INTO 'dancesstepsmap' VALUES (5664, 6143, 1);
INSERT INTO 'dancesstepsmap' VALUES (5665, 6144, 4);
INSERT INTO 'dancesstepsmap' VALUES (5666, 6145, 1);
INSERT INTO 'dancesstepsmap' VALUES (5667, 6146, 1);
INSERT INTO 'dancesstepsmap' VALUES (5668, 6147, 4);
INSERT INTO 'dancesstepsmap' VALUES (5669, 6148, 1);
INSERT INTO 'dancesstepsmap' VALUES (5670, 6150, 5);
INSERT INTO 'dancesstepsmap' VALUES (5671, 6151, 1);
INSERT INTO 'dancesstepsmap' VALUES (5672, 6152, 1);
INSERT INTO 'dancesstepsmap' VALUES (5673, 6153, 4);
INSERT INTO 'dancesstepsmap' VALUES (5674, 6154, 4);
INSERT INTO 'dancesstepsmap' VALUES (5675, 6155, 4);
INSERT INTO 'dancesstepsmap' VALUES (5676, 6156, 1);
INSERT INTO 'dancesstepsmap' VALUES (5677, 6157, 1);
INSERT INTO 'dancesstepsmap' VALUES (5678, 6159, 4);
INSERT INTO 'dancesstepsmap' VALUES (5679, 6160, 1);
INSERT INTO 'dancesstepsmap' VALUES (5680, 6161, 1);
INSERT INTO 'dancesstepsmap' VALUES (5681, 6162, 4);
INSERT INTO 'dancesstepsmap' VALUES (5682, 6163, 1);
INSERT INTO 'dancesstepsmap' VALUES (5683, 6164, 1);
INSERT INTO 'dancesstepsmap' VALUES (5684, 6165, 4);
INSERT INTO 'dancesstepsmap' VALUES (5685, 6166, 4);
INSERT INTO 'dancesstepsmap' VALUES (5686, 6167, 4);
INSERT INTO 'dancesstepsmap' VALUES (5687, 6168, 4);
INSERT INTO 'dancesstepsmap' VALUES (5688, 6169, 4);
INSERT INTO 'dancesstepsmap' VALUES (5689, 6170, 4);
INSERT INTO 'dancesstepsmap' VALUES (5690, 6171, 1);
INSERT INTO 'dancesstepsmap' VALUES (5691, 6172, 1);
INSERT INTO 'dancesstepsmap' VALUES (5692, 6173, 1);
INSERT INTO 'dancesstepsmap' VALUES (5693, 6174, 1);
INSERT INTO 'dancesstepsmap' VALUES (5694, 6175, 4);
INSERT INTO 'dancesstepsmap' VALUES (5695, 6176, 4);
INSERT INTO 'dancesstepsmap' VALUES (5696, 6177, 1);
INSERT INTO 'dancesstepsmap' VALUES (5697, 6178, 1);
INSERT INTO 'dancesstepsmap' VALUES (5698, 6179, 4);
INSERT INTO 'dancesstepsmap' VALUES (5699, 6180, 1);
INSERT INTO 'dancesstepsmap' VALUES (5700, 6181, 1);
INSERT INTO 'dancesstepsmap' VALUES (5701, 6182, 1);
INSERT INTO 'dancesstepsmap' VALUES (5702, 6183, 1);
INSERT INTO 'dancesstepsmap' VALUES (5703, 6184, 1);
INSERT INTO 'dancesstepsmap' VALUES (5704, 6185, 1);
INSERT INTO 'dancesstepsmap' VALUES (5705, 6186, 1);
INSERT INTO 'dancesstepsmap' VALUES (5706, 6187, 4);
INSERT INTO 'dancesstepsmap' VALUES (5707, 6188, 4);
INSERT INTO 'dancesstepsmap' VALUES (5708, 6189, 4);
INSERT INTO 'dancesstepsmap' VALUES (23223, 18262, 1);
INSERT INTO 'dancesstepsmap' VALUES (5710, 6192, 1);
INSERT INTO 'dancesstepsmap' VALUES (5711, 6193, 1);
INSERT INTO 'dancesstepsmap' VALUES (5712, 6194, 1);
INSERT INTO 'dancesstepsmap' VALUES (5713, 6195, 4);
INSERT INTO 'dancesstepsmap' VALUES (5714, 6196, 4);
INSERT INTO 'dancesstepsmap' VALUES (5715, 6197, 4);
INSERT INTO 'dancesstepsmap' VALUES (5716, 6198, 1);
INSERT INTO 'dancesstepsmap' VALUES (5717, 6199, 4);
INSERT INTO 'dancesstepsmap' VALUES (5718, 6200, 1);
INSERT INTO 'dancesstepsmap' VALUES (5719, 6201, 1);
INSERT INTO 'dancesstepsmap' VALUES (5720, 6202, 1);
INSERT INTO 'dancesstepsmap' VALUES (5721, 6203, 1);
INSERT INTO 'dancesstepsmap' VALUES (5722, 6204, 1);
INSERT INTO 'dancesstepsmap' VALUES (5723, 6205, 1);
INSERT INTO 'dancesstepsmap' VALUES (5724, 6206, 4);
INSERT INTO 'dancesstepsmap' VALUES (5725, 6207, 4);
INSERT INTO 'dancesstepsmap' VALUES (5726, 6208, 4);
INSERT INTO 'dancesstepsmap' VALUES (5727, 6209, 1);
INSERT INTO 'dancesstepsmap' VALUES (5728, 6210, 1);
INSERT INTO 'dancesstepsmap' VALUES (5729, 6211, 4);
INSERT INTO 'dancesstepsmap' VALUES (5730, 6212, 4);
INSERT INTO 'dancesstepsmap' VALUES (5731, 6213, 4);
INSERT INTO 'dancesstepsmap' VALUES (5732, 6214, 4);
INSERT INTO 'dancesstepsmap' VALUES (5733, 6215, 1);
INSERT INTO 'dancesstepsmap' VALUES (5734, 6216, 4);
INSERT INTO 'dancesstepsmap' VALUES (5735, 6217, 1);
INSERT INTO 'dancesstepsmap' VALUES (5736, 6218, 1);
INSERT INTO 'dancesstepsmap' VALUES (5737, 6219, 1);
INSERT INTO 'dancesstepsmap' VALUES (12110, 10902, 2);
INSERT INTO 'dancesstepsmap' VALUES (12111, 10874, 1);
INSERT INTO 'dancesstepsmap' VALUES (12112, 10872, 1);
INSERT INTO 'dancesstepsmap' VALUES (12113, 10868, 1);
INSERT INTO 'dancesstepsmap' VALUES (12114, 10875, 1);
INSERT INTO 'dancesstepsmap' VALUES (12115, 10871, 1);
INSERT INTO 'dancesstepsmap' VALUES (12116, 10869, 1);
INSERT INTO 'dancesstepsmap' VALUES (12117, 10873, 1);
INSERT INTO 'dancesstepsmap' VALUES (12118, 10870, 4);
INSERT INTO 'dancesstepsmap' VALUES (12119, 10876, 4);
INSERT INTO 'dancesstepsmap' VALUES (12120, 10877, 4);
INSERT INTO 'dancesstepsmap' VALUES (12121, 9196, 1);
INSERT INTO 'dancesstepsmap' VALUES (12122, 9196, 2);
INSERT INTO 'dancesstepsmap' VALUES (12123, 9050, 3);
INSERT INTO 'dancesstepsmap' VALUES (12126, 9051, 1);
INSERT INTO 'dancesstepsmap' VALUES (12127, 9051, 3);
INSERT INTO 'dancesstepsmap' VALUES (12128, 9198, 2);
INSERT INTO 'dancesstepsmap' VALUES (12129, 9198, 3);
INSERT INTO 'dancesstepsmap' VALUES (12130, 9198, 1);
INSERT INTO 'dancesstepsmap' VALUES (12131, 9049, 2);
INSERT INTO 'dancesstepsmap' VALUES (12132, 9049, 1);
INSERT INTO 'dancesstepsmap' VALUES (12133, 9199, 1);
INSERT INTO 'dancesstepsmap' VALUES (12134, 9199, 2);
INSERT INTO 'dancesstepsmap' VALUES (12135, 9052, 4);
INSERT INTO 'dancesstepsmap' VALUES (12136, 10868, 2);
INSERT INTO 'dancesstepsmap' VALUES (12137, 10869, 2);
INSERT INTO 'dancesstepsmap' VALUES (12138, 10870, 5);
INSERT INTO 'dancesstepsmap' VALUES (12139, 10873, 2);
INSERT INTO 'dancesstepsmap' VALUES (12140, 10876, 5);
INSERT INTO 'dancesstepsmap' VALUES (12141, 10874, 2);
INSERT INTO 'dancesstepsmap' VALUES (12142, 10875, 2);
INSERT INTO 'dancesstepsmap' VALUES (12143, 10877, 5);
INSERT INTO 'dancesstepsmap' VALUES (12144, 10148, 1);
INSERT INTO 'dancesstepsmap' VALUES (12145, 10148, 2);
INSERT INTO 'dancesstepsmap' VALUES (12146, 10853, 2);
INSERT INTO 'dancesstepsmap' VALUES (12147, 10854, 2);
INSERT INTO 'dancesstepsmap' VALUES (12148, 10854, 1);
INSERT INTO 'dancesstepsmap' VALUES (12149, 10855, 4);
INSERT INTO 'dancesstepsmap' VALUES (12150, 10856, 1);
INSERT INTO 'dancesstepsmap' VALUES (12151, 10856, 2);
INSERT INTO 'dancesstepsmap' VALUES (17271, 14629, 3);
INSERT INTO 'dancesstepsmap' VALUES (17272, 14629, 2);
INSERT INTO 'dancesstepsmap' VALUES (17273, 14629, 1);
INSERT INTO 'dancesstepsmap' VALUES (5738, 6220, 1);
INSERT INTO 'dancesstepsmap' VALUES (5739, 6221, 4);
INSERT INTO 'dancesstepsmap' VALUES (5740, 6222, 1);
INSERT INTO 'dancesstepsmap' VALUES (5741, 6223, 1);
INSERT INTO 'dancesstepsmap' VALUES (5742, 6224, 4);
INSERT INTO 'dancesstepsmap' VALUES (5743, 6225, 1);
INSERT INTO 'dancesstepsmap' VALUES (5744, 6227, 1);
INSERT INTO 'dancesstepsmap' VALUES (5745, 6228, 1);
INSERT INTO 'dancesstepsmap' VALUES (5746, 6229, 1);
INSERT INTO 'dancesstepsmap' VALUES (5747, 6230, 1);
INSERT INTO 'dancesstepsmap' VALUES (5748, 6231, 1);
INSERT INTO 'dancesstepsmap' VALUES (5749, 6232, 1);
INSERT INTO 'dancesstepsmap' VALUES (5750, 6233, 1);
INSERT INTO 'dancesstepsmap' VALUES (5751, 6234, 4);
INSERT INTO 'dancesstepsmap' VALUES (5752, 6236, 1);
INSERT INTO 'dancesstepsmap' VALUES (5753, 6238, 4);
INSERT INTO 'dancesstepsmap' VALUES (5754, 6240, 4);
INSERT INTO 'dancesstepsmap' VALUES (5755, 6241, 4);
INSERT INTO 'dancesstepsmap' VALUES (5756, 6242, 4);
INSERT INTO 'dancesstepsmap' VALUES (5757, 6243, 1);
INSERT INTO 'dancesstepsmap' VALUES (5758, 6245, 4);
INSERT INTO 'dancesstepsmap' VALUES (5759, 6246, 1);
INSERT INTO 'dancesstepsmap' VALUES (5760, 6247, 1);
INSERT INTO 'dancesstepsmap' VALUES (5761, 6248, 1);
INSERT INTO 'dancesstepsmap' VALUES (5762, 6249, 1);
INSERT INTO 'dancesstepsmap' VALUES (5763, 6250, 1);
INSERT INTO 'dancesstepsmap' VALUES (5764, 6251, 1);
INSERT INTO 'dancesstepsmap' VALUES (5765, 6252, 1);
INSERT INTO 'dancesstepsmap' VALUES (5766, 6253, 1);
INSERT INTO 'dancesstepsmap' VALUES (5767, 6254, 1);
INSERT INTO 'dancesstepsmap' VALUES (5768, 6255, 1);
INSERT INTO 'dancesstepsmap' VALUES (5769, 6256, 1);
INSERT INTO 'dancesstepsmap' VALUES (5770, 6257, 4);
INSERT INTO 'dancesstepsmap' VALUES (5771, 6258, 1);
INSERT INTO 'dancesstepsmap' VALUES (5772, 6259, 1);
INSERT INTO 'dancesstepsmap' VALUES (5773, 6260, 4);
INSERT INTO 'dancesstepsmap' VALUES (5774, 6261, 1);
INSERT INTO 'dancesstepsmap' VALUES (5775, 6262, 4);
INSERT INTO 'dancesstepsmap' VALUES (5776, 6263, 1);
INSERT INTO 'dancesstepsmap' VALUES (5777, 6264, 4);
INSERT INTO 'dancesstepsmap' VALUES (5778, 6265, 1);
INSERT INTO 'dancesstepsmap' VALUES (5779, 6266, 4);
INSERT INTO 'dancesstepsmap' VALUES (5780, 6267, 1);
INSERT INTO 'dancesstepsmap' VALUES (5781, 6268, 4);
INSERT INTO 'dancesstepsmap' VALUES (5782, 6269, 1);
INSERT INTO 'dancesstepsmap' VALUES (5783, 6270, 1);
INSERT INTO 'dancesstepsmap' VALUES (5784, 6271, 4);
INSERT INTO 'dancesstepsmap' VALUES (5785, 6272, 1);
INSERT INTO 'dancesstepsmap' VALUES (5786, 6273, 1);
INSERT INTO 'dancesstepsmap' VALUES (5787, 6274, 1);
INSERT INTO 'dancesstepsmap' VALUES (5788, 6276, 1);
INSERT INTO 'dancesstepsmap' VALUES (5789, 6277, 1);
INSERT INTO 'dancesstepsmap' VALUES (5790, 6278, 4);
INSERT INTO 'dancesstepsmap' VALUES (5791, 6279, 4);
INSERT INTO 'dancesstepsmap' VALUES (5792, 6280, 1);
INSERT INTO 'dancesstepsmap' VALUES (5793, 6281, 1);
INSERT INTO 'dancesstepsmap' VALUES (5794, 6282, 1);
INSERT INTO 'dancesstepsmap' VALUES (5795, 6283, 1);
INSERT INTO 'dancesstepsmap' VALUES (5796, 6284, 1);
INSERT INTO 'dancesstepsmap' VALUES (5797, 6285, 4);
INSERT INTO 'dancesstepsmap' VALUES (5798, 6286, 1);
INSERT INTO 'dancesstepsmap' VALUES (5799, 6287, 1);
INSERT INTO 'dancesstepsmap' VALUES (5800, 6288, 1);
INSERT INTO 'dancesstepsmap' VALUES (5801, 6289, 1);
INSERT INTO 'dancesstepsmap' VALUES (5802, 6290, 1);
INSERT INTO 'dancesstepsmap' VALUES (5803, 6291, 1);
INSERT INTO 'dancesstepsmap' VALUES (5804, 6292, 1);
INSERT INTO 'dancesstepsmap' VALUES (5805, 6293, 4);
INSERT INTO 'dancesstepsmap' VALUES (5806, 6294, 1);
INSERT INTO 'dancesstepsmap' VALUES (5807, 6295, 1);
INSERT INTO 'dancesstepsmap' VALUES (5808, 6296, 1);
INSERT INTO 'dancesstepsmap' VALUES (5809, 6297, 1);
INSERT INTO 'dancesstepsmap' VALUES (5810, 6298, 1);
INSERT INTO 'dancesstepsmap' VALUES (5811, 6300, 1);
INSERT INTO 'dancesstepsmap' VALUES (5812, 6301, 1);
INSERT INTO 'dancesstepsmap' VALUES (5813, 6302, 4);
INSERT INTO 'dancesstepsmap' VALUES (5814, 6303, 4);
INSERT INTO 'dancesstepsmap' VALUES (5815, 6304, 4);
INSERT INTO 'dancesstepsmap' VALUES (5816, 6305, 1);
INSERT INTO 'dancesstepsmap' VALUES (5817, 6306, 4);
INSERT INTO 'dancesstepsmap' VALUES (5818, 6307, 1);
INSERT INTO 'dancesstepsmap' VALUES (5819, 6308, 1);
INSERT INTO 'dancesstepsmap' VALUES (5820, 6309, 1);
INSERT INTO 'dancesstepsmap' VALUES (5821, 6310, 4);
INSERT INTO 'dancesstepsmap' VALUES (5822, 6311, 4);
INSERT INTO 'dancesstepsmap' VALUES (5823, 6312, 1);
INSERT INTO 'dancesstepsmap' VALUES (5824, 6313, 4);
INSERT INTO 'dancesstepsmap' VALUES (5825, 6314, 1);
INSERT INTO 'dancesstepsmap' VALUES (5826, 6315, 4);
INSERT INTO 'dancesstepsmap' VALUES (5827, 6316, 1);
INSERT INTO 'dancesstepsmap' VALUES (5828, 6317, 1);
INSERT INTO 'dancesstepsmap' VALUES (5829, 6318, 1);
INSERT INTO 'dancesstepsmap' VALUES (12152, 10857, 2);
INSERT INTO 'dancesstepsmap' VALUES (12153, 10857, 1);
INSERT INTO 'dancesstepsmap' VALUES (12154, 10858, 4);
INSERT INTO 'dancesstepsmap' VALUES (12155, 10859, 2);
INSERT INTO 'dancesstepsmap' VALUES (12156, 10859, 1);
INSERT INTO 'dancesstepsmap' VALUES (12157, 10860, 5);
INSERT INTO 'dancesstepsmap' VALUES (12158, 10860, 2);
INSERT INTO 'dancesstepsmap' VALUES (12159, 10860, 10);
INSERT INTO 'dancesstepsmap' VALUES (12160, 10903, 2);
INSERT INTO 'dancesstepsmap' VALUES (12161, 10903, 1);
INSERT INTO 'dancesstepsmap' VALUES (12162, 10904, 1);
INSERT INTO 'dancesstepsmap' VALUES (12163, 10904, 3);
INSERT INTO 'dancesstepsmap' VALUES (12164, 10905, 4);
INSERT INTO 'dancesstepsmap' VALUES (12165, 10906, 4);
INSERT INTO 'dancesstepsmap' VALUES (12166, 10906, 5);
INSERT INTO 'dancesstepsmap' VALUES (12167, 10907, 1);
INSERT INTO 'dancesstepsmap' VALUES (12168, 10908, 1);
INSERT INTO 'dancesstepsmap' VALUES (12170, 10909, 4);
INSERT INTO 'dancesstepsmap' VALUES (12171, 10910, 5);
INSERT INTO 'dancesstepsmap' VALUES (12172, 10910, 4);
INSERT INTO 'dancesstepsmap' VALUES (12174, 10902, 1);
INSERT INTO 'dancesstepsmap' VALUES (12175, 10911, 1);
INSERT INTO 'dancesstepsmap' VALUES (12176, 1914, 2);
INSERT INTO 'dancesstepsmap' VALUES (12177, 1914, 1);
INSERT INTO 'dancesstepsmap' VALUES (12178, 8857, 4);
INSERT INTO 'dancesstepsmap' VALUES (12179, 8857, 5);
INSERT INTO 'dancesstepsmap' VALUES (12180, 10912, 3);
INSERT INTO 'dancesstepsmap' VALUES (12181, 10912, 1);
INSERT INTO 'dancesstepsmap' VALUES (12182, 10913, 4);
INSERT INTO 'dancesstepsmap' VALUES (12183, 10914, 2);
INSERT INTO 'dancesstepsmap' VALUES (12184, 10914, 1);
INSERT INTO 'dancesstepsmap' VALUES (12185, 10914, 3);
INSERT INTO 'dancesstepsmap' VALUES (12186, 10915, 1);
INSERT INTO 'dancesstepsmap' VALUES (12187, 10915, 3);
INSERT INTO 'dancesstepsmap' VALUES (12188, 10916, 2);
INSERT INTO 'dancesstepsmap' VALUES (12189, 10916, 1);
INSERT INTO 'dancesstepsmap' VALUES (12190, 10916, 3);
INSERT INTO 'dancesstepsmap' VALUES (12191, 1247, 5);
INSERT INTO 'dancesstepsmap' VALUES (12192, 1247, 6);
INSERT INTO 'dancesstepsmap' VALUES (12193, 10917, 2);
INSERT INTO 'dancesstepsmap' VALUES (12194, 10917, 3);
INSERT INTO 'dancesstepsmap' VALUES (17274, 14630, 5);
INSERT INTO 'dancesstepsmap' VALUES (17275, 14630, 4);
INSERT INTO 'dancesstepsmap' VALUES (5830, 6319, 4);
INSERT INTO 'dancesstepsmap' VALUES (5831, 6320, 4);
INSERT INTO 'dancesstepsmap' VALUES (5832, 6321, 1);
INSERT INTO 'dancesstepsmap' VALUES (5833, 6322, 1);
INSERT INTO 'dancesstepsmap' VALUES (5834, 6323, 4);
INSERT INTO 'dancesstepsmap' VALUES (5835, 6324, 1);
INSERT INTO 'dancesstepsmap' VALUES (5836, 6325, 1);
INSERT INTO 'dancesstepsmap' VALUES (5837, 6326, 1);
INSERT INTO 'dancesstepsmap' VALUES (5838, 6327, 4);
INSERT INTO 'dancesstepsmap' VALUES (5839, 6328, 1);
INSERT INTO 'dancesstepsmap' VALUES (5840, 6329, 1);
INSERT INTO 'dancesstepsmap' VALUES (5841, 6331, 1);
INSERT INTO 'dancesstepsmap' VALUES (5842, 6332, 4);
INSERT INTO 'dancesstepsmap' VALUES (5843, 6333, 4);
INSERT INTO 'dancesstepsmap' VALUES (5844, 6334, 1);
INSERT INTO 'dancesstepsmap' VALUES (5845, 6335, 4);
INSERT INTO 'dancesstepsmap' VALUES (5846, 6336, 4);
INSERT INTO 'dancesstepsmap' VALUES (5847, 6337, 4);
INSERT INTO 'dancesstepsmap' VALUES (5848, 6338, 1);
INSERT INTO 'dancesstepsmap' VALUES (5849, 6339, 4);
INSERT INTO 'dancesstepsmap' VALUES (5850, 6340, 1);
INSERT INTO 'dancesstepsmap' VALUES (5851, 6341, 1);
INSERT INTO 'dancesstepsmap' VALUES (5852, 6342, 4);
INSERT INTO 'dancesstepsmap' VALUES (5853, 6343, 4);
INSERT INTO 'dancesstepsmap' VALUES (5854, 6344, 1);
INSERT INTO 'dancesstepsmap' VALUES (5855, 6345, 4);
INSERT INTO 'dancesstepsmap' VALUES (5856, 6346, 1);
INSERT INTO 'dancesstepsmap' VALUES (5857, 6348, 1);
INSERT INTO 'dancesstepsmap' VALUES (5858, 6349, 4);
INSERT INTO 'dancesstepsmap' VALUES (5859, 6350, 4);
INSERT INTO 'dancesstepsmap' VALUES (5860, 6351, 4);
INSERT INTO 'dancesstepsmap' VALUES (5861, 6352, 4);
INSERT INTO 'dancesstepsmap' VALUES (5862, 6353, 4);
INSERT INTO 'dancesstepsmap' VALUES (5863, 6354, 4);
INSERT INTO 'dancesstepsmap' VALUES (5864, 6356, 1);
INSERT INTO 'dancesstepsmap' VALUES (5865, 6357, 1);
INSERT INTO 'dancesstepsmap' VALUES (5866, 6358, 4);
INSERT INTO 'dancesstepsmap' VALUES (5867, 6360, 1);
INSERT INTO 'dancesstepsmap' VALUES (5868, 6361, 4);
INSERT INTO 'dancesstepsmap' VALUES (5869, 6362, 1);
INSERT INTO 'dancesstepsmap' VALUES (5870, 6363, 4);
INSERT INTO 'dancesstepsmap' VALUES (5871, 6364, 4);
INSERT INTO 'dancesstepsmap' VALUES (5872, 6365, 4);
INSERT INTO 'dancesstepsmap' VALUES (5873, 6366, 1);
INSERT INTO 'dancesstepsmap' VALUES (23149, 17885, 2);
INSERT INTO 'dancesstepsmap' VALUES (5875, 6368, 4);
INSERT INTO 'dancesstepsmap' VALUES (5876, 6369, 1);
INSERT INTO 'dancesstepsmap' VALUES (5877, 6370, 1);
INSERT INTO 'dancesstepsmap' VALUES (5878, 6371, 1);
INSERT INTO 'dancesstepsmap' VALUES (5879, 6372, 1);
INSERT INTO 'dancesstepsmap' VALUES (5880, 6373, 4);
INSERT INTO 'dancesstepsmap' VALUES (5881, 6374, 1);
INSERT INTO 'dancesstepsmap' VALUES (5882, 6375, 4);
INSERT INTO 'dancesstepsmap' VALUES (5883, 6376, 1);
INSERT INTO 'dancesstepsmap' VALUES (5884, 6377, 1);
INSERT INTO 'dancesstepsmap' VALUES (5885, 6378, 1);
INSERT INTO 'dancesstepsmap' VALUES (5886, 6379, 1);
INSERT INTO 'dancesstepsmap' VALUES (5887, 6380, 1);
INSERT INTO 'dancesstepsmap' VALUES (5888, 6381, 1);
INSERT INTO 'dancesstepsmap' VALUES (5889, 6382, 4);
INSERT INTO 'dancesstepsmap' VALUES (5890, 6383, 4);
INSERT INTO 'dancesstepsmap' VALUES (5891, 6384, 4);
INSERT INTO 'dancesstepsmap' VALUES (5892, 6385, 4);
INSERT INTO 'dancesstepsmap' VALUES (5893, 6386, 1);
INSERT INTO 'dancesstepsmap' VALUES (5894, 6387, 1);
INSERT INTO 'dancesstepsmap' VALUES (5895, 6388, 1);
INSERT INTO 'dancesstepsmap' VALUES (5896, 6389, 4);
INSERT INTO 'dancesstepsmap' VALUES (5897, 6390, 1);
INSERT INTO 'dancesstepsmap' VALUES (5898, 6391, 1);
INSERT INTO 'dancesstepsmap' VALUES (5899, 6392, 1);
INSERT INTO 'dancesstepsmap' VALUES (5900, 6393, 4);
INSERT INTO 'dancesstepsmap' VALUES (5901, 6394, 1);
INSERT INTO 'dancesstepsmap' VALUES (5902, 6395, 4);
INSERT INTO 'dancesstepsmap' VALUES (5903, 6397, 4);
INSERT INTO 'dancesstepsmap' VALUES (5904, 6398, 1);
INSERT INTO 'dancesstepsmap' VALUES (5905, 6399, 1);
INSERT INTO 'dancesstepsmap' VALUES (5906, 6400, 1);
INSERT INTO 'dancesstepsmap' VALUES (5907, 6401, 4);
INSERT INTO 'dancesstepsmap' VALUES (5908, 6402, 1);
INSERT INTO 'dancesstepsmap' VALUES (5909, 6404, 1);
INSERT INTO 'dancesstepsmap' VALUES (5910, 6405, 4);
INSERT INTO 'dancesstepsmap' VALUES (5911, 6406, 1);
INSERT INTO 'dancesstepsmap' VALUES (5912, 6407, 1);
INSERT INTO 'dancesstepsmap' VALUES (5913, 6408, 1);
INSERT INTO 'dancesstepsmap' VALUES (5914, 6409, 4);
INSERT INTO 'dancesstepsmap' VALUES (5915, 6410, 1);
INSERT INTO 'dancesstepsmap' VALUES (5916, 6411, 4);
INSERT INTO 'dancesstepsmap' VALUES (5917, 6412, 4);
INSERT INTO 'dancesstepsmap' VALUES (5918, 6413, 4);
INSERT INTO 'dancesstepsmap' VALUES (5919, 6414, 4);
INSERT INTO 'dancesstepsmap' VALUES (5920, 6415, 4);
INSERT INTO 'dancesstepsmap' VALUES (5921, 6416, 1);
INSERT INTO 'dancesstepsmap' VALUES (5922, 6417, 4);
INSERT INTO 'dancesstepsmap' VALUES (12195, 7018, 3);
INSERT INTO 'dancesstepsmap' VALUES (12196, 10918, 1);
INSERT INTO 'dancesstepsmap' VALUES (12197, 10919, 1);
INSERT INTO 'dancesstepsmap' VALUES (12198, 10920, 1);
INSERT INTO 'dancesstepsmap' VALUES (12199, 10921, 4);
INSERT INTO 'dancesstepsmap' VALUES (12200, 10921, 5);
INSERT INTO 'dancesstepsmap' VALUES (12202, 10927, 1);
INSERT INTO 'dancesstepsmap' VALUES (12203, 10928, 1);
INSERT INTO 'dancesstepsmap' VALUES (12204, 10928, 3);
INSERT INTO 'dancesstepsmap' VALUES (12205, 10929, 1);
INSERT INTO 'dancesstepsmap' VALUES (12206, 8986, 2);
INSERT INTO 'dancesstepsmap' VALUES (12207, 8986, 1);
INSERT INTO 'dancesstepsmap' VALUES (12208, 10931, 1);
INSERT INTO 'dancesstepsmap' VALUES (12209, 10931, 2);
INSERT INTO 'dancesstepsmap' VALUES (12210, 6334, 2);
INSERT INTO 'dancesstepsmap' VALUES (12211, 10933, 1);
INSERT INTO 'dancesstepsmap' VALUES (12212, 10933, 3);
INSERT INTO 'dancesstepsmap' VALUES (12213, 10934, 1);
INSERT INTO 'dancesstepsmap' VALUES (12214, 10935, 1);
INSERT INTO 'dancesstepsmap' VALUES (12215, 10936, 6);
INSERT INTO 'dancesstepsmap' VALUES (12216, 10936, 4);
INSERT INTO 'dancesstepsmap' VALUES (12217, 10936, 5);
INSERT INTO 'dancesstepsmap' VALUES (12218, 10937, 2);
INSERT INTO 'dancesstepsmap' VALUES (12219, 10937, 1);
INSERT INTO 'dancesstepsmap' VALUES (12220, 10937, 3);
INSERT INTO 'dancesstepsmap' VALUES (12221, 10938, 1);
INSERT INTO 'dancesstepsmap' VALUES (12222, 10938, 2);
INSERT INTO 'dancesstepsmap' VALUES (12223, 10939, 1);
INSERT INTO 'dancesstepsmap' VALUES (12224, 10940, 4);
INSERT INTO 'dancesstepsmap' VALUES (12225, 10941, 1);
INSERT INTO 'dancesstepsmap' VALUES (12226, 10941, 3);
INSERT INTO 'dancesstepsmap' VALUES (12227, 10942, 1);
INSERT INTO 'dancesstepsmap' VALUES (12228, 10942, 3);
INSERT INTO 'dancesstepsmap' VALUES (12229, 10943, 1);
INSERT INTO 'dancesstepsmap' VALUES (12230, 10944, 3);
INSERT INTO 'dancesstepsmap' VALUES (12231, 10944, 1);
INSERT INTO 'dancesstepsmap' VALUES (12232, 10945, 1);
INSERT INTO 'dancesstepsmap' VALUES (12233, 10946, 1);
INSERT INTO 'dancesstepsmap' VALUES (12234, 10947, 3);
INSERT INTO 'dancesstepsmap' VALUES (12235, 10947, 1);
INSERT INTO 'dancesstepsmap' VALUES (12236, 10948, 4);
INSERT INTO 'dancesstepsmap' VALUES (17276, 14631, 2);
INSERT INTO 'dancesstepsmap' VALUES (17277, 14631, 1);
INSERT INTO 'dancesstepsmap' VALUES (5923, 6418, 4);
INSERT INTO 'dancesstepsmap' VALUES (5924, 6419, 4);
INSERT INTO 'dancesstepsmap' VALUES (5925, 6420, 1);
INSERT INTO 'dancesstepsmap' VALUES (5926, 6421, 1);
INSERT INTO 'dancesstepsmap' VALUES (5927, 6422, 1);
INSERT INTO 'dancesstepsmap' VALUES (5928, 6423, 4);
INSERT INTO 'dancesstepsmap' VALUES (5929, 6424, 1);
INSERT INTO 'dancesstepsmap' VALUES (5930, 6425, 4);
INSERT INTO 'dancesstepsmap' VALUES (5931, 6426, 1);
INSERT INTO 'dancesstepsmap' VALUES (5932, 6427, 4);
INSERT INTO 'dancesstepsmap' VALUES (5933, 6428, 1);
INSERT INTO 'dancesstepsmap' VALUES (5934, 6429, 1);
INSERT INTO 'dancesstepsmap' VALUES (5935, 6430, 1);
INSERT INTO 'dancesstepsmap' VALUES (5936, 6431, 1);
INSERT INTO 'dancesstepsmap' VALUES (5937, 6432, 4);
INSERT INTO 'dancesstepsmap' VALUES (5938, 6433, 1);
INSERT INTO 'dancesstepsmap' VALUES (5939, 6434, 1);
INSERT INTO 'dancesstepsmap' VALUES (5940, 6435, 1);
INSERT INTO 'dancesstepsmap' VALUES (5941, 6436, 1);
INSERT INTO 'dancesstepsmap' VALUES (5942, 6437, 1);
INSERT INTO 'dancesstepsmap' VALUES (5943, 6438, 1);
INSERT INTO 'dancesstepsmap' VALUES (5944, 6439, 4);
INSERT INTO 'dancesstepsmap' VALUES (5945, 6440, 1);
INSERT INTO 'dancesstepsmap' VALUES (5946, 6441, 1);
INSERT INTO 'dancesstepsmap' VALUES (5947, 6442, 1);
INSERT INTO 'dancesstepsmap' VALUES (5948, 6443, 1);
INSERT INTO 'dancesstepsmap' VALUES (5949, 6444, 1);
INSERT INTO 'dancesstepsmap' VALUES (5950, 6445, 4);
INSERT INTO 'dancesstepsmap' VALUES (5951, 6446, 1);
INSERT INTO 'dancesstepsmap' VALUES (5952, 6447, 4);
INSERT INTO 'dancesstepsmap' VALUES (5953, 6448, 1);
INSERT INTO 'dancesstepsmap' VALUES (5954, 6449, 1);
INSERT INTO 'dancesstepsmap' VALUES (5955, 6450, 1);
INSERT INTO 'dancesstepsmap' VALUES (5956, 6451, 1);
INSERT INTO 'dancesstepsmap' VALUES (5957, 6452, 1);
INSERT INTO 'dancesstepsmap' VALUES (5958, 6454, 1);
INSERT INTO 'dancesstepsmap' VALUES (5959, 6455, 1);
INSERT INTO 'dancesstepsmap' VALUES (5960, 6457, 1);
INSERT INTO 'dancesstepsmap' VALUES (5961, 6458, 4);
INSERT INTO 'dancesstepsmap' VALUES (5962, 6459, 1);
INSERT INTO 'dancesstepsmap' VALUES (5963, 6460, 1);
INSERT INTO 'dancesstepsmap' VALUES (5964, 6461, 1);
INSERT INTO 'dancesstepsmap' VALUES (5965, 6462, 1);
INSERT INTO 'dancesstepsmap' VALUES (5966, 6463, 1);
INSERT INTO 'dancesstepsmap' VALUES (5967, 6464, 1);
INSERT INTO 'dancesstepsmap' VALUES (5968, 6465, 1);
INSERT INTO 'dancesstepsmap' VALUES (5969, 6466, 1);
INSERT INTO 'dancesstepsmap' VALUES (5970, 6467, 1);
INSERT INTO 'dancesstepsmap' VALUES (5971, 6468, 1);
INSERT INTO 'dancesstepsmap' VALUES (5972, 6469, 4);
INSERT INTO 'dancesstepsmap' VALUES (5973, 6471, 1);
INSERT INTO 'dancesstepsmap' VALUES (5974, 6472, 1);
INSERT INTO 'dancesstepsmap' VALUES (5975, 6473, 1);
INSERT INTO 'dancesstepsmap' VALUES (5976, 6474, 1);
INSERT INTO 'dancesstepsmap' VALUES (5977, 6475, 1);
INSERT INTO 'dancesstepsmap' VALUES (5978, 6476, 1);
INSERT INTO 'dancesstepsmap' VALUES (5979, 6477, 4);
INSERT INTO 'dancesstepsmap' VALUES (5980, 6478, 1);
INSERT INTO 'dancesstepsmap' VALUES (5981, 6480, 4);
INSERT INTO 'dancesstepsmap' VALUES (5982, 6481, 4);
INSERT INTO 'dancesstepsmap' VALUES (5983, 6482, 1);
INSERT INTO 'dancesstepsmap' VALUES (5984, 6483, 1);
INSERT INTO 'dancesstepsmap' VALUES (5985, 6484, 1);
INSERT INTO 'dancesstepsmap' VALUES (5986, 6485, 1);
INSERT INTO 'dancesstepsmap' VALUES (5987, 6486, 1);
INSERT INTO 'dancesstepsmap' VALUES (5988, 6487, 1);
INSERT INTO 'dancesstepsmap' VALUES (5989, 6488, 4);
INSERT INTO 'dancesstepsmap' VALUES (5990, 6489, 1);
INSERT INTO 'dancesstepsmap' VALUES (5991, 6491, 1);
INSERT INTO 'dancesstepsmap' VALUES (5992, 6492, 1);
INSERT INTO 'dancesstepsmap' VALUES (5993, 6494, 1);
INSERT INTO 'dancesstepsmap' VALUES (5994, 6495, 1);
INSERT INTO 'dancesstepsmap' VALUES (5995, 6496, 1);
INSERT INTO 'dancesstepsmap' VALUES (5996, 6497, 1);
INSERT INTO 'dancesstepsmap' VALUES (5997, 6498, 4);
INSERT INTO 'dancesstepsmap' VALUES (5998, 6499, 1);
INSERT INTO 'dancesstepsmap' VALUES (5999, 6500, 1);
INSERT INTO 'dancesstepsmap' VALUES (6000, 6501, 4);
INSERT INTO 'dancesstepsmap' VALUES (6001, 6502, 1);
INSERT INTO 'dancesstepsmap' VALUES (6002, 6503, 1);
INSERT INTO 'dancesstepsmap' VALUES (6003, 6504, 4);
INSERT INTO 'dancesstepsmap' VALUES (6004, 6505, 1);
INSERT INTO 'dancesstepsmap' VALUES (6005, 6507, 1);
INSERT INTO 'dancesstepsmap' VALUES (6006, 6508, 4);
INSERT INTO 'dancesstepsmap' VALUES (6007, 6509, 1);
INSERT INTO 'dancesstepsmap' VALUES (6008, 6510, 4);
INSERT INTO 'dancesstepsmap' VALUES (6009, 6511, 4);
INSERT INTO 'dancesstepsmap' VALUES (6010, 6512, 4);
INSERT INTO 'dancesstepsmap' VALUES (6011, 6513, 1);
INSERT INTO 'dancesstepsmap' VALUES (6012, 6514, 1);
INSERT INTO 'dancesstepsmap' VALUES (6013, 6515, 1);
INSERT INTO 'dancesstepsmap' VALUES (6014, 6516, 4);
INSERT INTO 'dancesstepsmap' VALUES (6015, 6517, 1);
INSERT INTO 'dancesstepsmap' VALUES (6016, 6518, 4);
INSERT INTO 'dancesstepsmap' VALUES (6017, 6519, 1);
INSERT INTO 'dancesstepsmap' VALUES (6018, 6520, 1);
INSERT INTO 'dancesstepsmap' VALUES (6019, 6521, 1);
INSERT INTO 'dancesstepsmap' VALUES (6020, 6522, 1);
INSERT INTO 'dancesstepsmap' VALUES (6021, 6523, 4);
INSERT INTO 'dancesstepsmap' VALUES (6022, 6524, 4);
INSERT INTO 'dancesstepsmap' VALUES (6023, 6525, 1);
INSERT INTO 'dancesstepsmap' VALUES (6024, 6526, 4);
INSERT INTO 'dancesstepsmap' VALUES (6026, 6529, 1);
INSERT INTO 'dancesstepsmap' VALUES (6027, 6530, 1);
INSERT INTO 'dancesstepsmap' VALUES (6028, 6531, 1);
INSERT INTO 'dancesstepsmap' VALUES (6029, 6533, 1);
INSERT INTO 'dancesstepsmap' VALUES (6030, 6534, 1);
INSERT INTO 'dancesstepsmap' VALUES (6031, 6535, 1);
INSERT INTO 'dancesstepsmap' VALUES (6032, 6536, 1);
INSERT INTO 'dancesstepsmap' VALUES (6033, 6538, 1);
INSERT INTO 'dancesstepsmap' VALUES (6034, 6539, 4);
INSERT INTO 'dancesstepsmap' VALUES (6035, 6540, 1);
INSERT INTO 'dancesstepsmap' VALUES (6036, 6541, 4);
INSERT INTO 'dancesstepsmap' VALUES (6037, 6542, 4);
INSERT INTO 'dancesstepsmap' VALUES (6038, 6543, 1);
INSERT INTO 'dancesstepsmap' VALUES (6039, 6544, 1);
INSERT INTO 'dancesstepsmap' VALUES (6040, 6545, 1);
INSERT INTO 'dancesstepsmap' VALUES (6041, 6546, 1);
INSERT INTO 'dancesstepsmap' VALUES (6042, 6547, 1);
INSERT INTO 'dancesstepsmap' VALUES (6043, 6548, 1);
INSERT INTO 'dancesstepsmap' VALUES (6044, 6549, 1);
INSERT INTO 'dancesstepsmap' VALUES (6045, 6550, 1);
INSERT INTO 'dancesstepsmap' VALUES (6046, 6551, 1);
INSERT INTO 'dancesstepsmap' VALUES (6047, 6552, 1);
INSERT INTO 'dancesstepsmap' VALUES (6048, 6555, 4);
INSERT INTO 'dancesstepsmap' VALUES (6049, 6556, 1);
INSERT INTO 'dancesstepsmap' VALUES (6050, 6557, 1);
INSERT INTO 'dancesstepsmap' VALUES (6051, 6558, 1);
INSERT INTO 'dancesstepsmap' VALUES (6052, 6559, 1);
INSERT INTO 'dancesstepsmap' VALUES (6053, 6560, 1);
INSERT INTO 'dancesstepsmap' VALUES (12237, 10949, 3);
INSERT INTO 'dancesstepsmap' VALUES (12238, 10949, 1);
INSERT INTO 'dancesstepsmap' VALUES (12239, 10950, 7);
INSERT INTO 'dancesstepsmap' VALUES (12240, 10952, 4);
INSERT INTO 'dancesstepsmap' VALUES (12241, 10952, 5);
INSERT INTO 'dancesstepsmap' VALUES (12242, 10957, 1);
INSERT INTO 'dancesstepsmap' VALUES (12243, 10958, 1);
INSERT INTO 'dancesstepsmap' VALUES (12244, 10959, 3);
INSERT INTO 'dancesstepsmap' VALUES (12245, 10959, 1);
INSERT INTO 'dancesstepsmap' VALUES (12246, 10960, 1);
INSERT INTO 'dancesstepsmap' VALUES (12247, 10960, 3);
INSERT INTO 'dancesstepsmap' VALUES (12248, 10961, 1);
INSERT INTO 'dancesstepsmap' VALUES (12249, 10961, 3);
INSERT INTO 'dancesstepsmap' VALUES (12250, 10967, 4);
INSERT INTO 'dancesstepsmap' VALUES (12251, 10968, 2);
INSERT INTO 'dancesstepsmap' VALUES (17278, 14632, 2);
INSERT INTO 'dancesstepsmap' VALUES (6054, 6561, 4);
INSERT INTO 'dancesstepsmap' VALUES (6055, 6562, 1);
INSERT INTO 'dancesstepsmap' VALUES (6056, 6563, 1);
INSERT INTO 'dancesstepsmap' VALUES (6057, 6564, 4);
INSERT INTO 'dancesstepsmap' VALUES (6058, 6565, 4);
INSERT INTO 'dancesstepsmap' VALUES (6059, 6566, 4);
INSERT INTO 'dancesstepsmap' VALUES (6060, 6567, 4);
INSERT INTO 'dancesstepsmap' VALUES (6061, 6569, 4);
INSERT INTO 'dancesstepsmap' VALUES (6062, 6570, 1);
INSERT INTO 'dancesstepsmap' VALUES (6063, 6571, 1);
INSERT INTO 'dancesstepsmap' VALUES (6064, 6572, 1);
INSERT INTO 'dancesstepsmap' VALUES (6065, 6573, 1);
INSERT INTO 'dancesstepsmap' VALUES (6066, 6574, 1);
INSERT INTO 'dancesstepsmap' VALUES (6067, 6576, 1);
INSERT INTO 'dancesstepsmap' VALUES (6068, 6577, 4);
INSERT INTO 'dancesstepsmap' VALUES (6069, 6578, 4);
INSERT INTO 'dancesstepsmap' VALUES (6070, 6579, 1);
INSERT INTO 'dancesstepsmap' VALUES (6071, 6580, 1);
INSERT INTO 'dancesstepsmap' VALUES (6072, 6582, 1);
INSERT INTO 'dancesstepsmap' VALUES (6073, 6583, 1);
INSERT INTO 'dancesstepsmap' VALUES (6074, 6586, 4);
INSERT INTO 'dancesstepsmap' VALUES (6075, 6587, 4);
INSERT INTO 'dancesstepsmap' VALUES (6076, 6588, 4);
INSERT INTO 'dancesstepsmap' VALUES (6077, 6589, 1);
INSERT INTO 'dancesstepsmap' VALUES (6078, 6590, 1);
INSERT INTO 'dancesstepsmap' VALUES (6079, 6591, 1);
INSERT INTO 'dancesstepsmap' VALUES (6080, 6592, 1);
INSERT INTO 'dancesstepsmap' VALUES (6081, 6594, 1);
INSERT INTO 'dancesstepsmap' VALUES (6082, 6595, 1);
INSERT INTO 'dancesstepsmap' VALUES (6083, 6596, 4);
INSERT INTO 'dancesstepsmap' VALUES (6084, 6597, 1);
INSERT INTO 'dancesstepsmap' VALUES (6085, 6598, 1);
INSERT INTO 'dancesstepsmap' VALUES (6086, 6599, 4);
INSERT INTO 'dancesstepsmap' VALUES (6087, 6600, 1);
INSERT INTO 'dancesstepsmap' VALUES (6088, 6601, 1);
INSERT INTO 'dancesstepsmap' VALUES (6089, 6602, 1);
INSERT INTO 'dancesstepsmap' VALUES (6090, 6605, 1);
INSERT INTO 'dancesstepsmap' VALUES (6091, 6606, 1);
INSERT INTO 'dancesstepsmap' VALUES (6093, 6608, 1);
INSERT INTO 'dancesstepsmap' VALUES (6094, 6609, 1);
INSERT INTO 'dancesstepsmap' VALUES (6095, 6610, 1);
INSERT INTO 'dancesstepsmap' VALUES (6096, 6611, 1);
INSERT INTO 'dancesstepsmap' VALUES (6097, 6612, 1);
INSERT INTO 'dancesstepsmap' VALUES (6098, 6613, 1);
INSERT INTO 'dancesstepsmap' VALUES (6099, 6614, 1);
INSERT INTO 'dancesstepsmap' VALUES (6100, 6615, 1);
INSERT INTO 'dancesstepsmap' VALUES (6101, 6617, 1);
INSERT INTO 'dancesstepsmap' VALUES (6102, 6618, 1);
INSERT INTO 'dancesstepsmap' VALUES (6103, 6619, 1);
INSERT INTO 'dancesstepsmap' VALUES (6104, 6620, 1);
INSERT INTO 'dancesstepsmap' VALUES (6105, 6621, 1);
INSERT INTO 'dancesstepsmap' VALUES (6106, 6623, 1);
INSERT INTO 'dancesstepsmap' VALUES (6108, 6625, 1);
INSERT INTO 'dancesstepsmap' VALUES (6109, 6626, 4);
INSERT INTO 'dancesstepsmap' VALUES (6110, 6627, 1);
INSERT INTO 'dancesstepsmap' VALUES (6111, 6628, 4);
INSERT INTO 'dancesstepsmap' VALUES (6112, 6629, 1);
INSERT INTO 'dancesstepsmap' VALUES (6113, 6631, 1);
INSERT INTO 'dancesstepsmap' VALUES (6114, 6632, 1);
INSERT INTO 'dancesstepsmap' VALUES (6115, 6633, 1);
INSERT INTO 'dancesstepsmap' VALUES (6116, 6634, 1);
INSERT INTO 'dancesstepsmap' VALUES (6117, 6636, 1);
INSERT INTO 'dancesstepsmap' VALUES (6118, 6637, 1);
INSERT INTO 'dancesstepsmap' VALUES (6119, 6638, 1);
INSERT INTO 'dancesstepsmap' VALUES (6120, 6639, 1);
INSERT INTO 'dancesstepsmap' VALUES (6121, 6640, 4);
INSERT INTO 'dancesstepsmap' VALUES (6122, 6641, 1);
INSERT INTO 'dancesstepsmap' VALUES (6123, 6643, 1);
INSERT INTO 'dancesstepsmap' VALUES (6124, 6644, 1);
INSERT INTO 'dancesstepsmap' VALUES (6125, 6645, 1);
INSERT INTO 'dancesstepsmap' VALUES (6126, 6646, 1);
INSERT INTO 'dancesstepsmap' VALUES (6127, 6647, 1);
INSERT INTO 'dancesstepsmap' VALUES (6128, 6648, 1);
INSERT INTO 'dancesstepsmap' VALUES (6129, 6649, 1);
INSERT INTO 'dancesstepsmap' VALUES (6130, 6650, 1);
INSERT INTO 'dancesstepsmap' VALUES (6131, 6651, 1);
INSERT INTO 'dancesstepsmap' VALUES (6132, 6652, 4);
INSERT INTO 'dancesstepsmap' VALUES (6133, 6653, 1);
INSERT INTO 'dancesstepsmap' VALUES (6134, 6654, 4);
INSERT INTO 'dancesstepsmap' VALUES (6135, 6655, 4);
INSERT INTO 'dancesstepsmap' VALUES (6136, 6656, 4);
INSERT INTO 'dancesstepsmap' VALUES (6137, 6657, 1);
INSERT INTO 'dancesstepsmap' VALUES (6138, 6658, 1);
INSERT INTO 'dancesstepsmap' VALUES (6139, 6659, 1);
INSERT INTO 'dancesstepsmap' VALUES (6140, 6660, 1);
INSERT INTO 'dancesstepsmap' VALUES (6141, 6661, 1);
INSERT INTO 'dancesstepsmap' VALUES (6142, 6662, 1);
INSERT INTO 'dancesstepsmap' VALUES (6143, 6663, 4);
INSERT INTO 'dancesstepsmap' VALUES (6144, 6664, 1);
INSERT INTO 'dancesstepsmap' VALUES (6145, 6665, 4);
INSERT INTO 'dancesstepsmap' VALUES (12252, 10968, 1);
INSERT INTO 'dancesstepsmap' VALUES (12253, 10977, 2);
INSERT INTO 'dancesstepsmap' VALUES (12254, 10977, 1);
INSERT INTO 'dancesstepsmap' VALUES (12256, 10716, 4);
INSERT INTO 'dancesstepsmap' VALUES (12257, 3326, 2);
INSERT INTO 'dancesstepsmap' VALUES (12258, 6712, 2);
INSERT INTO 'dancesstepsmap' VALUES (12259, 11029, 2);
INSERT INTO 'dancesstepsmap' VALUES (12260, 11029, 5);
INSERT INTO 'dancesstepsmap' VALUES (12261, 11030, 2);
INSERT INTO 'dancesstepsmap' VALUES (12262, 11032, 3);
INSERT INTO 'dancesstepsmap' VALUES (12263, 11033, 2);
INSERT INTO 'dancesstepsmap' VALUES (12264, 11033, 1);
INSERT INTO 'dancesstepsmap' VALUES (12265, 11034, 3);
INSERT INTO 'dancesstepsmap' VALUES (12266, 11035, 2);
INSERT INTO 'dancesstepsmap' VALUES (12267, 11036, 4);
INSERT INTO 'dancesstepsmap' VALUES (12268, 11037, 4);
INSERT INTO 'dancesstepsmap' VALUES (12269, 11038, 5);
INSERT INTO 'dancesstepsmap' VALUES (12270, 11038, 4);
INSERT INTO 'dancesstepsmap' VALUES (12271, 11039, 4);
INSERT INTO 'dancesstepsmap' VALUES (12272, 11040, 3);
INSERT INTO 'dancesstepsmap' VALUES (12273, 11040, 1);
INSERT INTO 'dancesstepsmap' VALUES (12274, 11041, 1);
INSERT INTO 'dancesstepsmap' VALUES (12275, 11041, 3);
INSERT INTO 'dancesstepsmap' VALUES (12276, 11042, 1);
INSERT INTO 'dancesstepsmap' VALUES (12277, 11043, 5);
INSERT INTO 'dancesstepsmap' VALUES (12278, 11043, 4);
INSERT INTO 'dancesstepsmap' VALUES (12279, 11044, 1);
INSERT INTO 'dancesstepsmap' VALUES (12280, 11044, 3);
INSERT INTO 'dancesstepsmap' VALUES (12281, 11045, 5);
INSERT INTO 'dancesstepsmap' VALUES (12255, 10978, 1);
INSERT INTO 'dancesstepsmap' VALUES (12282, 11045, 1);
INSERT INTO 'dancesstepsmap' VALUES (12283, 11045, 2);
INSERT INTO 'dancesstepsmap' VALUES (12284, 11045, 4);
INSERT INTO 'dancesstepsmap' VALUES (12285, 11046, 2);
INSERT INTO 'dancesstepsmap' VALUES (12286, 11046, 1);
INSERT INTO 'dancesstepsmap' VALUES (12287, 11046, 3);
INSERT INTO 'dancesstepsmap' VALUES (12288, 11047, 5);
INSERT INTO 'dancesstepsmap' VALUES (12289, 11047, 4);
INSERT INTO 'dancesstepsmap' VALUES (12290, 11048, 4);
INSERT INTO 'dancesstepsmap' VALUES (12291, 11049, 4);
INSERT INTO 'dancesstepsmap' VALUES (12292, 11050, 4);
INSERT INTO 'dancesstepsmap' VALUES (12293, 9474, 4);
INSERT INTO 'dancesstepsmap' VALUES (12294, 112, 5);
INSERT INTO 'dancesstepsmap' VALUES (17279, 14632, 1);
INSERT INTO 'dancesstepsmap' VALUES (6146, 6666, 1);
INSERT INTO 'dancesstepsmap' VALUES (6147, 6667, 1);
INSERT INTO 'dancesstepsmap' VALUES (6148, 6668, 1);
INSERT INTO 'dancesstepsmap' VALUES (6149, 6669, 1);
INSERT INTO 'dancesstepsmap' VALUES (6150, 6670, 1);
INSERT INTO 'dancesstepsmap' VALUES (6151, 6671, 4);
INSERT INTO 'dancesstepsmap' VALUES (6152, 6673, 4);
INSERT INTO 'dancesstepsmap' VALUES (6153, 6674, 1);
INSERT INTO 'dancesstepsmap' VALUES (6154, 6675, 4);
INSERT INTO 'dancesstepsmap' VALUES (6155, 6676, 4);
INSERT INTO 'dancesstepsmap' VALUES (6156, 6677, 1);
INSERT INTO 'dancesstepsmap' VALUES (6157, 6679, 1);
INSERT INTO 'dancesstepsmap' VALUES (6158, 6680, 1);
INSERT INTO 'dancesstepsmap' VALUES (6159, 6681, 1);
INSERT INTO 'dancesstepsmap' VALUES (6160, 6682, 1);
INSERT INTO 'dancesstepsmap' VALUES (6161, 6683, 1);
INSERT INTO 'dancesstepsmap' VALUES (6162, 6684, 1);
INSERT INTO 'dancesstepsmap' VALUES (6163, 6685, 1);
INSERT INTO 'dancesstepsmap' VALUES (6164, 6686, 1);
INSERT INTO 'dancesstepsmap' VALUES (6165, 6687, 1);
INSERT INTO 'dancesstepsmap' VALUES (6166, 6688, 1);
INSERT INTO 'dancesstepsmap' VALUES (6167, 6689, 1);
INSERT INTO 'dancesstepsmap' VALUES (6168, 6690, 1);
INSERT INTO 'dancesstepsmap' VALUES (6169, 6692, 4);
INSERT INTO 'dancesstepsmap' VALUES (6170, 6693, 4);
INSERT INTO 'dancesstepsmap' VALUES (6171, 6694, 1);
INSERT INTO 'dancesstepsmap' VALUES (6172, 6695, 1);
INSERT INTO 'dancesstepsmap' VALUES (6173, 6696, 1);
INSERT INTO 'dancesstepsmap' VALUES (6174, 6697, 1);
INSERT INTO 'dancesstepsmap' VALUES (6175, 6698, 1);
INSERT INTO 'dancesstepsmap' VALUES (6176, 6699, 4);
INSERT INTO 'dancesstepsmap' VALUES (6177, 6700, 4);
INSERT INTO 'dancesstepsmap' VALUES (6178, 6701, 1);
INSERT INTO 'dancesstepsmap' VALUES (6179, 6702, 1);
INSERT INTO 'dancesstepsmap' VALUES (6180, 6704, 1);
INSERT INTO 'dancesstepsmap' VALUES (6181, 6705, 1);
INSERT INTO 'dancesstepsmap' VALUES (6182, 6706, 4);
INSERT INTO 'dancesstepsmap' VALUES (6183, 6707, 1);
INSERT INTO 'dancesstepsmap' VALUES (6184, 6708, 1);
INSERT INTO 'dancesstepsmap' VALUES (6185, 6709, 1);
INSERT INTO 'dancesstepsmap' VALUES (6186, 6710, 1);
INSERT INTO 'dancesstepsmap' VALUES (6187, 6711, 1);
INSERT INTO 'dancesstepsmap' VALUES (6188, 6712, 1);
INSERT INTO 'dancesstepsmap' VALUES (6189, 6713, 1);
INSERT INTO 'dancesstepsmap' VALUES (6190, 6714, 1);
INSERT INTO 'dancesstepsmap' VALUES (6191, 6715, 1);
INSERT INTO 'dancesstepsmap' VALUES (6192, 6716, 4);
INSERT INTO 'dancesstepsmap' VALUES (6193, 6717, 1);
INSERT INTO 'dancesstepsmap' VALUES (6194, 6718, 1);
INSERT INTO 'dancesstepsmap' VALUES (6195, 6719, 1);
INSERT INTO 'dancesstepsmap' VALUES (6196, 6720, 1);
INSERT INTO 'dancesstepsmap' VALUES (6197, 6721, 4);
INSERT INTO 'dancesstepsmap' VALUES (6198, 6722, 1);
INSERT INTO 'dancesstepsmap' VALUES (6199, 6723, 4);
INSERT INTO 'dancesstepsmap' VALUES (6200, 6724, 1);
INSERT INTO 'dancesstepsmap' VALUES (6201, 6725, 1);
INSERT INTO 'dancesstepsmap' VALUES (6202, 6726, 1);
INSERT INTO 'dancesstepsmap' VALUES (6203, 6727, 1);
INSERT INTO 'dancesstepsmap' VALUES (6204, 6728, 1);
INSERT INTO 'dancesstepsmap' VALUES (6205, 6729, 1);
INSERT INTO 'dancesstepsmap' VALUES (6206, 6730, 4);
INSERT INTO 'dancesstepsmap' VALUES (6207, 6731, 1);
INSERT INTO 'dancesstepsmap' VALUES (6208, 6732, 1);
INSERT INTO 'dancesstepsmap' VALUES (6209, 6733, 1);
INSERT INTO 'dancesstepsmap' VALUES (6210, 6734, 1);
INSERT INTO 'dancesstepsmap' VALUES (6211, 6735, 1);
INSERT INTO 'dancesstepsmap' VALUES (6212, 6736, 1);
INSERT INTO 'dancesstepsmap' VALUES (6213, 6737, 1);
INSERT INTO 'dancesstepsmap' VALUES (6214, 6738, 1);
INSERT INTO 'dancesstepsmap' VALUES (6215, 6739, 4);
INSERT INTO 'dancesstepsmap' VALUES (6216, 6740, 1);
INSERT INTO 'dancesstepsmap' VALUES (6217, 6741, 4);
INSERT INTO 'dancesstepsmap' VALUES (6218, 6742, 1);
INSERT INTO 'dancesstepsmap' VALUES (6219, 6743, 1);
INSERT INTO 'dancesstepsmap' VALUES (6220, 6744, 1);
INSERT INTO 'dancesstepsmap' VALUES (6221, 6745, 1);
INSERT INTO 'dancesstepsmap' VALUES (6222, 6746, 1);
INSERT INTO 'dancesstepsmap' VALUES (6223, 6747, 1);
INSERT INTO 'dancesstepsmap' VALUES (6224, 6748, 1);
INSERT INTO 'dancesstepsmap' VALUES (6225, 6750, 4);
INSERT INTO 'dancesstepsmap' VALUES (6226, 6751, 1);
INSERT INTO 'dancesstepsmap' VALUES (6227, 6752, 1);
INSERT INTO 'dancesstepsmap' VALUES (6228, 6753, 1);
INSERT INTO 'dancesstepsmap' VALUES (6229, 6754, 4);
INSERT INTO 'dancesstepsmap' VALUES (6230, 6755, 1);
INSERT INTO 'dancesstepsmap' VALUES (6231, 6756, 4);
INSERT INTO 'dancesstepsmap' VALUES (6232, 6757, 1);
INSERT INTO 'dancesstepsmap' VALUES (6233, 6758, 1);
INSERT INTO 'dancesstepsmap' VALUES (6234, 6759, 4);
INSERT INTO 'dancesstepsmap' VALUES (6235, 6760, 4);
INSERT INTO 'dancesstepsmap' VALUES (6236, 6761, 1);
INSERT INTO 'dancesstepsmap' VALUES (6237, 6762, 1);
INSERT INTO 'dancesstepsmap' VALUES (6238, 6763, 4);
INSERT INTO 'dancesstepsmap' VALUES (12295, 906, 3);
INSERT INTO 'dancesstepsmap' VALUES (12296, 1929, 5);
INSERT INTO 'dancesstepsmap' VALUES (12297, 3199, 2);
INSERT INTO 'dancesstepsmap' VALUES (12298, 6398, 2);
INSERT INTO 'dancesstepsmap' VALUES (12299, 7240, 2);
INSERT INTO 'dancesstepsmap' VALUES (12300, 11052, 1);
INSERT INTO 'dancesstepsmap' VALUES (12301, 11052, 2);
INSERT INTO 'dancesstepsmap' VALUES (12302, 11053, 1);
INSERT INTO 'dancesstepsmap' VALUES (12303, 11053, 3);
INSERT INTO 'dancesstepsmap' VALUES (12304, 11057, 4);
INSERT INTO 'dancesstepsmap' VALUES (12305, 11058, 1);
INSERT INTO 'dancesstepsmap' VALUES (12306, 11058, 2);
INSERT INTO 'dancesstepsmap' VALUES (12307, 11058, 3);
INSERT INTO 'dancesstepsmap' VALUES (12308, 11059, 1);
INSERT INTO 'dancesstepsmap' VALUES (12309, 11061, 1);
INSERT INTO 'dancesstepsmap' VALUES (12310, 11062, 1);
INSERT INTO 'dancesstepsmap' VALUES (12311, 11063, 4);
INSERT INTO 'dancesstepsmap' VALUES (12312, 11063, 5);
INSERT INTO 'dancesstepsmap' VALUES (12313, 11064, 1);
INSERT INTO 'dancesstepsmap' VALUES (12314, 11065, 2);
INSERT INTO 'dancesstepsmap' VALUES (12315, 11066, 6);
INSERT INTO 'dancesstepsmap' VALUES (12316, 11066, 4);
INSERT INTO 'dancesstepsmap' VALUES (12317, 11066, 5);
INSERT INTO 'dancesstepsmap' VALUES (12318, 11068, 4);
INSERT INTO 'dancesstepsmap' VALUES (12319, 11069, 1);
INSERT INTO 'dancesstepsmap' VALUES (12320, 11070, 2);
INSERT INTO 'dancesstepsmap' VALUES (12321, 11070, 1);
INSERT INTO 'dancesstepsmap' VALUES (12322, 11071, 2);
INSERT INTO 'dancesstepsmap' VALUES (12323, 11071, 1);
INSERT INTO 'dancesstepsmap' VALUES (12324, 11072, 2);
INSERT INTO 'dancesstepsmap' VALUES (12325, 11072, 1);
INSERT INTO 'dancesstepsmap' VALUES (12326, 11073, 2);
INSERT INTO 'dancesstepsmap' VALUES (12327, 11073, 1);
INSERT INTO 'dancesstepsmap' VALUES (12328, 11074, 2);
INSERT INTO 'dancesstepsmap' VALUES (12329, 11074, 1);
INSERT INTO 'dancesstepsmap' VALUES (12330, 11075, 3);
INSERT INTO 'dancesstepsmap' VALUES (12331, 11075, 1);
INSERT INTO 'dancesstepsmap' VALUES (12332, 11076, 10);
INSERT INTO 'dancesstepsmap' VALUES (12333, 11076, 1);
INSERT INTO 'dancesstepsmap' VALUES (12334, 11077, 2);
INSERT INTO 'dancesstepsmap' VALUES (12335, 11077, 1);
INSERT INTO 'dancesstepsmap' VALUES (12336, 11078, 4);
INSERT INTO 'dancesstepsmap' VALUES (17280, 14619, 1);
INSERT INTO 'dancesstepsmap' VALUES (17281, 14619, 2);
INSERT INTO 'dancesstepsmap' VALUES (17282, 14612, 3);
INSERT INTO 'dancesstepsmap' VALUES (17283, 14612, 1);
INSERT INTO 'dancesstepsmap' VALUES (23150, 18248, 1);
INSERT INTO 'dancesstepsmap' VALUES (17285, 14616, 1);
INSERT INTO 'dancesstepsmap' VALUES (17286, 14616, 3);
INSERT INTO 'dancesstepsmap' VALUES (17287, 153, 2);
INSERT INTO 'dancesstepsmap' VALUES (17289, 12665, 2);
INSERT INTO 'dancesstepsmap' VALUES (17290, 5079, 2);
INSERT INTO 'dancesstepsmap' VALUES (17291, 5040, 2);
INSERT INTO 'dancesstepsmap' VALUES (17292, 3935, 2);
INSERT INTO 'dancesstepsmap' VALUES (17293, 14633, 1);
INSERT INTO 'dancesstepsmap' VALUES (17294, 14633, 3);
INSERT INTO 'dancesstepsmap' VALUES (17295, 14633, 2);
INSERT INTO 'dancesstepsmap' VALUES (17296, 14634, 1);
INSERT INTO 'dancesstepsmap' VALUES (17297, 14634, 2);
INSERT INTO 'dancesstepsmap' VALUES (17298, 14634, 3);
INSERT INTO 'dancesstepsmap' VALUES (17299, 14636, 1);
INSERT INTO 'dancesstepsmap' VALUES (17300, 14636, 3);
INSERT INTO 'dancesstepsmap' VALUES (17301, 14637, 1);
INSERT INTO 'dancesstepsmap' VALUES (6239, 6765, 1);
INSERT INTO 'dancesstepsmap' VALUES (6240, 6766, 1);
INSERT INTO 'dancesstepsmap' VALUES (6241, 6767, 4);
INSERT INTO 'dancesstepsmap' VALUES (6242, 6768, 1);
INSERT INTO 'dancesstepsmap' VALUES (6243, 6769, 4);
INSERT INTO 'dancesstepsmap' VALUES (6244, 6770, 4);
INSERT INTO 'dancesstepsmap' VALUES (6245, 6771, 1);
INSERT INTO 'dancesstepsmap' VALUES (6246, 6772, 1);
INSERT INTO 'dancesstepsmap' VALUES (6247, 6773, 1);
INSERT INTO 'dancesstepsmap' VALUES (6248, 6774, 1);
INSERT INTO 'dancesstepsmap' VALUES (6249, 6775, 1);
INSERT INTO 'dancesstepsmap' VALUES (6250, 6776, 1);
INSERT INTO 'dancesstepsmap' VALUES (6251, 6777, 1);
INSERT INTO 'dancesstepsmap' VALUES (6252, 6778, 1);
INSERT INTO 'dancesstepsmap' VALUES (6253, 6780, 1);
INSERT INTO 'dancesstepsmap' VALUES (6254, 6781, 1);
INSERT INTO 'dancesstepsmap' VALUES (6255, 6782, 1);
INSERT INTO 'dancesstepsmap' VALUES (6256, 6783, 1);
INSERT INTO 'dancesstepsmap' VALUES (6257, 6784, 1);
INSERT INTO 'dancesstepsmap' VALUES (6258, 6785, 4);
INSERT INTO 'dancesstepsmap' VALUES (6259, 6786, 1);
INSERT INTO 'dancesstepsmap' VALUES (6260, 6787, 1);
INSERT INTO 'dancesstepsmap' VALUES (6261, 6788, 1);
INSERT INTO 'dancesstepsmap' VALUES (6262, 6789, 1);
INSERT INTO 'dancesstepsmap' VALUES (6263, 6790, 1);
INSERT INTO 'dancesstepsmap' VALUES (6264, 6791, 1);
INSERT INTO 'dancesstepsmap' VALUES (6265, 6792, 1);
INSERT INTO 'dancesstepsmap' VALUES (6266, 6793, 1);
INSERT INTO 'dancesstepsmap' VALUES (6267, 6794, 4);
INSERT INTO 'dancesstepsmap' VALUES (6268, 6795, 4);
INSERT INTO 'dancesstepsmap' VALUES (6269, 6796, 1);
INSERT INTO 'dancesstepsmap' VALUES (6270, 6798, 1);
INSERT INTO 'dancesstepsmap' VALUES (6271, 6799, 1);
INSERT INTO 'dancesstepsmap' VALUES (6272, 6800, 1);
INSERT INTO 'dancesstepsmap' VALUES (6273, 6801, 4);
INSERT INTO 'dancesstepsmap' VALUES (6274, 6802, 1);
INSERT INTO 'dancesstepsmap' VALUES (6275, 6803, 1);
INSERT INTO 'dancesstepsmap' VALUES (6276, 6805, 1);
INSERT INTO 'dancesstepsmap' VALUES (6277, 6806, 1);
INSERT INTO 'dancesstepsmap' VALUES (6278, 6807, 1);
INSERT INTO 'dancesstepsmap' VALUES (6279, 6808, 4);
INSERT INTO 'dancesstepsmap' VALUES (6280, 6809, 1);
INSERT INTO 'dancesstepsmap' VALUES (6281, 6810, 4);
INSERT INTO 'dancesstepsmap' VALUES (6282, 6811, 1);
INSERT INTO 'dancesstepsmap' VALUES (6283, 6812, 1);
INSERT INTO 'dancesstepsmap' VALUES (6284, 6813, 4);
INSERT INTO 'dancesstepsmap' VALUES (6285, 6814, 1);
INSERT INTO 'dancesstepsmap' VALUES (6286, 6815, 4);
INSERT INTO 'dancesstepsmap' VALUES (6287, 6816, 1);
INSERT INTO 'dancesstepsmap' VALUES (6288, 6817, 1);
INSERT INTO 'dancesstepsmap' VALUES (6289, 6818, 1);
INSERT INTO 'dancesstepsmap' VALUES (6290, 6819, 1);
INSERT INTO 'dancesstepsmap' VALUES (6291, 6820, 1);
INSERT INTO 'dancesstepsmap' VALUES (6292, 6823, 1);
INSERT INTO 'dancesstepsmap' VALUES (6293, 6824, 1);
INSERT INTO 'dancesstepsmap' VALUES (6294, 6825, 4);
INSERT INTO 'dancesstepsmap' VALUES (6295, 6826, 1);
INSERT INTO 'dancesstepsmap' VALUES (6296, 6827, 4);
INSERT INTO 'dancesstepsmap' VALUES (6297, 6828, 1);
INSERT INTO 'dancesstepsmap' VALUES (6298, 6829, 4);
INSERT INTO 'dancesstepsmap' VALUES (6299, 6830, 1);
INSERT INTO 'dancesstepsmap' VALUES (6300, 6831, 1);
INSERT INTO 'dancesstepsmap' VALUES (6301, 6832, 1);
INSERT INTO 'dancesstepsmap' VALUES (6302, 6833, 1);
INSERT INTO 'dancesstepsmap' VALUES (6303, 6834, 4);
INSERT INTO 'dancesstepsmap' VALUES (6304, 6835, 1);
INSERT INTO 'dancesstepsmap' VALUES (6305, 6836, 4);
INSERT INTO 'dancesstepsmap' VALUES (6306, 6837, 1);
INSERT INTO 'dancesstepsmap' VALUES (6307, 6838, 1);
INSERT INTO 'dancesstepsmap' VALUES (6308, 6839, 4);
INSERT INTO 'dancesstepsmap' VALUES (6309, 6840, 1);
INSERT INTO 'dancesstepsmap' VALUES (6310, 6841, 1);
INSERT INTO 'dancesstepsmap' VALUES (6311, 6842, 1);
INSERT INTO 'dancesstepsmap' VALUES (6312, 6843, 4);
INSERT INTO 'dancesstepsmap' VALUES (6313, 6844, 1);
INSERT INTO 'dancesstepsmap' VALUES (6314, 6845, 1);
INSERT INTO 'dancesstepsmap' VALUES (6315, 6846, 1);
INSERT INTO 'dancesstepsmap' VALUES (6316, 6847, 1);
INSERT INTO 'dancesstepsmap' VALUES (6317, 6848, 4);
INSERT INTO 'dancesstepsmap' VALUES (6318, 6849, 1);
INSERT INTO 'dancesstepsmap' VALUES (6319, 6850, 1);
INSERT INTO 'dancesstepsmap' VALUES (6320, 6851, 1);
INSERT INTO 'dancesstepsmap' VALUES (6321, 6852, 4);
INSERT INTO 'dancesstepsmap' VALUES (6322, 6853, 1);
INSERT INTO 'dancesstepsmap' VALUES (6323, 6854, 1);
INSERT INTO 'dancesstepsmap' VALUES (6324, 6855, 4);
INSERT INTO 'dancesstepsmap' VALUES (6325, 6857, 1);
INSERT INTO 'dancesstepsmap' VALUES (6326, 6858, 1);
INSERT INTO 'dancesstepsmap' VALUES (6327, 6859, 4);
INSERT INTO 'dancesstepsmap' VALUES (6328, 6860, 1);
INSERT INTO 'dancesstepsmap' VALUES (6329, 6861, 1);
INSERT INTO 'dancesstepsmap' VALUES (6330, 6862, 4);
INSERT INTO 'dancesstepsmap' VALUES (12337, 11078, 5);
INSERT INTO 'dancesstepsmap' VALUES (12338, 11079, 5);
INSERT INTO 'dancesstepsmap' VALUES (12339, 11079, 4);
INSERT INTO 'dancesstepsmap' VALUES (12340, 11080, 4);
INSERT INTO 'dancesstepsmap' VALUES (12341, 11081, 5);
INSERT INTO 'dancesstepsmap' VALUES (12342, 11081, 4);
INSERT INTO 'dancesstepsmap' VALUES (12343, 11082, 4);
INSERT INTO 'dancesstepsmap' VALUES (12346, 10536, 4);
INSERT INTO 'dancesstepsmap' VALUES (12347, 8334, 2);
INSERT INTO 'dancesstepsmap' VALUES (12348, 8334, 3);
INSERT INTO 'dancesstepsmap' VALUES (12349, 4647, 2);
INSERT INTO 'dancesstepsmap' VALUES (12350, 4647, 3);
INSERT INTO 'dancesstepsmap' VALUES (12351, 11106, 1);
INSERT INTO 'dancesstepsmap' VALUES (12352, 11106, 3);
INSERT INTO 'dancesstepsmap' VALUES (12353, 9391, 1);
INSERT INTO 'dancesstepsmap' VALUES (12354, 11108, 1);
INSERT INTO 'dancesstepsmap' VALUES (12355, 11108, 2);
INSERT INTO 'dancesstepsmap' VALUES (12356, 11108, 3);
INSERT INTO 'dancesstepsmap' VALUES (12357, 11109, 5);
INSERT INTO 'dancesstepsmap' VALUES (12358, 11109, 4);
INSERT INTO 'dancesstepsmap' VALUES (12359, 2016, 5);
INSERT INTO 'dancesstepsmap' VALUES (12360, 1113, 3);
INSERT INTO 'dancesstepsmap' VALUES (12361, 11110, 4);
INSERT INTO 'dancesstepsmap' VALUES (12362, 11110, 5);
INSERT INTO 'dancesstepsmap' VALUES (12363, 9043, 2);
INSERT INTO 'dancesstepsmap' VALUES (12364, 11111, 2);
INSERT INTO 'dancesstepsmap' VALUES (12365, 11111, 3);
INSERT INTO 'dancesstepsmap' VALUES (12366, 11111, 1);
INSERT INTO 'dancesstepsmap' VALUES (12367, 11112, 1);
INSERT INTO 'dancesstepsmap' VALUES (12368, 11112, 2);
INSERT INTO 'dancesstepsmap' VALUES (12369, 11113, 2);
INSERT INTO 'dancesstepsmap' VALUES (12370, 11113, 1);
INSERT INTO 'dancesstepsmap' VALUES (12371, 11114, 4);
INSERT INTO 'dancesstepsmap' VALUES (12372, 11114, 5);
INSERT INTO 'dancesstepsmap' VALUES (12373, 11126, 1);
INSERT INTO 'dancesstepsmap' VALUES (12374, 11129, 2);
INSERT INTO 'dancesstepsmap' VALUES (12375, 11134, 4);
INSERT INTO 'dancesstepsmap' VALUES (12376, 11140, 4);
INSERT INTO 'dancesstepsmap' VALUES (12377, 11140, 5);
INSERT INTO 'dancesstepsmap' VALUES (12378, 11142, 2);
INSERT INTO 'dancesstepsmap' VALUES (12379, 11147, 4);
INSERT INTO 'dancesstepsmap' VALUES (12380, 11121, 2);
INSERT INTO 'dancesstepsmap' VALUES (17302, 14637, 2);
INSERT INTO 'dancesstepsmap' VALUES (6331, 6863, 1);
INSERT INTO 'dancesstepsmap' VALUES (6332, 6864, 4);
INSERT INTO 'dancesstepsmap' VALUES (6333, 6865, 1);
INSERT INTO 'dancesstepsmap' VALUES (6334, 6866, 1);
INSERT INTO 'dancesstepsmap' VALUES (6335, 6867, 1);
INSERT INTO 'dancesstepsmap' VALUES (6336, 6868, 1);
INSERT INTO 'dancesstepsmap' VALUES (6337, 6869, 4);
INSERT INTO 'dancesstepsmap' VALUES (6338, 6870, 1);
INSERT INTO 'dancesstepsmap' VALUES (6339, 6871, 4);
INSERT INTO 'dancesstepsmap' VALUES (6340, 6872, 4);
INSERT INTO 'dancesstepsmap' VALUES (6341, 6873, 1);
INSERT INTO 'dancesstepsmap' VALUES (6342, 6874, 1);
INSERT INTO 'dancesstepsmap' VALUES (6343, 6875, 4);
INSERT INTO 'dancesstepsmap' VALUES (6344, 6876, 1);
INSERT INTO 'dancesstepsmap' VALUES (6345, 6877, 1);
INSERT INTO 'dancesstepsmap' VALUES (6346, 6878, 1);
INSERT INTO 'dancesstepsmap' VALUES (6347, 6879, 4);
INSERT INTO 'dancesstepsmap' VALUES (6348, 6880, 4);
INSERT INTO 'dancesstepsmap' VALUES (6349, 6881, 1);
INSERT INTO 'dancesstepsmap' VALUES (6350, 6882, 1);
INSERT INTO 'dancesstepsmap' VALUES (6351, 6883, 1);
INSERT INTO 'dancesstepsmap' VALUES (6352, 6884, 1);
INSERT INTO 'dancesstepsmap' VALUES (6353, 6885, 4);
INSERT INTO 'dancesstepsmap' VALUES (6354, 6886, 4);
INSERT INTO 'dancesstepsmap' VALUES (6355, 6887, 1);
INSERT INTO 'dancesstepsmap' VALUES (6356, 6888, 1);
INSERT INTO 'dancesstepsmap' VALUES (6357, 6889, 1);
INSERT INTO 'dancesstepsmap' VALUES (6358, 6890, 4);
INSERT INTO 'dancesstepsmap' VALUES (6359, 6891, 1);
INSERT INTO 'dancesstepsmap' VALUES (6360, 6892, 4);
INSERT INTO 'dancesstepsmap' VALUES (6361, 6893, 1);
INSERT INTO 'dancesstepsmap' VALUES (6362, 6894, 1);
INSERT INTO 'dancesstepsmap' VALUES (6363, 6896, 4);
INSERT INTO 'dancesstepsmap' VALUES (6364, 6897, 1);
INSERT INTO 'dancesstepsmap' VALUES (6365, 6898, 1);
INSERT INTO 'dancesstepsmap' VALUES (6366, 6899, 1);
INSERT INTO 'dancesstepsmap' VALUES (6367, 6901, 1);
INSERT INTO 'dancesstepsmap' VALUES (6368, 6902, 1);
INSERT INTO 'dancesstepsmap' VALUES (6369, 6903, 1);
INSERT INTO 'dancesstepsmap' VALUES (6370, 6904, 4);
INSERT INTO 'dancesstepsmap' VALUES (6371, 6905, 4);
INSERT INTO 'dancesstepsmap' VALUES (6372, 6906, 1);
INSERT INTO 'dancesstepsmap' VALUES (6373, 6908, 4);
INSERT INTO 'dancesstepsmap' VALUES (6374, 6909, 4);
INSERT INTO 'dancesstepsmap' VALUES (6375, 6910, 1);
INSERT INTO 'dancesstepsmap' VALUES (6376, 6911, 1);
INSERT INTO 'dancesstepsmap' VALUES (6377, 6912, 4);
INSERT INTO 'dancesstepsmap' VALUES (6378, 6913, 4);
INSERT INTO 'dancesstepsmap' VALUES (6379, 6914, 1);
INSERT INTO 'dancesstepsmap' VALUES (6380, 6916, 1);
INSERT INTO 'dancesstepsmap' VALUES (6381, 6917, 1);
INSERT INTO 'dancesstepsmap' VALUES (6382, 6918, 1);
INSERT INTO 'dancesstepsmap' VALUES (6383, 6919, 1);
INSERT INTO 'dancesstepsmap' VALUES (6384, 6920, 1);
INSERT INTO 'dancesstepsmap' VALUES (6385, 6921, 4);
INSERT INTO 'dancesstepsmap' VALUES (6386, 6922, 4);
INSERT INTO 'dancesstepsmap' VALUES (6387, 6923, 4);
INSERT INTO 'dancesstepsmap' VALUES (6388, 6924, 1);
INSERT INTO 'dancesstepsmap' VALUES (6389, 6925, 4);
INSERT INTO 'dancesstepsmap' VALUES (6390, 6927, 1);
INSERT INTO 'dancesstepsmap' VALUES (6391, 6928, 1);
INSERT INTO 'dancesstepsmap' VALUES (6392, 6929, 1);
INSERT INTO 'dancesstepsmap' VALUES (6393, 6931, 1);
INSERT INTO 'dancesstepsmap' VALUES (6394, 6932, 1);
INSERT INTO 'dancesstepsmap' VALUES (6395, 6933, 4);
INSERT INTO 'dancesstepsmap' VALUES (6396, 6934, 1);
INSERT INTO 'dancesstepsmap' VALUES (6397, 6935, 4);
INSERT INTO 'dancesstepsmap' VALUES (6398, 6936, 1);
INSERT INTO 'dancesstepsmap' VALUES (6399, 6938, 1);
INSERT INTO 'dancesstepsmap' VALUES (6400, 6939, 1);
INSERT INTO 'dancesstepsmap' VALUES (6401, 6940, 4);
INSERT INTO 'dancesstepsmap' VALUES (6402, 6941, 4);
INSERT INTO 'dancesstepsmap' VALUES (6403, 6942, 1);
INSERT INTO 'dancesstepsmap' VALUES (6404, 6943, 1);
INSERT INTO 'dancesstepsmap' VALUES (6405, 6944, 4);
INSERT INTO 'dancesstepsmap' VALUES (6406, 6945, 1);
INSERT INTO 'dancesstepsmap' VALUES (6407, 6946, 1);
INSERT INTO 'dancesstepsmap' VALUES (6408, 6947, 1);
INSERT INTO 'dancesstepsmap' VALUES (6409, 6949, 1);
INSERT INTO 'dancesstepsmap' VALUES (6410, 6950, 1);
INSERT INTO 'dancesstepsmap' VALUES (6411, 6952, 1);
INSERT INTO 'dancesstepsmap' VALUES (6412, 6953, 1);
INSERT INTO 'dancesstepsmap' VALUES (6413, 6954, 1);
INSERT INTO 'dancesstepsmap' VALUES (6414, 6955, 1);
INSERT INTO 'dancesstepsmap' VALUES (6415, 6956, 4);
INSERT INTO 'dancesstepsmap' VALUES (6416, 6957, 1);
INSERT INTO 'dancesstepsmap' VALUES (6417, 6958, 1);
INSERT INTO 'dancesstepsmap' VALUES (6418, 6959, 1);
INSERT INTO 'dancesstepsmap' VALUES (6419, 6960, 1);
INSERT INTO 'dancesstepsmap' VALUES (6420, 6961, 4);
INSERT INTO 'dancesstepsmap' VALUES (6421, 6962, 1);
INSERT INTO 'dancesstepsmap' VALUES (6422, 6963, 1);
INSERT INTO 'dancesstepsmap' VALUES (6423, 6964, 4);
INSERT INTO 'dancesstepsmap' VALUES (12381, 11151, 4);
INSERT INTO 'dancesstepsmap' VALUES (12382, 10149, 4);
INSERT INTO 'dancesstepsmap' VALUES (12383, 11155, 2);
INSERT INTO 'dancesstepsmap' VALUES (12384, 11155, 1);
INSERT INTO 'dancesstepsmap' VALUES (12385, 11156, 4);
INSERT INTO 'dancesstepsmap' VALUES (12386, 11156, 5);
INSERT INTO 'dancesstepsmap' VALUES (12387, 11158, 1);
INSERT INTO 'dancesstepsmap' VALUES (12388, 11158, 2);
INSERT INTO 'dancesstepsmap' VALUES (12389, 11159, 4);
INSERT INTO 'dancesstepsmap' VALUES (12390, 11107, 4);
INSERT INTO 'dancesstepsmap' VALUES (12391, 11107, 5);
INSERT INTO 'dancesstepsmap' VALUES (12392, 10497, 4);
INSERT INTO 'dancesstepsmap' VALUES (12393, 5652, 2);
INSERT INTO 'dancesstepsmap' VALUES (12394, 5652, 3);
INSERT INTO 'dancesstepsmap' VALUES (12395, 370, 5);
INSERT INTO 'dancesstepsmap' VALUES (12396, 2642, 2);
INSERT INTO 'dancesstepsmap' VALUES (12397, 3820, 6);
INSERT INTO 'dancesstepsmap' VALUES (12398, 1597, 2);
INSERT INTO 'dancesstepsmap' VALUES (12399, 3534, 2);
INSERT INTO 'dancesstepsmap' VALUES (12400, 1117, 2);
INSERT INTO 'dancesstepsmap' VALUES (12401, 1117, 3);
INSERT INTO 'dancesstepsmap' VALUES (12402, 785, 5);
INSERT INTO 'dancesstepsmap' VALUES (12403, 6483, 2);
INSERT INTO 'dancesstepsmap' VALUES (12404, 2689, 3);
INSERT INTO 'dancesstepsmap' VALUES (12405, 3599, 5);
INSERT INTO 'dancesstepsmap' VALUES (12406, 3005, 2);
INSERT INTO 'dancesstepsmap' VALUES (12407, 562, 2);
INSERT INTO 'dancesstepsmap' VALUES (12408, 1241, 3);
INSERT INTO 'dancesstepsmap' VALUES (12409, 4076, 3);
INSERT INTO 'dancesstepsmap' VALUES (12410, 2230, 5);
INSERT INTO 'dancesstepsmap' VALUES (12411, 6831, 2);
INSERT INTO 'dancesstepsmap' VALUES (12412, 12, 5);
INSERT INTO 'dancesstepsmap' VALUES (12413, 6972, 2);
INSERT INTO 'dancesstepsmap' VALUES (12414, 11160, 5);
INSERT INTO 'dancesstepsmap' VALUES (12415, 4362, 2);
INSERT INTO 'dancesstepsmap' VALUES (12419, 2954, 5);
INSERT INTO 'dancesstepsmap' VALUES (12420, 459, 5);
INSERT INTO 'dancesstepsmap' VALUES (12421, 459, 4);
INSERT INTO 'dancesstepsmap' VALUES (12422, 459, 1);
INSERT INTO 'dancesstepsmap' VALUES (12423, 459, 3);
INSERT INTO 'dancesstepsmap' VALUES (12424, 3120, 2);
INSERT INTO 'dancesstepsmap' VALUES (12425, 6525, 2);
INSERT INTO 'dancesstepsmap' VALUES (17303, 14640, 1);
INSERT INTO 'dancesstepsmap' VALUES (17304, 14640, 3);
INSERT INTO 'dancesstepsmap' VALUES (17305, 14641, 4);
INSERT INTO 'dancesstepsmap' VALUES (17306, 14641, 5);
INSERT INTO 'dancesstepsmap' VALUES (17307, 14642, 2);
INSERT INTO 'dancesstepsmap' VALUES (17308, 14642, 1);
INSERT INTO 'dancesstepsmap' VALUES (17313, 14644, 4);
INSERT INTO 'dancesstepsmap' VALUES (17320, 14648, 2);
INSERT INTO 'dancesstepsmap' VALUES (17321, 14648, 1);
INSERT INTO 'dancesstepsmap' VALUES (17323, 14650, 1);
INSERT INTO 'dancesstepsmap' VALUES (17324, 14650, 2);
INSERT INTO 'dancesstepsmap' VALUES (17325, 14650, 3);
INSERT INTO 'dancesstepsmap' VALUES (17328, 14652, 4);
INSERT INTO 'dancesstepsmap' VALUES (17329, 14652, 5);
INSERT INTO 'dancesstepsmap' VALUES (17340, 14659, 1);
INSERT INTO 'dancesstepsmap' VALUES (17341, 11731, 3);
INSERT INTO 'dancesstepsmap' VALUES (17343, 11195, 1);
INSERT INTO 'dancesstepsmap' VALUES (17344, 11195, 2);
INSERT INTO 'dancesstepsmap' VALUES (17345, 14661, 1);
INSERT INTO 'dancesstepsmap' VALUES (17346, 14661, 2);
INSERT INTO 'dancesstepsmap' VALUES (17347, 14661, 3);
INSERT INTO 'dancesstepsmap' VALUES (17348, 8571, 5);
INSERT INTO 'dancesstepsmap' VALUES (17349, 14679, 1);
INSERT INTO 'dancesstepsmap' VALUES (6424, 6965, 1);
INSERT INTO 'dancesstepsmap' VALUES (6425, 6967, 4);
INSERT INTO 'dancesstepsmap' VALUES (6426, 6968, 4);
INSERT INTO 'dancesstepsmap' VALUES (6427, 6969, 1);
INSERT INTO 'dancesstepsmap' VALUES (6428, 6970, 4);
INSERT INTO 'dancesstepsmap' VALUES (6429, 6971, 1);
INSERT INTO 'dancesstepsmap' VALUES (6430, 6972, 1);
INSERT INTO 'dancesstepsmap' VALUES (6431, 6974, 4);
INSERT INTO 'dancesstepsmap' VALUES (6432, 6975, 1);
INSERT INTO 'dancesstepsmap' VALUES (6433, 6977, 1);
INSERT INTO 'dancesstepsmap' VALUES (6434, 6978, 1);
INSERT INTO 'dancesstepsmap' VALUES (6435, 6979, 4);
INSERT INTO 'dancesstepsmap' VALUES (6436, 6980, 1);
INSERT INTO 'dancesstepsmap' VALUES (6437, 6981, 1);
INSERT INTO 'dancesstepsmap' VALUES (6438, 6982, 4);
INSERT INTO 'dancesstepsmap' VALUES (6439, 6984, 4);
INSERT INTO 'dancesstepsmap' VALUES (6440, 6985, 4);
INSERT INTO 'dancesstepsmap' VALUES (6441, 6988, 1);
INSERT INTO 'dancesstepsmap' VALUES (6442, 6989, 4);
INSERT INTO 'dancesstepsmap' VALUES (6443, 6990, 1);
INSERT INTO 'dancesstepsmap' VALUES (6444, 6991, 1);
INSERT INTO 'dancesstepsmap' VALUES (6445, 6992, 1);
INSERT INTO 'dancesstepsmap' VALUES (6446, 6993, 1);
INSERT INTO 'dancesstepsmap' VALUES (6447, 6994, 4);
INSERT INTO 'dancesstepsmap' VALUES (6448, 6995, 1);
INSERT INTO 'dancesstepsmap' VALUES (6449, 6996, 1);
INSERT INTO 'dancesstepsmap' VALUES (6450, 6997, 1);
INSERT INTO 'dancesstepsmap' VALUES (6451, 6999, 1);
INSERT INTO 'dancesstepsmap' VALUES (6452, 7000, 1);
INSERT INTO 'dancesstepsmap' VALUES (6453, 7001, 1);
INSERT INTO 'dancesstepsmap' VALUES (6454, 7002, 1);
INSERT INTO 'dancesstepsmap' VALUES (6455, 7003, 1);
INSERT INTO 'dancesstepsmap' VALUES (6456, 7005, 4);
INSERT INTO 'dancesstepsmap' VALUES (6457, 7006, 4);
INSERT INTO 'dancesstepsmap' VALUES (6458, 7007, 4);
INSERT INTO 'dancesstepsmap' VALUES (6459, 7008, 4);
INSERT INTO 'dancesstepsmap' VALUES (6460, 7009, 1);
INSERT INTO 'dancesstepsmap' VALUES (6461, 7010, 4);
INSERT INTO 'dancesstepsmap' VALUES (6462, 7011, 1);
INSERT INTO 'dancesstepsmap' VALUES (6463, 7012, 1);
INSERT INTO 'dancesstepsmap' VALUES (6464, 7013, 4);
INSERT INTO 'dancesstepsmap' VALUES (6465, 7014, 4);
INSERT INTO 'dancesstepsmap' VALUES (6466, 7015, 4);
INSERT INTO 'dancesstepsmap' VALUES (6467, 7016, 4);
INSERT INTO 'dancesstepsmap' VALUES (6468, 7017, 1);
INSERT INTO 'dancesstepsmap' VALUES (6469, 7018, 1);
INSERT INTO 'dancesstepsmap' VALUES (6470, 7019, 1);
INSERT INTO 'dancesstepsmap' VALUES (6471, 7020, 1);
INSERT INTO 'dancesstepsmap' VALUES (6472, 7021, 1);
INSERT INTO 'dancesstepsmap' VALUES (6473, 7022, 1);
INSERT INTO 'dancesstepsmap' VALUES (6474, 7023, 1);
INSERT INTO 'dancesstepsmap' VALUES (6475, 7024, 4);
INSERT INTO 'dancesstepsmap' VALUES (6476, 7025, 4);
INSERT INTO 'dancesstepsmap' VALUES (6477, 7026, 4);
INSERT INTO 'dancesstepsmap' VALUES (6478, 7027, 4);
INSERT INTO 'dancesstepsmap' VALUES (6479, 7028, 4);
INSERT INTO 'dancesstepsmap' VALUES (6481, 7030, 1);
INSERT INTO 'dancesstepsmap' VALUES (6482, 7031, 1);
INSERT INTO 'dancesstepsmap' VALUES (6483, 7032, 1);
INSERT INTO 'dancesstepsmap' VALUES (6484, 7033, 1);
INSERT INTO 'dancesstepsmap' VALUES (6485, 7034, 1);
INSERT INTO 'dancesstepsmap' VALUES (6486, 7035, 1);
INSERT INTO 'dancesstepsmap' VALUES (6487, 7036, 1);
INSERT INTO 'dancesstepsmap' VALUES (6488, 7037, 1);
INSERT INTO 'dancesstepsmap' VALUES (6490, 7039, 4);
INSERT INTO 'dancesstepsmap' VALUES (6491, 7040, 1);
INSERT INTO 'dancesstepsmap' VALUES (6492, 7041, 1);
INSERT INTO 'dancesstepsmap' VALUES (6493, 7042, 4);
INSERT INTO 'dancesstepsmap' VALUES (6494, 7043, 4);
INSERT INTO 'dancesstepsmap' VALUES (6495, 7044, 4);
INSERT INTO 'dancesstepsmap' VALUES (6496, 7045, 1);
INSERT INTO 'dancesstepsmap' VALUES (6497, 7046, 1);
INSERT INTO 'dancesstepsmap' VALUES (6498, 7047, 1);
INSERT INTO 'dancesstepsmap' VALUES (6499, 7048, 1);
INSERT INTO 'dancesstepsmap' VALUES (6500, 7049, 1);
INSERT INTO 'dancesstepsmap' VALUES (6501, 7050, 1);
INSERT INTO 'dancesstepsmap' VALUES (6502, 7051, 1);
INSERT INTO 'dancesstepsmap' VALUES (6503, 7052, 4);
INSERT INTO 'dancesstepsmap' VALUES (6504, 7053, 4);
INSERT INTO 'dancesstepsmap' VALUES (6505, 7054, 1);
INSERT INTO 'dancesstepsmap' VALUES (6506, 7055, 1);
INSERT INTO 'dancesstepsmap' VALUES (6507, 7056, 1);
INSERT INTO 'dancesstepsmap' VALUES (6508, 7057, 1);
INSERT INTO 'dancesstepsmap' VALUES (6509, 7058, 4);
INSERT INTO 'dancesstepsmap' VALUES (6510, 7059, 4);
INSERT INTO 'dancesstepsmap' VALUES (6511, 7060, 1);
INSERT INTO 'dancesstepsmap' VALUES (6512, 7061, 1);
INSERT INTO 'dancesstepsmap' VALUES (6513, 7062, 1);
INSERT INTO 'dancesstepsmap' VALUES (6514, 7063, 1);
INSERT INTO 'dancesstepsmap' VALUES (6515, 7064, 1);
INSERT INTO 'dancesstepsmap' VALUES (6516, 7065, 1);
INSERT INTO 'dancesstepsmap' VALUES (6517, 7066, 1);
INSERT INTO 'dancesstepsmap' VALUES (6518, 7067, 4);
INSERT INTO 'dancesstepsmap' VALUES (6519, 7068, 1);
INSERT INTO 'dancesstepsmap' VALUES (6520, 7069, 1);
INSERT INTO 'dancesstepsmap' VALUES (6521, 7070, 1);
INSERT INTO 'dancesstepsmap' VALUES (6522, 7071, 1);
INSERT INTO 'dancesstepsmap' VALUES (6523, 7072, 1);
INSERT INTO 'dancesstepsmap' VALUES (6524, 7073, 1);
INSERT INTO 'dancesstepsmap' VALUES (6525, 7074, 4);
INSERT INTO 'dancesstepsmap' VALUES (6526, 7075, 1);
INSERT INTO 'dancesstepsmap' VALUES (6527, 7076, 1);
INSERT INTO 'dancesstepsmap' VALUES (6528, 7077, 1);
INSERT INTO 'dancesstepsmap' VALUES (6529, 7078, 4);
INSERT INTO 'dancesstepsmap' VALUES (6530, 7080, 4);
INSERT INTO 'dancesstepsmap' VALUES (6531, 7081, 1);
INSERT INTO 'dancesstepsmap' VALUES (6532, 7082, 1);
INSERT INTO 'dancesstepsmap' VALUES (6533, 7083, 1);
INSERT INTO 'dancesstepsmap' VALUES (6534, 7085, 4);
INSERT INTO 'dancesstepsmap' VALUES (6535, 7086, 1);
INSERT INTO 'dancesstepsmap' VALUES (6536, 7087, 1);
INSERT INTO 'dancesstepsmap' VALUES (6537, 7088, 1);
INSERT INTO 'dancesstepsmap' VALUES (6538, 7089, 1);
INSERT INTO 'dancesstepsmap' VALUES (6539, 7090, 1);
INSERT INTO 'dancesstepsmap' VALUES (6540, 7091, 1);
INSERT INTO 'dancesstepsmap' VALUES (6541, 7092, 1);
INSERT INTO 'dancesstepsmap' VALUES (6542, 7093, 1);
INSERT INTO 'dancesstepsmap' VALUES (6543, 7095, 1);
INSERT INTO 'dancesstepsmap' VALUES (6544, 7096, 1);
INSERT INTO 'dancesstepsmap' VALUES (6545, 7097, 1);
INSERT INTO 'dancesstepsmap' VALUES (6546, 7099, 4);
INSERT INTO 'dancesstepsmap' VALUES (6547, 7100, 1);
INSERT INTO 'dancesstepsmap' VALUES (6548, 7101, 1);
INSERT INTO 'dancesstepsmap' VALUES (6549, 7102, 1);
INSERT INTO 'dancesstepsmap' VALUES (6550, 7103, 1);
INSERT INTO 'dancesstepsmap' VALUES (6551, 7104, 1);
INSERT INTO 'dancesstepsmap' VALUES (6552, 7105, 1);
INSERT INTO 'dancesstepsmap' VALUES (6553, 7106, 1);
INSERT INTO 'dancesstepsmap' VALUES (12426, 6184, 2);
INSERT INTO 'dancesstepsmap' VALUES (12427, 6184, 3);
INSERT INTO 'dancesstepsmap' VALUES (12428, 4054, 2);
INSERT INTO 'dancesstepsmap' VALUES (12429, 2417, 5);
INSERT INTO 'dancesstepsmap' VALUES (12430, 5052, 5);
INSERT INTO 'dancesstepsmap' VALUES (12431, 4687, 3);
INSERT INTO 'dancesstepsmap' VALUES (12432, 6608, 2);
INSERT INTO 'dancesstepsmap' VALUES (12433, 6608, 3);
INSERT INTO 'dancesstepsmap' VALUES (12434, 6925, 5);
INSERT INTO 'dancesstepsmap' VALUES (12435, 6132, 3);
INSERT INTO 'dancesstepsmap' VALUES (12436, 36, 2);
INSERT INTO 'dancesstepsmap' VALUES (12437, 1737, 5);
INSERT INTO 'dancesstepsmap' VALUES (12438, 1529, 2);
INSERT INTO 'dancesstepsmap' VALUES (12439, 1529, 3);
INSERT INTO 'dancesstepsmap' VALUES (12440, 4168, 5);
INSERT INTO 'dancesstepsmap' VALUES (12441, 3087, 2);
INSERT INTO 'dancesstepsmap' VALUES (6554, 7107, 1);
INSERT INTO 'dancesstepsmap' VALUES (6555, 7108, 4);
INSERT INTO 'dancesstepsmap' VALUES (6556, 7109, 1);
INSERT INTO 'dancesstepsmap' VALUES (6557, 7110, 4);
INSERT INTO 'dancesstepsmap' VALUES (6558, 7111, 1);
INSERT INTO 'dancesstepsmap' VALUES (6559, 7112, 4);
INSERT INTO 'dancesstepsmap' VALUES (6560, 7113, 4);
INSERT INTO 'dancesstepsmap' VALUES (6561, 7114, 4);
INSERT INTO 'dancesstepsmap' VALUES (6562, 7115, 4);
INSERT INTO 'dancesstepsmap' VALUES (6563, 7116, 1);
INSERT INTO 'dancesstepsmap' VALUES (6564, 7117, 1);
INSERT INTO 'dancesstepsmap' VALUES (6565, 7118, 1);
INSERT INTO 'dancesstepsmap' VALUES (6566, 7119, 1);
INSERT INTO 'dancesstepsmap' VALUES (6567, 7120, 4);
INSERT INTO 'dancesstepsmap' VALUES (6568, 7121, 4);
INSERT INTO 'dancesstepsmap' VALUES (6569, 7123, 1);
INSERT INTO 'dancesstepsmap' VALUES (6570, 7124, 1);
INSERT INTO 'dancesstepsmap' VALUES (6571, 7125, 1);
INSERT INTO 'dancesstepsmap' VALUES (6572, 7127, 1);
INSERT INTO 'dancesstepsmap' VALUES (6573, 7128, 1);
INSERT INTO 'dancesstepsmap' VALUES (6574, 7129, 1);
INSERT INTO 'dancesstepsmap' VALUES (6575, 7130, 4);
INSERT INTO 'dancesstepsmap' VALUES (6576, 7131, 1);
INSERT INTO 'dancesstepsmap' VALUES (6577, 7132, 1);
INSERT INTO 'dancesstepsmap' VALUES (6578, 7133, 1);
INSERT INTO 'dancesstepsmap' VALUES (6579, 7134, 4);
INSERT INTO 'dancesstepsmap' VALUES (6580, 7135, 1);
INSERT INTO 'dancesstepsmap' VALUES (6581, 7137, 1);
INSERT INTO 'dancesstepsmap' VALUES (6582, 7138, 1);
INSERT INTO 'dancesstepsmap' VALUES (6583, 7139, 1);
INSERT INTO 'dancesstepsmap' VALUES (6584, 7141, 1);
INSERT INTO 'dancesstepsmap' VALUES (6585, 7142, 1);
INSERT INTO 'dancesstepsmap' VALUES (6586, 7143, 4);
INSERT INTO 'dancesstepsmap' VALUES (6587, 7144, 1);
INSERT INTO 'dancesstepsmap' VALUES (6588, 7145, 4);
INSERT INTO 'dancesstepsmap' VALUES (6589, 7146, 4);
INSERT INTO 'dancesstepsmap' VALUES (6590, 7147, 1);
INSERT INTO 'dancesstepsmap' VALUES (6591, 7148, 1);
INSERT INTO 'dancesstepsmap' VALUES (6592, 7149, 4);
INSERT INTO 'dancesstepsmap' VALUES (6593, 7150, 4);
INSERT INTO 'dancesstepsmap' VALUES (6594, 7152, 1);
INSERT INTO 'dancesstepsmap' VALUES (6595, 7153, 4);
INSERT INTO 'dancesstepsmap' VALUES (6596, 7154, 4);
INSERT INTO 'dancesstepsmap' VALUES (6597, 7155, 1);
INSERT INTO 'dancesstepsmap' VALUES (6598, 7157, 4);
INSERT INTO 'dancesstepsmap' VALUES (6599, 7158, 1);
INSERT INTO 'dancesstepsmap' VALUES (6600, 7159, 1);
INSERT INTO 'dancesstepsmap' VALUES (6601, 7160, 4);
INSERT INTO 'dancesstepsmap' VALUES (6602, 7161, 4);
INSERT INTO 'dancesstepsmap' VALUES (6603, 7162, 4);
INSERT INTO 'dancesstepsmap' VALUES (6604, 7163, 4);
INSERT INTO 'dancesstepsmap' VALUES (6605, 7164, 4);
INSERT INTO 'dancesstepsmap' VALUES (6606, 7165, 4);
INSERT INTO 'dancesstepsmap' VALUES (6607, 7166, 4);
INSERT INTO 'dancesstepsmap' VALUES (6608, 7167, 1);
INSERT INTO 'dancesstepsmap' VALUES (6609, 7168, 1);
INSERT INTO 'dancesstepsmap' VALUES (6610, 7169, 1);
INSERT INTO 'dancesstepsmap' VALUES (6611, 7170, 4);
INSERT INTO 'dancesstepsmap' VALUES (6612, 7171, 4);
INSERT INTO 'dancesstepsmap' VALUES (6613, 7172, 1);
INSERT INTO 'dancesstepsmap' VALUES (6614, 7173, 1);
INSERT INTO 'dancesstepsmap' VALUES (6615, 7174, 1);
INSERT INTO 'dancesstepsmap' VALUES (6616, 7175, 1);
INSERT INTO 'dancesstepsmap' VALUES (6617, 7176, 4);
INSERT INTO 'dancesstepsmap' VALUES (6618, 7177, 1);
INSERT INTO 'dancesstepsmap' VALUES (6619, 7178, 4);
INSERT INTO 'dancesstepsmap' VALUES (6620, 7179, 1);
INSERT INTO 'dancesstepsmap' VALUES (6621, 7180, 4);
INSERT INTO 'dancesstepsmap' VALUES (6622, 7181, 1);
INSERT INTO 'dancesstepsmap' VALUES (6623, 7182, 1);
INSERT INTO 'dancesstepsmap' VALUES (6624, 7183, 1);
INSERT INTO 'dancesstepsmap' VALUES (6625, 7184, 1);
INSERT INTO 'dancesstepsmap' VALUES (6626, 7185, 1);
INSERT INTO 'dancesstepsmap' VALUES (6627, 7186, 1);
INSERT INTO 'dancesstepsmap' VALUES (6628, 7188, 4);
INSERT INTO 'dancesstepsmap' VALUES (6629, 7189, 4);
INSERT INTO 'dancesstepsmap' VALUES (6630, 7190, 4);
INSERT INTO 'dancesstepsmap' VALUES (6631, 7191, 1);
INSERT INTO 'dancesstepsmap' VALUES (6632, 7192, 1);
INSERT INTO 'dancesstepsmap' VALUES (6633, 7193, 1);
INSERT INTO 'dancesstepsmap' VALUES (6634, 7194, 1);
INSERT INTO 'dancesstepsmap' VALUES (6635, 7195, 1);
INSERT INTO 'dancesstepsmap' VALUES (6636, 7196, 1);
INSERT INTO 'dancesstepsmap' VALUES (6637, 7197, 1);
INSERT INTO 'dancesstepsmap' VALUES (6638, 7198, 1);
INSERT INTO 'dancesstepsmap' VALUES (6639, 7199, 1);
INSERT INTO 'dancesstepsmap' VALUES (6640, 7200, 1);
INSERT INTO 'dancesstepsmap' VALUES (6641, 7201, 1);
INSERT INTO 'dancesstepsmap' VALUES (6642, 7202, 1);
INSERT INTO 'dancesstepsmap' VALUES (6643, 7203, 1);
INSERT INTO 'dancesstepsmap' VALUES (6644, 7204, 4);
INSERT INTO 'dancesstepsmap' VALUES (6645, 7205, 4);
INSERT INTO 'dancesstepsmap' VALUES (12442, 1174, 5);
INSERT INTO 'dancesstepsmap' VALUES (12443, 8216, 2);
INSERT INTO 'dancesstepsmap' VALUES (12444, 11162, 4);
INSERT INTO 'dancesstepsmap' VALUES (12445, 11162, 5);
INSERT INTO 'dancesstepsmap' VALUES (12446, 4990, 5);
INSERT INTO 'dancesstepsmap' VALUES (12447, 8200, 2);
INSERT INTO 'dancesstepsmap' VALUES (12449, 8043, 3);
INSERT INTO 'dancesstepsmap' VALUES (12450, 11163, 4);
INSERT INTO 'dancesstepsmap' VALUES (12451, 10655, 4);
INSERT INTO 'dancesstepsmap' VALUES (12452, 11157, 2);
INSERT INTO 'dancesstepsmap' VALUES (12453, 11157, 1);
INSERT INTO 'dancesstepsmap' VALUES (12454, 11157, 3);
INSERT INTO 'dancesstepsmap' VALUES (12455, 11153, 2);
INSERT INTO 'dancesstepsmap' VALUES (12456, 11153, 1);
INSERT INTO 'dancesstepsmap' VALUES (12457, 11153, 3);
INSERT INTO 'dancesstepsmap' VALUES (12458, 11154, 5);
INSERT INTO 'dancesstepsmap' VALUES (12459, 11154, 4);
INSERT INTO 'dancesstepsmap' VALUES (12460, 11191, 4);
INSERT INTO 'dancesstepsmap' VALUES (12461, 11191, 1);
INSERT INTO 'dancesstepsmap' VALUES (12462, 11191, 3);
INSERT INTO 'dancesstepsmap' VALUES (23151, 18248, 2);
INSERT INTO 'dancesstepsmap' VALUES (23152, 18249, 4);
INSERT INTO 'dancesstepsmap' VALUES (12465, 11194, 1);
INSERT INTO 'dancesstepsmap' VALUES (12466, 8726, 1);
INSERT INTO 'dancesstepsmap' VALUES (12467, 8726, 2);
INSERT INTO 'dancesstepsmap' VALUES (12468, 11184, 1);
INSERT INTO 'dancesstepsmap' VALUES (12469, 11184, 3);
INSERT INTO 'dancesstepsmap' VALUES (12470, 11185, 1);
INSERT INTO 'dancesstepsmap' VALUES (12471, 11185, 2);
INSERT INTO 'dancesstepsmap' VALUES (12472, 11186, 4);
INSERT INTO 'dancesstepsmap' VALUES (12473, 11187, 1);
INSERT INTO 'dancesstepsmap' VALUES (12474, 11187, 2);
INSERT INTO 'dancesstepsmap' VALUES (12475, 11189, 1);
INSERT INTO 'dancesstepsmap' VALUES (12476, 11190, 1);
INSERT INTO 'dancesstepsmap' VALUES (12477, 11190, 3);
INSERT INTO 'dancesstepsmap' VALUES (12478, 11190, 2);
INSERT INTO 'dancesstepsmap' VALUES (12479, 11186, 5);
INSERT INTO 'dancesstepsmap' VALUES (12480, 11188, 5);
INSERT INTO 'dancesstepsmap' VALUES (12481, 11188, 4);
INSERT INTO 'dancesstepsmap' VALUES (12482, 9067, 2);
INSERT INTO 'dancesstepsmap' VALUES (12483, 9067, 1);
INSERT INTO 'dancesstepsmap' VALUES (17309, 14642, 3);
INSERT INTO 'dancesstepsmap' VALUES (17314, 14645, 1);
INSERT INTO 'dancesstepsmap' VALUES (17315, 14645, 2);
INSERT INTO 'dancesstepsmap' VALUES (17322, 14649, 4);
INSERT INTO 'dancesstepsmap' VALUES (17326, 14651, 4);
INSERT INTO 'dancesstepsmap' VALUES (17327, 14651, 5);
INSERT INTO 'dancesstepsmap' VALUES (17342, 2048, 3);
INSERT INTO 'dancesstepsmap' VALUES (17350, 14679, 2);
INSERT INTO 'dancesstepsmap' VALUES (23153, 18249, 5);
INSERT INTO 'dancesstepsmap' VALUES (6646, 7206, 1);
INSERT INTO 'dancesstepsmap' VALUES (6647, 7207, 1);
INSERT INTO 'dancesstepsmap' VALUES (6648, 7208, 1);
INSERT INTO 'dancesstepsmap' VALUES (6649, 7209, 4);
INSERT INTO 'dancesstepsmap' VALUES (6650, 7210, 4);
INSERT INTO 'dancesstepsmap' VALUES (6651, 7211, 1);
INSERT INTO 'dancesstepsmap' VALUES (6652, 7213, 4);
INSERT INTO 'dancesstepsmap' VALUES (6653, 7214, 1);
INSERT INTO 'dancesstepsmap' VALUES (6654, 7215, 1);
INSERT INTO 'dancesstepsmap' VALUES (6655, 7216, 1);
INSERT INTO 'dancesstepsmap' VALUES (6656, 7217, 1);
INSERT INTO 'dancesstepsmap' VALUES (6657, 7218, 1);
INSERT INTO 'dancesstepsmap' VALUES (6658, 7219, 1);
INSERT INTO 'dancesstepsmap' VALUES (6659, 7220, 1);
INSERT INTO 'dancesstepsmap' VALUES (6660, 7221, 1);
INSERT INTO 'dancesstepsmap' VALUES (6661, 7222, 1);
INSERT INTO 'dancesstepsmap' VALUES (6662, 7223, 1);
INSERT INTO 'dancesstepsmap' VALUES (6663, 7224, 1);
INSERT INTO 'dancesstepsmap' VALUES (6664, 7225, 1);
INSERT INTO 'dancesstepsmap' VALUES (6665, 7226, 1);
INSERT INTO 'dancesstepsmap' VALUES (6666, 7227, 1);
INSERT INTO 'dancesstepsmap' VALUES (6667, 7228, 4);
INSERT INTO 'dancesstepsmap' VALUES (6668, 7229, 1);
INSERT INTO 'dancesstepsmap' VALUES (6669, 7230, 4);
INSERT INTO 'dancesstepsmap' VALUES (6670, 7231, 1);
INSERT INTO 'dancesstepsmap' VALUES (6671, 7232, 1);
INSERT INTO 'dancesstepsmap' VALUES (6672, 7233, 1);
INSERT INTO 'dancesstepsmap' VALUES (6673, 7234, 4);
INSERT INTO 'dancesstepsmap' VALUES (6674, 7235, 1);
INSERT INTO 'dancesstepsmap' VALUES (6675, 7236, 1);
INSERT INTO 'dancesstepsmap' VALUES (6676, 7237, 1);
INSERT INTO 'dancesstepsmap' VALUES (6677, 7238, 1);
INSERT INTO 'dancesstepsmap' VALUES (6678, 7239, 1);
INSERT INTO 'dancesstepsmap' VALUES (6679, 7240, 1);
INSERT INTO 'dancesstepsmap' VALUES (6680, 7241, 4);
INSERT INTO 'dancesstepsmap' VALUES (6681, 7242, 4);
INSERT INTO 'dancesstepsmap' VALUES (6682, 7244, 1);
INSERT INTO 'dancesstepsmap' VALUES (6683, 7245, 1);
INSERT INTO 'dancesstepsmap' VALUES (6684, 7246, 4);
INSERT INTO 'dancesstepsmap' VALUES (6685, 7248, 1);
INSERT INTO 'dancesstepsmap' VALUES (6686, 7249, 1);
INSERT INTO 'dancesstepsmap' VALUES (6687, 7250, 4);
INSERT INTO 'dancesstepsmap' VALUES (6688, 7251, 1);
INSERT INTO 'dancesstepsmap' VALUES (6689, 7252, 4);
INSERT INTO 'dancesstepsmap' VALUES (6690, 7253, 4);
INSERT INTO 'dancesstepsmap' VALUES (6691, 7254, 1);
INSERT INTO 'dancesstepsmap' VALUES (6692, 7255, 1);
INSERT INTO 'dancesstepsmap' VALUES (6693, 7257, 4);
INSERT INTO 'dancesstepsmap' VALUES (6694, 7258, 4);
INSERT INTO 'dancesstepsmap' VALUES (6695, 7259, 1);
INSERT INTO 'dancesstepsmap' VALUES (6696, 7260, 1);
INSERT INTO 'dancesstepsmap' VALUES (6697, 7261, 4);
INSERT INTO 'dancesstepsmap' VALUES (6698, 7262, 1);
INSERT INTO 'dancesstepsmap' VALUES (6699, 7263, 1);
INSERT INTO 'dancesstepsmap' VALUES (6700, 7264, 1);
INSERT INTO 'dancesstepsmap' VALUES (6701, 7265, 4);
INSERT INTO 'dancesstepsmap' VALUES (6702, 7266, 1);
INSERT INTO 'dancesstepsmap' VALUES (6703, 7267, 4);
INSERT INTO 'dancesstepsmap' VALUES (6704, 7268, 4);
INSERT INTO 'dancesstepsmap' VALUES (6705, 7269, 1);
INSERT INTO 'dancesstepsmap' VALUES (6706, 7271, 1);
INSERT INTO 'dancesstepsmap' VALUES (6707, 7273, 1);
INSERT INTO 'dancesstepsmap' VALUES (6708, 7275, 4);
INSERT INTO 'dancesstepsmap' VALUES (6709, 7276, 4);
INSERT INTO 'dancesstepsmap' VALUES (6710, 7277, 1);
INSERT INTO 'dancesstepsmap' VALUES (6711, 7279, 4);
INSERT INTO 'dancesstepsmap' VALUES (6712, 7280, 1);
INSERT INTO 'dancesstepsmap' VALUES (6713, 7281, 1);
INSERT INTO 'dancesstepsmap' VALUES (6714, 7282, 1);
INSERT INTO 'dancesstepsmap' VALUES (6715, 7283, 1);
INSERT INTO 'dancesstepsmap' VALUES (6716, 7284, 4);
INSERT INTO 'dancesstepsmap' VALUES (6717, 7285, 1);
INSERT INTO 'dancesstepsmap' VALUES (6718, 7286, 1);
INSERT INTO 'dancesstepsmap' VALUES (6719, 7288, 1);
INSERT INTO 'dancesstepsmap' VALUES (6720, 159, 5);
INSERT INTO 'dancesstepsmap' VALUES (6721, 6, 2);
INSERT INTO 'dancesstepsmap' VALUES (6722, 7283, 2);
INSERT INTO 'dancesstepsmap' VALUES (6723, 4933, 2);
INSERT INTO 'dancesstepsmap' VALUES (6724, 4933, 3);
INSERT INTO 'dancesstepsmap' VALUES (6725, 7284, 5);
INSERT INTO 'dancesstepsmap' VALUES (6726, 7286, 3);
INSERT INTO 'dancesstepsmap' VALUES (6727, 1782, 3);
INSERT INTO 'dancesstepsmap' VALUES (6728, 5637, 6);
INSERT INTO 'dancesstepsmap' VALUES (6729, 5354, 2);
INSERT INTO 'dancesstepsmap' VALUES (6730, 5354, 8);
INSERT INTO 'dancesstepsmap' VALUES (6731, 7287, 4);
INSERT INTO 'dancesstepsmap' VALUES (6732, 7287, 5);
INSERT INTO 'dancesstepsmap' VALUES (6733, 7288, 2);
INSERT INTO 'dancesstepsmap' VALUES (6734, 7291, 1);
INSERT INTO 'dancesstepsmap' VALUES (6735, 7291, 2);
INSERT INTO 'dancesstepsmap' VALUES (6736, 7292, 1);
INSERT INTO 'dancesstepsmap' VALUES (6737, 7292, 2);
INSERT INTO 'dancesstepsmap' VALUES (6738, 7292, 3);
INSERT INTO 'dancesstepsmap' VALUES (12484, 9067, 4);
INSERT INTO 'dancesstepsmap' VALUES (12485, 9898, 5);
INSERT INTO 'dancesstepsmap' VALUES (12486, 9898, 4);
INSERT INTO 'dancesstepsmap' VALUES (12487, 11164, 2);
INSERT INTO 'dancesstepsmap' VALUES (12488, 11164, 3);
INSERT INTO 'dancesstepsmap' VALUES (12489, 11164, 1);
INSERT INTO 'dancesstepsmap' VALUES (12490, 11170, 4);
INSERT INTO 'dancesstepsmap' VALUES (12491, 11216, 1);
INSERT INTO 'dancesstepsmap' VALUES (12492, 11217, 2);
INSERT INTO 'dancesstepsmap' VALUES (12493, 11217, 1);
INSERT INTO 'dancesstepsmap' VALUES (12494, 10554, 3);
INSERT INTO 'dancesstepsmap' VALUES (12495, 10554, 1);
INSERT INTO 'dancesstepsmap' VALUES (12496, 10554, 2);
INSERT INTO 'dancesstepsmap' VALUES (12497, 10554, 4);
INSERT INTO 'dancesstepsmap' VALUES (12498, 10554, 5);
INSERT INTO 'dancesstepsmap' VALUES (12499, 9862, 5);
INSERT INTO 'dancesstepsmap' VALUES (12500, 9862, 4);
INSERT INTO 'dancesstepsmap' VALUES (12501, 11218, 4);
INSERT INTO 'dancesstepsmap' VALUES (12502, 11219, 1);
INSERT INTO 'dancesstepsmap' VALUES (12503, 11219, 2);
INSERT INTO 'dancesstepsmap' VALUES (12504, 11220, 4);
INSERT INTO 'dancesstepsmap' VALUES (12505, 11221, 1);
INSERT INTO 'dancesstepsmap' VALUES (12506, 11221, 2);
INSERT INTO 'dancesstepsmap' VALUES (12507, 10703, 1);
INSERT INTO 'dancesstepsmap' VALUES (12508, 1829, 2);
INSERT INTO 'dancesstepsmap' VALUES (12509, 615, 2);
INSERT INTO 'dancesstepsmap' VALUES (12510, 10533, 1);
INSERT INTO 'dancesstepsmap' VALUES (12511, 10533, 2);
INSERT INTO 'dancesstepsmap' VALUES (12512, 10533, 3);
INSERT INTO 'dancesstepsmap' VALUES (12513, 10534, 4);
INSERT INTO 'dancesstepsmap' VALUES (12514, 10534, 5);
INSERT INTO 'dancesstepsmap' VALUES (12515, 10318, 2);
INSERT INTO 'dancesstepsmap' VALUES (12516, 11258, 2);
INSERT INTO 'dancesstepsmap' VALUES (12517, 11258, 1);
INSERT INTO 'dancesstepsmap' VALUES (12518, 11027, 1);
INSERT INTO 'dancesstepsmap' VALUES (12519, 11027, 2);
INSERT INTO 'dancesstepsmap' VALUES (12520, 11027, 3);
INSERT INTO 'dancesstepsmap' VALUES (12521, 10761, 1);
INSERT INTO 'dancesstepsmap' VALUES (12522, 160, 3);
INSERT INTO 'dancesstepsmap' VALUES (12523, 170, 2);
INSERT INTO 'dancesstepsmap' VALUES (12524, 280, 3);
INSERT INTO 'dancesstepsmap' VALUES (12525, 7344, 5);
INSERT INTO 'dancesstepsmap' VALUES (17310, 14643, 1);
INSERT INTO 'dancesstepsmap' VALUES (17311, 14643, 2);
INSERT INTO 'dancesstepsmap' VALUES (17312, 14643, 3);
INSERT INTO 'dancesstepsmap' VALUES (17316, 14646, 4);
INSERT INTO 'dancesstepsmap' VALUES (17317, 14646, 5);
INSERT INTO 'dancesstepsmap' VALUES (17332, 14654, 5);
INSERT INTO 'dancesstepsmap' VALUES (17333, 14654, 4);
INSERT INTO 'dancesstepsmap' VALUES (17352, 14681, 4);
INSERT INTO 'dancesstepsmap' VALUES (17353, 14681, 5);
INSERT INTO 'dancesstepsmap' VALUES (17354, 14682, 1);
INSERT INTO 'dancesstepsmap' VALUES (17355, 14682, 2);
INSERT INTO 'dancesstepsmap' VALUES (17356, 14682, 3);
INSERT INTO 'dancesstepsmap' VALUES (17357, 14683, 4);
INSERT INTO 'dancesstepsmap' VALUES (17358, 14684, 1);
INSERT INTO 'dancesstepsmap' VALUES (23154, 7459, 5);
INSERT INTO 'dancesstepsmap' VALUES (17365, 2588, 5);
INSERT INTO 'dancesstepsmap' VALUES (17366, 5476, 2);
INSERT INTO 'dancesstepsmap' VALUES (17368, 2747, 2);
INSERT INTO 'dancesstepsmap' VALUES (17369, 8842, 2);
INSERT INTO 'dancesstepsmap' VALUES (17370, 8161, 99);
INSERT INTO 'dancesstepsmap' VALUES (17351, 14679, 8);
INSERT INTO 'dancesstepsmap' VALUES (17371, 14690, 3);
INSERT INTO 'dancesstepsmap' VALUES (17372, 14690, 1);
INSERT INTO 'dancesstepsmap' VALUES (6739, 7295, 1);
INSERT INTO 'dancesstepsmap' VALUES (6740, 7295, 2);
INSERT INTO 'dancesstepsmap' VALUES (6741, 5915, 2);
INSERT INTO 'dancesstepsmap' VALUES (6742, 5915, 1);
INSERT INTO 'dancesstepsmap' VALUES (6743, 5915, 4);
INSERT INTO 'dancesstepsmap' VALUES (6744, 5915, 5);
INSERT INTO 'dancesstepsmap' VALUES (23155, 17878, 1);
INSERT INTO 'dancesstepsmap' VALUES (6746, 3317, 5);
INSERT INTO 'dancesstepsmap' VALUES (6747, 2333, 2);
INSERT INTO 'dancesstepsmap' VALUES (6748, 2333, 8);
INSERT INTO 'dancesstepsmap' VALUES (6749, 1492, 2);
INSERT INTO 'dancesstepsmap' VALUES (6750, 1492, 3);
INSERT INTO 'dancesstepsmap' VALUES (6751, 2237, 5);
INSERT INTO 'dancesstepsmap' VALUES (6752, 2237, 6);
INSERT INTO 'dancesstepsmap' VALUES (6753, 4273, 2);
INSERT INTO 'dancesstepsmap' VALUES (6754, 2745, 2);
INSERT INTO 'dancesstepsmap' VALUES (6755, 2745, 3);
INSERT INTO 'dancesstepsmap' VALUES (6756, 754, 5);
INSERT INTO 'dancesstepsmap' VALUES (6757, 1296, 2);
INSERT INTO 'dancesstepsmap' VALUES (6758, 1792, 2);
INSERT INTO 'dancesstepsmap' VALUES (6759, 2302, 7);
INSERT INTO 'dancesstepsmap' VALUES (6760, 2846, 7);
INSERT INTO 'dancesstepsmap' VALUES (6761, 3373, 2);
INSERT INTO 'dancesstepsmap' VALUES (6762, 6359, 7);
INSERT INTO 'dancesstepsmap' VALUES (6763, 407, 5);
INSERT INTO 'dancesstepsmap' VALUES (6764, 888, 2);
INSERT INTO 'dancesstepsmap' VALUES (6765, 1854, 5);
INSERT INTO 'dancesstepsmap' VALUES (6766, 2900, 2);
INSERT INTO 'dancesstepsmap' VALUES (6767, 4776, 2);
INSERT INTO 'dancesstepsmap' VALUES (6768, 6387, 2);
INSERT INTO 'dancesstepsmap' VALUES (6769, 6387, 3);
INSERT INTO 'dancesstepsmap' VALUES (6770, 2900, 3);
INSERT INTO 'dancesstepsmap' VALUES (6771, 3623, 2);
INSERT INTO 'dancesstepsmap' VALUES (6772, 4309, 2);
INSERT INTO 'dancesstepsmap' VALUES (6773, 4309, 3);
INSERT INTO 'dancesstepsmap' VALUES (6774, 4356, 3);
INSERT INTO 'dancesstepsmap' VALUES (6775, 4356, 2);
INSERT INTO 'dancesstepsmap' VALUES (6776, 5497, 2);
INSERT INTO 'dancesstepsmap' VALUES (6777, 7242, 5);
INSERT INTO 'dancesstepsmap' VALUES (6778, 7245, 2);
INSERT INTO 'dancesstepsmap' VALUES (6779, 7298, 1);
INSERT INTO 'dancesstepsmap' VALUES (6780, 7299, 1);
INSERT INTO 'dancesstepsmap' VALUES (6781, 7302, 1);
INSERT INTO 'dancesstepsmap' VALUES (6782, 7303, 4);
INSERT INTO 'dancesstepsmap' VALUES (6783, 7303, 5);
INSERT INTO 'dancesstepsmap' VALUES (6784, 7305, 1);
INSERT INTO 'dancesstepsmap' VALUES (6785, 7305, 2);
INSERT INTO 'dancesstepsmap' VALUES (6786, 7306, 1);
INSERT INTO 'dancesstepsmap' VALUES (6787, 7307, 1);
INSERT INTO 'dancesstepsmap' VALUES (6788, 7308, 1);
INSERT INTO 'dancesstepsmap' VALUES (6789, 7309, 1);
INSERT INTO 'dancesstepsmap' VALUES (6790, 7310, 1);
INSERT INTO 'dancesstepsmap' VALUES (6791, 3631, 2);
INSERT INTO 'dancesstepsmap' VALUES (6792, 742, 5);
INSERT INTO 'dancesstepsmap' VALUES (6793, 742, 6);
INSERT INTO 'dancesstepsmap' VALUES (6794, 1930, 2);
INSERT INTO 'dancesstepsmap' VALUES (6795, 7281, 2);
INSERT INTO 'dancesstepsmap' VALUES (6796, 2409, 6);
INSERT INTO 'dancesstepsmap' VALUES (6797, 4236, 2);
INSERT INTO 'dancesstepsmap' VALUES (6798, 468, 4);
INSERT INTO 'dancesstepsmap' VALUES (6799, 2332, 2);
INSERT INTO 'dancesstepsmap' VALUES (6800, 4311, 2);
INSERT INTO 'dancesstepsmap' VALUES (6801, 4310, 2);
INSERT INTO 'dancesstepsmap' VALUES (6802, 7037, 2);
INSERT INTO 'dancesstepsmap' VALUES (6803, 7319, 4);
INSERT INTO 'dancesstepsmap' VALUES (6804, 7320, 1);
INSERT INTO 'dancesstepsmap' VALUES (6805, 7323, 1);
INSERT INTO 'dancesstepsmap' VALUES (6806, 7324, 4);
INSERT INTO 'dancesstepsmap' VALUES (6807, 7271, 99);
INSERT INTO 'dancesstepsmap' VALUES (6808, 7271, 2);
INSERT INTO 'dancesstepsmap' VALUES (6809, 6852, 5);
INSERT INTO 'dancesstepsmap' VALUES (6810, 7327, 1);
INSERT INTO 'dancesstepsmap' VALUES (6811, 7329, 1);
INSERT INTO 'dancesstepsmap' VALUES (6812, 7329, 2);
INSERT INTO 'dancesstepsmap' VALUES (6813, 7330, 2);
INSERT INTO 'dancesstepsmap' VALUES (6814, 7330, 1);
INSERT INTO 'dancesstepsmap' VALUES (6815, 7332, 1);
INSERT INTO 'dancesstepsmap' VALUES (6816, 7331, 1);
INSERT INTO 'dancesstepsmap' VALUES (6817, 7331, 2);
INSERT INTO 'dancesstepsmap' VALUES (6818, 1, 1);
INSERT INTO 'dancesstepsmap' VALUES (6821, 5260, 3);
INSERT INTO 'dancesstepsmap' VALUES (6822, 5260, 2);
INSERT INTO 'dancesstepsmap' VALUES (6823, 4126, 5);
INSERT INTO 'dancesstepsmap' VALUES (6824, 7466, 1);
INSERT INTO 'dancesstepsmap' VALUES (6825, 7466, 2);
INSERT INTO 'dancesstepsmap' VALUES (6826, 7337, 3);
INSERT INTO 'dancesstepsmap' VALUES (6827, 7337, 1);
INSERT INTO 'dancesstepsmap' VALUES (6828, 7339, 1);
INSERT INTO 'dancesstepsmap' VALUES (6829, 7350, 1);
INSERT INTO 'dancesstepsmap' VALUES (6830, 7350, 2);
INSERT INTO 'dancesstepsmap' VALUES (12526, 9453, 1);
INSERT INTO 'dancesstepsmap' VALUES (12527, 9453, 2);
INSERT INTO 'dancesstepsmap' VALUES (12528, 11259, 1);
INSERT INTO 'dancesstepsmap' VALUES (12529, 11260, 3);
INSERT INTO 'dancesstepsmap' VALUES (12530, 11260, 1);
INSERT INTO 'dancesstepsmap' VALUES (12531, 11261, 4);
INSERT INTO 'dancesstepsmap' VALUES (12532, 11261, 5);
INSERT INTO 'dancesstepsmap' VALUES (12533, 11223, 1);
INSERT INTO 'dancesstepsmap' VALUES (12534, 11223, 2);
INSERT INTO 'dancesstepsmap' VALUES (12535, 11223, 3);
INSERT INTO 'dancesstepsmap' VALUES (12536, 11262, 1);
INSERT INTO 'dancesstepsmap' VALUES (12537, 11262, 3);
INSERT INTO 'dancesstepsmap' VALUES (12538, 11262, 2);
INSERT INTO 'dancesstepsmap' VALUES (12539, 11264, 4);
INSERT INTO 'dancesstepsmap' VALUES (12540, 11265, 3);
INSERT INTO 'dancesstepsmap' VALUES (12541, 11266, 2);
INSERT INTO 'dancesstepsmap' VALUES (12542, 11266, 1);
INSERT INTO 'dancesstepsmap' VALUES (12543, 11266, 3);
INSERT INTO 'dancesstepsmap' VALUES (12544, 11267, 4);
INSERT INTO 'dancesstepsmap' VALUES (12545, 11268, 4);
INSERT INTO 'dancesstepsmap' VALUES (12546, 11268, 5);
INSERT INTO 'dancesstepsmap' VALUES (12547, 5080, 2);
INSERT INTO 'dancesstepsmap' VALUES (12548, 2668, 1);
INSERT INTO 'dancesstepsmap' VALUES (12549, 7568, 5);
INSERT INTO 'dancesstepsmap' VALUES (12550, 7567, 2);
INSERT INTO 'dancesstepsmap' VALUES (12551, 7569, 2);
INSERT INTO 'dancesstepsmap' VALUES (12552, 3008, 2);
INSERT INTO 'dancesstepsmap' VALUES (12553, 3008, 1);
INSERT INTO 'dancesstepsmap' VALUES (12554, 3008, 3);
INSERT INTO 'dancesstepsmap' VALUES (12555, 3641, 4);
INSERT INTO 'dancesstepsmap' VALUES (12556, 4517, 5);
INSERT INTO 'dancesstepsmap' VALUES (12557, 4517, 4);
INSERT INTO 'dancesstepsmap' VALUES (12558, 4517, 1);
INSERT INTO 'dancesstepsmap' VALUES (12559, 4517, 2);
INSERT INTO 'dancesstepsmap' VALUES (12560, 1335, 2);
INSERT INTO 'dancesstepsmap' VALUES (12561, 3421, 2);
INSERT INTO 'dancesstepsmap' VALUES (12562, 5174, 2);
INSERT INTO 'dancesstepsmap' VALUES (12563, 5535, 2);
INSERT INTO 'dancesstepsmap' VALUES (12564, 5853, 4);
INSERT INTO 'dancesstepsmap' VALUES (12565, 8992, 4);
INSERT INTO 'dancesstepsmap' VALUES (12566, 8992, 5);
INSERT INTO 'dancesstepsmap' VALUES (12567, 11269, 5);
INSERT INTO 'dancesstepsmap' VALUES (12568, 11269, 4);
INSERT INTO 'dancesstepsmap' VALUES (17318, 14647, 1);
INSERT INTO 'dancesstepsmap' VALUES (17319, 14647, 2);
INSERT INTO 'dancesstepsmap' VALUES (17334, 14655, 2);
INSERT INTO 'dancesstepsmap' VALUES (17335, 14655, 1);
INSERT INTO 'dancesstepsmap' VALUES (17359, 14685, 4);
INSERT INTO 'dancesstepsmap' VALUES (17367, 5867, 2);
INSERT INTO 'dancesstepsmap' VALUES (17373, 14691, 2);
INSERT INTO 'dancesstepsmap' VALUES (17374, 14691, 1);
INSERT INTO 'dancesstepsmap' VALUES (17375, 14692, 2);
INSERT INTO 'dancesstepsmap' VALUES (17376, 14692, 1);
INSERT INTO 'dancesstepsmap' VALUES (6831, 7351, 4);
INSERT INTO 'dancesstepsmap' VALUES (6832, 7351, 5);
INSERT INTO 'dancesstepsmap' VALUES (6833, 7368, 1);
INSERT INTO 'dancesstepsmap' VALUES (6834, 7368, 2);
INSERT INTO 'dancesstepsmap' VALUES (6835, 7375, 1);
INSERT INTO 'dancesstepsmap' VALUES (6836, 7375, 3);
INSERT INTO 'dancesstepsmap' VALUES (6837, 7388, 2);
INSERT INTO 'dancesstepsmap' VALUES (6838, 7388, 1);
INSERT INTO 'dancesstepsmap' VALUES (6839, 7404, 4);
INSERT INTO 'dancesstepsmap' VALUES (6840, 7404, 5);
INSERT INTO 'dancesstepsmap' VALUES (6841, 7406, 1);
INSERT INTO 'dancesstepsmap' VALUES (6842, 7406, 3);
INSERT INTO 'dancesstepsmap' VALUES (6843, 7420, 4);
INSERT INTO 'dancesstepsmap' VALUES (6844, 7420, 5);
INSERT INTO 'dancesstepsmap' VALUES (6845, 132, 2);
INSERT INTO 'dancesstepsmap' VALUES (6846, 301, 5);
INSERT INTO 'dancesstepsmap' VALUES (6847, 656, 2);
INSERT INTO 'dancesstepsmap' VALUES (6848, 805, 5);
INSERT INTO 'dancesstepsmap' VALUES (6849, 805, 6);
INSERT INTO 'dancesstepsmap' VALUES (6850, 848, 3);
INSERT INTO 'dancesstepsmap' VALUES (6851, 1163, 3);
INSERT INTO 'dancesstepsmap' VALUES (6852, 1163, 2);
INSERT INTO 'dancesstepsmap' VALUES (6853, 1733, 3);
INSERT INTO 'dancesstepsmap' VALUES (6854, 1733, 2);
INSERT INTO 'dancesstepsmap' VALUES (6855, 2136, 5);
INSERT INTO 'dancesstepsmap' VALUES (6856, 3428, 5);
INSERT INTO 'dancesstepsmap' VALUES (6857, 3437, 2);
INSERT INTO 'dancesstepsmap' VALUES (6858, 3526, 2);
INSERT INTO 'dancesstepsmap' VALUES (6859, 3620, 2);
INSERT INTO 'dancesstepsmap' VALUES (6860, 3883, 99);
INSERT INTO 'dancesstepsmap' VALUES (6861, 4014, 99);
INSERT INTO 'dancesstepsmap' VALUES (6862, 4014, 2);
INSERT INTO 'dancesstepsmap' VALUES (6863, 4358, 4);
INSERT INTO 'dancesstepsmap' VALUES (6864, 4358, 5);
INSERT INTO 'dancesstepsmap' VALUES (6865, 4358, 2);
INSERT INTO 'dancesstepsmap' VALUES (6866, 4358, 1);
INSERT INTO 'dancesstepsmap' VALUES (6867, 4359, 2);
INSERT INTO 'dancesstepsmap' VALUES (6868, 4579, 5);
INSERT INTO 'dancesstepsmap' VALUES (6869, 4680, 5);
INSERT INTO 'dancesstepsmap' VALUES (6870, 4680, 7);
INSERT INTO 'dancesstepsmap' VALUES (6871, 4680, 6);
INSERT INTO 'dancesstepsmap' VALUES (6872, 4894, 3);
INSERT INTO 'dancesstepsmap' VALUES (6873, 5128, 2);
INSERT INTO 'dancesstepsmap' VALUES (6874, 5128, 99);
INSERT INTO 'dancesstepsmap' VALUES (6875, 5407, 2);
INSERT INTO 'dancesstepsmap' VALUES (6876, 5624, 5);
INSERT INTO 'dancesstepsmap' VALUES (6877, 5749, 2);
INSERT INTO 'dancesstepsmap' VALUES (6878, 5749, 3);
INSERT INTO 'dancesstepsmap' VALUES (6879, 5847, 2);
INSERT INTO 'dancesstepsmap' VALUES (6880, 6130, 3);
INSERT INTO 'dancesstepsmap' VALUES (6881, 6130, 2);
INSERT INTO 'dancesstepsmap' VALUES (6882, 6710, 2);
INSERT INTO 'dancesstepsmap' VALUES (6883, 6824, 2);
INSERT INTO 'dancesstepsmap' VALUES (6884, 7548, 6);
INSERT INTO 'dancesstepsmap' VALUES (6886, 6532, 4);
INSERT INTO 'dancesstepsmap' VALUES (6887, 6532, 1);
INSERT INTO 'dancesstepsmap' VALUES (6888, 7557, 1);
INSERT INTO 'dancesstepsmap' VALUES (6889, 7557, 2);
INSERT INTO 'dancesstepsmap' VALUES (6890, 7558, 1);
INSERT INTO 'dancesstepsmap' VALUES (6891, 4858, 2);
INSERT INTO 'dancesstepsmap' VALUES (6892, 5065, 2);
INSERT INTO 'dancesstepsmap' VALUES (6893, 1641, 3);
INSERT INTO 'dancesstepsmap' VALUES (6894, 2046, 2);
INSERT INTO 'dancesstepsmap' VALUES (6895, 3085, 3);
INSERT INTO 'dancesstepsmap' VALUES (6896, 3085, 2);
INSERT INTO 'dancesstepsmap' VALUES (6897, 5239, 2);
INSERT INTO 'dancesstepsmap' VALUES (6898, 6748, 2);
INSERT INTO 'dancesstepsmap' VALUES (6899, 1210, 2);
INSERT INTO 'dancesstepsmap' VALUES (6900, 5007, 2);
INSERT INTO 'dancesstepsmap' VALUES (6901, 2166, 2);
INSERT INTO 'dancesstepsmap' VALUES (6902, 862, 2);
INSERT INTO 'dancesstepsmap' VALUES (6903, 2498, 99);
INSERT INTO 'dancesstepsmap' VALUES (6904, 6233, 2);
INSERT INTO 'dancesstepsmap' VALUES (6905, 5376, 3);
INSERT INTO 'dancesstepsmap' VALUES (6906, 2682, 5);
INSERT INTO 'dancesstepsmap' VALUES (6907, 608, 5);
INSERT INTO 'dancesstepsmap' VALUES (6908, 2820, 7);
INSERT INTO 'dancesstepsmap' VALUES (6909, 1931, 2);
INSERT INTO 'dancesstepsmap' VALUES (6910, 1562, 2);
INSERT INTO 'dancesstepsmap' VALUES (6911, 5641, 2);
INSERT INTO 'dancesstepsmap' VALUES (6912, 5450, 2);
INSERT INTO 'dancesstepsmap' VALUES (6913, 1927, 2);
INSERT INTO 'dancesstepsmap' VALUES (6914, 2317, 99);
INSERT INTO 'dancesstepsmap' VALUES (6915, 5532, 2);
INSERT INTO 'dancesstepsmap' VALUES (6916, 5532, 8);
INSERT INTO 'dancesstepsmap' VALUES (6917, 5532, 99);
INSERT INTO 'dancesstepsmap' VALUES (6918, 6658, 2);
INSERT INTO 'dancesstepsmap' VALUES (6919, 5436, 2);
INSERT INTO 'dancesstepsmap' VALUES (6920, 3802, 2);
INSERT INTO 'dancesstepsmap' VALUES (23156, 17878, 2);
INSERT INTO 'dancesstepsmap' VALUES (6922, 2812, 6);
INSERT INTO 'dancesstepsmap' VALUES (6923, 6505, 2);
INSERT INTO 'dancesstepsmap' VALUES (12569, 9407, 1);
INSERT INTO 'dancesstepsmap' VALUES (12570, 9407, 2);
INSERT INTO 'dancesstepsmap' VALUES (12571, 9407, 3);
INSERT INTO 'dancesstepsmap' VALUES (12572, 11270, 5);
INSERT INTO 'dancesstepsmap' VALUES (12573, 11270, 4);
INSERT INTO 'dancesstepsmap' VALUES (12574, 11271, 1);
INSERT INTO 'dancesstepsmap' VALUES (12575, 11272, 4);
INSERT INTO 'dancesstepsmap' VALUES (12578, 11274, 1);
INSERT INTO 'dancesstepsmap' VALUES (12579, 11274, 2);
INSERT INTO 'dancesstepsmap' VALUES (12582, 11276, 5);
INSERT INTO 'dancesstepsmap' VALUES (12583, 11276, 4);
INSERT INTO 'dancesstepsmap' VALUES (12584, 11276, 1);
INSERT INTO 'dancesstepsmap' VALUES (12585, 11276, 2);
INSERT INTO 'dancesstepsmap' VALUES (12586, 11276, 10);
INSERT INTO 'dancesstepsmap' VALUES (12587, 11277, 1);
INSERT INTO 'dancesstepsmap' VALUES (12588, 11277, 2);
INSERT INTO 'dancesstepsmap' VALUES (12589, 11278, 1);
INSERT INTO 'dancesstepsmap' VALUES (12590, 11278, 2);
INSERT INTO 'dancesstepsmap' VALUES (12591, 11279, 3);
INSERT INTO 'dancesstepsmap' VALUES (12592, 11279, 1);
INSERT INTO 'dancesstepsmap' VALUES (12593, 11280, 1);
INSERT INTO 'dancesstepsmap' VALUES (12594, 11280, 2);
INSERT INTO 'dancesstepsmap' VALUES (12595, 11279, 2);
INSERT INTO 'dancesstepsmap' VALUES (12596, 11279, 8);
INSERT INTO 'dancesstepsmap' VALUES (12597, 11279, 10);
INSERT INTO 'dancesstepsmap' VALUES (12598, 11281, 5);
INSERT INTO 'dancesstepsmap' VALUES (12599, 11281, 4);
INSERT INTO 'dancesstepsmap' VALUES (12600, 11299, 4);
INSERT INTO 'dancesstepsmap' VALUES (12601, 11299, 5);
INSERT INTO 'dancesstepsmap' VALUES (12602, 11297, 2);
INSERT INTO 'dancesstepsmap' VALUES (12603, 11297, 1);
INSERT INTO 'dancesstepsmap' VALUES (12606, 11306, 4);
INSERT INTO 'dancesstepsmap' VALUES (12607, 11306, 5);
INSERT INTO 'dancesstepsmap' VALUES (12608, 11307, 2);
INSERT INTO 'dancesstepsmap' VALUES (12609, 11307, 1);
INSERT INTO 'dancesstepsmap' VALUES (12610, 11308, 2);
INSERT INTO 'dancesstepsmap' VALUES (17336, 14656, 1);
INSERT INTO 'dancesstepsmap' VALUES (17337, 14656, 2);
INSERT INTO 'dancesstepsmap' VALUES (17360, 14686, 1);
INSERT INTO 'dancesstepsmap' VALUES (17361, 14686, 2);
INSERT INTO 'dancesstepsmap' VALUES (17362, 14686, 3);
INSERT INTO 'dancesstepsmap' VALUES (17377, 14693, 5);
INSERT INTO 'dancesstepsmap' VALUES (17378, 14693, 4);
INSERT INTO 'dancesstepsmap' VALUES (17379, 14694, 1);
INSERT INTO 'dancesstepsmap' VALUES (17380, 14694, 2);
INSERT INTO 'dancesstepsmap' VALUES (17381, 14694, 3);
INSERT INTO 'dancesstepsmap' VALUES (17384, 14696, 1);
INSERT INTO 'dancesstepsmap' VALUES (17385, 14696, 2);
INSERT INTO 'dancesstepsmap' VALUES (17386, 14696, 3);
INSERT INTO 'dancesstepsmap' VALUES (17387, 14689, 1);
INSERT INTO 'dancesstepsmap' VALUES (17388, 14689, 2);
INSERT INTO 'dancesstepsmap' VALUES (17389, 14688, 1);
INSERT INTO 'dancesstepsmap' VALUES (17390, 14688, 2);
INSERT INTO 'dancesstepsmap' VALUES (17391, 14697, 5);
INSERT INTO 'dancesstepsmap' VALUES (17392, 14697, 4);
INSERT INTO 'dancesstepsmap' VALUES (17395, 14244, 2);
INSERT INTO 'dancesstepsmap' VALUES (17396, 14244, 1);
INSERT INTO 'dancesstepsmap' VALUES (17397, 13762, 2);
INSERT INTO 'dancesstepsmap' VALUES (6924, 1799, 2);
INSERT INTO 'dancesstepsmap' VALUES (6925, 3236, 5);
INSERT INTO 'dancesstepsmap' VALUES (6926, 5708, 8);
INSERT INTO 'dancesstepsmap' VALUES (6927, 5708, 2);
INSERT INTO 'dancesstepsmap' VALUES (6928, 3834, 2);
INSERT INTO 'dancesstepsmap' VALUES (6929, 5963, 5);
INSERT INTO 'dancesstepsmap' VALUES (6930, 1790, 5);
INSERT INTO 'dancesstepsmap' VALUES (6931, 3637, 2);
INSERT INTO 'dancesstepsmap' VALUES (6932, 1476, 2);
INSERT INTO 'dancesstepsmap' VALUES (6933, 7109, 2);
INSERT INTO 'dancesstepsmap' VALUES (6934, 1274, 3);
INSERT INTO 'dancesstepsmap' VALUES (6935, 5731, 2);
INSERT INTO 'dancesstepsmap' VALUES (6936, 1916, 5);
INSERT INTO 'dancesstepsmap' VALUES (6937, 5702, 2);
INSERT INTO 'dancesstepsmap' VALUES (6938, 6585, 4);
INSERT INTO 'dancesstepsmap' VALUES (6939, 6585, 1);
INSERT INTO 'dancesstepsmap' VALUES (6940, 6585, 99);
INSERT INTO 'dancesstepsmap' VALUES (6941, 610, 3);
INSERT INTO 'dancesstepsmap' VALUES (6942, 3940, 2);
INSERT INTO 'dancesstepsmap' VALUES (6943, 4782, 2);
INSERT INTO 'dancesstepsmap' VALUES (6944, 738, 5);
INSERT INTO 'dancesstepsmap' VALUES (6945, 3246, 2);
INSERT INTO 'dancesstepsmap' VALUES (6946, 3730, 2);
INSERT INTO 'dancesstepsmap' VALUES (6947, 6599, 5);
INSERT INTO 'dancesstepsmap' VALUES (6948, 5032, 2);
INSERT INTO 'dancesstepsmap' VALUES (6949, 4450, 2);
INSERT INTO 'dancesstepsmap' VALUES (6950, 4862, 2);
INSERT INTO 'dancesstepsmap' VALUES (6951, 4755, 5);
INSERT INTO 'dancesstepsmap' VALUES (6952, 1501, 5);
INSERT INTO 'dancesstepsmap' VALUES (6953, 3091, 5);
INSERT INTO 'dancesstepsmap' VALUES (6954, 2428, 2);
INSERT INTO 'dancesstepsmap' VALUES (6955, 1415, 2);
INSERT INTO 'dancesstepsmap' VALUES (6956, 3152, 2);
INSERT INTO 'dancesstepsmap' VALUES (6957, 4068, 5);
INSERT INTO 'dancesstepsmap' VALUES (6958, 4032, 2);
INSERT INTO 'dancesstepsmap' VALUES (6959, 651, 1);
INSERT INTO 'dancesstepsmap' VALUES (6960, 651, 4);
INSERT INTO 'dancesstepsmap' VALUES (6961, 651, 5);
INSERT INTO 'dancesstepsmap' VALUES (6962, 5616, 5);
INSERT INTO 'dancesstepsmap' VALUES (6963, 3474, 1);
INSERT INTO 'dancesstepsmap' VALUES (6964, 3474, 2);
INSERT INTO 'dancesstepsmap' VALUES (6965, 1864, 3);
INSERT INTO 'dancesstepsmap' VALUES (6966, 3921, 4);
INSERT INTO 'dancesstepsmap' VALUES (6967, 3921, 1);
INSERT INTO 'dancesstepsmap' VALUES (6968, 3921, 2);
INSERT INTO 'dancesstepsmap' VALUES (6970, 4968, 2);
INSERT INTO 'dancesstepsmap' VALUES (6971, 6285, 5);
INSERT INTO 'dancesstepsmap' VALUES (6972, 6058, 2);
INSERT INTO 'dancesstepsmap' VALUES (6973, 6391, 2);
INSERT INTO 'dancesstepsmap' VALUES (6974, 3338, 2);
INSERT INTO 'dancesstepsmap' VALUES (6975, 5529, 2);
INSERT INTO 'dancesstepsmap' VALUES (6976, 3418, 2);
INSERT INTO 'dancesstepsmap' VALUES (6977, 4796, 5);
INSERT INTO 'dancesstepsmap' VALUES (6978, 2453, 2);
INSERT INTO 'dancesstepsmap' VALUES (6979, 2034, 2);
INSERT INTO 'dancesstepsmap' VALUES (6980, 4438, 2);
INSERT INTO 'dancesstepsmap' VALUES (6981, 2807, 2);
INSERT INTO 'dancesstepsmap' VALUES (6982, 5906, 2);
INSERT INTO 'dancesstepsmap' VALUES (6983, 6566, 5);
INSERT INTO 'dancesstepsmap' VALUES (6984, 2501, 5);
INSERT INTO 'dancesstepsmap' VALUES (6985, 5326, 2);
INSERT INTO 'dancesstepsmap' VALUES (6986, 1544, 2);
INSERT INTO 'dancesstepsmap' VALUES (6987, 7135, 2);
INSERT INTO 'dancesstepsmap' VALUES (6988, 1473, 5);
INSERT INTO 'dancesstepsmap' VALUES (6989, 6823, 2);
INSERT INTO 'dancesstepsmap' VALUES (6991, 2278, 2);
INSERT INTO 'dancesstepsmap' VALUES (12576, 11273, 1);
INSERT INTO 'dancesstepsmap' VALUES (12577, 11273, 2);
INSERT INTO 'dancesstepsmap' VALUES (12580, 11275, 4);
INSERT INTO 'dancesstepsmap' VALUES (12581, 11275, 5);
INSERT INTO 'dancesstepsmap' VALUES (17382, 14694, 102);
INSERT INTO 'dancesstepsmap' VALUES (6992, 2278, 3);
INSERT INTO 'dancesstepsmap' VALUES (6993, 2722, 3);
INSERT INTO 'dancesstepsmap' VALUES (6994, 2722, 1);
INSERT INTO 'dancesstepsmap' VALUES (6995, 2722, 2);
INSERT INTO 'dancesstepsmap' VALUES (6996, 2722, 5);
INSERT INTO 'dancesstepsmap' VALUES (6997, 2722, 4);
INSERT INTO 'dancesstepsmap' VALUES (6998, 6035, 2);
INSERT INTO 'dancesstepsmap' VALUES (6999, 6640, 5);
INSERT INTO 'dancesstepsmap' VALUES (7000, 5217, 2);
INSERT INTO 'dancesstepsmap' VALUES (7001, 5217, 3);
INSERT INTO 'dancesstepsmap' VALUES (7002, 629, 3);
INSERT INTO 'dancesstepsmap' VALUES (7003, 629, 2);
INSERT INTO 'dancesstepsmap' VALUES (7004, 6091, 5);
INSERT INTO 'dancesstepsmap' VALUES (7005, 5198, 2);
INSERT INTO 'dancesstepsmap' VALUES (7006, 5188, 2);
INSERT INTO 'dancesstepsmap' VALUES (7007, 6621, 2);
INSERT INTO 'dancesstepsmap' VALUES (7008, 3299, 2);
INSERT INTO 'dancesstepsmap' VALUES (7009, 387, 2);
INSERT INTO 'dancesstepsmap' VALUES (7010, 387, 1);
INSERT INTO 'dancesstepsmap' VALUES (7011, 387, 5);
INSERT INTO 'dancesstepsmap' VALUES (7012, 387, 4);
INSERT INTO 'dancesstepsmap' VALUES (7013, 695, 2);
INSERT INTO 'dancesstepsmap' VALUES (6990, 6862, 5);
INSERT INTO 'dancesstepsmap' VALUES (7014, 695, 1);
INSERT INTO 'dancesstepsmap' VALUES (7015, 3336, 2);
INSERT INTO 'dancesstepsmap' VALUES (7016, 3336, 1);
INSERT INTO 'dancesstepsmap' VALUES (7017, 3336, 5);
INSERT INTO 'dancesstepsmap' VALUES (7018, 3336, 4);
INSERT INTO 'dancesstepsmap' VALUES (7019, 1708, 3);
INSERT INTO 'dancesstepsmap' VALUES (7020, 1708, 2);
INSERT INTO 'dancesstepsmap' VALUES (7021, 502, 2);
INSERT INTO 'dancesstepsmap' VALUES (7022, 502, 1);
INSERT INTO 'dancesstepsmap' VALUES (7023, 1078, 5);
INSERT INTO 'dancesstepsmap' VALUES (7024, 1078, 6);
INSERT INTO 'dancesstepsmap' VALUES (7025, 218, 3);
INSERT INTO 'dancesstepsmap' VALUES (7026, 218, 2);
INSERT INTO 'dancesstepsmap' VALUES (7027, 1982, 5);
INSERT INTO 'dancesstepsmap' VALUES (7028, 7531, 1);
INSERT INTO 'dancesstepsmap' VALUES (7029, 505, 1);
INSERT INTO 'dancesstepsmap' VALUES (7030, 505, 3);
INSERT INTO 'dancesstepsmap' VALUES (7031, 505, 2);
INSERT INTO 'dancesstepsmap' VALUES (7032, 1924, 2);
INSERT INTO 'dancesstepsmap' VALUES (7033, 4998, 2);
INSERT INTO 'dancesstepsmap' VALUES (7034, 6481, 5);
INSERT INTO 'dancesstepsmap' VALUES (7035, 5199, 2);
INSERT INTO 'dancesstepsmap' VALUES (7036, 1246, 2);
INSERT INTO 'dancesstepsmap' VALUES (7037, 2004, 2);
INSERT INTO 'dancesstepsmap' VALUES (7038, 4728, 2);
INSERT INTO 'dancesstepsmap' VALUES (7039, 2312, 2);
INSERT INTO 'dancesstepsmap' VALUES (7040, 3252, 1);
INSERT INTO 'dancesstepsmap' VALUES (7041, 3252, 2);
INSERT INTO 'dancesstepsmap' VALUES (7042, 1633, 4);
INSERT INTO 'dancesstepsmap' VALUES (7043, 1633, 5);
INSERT INTO 'dancesstepsmap' VALUES (7044, 7787, 1);
INSERT INTO 'dancesstepsmap' VALUES (7045, 7787, 2);
INSERT INTO 'dancesstepsmap' VALUES (7046, 7787, 3);
INSERT INTO 'dancesstepsmap' VALUES (7047, 7788, 4);
INSERT INTO 'dancesstepsmap' VALUES (7048, 7788, 5);
INSERT INTO 'dancesstepsmap' VALUES (7049, 7852, 2);
INSERT INTO 'dancesstepsmap' VALUES (7050, 7852, 1);
INSERT INTO 'dancesstepsmap' VALUES (7051, 8051, 1);
INSERT INTO 'dancesstepsmap' VALUES (7052, 8087, 3);
INSERT INTO 'dancesstepsmap' VALUES (7053, 8087, 1);
INSERT INTO 'dancesstepsmap' VALUES (12611, 11289, 4);
INSERT INTO 'dancesstepsmap' VALUES (12612, 11290, 2);
INSERT INTO 'dancesstepsmap' VALUES (12613, 11290, 1);
INSERT INTO 'dancesstepsmap' VALUES (12614, 11290, 3);
INSERT INTO 'dancesstepsmap' VALUES (12615, 11291, 2);
INSERT INTO 'dancesstepsmap' VALUES (12616, 11291, 3);
INSERT INTO 'dancesstepsmap' VALUES (12617, 11292, 5);
INSERT INTO 'dancesstepsmap' VALUES (12618, 11292, 4);
INSERT INTO 'dancesstepsmap' VALUES (12619, 11293, 2);
INSERT INTO 'dancesstepsmap' VALUES (12620, 11293, 1);
INSERT INTO 'dancesstepsmap' VALUES (12621, 11293, 3);
INSERT INTO 'dancesstepsmap' VALUES (12622, 11294, 4);
INSERT INTO 'dancesstepsmap' VALUES (12623, 11294, 5);
INSERT INTO 'dancesstepsmap' VALUES (12624, 11295, 2);
INSERT INTO 'dancesstepsmap' VALUES (12625, 11295, 1);
INSERT INTO 'dancesstepsmap' VALUES (12626, 11295, 3);
INSERT INTO 'dancesstepsmap' VALUES (7054, 8087, 2);
INSERT INTO 'dancesstepsmap' VALUES (7055, 2934, 2);
INSERT INTO 'dancesstepsmap' VALUES (7056, 2934, 3);
INSERT INTO 'dancesstepsmap' VALUES (7057, 6575, 7);
INSERT INTO 'dancesstepsmap' VALUES (7058, 7147, 2);
INSERT INTO 'dancesstepsmap' VALUES (7059, 8110, 1);
INSERT INTO 'dancesstepsmap' VALUES (7060, 8110, 2);
INSERT INTO 'dancesstepsmap' VALUES (7061, 8110, 3);
INSERT INTO 'dancesstepsmap' VALUES (7062, 8113, 1);
INSERT INTO 'dancesstepsmap' VALUES (7063, 8113, 2);
INSERT INTO 'dancesstepsmap' VALUES (7064, 8103, 1);
INSERT INTO 'dancesstepsmap' VALUES (7065, 8103, 2);
INSERT INTO 'dancesstepsmap' VALUES (7066, 8114, 1);
INSERT INTO 'dancesstepsmap' VALUES (7067, 8114, 2);
INSERT INTO 'dancesstepsmap' VALUES (7068, 8102, 4);
INSERT INTO 'dancesstepsmap' VALUES (7069, 8102, 5);
INSERT INTO 'dancesstepsmap' VALUES (7070, 6459, 2);
INSERT INTO 'dancesstepsmap' VALUES (7071, 6459, 3);
INSERT INTO 'dancesstepsmap' VALUES (7072, 4293, 2);
INSERT INTO 'dancesstepsmap' VALUES (7073, 2250, 2);
INSERT INTO 'dancesstepsmap' VALUES (7074, 5658, 2);
INSERT INTO 'dancesstepsmap' VALUES (7075, 4325, 2);
INSERT INTO 'dancesstepsmap' VALUES (7076, 3575, 2);
INSERT INTO 'dancesstepsmap' VALUES (7077, 6816, 2);
INSERT INTO 'dancesstepsmap' VALUES (7078, 4075, 2);
INSERT INTO 'dancesstepsmap' VALUES (7079, 548, 1);
INSERT INTO 'dancesstepsmap' VALUES (7080, 548, 2);
INSERT INTO 'dancesstepsmap' VALUES (7081, 5704, 5);
INSERT INTO 'dancesstepsmap' VALUES (7082, 2116, 2);
INSERT INTO 'dancesstepsmap' VALUES (7083, 5964, 1);
INSERT INTO 'dancesstepsmap' VALUES (7084, 5964, 2);
INSERT INTO 'dancesstepsmap' VALUES (7085, 3562, 2);
INSERT INTO 'dancesstepsmap' VALUES (7086, 3562, 3);
INSERT INTO 'dancesstepsmap' VALUES (7087, 862, 3);
INSERT INTO 'dancesstepsmap' VALUES (7088, 2498, 9);
INSERT INTO 'dancesstepsmap' VALUES (7089, 5222, 1);
INSERT INTO 'dancesstepsmap' VALUES (7090, 5222, 2);
INSERT INTO 'dancesstepsmap' VALUES (7091, 5222, 4);
INSERT INTO 'dancesstepsmap' VALUES (7092, 5222, 5);
INSERT INTO 'dancesstepsmap' VALUES (7093, 6182, 2);
INSERT INTO 'dancesstepsmap' VALUES (7094, 5376, 2);
INSERT INTO 'dancesstepsmap' VALUES (7095, 1931, 10);
INSERT INTO 'dancesstepsmap' VALUES (7096, 7421, 1);
INSERT INTO 'dancesstepsmap' VALUES (7097, 7290, 1);
INSERT INTO 'dancesstepsmap' VALUES (7098, 7549, 1);
INSERT INTO 'dancesstepsmap' VALUES (7099, 4472, 1);
INSERT INTO 'dancesstepsmap' VALUES (7100, 7581, 1);
INSERT INTO 'dancesstepsmap' VALUES (7101, 7584, 1);
INSERT INTO 'dancesstepsmap' VALUES (7102, 7585, 1);
INSERT INTO 'dancesstepsmap' VALUES (7103, 7587, 1);
INSERT INTO 'dancesstepsmap' VALUES (7104, 7589, 1);
INSERT INTO 'dancesstepsmap' VALUES (7105, 7592, 1);
INSERT INTO 'dancesstepsmap' VALUES (7106, 7343, 1);
INSERT INTO 'dancesstepsmap' VALUES (7107, 7593, 1);
INSERT INTO 'dancesstepsmap' VALUES (7108, 7595, 1);
INSERT INTO 'dancesstepsmap' VALUES (7109, 7598, 1);
INSERT INTO 'dancesstepsmap' VALUES (7110, 7600, 1);
INSERT INTO 'dancesstepsmap' VALUES (7111, 7602, 1);
INSERT INTO 'dancesstepsmap' VALUES (7112, 7606, 1);
INSERT INTO 'dancesstepsmap' VALUES (7113, 7607, 1);
INSERT INTO 'dancesstepsmap' VALUES (7114, 7608, 1);
INSERT INTO 'dancesstepsmap' VALUES (7115, 7610, 1);
INSERT INTO 'dancesstepsmap' VALUES (7116, 7614, 1);
INSERT INTO 'dancesstepsmap' VALUES (7117, 7617, 1);
INSERT INTO 'dancesstepsmap' VALUES (7118, 7620, 1);
INSERT INTO 'dancesstepsmap' VALUES (7119, 7626, 1);
INSERT INTO 'dancesstepsmap' VALUES (7120, 7627, 1);
INSERT INTO 'dancesstepsmap' VALUES (7121, 7631, 1);
INSERT INTO 'dancesstepsmap' VALUES (7122, 7636, 1);
INSERT INTO 'dancesstepsmap' VALUES (7123, 7635, 1);
INSERT INTO 'dancesstepsmap' VALUES (7124, 8040, 1);
INSERT INTO 'dancesstepsmap' VALUES (7125, 7643, 1);
INSERT INTO 'dancesstepsmap' VALUES (7126, 7566, 1);
INSERT INTO 'dancesstepsmap' VALUES (7127, 7365, 1);
INSERT INTO 'dancesstepsmap' VALUES (7128, 7646, 1);
INSERT INTO 'dancesstepsmap' VALUES (7129, 7366, 1);
INSERT INTO 'dancesstepsmap' VALUES (7130, 7370, 1);
INSERT INTO 'dancesstepsmap' VALUES (7131, 7652, 1);
INSERT INTO 'dancesstepsmap' VALUES (7132, 7654, 1);
INSERT INTO 'dancesstepsmap' VALUES (7133, 7373, 1);
INSERT INTO 'dancesstepsmap' VALUES (7134, 7655, 1);
INSERT INTO 'dancesstepsmap' VALUES (7135, 4706, 1);
INSERT INTO 'dancesstepsmap' VALUES (7136, 7659, 1);
INSERT INTO 'dancesstepsmap' VALUES (7137, 7575, 1);
INSERT INTO 'dancesstepsmap' VALUES (7138, 7666, 1);
INSERT INTO 'dancesstepsmap' VALUES (7139, 7673, 1);
INSERT INTO 'dancesstepsmap' VALUES (7140, 7677, 1);
INSERT INTO 'dancesstepsmap' VALUES (7141, 7680, 1);
INSERT INTO 'dancesstepsmap' VALUES (7142, 8046, 1);
INSERT INTO 'dancesstepsmap' VALUES (7143, 7380, 1);
INSERT INTO 'dancesstepsmap' VALUES (7144, 7684, 1);
INSERT INTO 'dancesstepsmap' VALUES (7145, 8105, 1);
INSERT INTO 'dancesstepsmap' VALUES (12627, 11282, 2);
INSERT INTO 'dancesstepsmap' VALUES (12629, 11283, 4);
INSERT INTO 'dancesstepsmap' VALUES (12630, 11283, 5);
INSERT INTO 'dancesstepsmap' VALUES (12631, 11284, 5);
INSERT INTO 'dancesstepsmap' VALUES (12632, 11284, 4);
INSERT INTO 'dancesstepsmap' VALUES (12633, 11285, 6);
INSERT INTO 'dancesstepsmap' VALUES (12634, 11286, 1);
INSERT INTO 'dancesstepsmap' VALUES (12635, 11286, 2);
INSERT INTO 'dancesstepsmap' VALUES (12636, 11296, 1);
INSERT INTO 'dancesstepsmap' VALUES (12637, 11296, 3);
INSERT INTO 'dancesstepsmap' VALUES (12638, 4300, 2);
INSERT INTO 'dancesstepsmap' VALUES (12639, 11351, 1);
INSERT INTO 'dancesstepsmap' VALUES (12640, 11351, 2);
INSERT INTO 'dancesstepsmap' VALUES (12641, 11352, 1);
INSERT INTO 'dancesstepsmap' VALUES (12642, 11353, 1);
INSERT INTO 'dancesstepsmap' VALUES (12643, 11353, 3);
INSERT INTO 'dancesstepsmap' VALUES (12644, 11353, 2);
INSERT INTO 'dancesstepsmap' VALUES (12645, 11352, 2);
INSERT INTO 'dancesstepsmap' VALUES (12646, 11354, 1);
INSERT INTO 'dancesstepsmap' VALUES (12647, 11355, 2);
INSERT INTO 'dancesstepsmap' VALUES (12648, 11355, 1);
INSERT INTO 'dancesstepsmap' VALUES (12649, 11356, 1);
INSERT INTO 'dancesstepsmap' VALUES (12650, 11356, 3);
INSERT INTO 'dancesstepsmap' VALUES (12651, 11356, 2);
INSERT INTO 'dancesstepsmap' VALUES (12652, 11357, 1);
INSERT INTO 'dancesstepsmap' VALUES (12653, 11358, 1);
INSERT INTO 'dancesstepsmap' VALUES (12654, 11358, 2);
INSERT INTO 'dancesstepsmap' VALUES (12657, 11360, 4);
INSERT INTO 'dancesstepsmap' VALUES (12658, 11360, 5);
INSERT INTO 'dancesstepsmap' VALUES (12659, 11361, 9);
INSERT INTO 'dancesstepsmap' VALUES (12660, 11361, 4);
INSERT INTO 'dancesstepsmap' VALUES (12661, 11362, 4);
INSERT INTO 'dancesstepsmap' VALUES (12662, 11362, 5);
INSERT INTO 'dancesstepsmap' VALUES (12663, 11363, 4);
INSERT INTO 'dancesstepsmap' VALUES (12664, 11364, 4);
INSERT INTO 'dancesstepsmap' VALUES (12665, 11365, 1);
INSERT INTO 'dancesstepsmap' VALUES (12666, 11365, 2);
INSERT INTO 'dancesstepsmap' VALUES (12667, 11366, 1);
INSERT INTO 'dancesstepsmap' VALUES (12668, 11367, 1);
INSERT INTO 'dancesstepsmap' VALUES (17338, 14657, 1);
INSERT INTO 'dancesstepsmap' VALUES (17383, 14695, 1);
INSERT INTO 'dancesstepsmap' VALUES (17393, 14698, 4);
INSERT INTO 'dancesstepsmap' VALUES (17394, 14698, 5);
INSERT INTO 'dancesstepsmap' VALUES (17398, 13762, 1);
INSERT INTO 'dancesstepsmap' VALUES (7146, 7385, 1);
INSERT INTO 'dancesstepsmap' VALUES (7147, 7687, 1);
INSERT INTO 'dancesstepsmap' VALUES (7148, 1772, 1);
INSERT INTO 'dancesstepsmap' VALUES (7149, 7690, 1);
INSERT INTO 'dancesstepsmap' VALUES (7150, 8116, 1);
INSERT INTO 'dancesstepsmap' VALUES (7151, 7818, 1);
INSERT INTO 'dancesstepsmap' VALUES (7152, 7699, 1);
INSERT INTO 'dancesstepsmap' VALUES (7153, 7702, 1);
INSERT INTO 'dancesstepsmap' VALUES (7154, 7706, 1);
INSERT INTO 'dancesstepsmap' VALUES (7155, 8048, 1);
INSERT INTO 'dancesstepsmap' VALUES (7156, 8028, 1);
INSERT INTO 'dancesstepsmap' VALUES (7157, 1813, 1);
INSERT INTO 'dancesstepsmap' VALUES (7158, 1750, 1);
INSERT INTO 'dancesstepsmap' VALUES (7159, 2765, 1);
INSERT INTO 'dancesstepsmap' VALUES (7160, 4936, 1);
INSERT INTO 'dancesstepsmap' VALUES (7161, 2625, 1);
INSERT INTO 'dancesstepsmap' VALUES (7162, 6966, 1);
INSERT INTO 'dancesstepsmap' VALUES (7163, 7707, 1);
INSERT INTO 'dancesstepsmap' VALUES (7164, 8050, 1);
INSERT INTO 'dancesstepsmap' VALUES (7165, 2226, 1);
INSERT INTO 'dancesstepsmap' VALUES (7166, 7720, 1);
INSERT INTO 'dancesstepsmap' VALUES (7167, 7722, 1);
INSERT INTO 'dancesstepsmap' VALUES (7168, 2479, 1);
INSERT INTO 'dancesstepsmap' VALUES (7169, 8052, 1);
INSERT INTO 'dancesstepsmap' VALUES (7170, 7737, 1);
INSERT INTO 'dancesstepsmap' VALUES (7171, 7731, 1);
INSERT INTO 'dancesstepsmap' VALUES (7172, 7735, 1);
INSERT INTO 'dancesstepsmap' VALUES (7173, 8109, 1);
INSERT INTO 'dancesstepsmap' VALUES (7174, 7741, 1);
INSERT INTO 'dancesstepsmap' VALUES (7175, 7742, 1);
INSERT INTO 'dancesstepsmap' VALUES (7176, 7410, 1);
INSERT INTO 'dancesstepsmap' VALUES (7177, 7411, 1);
INSERT INTO 'dancesstepsmap' VALUES (23157, 17878, 3);
INSERT INTO 'dancesstepsmap' VALUES (7179, 2754, 1);
INSERT INTO 'dancesstepsmap' VALUES (7180, 2989, 1);
INSERT INTO 'dancesstepsmap' VALUES (7181, 3587, 1);
INSERT INTO 'dancesstepsmap' VALUES (7182, 3785, 1);
INSERT INTO 'dancesstepsmap' VALUES (7183, 8056, 1);
INSERT INTO 'dancesstepsmap' VALUES (7184, 5286, 1);
INSERT INTO 'dancesstepsmap' VALUES (7185, 8057, 1);
INSERT INTO 'dancesstepsmap' VALUES (7186, 7744, 1);
INSERT INTO 'dancesstepsmap' VALUES (7187, 7748, 1);
INSERT INTO 'dancesstepsmap' VALUES (7188, 8123, 1);
INSERT INTO 'dancesstepsmap' VALUES (7189, 7423, 1);
INSERT INTO 'dancesstepsmap' VALUES (7190, 7424, 1);
INSERT INTO 'dancesstepsmap' VALUES (7191, 7750, 1);
INSERT INTO 'dancesstepsmap' VALUES (7192, 7752, 1);
INSERT INTO 'dancesstepsmap' VALUES (7193, 7753, 1);
INSERT INTO 'dancesstepsmap' VALUES (7194, 7756, 1);
INSERT INTO 'dancesstepsmap' VALUES (7195, 7429, 1);
INSERT INTO 'dancesstepsmap' VALUES (7196, 8058, 1);
INSERT INTO 'dancesstepsmap' VALUES (7197, 7758, 1);
INSERT INTO 'dancesstepsmap' VALUES (7198, 8059, 1);
INSERT INTO 'dancesstepsmap' VALUES (7199, 8060, 1);
INSERT INTO 'dancesstepsmap' VALUES (7200, 7760, 1);
INSERT INTO 'dancesstepsmap' VALUES (7201, 7763, 1);
INSERT INTO 'dancesstepsmap' VALUES (7202, 7762, 1);
INSERT INTO 'dancesstepsmap' VALUES (7203, 1203, 1);
INSERT INTO 'dancesstepsmap' VALUES (7204, 7766, 1);
INSERT INTO 'dancesstepsmap' VALUES (7205, 7767, 1);
INSERT INTO 'dancesstepsmap' VALUES (7206, 7768, 1);
INSERT INTO 'dancesstepsmap' VALUES (7207, 7769, 1);
INSERT INTO 'dancesstepsmap' VALUES (7208, 5942, 1);
INSERT INTO 'dancesstepsmap' VALUES (7209, 6604, 1);
INSERT INTO 'dancesstepsmap' VALUES (7210, 7770, 1);
INSERT INTO 'dancesstepsmap' VALUES (7211, 7771, 1);
INSERT INTO 'dancesstepsmap' VALUES (7212, 7764, 1);
INSERT INTO 'dancesstepsmap' VALUES (7213, 7433, 1);
INSERT INTO 'dancesstepsmap' VALUES (7214, 7773, 1);
INSERT INTO 'dancesstepsmap' VALUES (7215, 8061, 1);
INSERT INTO 'dancesstepsmap' VALUES (7216, 7777, 1);
INSERT INTO 'dancesstepsmap' VALUES (7217, 7784, 1);
INSERT INTO 'dancesstepsmap' VALUES (7218, 7786, 1);
INSERT INTO 'dancesstepsmap' VALUES (7219, 7441, 1);
INSERT INTO 'dancesstepsmap' VALUES (7220, 7792, 1);
INSERT INTO 'dancesstepsmap' VALUES (7221, 7445, 1);
INSERT INTO 'dancesstepsmap' VALUES (7222, 7559, 1);
INSERT INTO 'dancesstepsmap' VALUES (7223, 7448, 1);
INSERT INTO 'dancesstepsmap' VALUES (7225, 7798, 1);
INSERT INTO 'dancesstepsmap' VALUES (7226, 7799, 1);
INSERT INTO 'dancesstepsmap' VALUES (7227, 8130, 1);
INSERT INTO 'dancesstepsmap' VALUES (7228, 3815, 1);
INSERT INTO 'dancesstepsmap' VALUES (7229, 7802, 1);
INSERT INTO 'dancesstepsmap' VALUES (7230, 7804, 1);
INSERT INTO 'dancesstepsmap' VALUES (7231, 7805, 1);
INSERT INTO 'dancesstepsmap' VALUES (7232, 7809, 1);
INSERT INTO 'dancesstepsmap' VALUES (7233, 7810, 1);
INSERT INTO 'dancesstepsmap' VALUES (7234, 7811, 1);
INSERT INTO 'dancesstepsmap' VALUES (7235, 7452, 1);
INSERT INTO 'dancesstepsmap' VALUES (7236, 708, 1);
INSERT INTO 'dancesstepsmap' VALUES (7237, 7819, 1);
INSERT INTO 'dancesstepsmap' VALUES (7238, 3779, 1);
INSERT INTO 'dancesstepsmap' VALUES (12669, 11367, 3);
INSERT INTO 'dancesstepsmap' VALUES (12670, 11368, 4);
INSERT INTO 'dancesstepsmap' VALUES (12671, 11369, 2);
INSERT INTO 'dancesstepsmap' VALUES (12672, 11369, 1);
INSERT INTO 'dancesstepsmap' VALUES (12673, 11369, 3);
INSERT INTO 'dancesstepsmap' VALUES (12674, 11370, 3);
INSERT INTO 'dancesstepsmap' VALUES (12675, 11370, 1);
INSERT INTO 'dancesstepsmap' VALUES (12676, 11371, 4);
INSERT INTO 'dancesstepsmap' VALUES (12677, 11371, 5);
INSERT INTO 'dancesstepsmap' VALUES (12678, 11372, 2);
INSERT INTO 'dancesstepsmap' VALUES (12679, 11372, 1);
INSERT INTO 'dancesstepsmap' VALUES (12680, 11373, 2);
INSERT INTO 'dancesstepsmap' VALUES (12681, 11373, 1);
INSERT INTO 'dancesstepsmap' VALUES (12683, 11374, 4);
INSERT INTO 'dancesstepsmap' VALUES (12684, 11374, 5);
INSERT INTO 'dancesstepsmap' VALUES (12685, 11375, 1);
INSERT INTO 'dancesstepsmap' VALUES (12686, 11376, 2);
INSERT INTO 'dancesstepsmap' VALUES (12687, 11376, 1);
INSERT INTO 'dancesstepsmap' VALUES (12688, 11376, 3);
INSERT INTO 'dancesstepsmap' VALUES (12689, 5204, 2);
INSERT INTO 'dancesstepsmap' VALUES (12690, 340, 2);
INSERT INTO 'dancesstepsmap' VALUES (12691, 4720, 5);
INSERT INTO 'dancesstepsmap' VALUES (12692, 6386, 3);
INSERT INTO 'dancesstepsmap' VALUES (12693, 11401, 2);
INSERT INTO 'dancesstepsmap' VALUES (12694, 11401, 1);
INSERT INTO 'dancesstepsmap' VALUES (12695, 11402, 2);
INSERT INTO 'dancesstepsmap' VALUES (12696, 1187, 2);
INSERT INTO 'dancesstepsmap' VALUES (12697, 11403, 5);
INSERT INTO 'dancesstepsmap' VALUES (12698, 11403, 4);
INSERT INTO 'dancesstepsmap' VALUES (12699, 11402, 1);
INSERT INTO 'dancesstepsmap' VALUES (12700, 11404, 1);
INSERT INTO 'dancesstepsmap' VALUES (12701, 11404, 2);
INSERT INTO 'dancesstepsmap' VALUES (12702, 1201, 3);
INSERT INTO 'dancesstepsmap' VALUES (12703, 8944, 2);
INSERT INTO 'dancesstepsmap' VALUES (12704, 8944, 1);
INSERT INTO 'dancesstepsmap' VALUES (12705, 9946, 2);
INSERT INTO 'dancesstepsmap' VALUES (12706, 9946, 1);
INSERT INTO 'dancesstepsmap' VALUES (12707, 9946, 3);
INSERT INTO 'dancesstepsmap' VALUES (12708, 9947, 1);
INSERT INTO 'dancesstepsmap' VALUES (12709, 9947, 3);
INSERT INTO 'dancesstepsmap' VALUES (12710, 9947, 2);
INSERT INTO 'dancesstepsmap' VALUES (17339, 14658, 1);
INSERT INTO 'dancesstepsmap' VALUES (17399, 14699, 5);
INSERT INTO 'dancesstepsmap' VALUES (17400, 14699, 4);
INSERT INTO 'dancesstepsmap' VALUES (17401, 9930, 1);
INSERT INTO 'dancesstepsmap' VALUES (17402, 9930, 2);
INSERT INTO 'dancesstepsmap' VALUES (17403, 14700, 2);
INSERT INTO 'dancesstepsmap' VALUES (17404, 14700, 1);
INSERT INTO 'dancesstepsmap' VALUES (17405, 14700, 3);
INSERT INTO 'dancesstepsmap' VALUES (17406, 14701, 1);
INSERT INTO 'dancesstepsmap' VALUES (7239, 3993, 1);
INSERT INTO 'dancesstepsmap' VALUES (7240, 7455, 1);
INSERT INTO 'dancesstepsmap' VALUES (7241, 7451, 1);
INSERT INTO 'dancesstepsmap' VALUES (7242, 7824, 1);
INSERT INTO 'dancesstepsmap' VALUES (7243, 7827, 1);
INSERT INTO 'dancesstepsmap' VALUES (7244, 7823, 1);
INSERT INTO 'dancesstepsmap' VALUES (7245, 7829, 1);
INSERT INTO 'dancesstepsmap' VALUES (7246, 7543, 1);
INSERT INTO 'dancesstepsmap' VALUES (7247, 7830, 1);
INSERT INTO 'dancesstepsmap' VALUES (7248, 7832, 1);
INSERT INTO 'dancesstepsmap' VALUES (7249, 7463, 1);
INSERT INTO 'dancesstepsmap' VALUES (7250, 7838, 1);
INSERT INTO 'dancesstepsmap' VALUES (7251, 7844, 1);
INSERT INTO 'dancesstepsmap' VALUES (7252, 7846, 1);
INSERT INTO 'dancesstepsmap' VALUES (7253, 7856, 1);
INSERT INTO 'dancesstepsmap' VALUES (7254, 7469, 1);
INSERT INTO 'dancesstepsmap' VALUES (7255, 5226, 1);
INSERT INTO 'dancesstepsmap' VALUES (7256, 7472, 1);
INSERT INTO 'dancesstepsmap' VALUES (7257, 7151, 1);
INSERT INTO 'dancesstepsmap' VALUES (7258, 8119, 1);
INSERT INTO 'dancesstepsmap' VALUES (7259, 7475, 1);
INSERT INTO 'dancesstepsmap' VALUES (7260, 7865, 1);
INSERT INTO 'dancesstepsmap' VALUES (7261, 7866, 1);
INSERT INTO 'dancesstepsmap' VALUES (7262, 7478, 1);
INSERT INTO 'dancesstepsmap' VALUES (7263, 7873, 1);
INSERT INTO 'dancesstepsmap' VALUES (7264, 7879, 1);
INSERT INTO 'dancesstepsmap' VALUES (7265, 8069, 1);
INSERT INTO 'dancesstepsmap' VALUES (7266, 7880, 1);
INSERT INTO 'dancesstepsmap' VALUES (7267, 7881, 1);
INSERT INTO 'dancesstepsmap' VALUES (7268, 8071, 1);
INSERT INTO 'dancesstepsmap' VALUES (7269, 7315, 1);
INSERT INTO 'dancesstepsmap' VALUES (7270, 8072, 1);
INSERT INTO 'dancesstepsmap' VALUES (7271, 7887, 1);
INSERT INTO 'dancesstepsmap' VALUES (7272, 7890, 1);
INSERT INTO 'dancesstepsmap' VALUES (7273, 7892, 1);
INSERT INTO 'dancesstepsmap' VALUES (7274, 7489, 1);
INSERT INTO 'dancesstepsmap' VALUES (7275, 7490, 1);
INSERT INTO 'dancesstepsmap' VALUES (7276, 7896, 1);
INSERT INTO 'dancesstepsmap' VALUES (7277, 7491, 1);
INSERT INTO 'dancesstepsmap' VALUES (7278, 8097, 1);
INSERT INTO 'dancesstepsmap' VALUES (7279, 1268, 1);
INSERT INTO 'dancesstepsmap' VALUES (7280, 5292, 1);
INSERT INTO 'dancesstepsmap' VALUES (7281, 8073, 1);
INSERT INTO 'dancesstepsmap' VALUES (7282, 6900, 1);
INSERT INTO 'dancesstepsmap' VALUES (7283, 7894, 1);
INSERT INTO 'dancesstepsmap' VALUES (7284, 7497, 1);
INSERT INTO 'dancesstepsmap' VALUES (7285, 7499, 1);
INSERT INTO 'dancesstepsmap' VALUES (7286, 8139, 1);
INSERT INTO 'dancesstepsmap' VALUES (7287, 4135, 1);
INSERT INTO 'dancesstepsmap' VALUES (7288, 7914, 1);
INSERT INTO 'dancesstepsmap' VALUES (7289, 8106, 1);
INSERT INTO 'dancesstepsmap' VALUES (7290, 7917, 1);
INSERT INTO 'dancesstepsmap' VALUES (7291, 7918, 1);
INSERT INTO 'dancesstepsmap' VALUES (7292, 7920, 1);
INSERT INTO 'dancesstepsmap' VALUES (7293, 8140, 1);
INSERT INTO 'dancesstepsmap' VALUES (7294, 7925, 1);
INSERT INTO 'dancesstepsmap' VALUES (7295, 7926, 1);
INSERT INTO 'dancesstepsmap' VALUES (7296, 7928, 1);
INSERT INTO 'dancesstepsmap' VALUES (7297, 8078, 1);
INSERT INTO 'dancesstepsmap' VALUES (7298, 7934, 1);
INSERT INTO 'dancesstepsmap' VALUES (7299, 7935, 1);
INSERT INTO 'dancesstepsmap' VALUES (7300, 7936, 1);
INSERT INTO 'dancesstepsmap' VALUES (7301, 7938, 1);
INSERT INTO 'dancesstepsmap' VALUES (7302, 7508, 1);
INSERT INTO 'dancesstepsmap' VALUES (7303, 5938, 1);
INSERT INTO 'dancesstepsmap' VALUES (7304, 7947, 1);
INSERT INTO 'dancesstepsmap' VALUES (7305, 243, 1);
INSERT INTO 'dancesstepsmap' VALUES (7306, 1088, 1);
INSERT INTO 'dancesstepsmap' VALUES (7307, 1749, 1);
INSERT INTO 'dancesstepsmap' VALUES (7308, 7952, 1);
INSERT INTO 'dancesstepsmap' VALUES (7309, 7953, 1);
INSERT INTO 'dancesstepsmap' VALUES (7310, 8037, 1);
INSERT INTO 'dancesstepsmap' VALUES (7311, 8036, 1);
INSERT INTO 'dancesstepsmap' VALUES (7312, 7954, 1);
INSERT INTO 'dancesstepsmap' VALUES (7313, 7956, 1);
INSERT INTO 'dancesstepsmap' VALUES (7314, 7521, 1);
INSERT INTO 'dancesstepsmap' VALUES (7315, 6359, 1);
INSERT INTO 'dancesstepsmap' VALUES (7316, 7578, 1);
INSERT INTO 'dancesstepsmap' VALUES (7317, 7523, 1);
INSERT INTO 'dancesstepsmap' VALUES (7318, 6347, 1);
INSERT INTO 'dancesstepsmap' VALUES (7319, 8099, 1);
INSERT INTO 'dancesstepsmap' VALUES (7320, 7964, 1);
INSERT INTO 'dancesstepsmap' VALUES (7321, 7526, 1);
INSERT INTO 'dancesstepsmap' VALUES (7322, 7971, 1);
INSERT INTO 'dancesstepsmap' VALUES (7323, 8080, 1);
INSERT INTO 'dancesstepsmap' VALUES (7324, 7973, 1);
INSERT INTO 'dancesstepsmap' VALUES (7325, 6575, 1);
INSERT INTO 'dancesstepsmap' VALUES (7326, 8081, 1);
INSERT INTO 'dancesstepsmap' VALUES (7327, 6593, 1);
INSERT INTO 'dancesstepsmap' VALUES (7328, 7977, 1);
INSERT INTO 'dancesstepsmap' VALUES (7329, 7978, 1);
INSERT INTO 'dancesstepsmap' VALUES (7330, 7529, 1);
INSERT INTO 'dancesstepsmap' VALUES (12711, 9948, 3);
INSERT INTO 'dancesstepsmap' VALUES (12712, 9949, 4);
INSERT INTO 'dancesstepsmap' VALUES (12713, 8781, 1);
INSERT INTO 'dancesstepsmap' VALUES (12714, 11409, 4);
INSERT INTO 'dancesstepsmap' VALUES (12715, 11410, 1);
INSERT INTO 'dancesstepsmap' VALUES (12716, 11410, 2);
INSERT INTO 'dancesstepsmap' VALUES (12717, 3365, 2);
INSERT INTO 'dancesstepsmap' VALUES (12718, 480, 2);
INSERT INTO 'dancesstepsmap' VALUES (12719, 4431, 2);
INSERT INTO 'dancesstepsmap' VALUES (12720, 4543, 2);
INSERT INTO 'dancesstepsmap' VALUES (12721, 6018, 2);
INSERT INTO 'dancesstepsmap' VALUES (12722, 3735, 2);
INSERT INTO 'dancesstepsmap' VALUES (12723, 2042, 2);
INSERT INTO 'dancesstepsmap' VALUES (12724, 3537, 2);
INSERT INTO 'dancesstepsmap' VALUES (12725, 3645, 2);
INSERT INTO 'dancesstepsmap' VALUES (12726, 760, 2);
INSERT INTO 'dancesstepsmap' VALUES (12727, 8939, 1);
INSERT INTO 'dancesstepsmap' VALUES (12728, 11427, 2);
INSERT INTO 'dancesstepsmap' VALUES (12729, 11427, 1);
INSERT INTO 'dancesstepsmap' VALUES (12730, 11427, 3);
INSERT INTO 'dancesstepsmap' VALUES (12731, 11428, 1);
INSERT INTO 'dancesstepsmap' VALUES (12732, 11429, 5);
INSERT INTO 'dancesstepsmap' VALUES (12733, 11429, 4);
INSERT INTO 'dancesstepsmap' VALUES (12734, 11430, 2);
INSERT INTO 'dancesstepsmap' VALUES (12735, 11430, 1);
INSERT INTO 'dancesstepsmap' VALUES (12736, 11430, 3);
INSERT INTO 'dancesstepsmap' VALUES (12737, 11431, 4);
INSERT INTO 'dancesstepsmap' VALUES (12738, 11431, 5);
INSERT INTO 'dancesstepsmap' VALUES (12739, 11432, 1);
INSERT INTO 'dancesstepsmap' VALUES (12740, 11432, 2);
INSERT INTO 'dancesstepsmap' VALUES (12741, 11432, 4);
INSERT INTO 'dancesstepsmap' VALUES (12742, 11432, 5);
INSERT INTO 'dancesstepsmap' VALUES (12743, 11433, 2);
INSERT INTO 'dancesstepsmap' VALUES (12744, 11433, 1);
INSERT INTO 'dancesstepsmap' VALUES (12745, 11434, 5);
INSERT INTO 'dancesstepsmap' VALUES (12746, 11434, 4);
INSERT INTO 'dancesstepsmap' VALUES (12747, 11435, 2);
INSERT INTO 'dancesstepsmap' VALUES (12748, 11435, 1);
INSERT INTO 'dancesstepsmap' VALUES (12749, 9120, 5);
INSERT INTO 'dancesstepsmap' VALUES (12750, 11437, 1);
INSERT INTO 'dancesstepsmap' VALUES (12751, 11438, 1);
INSERT INTO 'dancesstepsmap' VALUES (12752, 11438, 2);
INSERT INTO 'dancesstepsmap' VALUES (12753, 11438, 3);
INSERT INTO 'dancesstepsmap' VALUES (17407, 14702, 5);
INSERT INTO 'dancesstepsmap' VALUES (17408, 14702, 4);
INSERT INTO 'dancesstepsmap' VALUES (7331, 7983, 1);
INSERT INTO 'dancesstepsmap' VALUES (7332, 7984, 1);
INSERT INTO 'dancesstepsmap' VALUES (7333, 7985, 1);
INSERT INTO 'dancesstepsmap' VALUES (7334, 7530, 1);
INSERT INTO 'dancesstepsmap' VALUES (7335, 7989, 1);
INSERT INTO 'dancesstepsmap' VALUES (7336, 7991, 1);
INSERT INTO 'dancesstepsmap' VALUES (7337, 3300, 1);
INSERT INTO 'dancesstepsmap' VALUES (7338, 7992, 1);
INSERT INTO 'dancesstepsmap' VALUES (7339, 7993, 1);
INSERT INTO 'dancesstepsmap' VALUES (7340, 7995, 1);
INSERT INTO 'dancesstepsmap' VALUES (7341, 7325, 1);
INSERT INTO 'dancesstepsmap' VALUES (7342, 7997, 1);
INSERT INTO 'dancesstepsmap' VALUES (7343, 8000, 1);
INSERT INTO 'dancesstepsmap' VALUES (7344, 8001, 1);
INSERT INTO 'dancesstepsmap' VALUES (7345, 8005, 1);
INSERT INTO 'dancesstepsmap' VALUES (7346, 7532, 1);
INSERT INTO 'dancesstepsmap' VALUES (7347, 8007, 1);
INSERT INTO 'dancesstepsmap' VALUES (7348, 8008, 1);
INSERT INTO 'dancesstepsmap' VALUES (7349, 7533, 1);
INSERT INTO 'dancesstepsmap' VALUES (7350, 6149, 1);
INSERT INTO 'dancesstepsmap' VALUES (7351, 8082, 1);
INSERT INTO 'dancesstepsmap' VALUES (7352, 6581, 1);
INSERT INTO 'dancesstepsmap' VALUES (7353, 7094, 1);
INSERT INTO 'dancesstepsmap' VALUES (7354, 8013, 1);
INSERT INTO 'dancesstepsmap' VALUES (7355, 8014, 1);
INSERT INTO 'dancesstepsmap' VALUES (7356, 7541, 1);
INSERT INTO 'dancesstepsmap' VALUES (7357, 5693, 1);
INSERT INTO 'dancesstepsmap' VALUES (7358, 3941, 3);
INSERT INTO 'dancesstepsmap' VALUES (7359, 5693, 3);
INSERT INTO 'dancesstepsmap' VALUES (7360, 4784, 3);
INSERT INTO 'dancesstepsmap' VALUES (7361, 3237, 2);
INSERT INTO 'dancesstepsmap' VALUES (7362, 588, 2);
INSERT INTO 'dancesstepsmap' VALUES (7363, 2044, 3);
INSERT INTO 'dancesstepsmap' VALUES (7364, 2317, 1);
INSERT INTO 'dancesstepsmap' VALUES (7365, 523, 2);
INSERT INTO 'dancesstepsmap' VALUES (7366, 3383, 4);
INSERT INTO 'dancesstepsmap' VALUES (7367, 3383, 5);
INSERT INTO 'dancesstepsmap' VALUES (7368, 5581, 3);
INSERT INTO 'dancesstepsmap' VALUES (7369, 6912, 5);
INSERT INTO 'dancesstepsmap' VALUES (7370, 6658, 3);
INSERT INTO 'dancesstepsmap' VALUES (7371, 2916, 2);
INSERT INTO 'dancesstepsmap' VALUES (7372, 1348, 2);
INSERT INTO 'dancesstepsmap' VALUES (7373, 723, 2);
INSERT INTO 'dancesstepsmap' VALUES (7374, 8163, 1);
INSERT INTO 'dancesstepsmap' VALUES (7375, 8163, 2);
INSERT INTO 'dancesstepsmap' VALUES (7376, 8163, 3);
INSERT INTO 'dancesstepsmap' VALUES (7377, 8164, 4);
INSERT INTO 'dancesstepsmap' VALUES (7378, 8164, 5);
INSERT INTO 'dancesstepsmap' VALUES (7379, 7551, 1);
INSERT INTO 'dancesstepsmap' VALUES (7380, 7551, 2);
INSERT INTO 'dancesstepsmap' VALUES (7383, 8141, 3);
INSERT INTO 'dancesstepsmap' VALUES (7384, 8166, 1);
INSERT INTO 'dancesstepsmap' VALUES (7385, 8167, 1);
INSERT INTO 'dancesstepsmap' VALUES (7386, 8167, 2);
INSERT INTO 'dancesstepsmap' VALUES (7387, 8168, 2);
INSERT INTO 'dancesstepsmap' VALUES (7388, 8168, 1);
INSERT INTO 'dancesstepsmap' VALUES (7389, 8169, 1);
INSERT INTO 'dancesstepsmap' VALUES (7390, 8169, 2);
INSERT INTO 'dancesstepsmap' VALUES (7391, 8170, 1);
INSERT INTO 'dancesstepsmap' VALUES (7392, 5702, 3);
INSERT INTO 'dancesstepsmap' VALUES (7393, 5141, 5);
INSERT INTO 'dancesstepsmap' VALUES (7394, 6585, 6);
INSERT INTO 'dancesstepsmap' VALUES (7395, 5144, 2);
INSERT INTO 'dancesstepsmap' VALUES (7396, 5144, 3);
INSERT INTO 'dancesstepsmap' VALUES (7397, 70, 5);
INSERT INTO 'dancesstepsmap' VALUES (7398, 1232, 5);
INSERT INTO 'dancesstepsmap' VALUES (7399, 1232, 4);
INSERT INTO 'dancesstepsmap' VALUES (7400, 1429, 4);
INSERT INTO 'dancesstepsmap' VALUES (7401, 1566, 4);
INSERT INTO 'dancesstepsmap' VALUES (7402, 1609, 1);
INSERT INTO 'dancesstepsmap' VALUES (7403, 1609, 2);
INSERT INTO 'dancesstepsmap' VALUES (7404, 8262, 4);
INSERT INTO 'dancesstepsmap' VALUES (7405, 6630, 4);
INSERT INTO 'dancesstepsmap' VALUES (7406, 6804, 4);
INSERT INTO 'dancesstepsmap' VALUES (7407, 6937, 4);
INSERT INTO 'dancesstepsmap' VALUES (7408, 7136, 4);
INSERT INTO 'dancesstepsmap' VALUES (7409, 8452, 4);
INSERT INTO 'dancesstepsmap' VALUES (7410, 8436, 4);
INSERT INTO 'dancesstepsmap' VALUES (7411, 7156, 4);
INSERT INTO 'dancesstepsmap' VALUES (7412, 7294, 4);
INSERT INTO 'dancesstepsmap' VALUES (7413, 7467, 4);
INSERT INTO 'dancesstepsmap' VALUES (7414, 7579, 4);
INSERT INTO 'dancesstepsmap' VALUES (7415, 7580, 4);
INSERT INTO 'dancesstepsmap' VALUES (7416, 7583, 4);
INSERT INTO 'dancesstepsmap' VALUES (7417, 7340, 4);
INSERT INTO 'dancesstepsmap' VALUES (7418, 7586, 4);
INSERT INTO 'dancesstepsmap' VALUES (7419, 7591, 4);
INSERT INTO 'dancesstepsmap' VALUES (7420, 3791, 4);
INSERT INTO 'dancesstepsmap' VALUES (7421, 8225, 4);
INSERT INTO 'dancesstepsmap' VALUES (7422, 7594, 4);
INSERT INTO 'dancesstepsmap' VALUES (7423, 8233, 4);
INSERT INTO 'dancesstepsmap' VALUES (12754, 6152, 3);
INSERT INTO 'dancesstepsmap' VALUES (12755, 7999, 4);
INSERT INTO 'dancesstepsmap' VALUES (12756, 11439, 1);
INSERT INTO 'dancesstepsmap' VALUES (12757, 11439, 2);
INSERT INTO 'dancesstepsmap' VALUES (12758, 11440, 2);
INSERT INTO 'dancesstepsmap' VALUES (12759, 11440, 1);
INSERT INTO 'dancesstepsmap' VALUES (12760, 11441, 1);
INSERT INTO 'dancesstepsmap' VALUES (12761, 11442, 5);
INSERT INTO 'dancesstepsmap' VALUES (12762, 11442, 4);
INSERT INTO 'dancesstepsmap' VALUES (12763, 11443, 2);
INSERT INTO 'dancesstepsmap' VALUES (12764, 11443, 1);
INSERT INTO 'dancesstepsmap' VALUES (12765, 11444, 2);
INSERT INTO 'dancesstepsmap' VALUES (12766, 11444, 1);
INSERT INTO 'dancesstepsmap' VALUES (12767, 11445, 4);
INSERT INTO 'dancesstepsmap' VALUES (12768, 11446, 5);
INSERT INTO 'dancesstepsmap' VALUES (12769, 11446, 4);
INSERT INTO 'dancesstepsmap' VALUES (12770, 11447, 5);
INSERT INTO 'dancesstepsmap' VALUES (12771, 11447, 4);
INSERT INTO 'dancesstepsmap' VALUES (12772, 11448, 1);
INSERT INTO 'dancesstepsmap' VALUES (12773, 11448, 2);
INSERT INTO 'dancesstepsmap' VALUES (12774, 11449, 4);
INSERT INTO 'dancesstepsmap' VALUES (12775, 11451, 4);
INSERT INTO 'dancesstepsmap' VALUES (12776, 11452, 4);
INSERT INTO 'dancesstepsmap' VALUES (12777, 11453, 1);
INSERT INTO 'dancesstepsmap' VALUES (12778, 11453, 2);
INSERT INTO 'dancesstepsmap' VALUES (12779, 11454, 2);
INSERT INTO 'dancesstepsmap' VALUES (12780, 11454, 1);
INSERT INTO 'dancesstepsmap' VALUES (12781, 1372, 2);
INSERT INTO 'dancesstepsmap' VALUES (12782, 11455, 1);
INSERT INTO 'dancesstepsmap' VALUES (12783, 11456, 2);
INSERT INTO 'dancesstepsmap' VALUES (12784, 11456, 1);
INSERT INTO 'dancesstepsmap' VALUES (12785, 11457, 4);
INSERT INTO 'dancesstepsmap' VALUES (12786, 11458, 1);
INSERT INTO 'dancesstepsmap' VALUES (12787, 11459, 1);
INSERT INTO 'dancesstepsmap' VALUES (12788, 11460, 1);
INSERT INTO 'dancesstepsmap' VALUES (12792, 11465, 4);
INSERT INTO 'dancesstepsmap' VALUES (12793, 11465, 5);
INSERT INTO 'dancesstepsmap' VALUES (12794, 11466, 4);
INSERT INTO 'dancesstepsmap' VALUES (12795, 11467, 1);
INSERT INTO 'dancesstepsmap' VALUES (17409, 14703, 4);
INSERT INTO 'dancesstepsmap' VALUES (17410, 14703, 6);
INSERT INTO 'dancesstepsmap' VALUES (17411, 14703, 5);
INSERT INTO 'dancesstepsmap' VALUES (7424, 7344, 4);
INSERT INTO 'dancesstepsmap' VALUES (23158, 18250, 1);
INSERT INTO 'dancesstepsmap' VALUES (7426, 8111, 4);
INSERT INTO 'dancesstepsmap' VALUES (7427, 7345, 4);
INSERT INTO 'dancesstepsmap' VALUES (7428, 7597, 4);
INSERT INTO 'dancesstepsmap' VALUES (7429, 312, 2);
INSERT INTO 'dancesstepsmap' VALUES (7430, 7609, 4);
INSERT INTO 'dancesstepsmap' VALUES (7431, 7601, 4);
INSERT INTO 'dancesstepsmap' VALUES (7432, 7348, 4);
INSERT INTO 'dancesstepsmap' VALUES (7433, 7605, 4);
INSERT INTO 'dancesstepsmap' VALUES (7434, 8023, 4);
INSERT INTO 'dancesstepsmap' VALUES (7435, 8122, 4);
INSERT INTO 'dancesstepsmap' VALUES (7436, 8580, 4);
INSERT INTO 'dancesstepsmap' VALUES (7437, 7615, 4);
INSERT INTO 'dancesstepsmap' VALUES (7438, 8125, 4);
INSERT INTO 'dancesstepsmap' VALUES (7439, 8554, 4);
INSERT INTO 'dancesstepsmap' VALUES (7440, 7616, 4);
INSERT INTO 'dancesstepsmap' VALUES (7441, 7342, 4);
INSERT INTO 'dancesstepsmap' VALUES (7442, 8294, 4);
INSERT INTO 'dancesstepsmap' VALUES (7443, 8407, 4);
INSERT INTO 'dancesstepsmap' VALUES (7444, 7618, 4);
INSERT INTO 'dancesstepsmap' VALUES (7445, 8345, 4);
INSERT INTO 'dancesstepsmap' VALUES (7446, 7621, 4);
INSERT INTO 'dancesstepsmap' VALUES (7447, 7353, 4);
INSERT INTO 'dancesstepsmap' VALUES (7448, 8460, 4);
INSERT INTO 'dancesstepsmap' VALUES (7449, 203, 4);
INSERT INTO 'dancesstepsmap' VALUES (7450, 8559, 4);
INSERT INTO 'dancesstepsmap' VALUES (7451, 7354, 4);
INSERT INTO 'dancesstepsmap' VALUES (7452, 1779, 4);
INSERT INTO 'dancesstepsmap' VALUES (7453, 8330, 4);
INSERT INTO 'dancesstepsmap' VALUES (7454, 8346, 4);
INSERT INTO 'dancesstepsmap' VALUES (7455, 8453, 4);
INSERT INTO 'dancesstepsmap' VALUES (7456, 8455, 4);
INSERT INTO 'dancesstepsmap' VALUES (7457, 8331, 4);
INSERT INTO 'dancesstepsmap' VALUES (7458, 8191, 4);
INSERT INTO 'dancesstepsmap' VALUES (7459, 7335, 4);
INSERT INTO 'dancesstepsmap' VALUES (7460, 8281, 4);
INSERT INTO 'dancesstepsmap' VALUES (7461, 8260, 4);
INSERT INTO 'dancesstepsmap' VALUES (7462, 8348, 4);
INSERT INTO 'dancesstepsmap' VALUES (7463, 7624, 4);
INSERT INTO 'dancesstepsmap' VALUES (7464, 7625, 4);
INSERT INTO 'dancesstepsmap' VALUES (7465, 8448, 4);
INSERT INTO 'dancesstepsmap' VALUES (7466, 7357, 4);
INSERT INTO 'dancesstepsmap' VALUES (7467, 8454, 4);
INSERT INTO 'dancesstepsmap' VALUES (7468, 4847, 4);
INSERT INTO 'dancesstepsmap' VALUES (7469, 7629, 4);
INSERT INTO 'dancesstepsmap' VALUES (7470, 2050, 4);
INSERT INTO 'dancesstepsmap' VALUES (7471, 7637, 4);
INSERT INTO 'dancesstepsmap' VALUES (7472, 7358, 4);
INSERT INTO 'dancesstepsmap' VALUES (7473, 7641, 4);
INSERT INTO 'dancesstepsmap' VALUES (7474, 8285, 4);
INSERT INTO 'dancesstepsmap' VALUES (7475, 7644, 4);
INSERT INTO 'dancesstepsmap' VALUES (7476, 7645, 4);
INSERT INTO 'dancesstepsmap' VALUES (7477, 8447, 4);
INSERT INTO 'dancesstepsmap' VALUES (7478, 8370, 4);
INSERT INTO 'dancesstepsmap' VALUES (7479, 7634, 4);
INSERT INTO 'dancesstepsmap' VALUES (7480, 7363, 4);
INSERT INTO 'dancesstepsmap' VALUES (7481, 8443, 4);
INSERT INTO 'dancesstepsmap' VALUES (7482, 3460, 4);
INSERT INTO 'dancesstepsmap' VALUES (7483, 5324, 4);
INSERT INTO 'dancesstepsmap' VALUES (7484, 7367, 4);
INSERT INTO 'dancesstepsmap' VALUES (7485, 7648, 4);
INSERT INTO 'dancesstepsmap' VALUES (7486, 8435, 4);
INSERT INTO 'dancesstepsmap' VALUES (7487, 7369, 4);
INSERT INTO 'dancesstepsmap' VALUES (7488, 8451, 4);
INSERT INTO 'dancesstepsmap' VALUES (7489, 7371, 4);
INSERT INTO 'dancesstepsmap' VALUES (7490, 5524, 4);
INSERT INTO 'dancesstepsmap' VALUES (7491, 6244, 4);
INSERT INTO 'dancesstepsmap' VALUES (7492, 1333, 4);
INSERT INTO 'dancesstepsmap' VALUES (7493, 8026, 4);
INSERT INTO 'dancesstepsmap' VALUES (7494, 8393, 4);
INSERT INTO 'dancesstepsmap' VALUES (7495, 7661, 4);
INSERT INTO 'dancesstepsmap' VALUES (7496, 7662, 4);
INSERT INTO 'dancesstepsmap' VALUES (7497, 7376, 4);
INSERT INTO 'dancesstepsmap' VALUES (7498, 7663, 4);
INSERT INTO 'dancesstepsmap' VALUES (7499, 7664, 4);
INSERT INTO 'dancesstepsmap' VALUES (7500, 8193, 4);
INSERT INTO 'dancesstepsmap' VALUES (7501, 7665, 4);
INSERT INTO 'dancesstepsmap' VALUES (7502, 8089, 4);
INSERT INTO 'dancesstepsmap' VALUES (7503, 8234, 4);
INSERT INTO 'dancesstepsmap' VALUES (7504, 8344, 4);
INSERT INTO 'dancesstepsmap' VALUES (7505, 8235, 4);
INSERT INTO 'dancesstepsmap' VALUES (7506, 8308, 4);
INSERT INTO 'dancesstepsmap' VALUES (7507, 8449, 4);
INSERT INTO 'dancesstepsmap' VALUES (7508, 7679, 4);
INSERT INTO 'dancesstepsmap' VALUES (7509, 7442, 4);
INSERT INTO 'dancesstepsmap' VALUES (7510, 7449, 4);
INSERT INTO 'dancesstepsmap' VALUES (7511, 8298, 4);
INSERT INTO 'dancesstepsmap' VALUES (7512, 7515, 4);
INSERT INTO 'dancesstepsmap' VALUES (7513, 8231, 4);
INSERT INTO 'dancesstepsmap' VALUES (7514, 3016, 2);
INSERT INTO 'dancesstepsmap' VALUES (7515, 6826, 2);
INSERT INTO 'dancesstepsmap' VALUES (7516, 15, 2);
INSERT INTO 'dancesstepsmap' VALUES (7517, 30, 2);
INSERT INTO 'dancesstepsmap' VALUES (7518, 7336, 2);
INSERT INTO 'dancesstepsmap' VALUES (7519, 113, 2);
INSERT INTO 'dancesstepsmap' VALUES (7520, 139, 2);
INSERT INTO 'dancesstepsmap' VALUES (7521, 143, 2);
INSERT INTO 'dancesstepsmap' VALUES (7522, 200, 2);
INSERT INTO 'dancesstepsmap' VALUES (7523, 238, 2);
INSERT INTO 'dancesstepsmap' VALUES (7524, 389, 2);
INSERT INTO 'dancesstepsmap' VALUES (7525, 414, 2);
INSERT INTO 'dancesstepsmap' VALUES (7526, 763, 2);
INSERT INTO 'dancesstepsmap' VALUES (7527, 778, 2);
INSERT INTO 'dancesstepsmap' VALUES (7528, 819, 2);
INSERT INTO 'dancesstepsmap' VALUES (7529, 852, 2);
INSERT INTO 'dancesstepsmap' VALUES (7530, 877, 2);
INSERT INTO 'dancesstepsmap' VALUES (7531, 933, 2);
INSERT INTO 'dancesstepsmap' VALUES (7532, 958, 2);
INSERT INTO 'dancesstepsmap' VALUES (7533, 1034, 2);
INSERT INTO 'dancesstepsmap' VALUES (7534, 8086, 2);
INSERT INTO 'dancesstepsmap' VALUES (7535, 1288, 2);
INSERT INTO 'dancesstepsmap' VALUES (7536, 1334, 2);
INSERT INTO 'dancesstepsmap' VALUES (7537, 1345, 2);
INSERT INTO 'dancesstepsmap' VALUES (7538, 1413, 2);
INSERT INTO 'dancesstepsmap' VALUES (7539, 1638, 2);
INSERT INTO 'dancesstepsmap' VALUES (7540, 1698, 2);
INSERT INTO 'dancesstepsmap' VALUES (7541, 1770, 2);
INSERT INTO 'dancesstepsmap' VALUES (7542, 1878, 2);
INSERT INTO 'dancesstepsmap' VALUES (7543, 2091, 2);
INSERT INTO 'dancesstepsmap' VALUES (7544, 2148, 2);
INSERT INTO 'dancesstepsmap' VALUES (7545, 2153, 2);
INSERT INTO 'dancesstepsmap' VALUES (7546, 2504, 2);
INSERT INTO 'dancesstepsmap' VALUES (7547, 2526, 2);
INSERT INTO 'dancesstepsmap' VALUES (7548, 2551, 2);
INSERT INTO 'dancesstepsmap' VALUES (7549, 2605, 2);
INSERT INTO 'dancesstepsmap' VALUES (7550, 2713, 2);
INSERT INTO 'dancesstepsmap' VALUES (7551, 2808, 2);
INSERT INTO 'dancesstepsmap' VALUES (7552, 2837, 2);
INSERT INTO 'dancesstepsmap' VALUES (7553, 2903, 2);
INSERT INTO 'dancesstepsmap' VALUES (12796, 11467, 2);
INSERT INTO 'dancesstepsmap' VALUES (12797, 11468, 2);
INSERT INTO 'dancesstepsmap' VALUES (12798, 11469, 1);
INSERT INTO 'dancesstepsmap' VALUES (12799, 11470, 1);
INSERT INTO 'dancesstepsmap' VALUES (12800, 11471, 1);
INSERT INTO 'dancesstepsmap' VALUES (12801, 11472, 1);
INSERT INTO 'dancesstepsmap' VALUES (12802, 11473, 3);
INSERT INTO 'dancesstepsmap' VALUES (12803, 11473, 1);
INSERT INTO 'dancesstepsmap' VALUES (12804, 11474, 1);
INSERT INTO 'dancesstepsmap' VALUES (12805, 11475, 4);
INSERT INTO 'dancesstepsmap' VALUES (12806, 11476, 1);
INSERT INTO 'dancesstepsmap' VALUES (12807, 11477, 2);
INSERT INTO 'dancesstepsmap' VALUES (12808, 11477, 1);
INSERT INTO 'dancesstepsmap' VALUES (12809, 11477, 3);
INSERT INTO 'dancesstepsmap' VALUES (12810, 11478, 6);
INSERT INTO 'dancesstepsmap' VALUES (17412, 14704, 3);
INSERT INTO 'dancesstepsmap' VALUES (7554, 2964, 2);
INSERT INTO 'dancesstepsmap' VALUES (7555, 3092, 2);
INSERT INTO 'dancesstepsmap' VALUES (7556, 3111, 2);
INSERT INTO 'dancesstepsmap' VALUES (7557, 3215, 2);
INSERT INTO 'dancesstepsmap' VALUES (7558, 3248, 2);
INSERT INTO 'dancesstepsmap' VALUES (7559, 3286, 2);
INSERT INTO 'dancesstepsmap' VALUES (7560, 3358, 2);
INSERT INTO 'dancesstepsmap' VALUES (7561, 3506, 2);
INSERT INTO 'dancesstepsmap' VALUES (7562, 3589, 2);
INSERT INTO 'dancesstepsmap' VALUES (7563, 3656, 2);
INSERT INTO 'dancesstepsmap' VALUES (7564, 3722, 2);
INSERT INTO 'dancesstepsmap' VALUES (7565, 3787, 2);
INSERT INTO 'dancesstepsmap' VALUES (7566, 3862, 2);
INSERT INTO 'dancesstepsmap' VALUES (7567, 3958, 2);
INSERT INTO 'dancesstepsmap' VALUES (7568, 4091, 2);
INSERT INTO 'dancesstepsmap' VALUES (7569, 4159, 2);
INSERT INTO 'dancesstepsmap' VALUES (7570, 4269, 2);
INSERT INTO 'dancesstepsmap' VALUES (7571, 7825, 2);
INSERT INTO 'dancesstepsmap' VALUES (7572, 4404, 2);
INSERT INTO 'dancesstepsmap' VALUES (7573, 4440, 2);
INSERT INTO 'dancesstepsmap' VALUES (7574, 4461, 2);
INSERT INTO 'dancesstepsmap' VALUES (7575, 4508, 2);
INSERT INTO 'dancesstepsmap' VALUES (7576, 4638, 2);
INSERT INTO 'dancesstepsmap' VALUES (7577, 4676, 2);
INSERT INTO 'dancesstepsmap' VALUES (7578, 4927, 2);
INSERT INTO 'dancesstepsmap' VALUES (7579, 4935, 2);
INSERT INTO 'dancesstepsmap' VALUES (7580, 4948, 2);
INSERT INTO 'dancesstepsmap' VALUES (7581, 5288, 2);
INSERT INTO 'dancesstepsmap' VALUES (7582, 5344, 2);
INSERT INTO 'dancesstepsmap' VALUES (7583, 5399, 2);
INSERT INTO 'dancesstepsmap' VALUES (7584, 5402, 2);
INSERT INTO 'dancesstepsmap' VALUES (7585, 5421, 2);
INSERT INTO 'dancesstepsmap' VALUES (7586, 5465, 2);
INSERT INTO 'dancesstepsmap' VALUES (7587, 5479, 2);
INSERT INTO 'dancesstepsmap' VALUES (7588, 8172, 2);
INSERT INTO 'dancesstepsmap' VALUES (7589, 5539, 2);
INSERT INTO 'dancesstepsmap' VALUES (7590, 5555, 2);
INSERT INTO 'dancesstepsmap' VALUES (7591, 8194, 2);
INSERT INTO 'dancesstepsmap' VALUES (7592, 5576, 2);
INSERT INTO 'dancesstepsmap' VALUES (7593, 5734, 2);
INSERT INTO 'dancesstepsmap' VALUES (7594, 5736, 2);
INSERT INTO 'dancesstepsmap' VALUES (7595, 5765, 2);
INSERT INTO 'dancesstepsmap' VALUES (7596, 5832, 2);
INSERT INTO 'dancesstepsmap' VALUES (7597, 6107, 2);
INSERT INTO 'dancesstepsmap' VALUES (7598, 5999, 2);
INSERT INTO 'dancesstepsmap' VALUES (7599, 6114, 2);
INSERT INTO 'dancesstepsmap' VALUES (7600, 6258, 2);
INSERT INTO 'dancesstepsmap' VALUES (7601, 6282, 2);
INSERT INTO 'dancesstepsmap' VALUES (7602, 6298, 2);
INSERT INTO 'dancesstepsmap' VALUES (7603, 6377, 2);
INSERT INTO 'dancesstepsmap' VALUES (7604, 6386, 2);
INSERT INTO 'dancesstepsmap' VALUES (7605, 6424, 2);
INSERT INTO 'dancesstepsmap' VALUES (7606, 6500, 2);
INSERT INTO 'dancesstepsmap' VALUES (7607, 6574, 2);
INSERT INTO 'dancesstepsmap' VALUES (7608, 6782, 2);
INSERT INTO 'dancesstepsmap' VALUES (7609, 6818, 2);
INSERT INTO 'dancesstepsmap' VALUES (7610, 6819, 2);
INSERT INTO 'dancesstepsmap' VALUES (7611, 6846, 2);
INSERT INTO 'dancesstepsmap' VALUES (7612, 6887, 2);
INSERT INTO 'dancesstepsmap' VALUES (7613, 6888, 2);
INSERT INTO 'dancesstepsmap' VALUES (7614, 6938, 2);
INSERT INTO 'dancesstepsmap' VALUES (7615, 7068, 2);
INSERT INTO 'dancesstepsmap' VALUES (7616, 8174, 2);
INSERT INTO 'dancesstepsmap' VALUES (7617, 7141, 2);
INSERT INTO 'dancesstepsmap' VALUES (7618, 66, 3);
INSERT INTO 'dancesstepsmap' VALUES (7619, 78, 3);
INSERT INTO 'dancesstepsmap' VALUES (7620, 98, 3);
INSERT INTO 'dancesstepsmap' VALUES (7621, 214, 3);
INSERT INTO 'dancesstepsmap' VALUES (7622, 222, 3);
INSERT INTO 'dancesstepsmap' VALUES (7624, 282, 3);
INSERT INTO 'dancesstepsmap' VALUES (7625, 339, 3);
INSERT INTO 'dancesstepsmap' VALUES (7626, 393, 3);
INSERT INTO 'dancesstepsmap' VALUES (7627, 428, 3);
INSERT INTO 'dancesstepsmap' VALUES (7628, 7349, 3);
INSERT INTO 'dancesstepsmap' VALUES (7630, 596, 3);
INSERT INTO 'dancesstepsmap' VALUES (7631, 655, 3);
INSERT INTO 'dancesstepsmap' VALUES (7632, 711, 3);
INSERT INTO 'dancesstepsmap' VALUES (7633, 739, 3);
INSERT INTO 'dancesstepsmap' VALUES (7634, 819, 3);
INSERT INTO 'dancesstepsmap' VALUES (7635, 830, 3);
INSERT INTO 'dancesstepsmap' VALUES (7636, 902, 3);
INSERT INTO 'dancesstepsmap' VALUES (7637, 930, 3);
INSERT INTO 'dancesstepsmap' VALUES (7638, 933, 3);
INSERT INTO 'dancesstepsmap' VALUES (7639, 943, 3);
INSERT INTO 'dancesstepsmap' VALUES (7640, 945, 3);
INSERT INTO 'dancesstepsmap' VALUES (7641, 987, 3);
INSERT INTO 'dancesstepsmap' VALUES (7642, 1020, 3);
INSERT INTO 'dancesstepsmap' VALUES (7643, 1101, 3);
INSERT INTO 'dancesstepsmap' VALUES (7644, 1103, 3);
INSERT INTO 'dancesstepsmap' VALUES (7645, 1154, 3);
INSERT INTO 'dancesstepsmap' VALUES (12811, 11478, 4);
INSERT INTO 'dancesstepsmap' VALUES (12812, 11478, 5);
INSERT INTO 'dancesstepsmap' VALUES (12813, 11479, 1);
INSERT INTO 'dancesstepsmap' VALUES (12814, 11479, 2);
INSERT INTO 'dancesstepsmap' VALUES (12815, 11480, 4);
INSERT INTO 'dancesstepsmap' VALUES (12816, 11481, 1);
INSERT INTO 'dancesstepsmap' VALUES (12817, 11482, 5);
INSERT INTO 'dancesstepsmap' VALUES (12818, 11482, 4);
INSERT INTO 'dancesstepsmap' VALUES (12819, 11483, 1);
INSERT INTO 'dancesstepsmap' VALUES (12820, 11483, 2);
INSERT INTO 'dancesstepsmap' VALUES (12821, 11483, 3);
INSERT INTO 'dancesstepsmap' VALUES (12822, 11484, 4);
INSERT INTO 'dancesstepsmap' VALUES (12823, 11484, 5);
INSERT INTO 'dancesstepsmap' VALUES (12824, 11485, 1);
INSERT INTO 'dancesstepsmap' VALUES (12825, 11486, 1);
INSERT INTO 'dancesstepsmap' VALUES (12826, 11487, 5);
INSERT INTO 'dancesstepsmap' VALUES (12827, 11487, 6);
INSERT INTO 'dancesstepsmap' VALUES (12828, 11487, 4);
INSERT INTO 'dancesstepsmap' VALUES (12829, 11489, 4);
INSERT INTO 'dancesstepsmap' VALUES (12830, 11490, 1);
INSERT INTO 'dancesstepsmap' VALUES (12833, 11491, 3);
INSERT INTO 'dancesstepsmap' VALUES (12834, 11492, 5);
INSERT INTO 'dancesstepsmap' VALUES (12835, 11492, 4);
INSERT INTO 'dancesstepsmap' VALUES (12836, 11493, 2);
INSERT INTO 'dancesstepsmap' VALUES (12837, 11493, 1);
INSERT INTO 'dancesstepsmap' VALUES (12838, 11494, 2);
INSERT INTO 'dancesstepsmap' VALUES (12839, 11494, 1);
INSERT INTO 'dancesstepsmap' VALUES (12840, 11495, 1);
INSERT INTO 'dancesstepsmap' VALUES (12841, 11495, 2);
INSERT INTO 'dancesstepsmap' VALUES (12843, 11496, 4);
INSERT INTO 'dancesstepsmap' VALUES (12844, 11496, 5);
INSERT INTO 'dancesstepsmap' VALUES (12845, 11497, 2);
INSERT INTO 'dancesstepsmap' VALUES (12846, 11497, 1);
INSERT INTO 'dancesstepsmap' VALUES (12847, 11497, 3);
INSERT INTO 'dancesstepsmap' VALUES (12848, 11498, 1);
INSERT INTO 'dancesstepsmap' VALUES (12849, 11499, 1);
INSERT INTO 'dancesstepsmap' VALUES (12850, 11500, 1);
INSERT INTO 'dancesstepsmap' VALUES (12851, 11500, 2);
INSERT INTO 'dancesstepsmap' VALUES (12852, 11501, 2);
INSERT INTO 'dancesstepsmap' VALUES (12853, 11501, 1);
INSERT INTO 'dancesstepsmap' VALUES (17413, 14704, 1);
INSERT INTO 'dancesstepsmap' VALUES (7646, 1246, 3);
INSERT INTO 'dancesstepsmap' VALUES (7647, 8086, 3);
INSERT INTO 'dancesstepsmap' VALUES (7648, 1267, 3);
INSERT INTO 'dancesstepsmap' VALUES (7649, 1280, 3);
INSERT INTO 'dancesstepsmap' VALUES (7650, 1374, 3);
INSERT INTO 'dancesstepsmap' VALUES (7651, 8169, 3);
INSERT INTO 'dancesstepsmap' VALUES (7652, 1414, 3);
INSERT INTO 'dancesstepsmap' VALUES (7653, 1431, 3);
INSERT INTO 'dancesstepsmap' VALUES (7629, 489, 2);
INSERT INTO 'dancesstepsmap' VALUES (12831, 11491, 1);
INSERT INTO 'dancesstepsmap' VALUES (7654, 1562, 3);
INSERT INTO 'dancesstepsmap' VALUES (7655, 1582, 3);
INSERT INTO 'dancesstepsmap' VALUES (7656, 1582, 2);
INSERT INTO 'dancesstepsmap' VALUES (7657, 1627, 3);
INSERT INTO 'dancesstepsmap' VALUES (7659, 1666, 3);
INSERT INTO 'dancesstepsmap' VALUES (7660, 1682, 3);
INSERT INTO 'dancesstepsmap' VALUES (7661, 1709, 3);
INSERT INTO 'dancesstepsmap' VALUES (7662, 1726, 3);
INSERT INTO 'dancesstepsmap' VALUES (7663, 1762, 3);
INSERT INTO 'dancesstepsmap' VALUES (7664, 1884, 3);
INSERT INTO 'dancesstepsmap' VALUES (7665, 1931, 3);
INSERT INTO 'dancesstepsmap' VALUES (7666, 1966, 3);
INSERT INTO 'dancesstepsmap' VALUES (7667, 1983, 3);
INSERT INTO 'dancesstepsmap' VALUES (7668, 2018, 3);
INSERT INTO 'dancesstepsmap' VALUES (7669, 7709, 3);
INSERT INTO 'dancesstepsmap' VALUES (7670, 2065, 3);
INSERT INTO 'dancesstepsmap' VALUES (7671, 2116, 3);
INSERT INTO 'dancesstepsmap' VALUES (7673, 2196, 3);
INSERT INTO 'dancesstepsmap' VALUES (7674, 2258, 3);
INSERT INTO 'dancesstepsmap' VALUES (7675, 2277, 3);
INSERT INTO 'dancesstepsmap' VALUES (7676, 7401, 3);
INSERT INTO 'dancesstepsmap' VALUES (7677, 2389, 3);
INSERT INTO 'dancesstepsmap' VALUES (7679, 8051, 3);
INSERT INTO 'dancesstepsmap' VALUES (7680, 250, 3);
INSERT INTO 'dancesstepsmap' VALUES (7681, 2536, 3);
INSERT INTO 'dancesstepsmap' VALUES (7678, 2430, 2);
INSERT INTO 'dancesstepsmap' VALUES (7682, 2644, 3);
INSERT INTO 'dancesstepsmap' VALUES (7683, 2666, 3);
INSERT INTO 'dancesstepsmap' VALUES (7684, 2703, 3);
INSERT INTO 'dancesstepsmap' VALUES (7685, 2711, 3);
INSERT INTO 'dancesstepsmap' VALUES (7686, 2789, 3);
INSERT INTO 'dancesstepsmap' VALUES (7687, 2821, 3);
INSERT INTO 'dancesstepsmap' VALUES (7688, 2886, 3);
INSERT INTO 'dancesstepsmap' VALUES (7689, 2897, 3);
INSERT INTO 'dancesstepsmap' VALUES (7690, 2925, 3);
INSERT INTO 'dancesstepsmap' VALUES (7691, 2935, 3);
INSERT INTO 'dancesstepsmap' VALUES (7692, 2936, 3);
INSERT INTO 'dancesstepsmap' VALUES (7693, 2972, 3);
INSERT INTO 'dancesstepsmap' VALUES (7694, 2981, 3);
INSERT INTO 'dancesstepsmap' VALUES (7695, 3047, 3);
INSERT INTO 'dancesstepsmap' VALUES (7697, 3065, 3);
INSERT INTO 'dancesstepsmap' VALUES (7698, 3066, 3);
INSERT INTO 'dancesstepsmap' VALUES (7699, 3092, 3);
INSERT INTO 'dancesstepsmap' VALUES (7700, 3220, 3);
INSERT INTO 'dancesstepsmap' VALUES (7702, 3339, 3);
INSERT INTO 'dancesstepsmap' VALUES (7703, 3347, 3);
INSERT INTO 'dancesstepsmap' VALUES (7704, 3357, 3);
INSERT INTO 'dancesstepsmap' VALUES (7705, 3367, 3);
INSERT INTO 'dancesstepsmap' VALUES (7706, 3416, 3);
INSERT INTO 'dancesstepsmap' VALUES (7708, 3608, 3);
INSERT INTO 'dancesstepsmap' VALUES (7709, 8381, 3);
INSERT INTO 'dancesstepsmap' VALUES (7710, 3656, 3);
INSERT INTO 'dancesstepsmap' VALUES (7711, 3658, 3);
INSERT INTO 'dancesstepsmap' VALUES (7712, 3704, 3);
INSERT INTO 'dancesstepsmap' VALUES (7713, 3805, 3);
INSERT INTO 'dancesstepsmap' VALUES (7714, 3870, 3);
INSERT INTO 'dancesstepsmap' VALUES (7715, 3923, 3);
INSERT INTO 'dancesstepsmap' VALUES (7716, 3931, 3);
INSERT INTO 'dancesstepsmap' VALUES (7717, 3951, 3);
INSERT INTO 'dancesstepsmap' VALUES (7719, 3990, 3);
INSERT INTO 'dancesstepsmap' VALUES (7720, 4102, 3);
INSERT INTO 'dancesstepsmap' VALUES (7721, 4170, 3);
INSERT INTO 'dancesstepsmap' VALUES (7722, 4221, 3);
INSERT INTO 'dancesstepsmap' VALUES (7724, 4273, 3);
INSERT INTO 'dancesstepsmap' VALUES (7725, 4331, 3);
INSERT INTO 'dancesstepsmap' VALUES (7726, 4352, 3);
INSERT INTO 'dancesstepsmap' VALUES (7727, 4433, 3);
INSERT INTO 'dancesstepsmap' VALUES (7728, 4438, 3);
INSERT INTO 'dancesstepsmap' VALUES (7729, 4471, 3);
INSERT INTO 'dancesstepsmap' VALUES (7730, 4476, 3);
INSERT INTO 'dancesstepsmap' VALUES (7731, 4479, 3);
INSERT INTO 'dancesstepsmap' VALUES (7732, 4636, 3);
INSERT INTO 'dancesstepsmap' VALUES (7733, 4638, 3);
INSERT INTO 'dancesstepsmap' VALUES (7734, 4697, 3);
INSERT INTO 'dancesstepsmap' VALUES (7735, 4725, 3);
INSERT INTO 'dancesstepsmap' VALUES (7736, 4728, 3);
INSERT INTO 'dancesstepsmap' VALUES (7737, 7470, 3);
INSERT INTO 'dancesstepsmap' VALUES (7738, 4803, 3);
INSERT INTO 'dancesstepsmap' VALUES (12854, 11502, 2);
INSERT INTO 'dancesstepsmap' VALUES (12855, 11502, 1);
INSERT INTO 'dancesstepsmap' VALUES (12856, 11504, 1);
INSERT INTO 'dancesstepsmap' VALUES (12857, 11505, 1);
INSERT INTO 'dancesstepsmap' VALUES (12858, 11505, 2);
INSERT INTO 'dancesstepsmap' VALUES (12859, 11506, 2);
INSERT INTO 'dancesstepsmap' VALUES (12860, 11506, 1);
INSERT INTO 'dancesstepsmap' VALUES (12861, 11507, 1);
INSERT INTO 'dancesstepsmap' VALUES (12862, 11508, 1);
INSERT INTO 'dancesstepsmap' VALUES (12863, 11509, 1);
INSERT INTO 'dancesstepsmap' VALUES (12864, 11510, 1);
INSERT INTO 'dancesstepsmap' VALUES (12865, 8861, 2);
INSERT INTO 'dancesstepsmap' VALUES (12866, 8861, 1);
INSERT INTO 'dancesstepsmap' VALUES (12867, 7536, 4);
INSERT INTO 'dancesstepsmap' VALUES (12868, 7536, 5);
INSERT INTO 'dancesstepsmap' VALUES (12869, 8847, 1);
INSERT INTO 'dancesstepsmap' VALUES (12870, 8849, 1);
INSERT INTO 'dancesstepsmap' VALUES (12871, 8866, 4);
INSERT INTO 'dancesstepsmap' VALUES (12872, 8867, 1);
INSERT INTO 'dancesstepsmap' VALUES (12873, 8868, 5);
INSERT INTO 'dancesstepsmap' VALUES (12874, 8868, 6);
INSERT INTO 'dancesstepsmap' VALUES (12875, 8868, 4);
INSERT INTO 'dancesstepsmap' VALUES (12876, 8869, 2);
INSERT INTO 'dancesstepsmap' VALUES (12877, 8869, 3);
INSERT INTO 'dancesstepsmap' VALUES (12878, 8870, 4);
INSERT INTO 'dancesstepsmap' VALUES (12879, 8872, 4);
INSERT INTO 'dancesstepsmap' VALUES (12880, 8873, 1);
INSERT INTO 'dancesstepsmap' VALUES (12881, 8874, 5);
INSERT INTO 'dancesstepsmap' VALUES (12882, 8874, 4);
INSERT INTO 'dancesstepsmap' VALUES (12883, 8875, 2);
INSERT INTO 'dancesstepsmap' VALUES (12884, 8875, 10);
INSERT INTO 'dancesstepsmap' VALUES (12885, 8875, 3);
INSERT INTO 'dancesstepsmap' VALUES (12886, 8875, 1);
INSERT INTO 'dancesstepsmap' VALUES (12887, 8876, 4);
INSERT INTO 'dancesstepsmap' VALUES (12889, 8878, 4);
INSERT INTO 'dancesstepsmap' VALUES (12890, 8879, 1);
INSERT INTO 'dancesstepsmap' VALUES (12891, 8880, 4);
INSERT INTO 'dancesstepsmap' VALUES (12892, 8881, 2);
INSERT INTO 'dancesstepsmap' VALUES (12893, 8881, 3);
INSERT INTO 'dancesstepsmap' VALUES (12894, 8882, 5);
INSERT INTO 'dancesstepsmap' VALUES (12895, 8882, 4);
INSERT INTO 'dancesstepsmap' VALUES (17414, 14705, 2);
INSERT INTO 'dancesstepsmap' VALUES (17415, 14705, 1);
INSERT INTO 'dancesstepsmap' VALUES (17416, 14705, 3);
INSERT INTO 'dancesstepsmap' VALUES (7739, 4862, 3);
INSERT INTO 'dancesstepsmap' VALUES (7740, 4881, 3);
INSERT INTO 'dancesstepsmap' VALUES (7741, 4938, 3);
INSERT INTO 'dancesstepsmap' VALUES (7742, 4953, 3);
INSERT INTO 'dancesstepsmap' VALUES (7743, 4998, 3);
INSERT INTO 'dancesstepsmap' VALUES (7744, 5090, 3);
INSERT INTO 'dancesstepsmap' VALUES (7745, 5106, 3);
INSERT INTO 'dancesstepsmap' VALUES (7746, 5154, 3);
INSERT INTO 'dancesstepsmap' VALUES (7748, 5257, 3);
INSERT INTO 'dancesstepsmap' VALUES (7749, 5326, 3);
INSERT INTO 'dancesstepsmap' VALUES (7750, 5358, 3);
INSERT INTO 'dancesstepsmap' VALUES (7751, 5385, 3);
INSERT INTO 'dancesstepsmap' VALUES (7752, 5398, 3);
INSERT INTO 'dancesstepsmap' VALUES (7753, 5468, 3);
INSERT INTO 'dancesstepsmap' VALUES (7754, 5477, 3);
INSERT INTO 'dancesstepsmap' VALUES (7755, 5525, 3);
INSERT INTO 'dancesstepsmap' VALUES (7756, 5529, 3);
INSERT INTO 'dancesstepsmap' VALUES (7757, 5539, 3);
INSERT INTO 'dancesstepsmap' VALUES (7758, 5545, 3);
INSERT INTO 'dancesstepsmap' VALUES (7759, 5547, 3);
INSERT INTO 'dancesstepsmap' VALUES (7760, 5626, 3);
INSERT INTO 'dancesstepsmap' VALUES (7761, 5800, 3);
INSERT INTO 'dancesstepsmap' VALUES (7762, 5921, 3);
INSERT INTO 'dancesstepsmap' VALUES (7763, 7320, 3);
INSERT INTO 'dancesstepsmap' VALUES (7764, 6086, 3);
INSERT INTO 'dancesstepsmap' VALUES (7765, 6186, 3);
INSERT INTO 'dancesstepsmap' VALUES (7766, 6380, 3);
INSERT INTO 'dancesstepsmap' VALUES (7767, 6406, 3);
INSERT INTO 'dancesstepsmap' VALUES (7768, 7524, 3);
INSERT INTO 'dancesstepsmap' VALUES (7769, 6437, 3);
INSERT INTO 'dancesstepsmap' VALUES (7770, 6552, 3);
INSERT INTO 'dancesstepsmap' VALUES (7771, 6572, 3);
INSERT INTO 'dancesstepsmap' VALUES (7772, 6621, 3);
INSERT INTO 'dancesstepsmap' VALUES (7773, 6653, 3);
INSERT INTO 'dancesstepsmap' VALUES (7774, 6788, 3);
INSERT INTO 'dancesstepsmap' VALUES (7775, 8389, 3);
INSERT INTO 'dancesstepsmap' VALUES (7776, 7531, 3);
INSERT INTO 'dancesstepsmap' VALUES (7777, 6916, 3);
INSERT INTO 'dancesstepsmap' VALUES (7778, 6928, 3);
INSERT INTO 'dancesstepsmap' VALUES (7779, 6929, 3);
INSERT INTO 'dancesstepsmap' VALUES (7780, 6931, 3);
INSERT INTO 'dancesstepsmap' VALUES (7781, 7030, 3);
INSERT INTO 'dancesstepsmap' VALUES (7782, 7048, 3);
INSERT INTO 'dancesstepsmap' VALUES (7783, 7055, 3);
INSERT INTO 'dancesstepsmap' VALUES (7784, 7068, 3);
INSERT INTO 'dancesstepsmap' VALUES (7785, 7076, 3);
INSERT INTO 'dancesstepsmap' VALUES (7786, 7106, 3);
INSERT INTO 'dancesstepsmap' VALUES (7787, 7109, 3);
INSERT INTO 'dancesstepsmap' VALUES (7788, 7118, 3);
INSERT INTO 'dancesstepsmap' VALUES (7789, 7135, 3);
INSERT INTO 'dancesstepsmap' VALUES (7790, 7142, 3);
INSERT INTO 'dancesstepsmap' VALUES (7791, 7182, 3);
INSERT INTO 'dancesstepsmap' VALUES (7792, 7259, 3);
INSERT INTO 'dancesstepsmap' VALUES (7793, 1435, 1);
INSERT INTO 'dancesstepsmap' VALUES (7718, 3955, 8);
INSERT INTO 'dancesstepsmap' VALUES (7747, 5225, 2);
INSERT INTO 'dancesstepsmap' VALUES (7794, 1435, 2);
INSERT INTO 'dancesstepsmap' VALUES (7795, 7338, 2);
INSERT INTO 'dancesstepsmap' VALUES (7796, 142, 2);
INSERT INTO 'dancesstepsmap' VALUES (7797, 169, 2);
INSERT INTO 'dancesstepsmap' VALUES (7798, 211, 2);
INSERT INTO 'dancesstepsmap' VALUES (7799, 240, 2);
INSERT INTO 'dancesstepsmap' VALUES (7800, 353, 2);
INSERT INTO 'dancesstepsmap' VALUES (7802, 531, 2);
INSERT INTO 'dancesstepsmap' VALUES (7803, 603, 2);
INSERT INTO 'dancesstepsmap' VALUES (7804, 735, 2);
INSERT INTO 'dancesstepsmap' VALUES (7805, 777, 2);
INSERT INTO 'dancesstepsmap' VALUES (7806, 803, 2);
INSERT INTO 'dancesstepsmap' VALUES (7807, 1149, 2);
INSERT INTO 'dancesstepsmap' VALUES (7808, 1153, 2);
INSERT INTO 'dancesstepsmap' VALUES (7809, 1200, 2);
INSERT INTO 'dancesstepsmap' VALUES (7810, 1442, 2);
INSERT INTO 'dancesstepsmap' VALUES (7811, 1664, 2);
INSERT INTO 'dancesstepsmap' VALUES (7812, 1667, 2);
INSERT INTO 'dancesstepsmap' VALUES (7813, 1728, 2);
INSERT INTO 'dancesstepsmap' VALUES (7814, 1812, 2);
INSERT INTO 'dancesstepsmap' VALUES (7815, 1817, 2);
INSERT INTO 'dancesstepsmap' VALUES (7816, 1891, 2);
INSERT INTO 'dancesstepsmap' VALUES (7817, 8236, 2);
INSERT INTO 'dancesstepsmap' VALUES (7818, 1976, 2);
INSERT INTO 'dancesstepsmap' VALUES (7819, 2234, 2);
INSERT INTO 'dancesstepsmap' VALUES (7820, 2547, 2);
INSERT INTO 'dancesstepsmap' VALUES (7821, 2658, 2);
INSERT INTO 'dancesstepsmap' VALUES (7822, 152, 2);
INSERT INTO 'dancesstepsmap' VALUES (7823, 1553, 2);
INSERT INTO 'dancesstepsmap' VALUES (12888, 8878, 5);
INSERT INTO 'dancesstepsmap' VALUES (7824, 2708, 2);
INSERT INTO 'dancesstepsmap' VALUES (7825, 2744, 2);
INSERT INTO 'dancesstepsmap' VALUES (7826, 2951, 2);
INSERT INTO 'dancesstepsmap' VALUES (7827, 2983, 2);
INSERT INTO 'dancesstepsmap' VALUES (7828, 3335, 2);
INSERT INTO 'dancesstepsmap' VALUES (7829, 3406, 2);
INSERT INTO 'dancesstepsmap' VALUES (7830, 3479, 2);
INSERT INTO 'dancesstepsmap' VALUES (12896, 8883, 10);
INSERT INTO 'dancesstepsmap' VALUES (12897, 8883, 3);
INSERT INTO 'dancesstepsmap' VALUES (12898, 8883, 1);
INSERT INTO 'dancesstepsmap' VALUES (12899, 8884, 10);
INSERT INTO 'dancesstepsmap' VALUES (12900, 8884, 2);
INSERT INTO 'dancesstepsmap' VALUES (12901, 8884, 3);
INSERT INTO 'dancesstepsmap' VALUES (12902, 8884, 1);
INSERT INTO 'dancesstepsmap' VALUES (12903, 8885, 1);
INSERT INTO 'dancesstepsmap' VALUES (12904, 8886, 4);
INSERT INTO 'dancesstepsmap' VALUES (12905, 8887, 2);
INSERT INTO 'dancesstepsmap' VALUES (12906, 4279, 1);
INSERT INTO 'dancesstepsmap' VALUES (12907, 7647, 4);
INSERT INTO 'dancesstepsmap' VALUES (12908, 11222, 1);
INSERT INTO 'dancesstepsmap' VALUES (12909, 11511, 4);
INSERT INTO 'dancesstepsmap' VALUES (12910, 11512, 4);
INSERT INTO 'dancesstepsmap' VALUES (12911, 11513, 1);
INSERT INTO 'dancesstepsmap' VALUES (12912, 11511, 5);
INSERT INTO 'dancesstepsmap' VALUES (12913, 11514, 3);
INSERT INTO 'dancesstepsmap' VALUES (12914, 11515, 1);
INSERT INTO 'dancesstepsmap' VALUES (12915, 11515, 2);
INSERT INTO 'dancesstepsmap' VALUES (12916, 11515, 3);
INSERT INTO 'dancesstepsmap' VALUES (12917, 11516, 3);
INSERT INTO 'dancesstepsmap' VALUES (12918, 11516, 1);
INSERT INTO 'dancesstepsmap' VALUES (12919, 11516, 2);
INSERT INTO 'dancesstepsmap' VALUES (12920, 11517, 5);
INSERT INTO 'dancesstepsmap' VALUES (12921, 11517, 4);
INSERT INTO 'dancesstepsmap' VALUES (12922, 11518, 2);
INSERT INTO 'dancesstepsmap' VALUES (12923, 11518, 1);
INSERT INTO 'dancesstepsmap' VALUES (12924, 11519, 5);
INSERT INTO 'dancesstepsmap' VALUES (12925, 11519, 4);
INSERT INTO 'dancesstepsmap' VALUES (12926, 11520, 4);
INSERT INTO 'dancesstepsmap' VALUES (12927, 11520, 5);
INSERT INTO 'dancesstepsmap' VALUES (12928, 11521, 5);
INSERT INTO 'dancesstepsmap' VALUES (12929, 11521, 4);
INSERT INTO 'dancesstepsmap' VALUES (12930, 11522, 1);
INSERT INTO 'dancesstepsmap' VALUES (12931, 11522, 3);
INSERT INTO 'dancesstepsmap' VALUES (12932, 11523, 2);
INSERT INTO 'dancesstepsmap' VALUES (12933, 11523, 1);
INSERT INTO 'dancesstepsmap' VALUES (12934, 11525, 4);
INSERT INTO 'dancesstepsmap' VALUES (12935, 11526, 1);
INSERT INTO 'dancesstepsmap' VALUES (12936, 11527, 99);
INSERT INTO 'dancesstepsmap' VALUES (12937, 11527, 3);
INSERT INTO 'dancesstepsmap' VALUES (17417, 14706, 1);
INSERT INTO 'dancesstepsmap' VALUES (17418, 14706, 2);
INSERT INTO 'dancesstepsmap' VALUES (17419, 14707, 4);
INSERT INTO 'dancesstepsmap' VALUES (17420, 14707, 5);
INSERT INTO 'dancesstepsmap' VALUES (17421, 14707, 1);
INSERT INTO 'dancesstepsmap' VALUES (17422, 14707, 2);
INSERT INTO 'dancesstepsmap' VALUES (7831, 3492, 2);
INSERT INTO 'dancesstepsmap' VALUES (7832, 3601, 2);
INSERT INTO 'dancesstepsmap' VALUES (7833, 3713, 2);
INSERT INTO 'dancesstepsmap' VALUES (7834, 7447, 2);
INSERT INTO 'dancesstepsmap' VALUES (7835, 3778, 2);
INSERT INTO 'dancesstepsmap' VALUES (7836, 3798, 2);
INSERT INTO 'dancesstepsmap' VALUES (7837, 3818, 2);
INSERT INTO 'dancesstepsmap' VALUES (7838, 3829, 2);
INSERT INTO 'dancesstepsmap' VALUES (7839, 3891, 2);
INSERT INTO 'dancesstepsmap' VALUES (7840, 3969, 2);
INSERT INTO 'dancesstepsmap' VALUES (7841, 4004, 2);
INSERT INTO 'dancesstepsmap' VALUES (7842, 4098, 2);
INSERT INTO 'dancesstepsmap' VALUES (7843, 4285, 2);
INSERT INTO 'dancesstepsmap' VALUES (7844, 4383, 2);
INSERT INTO 'dancesstepsmap' VALUES (7845, 4407, 2);
INSERT INTO 'dancesstepsmap' VALUES (7846, 4414, 2);
INSERT INTO 'dancesstepsmap' VALUES (7847, 4591, 2);
INSERT INTO 'dancesstepsmap' VALUES (7848, 4596, 2);
INSERT INTO 'dancesstepsmap' VALUES (7849, 4645, 2);
INSERT INTO 'dancesstepsmap' VALUES (7850, 8437, 2);
INSERT INTO 'dancesstepsmap' VALUES (7851, 4817, 2);
INSERT INTO 'dancesstepsmap' VALUES (7852, 4856, 2);
INSERT INTO 'dancesstepsmap' VALUES (7853, 4864, 2);
INSERT INTO 'dancesstepsmap' VALUES (7854, 5216, 2);
INSERT INTO 'dancesstepsmap' VALUES (7855, 5241, 2);
INSERT INTO 'dancesstepsmap' VALUES (7856, 5262, 2);
INSERT INTO 'dancesstepsmap' VALUES (7857, 5405, 2);
INSERT INTO 'dancesstepsmap' VALUES (7858, 5449, 2);
INSERT INTO 'dancesstepsmap' VALUES (7859, 5533, 2);
INSERT INTO 'dancesstepsmap' VALUES (7860, 5663, 2);
INSERT INTO 'dancesstepsmap' VALUES (7861, 5800, 2);
INSERT INTO 'dancesstepsmap' VALUES (7862, 5803, 2);
INSERT INTO 'dancesstepsmap' VALUES (7863, 5878, 2);
INSERT INTO 'dancesstepsmap' VALUES (7864, 5909, 2);
INSERT INTO 'dancesstepsmap' VALUES (7865, 5925, 2);
INSERT INTO 'dancesstepsmap' VALUES (7866, 5935, 2);
INSERT INTO 'dancesstepsmap' VALUES (7867, 7512, 2);
INSERT INTO 'dancesstepsmap' VALUES (7868, 5977, 2);
INSERT INTO 'dancesstepsmap' VALUES (7869, 6348, 2);
INSERT INTO 'dancesstepsmap' VALUES (7870, 6404, 2);
INSERT INTO 'dancesstepsmap' VALUES (7871, 6406, 2);
INSERT INTO 'dancesstepsmap' VALUES (7872, 6410, 2);
INSERT INTO 'dancesstepsmap' VALUES (7873, 6551, 2);
INSERT INTO 'dancesstepsmap' VALUES (7874, 6560, 2);
INSERT INTO 'dancesstepsmap' VALUES (7875, 6590, 2);
INSERT INTO 'dancesstepsmap' VALUES (7876, 6613, 2);
INSERT INTO 'dancesstepsmap' VALUES (7877, 6644, 2);
INSERT INTO 'dancesstepsmap' VALUES (7878, 6661, 2);
INSERT INTO 'dancesstepsmap' VALUES (7879, 6727, 2);
INSERT INTO 'dancesstepsmap' VALUES (7880, 6768, 2);
INSERT INTO 'dancesstepsmap' VALUES (7881, 6931, 2);
INSERT INTO 'dancesstepsmap' VALUES (7882, 6997, 2);
INSERT INTO 'dancesstepsmap' VALUES (7883, 7105, 2);
INSERT INTO 'dancesstepsmap' VALUES (7884, 7106, 2);
INSERT INTO 'dancesstepsmap' VALUES (7885, 227, 2);
INSERT INTO 'dancesstepsmap' VALUES (7886, 590, 2);
INSERT INTO 'dancesstepsmap' VALUES (7887, 896, 2);
INSERT INTO 'dancesstepsmap' VALUES (7888, 1141, 2);
INSERT INTO 'dancesstepsmap' VALUES (7889, 2299, 2);
INSERT INTO 'dancesstepsmap' VALUES (7890, 3388, 2);
INSERT INTO 'dancesstepsmap' VALUES (7891, 3505, 2);
INSERT INTO 'dancesstepsmap' VALUES (7892, 5617, 2);
INSERT INTO 'dancesstepsmap' VALUES (7893, 6265, 2);
INSERT INTO 'dancesstepsmap' VALUES (7894, 6399, 2);
INSERT INTO 'dancesstepsmap' VALUES (7895, 42, 2);
INSERT INTO 'dancesstepsmap' VALUES (7896, 358, 2);
INSERT INTO 'dancesstepsmap' VALUES (7897, 464, 2);
INSERT INTO 'dancesstepsmap' VALUES (7898, 8386, 2);
INSERT INTO 'dancesstepsmap' VALUES (7899, 535, 2);
INSERT INTO 'dancesstepsmap' VALUES (7900, 639, 2);
INSERT INTO 'dancesstepsmap' VALUES (7901, 891, 2);
INSERT INTO 'dancesstepsmap' VALUES (7902, 940, 2);
INSERT INTO 'dancesstepsmap' VALUES (7903, 998, 2);
INSERT INTO 'dancesstepsmap' VALUES (7904, 1022, 2);
INSERT INTO 'dancesstepsmap' VALUES (7905, 1057, 2);
INSERT INTO 'dancesstepsmap' VALUES (7906, 1128, 2);
INSERT INTO 'dancesstepsmap' VALUES (7907, 1197, 2);
INSERT INTO 'dancesstepsmap' VALUES (7908, 1417, 2);
INSERT INTO 'dancesstepsmap' VALUES (7909, 2080, 2);
INSERT INTO 'dancesstepsmap' VALUES (7910, 2177, 2);
INSERT INTO 'dancesstepsmap' VALUES (7911, 2306, 2);
INSERT INTO 'dancesstepsmap' VALUES (7912, 2386, 2);
INSERT INTO 'dancesstepsmap' VALUES (7913, 2562, 2);
INSERT INTO 'dancesstepsmap' VALUES (7914, 2629, 2);
INSERT INTO 'dancesstepsmap' VALUES (7915, 2882, 2);
INSERT INTO 'dancesstepsmap' VALUES (7916, 8221, 2);
INSERT INTO 'dancesstepsmap' VALUES (7917, 3202, 2);
INSERT INTO 'dancesstepsmap' VALUES (7918, 3454, 2);
INSERT INTO 'dancesstepsmap' VALUES (7919, 3517, 2);
INSERT INTO 'dancesstepsmap' VALUES (7920, 3525, 2);
INSERT INTO 'dancesstepsmap' VALUES (7921, 3748, 2);
INSERT INTO 'dancesstepsmap' VALUES (7922, 3830, 2);
INSERT INTO 'dancesstepsmap' VALUES (7923, 3973, 2);
INSERT INTO 'dancesstepsmap' VALUES (12938, 11527, 1);
INSERT INTO 'dancesstepsmap' VALUES (12939, 11528, 1);
INSERT INTO 'dancesstepsmap' VALUES (12940, 11528, 3);
INSERT INTO 'dancesstepsmap' VALUES (12941, 11529, 1);
INSERT INTO 'dancesstepsmap' VALUES (12942, 11529, 2);
INSERT INTO 'dancesstepsmap' VALUES (12943, 11530, 1);
INSERT INTO 'dancesstepsmap' VALUES (23159, 18250, 3);
INSERT INTO 'dancesstepsmap' VALUES (23160, 18251, 2);
INSERT INTO 'dancesstepsmap' VALUES (12946, 11532, 4);
INSERT INTO 'dancesstepsmap' VALUES (12947, 11533, 4);
INSERT INTO 'dancesstepsmap' VALUES (12948, 11534, 2);
INSERT INTO 'dancesstepsmap' VALUES (12949, 11534, 1);
INSERT INTO 'dancesstepsmap' VALUES (12950, 5487, 1);
INSERT INTO 'dancesstepsmap' VALUES (12951, 5487, 3);
INSERT INTO 'dancesstepsmap' VALUES (12952, 11536, 1);
INSERT INTO 'dancesstepsmap' VALUES (12953, 11536, 3);
INSERT INTO 'dancesstepsmap' VALUES (12954, 11537, 2);
INSERT INTO 'dancesstepsmap' VALUES (12955, 11537, 1);
INSERT INTO 'dancesstepsmap' VALUES (12956, 11538, 1);
INSERT INTO 'dancesstepsmap' VALUES (12957, 9787, 1);
INSERT INTO 'dancesstepsmap' VALUES (12958, 9787, 2);
INSERT INTO 'dancesstepsmap' VALUES (12959, 11410, 3);
INSERT INTO 'dancesstepsmap' VALUES (12960, 11539, 4);
INSERT INTO 'dancesstepsmap' VALUES (12961, 11539, 5);
INSERT INTO 'dancesstepsmap' VALUES (12962, 11540, 1);
INSERT INTO 'dancesstepsmap' VALUES (12963, 11540, 2);
INSERT INTO 'dancesstepsmap' VALUES (12964, 11541, 4);
INSERT INTO 'dancesstepsmap' VALUES (12965, 11541, 5);
INSERT INTO 'dancesstepsmap' VALUES (12966, 11542, 2);
INSERT INTO 'dancesstepsmap' VALUES (12967, 11542, 1);
INSERT INTO 'dancesstepsmap' VALUES (12968, 11543, 1);
INSERT INTO 'dancesstepsmap' VALUES (12969, 11543, 2);
INSERT INTO 'dancesstepsmap' VALUES (12970, 11545, 1);
INSERT INTO 'dancesstepsmap' VALUES (12971, 11546, 4);
INSERT INTO 'dancesstepsmap' VALUES (12972, 11547, 3);
INSERT INTO 'dancesstepsmap' VALUES (12973, 11547, 2);
INSERT INTO 'dancesstepsmap' VALUES (12974, 11548, 1);
INSERT INTO 'dancesstepsmap' VALUES (12975, 11549, 1);
INSERT INTO 'dancesstepsmap' VALUES (12976, 11551, 4);
INSERT INTO 'dancesstepsmap' VALUES (12977, 11552, 3);
INSERT INTO 'dancesstepsmap' VALUES (12978, 11552, 1);
INSERT INTO 'dancesstepsmap' VALUES (12979, 11553, 4);
INSERT INTO 'dancesstepsmap' VALUES (17423, 14708, 1);
INSERT INTO 'dancesstepsmap' VALUES (17424, 14708, 2);
INSERT INTO 'dancesstepsmap' VALUES (7924, 4022, 2);
INSERT INTO 'dancesstepsmap' VALUES (7925, 7453, 2);
INSERT INTO 'dancesstepsmap' VALUES (7926, 4333, 2);
INSERT INTO 'dancesstepsmap' VALUES (7927, 4447, 2);
INSERT INTO 'dancesstepsmap' VALUES (7928, 4466, 2);
INSERT INTO 'dancesstepsmap' VALUES (7929, 4715, 2);
INSERT INTO 'dancesstepsmap' VALUES (7930, 4780, 2);
INSERT INTO 'dancesstepsmap' VALUES (7931, 4881, 2);
INSERT INTO 'dancesstepsmap' VALUES (7932, 4844, 2);
INSERT INTO 'dancesstepsmap' VALUES (7933, 4941, 2);
INSERT INTO 'dancesstepsmap' VALUES (7934, 5130, 2);
INSERT INTO 'dancesstepsmap' VALUES (7935, 5201, 2);
INSERT INTO 'dancesstepsmap' VALUES (7936, 5219, 2);
INSERT INTO 'dancesstepsmap' VALUES (7937, 8403, 2);
INSERT INTO 'dancesstepsmap' VALUES (7938, 5406, 2);
INSERT INTO 'dancesstepsmap' VALUES (7939, 7495, 2);
INSERT INTO 'dancesstepsmap' VALUES (7940, 5525, 2);
INSERT INTO 'dancesstepsmap' VALUES (7941, 5865, 2);
INSERT INTO 'dancesstepsmap' VALUES (7942, 5914, 2);
INSERT INTO 'dancesstepsmap' VALUES (7943, 6043, 2);
INSERT INTO 'dancesstepsmap' VALUES (7944, 873, 2);
INSERT INTO 'dancesstepsmap' VALUES (7945, 93, 2);
INSERT INTO 'dancesstepsmap' VALUES (7946, 194, 2);
INSERT INTO 'dancesstepsmap' VALUES (7947, 230, 2);
INSERT INTO 'dancesstepsmap' VALUES (7948, 276, 2);
INSERT INTO 'dancesstepsmap' VALUES (7949, 500, 2);
INSERT INTO 'dancesstepsmap' VALUES (7950, 627, 2);
INSERT INTO 'dancesstepsmap' VALUES (7951, 718, 2);
INSERT INTO 'dancesstepsmap' VALUES (7952, 779, 2);
INSERT INTO 'dancesstepsmap' VALUES (7953, 971, 2);
INSERT INTO 'dancesstepsmap' VALUES (7954, 1005, 2);
INSERT INTO 'dancesstepsmap' VALUES (7955, 1023, 2);
INSERT INTO 'dancesstepsmap' VALUES (7956, 1131, 2);
INSERT INTO 'dancesstepsmap' VALUES (7957, 1146, 2);
INSERT INTO 'dancesstepsmap' VALUES (7958, 1312, 2);
INSERT INTO 'dancesstepsmap' VALUES (7959, 1488, 2);
INSERT INTO 'dancesstepsmap' VALUES (7960, 1634, 2);
INSERT INTO 'dancesstepsmap' VALUES (7961, 1650, 2);
INSERT INTO 'dancesstepsmap' VALUES (7962, 1681, 2);
INSERT INTO 'dancesstepsmap' VALUES (7963, 1796, 2);
INSERT INTO 'dancesstepsmap' VALUES (7964, 7386, 2);
INSERT INTO 'dancesstepsmap' VALUES (7965, 1865, 2);
INSERT INTO 'dancesstepsmap' VALUES (7966, 2189, 2);
INSERT INTO 'dancesstepsmap' VALUES (7967, 2224, 2);
INSERT INTO 'dancesstepsmap' VALUES (7968, 2443, 2);
INSERT INTO 'dancesstepsmap' VALUES (7969, 2553, 2);
INSERT INTO 'dancesstepsmap' VALUES (7970, 2558, 2);
INSERT INTO 'dancesstepsmap' VALUES (7971, 2789, 2);
INSERT INTO 'dancesstepsmap' VALUES (7972, 3136, 2);
INSERT INTO 'dancesstepsmap' VALUES (7973, 3329, 2);
INSERT INTO 'dancesstepsmap' VALUES (7974, 3441, 2);
INSERT INTO 'dancesstepsmap' VALUES (7975, 3709, 2);
INSERT INTO 'dancesstepsmap' VALUES (7976, 3679, 2);
INSERT INTO 'dancesstepsmap' VALUES (7977, 3836, 2);
INSERT INTO 'dancesstepsmap' VALUES (7978, 3890, 2);
INSERT INTO 'dancesstepsmap' VALUES (7979, 4104, 2);
INSERT INTO 'dancesstepsmap' VALUES (7980, 4181, 2);
INSERT INTO 'dancesstepsmap' VALUES (7981, 4248, 2);
INSERT INTO 'dancesstepsmap' VALUES (7982, 4268, 2);
INSERT INTO 'dancesstepsmap' VALUES (7983, 4375, 2);
INSERT INTO 'dancesstepsmap' VALUES (7984, 4408, 2);
INSERT INTO 'dancesstepsmap' VALUES (7985, 4681, 2);
INSERT INTO 'dancesstepsmap' VALUES (7986, 4701, 2);
INSERT INTO 'dancesstepsmap' VALUES (7987, 5016, 2);
INSERT INTO 'dancesstepsmap' VALUES (7988, 5154, 2);
INSERT INTO 'dancesstepsmap' VALUES (7989, 5296, 2);
INSERT INTO 'dancesstepsmap' VALUES (7990, 5705, 2);
INSERT INTO 'dancesstepsmap' VALUES (7991, 4921, 2);
INSERT INTO 'dancesstepsmap' VALUES (7992, 4930, 2);
INSERT INTO 'dancesstepsmap' VALUES (7993, 5706, 2);
INSERT INTO 'dancesstepsmap' VALUES (7994, 8277, 2);
INSERT INTO 'dancesstepsmap' VALUES (7995, 6198, 2);
INSERT INTO 'dancesstepsmap' VALUES (7996, 6281, 2);
INSERT INTO 'dancesstepsmap' VALUES (7997, 6294, 2);
INSERT INTO 'dancesstepsmap' VALUES (7998, 6552, 2);
INSERT INTO 'dancesstepsmap' VALUES (7999, 6954, 2);
INSERT INTO 'dancesstepsmap' VALUES (8000, 8270, 2);
INSERT INTO 'dancesstepsmap' VALUES (8001, 6990, 2);
INSERT INTO 'dancesstepsmap' VALUES (8002, 8270, 1);
INSERT INTO 'dancesstepsmap' VALUES (8003, 7030, 2);
INSERT INTO 'dancesstepsmap' VALUES (8004, 7244, 2);
INSERT INTO 'dancesstepsmap' VALUES (8005, 57, 2);
INSERT INTO 'dancesstepsmap' VALUES (8006, 696, 2);
INSERT INTO 'dancesstepsmap' VALUES (8007, 886, 2);
INSERT INTO 'dancesstepsmap' VALUES (8008, 935, 2);
INSERT INTO 'dancesstepsmap' VALUES (8009, 941, 2);
INSERT INTO 'dancesstepsmap' VALUES (8010, 942, 2);
INSERT INTO 'dancesstepsmap' VALUES (8011, 8178, 2);
INSERT INTO 'dancesstepsmap' VALUES (8012, 1280, 2);
INSERT INTO 'dancesstepsmap' VALUES (8013, 1329, 2);
INSERT INTO 'dancesstepsmap' VALUES (8014, 1375, 2);
INSERT INTO 'dancesstepsmap' VALUES (8015, 1451, 2);
INSERT INTO 'dancesstepsmap' VALUES (8016, 1521, 2);
INSERT INTO 'dancesstepsmap' VALUES (8017, 1825, 2);
INSERT INTO 'dancesstepsmap' VALUES (8018, 245, 2);
INSERT INTO 'dancesstepsmap' VALUES (8019, 662, 2);
INSERT INTO 'dancesstepsmap' VALUES (8020, 1130, 2);
INSERT INTO 'dancesstepsmap' VALUES (8021, 2018, 2);
INSERT INTO 'dancesstepsmap' VALUES (8022, 2169, 2);
INSERT INTO 'dancesstepsmap' VALUES (8023, 2429, 2);
INSERT INTO 'dancesstepsmap' VALUES (8024, 2465, 2);
INSERT INTO 'dancesstepsmap' VALUES (8025, 2711, 2);
INSERT INTO 'dancesstepsmap' VALUES (8026, 8237, 2);
INSERT INTO 'dancesstepsmap' VALUES (8027, 2876, 2);
INSERT INTO 'dancesstepsmap' VALUES (8028, 2887, 2);
INSERT INTO 'dancesstepsmap' VALUES (8029, 2997, 2);
INSERT INTO 'dancesstepsmap' VALUES (8030, 3073, 2);
INSERT INTO 'dancesstepsmap' VALUES (8031, 3220, 2);
INSERT INTO 'dancesstepsmap' VALUES (8032, 3330, 2);
INSERT INTO 'dancesstepsmap' VALUES (8033, 3387, 2);
INSERT INTO 'dancesstepsmap' VALUES (8034, 3395, 2);
INSERT INTO 'dancesstepsmap' VALUES (8035, 3643, 2);
INSERT INTO 'dancesstepsmap' VALUES (8036, 3666, 2);
INSERT INTO 'dancesstepsmap' VALUES (8037, 4052, 2);
INSERT INTO 'dancesstepsmap' VALUES (8038, 4303, 2);
INSERT INTO 'dancesstepsmap' VALUES (8039, 7464, 2);
INSERT INTO 'dancesstepsmap' VALUES (8040, 4837, 2);
INSERT INTO 'dancesstepsmap' VALUES (8041, 4843, 2);
INSERT INTO 'dancesstepsmap' VALUES (8042, 5084, 2);
INSERT INTO 'dancesstepsmap' VALUES (8043, 5118, 2);
INSERT INTO 'dancesstepsmap' VALUES (8044, 5205, 2);
INSERT INTO 'dancesstepsmap' VALUES (8045, 5339, 2);
INSERT INTO 'dancesstepsmap' VALUES (8046, 5542, 2);
INSERT INTO 'dancesstepsmap' VALUES (8047, 5545, 2);
INSERT INTO 'dancesstepsmap' VALUES (8048, 5923, 2);
INSERT INTO 'dancesstepsmap' VALUES (8049, 6163, 2);
INSERT INTO 'dancesstepsmap' VALUES (8050, 6362, 2);
INSERT INTO 'dancesstepsmap' VALUES (8051, 6444, 2);
INSERT INTO 'dancesstepsmap' VALUES (8052, 6492, 2);
INSERT INTO 'dancesstepsmap' VALUES (8053, 6503, 2);
INSERT INTO 'dancesstepsmap' VALUES (12980, 11553, 5);
INSERT INTO 'dancesstepsmap' VALUES (12981, 11554, 4);
INSERT INTO 'dancesstepsmap' VALUES (12982, 11554, 5);
INSERT INTO 'dancesstepsmap' VALUES (12983, 8888, 4);
INSERT INTO 'dancesstepsmap' VALUES (12984, 8889, 2);
INSERT INTO 'dancesstepsmap' VALUES (12985, 8889, 1);
INSERT INTO 'dancesstepsmap' VALUES (12986, 8890, 6);
INSERT INTO 'dancesstepsmap' VALUES (12987, 8890, 4);
INSERT INTO 'dancesstepsmap' VALUES (12988, 8891, 2);
INSERT INTO 'dancesstepsmap' VALUES (12989, 8891, 1);
INSERT INTO 'dancesstepsmap' VALUES (12991, 8892, 4);
INSERT INTO 'dancesstepsmap' VALUES (12992, 8893, 1);
INSERT INTO 'dancesstepsmap' VALUES (12993, 8894, 5);
INSERT INTO 'dancesstepsmap' VALUES (12994, 8894, 6);
INSERT INTO 'dancesstepsmap' VALUES (12995, 8894, 4);
INSERT INTO 'dancesstepsmap' VALUES (8054, 6632, 2);
INSERT INTO 'dancesstepsmap' VALUES (8055, 6697, 2);
INSERT INTO 'dancesstepsmap' VALUES (8056, 7062, 2);
INSERT INTO 'dancesstepsmap' VALUES (8057, 7139, 2);
INSERT INTO 'dancesstepsmap' VALUES (8058, 7175, 2);
INSERT INTO 'dancesstepsmap' VALUES (8059, 7336, 1);
INSERT INTO 'dancesstepsmap' VALUES (8060, 7338, 1);
INSERT INTO 'dancesstepsmap' VALUES (8061, 7272, 1);
INSERT INTO 'dancesstepsmap' VALUES (8062, 8499, 1);
INSERT INTO 'dancesstepsmap' VALUES (8063, 7556, 1);
INSERT INTO 'dancesstepsmap' VALUES (8064, 7562, 1);
INSERT INTO 'dancesstepsmap' VALUES (8065, 7571, 1);
INSERT INTO 'dancesstepsmap' VALUES (8066, 8528, 1);
INSERT INTO 'dancesstepsmap' VALUES (8067, 7582, 1);
INSERT INTO 'dancesstepsmap' VALUES (8068, 8309, 1);
INSERT INTO 'dancesstepsmap' VALUES (8069, 7341, 1);
INSERT INTO 'dancesstepsmap' VALUES (8070, 8245, 1);
INSERT INTO 'dancesstepsmap' VALUES (8071, 7596, 1);
INSERT INTO 'dancesstepsmap' VALUES (8072, 7346, 1);
INSERT INTO 'dancesstepsmap' VALUES (8073, 7347, 1);
INSERT INTO 'dancesstepsmap' VALUES (8074, 8093, 1);
INSERT INTO 'dancesstepsmap' VALUES (8075, 7599, 1);
INSERT INTO 'dancesstepsmap' VALUES (8076, 7603, 1);
INSERT INTO 'dancesstepsmap' VALUES (8077, 7604, 1);
INSERT INTO 'dancesstepsmap' VALUES (8078, 8427, 1);
INSERT INTO 'dancesstepsmap' VALUES (8079, 7349, 1);
INSERT INTO 'dancesstepsmap' VALUES (8080, 8543, 1);
INSERT INTO 'dancesstepsmap' VALUES (8081, 8479, 1);
INSERT INTO 'dancesstepsmap' VALUES (8082, 8207, 1);
INSERT INTO 'dancesstepsmap' VALUES (8083, 8375, 1);
INSERT INTO 'dancesstepsmap' VALUES (8084, 8386, 1);
INSERT INTO 'dancesstepsmap' VALUES (8085, 8376, 1);
INSERT INTO 'dancesstepsmap' VALUES (8086, 8039, 1);
INSERT INTO 'dancesstepsmap' VALUES (8087, 8529, 1);
INSERT INTO 'dancesstepsmap' VALUES (8088, 8329, 1);
INSERT INTO 'dancesstepsmap' VALUES (8089, 7619, 1);
INSERT INTO 'dancesstepsmap' VALUES (8090, 7352, 1);
INSERT INTO 'dancesstepsmap' VALUES (8091, 684, 1);
INSERT INTO 'dancesstepsmap' VALUES (8092, 7623, 1);
INSERT INTO 'dancesstepsmap' VALUES (8093, 8500, 1);
INSERT INTO 'dancesstepsmap' VALUES (8094, 181, 1);
INSERT INTO 'dancesstepsmap' VALUES (8095, 1519, 1);
INSERT INTO 'dancesstepsmap' VALUES (8096, 8418, 1);
INSERT INTO 'dancesstepsmap' VALUES (8097, 8413, 1);
INSERT INTO 'dancesstepsmap' VALUES (8098, 8419, 1);
INSERT INTO 'dancesstepsmap' VALUES (8099, 8501, 1);
INSERT INTO 'dancesstepsmap' VALUES (8100, 5588, 1);
INSERT INTO 'dancesstepsmap' VALUES (8101, 8347, 1);
INSERT INTO 'dancesstepsmap' VALUES (8102, 7355, 1);
INSERT INTO 'dancesstepsmap' VALUES (8103, 8024, 1);
INSERT INTO 'dancesstepsmap' VALUES (8104, 7356, 1);
INSERT INTO 'dancesstepsmap' VALUES (8105, 8560, 1);
INSERT INTO 'dancesstepsmap' VALUES (8106, 4842, 1);
INSERT INTO 'dancesstepsmap' VALUES (8107, 5532, 1);
INSERT INTO 'dancesstepsmap' VALUES (8108, 5708, 1);
INSERT INTO 'dancesstepsmap' VALUES (8109, 7333, 1);
INSERT INTO 'dancesstepsmap' VALUES (8110, 7360, 1);
INSERT INTO 'dancesstepsmap' VALUES (8111, 7361, 1);
INSERT INTO 'dancesstepsmap' VALUES (8112, 7362, 1);
INSERT INTO 'dancesstepsmap' VALUES (8113, 7364, 1);
INSERT INTO 'dancesstepsmap' VALUES (8114, 7372, 1);
INSERT INTO 'dancesstepsmap' VALUES (8115, 7374, 1);
INSERT INTO 'dancesstepsmap' VALUES (8116, 7379, 1);
INSERT INTO 'dancesstepsmap' VALUES (8117, 7382, 1);
INSERT INTO 'dancesstepsmap' VALUES (8118, 7383, 1);
INSERT INTO 'dancesstepsmap' VALUES (8119, 7384, 1);
INSERT INTO 'dancesstepsmap' VALUES (8120, 7386, 1);
INSERT INTO 'dancesstepsmap' VALUES (8121, 7387, 1);
INSERT INTO 'dancesstepsmap' VALUES (8122, 7390, 1);
INSERT INTO 'dancesstepsmap' VALUES (8123, 7391, 1);
INSERT INTO 'dancesstepsmap' VALUES (8124, 7394, 1);
INSERT INTO 'dancesstepsmap' VALUES (8125, 7399, 1);
INSERT INTO 'dancesstepsmap' VALUES (8126, 7401, 1);
INSERT INTO 'dancesstepsmap' VALUES (8127, 7402, 1);
INSERT INTO 'dancesstepsmap' VALUES (8128, 7403, 1);
INSERT INTO 'dancesstepsmap' VALUES (8129, 7405, 1);
INSERT INTO 'dancesstepsmap' VALUES (8130, 7408, 1);
INSERT INTO 'dancesstepsmap' VALUES (8131, 7409, 1);
INSERT INTO 'dancesstepsmap' VALUES (8132, 7412, 1);
INSERT INTO 'dancesstepsmap' VALUES (8133, 7413, 1);
INSERT INTO 'dancesstepsmap' VALUES (8134, 7418, 1);
INSERT INTO 'dancesstepsmap' VALUES (8135, 7419, 1);
INSERT INTO 'dancesstepsmap' VALUES (8136, 7426, 1);
INSERT INTO 'dancesstepsmap' VALUES (8137, 7427, 1);
INSERT INTO 'dancesstepsmap' VALUES (8138, 7428, 1);
INSERT INTO 'dancesstepsmap' VALUES (8139, 7434, 1);
INSERT INTO 'dancesstepsmap' VALUES (8140, 7437, 1);
INSERT INTO 'dancesstepsmap' VALUES (8141, 7438, 1);
INSERT INTO 'dancesstepsmap' VALUES (8142, 7440, 1);
INSERT INTO 'dancesstepsmap' VALUES (8143, 7447, 1);
INSERT INTO 'dancesstepsmap' VALUES (8144, 7453, 1);
INSERT INTO 'dancesstepsmap' VALUES (8145, 7457, 1);
INSERT INTO 'dancesstepsmap' VALUES (12996, 8895, 1);
INSERT INTO 'dancesstepsmap' VALUES (12997, 8896, 6);
INSERT INTO 'dancesstepsmap' VALUES (12998, 8896, 4);
INSERT INTO 'dancesstepsmap' VALUES (12999, 8897, 1);
INSERT INTO 'dancesstepsmap' VALUES (13000, 10196, 5);
INSERT INTO 'dancesstepsmap' VALUES (13001, 10196, 4);
INSERT INTO 'dancesstepsmap' VALUES (13002, 10197, 2);
INSERT INTO 'dancesstepsmap' VALUES (13003, 10197, 1);
INSERT INTO 'dancesstepsmap' VALUES (13004, 10199, 2);
INSERT INTO 'dancesstepsmap' VALUES (13005, 10200, 5);
INSERT INTO 'dancesstepsmap' VALUES (13006, 10200, 4);
INSERT INTO 'dancesstepsmap' VALUES (13007, 10201, 2);
INSERT INTO 'dancesstepsmap' VALUES (13008, 10201, 1);
INSERT INTO 'dancesstepsmap' VALUES (13009, 10202, 4);
INSERT INTO 'dancesstepsmap' VALUES (13010, 10202, 5);
INSERT INTO 'dancesstepsmap' VALUES (13011, 10203, 1);
INSERT INTO 'dancesstepsmap' VALUES (13012, 10203, 2);
INSERT INTO 'dancesstepsmap' VALUES (13013, 10204, 4);
INSERT INTO 'dancesstepsmap' VALUES (13014, 10205, 8);
INSERT INTO 'dancesstepsmap' VALUES (13015, 10205, 1);
INSERT INTO 'dancesstepsmap' VALUES (13016, 10205, 3);
INSERT INTO 'dancesstepsmap' VALUES (13017, 10206, 5);
INSERT INTO 'dancesstepsmap' VALUES (13018, 10206, 4);
INSERT INTO 'dancesstepsmap' VALUES (13019, 10207, 1);
INSERT INTO 'dancesstepsmap' VALUES (13020, 10208, 9);
INSERT INTO 'dancesstepsmap' VALUES (13021, 10208, 5);
INSERT INTO 'dancesstepsmap' VALUES (13022, 10208, 6);
INSERT INTO 'dancesstepsmap' VALUES (13023, 10208, 4);
INSERT INTO 'dancesstepsmap' VALUES (13024, 10209, 6);
INSERT INTO 'dancesstepsmap' VALUES (13025, 10209, 5);
INSERT INTO 'dancesstepsmap' VALUES (13026, 10209, 9);
INSERT INTO 'dancesstepsmap' VALUES (13027, 10209, 4);
INSERT INTO 'dancesstepsmap' VALUES (13028, 10209, 10);
INSERT INTO 'dancesstepsmap' VALUES (13029, 10210, 10);
INSERT INTO 'dancesstepsmap' VALUES (13030, 10210, 6);
INSERT INTO 'dancesstepsmap' VALUES (13031, 10210, 9);
INSERT INTO 'dancesstepsmap' VALUES (13032, 10211, 10);
INSERT INTO 'dancesstepsmap' VALUES (13033, 10211, 9);
INSERT INTO 'dancesstepsmap' VALUES (13034, 10212, 10);
INSERT INTO 'dancesstepsmap' VALUES (13035, 10213, 10);
INSERT INTO 'dancesstepsmap' VALUES (13036, 10214, 4);
INSERT INTO 'dancesstepsmap' VALUES (13037, 10215, 99);
INSERT INTO 'dancesstepsmap' VALUES (13038, 10216, 5);
INSERT INTO 'dancesstepsmap' VALUES (13039, 10216, 4);
INSERT INTO 'dancesstepsmap' VALUES (13040, 10217, 1);
INSERT INTO 'dancesstepsmap' VALUES (13041, 10218, 5);
INSERT INTO 'dancesstepsmap' VALUES (13042, 10218, 4);
INSERT INTO 'dancesstepsmap' VALUES (13043, 10219, 1);
INSERT INTO 'dancesstepsmap' VALUES (13044, 10219, 3);
INSERT INTO 'dancesstepsmap' VALUES (13045, 10220, 9);
INSERT INTO 'dancesstepsmap' VALUES (13046, 10220, 4);
INSERT INTO 'dancesstepsmap' VALUES (13047, 10220, 5);
INSERT INTO 'dancesstepsmap' VALUES (13048, 10221, 10);
INSERT INTO 'dancesstepsmap' VALUES (17425, 14709, 1);
INSERT INTO 'dancesstepsmap' VALUES (8146, 7458, 1);
INSERT INTO 'dancesstepsmap' VALUES (8147, 7461, 1);
INSERT INTO 'dancesstepsmap' VALUES (8148, 7464, 1);
INSERT INTO 'dancesstepsmap' VALUES (8149, 7465, 1);
INSERT INTO 'dancesstepsmap' VALUES (8150, 7468, 1);
INSERT INTO 'dancesstepsmap' VALUES (8151, 7470, 1);
INSERT INTO 'dancesstepsmap' VALUES (8152, 7471, 1);
INSERT INTO 'dancesstepsmap' VALUES (8153, 7480, 1);
INSERT INTO 'dancesstepsmap' VALUES (8154, 7481, 1);
INSERT INTO 'dancesstepsmap' VALUES (8155, 7486, 1);
INSERT INTO 'dancesstepsmap' VALUES (8156, 7487, 1);
INSERT INTO 'dancesstepsmap' VALUES (8157, 7495, 1);
INSERT INTO 'dancesstepsmap' VALUES (8158, 7504, 1);
INSERT INTO 'dancesstepsmap' VALUES (8159, 7505, 1);
INSERT INTO 'dancesstepsmap' VALUES (8160, 7507, 1);
INSERT INTO 'dancesstepsmap' VALUES (8161, 7509, 1);
INSERT INTO 'dancesstepsmap' VALUES (8162, 7510, 1);
INSERT INTO 'dancesstepsmap' VALUES (8163, 7511, 1);
INSERT INTO 'dancesstepsmap' VALUES (8164, 7512, 1);
INSERT INTO 'dancesstepsmap' VALUES (8165, 7514, 1);
INSERT INTO 'dancesstepsmap' VALUES (8166, 7516, 1);
INSERT INTO 'dancesstepsmap' VALUES (8167, 7522, 1);
INSERT INTO 'dancesstepsmap' VALUES (8168, 7524, 1);
INSERT INTO 'dancesstepsmap' VALUES (8169, 7525, 1);
INSERT INTO 'dancesstepsmap' VALUES (8170, 7527, 1);
INSERT INTO 'dancesstepsmap' VALUES (8171, 7537, 1);
INSERT INTO 'dancesstepsmap' VALUES (8172, 7539, 1);
INSERT INTO 'dancesstepsmap' VALUES (8173, 7544, 1);
INSERT INTO 'dancesstepsmap' VALUES (8174, 7545, 1);
INSERT INTO 'dancesstepsmap' VALUES (8175, 7561, 1);
INSERT INTO 'dancesstepsmap' VALUES (8176, 7563, 1);
INSERT INTO 'dancesstepsmap' VALUES (8177, 7564, 1);
INSERT INTO 'dancesstepsmap' VALUES (8178, 7565, 1);
INSERT INTO 'dancesstepsmap' VALUES (8179, 7567, 1);
INSERT INTO 'dancesstepsmap' VALUES (8180, 7569, 1);
INSERT INTO 'dancesstepsmap' VALUES (8181, 7570, 1);
INSERT INTO 'dancesstepsmap' VALUES (8182, 7576, 1);
INSERT INTO 'dancesstepsmap' VALUES (8183, 250, 1);
INSERT INTO 'dancesstepsmap' VALUES (8184, 868, 1);
INSERT INTO 'dancesstepsmap' VALUES (8185, 2922, 1);
INSERT INTO 'dancesstepsmap' VALUES (8186, 5391, 1);
INSERT INTO 'dancesstepsmap' VALUES (8187, 5481, 1);
INSERT INTO 'dancesstepsmap' VALUES (8188, 6537, 1);
INSERT INTO 'dancesstepsmap' VALUES (8189, 7628, 1);
INSERT INTO 'dancesstepsmap' VALUES (8190, 7630, 1);
INSERT INTO 'dancesstepsmap' VALUES (8191, 7632, 1);
INSERT INTO 'dancesstepsmap' VALUES (8192, 7633, 1);
INSERT INTO 'dancesstepsmap' VALUES (8193, 7638, 1);
INSERT INTO 'dancesstepsmap' VALUES (8194, 7639, 1);
INSERT INTO 'dancesstepsmap' VALUES (8195, 7640, 1);
INSERT INTO 'dancesstepsmap' VALUES (8196, 693, 1);
INSERT INTO 'dancesstepsmap' VALUES (8197, 701, 1);
INSERT INTO 'dancesstepsmap' VALUES (8198, 1035, 1);
INSERT INTO 'dancesstepsmap' VALUES (8199, 7650, 1);
INSERT INTO 'dancesstepsmap' VALUES (8200, 7653, 1);
INSERT INTO 'dancesstepsmap' VALUES (8201, 7657, 1);
INSERT INTO 'dancesstepsmap' VALUES (8202, 7658, 1);
INSERT INTO 'dancesstepsmap' VALUES (8203, 7660, 1);
INSERT INTO 'dancesstepsmap' VALUES (8204, 7667, 1);
INSERT INTO 'dancesstepsmap' VALUES (8205, 7668, 1);
INSERT INTO 'dancesstepsmap' VALUES (8206, 7670, 1);
INSERT INTO 'dancesstepsmap' VALUES (8207, 7672, 1);
INSERT INTO 'dancesstepsmap' VALUES (8208, 7675, 1);
INSERT INTO 'dancesstepsmap' VALUES (8209, 7676, 1);
INSERT INTO 'dancesstepsmap' VALUES (8211, 7682, 1);
INSERT INTO 'dancesstepsmap' VALUES (8212, 7683, 1);
INSERT INTO 'dancesstepsmap' VALUES (8213, 7685, 1);
INSERT INTO 'dancesstepsmap' VALUES (8214, 7686, 1);
INSERT INTO 'dancesstepsmap' VALUES (8215, 7688, 1);
INSERT INTO 'dancesstepsmap' VALUES (8216, 7692, 1);
INSERT INTO 'dancesstepsmap' VALUES (8217, 7695, 1);
INSERT INTO 'dancesstepsmap' VALUES (8218, 7698, 1);
INSERT INTO 'dancesstepsmap' VALUES (8219, 7700, 1);
INSERT INTO 'dancesstepsmap' VALUES (8220, 7703, 1);
INSERT INTO 'dancesstepsmap' VALUES (8221, 7708, 1);
INSERT INTO 'dancesstepsmap' VALUES (8222, 7709, 1);
INSERT INTO 'dancesstepsmap' VALUES (8223, 7710, 1);
INSERT INTO 'dancesstepsmap' VALUES (8224, 7712, 1);
INSERT INTO 'dancesstepsmap' VALUES (8225, 7714, 1);
INSERT INTO 'dancesstepsmap' VALUES (8226, 1771, 1);
INSERT INTO 'dancesstepsmap' VALUES (8227, 2036, 1);
INSERT INTO 'dancesstepsmap' VALUES (8228, 4702, 1);
INSERT INTO 'dancesstepsmap' VALUES (8229, 4740, 1);
INSERT INTO 'dancesstepsmap' VALUES (8230, 5490, 1);
INSERT INTO 'dancesstepsmap' VALUES (8231, 5694, 1);
INSERT INTO 'dancesstepsmap' VALUES (8232, 6083, 1);
INSERT INTO 'dancesstepsmap' VALUES (8233, 7392, 1);
INSERT INTO 'dancesstepsmap' VALUES (8234, 7716, 1);
INSERT INTO 'dancesstepsmap' VALUES (8235, 7719, 1);
INSERT INTO 'dancesstepsmap' VALUES (8236, 7721, 1);
INSERT INTO 'dancesstepsmap' VALUES (8237, 7727, 1);
INSERT INTO 'dancesstepsmap' VALUES (8238, 7728, 1);
INSERT INTO 'dancesstepsmap' VALUES (13049, 10221, 1);
INSERT INTO 'dancesstepsmap' VALUES (13050, 10222, 5);
INSERT INTO 'dancesstepsmap' VALUES (13051, 10222, 4);
INSERT INTO 'dancesstepsmap' VALUES (13052, 10223, 1);
INSERT INTO 'dancesstepsmap' VALUES (13053, 10224, 4);
INSERT INTO 'dancesstepsmap' VALUES (13054, 10225, 2);
INSERT INTO 'dancesstepsmap' VALUES (13055, 10225, 1);
INSERT INTO 'dancesstepsmap' VALUES (13056, 10226, 4);
INSERT INTO 'dancesstepsmap' VALUES (13057, 10226, 5);
INSERT INTO 'dancesstepsmap' VALUES (13058, 10227, 4);
INSERT INTO 'dancesstepsmap' VALUES (13059, 10228, 4);
INSERT INTO 'dancesstepsmap' VALUES (13060, 10228, 5);
INSERT INTO 'dancesstepsmap' VALUES (13061, 10228, 9);
INSERT INTO 'dancesstepsmap' VALUES (13062, 10229, 4);
INSERT INTO 'dancesstepsmap' VALUES (13063, 10587, 1);
INSERT INTO 'dancesstepsmap' VALUES (13064, 10587, 2);
INSERT INTO 'dancesstepsmap' VALUES (13065, 10587, 3);
INSERT INTO 'dancesstepsmap' VALUES (13066, 10592, 5);
INSERT INTO 'dancesstepsmap' VALUES (13067, 10592, 4);
INSERT INTO 'dancesstepsmap' VALUES (13068, 10598, 1);
INSERT INTO 'dancesstepsmap' VALUES (13069, 10598, 3);
INSERT INTO 'dancesstepsmap' VALUES (13070, 10598, 2);
INSERT INTO 'dancesstepsmap' VALUES (13071, 10594, 4);
INSERT INTO 'dancesstepsmap' VALUES (13072, 10594, 5);
INSERT INTO 'dancesstepsmap' VALUES (13073, 10593, 1);
INSERT INTO 'dancesstepsmap' VALUES (13074, 10593, 2);
INSERT INTO 'dancesstepsmap' VALUES (13075, 1382, 5);
INSERT INTO 'dancesstepsmap' VALUES (13077, 11390, 1);
INSERT INTO 'dancesstepsmap' VALUES (13078, 11391, 1);
INSERT INTO 'dancesstepsmap' VALUES (13079, 11392, 1);
INSERT INTO 'dancesstepsmap' VALUES (13080, 11393, 4);
INSERT INTO 'dancesstepsmap' VALUES (13081, 11394, 4);
INSERT INTO 'dancesstepsmap' VALUES (13082, 11394, 5);
INSERT INTO 'dancesstepsmap' VALUES (13083, 11395, 4);
INSERT INTO 'dancesstepsmap' VALUES (13084, 11396, 4);
INSERT INTO 'dancesstepsmap' VALUES (13085, 11396, 5);
INSERT INTO 'dancesstepsmap' VALUES (13086, 11397, 1);
INSERT INTO 'dancesstepsmap' VALUES (13087, 11398, 4);
INSERT INTO 'dancesstepsmap' VALUES (13088, 11399, 1);
INSERT INTO 'dancesstepsmap' VALUES (13089, 11400, 1);
INSERT INTO 'dancesstepsmap' VALUES (13090, 11555, 1);
INSERT INTO 'dancesstepsmap' VALUES (17426, 14709, 3);
INSERT INTO 'dancesstepsmap' VALUES (17427, 14709, 2);
INSERT INTO 'dancesstepsmap' VALUES (8239, 7730, 1);
INSERT INTO 'dancesstepsmap' VALUES (8241, 7739, 1);
INSERT INTO 'dancesstepsmap' VALUES (8242, 2542, 1);
INSERT INTO 'dancesstepsmap' VALUES (8243, 2559, 1);
INSERT INTO 'dancesstepsmap' VALUES (8244, 2580, 1);
INSERT INTO 'dancesstepsmap' VALUES (8245, 2614, 1);
INSERT INTO 'dancesstepsmap' VALUES (8246, 4621, 1);
INSERT INTO 'dancesstepsmap' VALUES (8247, 5429, 1);
INSERT INTO 'dancesstepsmap' VALUES (8248, 7747, 1);
INSERT INTO 'dancesstepsmap' VALUES (8249, 7754, 1);
INSERT INTO 'dancesstepsmap' VALUES (8250, 7757, 1);
INSERT INTO 'dancesstepsmap' VALUES (8251, 7761, 1);
INSERT INTO 'dancesstepsmap' VALUES (8252, 3074, 1);
INSERT INTO 'dancesstepsmap' VALUES (8253, 7774, 1);
INSERT INTO 'dancesstepsmap' VALUES (8254, 7781, 1);
INSERT INTO 'dancesstepsmap' VALUES (8255, 7782, 1);
INSERT INTO 'dancesstepsmap' VALUES (8256, 7791, 1);
INSERT INTO 'dancesstepsmap' VALUES (8257, 7794, 1);
INSERT INTO 'dancesstepsmap' VALUES (8258, 7795, 1);
INSERT INTO 'dancesstepsmap' VALUES (8259, 7800, 1);
INSERT INTO 'dancesstepsmap' VALUES (8260, 7801, 1);
INSERT INTO 'dancesstepsmap' VALUES (8261, 7814, 1);
INSERT INTO 'dancesstepsmap' VALUES (8262, 7817, 1);
INSERT INTO 'dancesstepsmap' VALUES (8264, 7821, 1);
INSERT INTO 'dancesstepsmap' VALUES (8265, 2144, 1);
INSERT INTO 'dancesstepsmap' VALUES (8266, 3688, 1);
INSERT INTO 'dancesstepsmap' VALUES (8267, 3750, 1);
INSERT INTO 'dancesstepsmap' VALUES (8268, 6642, 1);
INSERT INTO 'dancesstepsmap' VALUES (8269, 7785, 1);
INSERT INTO 'dancesstepsmap' VALUES (8270, 7825, 1);
INSERT INTO 'dancesstepsmap' VALUES (8271, 7826, 1);
INSERT INTO 'dancesstepsmap' VALUES (8272, 7828, 1);
INSERT INTO 'dancesstepsmap' VALUES (8273, 7831, 1);
INSERT INTO 'dancesstepsmap' VALUES (8274, 7834, 1);
INSERT INTO 'dancesstepsmap' VALUES (8275, 7836, 1);
INSERT INTO 'dancesstepsmap' VALUES (8276, 7840, 1);
INSERT INTO 'dancesstepsmap' VALUES (8277, 7843, 1);
INSERT INTO 'dancesstepsmap' VALUES (8278, 7847, 1);
INSERT INTO 'dancesstepsmap' VALUES (8279, 7850, 1);
INSERT INTO 'dancesstepsmap' VALUES (8281, 7857, 1);
INSERT INTO 'dancesstepsmap' VALUES (8282, 7858, 1);
INSERT INTO 'dancesstepsmap' VALUES (8283, 7859, 1);
INSERT INTO 'dancesstepsmap' VALUES (8284, 7863, 1);
INSERT INTO 'dancesstepsmap' VALUES (8285, 4121, 1);
INSERT INTO 'dancesstepsmap' VALUES (8286, 5565, 1);
INSERT INTO 'dancesstepsmap' VALUES (8287, 7870, 1);
INSERT INTO 'dancesstepsmap' VALUES (8288, 7871, 1);
INSERT INTO 'dancesstepsmap' VALUES (8289, 7874, 1);
INSERT INTO 'dancesstepsmap' VALUES (8290, 7875, 1);
INSERT INTO 'dancesstepsmap' VALUES (8291, 7878, 1);
INSERT INTO 'dancesstepsmap' VALUES (8292, 7882, 1);
INSERT INTO 'dancesstepsmap' VALUES (8293, 7888, 1);
INSERT INTO 'dancesstepsmap' VALUES (8294, 7899, 1);
INSERT INTO 'dancesstepsmap' VALUES (8295, 7901, 1);
INSERT INTO 'dancesstepsmap' VALUES (8296, 7902, 1);
INSERT INTO 'dancesstepsmap' VALUES (8297, 7903, 1);
INSERT INTO 'dancesstepsmap' VALUES (8298, 7906, 1);
INSERT INTO 'dancesstepsmap' VALUES (8299, 7907, 1);
INSERT INTO 'dancesstepsmap' VALUES (8300, 7908, 1);
INSERT INTO 'dancesstepsmap' VALUES (8301, 7909, 1);
INSERT INTO 'dancesstepsmap' VALUES (8302, 7911, 1);
INSERT INTO 'dancesstepsmap' VALUES (8303, 2810, 1);
INSERT INTO 'dancesstepsmap' VALUES (8304, 7915, 1);
INSERT INTO 'dancesstepsmap' VALUES (8305, 7919, 1);
INSERT INTO 'dancesstepsmap' VALUES (8306, 7921, 1);
INSERT INTO 'dancesstepsmap' VALUES (8307, 7923, 1);
INSERT INTO 'dancesstepsmap' VALUES (8308, 7924, 1);
INSERT INTO 'dancesstepsmap' VALUES (8309, 7929, 1);
INSERT INTO 'dancesstepsmap' VALUES (8310, 7933, 1);
INSERT INTO 'dancesstepsmap' VALUES (8311, 7937, 1);
INSERT INTO 'dancesstepsmap' VALUES (8312, 7941, 1);
INSERT INTO 'dancesstepsmap' VALUES (8313, 7943, 1);
INSERT INTO 'dancesstepsmap' VALUES (8314, 5742, 1);
INSERT INTO 'dancesstepsmap' VALUES (8315, 5745, 1);
INSERT INTO 'dancesstepsmap' VALUES (8316, 5780, 1);
INSERT INTO 'dancesstepsmap' VALUES (8317, 5990, 1);
INSERT INTO 'dancesstepsmap' VALUES (8318, 7946, 1);
INSERT INTO 'dancesstepsmap' VALUES (8320, 7959, 1);
INSERT INTO 'dancesstepsmap' VALUES (8321, 7961, 1);
INSERT INTO 'dancesstepsmap' VALUES (8322, 7963, 1);
INSERT INTO 'dancesstepsmap' VALUES (8323, 7965, 1);
INSERT INTO 'dancesstepsmap' VALUES (8324, 7321, 1);
INSERT INTO 'dancesstepsmap' VALUES (8325, 7966, 1);
INSERT INTO 'dancesstepsmap' VALUES (8326, 7967, 1);
INSERT INTO 'dancesstepsmap' VALUES (8327, 7969, 1);
INSERT INTO 'dancesstepsmap' VALUES (8328, 7976, 1);
INSERT INTO 'dancesstepsmap' VALUES (8329, 7994, 1);
INSERT INTO 'dancesstepsmap' VALUES (8330, 8006, 1);
INSERT INTO 'dancesstepsmap' VALUES (8331, 8009, 1);
INSERT INTO 'dancesstepsmap' VALUES (8332, 8010, 1);
INSERT INTO 'dancesstepsmap' VALUES (13091, 11555, 2);
INSERT INTO 'dancesstepsmap' VALUES (13092, 11556, 3);
INSERT INTO 'dancesstepsmap' VALUES (13093, 2360, 2);
INSERT INTO 'dancesstepsmap' VALUES (13094, 6042, 3);
INSERT INTO 'dancesstepsmap' VALUES (13095, 3621, 3);
INSERT INTO 'dancesstepsmap' VALUES (13096, 1030, 2);
INSERT INTO 'dancesstepsmap' VALUES (13097, 3986, 3);
INSERT INTO 'dancesstepsmap' VALUES (13098, 3986, 2);
INSERT INTO 'dancesstepsmap' VALUES (13099, 11557, 2);
INSERT INTO 'dancesstepsmap' VALUES (13100, 11557, 1);
INSERT INTO 'dancesstepsmap' VALUES (13101, 11558, 2);
INSERT INTO 'dancesstepsmap' VALUES (13102, 11558, 1);
INSERT INTO 'dancesstepsmap' VALUES (13103, 11559, 4);
INSERT INTO 'dancesstepsmap' VALUES (13104, 11559, 5);
INSERT INTO 'dancesstepsmap' VALUES (13105, 11560, 10);
INSERT INTO 'dancesstepsmap' VALUES (13106, 11560, 1);
INSERT INTO 'dancesstepsmap' VALUES (13107, 11561, 2);
INSERT INTO 'dancesstepsmap' VALUES (13108, 11561, 1);
INSERT INTO 'dancesstepsmap' VALUES (13109, 11562, 4);
INSERT INTO 'dancesstepsmap' VALUES (13110, 11563, 1);
INSERT INTO 'dancesstepsmap' VALUES (13111, 11564, 5);
INSERT INTO 'dancesstepsmap' VALUES (13112, 11564, 4);
INSERT INTO 'dancesstepsmap' VALUES (13113, 5615, 2);
INSERT INTO 'dancesstepsmap' VALUES (13114, 11565, 2);
INSERT INTO 'dancesstepsmap' VALUES (13115, 11565, 1);
INSERT INTO 'dancesstepsmap' VALUES (13116, 11566, 5);
INSERT INTO 'dancesstepsmap' VALUES (13117, 11566, 4);
INSERT INTO 'dancesstepsmap' VALUES (13118, 11567, 1);
INSERT INTO 'dancesstepsmap' VALUES (13119, 11568, 2);
INSERT INTO 'dancesstepsmap' VALUES (13120, 11568, 1);
INSERT INTO 'dancesstepsmap' VALUES (13121, 11568, 3);
INSERT INTO 'dancesstepsmap' VALUES (13122, 11569, 4);
INSERT INTO 'dancesstepsmap' VALUES (13123, 11193, 1);
INSERT INTO 'dancesstepsmap' VALUES (13124, 11193, 2);
INSERT INTO 'dancesstepsmap' VALUES (13125, 11193, 3);
INSERT INTO 'dancesstepsmap' VALUES (13126, 11570, 2);
INSERT INTO 'dancesstepsmap' VALUES (13127, 11570, 1);
INSERT INTO 'dancesstepsmap' VALUES (13128, 11570, 3);
INSERT INTO 'dancesstepsmap' VALUES (13129, 11480, 5);
INSERT INTO 'dancesstepsmap' VALUES (13130, 11571, 1);
INSERT INTO 'dancesstepsmap' VALUES (13131, 11571, 2);
INSERT INTO 'dancesstepsmap' VALUES (13132, 11571, 3);
INSERT INTO 'dancesstepsmap' VALUES (13133, 11572, 1);
INSERT INTO 'dancesstepsmap' VALUES (17428, 14710, 4);
INSERT INTO 'dancesstepsmap' VALUES (17431, 14711, 5);
INSERT INTO 'dancesstepsmap' VALUES (17432, 14711, 4);
INSERT INTO 'dancesstepsmap' VALUES (17435, 8202, 3);
INSERT INTO 'dancesstepsmap' VALUES (17436, 14713, 4);
INSERT INTO 'dancesstepsmap' VALUES (17437, 14713, 10);
INSERT INTO 'dancesstepsmap' VALUES (17440, 11795, 2);
INSERT INTO 'dancesstepsmap' VALUES (17441, 12801, 5);
INSERT INTO 'dancesstepsmap' VALUES (17442, 12801, 4);
INSERT INTO 'dancesstepsmap' VALUES (17443, 7662, 5);
INSERT INTO 'dancesstepsmap' VALUES (23161, 18251, 1);
INSERT INTO 'dancesstepsmap' VALUES (23224, 12312, 4);
INSERT INTO 'dancesstepsmap' VALUES (17447, 1713, 3);
INSERT INTO 'dancesstepsmap' VALUES (17448, 1713, 2);
INSERT INTO 'dancesstepsmap' VALUES (17449, 1858, 5);
INSERT INTO 'dancesstepsmap' VALUES (17450, 12769, 2);
INSERT INTO 'dancesstepsmap' VALUES (17451, 10853, 1);
INSERT INTO 'dancesstepsmap' VALUES (17452, 4511, 5);
INSERT INTO 'dancesstepsmap' VALUES (17453, 2600, 5);
INSERT INTO 'dancesstepsmap' VALUES (17454, 780, 3);
INSERT INTO 'dancesstepsmap' VALUES (17455, 5152, 5);
INSERT INTO 'dancesstepsmap' VALUES (17456, 11770, 1);
INSERT INTO 'dancesstepsmap' VALUES (8333, 2159, 1);
INSERT INTO 'dancesstepsmap' VALUES (8334, 6528, 1);
INSERT INTO 'dancesstepsmap' VALUES (8335, 8015, 1);
INSERT INTO 'dancesstepsmap' VALUES (8336, 8017, 1);
INSERT INTO 'dancesstepsmap' VALUES (8337, 8020, 1);
INSERT INTO 'dancesstepsmap' VALUES (8338, 8021, 1);
INSERT INTO 'dancesstepsmap' VALUES (8339, 8025, 1);
INSERT INTO 'dancesstepsmap' VALUES (8340, 8027, 1);
INSERT INTO 'dancesstepsmap' VALUES (8341, 8032, 1);
INSERT INTO 'dancesstepsmap' VALUES (8342, 8033, 1);
INSERT INTO 'dancesstepsmap' VALUES (8343, 8038, 1);
INSERT INTO 'dancesstepsmap' VALUES (8344, 8041, 1);
INSERT INTO 'dancesstepsmap' VALUES (8345, 8042, 1);
INSERT INTO 'dancesstepsmap' VALUES (8346, 8043, 1);
INSERT INTO 'dancesstepsmap' VALUES (8347, 8044, 1);
INSERT INTO 'dancesstepsmap' VALUES (8348, 8045, 1);
INSERT INTO 'dancesstepsmap' VALUES (8349, 8049, 1);
INSERT INTO 'dancesstepsmap' VALUES (8350, 8053, 1);
INSERT INTO 'dancesstepsmap' VALUES (8351, 8054, 1);
INSERT INTO 'dancesstepsmap' VALUES (8352, 8062, 1);
INSERT INTO 'dancesstepsmap' VALUES (8353, 8063, 1);
INSERT INTO 'dancesstepsmap' VALUES (8354, 8065, 1);
INSERT INTO 'dancesstepsmap' VALUES (8355, 8067, 1);
INSERT INTO 'dancesstepsmap' VALUES (8356, 8070, 1);
INSERT INTO 'dancesstepsmap' VALUES (8357, 8074, 1);
INSERT INTO 'dancesstepsmap' VALUES (8358, 8075, 1);
INSERT INTO 'dancesstepsmap' VALUES (8359, 8076, 1);
INSERT INTO 'dancesstepsmap' VALUES (8360, 8077, 1);
INSERT INTO 'dancesstepsmap' VALUES (8361, 5635, 1);
INSERT INTO 'dancesstepsmap' VALUES (8362, 8079, 1);
INSERT INTO 'dancesstepsmap' VALUES (8363, 8084, 1);
INSERT INTO 'dancesstepsmap' VALUES (8364, 8085, 1);
INSERT INTO 'dancesstepsmap' VALUES (8365, 8086, 1);
INSERT INTO 'dancesstepsmap' VALUES (8366, 8088, 1);
INSERT INTO 'dancesstepsmap' VALUES (8367, 7656, 1);
INSERT INTO 'dancesstepsmap' VALUES (8368, 8090, 1);
INSERT INTO 'dancesstepsmap' VALUES (8369, 8095, 1);
INSERT INTO 'dancesstepsmap' VALUES (8370, 8096, 1);
INSERT INTO 'dancesstepsmap' VALUES (8371, 8098, 1);
INSERT INTO 'dancesstepsmap' VALUES (8372, 8104, 1);
INSERT INTO 'dancesstepsmap' VALUES (8373, 8107, 1);
INSERT INTO 'dancesstepsmap' VALUES (8374, 8108, 1);
INSERT INTO 'dancesstepsmap' VALUES (8375, 8112, 1);
INSERT INTO 'dancesstepsmap' VALUES (8376, 8117, 1);
INSERT INTO 'dancesstepsmap' VALUES (8377, 8121, 1);
INSERT INTO 'dancesstepsmap' VALUES (8378, 8124, 1);
INSERT INTO 'dancesstepsmap' VALUES (8379, 8126, 1);
INSERT INTO 'dancesstepsmap' VALUES (8380, 8127, 1);
INSERT INTO 'dancesstepsmap' VALUES (8381, 8129, 1);
INSERT INTO 'dancesstepsmap' VALUES (8382, 8132, 1);
INSERT INTO 'dancesstepsmap' VALUES (8383, 8133, 1);
INSERT INTO 'dancesstepsmap' VALUES (8384, 8134, 1);
INSERT INTO 'dancesstepsmap' VALUES (8385, 8135, 1);
INSERT INTO 'dancesstepsmap' VALUES (8386, 8136, 1);
INSERT INTO 'dancesstepsmap' VALUES (8387, 5527, 1);
INSERT INTO 'dancesstepsmap' VALUES (8388, 8158, 1);
INSERT INTO 'dancesstepsmap' VALUES (8389, 8165, 1);
INSERT INTO 'dancesstepsmap' VALUES (8390, 8172, 1);
INSERT INTO 'dancesstepsmap' VALUES (8391, 8174, 1);
INSERT INTO 'dancesstepsmap' VALUES (8392, 8178, 1);
INSERT INTO 'dancesstepsmap' VALUES (8393, 8182, 1);
INSERT INTO 'dancesstepsmap' VALUES (8394, 8183, 1);
INSERT INTO 'dancesstepsmap' VALUES (8395, 8185, 1);
INSERT INTO 'dancesstepsmap' VALUES (8396, 8188, 1);
INSERT INTO 'dancesstepsmap' VALUES (8397, 8194, 1);
INSERT INTO 'dancesstepsmap' VALUES (8398, 8200, 1);
INSERT INTO 'dancesstepsmap' VALUES (8399, 8209, 1);
INSERT INTO 'dancesstepsmap' VALUES (8400, 8211, 1);
INSERT INTO 'dancesstepsmap' VALUES (8401, 8216, 1);
INSERT INTO 'dancesstepsmap' VALUES (8402, 8218, 1);
INSERT INTO 'dancesstepsmap' VALUES (8403, 8221, 1);
INSERT INTO 'dancesstepsmap' VALUES (8404, 8227, 1);
INSERT INTO 'dancesstepsmap' VALUES (8405, 8236, 1);
INSERT INTO 'dancesstepsmap' VALUES (8406, 8237, 1);
INSERT INTO 'dancesstepsmap' VALUES (8407, 8242, 1);
INSERT INTO 'dancesstepsmap' VALUES (8408, 8246, 1);
INSERT INTO 'dancesstepsmap' VALUES (8409, 8247, 1);
INSERT INTO 'dancesstepsmap' VALUES (8410, 8249, 1);
INSERT INTO 'dancesstepsmap' VALUES (8411, 8253, 1);
INSERT INTO 'dancesstepsmap' VALUES (8412, 8256, 1);
INSERT INTO 'dancesstepsmap' VALUES (8413, 8258, 1);
INSERT INTO 'dancesstepsmap' VALUES (8414, 8259, 1);
INSERT INTO 'dancesstepsmap' VALUES (8415, 8263, 1);
INSERT INTO 'dancesstepsmap' VALUES (8416, 8274, 1);
INSERT INTO 'dancesstepsmap' VALUES (8417, 8277, 1);
INSERT INTO 'dancesstepsmap' VALUES (8418, 8288, 1);
INSERT INTO 'dancesstepsmap' VALUES (8419, 8289, 1);
INSERT INTO 'dancesstepsmap' VALUES (8420, 8295, 1);
INSERT INTO 'dancesstepsmap' VALUES (8421, 8297, 1);
INSERT INTO 'dancesstepsmap' VALUES (8422, 8299, 1);
INSERT INTO 'dancesstepsmap' VALUES (8423, 8301, 1);
INSERT INTO 'dancesstepsmap' VALUES (8424, 8304, 1);
INSERT INTO 'dancesstepsmap' VALUES (8425, 8305, 1);
INSERT INTO 'dancesstepsmap' VALUES (13134, 11572, 3);
INSERT INTO 'dancesstepsmap' VALUES (13135, 11573, 1);
INSERT INTO 'dancesstepsmap' VALUES (13136, 11573, 2);
INSERT INTO 'dancesstepsmap' VALUES (13137, 11574, 1);
INSERT INTO 'dancesstepsmap' VALUES (13138, 11575, 1);
INSERT INTO 'dancesstepsmap' VALUES (13139, 11575, 3);
INSERT INTO 'dancesstepsmap' VALUES (13140, 11576, 1);
INSERT INTO 'dancesstepsmap' VALUES (13141, 11576, 2);
INSERT INTO 'dancesstepsmap' VALUES (13142, 11577, 4);
INSERT INTO 'dancesstepsmap' VALUES (13143, 11579, 3);
INSERT INTO 'dancesstepsmap' VALUES (13144, 11579, 1);
INSERT INTO 'dancesstepsmap' VALUES (13145, 11580, 2);
INSERT INTO 'dancesstepsmap' VALUES (13146, 11580, 1);
INSERT INTO 'dancesstepsmap' VALUES (13147, 11581, 2);
INSERT INTO 'dancesstepsmap' VALUES (13148, 11582, 4);
INSERT INTO 'dancesstepsmap' VALUES (13149, 8344, 5);
INSERT INTO 'dancesstepsmap' VALUES (13150, 11583, 4);
INSERT INTO 'dancesstepsmap' VALUES (13151, 11583, 5);
INSERT INTO 'dancesstepsmap' VALUES (13152, 11585, 1);
INSERT INTO 'dancesstepsmap' VALUES (13153, 10647, 1);
INSERT INTO 'dancesstepsmap' VALUES (13154, 10682, 4);
INSERT INTO 'dancesstepsmap' VALUES (13155, 10682, 5);
INSERT INTO 'dancesstepsmap' VALUES (13156, 10695, 1);
INSERT INTO 'dancesstepsmap' VALUES (13157, 10677, 1);
INSERT INTO 'dancesstepsmap' VALUES (13158, 10678, 1);
INSERT INTO 'dancesstepsmap' VALUES (13159, 11586, 1);
INSERT INTO 'dancesstepsmap' VALUES (13160, 11587, 2);
INSERT INTO 'dancesstepsmap' VALUES (13161, 11587, 1);
INSERT INTO 'dancesstepsmap' VALUES (13162, 11588, 1);
INSERT INTO 'dancesstepsmap' VALUES (13163, 1225, 3);
INSERT INTO 'dancesstepsmap' VALUES (13164, 1541, 5);
INSERT INTO 'dancesstepsmap' VALUES (13165, 11589, 4);
INSERT INTO 'dancesstepsmap' VALUES (13166, 11589, 5);
INSERT INTO 'dancesstepsmap' VALUES (13167, 11590, 1);
INSERT INTO 'dancesstepsmap' VALUES (13168, 11590, 2);
INSERT INTO 'dancesstepsmap' VALUES (13169, 11591, 3);
INSERT INTO 'dancesstepsmap' VALUES (13170, 11591, 2);
INSERT INTO 'dancesstepsmap' VALUES (13171, 11591, 1);
INSERT INTO 'dancesstepsmap' VALUES (13172, 11592, 1);
INSERT INTO 'dancesstepsmap' VALUES (13173, 11593, 4);
INSERT INTO 'dancesstepsmap' VALUES (13174, 11594, 2);
INSERT INTO 'dancesstepsmap' VALUES (13175, 11594, 1);
INSERT INTO 'dancesstepsmap' VALUES (17429, 13590, 1);
INSERT INTO 'dancesstepsmap' VALUES (17430, 13590, 2);
INSERT INTO 'dancesstepsmap' VALUES (17433, 14712, 2);
INSERT INTO 'dancesstepsmap' VALUES (17434, 14712, 1);
INSERT INTO 'dancesstepsmap' VALUES (17444, 5460, 5);
INSERT INTO 'dancesstepsmap' VALUES (17457, 11770, 2);
INSERT INTO 'dancesstepsmap' VALUES (8426, 8313, 1);
INSERT INTO 'dancesstepsmap' VALUES (8427, 8332, 1);
INSERT INTO 'dancesstepsmap' VALUES (8428, 8335, 1);
INSERT INTO 'dancesstepsmap' VALUES (8429, 8336, 1);
INSERT INTO 'dancesstepsmap' VALUES (8430, 8339, 1);
INSERT INTO 'dancesstepsmap' VALUES (8431, 8340, 1);
INSERT INTO 'dancesstepsmap' VALUES (8433, 8353, 1);
INSERT INTO 'dancesstepsmap' VALUES (8434, 8356, 1);
INSERT INTO 'dancesstepsmap' VALUES (8435, 8368, 1);
INSERT INTO 'dancesstepsmap' VALUES (8436, 8373, 1);
INSERT INTO 'dancesstepsmap' VALUES (8437, 8380, 1);
INSERT INTO 'dancesstepsmap' VALUES (8438, 8381, 1);
INSERT INTO 'dancesstepsmap' VALUES (8439, 8387, 1);
INSERT INTO 'dancesstepsmap' VALUES (8440, 8389, 1);
INSERT INTO 'dancesstepsmap' VALUES (8441, 8391, 1);
INSERT INTO 'dancesstepsmap' VALUES (8442, 8394, 1);
INSERT INTO 'dancesstepsmap' VALUES (8443, 8396, 1);
INSERT INTO 'dancesstepsmap' VALUES (8444, 8397, 1);
INSERT INTO 'dancesstepsmap' VALUES (8445, 8401, 1);
INSERT INTO 'dancesstepsmap' VALUES (8446, 8402, 1);
INSERT INTO 'dancesstepsmap' VALUES (8447, 8403, 1);
INSERT INTO 'dancesstepsmap' VALUES (8448, 8408, 1);
INSERT INTO 'dancesstepsmap' VALUES (8449, 8414, 1);
INSERT INTO 'dancesstepsmap' VALUES (8450, 8415, 1);
INSERT INTO 'dancesstepsmap' VALUES (8451, 8416, 1);
INSERT INTO 'dancesstepsmap' VALUES (8452, 8417, 1);
INSERT INTO 'dancesstepsmap' VALUES (8453, 8422, 1);
INSERT INTO 'dancesstepsmap' VALUES (8454, 8423, 1);
INSERT INTO 'dancesstepsmap' VALUES (8455, 8425, 1);
INSERT INTO 'dancesstepsmap' VALUES (8456, 8430, 1);
INSERT INTO 'dancesstepsmap' VALUES (8457, 8433, 1);
INSERT INTO 'dancesstepsmap' VALUES (8458, 8437, 1);
INSERT INTO 'dancesstepsmap' VALUES (8459, 614, 1);
INSERT INTO 'dancesstepsmap' VALUES (8460, 8461, 1);
INSERT INTO 'dancesstepsmap' VALUES (8461, 8462, 1);
INSERT INTO 'dancesstepsmap' VALUES (8462, 8464, 1);
INSERT INTO 'dancesstepsmap' VALUES (8463, 8467, 1);
INSERT INTO 'dancesstepsmap' VALUES (8464, 8473, 1);
INSERT INTO 'dancesstepsmap' VALUES (8465, 8480, 1);
INSERT INTO 'dancesstepsmap' VALUES (8466, 8481, 1);
INSERT INTO 'dancesstepsmap' VALUES (8467, 8483, 1);
INSERT INTO 'dancesstepsmap' VALUES (8468, 8485, 1);
INSERT INTO 'dancesstepsmap' VALUES (8469, 8487, 1);
INSERT INTO 'dancesstepsmap' VALUES (8470, 8494, 1);
INSERT INTO 'dancesstepsmap' VALUES (8471, 8498, 1);
INSERT INTO 'dancesstepsmap' VALUES (8472, 8502, 1);
INSERT INTO 'dancesstepsmap' VALUES (8473, 8503, 1);
INSERT INTO 'dancesstepsmap' VALUES (8474, 8504, 1);
INSERT INTO 'dancesstepsmap' VALUES (8475, 8505, 1);
INSERT INTO 'dancesstepsmap' VALUES (8476, 8506, 1);
INSERT INTO 'dancesstepsmap' VALUES (8477, 8507, 1);
INSERT INTO 'dancesstepsmap' VALUES (8478, 8508, 1);
INSERT INTO 'dancesstepsmap' VALUES (8479, 8509, 1);
INSERT INTO 'dancesstepsmap' VALUES (8480, 8510, 1);
INSERT INTO 'dancesstepsmap' VALUES (8481, 8511, 1);
INSERT INTO 'dancesstepsmap' VALUES (8482, 8512, 1);
INSERT INTO 'dancesstepsmap' VALUES (8483, 8513, 1);
INSERT INTO 'dancesstepsmap' VALUES (8484, 8514, 1);
INSERT INTO 'dancesstepsmap' VALUES (8485, 8515, 1);
INSERT INTO 'dancesstepsmap' VALUES (8486, 8516, 1);
INSERT INTO 'dancesstepsmap' VALUES (8487, 8517, 1);
INSERT INTO 'dancesstepsmap' VALUES (8488, 8518, 1);
INSERT INTO 'dancesstepsmap' VALUES (8489, 8519, 1);
INSERT INTO 'dancesstepsmap' VALUES (8490, 8520, 1);
INSERT INTO 'dancesstepsmap' VALUES (8491, 8521, 1);
INSERT INTO 'dancesstepsmap' VALUES (8492, 8522, 1);
INSERT INTO 'dancesstepsmap' VALUES (8493, 8523, 1);
INSERT INTO 'dancesstepsmap' VALUES (8494, 8524, 1);
INSERT INTO 'dancesstepsmap' VALUES (8495, 8525, 1);
INSERT INTO 'dancesstepsmap' VALUES (8496, 8526, 1);
INSERT INTO 'dancesstepsmap' VALUES (8497, 8527, 1);
INSERT INTO 'dancesstepsmap' VALUES (8498, 8530, 1);
INSERT INTO 'dancesstepsmap' VALUES (8499, 8531, 1);
INSERT INTO 'dancesstepsmap' VALUES (8500, 8532, 1);
INSERT INTO 'dancesstepsmap' VALUES (8501, 8533, 1);
INSERT INTO 'dancesstepsmap' VALUES (8502, 8534, 1);
INSERT INTO 'dancesstepsmap' VALUES (8503, 8535, 1);
INSERT INTO 'dancesstepsmap' VALUES (8504, 8536, 1);
INSERT INTO 'dancesstepsmap' VALUES (8505, 8537, 1);
INSERT INTO 'dancesstepsmap' VALUES (8506, 8538, 1);
INSERT INTO 'dancesstepsmap' VALUES (8507, 8539, 1);
INSERT INTO 'dancesstepsmap' VALUES (8508, 8540, 1);
INSERT INTO 'dancesstepsmap' VALUES (8509, 8541, 1);
INSERT INTO 'dancesstepsmap' VALUES (8510, 8542, 1);
INSERT INTO 'dancesstepsmap' VALUES (8511, 8544, 1);
INSERT INTO 'dancesstepsmap' VALUES (8512, 8545, 1);
INSERT INTO 'dancesstepsmap' VALUES (8513, 8546, 1);
INSERT INTO 'dancesstepsmap' VALUES (8514, 8549, 1);
INSERT INTO 'dancesstepsmap' VALUES (8515, 8550, 1);
INSERT INTO 'dancesstepsmap' VALUES (8516, 8552, 1);
INSERT INTO 'dancesstepsmap' VALUES (8517, 8557, 1);
INSERT INTO 'dancesstepsmap' VALUES (8518, 8564, 1);
INSERT INTO 'dancesstepsmap' VALUES (8519, 8565, 1);
INSERT INTO 'dancesstepsmap' VALUES (8520, 8568, 1);
INSERT INTO 'dancesstepsmap' VALUES (8521, 8570, 1);
INSERT INTO 'dancesstepsmap' VALUES (8522, 8573, 1);
INSERT INTO 'dancesstepsmap' VALUES (8523, 8574, 1);
INSERT INTO 'dancesstepsmap' VALUES (8524, 8575, 1);
INSERT INTO 'dancesstepsmap' VALUES (8525, 8582, 1);
INSERT INTO 'dancesstepsmap' VALUES (23162, 18252, 5);
INSERT INTO 'dancesstepsmap' VALUES (8527, 8173, 1);
INSERT INTO 'dancesstepsmap' VALUES (8528, 8176, 1);
INSERT INTO 'dancesstepsmap' VALUES (8529, 8180, 1);
INSERT INTO 'dancesstepsmap' VALUES (8530, 8192, 1);
INSERT INTO 'dancesstepsmap' VALUES (8531, 8195, 1);
INSERT INTO 'dancesstepsmap' VALUES (8532, 8197, 1);
INSERT INTO 'dancesstepsmap' VALUES (8533, 8199, 1);
INSERT INTO 'dancesstepsmap' VALUES (8534, 8202, 1);
INSERT INTO 'dancesstepsmap' VALUES (8535, 8203, 1);
INSERT INTO 'dancesstepsmap' VALUES (8536, 8204, 1);
INSERT INTO 'dancesstepsmap' VALUES (8537, 8205, 1);
INSERT INTO 'dancesstepsmap' VALUES (8538, 8206, 1);
INSERT INTO 'dancesstepsmap' VALUES (8539, 8208, 1);
INSERT INTO 'dancesstepsmap' VALUES (8540, 8210, 1);
INSERT INTO 'dancesstepsmap' VALUES (8541, 8214, 1);
INSERT INTO 'dancesstepsmap' VALUES (8542, 8222, 1);
INSERT INTO 'dancesstepsmap' VALUES (8543, 8226, 1);
INSERT INTO 'dancesstepsmap' VALUES (8544, 8230, 1);
INSERT INTO 'dancesstepsmap' VALUES (8545, 8232, 1);
INSERT INTO 'dancesstepsmap' VALUES (8546, 8241, 1);
INSERT INTO 'dancesstepsmap' VALUES (8547, 8250, 1);
INSERT INTO 'dancesstepsmap' VALUES (8548, 8251, 1);
INSERT INTO 'dancesstepsmap' VALUES (8549, 8252, 1);
INSERT INTO 'dancesstepsmap' VALUES (8550, 8265, 1);
INSERT INTO 'dancesstepsmap' VALUES (8551, 8273, 1);
INSERT INTO 'dancesstepsmap' VALUES (8552, 8276, 1);
INSERT INTO 'dancesstepsmap' VALUES (8553, 8280, 1);
INSERT INTO 'dancesstepsmap' VALUES (8554, 8293, 1);
INSERT INTO 'dancesstepsmap' VALUES (8555, 8303, 1);
INSERT INTO 'dancesstepsmap' VALUES (8556, 8307, 1);
INSERT INTO 'dancesstepsmap' VALUES (13176, 5673, 2);
INSERT INTO 'dancesstepsmap' VALUES (13177, 11595, 3);
INSERT INTO 'dancesstepsmap' VALUES (13178, 11595, 1);
INSERT INTO 'dancesstepsmap' VALUES (13179, 11596, 2);
INSERT INTO 'dancesstepsmap' VALUES (13180, 11597, 4);
INSERT INTO 'dancesstepsmap' VALUES (13181, 11597, 5);
INSERT INTO 'dancesstepsmap' VALUES (13182, 11598, 1);
INSERT INTO 'dancesstepsmap' VALUES (13183, 11598, 2);
INSERT INTO 'dancesstepsmap' VALUES (13184, 11598, 3);
INSERT INTO 'dancesstepsmap' VALUES (13185, 11599, 1);
INSERT INTO 'dancesstepsmap' VALUES (13186, 11599, 3);
INSERT INTO 'dancesstepsmap' VALUES (13187, 11600, 1);
INSERT INTO 'dancesstepsmap' VALUES (13188, 11584, 1);
INSERT INTO 'dancesstepsmap' VALUES (13189, 11584, 2);
INSERT INTO 'dancesstepsmap' VALUES (13190, 11601, 2);
INSERT INTO 'dancesstepsmap' VALUES (17458, 981, 2);
INSERT INTO 'dancesstepsmap' VALUES (8557, 8311, 1);
INSERT INTO 'dancesstepsmap' VALUES (8558, 8315, 1);
INSERT INTO 'dancesstepsmap' VALUES (8559, 8322, 1);
INSERT INTO 'dancesstepsmap' VALUES (8560, 8323, 1);
INSERT INTO 'dancesstepsmap' VALUES (8561, 8324, 1);
INSERT INTO 'dancesstepsmap' VALUES (8562, 8325, 1);
INSERT INTO 'dancesstepsmap' VALUES (8563, 8328, 1);
INSERT INTO 'dancesstepsmap' VALUES (8564, 8334, 1);
INSERT INTO 'dancesstepsmap' VALUES (8565, 8338, 1);
INSERT INTO 'dancesstepsmap' VALUES (8567, 8349, 1);
INSERT INTO 'dancesstepsmap' VALUES (8568, 8351, 1);
INSERT INTO 'dancesstepsmap' VALUES (8569, 8360, 1);
INSERT INTO 'dancesstepsmap' VALUES (8570, 8363, 1);
INSERT INTO 'dancesstepsmap' VALUES (8571, 8364, 1);
INSERT INTO 'dancesstepsmap' VALUES (8572, 8365, 1);
INSERT INTO 'dancesstepsmap' VALUES (8573, 8366, 1);
INSERT INTO 'dancesstepsmap' VALUES (8574, 8371, 1);
INSERT INTO 'dancesstepsmap' VALUES (8575, 8374, 1);
INSERT INTO 'dancesstepsmap' VALUES (8576, 8377, 1);
INSERT INTO 'dancesstepsmap' VALUES (8577, 8378, 1);
INSERT INTO 'dancesstepsmap' VALUES (8578, 8384, 1);
INSERT INTO 'dancesstepsmap' VALUES (8579, 8388, 1);
INSERT INTO 'dancesstepsmap' VALUES (8580, 8399, 1);
INSERT INTO 'dancesstepsmap' VALUES (8581, 8400, 1);
INSERT INTO 'dancesstepsmap' VALUES (8582, 8404, 1);
INSERT INTO 'dancesstepsmap' VALUES (8583, 8405, 1);
INSERT INTO 'dancesstepsmap' VALUES (8584, 8406, 1);
INSERT INTO 'dancesstepsmap' VALUES (8585, 8409, 1);
INSERT INTO 'dancesstepsmap' VALUES (8586, 8410, 1);
INSERT INTO 'dancesstepsmap' VALUES (8587, 8411, 1);
INSERT INTO 'dancesstepsmap' VALUES (8588, 8426, 1);
INSERT INTO 'dancesstepsmap' VALUES (8589, 8428, 1);
INSERT INTO 'dancesstepsmap' VALUES (8590, 8431, 1);
INSERT INTO 'dancesstepsmap' VALUES (8591, 8438, 1);
INSERT INTO 'dancesstepsmap' VALUES (8592, 8444, 1);
INSERT INTO 'dancesstepsmap' VALUES (8593, 4403, 1);
INSERT INTO 'dancesstepsmap' VALUES (8594, 4435, 1);
INSERT INTO 'dancesstepsmap' VALUES (8595, 8465, 1);
INSERT INTO 'dancesstepsmap' VALUES (8596, 8466, 1);
INSERT INTO 'dancesstepsmap' VALUES (8597, 8469, 1);
INSERT INTO 'dancesstepsmap' VALUES (8598, 8470, 1);
INSERT INTO 'dancesstepsmap' VALUES (8599, 8476, 1);
INSERT INTO 'dancesstepsmap' VALUES (8600, 8478, 1);
INSERT INTO 'dancesstepsmap' VALUES (8601, 8484, 1);
INSERT INTO 'dancesstepsmap' VALUES (8602, 8486, 1);
INSERT INTO 'dancesstepsmap' VALUES (8603, 8489, 1);
INSERT INTO 'dancesstepsmap' VALUES (8604, 8490, 1);
INSERT INTO 'dancesstepsmap' VALUES (8605, 8496, 1);
INSERT INTO 'dancesstepsmap' VALUES (8606, 8547, 1);
INSERT INTO 'dancesstepsmap' VALUES (8607, 8555, 1);
INSERT INTO 'dancesstepsmap' VALUES (8608, 8556, 1);
INSERT INTO 'dancesstepsmap' VALUES (8609, 8558, 1);
INSERT INTO 'dancesstepsmap' VALUES (8610, 8561, 1);
INSERT INTO 'dancesstepsmap' VALUES (8611, 8563, 1);
INSERT INTO 'dancesstepsmap' VALUES (8612, 8569, 1);
INSERT INTO 'dancesstepsmap' VALUES (8613, 8577, 1);
INSERT INTO 'dancesstepsmap' VALUES (8614, 8578, 1);
INSERT INTO 'dancesstepsmap' VALUES (8615, 8572, 1);
INSERT INTO 'dancesstepsmap' VALUES (23163, 18252, 4);
INSERT INTO 'dancesstepsmap' VALUES (23225, 12312, 5);
INSERT INTO 'dancesstepsmap' VALUES (8618, 4680, 4);
INSERT INTO 'dancesstepsmap' VALUES (8619, 7378, 4);
INSERT INTO 'dancesstepsmap' VALUES (8620, 7381, 4);
INSERT INTO 'dancesstepsmap' VALUES (8621, 7389, 4);
INSERT INTO 'dancesstepsmap' VALUES (8622, 7393, 4);
INSERT INTO 'dancesstepsmap' VALUES (8623, 7395, 4);
INSERT INTO 'dancesstepsmap' VALUES (8624, 7396, 4);
INSERT INTO 'dancesstepsmap' VALUES (8625, 7397, 4);
INSERT INTO 'dancesstepsmap' VALUES (8626, 7398, 4);
INSERT INTO 'dancesstepsmap' VALUES (8627, 7407, 4);
INSERT INTO 'dancesstepsmap' VALUES (8628, 7415, 4);
INSERT INTO 'dancesstepsmap' VALUES (8629, 7416, 4);
INSERT INTO 'dancesstepsmap' VALUES (8630, 7417, 4);
INSERT INTO 'dancesstepsmap' VALUES (8631, 7422, 4);
INSERT INTO 'dancesstepsmap' VALUES (8632, 7425, 4);
INSERT INTO 'dancesstepsmap' VALUES (8633, 7432, 4);
INSERT INTO 'dancesstepsmap' VALUES (8634, 7435, 4);
INSERT INTO 'dancesstepsmap' VALUES (8635, 7439, 4);
INSERT INTO 'dancesstepsmap' VALUES (8636, 7444, 4);
INSERT INTO 'dancesstepsmap' VALUES (8637, 7446, 4);
INSERT INTO 'dancesstepsmap' VALUES (8638, 7454, 4);
INSERT INTO 'dancesstepsmap' VALUES (8639, 7456, 4);
INSERT INTO 'dancesstepsmap' VALUES (8640, 7459, 4);
INSERT INTO 'dancesstepsmap' VALUES (8641, 7462, 4);
INSERT INTO 'dancesstepsmap' VALUES (8642, 7473, 4);
INSERT INTO 'dancesstepsmap' VALUES (8643, 7474, 4);
INSERT INTO 'dancesstepsmap' VALUES (8644, 7476, 4);
INSERT INTO 'dancesstepsmap' VALUES (8645, 7477, 4);
INSERT INTO 'dancesstepsmap' VALUES (8646, 7483, 4);
INSERT INTO 'dancesstepsmap' VALUES (8647, 7484, 4);
INSERT INTO 'dancesstepsmap' VALUES (8648, 7485, 4);
INSERT INTO 'dancesstepsmap' VALUES (8649, 7492, 4);
INSERT INTO 'dancesstepsmap' VALUES (13191, 11601, 1);
INSERT INTO 'dancesstepsmap' VALUES (13192, 11601, 4);
INSERT INTO 'dancesstepsmap' VALUES (13193, 11601, 5);
INSERT INTO 'dancesstepsmap' VALUES (13194, 11602, 5);
INSERT INTO 'dancesstepsmap' VALUES (13195, 11602, 4);
INSERT INTO 'dancesstepsmap' VALUES (13196, 11603, 1);
INSERT INTO 'dancesstepsmap' VALUES (13197, 11603, 2);
INSERT INTO 'dancesstepsmap' VALUES (13198, 11603, 3);
INSERT INTO 'dancesstepsmap' VALUES (13199, 11604, 3);
INSERT INTO 'dancesstepsmap' VALUES (13200, 11605, 4);
INSERT INTO 'dancesstepsmap' VALUES (13201, 11605, 5);
INSERT INTO 'dancesstepsmap' VALUES (13202, 11606, 2);
INSERT INTO 'dancesstepsmap' VALUES (13203, 11607, 5);
INSERT INTO 'dancesstepsmap' VALUES (13204, 11607, 4);
INSERT INTO 'dancesstepsmap' VALUES (13205, 11608, 5);
INSERT INTO 'dancesstepsmap' VALUES (13206, 11608, 4);
INSERT INTO 'dancesstepsmap' VALUES (13207, 11610, 1);
INSERT INTO 'dancesstepsmap' VALUES (13208, 11611, 2);
INSERT INTO 'dancesstepsmap' VALUES (13209, 11612, 4);
INSERT INTO 'dancesstepsmap' VALUES (13210, 11613, 1);
INSERT INTO 'dancesstepsmap' VALUES (13212, 11614, 4);
INSERT INTO 'dancesstepsmap' VALUES (13213, 11614, 5);
INSERT INTO 'dancesstepsmap' VALUES (13214, 11615, 1);
INSERT INTO 'dancesstepsmap' VALUES (13215, 11615, 2);
INSERT INTO 'dancesstepsmap' VALUES (13216, 11616, 5);
INSERT INTO 'dancesstepsmap' VALUES (13217, 11616, 4);
INSERT INTO 'dancesstepsmap' VALUES (13218, 11617, 1);
INSERT INTO 'dancesstepsmap' VALUES (13219, 11618, 2);
INSERT INTO 'dancesstepsmap' VALUES (13220, 11619, 1);
INSERT INTO 'dancesstepsmap' VALUES (13221, 11620, 4);
INSERT INTO 'dancesstepsmap' VALUES (13222, 11621, 2);
INSERT INTO 'dancesstepsmap' VALUES (13223, 11621, 1);
INSERT INTO 'dancesstepsmap' VALUES (13224, 11621, 3);
INSERT INTO 'dancesstepsmap' VALUES (13225, 11622, 2);
INSERT INTO 'dancesstepsmap' VALUES (13226, 11622, 1);
INSERT INTO 'dancesstepsmap' VALUES (13227, 11623, 4);
INSERT INTO 'dancesstepsmap' VALUES (13228, 11623, 5);
INSERT INTO 'dancesstepsmap' VALUES (13229, 11624, 2);
INSERT INTO 'dancesstepsmap' VALUES (13230, 11625, 6);
INSERT INTO 'dancesstepsmap' VALUES (13231, 11625, 4);
INSERT INTO 'dancesstepsmap' VALUES (13232, 11625, 5);
INSERT INTO 'dancesstepsmap' VALUES (13233, 11626, 5);
INSERT INTO 'dancesstepsmap' VALUES (17459, 3045, 5);
INSERT INTO 'dancesstepsmap' VALUES (8650, 7493, 4);
INSERT INTO 'dancesstepsmap' VALUES (8651, 7494, 4);
INSERT INTO 'dancesstepsmap' VALUES (8652, 7496, 4);
INSERT INTO 'dancesstepsmap' VALUES (8653, 7498, 4);
INSERT INTO 'dancesstepsmap' VALUES (8654, 7500, 4);
INSERT INTO 'dancesstepsmap' VALUES (8655, 7501, 4);
INSERT INTO 'dancesstepsmap' VALUES (8656, 7502, 4);
INSERT INTO 'dancesstepsmap' VALUES (8657, 7503, 4);
INSERT INTO 'dancesstepsmap' VALUES (8658, 7506, 4);
INSERT INTO 'dancesstepsmap' VALUES (8659, 7513, 4);
INSERT INTO 'dancesstepsmap' VALUES (8660, 7517, 4);
INSERT INTO 'dancesstepsmap' VALUES (8661, 7518, 4);
INSERT INTO 'dancesstepsmap' VALUES (8662, 7520, 4);
INSERT INTO 'dancesstepsmap' VALUES (8663, 7528, 4);
INSERT INTO 'dancesstepsmap' VALUES (8664, 7534, 4);
INSERT INTO 'dancesstepsmap' VALUES (8665, 7535, 4);
INSERT INTO 'dancesstepsmap' VALUES (8666, 7540, 4);
INSERT INTO 'dancesstepsmap' VALUES (8668, 7560, 4);
INSERT INTO 'dancesstepsmap' VALUES (8669, 7568, 4);
INSERT INTO 'dancesstepsmap' VALUES (8670, 7573, 4);
INSERT INTO 'dancesstepsmap' VALUES (8671, 7577, 4);
INSERT INTO 'dancesstepsmap' VALUES (8672, 485, 4);
INSERT INTO 'dancesstepsmap' VALUES (8673, 3244, 4);
INSERT INTO 'dancesstepsmap' VALUES (8674, 3996, 4);
INSERT INTO 'dancesstepsmap' VALUES (8675, 4255, 4);
INSERT INTO 'dancesstepsmap' VALUES (8676, 4859, 4);
INSERT INTO 'dancesstepsmap' VALUES (8677, 7681, 4);
INSERT INTO 'dancesstepsmap' VALUES (8678, 7691, 4);
INSERT INTO 'dancesstepsmap' VALUES (8679, 7694, 4);
INSERT INTO 'dancesstepsmap' VALUES (8680, 7696, 4);
INSERT INTO 'dancesstepsmap' VALUES (8681, 7697, 4);
INSERT INTO 'dancesstepsmap' VALUES (8682, 7701, 4);
INSERT INTO 'dancesstepsmap' VALUES (8683, 7705, 4);
INSERT INTO 'dancesstepsmap' VALUES (8684, 7711, 4);
INSERT INTO 'dancesstepsmap' VALUES (8685, 7713, 4);
INSERT INTO 'dancesstepsmap' VALUES (8686, 7715, 4);
INSERT INTO 'dancesstepsmap' VALUES (8687, 2359, 4);
INSERT INTO 'dancesstepsmap' VALUES (8688, 7674, 4);
INSERT INTO 'dancesstepsmap' VALUES (8689, 7717, 4);
INSERT INTO 'dancesstepsmap' VALUES (8690, 7718, 4);
INSERT INTO 'dancesstepsmap' VALUES (8691, 7724, 4);
INSERT INTO 'dancesstepsmap' VALUES (8692, 7726, 4);
INSERT INTO 'dancesstepsmap' VALUES (8693, 7729, 4);
INSERT INTO 'dancesstepsmap' VALUES (8694, 7732, 4);
INSERT INTO 'dancesstepsmap' VALUES (8695, 7733, 4);
INSERT INTO 'dancesstepsmap' VALUES (8696, 7734, 4);
INSERT INTO 'dancesstepsmap' VALUES (8697, 7740, 4);
INSERT INTO 'dancesstepsmap' VALUES (8698, 7743, 4);
INSERT INTO 'dancesstepsmap' VALUES (8699, 2261, 4);
INSERT INTO 'dancesstepsmap' VALUES (8700, 3903, 4);
INSERT INTO 'dancesstepsmap' VALUES (8701, 5361, 4);
INSERT INTO 'dancesstepsmap' VALUES (8702, 7745, 4);
INSERT INTO 'dancesstepsmap' VALUES (8703, 7746, 4);
INSERT INTO 'dancesstepsmap' VALUES (8704, 7749, 4);
INSERT INTO 'dancesstepsmap' VALUES (8705, 7751, 4);
INSERT INTO 'dancesstepsmap' VALUES (8706, 7755, 4);
INSERT INTO 'dancesstepsmap' VALUES (8707, 7759, 4);
INSERT INTO 'dancesstepsmap' VALUES (8708, 7765, 4);
INSERT INTO 'dancesstepsmap' VALUES (8709, 5371, 4);
INSERT INTO 'dancesstepsmap' VALUES (8710, 7431, 4);
INSERT INTO 'dancesstepsmap' VALUES (8711, 7772, 4);
INSERT INTO 'dancesstepsmap' VALUES (8712, 7775, 4);
INSERT INTO 'dancesstepsmap' VALUES (8713, 7778, 4);
INSERT INTO 'dancesstepsmap' VALUES (8714, 7780, 4);
INSERT INTO 'dancesstepsmap' VALUES (8715, 7783, 4);
INSERT INTO 'dancesstepsmap' VALUES (8716, 7789, 4);
INSERT INTO 'dancesstepsmap' VALUES (8717, 7790, 4);
INSERT INTO 'dancesstepsmap' VALUES (8718, 7796, 4);
INSERT INTO 'dancesstepsmap' VALUES (8719, 7803, 4);
INSERT INTO 'dancesstepsmap' VALUES (8720, 7806, 4);
INSERT INTO 'dancesstepsmap' VALUES (8721, 7807, 4);
INSERT INTO 'dancesstepsmap' VALUES (8722, 7808, 4);
INSERT INTO 'dancesstepsmap' VALUES (8723, 7812, 4);
INSERT INTO 'dancesstepsmap' VALUES (8724, 7813, 4);
INSERT INTO 'dancesstepsmap' VALUES (8725, 7815, 4);
INSERT INTO 'dancesstepsmap' VALUES (8726, 7816, 4);
INSERT INTO 'dancesstepsmap' VALUES (8727, 7256, 4);
INSERT INTO 'dancesstepsmap' VALUES (8728, 7833, 4);
INSERT INTO 'dancesstepsmap' VALUES (8729, 7835, 4);
INSERT INTO 'dancesstepsmap' VALUES (8730, 7839, 4);
INSERT INTO 'dancesstepsmap' VALUES (8731, 7841, 4);
INSERT INTO 'dancesstepsmap' VALUES (8732, 7842, 4);
INSERT INTO 'dancesstepsmap' VALUES (8733, 7845, 4);
INSERT INTO 'dancesstepsmap' VALUES (8734, 7848, 4);
INSERT INTO 'dancesstepsmap' VALUES (8735, 7849, 4);
INSERT INTO 'dancesstepsmap' VALUES (8736, 7853, 4);
INSERT INTO 'dancesstepsmap' VALUES (8737, 7854, 4);
INSERT INTO 'dancesstepsmap' VALUES (8738, 7855, 4);
INSERT INTO 'dancesstepsmap' VALUES (8739, 7860, 4);
INSERT INTO 'dancesstepsmap' VALUES (8740, 7861, 4);
INSERT INTO 'dancesstepsmap' VALUES (8741, 7862, 4);
INSERT INTO 'dancesstepsmap' VALUES (8742, 4117, 4);
INSERT INTO 'dancesstepsmap' VALUES (13234, 11626, 4);
INSERT INTO 'dancesstepsmap' VALUES (13235, 11626, 1);
INSERT INTO 'dancesstepsmap' VALUES (13236, 11626, 2);
INSERT INTO 'dancesstepsmap' VALUES (13237, 556, 2);
INSERT INTO 'dancesstepsmap' VALUES (13238, 3561, 2);
INSERT INTO 'dancesstepsmap' VALUES (13239, 11627, 4);
INSERT INTO 'dancesstepsmap' VALUES (13240, 11628, 1);
INSERT INTO 'dancesstepsmap' VALUES (13241, 11628, 3);
INSERT INTO 'dancesstepsmap' VALUES (13242, 11366, 2);
INSERT INTO 'dancesstepsmap' VALUES (13243, 4853, 5);
INSERT INTO 'dancesstepsmap' VALUES (13244, 1560, 5);
INSERT INTO 'dancesstepsmap' VALUES (13245, 11662, 4);
INSERT INTO 'dancesstepsmap' VALUES (13246, 11663, 1);
INSERT INTO 'dancesstepsmap' VALUES (13247, 11663, 2);
INSERT INTO 'dancesstepsmap' VALUES (13248, 11664, 6);
INSERT INTO 'dancesstepsmap' VALUES (13249, 11664, 4);
INSERT INTO 'dancesstepsmap' VALUES (13250, 11665, 1);
INSERT INTO 'dancesstepsmap' VALUES (13251, 11665, 2);
INSERT INTO 'dancesstepsmap' VALUES (13252, 11666, 1);
INSERT INTO 'dancesstepsmap' VALUES (13253, 11666, 2);
INSERT INTO 'dancesstepsmap' VALUES (13254, 11666, 3);
INSERT INTO 'dancesstepsmap' VALUES (13255, 11667, 1);
INSERT INTO 'dancesstepsmap' VALUES (13256, 11667, 2);
INSERT INTO 'dancesstepsmap' VALUES (13257, 11668, 3);
INSERT INTO 'dancesstepsmap' VALUES (13258, 11668, 1);
INSERT INTO 'dancesstepsmap' VALUES (13259, 11668, 2);
INSERT INTO 'dancesstepsmap' VALUES (13260, 11669, 1);
INSERT INTO 'dancesstepsmap' VALUES (13261, 10599, 1);
INSERT INTO 'dancesstepsmap' VALUES (13262, 10599, 2);
INSERT INTO 'dancesstepsmap' VALUES (13263, 11670, 2);
INSERT INTO 'dancesstepsmap' VALUES (13264, 11670, 1);
INSERT INTO 'dancesstepsmap' VALUES (13265, 11671, 4);
INSERT INTO 'dancesstepsmap' VALUES (13266, 11672, 1);
INSERT INTO 'dancesstepsmap' VALUES (13267, 11672, 2);
INSERT INTO 'dancesstepsmap' VALUES (13268, 11673, 1);
INSERT INTO 'dancesstepsmap' VALUES (13269, 11673, 2);
INSERT INTO 'dancesstepsmap' VALUES (13270, 11674, 1);
INSERT INTO 'dancesstepsmap' VALUES (13271, 11675, 4);
INSERT INTO 'dancesstepsmap' VALUES (13272, 11676, 1);
INSERT INTO 'dancesstepsmap' VALUES (13273, 11676, 2);
INSERT INTO 'dancesstepsmap' VALUES (13274, 11677, 2);
INSERT INTO 'dancesstepsmap' VALUES (13275, 11677, 1);
INSERT INTO 'dancesstepsmap' VALUES (17460, 14346, 4);
INSERT INTO 'dancesstepsmap' VALUES (17461, 14346, 5);
INSERT INTO 'dancesstepsmap' VALUES (17462, 14715, 1);
INSERT INTO 'dancesstepsmap' VALUES (17467, 14718, 4);
INSERT INTO 'dancesstepsmap' VALUES (17468, 14718, 5);
INSERT INTO 'dancesstepsmap' VALUES (8743, 6493, 4);
INSERT INTO 'dancesstepsmap' VALUES (8744, 6678, 4);
INSERT INTO 'dancesstepsmap' VALUES (8745, 7864, 4);
INSERT INTO 'dancesstepsmap' VALUES (8746, 7867, 4);
INSERT INTO 'dancesstepsmap' VALUES (8747, 7868, 4);
INSERT INTO 'dancesstepsmap' VALUES (8748, 7869, 4);
INSERT INTO 'dancesstepsmap' VALUES (8749, 7876, 4);
INSERT INTO 'dancesstepsmap' VALUES (8750, 7877, 4);
INSERT INTO 'dancesstepsmap' VALUES (8751, 7883, 4);
INSERT INTO 'dancesstepsmap' VALUES (8752, 7884, 4);
INSERT INTO 'dancesstepsmap' VALUES (8753, 7885, 4);
INSERT INTO 'dancesstepsmap' VALUES (8754, 7886, 4);
INSERT INTO 'dancesstepsmap' VALUES (8755, 7889, 4);
INSERT INTO 'dancesstepsmap' VALUES (8756, 7893, 4);
INSERT INTO 'dancesstepsmap' VALUES (8757, 7895, 4);
INSERT INTO 'dancesstepsmap' VALUES (8758, 7897, 4);
INSERT INTO 'dancesstepsmap' VALUES (8759, 131, 4);
INSERT INTO 'dancesstepsmap' VALUES (8760, 7898, 4);
INSERT INTO 'dancesstepsmap' VALUES (8761, 7900, 4);
INSERT INTO 'dancesstepsmap' VALUES (8762, 7904, 4);
INSERT INTO 'dancesstepsmap' VALUES (8763, 7905, 4);
INSERT INTO 'dancesstepsmap' VALUES (8764, 7910, 4);
INSERT INTO 'dancesstepsmap' VALUES (8765, 7912, 4);
INSERT INTO 'dancesstepsmap' VALUES (8766, 7916, 4);
INSERT INTO 'dancesstepsmap' VALUES (8767, 7922, 4);
INSERT INTO 'dancesstepsmap' VALUES (8768, 7927, 4);
INSERT INTO 'dancesstepsmap' VALUES (8769, 7931, 4);
INSERT INTO 'dancesstepsmap' VALUES (8770, 7932, 4);
INSERT INTO 'dancesstepsmap' VALUES (8771, 7939, 4);
INSERT INTO 'dancesstepsmap' VALUES (8772, 7940, 4);
INSERT INTO 'dancesstepsmap' VALUES (8773, 7942, 4);
INSERT INTO 'dancesstepsmap' VALUES (8774, 2142, 4);
INSERT INTO 'dancesstepsmap' VALUES (8775, 5823, 4);
INSERT INTO 'dancesstepsmap' VALUES (8776, 5949, 4);
INSERT INTO 'dancesstepsmap' VALUES (8777, 7944, 4);
INSERT INTO 'dancesstepsmap' VALUES (8778, 7945, 4);
INSERT INTO 'dancesstepsmap' VALUES (8779, 7949, 4);
INSERT INTO 'dancesstepsmap' VALUES (8780, 7957, 4);
INSERT INTO 'dancesstepsmap' VALUES (8781, 7958, 4);
INSERT INTO 'dancesstepsmap' VALUES (8782, 7960, 4);
INSERT INTO 'dancesstepsmap' VALUES (8783, 7962, 4);
INSERT INTO 'dancesstepsmap' VALUES (8784, 791, 4);
INSERT INTO 'dancesstepsmap' VALUES (8785, 7968, 4);
INSERT INTO 'dancesstepsmap' VALUES (8786, 7970, 4);
INSERT INTO 'dancesstepsmap' VALUES (8787, 7974, 4);
INSERT INTO 'dancesstepsmap' VALUES (8788, 7975, 4);
INSERT INTO 'dancesstepsmap' VALUES (8789, 7979, 4);
INSERT INTO 'dancesstepsmap' VALUES (8790, 7980, 4);
INSERT INTO 'dancesstepsmap' VALUES (8791, 7981, 4);
INSERT INTO 'dancesstepsmap' VALUES (8792, 7982, 4);
INSERT INTO 'dancesstepsmap' VALUES (8793, 7986, 4);
INSERT INTO 'dancesstepsmap' VALUES (8794, 7988, 4);
INSERT INTO 'dancesstepsmap' VALUES (8795, 7990, 4);
INSERT INTO 'dancesstepsmap' VALUES (8796, 7996, 4);
INSERT INTO 'dancesstepsmap' VALUES (8797, 7998, 4);
INSERT INTO 'dancesstepsmap' VALUES (8798, 8002, 4);
INSERT INTO 'dancesstepsmap' VALUES (8799, 8003, 4);
INSERT INTO 'dancesstepsmap' VALUES (8800, 8004, 4);
INSERT INTO 'dancesstepsmap' VALUES (8801, 858, 4);
INSERT INTO 'dancesstepsmap' VALUES (8802, 1123, 4);
INSERT INTO 'dancesstepsmap' VALUES (8803, 6779, 4);
INSERT INTO 'dancesstepsmap' VALUES (8804, 8012, 4);
INSERT INTO 'dancesstepsmap' VALUES (8805, 8016, 4);
INSERT INTO 'dancesstepsmap' VALUES (8806, 8018, 4);
INSERT INTO 'dancesstepsmap' VALUES (8807, 8022, 4);
INSERT INTO 'dancesstepsmap' VALUES (8808, 8029, 4);
INSERT INTO 'dancesstepsmap' VALUES (8809, 8030, 4);
INSERT INTO 'dancesstepsmap' VALUES (8810, 8031, 4);
INSERT INTO 'dancesstepsmap' VALUES (8811, 8034, 4);
INSERT INTO 'dancesstepsmap' VALUES (8812, 8035, 4);
INSERT INTO 'dancesstepsmap' VALUES (8813, 8047, 4);
INSERT INTO 'dancesstepsmap' VALUES (8814, 8055, 4);
INSERT INTO 'dancesstepsmap' VALUES (8815, 8064, 4);
INSERT INTO 'dancesstepsmap' VALUES (8816, 8066, 4);
INSERT INTO 'dancesstepsmap' VALUES (8817, 8068, 4);
INSERT INTO 'dancesstepsmap' VALUES (8818, 8083, 4);
INSERT INTO 'dancesstepsmap' VALUES (8819, 8094, 4);
INSERT INTO 'dancesstepsmap' VALUES (8820, 8100, 4);
INSERT INTO 'dancesstepsmap' VALUES (8821, 8101, 4);
INSERT INTO 'dancesstepsmap' VALUES (8822, 2227, 4);
INSERT INTO 'dancesstepsmap' VALUES (8823, 3716, 4);
INSERT INTO 'dancesstepsmap' VALUES (8824, 8115, 4);
INSERT INTO 'dancesstepsmap' VALUES (8825, 8118, 4);
INSERT INTO 'dancesstepsmap' VALUES (8826, 8120, 4);
INSERT INTO 'dancesstepsmap' VALUES (8827, 8128, 4);
INSERT INTO 'dancesstepsmap' VALUES (8828, 8131, 4);
INSERT INTO 'dancesstepsmap' VALUES (8829, 8137, 4);
INSERT INTO 'dancesstepsmap' VALUES (8830, 8138, 4);
INSERT INTO 'dancesstepsmap' VALUES (8832, 8175, 4);
INSERT INTO 'dancesstepsmap' VALUES (8833, 8177, 4);
INSERT INTO 'dancesstepsmap' VALUES (8834, 8181, 4);
INSERT INTO 'dancesstepsmap' VALUES (8835, 8196, 4);
INSERT INTO 'dancesstepsmap' VALUES (13276, 11678, 1);
INSERT INTO 'dancesstepsmap' VALUES (13277, 11679, 1);
INSERT INTO 'dancesstepsmap' VALUES (13278, 11679, 2);
INSERT INTO 'dancesstepsmap' VALUES (13279, 11680, 2);
INSERT INTO 'dancesstepsmap' VALUES (13280, 11680, 1);
INSERT INTO 'dancesstepsmap' VALUES (13281, 11681, 2);
INSERT INTO 'dancesstepsmap' VALUES (13282, 11681, 1);
INSERT INTO 'dancesstepsmap' VALUES (13283, 11681, 3);
INSERT INTO 'dancesstepsmap' VALUES (13284, 8961, 2);
INSERT INTO 'dancesstepsmap' VALUES (13285, 4215, 2);
INSERT INTO 'dancesstepsmap' VALUES (13286, 10566, 5);
INSERT INTO 'dancesstepsmap' VALUES (13287, 9944, 5);
INSERT INTO 'dancesstepsmap' VALUES (13288, 11682, 2);
INSERT INTO 'dancesstepsmap' VALUES (13289, 11682, 1);
INSERT INTO 'dancesstepsmap' VALUES (13290, 11683, 1);
INSERT INTO 'dancesstepsmap' VALUES (13291, 11683, 2);
INSERT INTO 'dancesstepsmap' VALUES (13292, 11684, 2);
INSERT INTO 'dancesstepsmap' VALUES (13293, 11684, 1);
INSERT INTO 'dancesstepsmap' VALUES (13294, 11685, 5);
INSERT INTO 'dancesstepsmap' VALUES (13295, 11685, 4);
INSERT INTO 'dancesstepsmap' VALUES (13296, 11686, 4);
INSERT INTO 'dancesstepsmap' VALUES (13297, 11686, 5);
INSERT INTO 'dancesstepsmap' VALUES (13300, 11688, 5);
INSERT INTO 'dancesstepsmap' VALUES (13301, 11688, 4);
INSERT INTO 'dancesstepsmap' VALUES (13302, 11689, 4);
INSERT INTO 'dancesstepsmap' VALUES (13303, 11690, 1);
INSERT INTO 'dancesstepsmap' VALUES (13304, 11691, 1);
INSERT INTO 'dancesstepsmap' VALUES (13305, 11691, 2);
INSERT INTO 'dancesstepsmap' VALUES (13306, 11692, 4);
INSERT INTO 'dancesstepsmap' VALUES (13307, 11693, 2);
INSERT INTO 'dancesstepsmap' VALUES (13308, 11693, 1);
INSERT INTO 'dancesstepsmap' VALUES (13309, 11694, 1);
INSERT INTO 'dancesstepsmap' VALUES (13310, 11694, 2);
INSERT INTO 'dancesstepsmap' VALUES (13311, 11694, 3);
INSERT INTO 'dancesstepsmap' VALUES (13312, 11695, 5);
INSERT INTO 'dancesstepsmap' VALUES (13315, 11697, 1);
INSERT INTO 'dancesstepsmap' VALUES (13316, 11698, 2);
INSERT INTO 'dancesstepsmap' VALUES (13317, 11698, 1);
INSERT INTO 'dancesstepsmap' VALUES (17463, 14716, 2);
INSERT INTO 'dancesstepsmap' VALUES (17464, 14716, 1);
INSERT INTO 'dancesstepsmap' VALUES (17465, 14716, 3);
INSERT INTO 'dancesstepsmap' VALUES (8836, 8201, 4);
INSERT INTO 'dancesstepsmap' VALUES (8837, 8212, 4);
INSERT INTO 'dancesstepsmap' VALUES (8838, 8213, 4);
INSERT INTO 'dancesstepsmap' VALUES (8839, 8215, 4);
INSERT INTO 'dancesstepsmap' VALUES (8840, 8217, 4);
INSERT INTO 'dancesstepsmap' VALUES (8841, 8219, 4);
INSERT INTO 'dancesstepsmap' VALUES (8842, 8223, 4);
INSERT INTO 'dancesstepsmap' VALUES (8843, 8224, 4);
INSERT INTO 'dancesstepsmap' VALUES (8844, 8228, 4);
INSERT INTO 'dancesstepsmap' VALUES (8845, 8229, 4);
INSERT INTO 'dancesstepsmap' VALUES (8846, 8240, 4);
INSERT INTO 'dancesstepsmap' VALUES (8847, 8243, 4);
INSERT INTO 'dancesstepsmap' VALUES (8848, 8244, 4);
INSERT INTO 'dancesstepsmap' VALUES (8849, 8254, 4);
INSERT INTO 'dancesstepsmap' VALUES (8850, 8255, 4);
INSERT INTO 'dancesstepsmap' VALUES (8851, 8261, 4);
INSERT INTO 'dancesstepsmap' VALUES (8852, 8264, 4);
INSERT INTO 'dancesstepsmap' VALUES (8853, 8266, 4);
INSERT INTO 'dancesstepsmap' VALUES (8854, 8269, 4);
INSERT INTO 'dancesstepsmap' VALUES (8855, 8271, 4);
INSERT INTO 'dancesstepsmap' VALUES (8856, 8272, 4);
INSERT INTO 'dancesstepsmap' VALUES (8857, 8275, 4);
INSERT INTO 'dancesstepsmap' VALUES (8858, 8278, 4);
INSERT INTO 'dancesstepsmap' VALUES (8859, 8279, 4);
INSERT INTO 'dancesstepsmap' VALUES (8860, 8283, 4);
INSERT INTO 'dancesstepsmap' VALUES (8861, 8284, 4);
INSERT INTO 'dancesstepsmap' VALUES (8862, 8286, 4);
INSERT INTO 'dancesstepsmap' VALUES (8863, 8287, 4);
INSERT INTO 'dancesstepsmap' VALUES (8864, 8296, 4);
INSERT INTO 'dancesstepsmap' VALUES (8865, 8300, 4);
INSERT INTO 'dancesstepsmap' VALUES (8866, 8302, 4);
INSERT INTO 'dancesstepsmap' VALUES (8867, 8306, 4);
INSERT INTO 'dancesstepsmap' VALUES (8868, 8310, 4);
INSERT INTO 'dancesstepsmap' VALUES (8869, 8312, 4);
INSERT INTO 'dancesstepsmap' VALUES (8870, 8314, 4);
INSERT INTO 'dancesstepsmap' VALUES (8871, 8316, 4);
INSERT INTO 'dancesstepsmap' VALUES (8872, 8317, 4);
INSERT INTO 'dancesstepsmap' VALUES (8873, 8318, 4);
INSERT INTO 'dancesstepsmap' VALUES (8874, 8319, 4);
INSERT INTO 'dancesstepsmap' VALUES (8875, 8320, 4);
INSERT INTO 'dancesstepsmap' VALUES (8876, 8321, 4);
INSERT INTO 'dancesstepsmap' VALUES (8877, 8326, 4);
INSERT INTO 'dancesstepsmap' VALUES (8878, 8333, 4);
INSERT INTO 'dancesstepsmap' VALUES (8879, 8337, 4);
INSERT INTO 'dancesstepsmap' VALUES (8880, 8342, 4);
INSERT INTO 'dancesstepsmap' VALUES (8881, 8350, 4);
INSERT INTO 'dancesstepsmap' VALUES (8882, 8352, 4);
INSERT INTO 'dancesstepsmap' VALUES (8883, 8355, 4);
INSERT INTO 'dancesstepsmap' VALUES (8884, 8357, 4);
INSERT INTO 'dancesstepsmap' VALUES (8885, 8358, 4);
INSERT INTO 'dancesstepsmap' VALUES (8886, 8361, 4);
INSERT INTO 'dancesstepsmap' VALUES (8887, 8362, 4);
INSERT INTO 'dancesstepsmap' VALUES (8888, 8367, 4);
INSERT INTO 'dancesstepsmap' VALUES (8889, 8369, 4);
INSERT INTO 'dancesstepsmap' VALUES (8890, 8372, 4);
INSERT INTO 'dancesstepsmap' VALUES (8891, 8382, 4);
INSERT INTO 'dancesstepsmap' VALUES (8892, 8385, 4);
INSERT INTO 'dancesstepsmap' VALUES (8893, 8390, 4);
INSERT INTO 'dancesstepsmap' VALUES (8894, 8392, 4);
INSERT INTO 'dancesstepsmap' VALUES (8895, 8395, 4);
INSERT INTO 'dancesstepsmap' VALUES (8896, 8398, 4);
INSERT INTO 'dancesstepsmap' VALUES (8897, 8412, 4);
INSERT INTO 'dancesstepsmap' VALUES (8898, 8420, 4);
INSERT INTO 'dancesstepsmap' VALUES (8899, 8421, 4);
INSERT INTO 'dancesstepsmap' VALUES (8900, 8424, 4);
INSERT INTO 'dancesstepsmap' VALUES (8901, 8429, 4);
INSERT INTO 'dancesstepsmap' VALUES (8902, 8432, 4);
INSERT INTO 'dancesstepsmap' VALUES (8903, 8434, 4);
INSERT INTO 'dancesstepsmap' VALUES (8904, 8439, 4);
INSERT INTO 'dancesstepsmap' VALUES (8905, 8440, 4);
INSERT INTO 'dancesstepsmap' VALUES (8906, 8441, 4);
INSERT INTO 'dancesstepsmap' VALUES (8907, 8442, 4);
INSERT INTO 'dancesstepsmap' VALUES (8908, 8445, 4);
INSERT INTO 'dancesstepsmap' VALUES (8909, 8446, 4);
INSERT INTO 'dancesstepsmap' VALUES (8910, 8450, 4);
INSERT INTO 'dancesstepsmap' VALUES (8911, 8456, 4);
INSERT INTO 'dancesstepsmap' VALUES (8912, 8457, 4);
INSERT INTO 'dancesstepsmap' VALUES (8913, 8458, 4);
INSERT INTO 'dancesstepsmap' VALUES (8914, 8459, 4);
INSERT INTO 'dancesstepsmap' VALUES (8915, 626, 4);
INSERT INTO 'dancesstepsmap' VALUES (8916, 8354, 4);
INSERT INTO 'dancesstepsmap' VALUES (8917, 8463, 4);
INSERT INTO 'dancesstepsmap' VALUES (8918, 8471, 4);
INSERT INTO 'dancesstepsmap' VALUES (8919, 8472, 4);
INSERT INTO 'dancesstepsmap' VALUES (8920, 8474, 4);
INSERT INTO 'dancesstepsmap' VALUES (8921, 8475, 4);
INSERT INTO 'dancesstepsmap' VALUES (13298, 11687, 1);
INSERT INTO 'dancesstepsmap' VALUES (8923, 8482, 4);
INSERT INTO 'dancesstepsmap' VALUES (8924, 8488, 4);
INSERT INTO 'dancesstepsmap' VALUES (8925, 8492, 4);
INSERT INTO 'dancesstepsmap' VALUES (8926, 8493, 4);
INSERT INTO 'dancesstepsmap' VALUES (8927, 8495, 4);
INSERT INTO 'dancesstepsmap' VALUES (8928, 8497, 4);
INSERT INTO 'dancesstepsmap' VALUES (13318, 11698, 3);
INSERT INTO 'dancesstepsmap' VALUES (13319, 11699, 4);
INSERT INTO 'dancesstepsmap' VALUES (13320, 11699, 5);
INSERT INTO 'dancesstepsmap' VALUES (13321, 11700, 1);
INSERT INTO 'dancesstepsmap' VALUES (13322, 11700, 3);
INSERT INTO 'dancesstepsmap' VALUES (13323, 11701, 4);
INSERT INTO 'dancesstepsmap' VALUES (13324, 11701, 5);
INSERT INTO 'dancesstepsmap' VALUES (13327, 11703, 1);
INSERT INTO 'dancesstepsmap' VALUES (13328, 8467, 3);
INSERT INTO 'dancesstepsmap' VALUES (13329, 8462, 3);
INSERT INTO 'dancesstepsmap' VALUES (13330, 8464, 3);
INSERT INTO 'dancesstepsmap' VALUES (13331, 8465, 3);
INSERT INTO 'dancesstepsmap' VALUES (13332, 4435, 3);
INSERT INTO 'dancesstepsmap' VALUES (13333, 8461, 3);
INSERT INTO 'dancesstepsmap' VALUES (13334, 4403, 3);
INSERT INTO 'dancesstepsmap' VALUES (13335, 8474, 5);
INSERT INTO 'dancesstepsmap' VALUES (13336, 8478, 3);
INSERT INTO 'dancesstepsmap' VALUES (13337, 8470, 2);
INSERT INTO 'dancesstepsmap' VALUES (13338, 8473, 2);
INSERT INTO 'dancesstepsmap' VALUES (13339, 8473, 3);
INSERT INTO 'dancesstepsmap' VALUES (13340, 8476, 2);
INSERT INTO 'dancesstepsmap' VALUES (13341, 8469, 3);
INSERT INTO 'dancesstepsmap' VALUES (13342, 8471, 5);
INSERT INTO 'dancesstepsmap' VALUES (13344, 8486, 3);
INSERT INTO 'dancesstepsmap' VALUES (13345, 8479, 3);
INSERT INTO 'dancesstepsmap' VALUES (13346, 8479, 2);
INSERT INTO 'dancesstepsmap' VALUES (13347, 8487, 2);
INSERT INTO 'dancesstepsmap' VALUES (13348, 8481, 3);
INSERT INTO 'dancesstepsmap' VALUES (13349, 8481, 2);
INSERT INTO 'dancesstepsmap' VALUES (13350, 8483, 2);
INSERT INTO 'dancesstepsmap' VALUES (13351, 8483, 3);
INSERT INTO 'dancesstepsmap' VALUES (13352, 8485, 2);
INSERT INTO 'dancesstepsmap' VALUES (13353, 8488, 5);
INSERT INTO 'dancesstepsmap' VALUES (13354, 11610, 2);
INSERT INTO 'dancesstepsmap' VALUES (13355, 11612, 5);
INSERT INTO 'dancesstepsmap' VALUES (13356, 11704, 1);
INSERT INTO 'dancesstepsmap' VALUES (13357, 11704, 2);
INSERT INTO 'dancesstepsmap' VALUES (13358, 11706, 1);
INSERT INTO 'dancesstepsmap' VALUES (13359, 11706, 3);
INSERT INTO 'dancesstepsmap' VALUES (17466, 14717, 1);
INSERT INTO 'dancesstepsmap' VALUES (8929, 8548, 4);
INSERT INTO 'dancesstepsmap' VALUES (8930, 8551, 4);
INSERT INTO 'dancesstepsmap' VALUES (8931, 8553, 4);
INSERT INTO 'dancesstepsmap' VALUES (8932, 8562, 4);
INSERT INTO 'dancesstepsmap' VALUES (8933, 8566, 4);
INSERT INTO 'dancesstepsmap' VALUES (8934, 8571, 4);
INSERT INTO 'dancesstepsmap' VALUES (8935, 8576, 4);
INSERT INTO 'dancesstepsmap' VALUES (8937, 8581, 4);
INSERT INTO 'dancesstepsmap' VALUES (8938, 8379, 4);
INSERT INTO 'dancesstepsmap' VALUES (8939, 8567, 4);
INSERT INTO 'dancesstepsmap' VALUES (8940, 136, 2);
INSERT INTO 'dancesstepsmap' VALUES (8941, 507, 2);
INSERT INTO 'dancesstepsmap' VALUES (8942, 632, 2);
INSERT INTO 'dancesstepsmap' VALUES (8943, 702, 2);
INSERT INTO 'dancesstepsmap' VALUES (8944, 1024, 2);
INSERT INTO 'dancesstepsmap' VALUES (8945, 1052, 2);
INSERT INTO 'dancesstepsmap' VALUES (8946, 1150, 2);
INSERT INTO 'dancesstepsmap' VALUES (8947, 1277, 2);
INSERT INTO 'dancesstepsmap' VALUES (8948, 1552, 2);
INSERT INTO 'dancesstepsmap' VALUES (8949, 1598, 2);
INSERT INTO 'dancesstepsmap' VALUES (8950, 1712, 2);
INSERT INTO 'dancesstepsmap' VALUES (13343, 8468, 1);
INSERT INTO 'dancesstepsmap' VALUES (8922, 8477, 1);
INSERT INTO 'dancesstepsmap' VALUES (8951, 1824, 2);
INSERT INTO 'dancesstepsmap' VALUES (8952, 1961, 2);
INSERT INTO 'dancesstepsmap' VALUES (8953, 1989, 2);
INSERT INTO 'dancesstepsmap' VALUES (8954, 2015, 2);
INSERT INTO 'dancesstepsmap' VALUES (8955, 2053, 2);
INSERT INTO 'dancesstepsmap' VALUES (8956, 2257, 2);
INSERT INTO 'dancesstepsmap' VALUES (8957, 2283, 2);
INSERT INTO 'dancesstepsmap' VALUES (8958, 2693, 2);
INSERT INTO 'dancesstepsmap' VALUES (8959, 2736, 2);
INSERT INTO 'dancesstepsmap' VALUES (8960, 2768, 2);
INSERT INTO 'dancesstepsmap' VALUES (8961, 2879, 2);
INSERT INTO 'dancesstepsmap' VALUES (8962, 2970, 2);
INSERT INTO 'dancesstepsmap' VALUES (8963, 3061, 2);
INSERT INTO 'dancesstepsmap' VALUES (8964, 3144, 2);
INSERT INTO 'dancesstepsmap' VALUES (8965, 3342, 2);
INSERT INTO 'dancesstepsmap' VALUES (8966, 3381, 2);
INSERT INTO 'dancesstepsmap' VALUES (8967, 3580, 2);
INSERT INTO 'dancesstepsmap' VALUES (8968, 3715, 2);
INSERT INTO 'dancesstepsmap' VALUES (8969, 3740, 2);
INSERT INTO 'dancesstepsmap' VALUES (8970, 3774, 2);
INSERT INTO 'dancesstepsmap' VALUES (8971, 3800, 2);
INSERT INTO 'dancesstepsmap' VALUES (8972, 3914, 2);
INSERT INTO 'dancesstepsmap' VALUES (8973, 3953, 2);
INSERT INTO 'dancesstepsmap' VALUES (8974, 4144, 2);
INSERT INTO 'dancesstepsmap' VALUES (8975, 4334, 2);
INSERT INTO 'dancesstepsmap' VALUES (8976, 4376, 2);
INSERT INTO 'dancesstepsmap' VALUES (8977, 4695, 2);
INSERT INTO 'dancesstepsmap' VALUES (8978, 4827, 2);
INSERT INTO 'dancesstepsmap' VALUES (8979, 4982, 2);
INSERT INTO 'dancesstepsmap' VALUES (8980, 5033, 2);
INSERT INTO 'dancesstepsmap' VALUES (8981, 5115, 2);
INSERT INTO 'dancesstepsmap' VALUES (8982, 5153, 2);
INSERT INTO 'dancesstepsmap' VALUES (8983, 5208, 2);
INSERT INTO 'dancesstepsmap' VALUES (8984, 5236, 2);
INSERT INTO 'dancesstepsmap' VALUES (8985, 5457, 2);
INSERT INTO 'dancesstepsmap' VALUES (8986, 5498, 2);
INSERT INTO 'dancesstepsmap' VALUES (8987, 5591, 2);
INSERT INTO 'dancesstepsmap' VALUES (8988, 5754, 2);
INSERT INTO 'dancesstepsmap' VALUES (8989, 5759, 2);
INSERT INTO 'dancesstepsmap' VALUES (8990, 5807, 2);
INSERT INTO 'dancesstepsmap' VALUES (8991, 5864, 2);
INSERT INTO 'dancesstepsmap' VALUES (8992, 5939, 2);
INSERT INTO 'dancesstepsmap' VALUES (8993, 5981, 2);
INSERT INTO 'dancesstepsmap' VALUES (8994, 6061, 2);
INSERT INTO 'dancesstepsmap' VALUES (8995, 6272, 2);
INSERT INTO 'dancesstepsmap' VALUES (8996, 6295, 2);
INSERT INTO 'dancesstepsmap' VALUES (8997, 6471, 2);
INSERT INTO 'dancesstepsmap' VALUES (8998, 6489, 2);
INSERT INTO 'dancesstepsmap' VALUES (8999, 6601, 2);
INSERT INTO 'dancesstepsmap' VALUES (9000, 6646, 2);
INSERT INTO 'dancesstepsmap' VALUES (9001, 6677, 2);
INSERT INTO 'dancesstepsmap' VALUES (9002, 6734, 2);
INSERT INTO 'dancesstepsmap' VALUES (9003, 6777, 2);
INSERT INTO 'dancesstepsmap' VALUES (9004, 6867, 2);
INSERT INTO 'dancesstepsmap' VALUES (9005, 6957, 2);
INSERT INTO 'dancesstepsmap' VALUES (9006, 7101, 2);
INSERT INTO 'dancesstepsmap' VALUES (9007, 7181, 2);
INSERT INTO 'dancesstepsmap' VALUES (9008, 7219, 2);
INSERT INTO 'dancesstepsmap' VALUES (9009, 7236, 2);
INSERT INTO 'dancesstepsmap' VALUES (9010, 7429, 2);
INSERT INTO 'dancesstepsmap' VALUES (9011, 7541, 2);
INSERT INTO 'dancesstepsmap' VALUES (9012, 7964, 2);
INSERT INTO 'dancesstepsmap' VALUES (9013, 8384, 2);
INSERT INTO 'dancesstepsmap' VALUES (9014, 22, 2);
INSERT INTO 'dancesstepsmap' VALUES (9015, 116, 2);
INSERT INTO 'dancesstepsmap' VALUES (9016, 272, 2);
INSERT INTO 'dancesstepsmap' VALUES (9017, 398, 2);
INSERT INTO 'dancesstepsmap' VALUES (9018, 543, 2);
INSERT INTO 'dancesstepsmap' VALUES (9019, 959, 2);
INSERT INTO 'dancesstepsmap' VALUES (9020, 1369, 2);
INSERT INTO 'dancesstepsmap' VALUES (9021, 1373, 2);
INSERT INTO 'dancesstepsmap' VALUES (9022, 1467, 2);
INSERT INTO 'dancesstepsmap' VALUES (9023, 1593, 2);
INSERT INTO 'dancesstepsmap' VALUES (9024, 1895, 2);
INSERT INTO 'dancesstepsmap' VALUES (9025, 2267, 2);
INSERT INTO 'dancesstepsmap' VALUES (9026, 2573, 2);
INSERT INTO 'dancesstepsmap' VALUES (9027, 2784, 2);
INSERT INTO 'dancesstepsmap' VALUES (9028, 3010, 2);
INSERT INTO 'dancesstepsmap' VALUES (9029, 3064, 2);
INSERT INTO 'dancesstepsmap' VALUES (9030, 3647, 2);
INSERT INTO 'dancesstepsmap' VALUES (9031, 4173, 2);
INSERT INTO 'dancesstepsmap' VALUES (9032, 4760, 2);
INSERT INTO 'dancesstepsmap' VALUES (9033, 4790, 2);
INSERT INTO 'dancesstepsmap' VALUES (9034, 5155, 2);
INSERT INTO 'dancesstepsmap' VALUES (9035, 5937, 2);
INSERT INTO 'dancesstepsmap' VALUES (9036, 6010, 2);
INSERT INTO 'dancesstepsmap' VALUES (9037, 6420, 2);
INSERT INTO 'dancesstepsmap' VALUES (9038, 6514, 2);
INSERT INTO 'dancesstepsmap' VALUES (9039, 6558, 2);
INSERT INTO 'dancesstepsmap' VALUES (9040, 7532, 2);
INSERT INTO 'dancesstepsmap' VALUES (9041, 648, 2);
INSERT INTO 'dancesstepsmap' VALUES (9042, 660, 2);
INSERT INTO 'dancesstepsmap' VALUES (9043, 871, 2);
INSERT INTO 'dancesstepsmap' VALUES (9044, 1098, 2);
INSERT INTO 'dancesstepsmap' VALUES (9045, 1422, 2);
INSERT INTO 'dancesstepsmap' VALUES (9046, 1457, 2);
INSERT INTO 'dancesstepsmap' VALUES (9047, 1498, 2);
INSERT INTO 'dancesstepsmap' VALUES (9048, 2272, 2);
INSERT INTO 'dancesstepsmap' VALUES (9049, 2737, 2);
INSERT INTO 'dancesstepsmap' VALUES (9050, 2767, 2);
INSERT INTO 'dancesstepsmap' VALUES (9051, 2999, 2);
INSERT INTO 'dancesstepsmap' VALUES (9052, 3542, 2);
INSERT INTO 'dancesstepsmap' VALUES (9053, 3697, 2);
INSERT INTO 'dancesstepsmap' VALUES (9054, 3782, 2);
INSERT INTO 'dancesstepsmap' VALUES (9055, 3896, 2);
INSERT INTO 'dancesstepsmap' VALUES (9056, 4165, 2);
INSERT INTO 'dancesstepsmap' VALUES (9057, 4500, 2);
INSERT INTO 'dancesstepsmap' VALUES (9058, 5369, 2);
INSERT INTO 'dancesstepsmap' VALUES (13360, 11707, 4);
INSERT INTO 'dancesstepsmap' VALUES (13361, 11708, 3);
INSERT INTO 'dancesstepsmap' VALUES (13362, 11708, 2);
INSERT INTO 'dancesstepsmap' VALUES (13363, 11708, 1);
INSERT INTO 'dancesstepsmap' VALUES (13364, 11709, 3);
INSERT INTO 'dancesstepsmap' VALUES (13365, 11709, 1);
INSERT INTO 'dancesstepsmap' VALUES (13367, 11710, 4);
INSERT INTO 'dancesstepsmap' VALUES (13368, 11711, 5);
INSERT INTO 'dancesstepsmap' VALUES (13369, 11711, 4);
INSERT INTO 'dancesstepsmap' VALUES (13370, 11712, 5);
INSERT INTO 'dancesstepsmap' VALUES (13371, 11712, 4);
INSERT INTO 'dancesstepsmap' VALUES (13372, 11713, 2);
INSERT INTO 'dancesstepsmap' VALUES (13373, 11713, 1);
INSERT INTO 'dancesstepsmap' VALUES (13374, 11714, 4);
INSERT INTO 'dancesstepsmap' VALUES (13375, 11715, 6);
INSERT INTO 'dancesstepsmap' VALUES (9059, 5836, 2);
INSERT INTO 'dancesstepsmap' VALUES (9060, 6371, 2);
INSERT INTO 'dancesstepsmap' VALUES (9061, 7977, 2);
INSERT INTO 'dancesstepsmap' VALUES (9062, 8311, 2);
INSERT INTO 'dancesstepsmap' VALUES (9063, 325, 2);
INSERT INTO 'dancesstepsmap' VALUES (9064, 605, 2);
INSERT INTO 'dancesstepsmap' VALUES (9065, 4036, 2);
INSERT INTO 'dancesstepsmap' VALUES (9066, 5240, 2);
INSERT INTO 'dancesstepsmap' VALUES (9067, 6666, 2);
INSERT INTO 'dancesstepsmap' VALUES (9068, 6751, 2);
INSERT INTO 'dancesstepsmap' VALUES (9069, 7249, 2);
INSERT INTO 'dancesstepsmap' VALUES (9070, 513, 2);
INSERT INTO 'dancesstepsmap' VALUES (9071, 783, 2);
INSERT INTO 'dancesstepsmap' VALUES (9072, 1007, 2);
INSERT INTO 'dancesstepsmap' VALUES (9073, 1217, 2);
INSERT INTO 'dancesstepsmap' VALUES (9074, 1218, 2);
INSERT INTO 'dancesstepsmap' VALUES (9075, 1616, 2);
INSERT INTO 'dancesstepsmap' VALUES (9076, 1826, 2);
INSERT INTO 'dancesstepsmap' VALUES (9077, 1830, 2);
INSERT INTO 'dancesstepsmap' VALUES (9078, 1833, 2);
INSERT INTO 'dancesstepsmap' VALUES (9079, 1912, 2);
INSERT INTO 'dancesstepsmap' VALUES (9080, 1928, 2);
INSERT INTO 'dancesstepsmap' VALUES (9081, 2024, 2);
INSERT INTO 'dancesstepsmap' VALUES (9082, 2043, 2);
INSERT INTO 'dancesstepsmap' VALUES (9083, 2350, 2);
INSERT INTO 'dancesstepsmap' VALUES (9084, 2412, 2);
INSERT INTO 'dancesstepsmap' VALUES (9085, 2537, 2);
INSERT INTO 'dancesstepsmap' VALUES (9086, 2593, 2);
INSERT INTO 'dancesstepsmap' VALUES (9087, 2729, 2);
INSERT INTO 'dancesstepsmap' VALUES (9088, 2863, 2);
INSERT INTO 'dancesstepsmap' VALUES (9089, 2906, 2);
INSERT INTO 'dancesstepsmap' VALUES (9090, 3027, 2);
INSERT INTO 'dancesstepsmap' VALUES (9091, 3138, 2);
INSERT INTO 'dancesstepsmap' VALUES (9092, 3369, 2);
INSERT INTO 'dancesstepsmap' VALUES (9093, 3445, 2);
INSERT INTO 'dancesstepsmap' VALUES (9094, 3661, 2);
INSERT INTO 'dancesstepsmap' VALUES (9095, 3837, 2);
INSERT INTO 'dancesstepsmap' VALUES (9096, 4080, 2);
INSERT INTO 'dancesstepsmap' VALUES (9097, 4119, 2);
INSERT INTO 'dancesstepsmap' VALUES (9098, 4176, 2);
INSERT INTO 'dancesstepsmap' VALUES (9099, 4415, 2);
INSERT INTO 'dancesstepsmap' VALUES (9100, 4550, 2);
INSERT INTO 'dancesstepsmap' VALUES (9101, 4594, 2);
INSERT INTO 'dancesstepsmap' VALUES (9102, 4687, 2);
INSERT INTO 'dancesstepsmap' VALUES (9103, 4963, 2);
INSERT INTO 'dancesstepsmap' VALUES (9104, 4977, 2);
INSERT INTO 'dancesstepsmap' VALUES (9105, 5006, 2);
INSERT INTO 'dancesstepsmap' VALUES (9106, 5151, 2);
INSERT INTO 'dancesstepsmap' VALUES (9107, 5229, 2);
INSERT INTO 'dancesstepsmap' VALUES (9108, 5342, 2);
INSERT INTO 'dancesstepsmap' VALUES (9109, 5463, 2);
INSERT INTO 'dancesstepsmap' VALUES (9110, 5546, 2);
INSERT INTO 'dancesstepsmap' VALUES (9111, 5653, 2);
INSERT INTO 'dancesstepsmap' VALUES (9112, 5725, 2);
INSERT INTO 'dancesstepsmap' VALUES (9113, 5752, 2);
INSERT INTO 'dancesstepsmap' VALUES (9114, 5828, 2);
INSERT INTO 'dancesstepsmap' VALUES (9115, 5846, 2);
INSERT INTO 'dancesstepsmap' VALUES (9116, 6287, 2);
INSERT INTO 'dancesstepsmap' VALUES (9117, 6455, 2);
INSERT INTO 'dancesstepsmap' VALUES (9118, 6683, 2);
INSERT INTO 'dancesstepsmap' VALUES (9119, 6744, 2);
INSERT INTO 'dancesstepsmap' VALUES (9120, 6860, 2);
INSERT INTO 'dancesstepsmap' VALUES (9121, 6920, 2);
INSERT INTO 'dancesstepsmap' VALUES (9122, 7129, 2);
INSERT INTO 'dancesstepsmap' VALUES (9123, 7184, 2);
INSERT INTO 'dancesstepsmap' VALUES (9124, 7370, 2);
INSERT INTO 'dancesstepsmap' VALUES (9125, 7385, 2);
INSERT INTO 'dancesstepsmap' VALUES (9126, 7455, 2);
INSERT INTO 'dancesstepsmap' VALUES (9127, 7472, 2);
INSERT INTO 'dancesstepsmap' VALUES (9128, 8180, 2);
INSERT INTO 'dancesstepsmap' VALUES (9129, 8195, 2);
INSERT INTO 'dancesstepsmap' VALUES (9130, 8280, 2);
INSERT INTO 'dancesstepsmap' VALUES (9132, 32, 2);
INSERT INTO 'dancesstepsmap' VALUES (9133, 110, 2);
INSERT INTO 'dancesstepsmap' VALUES (9134, 476, 2);
INSERT INTO 'dancesstepsmap' VALUES (9135, 633, 2);
INSERT INTO 'dancesstepsmap' VALUES (9136, 1025, 2);
INSERT INTO 'dancesstepsmap' VALUES (9137, 1207, 2);
INSERT INTO 'dancesstepsmap' VALUES (9138, 1471, 2);
INSERT INTO 'dancesstepsmap' VALUES (9139, 1992, 2);
INSERT INTO 'dancesstepsmap' VALUES (9140, 2252, 2);
INSERT INTO 'dancesstepsmap' VALUES (9141, 2650, 2);
INSERT INTO 'dancesstepsmap' VALUES (9142, 2806, 2);
INSERT INTO 'dancesstepsmap' VALUES (9143, 3207, 2);
INSERT INTO 'dancesstepsmap' VALUES (9144, 3257, 2);
INSERT INTO 'dancesstepsmap' VALUES (9145, 3279, 2);
INSERT INTO 'dancesstepsmap' VALUES (9146, 3394, 2);
INSERT INTO 'dancesstepsmap' VALUES (9147, 3558, 2);
INSERT INTO 'dancesstepsmap' VALUES (9148, 3842, 2);
INSERT INTO 'dancesstepsmap' VALUES (9149, 4154, 2);
INSERT INTO 'dancesstepsmap' VALUES (9150, 4203, 2);
INSERT INTO 'dancesstepsmap' VALUES (9151, 4413, 2);
INSERT INTO 'dancesstepsmap' VALUES (13376, 11715, 4);
INSERT INTO 'dancesstepsmap' VALUES (23164, 18253, 3);
INSERT INTO 'dancesstepsmap' VALUES (13379, 11013, 1);
INSERT INTO 'dancesstepsmap' VALUES (13380, 11718, 4);
INSERT INTO 'dancesstepsmap' VALUES (13381, 11718, 5);
INSERT INTO 'dancesstepsmap' VALUES (13382, 11720, 1);
INSERT INTO 'dancesstepsmap' VALUES (13383, 1255, 4);
INSERT INTO 'dancesstepsmap' VALUES (13384, 4727, 4);
INSERT INTO 'dancesstepsmap' VALUES (13385, 10419, 1);
INSERT INTO 'dancesstepsmap' VALUES (13386, 10419, 3);
INSERT INTO 'dancesstepsmap' VALUES (13387, 8654, 1);
INSERT INTO 'dancesstepsmap' VALUES (13388, 8654, 3);
INSERT INTO 'dancesstepsmap' VALUES (13389, 11719, 1);
INSERT INTO 'dancesstepsmap' VALUES (13390, 11722, 1);
INSERT INTO 'dancesstepsmap' VALUES (13391, 11723, 1);
INSERT INTO 'dancesstepsmap' VALUES (13392, 11724, 4);
INSERT INTO 'dancesstepsmap' VALUES (13393, 11725, 1);
INSERT INTO 'dancesstepsmap' VALUES (13394, 11725, 2);
INSERT INTO 'dancesstepsmap' VALUES (13395, 11727, 1);
INSERT INTO 'dancesstepsmap' VALUES (13396, 9404, 1);
INSERT INTO 'dancesstepsmap' VALUES (13397, 9404, 2);
INSERT INTO 'dancesstepsmap' VALUES (13398, 9404, 3);
INSERT INTO 'dancesstepsmap' VALUES (13399, 11728, 1);
INSERT INTO 'dancesstepsmap' VALUES (13400, 11728, 3);
INSERT INTO 'dancesstepsmap' VALUES (13401, 8349, 3);
INSERT INTO 'dancesstepsmap' VALUES (13402, 11729, 4);
INSERT INTO 'dancesstepsmap' VALUES (13403, 11730, 4);
INSERT INTO 'dancesstepsmap' VALUES (13405, 11731, 1);
INSERT INTO 'dancesstepsmap' VALUES (13406, 6299, 10);
INSERT INTO 'dancesstepsmap' VALUES (13407, 6299, 6);
INSERT INTO 'dancesstepsmap' VALUES (23165, 18253, 1);
INSERT INTO 'dancesstepsmap' VALUES (23166, 18254, 5);
INSERT INTO 'dancesstepsmap' VALUES (13410, 11733, 1);
INSERT INTO 'dancesstepsmap' VALUES (13411, 11733, 2);
INSERT INTO 'dancesstepsmap' VALUES (13412, 7092, 3);
INSERT INTO 'dancesstepsmap' VALUES (13413, 11749, 1);
INSERT INTO 'dancesstepsmap' VALUES (13414, 11749, 3);
INSERT INTO 'dancesstepsmap' VALUES (13415, 4106, 3);
INSERT INTO 'dancesstepsmap' VALUES (13416, 4106, 2);
INSERT INTO 'dancesstepsmap' VALUES (13417, 11750, 3);
INSERT INTO 'dancesstepsmap' VALUES (9152, 4911, 2);
INSERT INTO 'dancesstepsmap' VALUES (9153, 5235, 2);
INSERT INTO 'dancesstepsmap' VALUES (9154, 5266, 2);
INSERT INTO 'dancesstepsmap' VALUES (9155, 5572, 2);
INSERT INTO 'dancesstepsmap' VALUES (9156, 5757, 2);
INSERT INTO 'dancesstepsmap' VALUES (9157, 5877, 2);
INSERT INTO 'dancesstepsmap' VALUES (9158, 6529, 2);
INSERT INTO 'dancesstepsmap' VALUES (9159, 6650, 2);
INSERT INTO 'dancesstepsmap' VALUES (9160, 7000, 2);
INSERT INTO 'dancesstepsmap' VALUES (9161, 7051, 2);
INSERT INTO 'dancesstepsmap' VALUES (9162, 7410, 2);
INSERT INTO 'dancesstepsmap' VALUES (9163, 7445, 2);
INSERT INTO 'dancesstepsmap' VALUES (9164, 8431, 2);
INSERT INTO 'dancesstepsmap' VALUES (9165, 2, 3);
INSERT INTO 'dancesstepsmap' VALUES (9166, 54, 3);
INSERT INTO 'dancesstepsmap' VALUES (9167, 81, 3);
INSERT INTO 'dancesstepsmap' VALUES (9168, 83, 3);
INSERT INTO 'dancesstepsmap' VALUES (9169, 162, 3);
INSERT INTO 'dancesstepsmap' VALUES (9170, 223, 3);
INSERT INTO 'dancesstepsmap' VALUES (9171, 233, 3);
INSERT INTO 'dancesstepsmap' VALUES (9172, 251, 3);
INSERT INTO 'dancesstepsmap' VALUES (9173, 309, 3);
INSERT INTO 'dancesstepsmap' VALUES (9174, 398, 3);
INSERT INTO 'dancesstepsmap' VALUES (9175, 465, 3);
INSERT INTO 'dancesstepsmap' VALUES (9176, 494, 3);
INSERT INTO 'dancesstepsmap' VALUES (9177, 495, 3);
INSERT INTO 'dancesstepsmap' VALUES (9178, 611, 3);
INSERT INTO 'dancesstepsmap' VALUES (9179, 685, 3);
INSERT INTO 'dancesstepsmap' VALUES (9180, 712, 3);
INSERT INTO 'dancesstepsmap' VALUES (9181, 774, 3);
INSERT INTO 'dancesstepsmap' VALUES (9182, 845, 3);
INSERT INTO 'dancesstepsmap' VALUES (9183, 864, 3);
INSERT INTO 'dancesstepsmap' VALUES (9184, 895, 3);
INSERT INTO 'dancesstepsmap' VALUES (9185, 916, 3);
INSERT INTO 'dancesstepsmap' VALUES (9186, 980, 3);
INSERT INTO 'dancesstepsmap' VALUES (9187, 1024, 3);
INSERT INTO 'dancesstepsmap' VALUES (9188, 1027, 3);
INSERT INTO 'dancesstepsmap' VALUES (9189, 1261, 3);
INSERT INTO 'dancesstepsmap' VALUES (9190, 1264, 3);
INSERT INTO 'dancesstepsmap' VALUES (9191, 1358, 3);
INSERT INTO 'dancesstepsmap' VALUES (9192, 1524, 3);
INSERT INTO 'dancesstepsmap' VALUES (9193, 1544, 3);
INSERT INTO 'dancesstepsmap' VALUES (9194, 1584, 3);
INSERT INTO 'dancesstepsmap' VALUES (9195, 1752, 3);
INSERT INTO 'dancesstepsmap' VALUES (9196, 1760, 3);
INSERT INTO 'dancesstepsmap' VALUES (9197, 1819, 3);
INSERT INTO 'dancesstepsmap' VALUES (9199, 1866, 3);
INSERT INTO 'dancesstepsmap' VALUES (9200, 1909, 3);
INSERT INTO 'dancesstepsmap' VALUES (9201, 1940, 3);
INSERT INTO 'dancesstepsmap' VALUES (9202, 1969, 3);
INSERT INTO 'dancesstepsmap' VALUES (9203, 2004, 3);
INSERT INTO 'dancesstepsmap' VALUES (9204, 2049, 3);
INSERT INTO 'dancesstepsmap' VALUES (9205, 2053, 3);
INSERT INTO 'dancesstepsmap' VALUES (9206, 2085, 3);
INSERT INTO 'dancesstepsmap' VALUES (9207, 2282, 3);
INSERT INTO 'dancesstepsmap' VALUES (9208, 2287, 3);
INSERT INTO 'dancesstepsmap' VALUES (9209, 2291, 3);
INSERT INTO 'dancesstepsmap' VALUES (9210, 2294, 3);
INSERT INTO 'dancesstepsmap' VALUES (9211, 2349, 3);
INSERT INTO 'dancesstepsmap' VALUES (9212, 2363, 3);
INSERT INTO 'dancesstepsmap' VALUES (9214, 2717, 3);
INSERT INTO 'dancesstepsmap' VALUES (9215, 2746, 3);
INSERT INTO 'dancesstepsmap' VALUES (9216, 2758, 3);
INSERT INTO 'dancesstepsmap' VALUES (9217, 2767, 3);
INSERT INTO 'dancesstepsmap' VALUES (9218, 2802, 3);
INSERT INTO 'dancesstepsmap' VALUES (9219, 2826, 3);
INSERT INTO 'dancesstepsmap' VALUES (9220, 2908, 3);
INSERT INTO 'dancesstepsmap' VALUES (9221, 2927, 3);
INSERT INTO 'dancesstepsmap' VALUES (9222, 2970, 3);
INSERT INTO 'dancesstepsmap' VALUES (9223, 2990, 3);
INSERT INTO 'dancesstepsmap' VALUES (9224, 3057, 3);
INSERT INTO 'dancesstepsmap' VALUES (9225, 3156, 3);
INSERT INTO 'dancesstepsmap' VALUES (9226, 3209, 3);
INSERT INTO 'dancesstepsmap' VALUES (9227, 3237, 3);
INSERT INTO 'dancesstepsmap' VALUES (9228, 3260, 3);
INSERT INTO 'dancesstepsmap' VALUES (9229, 3267, 3);
INSERT INTO 'dancesstepsmap' VALUES (9230, 3285, 3);
INSERT INTO 'dancesstepsmap' VALUES (9231, 3299, 3);
INSERT INTO 'dancesstepsmap' VALUES (9232, 3405, 3);
INSERT INTO 'dancesstepsmap' VALUES (9233, 3408, 3);
INSERT INTO 'dancesstepsmap' VALUES (9235, 3418, 3);
INSERT INTO 'dancesstepsmap' VALUES (9236, 3526, 3);
INSERT INTO 'dancesstepsmap' VALUES (9237, 3529, 3);
INSERT INTO 'dancesstepsmap' VALUES (9238, 3558, 3);
INSERT INTO 'dancesstepsmap' VALUES (9239, 3565, 3);
INSERT INTO 'dancesstepsmap' VALUES (9240, 3594, 3);
INSERT INTO 'dancesstepsmap' VALUES (9241, 3609, 3);
INSERT INTO 'dancesstepsmap' VALUES (9242, 3639, 3);
INSERT INTO 'dancesstepsmap' VALUES (9243, 3659, 3);
INSERT INTO 'dancesstepsmap' VALUES (9244, 3698, 3);
INSERT INTO 'dancesstepsmap' VALUES (13418, 2531, 3);
INSERT INTO 'dancesstepsmap' VALUES (13419, 8970, 3);
INSERT INTO 'dancesstepsmap' VALUES (13420, 188, 3);
INSERT INTO 'dancesstepsmap' VALUES (13421, 11752, 1);
INSERT INTO 'dancesstepsmap' VALUES (13422, 11753, 6);
INSERT INTO 'dancesstepsmap' VALUES (13423, 11753, 4);
INSERT INTO 'dancesstepsmap' VALUES (13424, 11754, 4);
INSERT INTO 'dancesstepsmap' VALUES (13425, 11754, 5);
INSERT INTO 'dancesstepsmap' VALUES (13426, 11755, 4);
INSERT INTO 'dancesstepsmap' VALUES (13427, 11756, 2);
INSERT INTO 'dancesstepsmap' VALUES (13428, 11756, 1);
INSERT INTO 'dancesstepsmap' VALUES (13429, 11757, 1);
INSERT INTO 'dancesstepsmap' VALUES (13430, 11758, 4);
INSERT INTO 'dancesstepsmap' VALUES (13431, 11759, 4);
INSERT INTO 'dancesstepsmap' VALUES (13432, 11760, 4);
INSERT INTO 'dancesstepsmap' VALUES (13433, 11761, 2);
INSERT INTO 'dancesstepsmap' VALUES (13434, 11761, 1);
INSERT INTO 'dancesstepsmap' VALUES (13435, 11762, 1);
INSERT INTO 'dancesstepsmap' VALUES (13436, 11763, 4);
INSERT INTO 'dancesstepsmap' VALUES (13437, 11763, 5);
INSERT INTO 'dancesstepsmap' VALUES (13377, 11716, 1);
INSERT INTO 'dancesstepsmap' VALUES (13438, 11765, 5);
INSERT INTO 'dancesstepsmap' VALUES (13439, 11765, 4);
INSERT INTO 'dancesstepsmap' VALUES (13440, 11765, 1);
INSERT INTO 'dancesstepsmap' VALUES (13441, 11765, 2);
INSERT INTO 'dancesstepsmap' VALUES (13442, 11767, 2);
INSERT INTO 'dancesstepsmap' VALUES (13443, 11767, 1);
INSERT INTO 'dancesstepsmap' VALUES (13444, 8241, 2);
INSERT INTO 'dancesstepsmap' VALUES (13445, 10234, 4);
INSERT INTO 'dancesstepsmap' VALUES (13446, 10234, 5);
INSERT INTO 'dancesstepsmap' VALUES (13447, 11768, 1);
INSERT INTO 'dancesstepsmap' VALUES (13448, 11774, 2);
INSERT INTO 'dancesstepsmap' VALUES (13449, 11774, 1);
INSERT INTO 'dancesstepsmap' VALUES (13450, 11774, 3);
INSERT INTO 'dancesstepsmap' VALUES (13451, 11775, 2);
INSERT INTO 'dancesstepsmap' VALUES (13452, 11775, 1);
INSERT INTO 'dancesstepsmap' VALUES (13453, 11775, 3);
INSERT INTO 'dancesstepsmap' VALUES (13454, 11776, 3);
INSERT INTO 'dancesstepsmap' VALUES (13455, 11776, 1);
INSERT INTO 'dancesstepsmap' VALUES (13456, 11778, 4);
INSERT INTO 'dancesstepsmap' VALUES (13457, 11779, 1);
INSERT INTO 'dancesstepsmap' VALUES (13458, 11780, 1);
INSERT INTO 'dancesstepsmap' VALUES (13459, 11780, 3);
INSERT INTO 'dancesstepsmap' VALUES (9245, 3724, 3);
INSERT INTO 'dancesstepsmap' VALUES (9246, 3737, 3);
INSERT INTO 'dancesstepsmap' VALUES (9247, 3769, 3);
INSERT INTO 'dancesstepsmap' VALUES (9248, 3783, 3);
INSERT INTO 'dancesstepsmap' VALUES (9249, 3834, 3);
INSERT INTO 'dancesstepsmap' VALUES (9251, 3861, 3);
INSERT INTO 'dancesstepsmap' VALUES (9252, 3916, 3);
INSERT INTO 'dancesstepsmap' VALUES (9253, 3989, 3);
INSERT INTO 'dancesstepsmap' VALUES (9254, 4058, 3);
INSERT INTO 'dancesstepsmap' VALUES (9255, 4141, 3);
INSERT INTO 'dancesstepsmap' VALUES (9256, 4157, 3);
INSERT INTO 'dancesstepsmap' VALUES (9257, 4199, 3);
INSERT INTO 'dancesstepsmap' VALUES (9258, 4250, 3);
INSERT INTO 'dancesstepsmap' VALUES (9259, 4324, 3);
INSERT INTO 'dancesstepsmap' VALUES (9260, 4336, 3);
INSERT INTO 'dancesstepsmap' VALUES (9262, 4491, 3);
INSERT INTO 'dancesstepsmap' VALUES (9263, 4498, 3);
INSERT INTO 'dancesstepsmap' VALUES (9264, 4529, 3);
INSERT INTO 'dancesstepsmap' VALUES (9265, 4644, 3);
INSERT INTO 'dancesstepsmap' VALUES (9266, 4669, 3);
INSERT INTO 'dancesstepsmap' VALUES (9268, 4928, 3);
INSERT INTO 'dancesstepsmap' VALUES (9269, 5065, 3);
INSERT INTO 'dancesstepsmap' VALUES (9270, 5097, 3);
INSERT INTO 'dancesstepsmap' VALUES (9271, 5099, 3);
INSERT INTO 'dancesstepsmap' VALUES (9272, 5160, 3);
INSERT INTO 'dancesstepsmap' VALUES (9273, 5200, 3);
INSERT INTO 'dancesstepsmap' VALUES (9274, 5522, 3);
INSERT INTO 'dancesstepsmap' VALUES (9275, 5621, 3);
INSERT INTO 'dancesstepsmap' VALUES (9276, 5641, 3);
INSERT INTO 'dancesstepsmap' VALUES (9277, 5647, 3);
INSERT INTO 'dancesstepsmap' VALUES (9278, 5717, 3);
INSERT INTO 'dancesstepsmap' VALUES (9279, 5802, 3);
INSERT INTO 'dancesstepsmap' VALUES (9280, 5846, 3);
INSERT INTO 'dancesstepsmap' VALUES (9281, 5883, 3);
INSERT INTO 'dancesstepsmap' VALUES (9282, 5894, 3);
INSERT INTO 'dancesstepsmap' VALUES (9283, 5940, 3);
INSERT INTO 'dancesstepsmap' VALUES (9284, 6035, 3);
INSERT INTO 'dancesstepsmap' VALUES (9285, 6053, 3);
INSERT INTO 'dancesstepsmap' VALUES (9286, 6185, 3);
INSERT INTO 'dancesstepsmap' VALUES (9287, 6287, 3);
INSERT INTO 'dancesstepsmap' VALUES (9289, 6338, 3);
INSERT INTO 'dancesstepsmap' VALUES (9290, 6473, 3);
INSERT INTO 'dancesstepsmap' VALUES (9291, 6589, 3);
INSERT INTO 'dancesstepsmap' VALUES (9292, 6631, 3);
INSERT INTO 'dancesstepsmap' VALUES (9293, 6677, 3);
INSERT INTO 'dancesstepsmap' VALUES (9294, 6680, 3);
INSERT INTO 'dancesstepsmap' VALUES (9295, 6711, 3);
INSERT INTO 'dancesstepsmap' VALUES (9296, 6719, 3);
INSERT INTO 'dancesstepsmap' VALUES (9297, 6732, 3);
INSERT INTO 'dancesstepsmap' VALUES (9298, 6751, 3);
INSERT INTO 'dancesstepsmap' VALUES (9299, 6793, 3);
INSERT INTO 'dancesstepsmap' VALUES (9300, 6817, 3);
INSERT INTO 'dancesstepsmap' VALUES (9301, 6838, 3);
INSERT INTO 'dancesstepsmap' VALUES (9302, 6849, 3);
INSERT INTO 'dancesstepsmap' VALUES (9303, 6910, 3);
INSERT INTO 'dancesstepsmap' VALUES (9304, 6952, 3);
INSERT INTO 'dancesstepsmap' VALUES (9305, 6965, 3);
INSERT INTO 'dancesstepsmap' VALUES (9306, 6969, 3);
INSERT INTO 'dancesstepsmap' VALUES (9307, 7065, 3);
INSERT INTO 'dancesstepsmap' VALUES (9308, 7073, 3);
INSERT INTO 'dancesstepsmap' VALUES (9309, 7083, 3);
INSERT INTO 'dancesstepsmap' VALUES (9310, 7148, 3);
INSERT INTO 'dancesstepsmap' VALUES (9311, 7173, 3);
INSERT INTO 'dancesstepsmap' VALUES (9312, 7219, 3);
INSERT INTO 'dancesstepsmap' VALUES (9313, 7343, 3);
INSERT INTO 'dancesstepsmap' VALUES (9314, 7423, 3);
INSERT INTO 'dancesstepsmap' VALUES (9315, 7424, 3);
INSERT INTO 'dancesstepsmap' VALUES (9316, 7508, 3);
INSERT INTO 'dancesstepsmap' VALUES (9318, 7530, 3);
INSERT INTO 'dancesstepsmap' VALUES (9319, 7532, 3);
INSERT INTO 'dancesstepsmap' VALUES (9320, 695, 3);
INSERT INTO 'dancesstepsmap' VALUES (9321, 7451, 3);
INSERT INTO 'dancesstepsmap' VALUES (9322, 8204, 3);
INSERT INTO 'dancesstepsmap' VALUES (9323, 8205, 3);
INSERT INTO 'dancesstepsmap' VALUES (9324, 8409, 3);
INSERT INTO 'dancesstepsmap' VALUES (9325, 313, 2);
INSERT INTO 'dancesstepsmap' VALUES (9326, 403, 2);
INSERT INTO 'dancesstepsmap' VALUES (9327, 1465, 2);
INSERT INTO 'dancesstepsmap' VALUES (9328, 2396, 2);
INSERT INTO 'dancesstepsmap' VALUES (9329, 2472, 2);
INSERT INTO 'dancesstepsmap' VALUES (9330, 4306, 2);
INSERT INTO 'dancesstepsmap' VALUES (9331, 4313, 2);
INSERT INTO 'dancesstepsmap' VALUES (9332, 4962, 2);
INSERT INTO 'dancesstepsmap' VALUES (9333, 5234, 2);
INSERT INTO 'dancesstepsmap' VALUES (9334, 6215, 2);
INSERT INTO 'dancesstepsmap' VALUES (9335, 6461, 2);
INSERT INTO 'dancesstepsmap' VALUES (9336, 7123, 2);
INSERT INTO 'dancesstepsmap' VALUES (13460, 11781, 4);
INSERT INTO 'dancesstepsmap' VALUES (13461, 11782, 1);
INSERT INTO 'dancesstepsmap' VALUES (13462, 11705, 4);
INSERT INTO 'dancesstepsmap' VALUES (13463, 11705, 5);
INSERT INTO 'dancesstepsmap' VALUES (13464, 11750, 1);
INSERT INTO 'dancesstepsmap' VALUES (13465, 11783, 4);
INSERT INTO 'dancesstepsmap' VALUES (13466, 11783, 5);
INSERT INTO 'dancesstepsmap' VALUES (13467, 11784, 1);
INSERT INTO 'dancesstepsmap' VALUES (13468, 11786, 1);
INSERT INTO 'dancesstepsmap' VALUES (13469, 11786, 3);
INSERT INTO 'dancesstepsmap' VALUES (13470, 11787, 4);
INSERT INTO 'dancesstepsmap' VALUES (13471, 11787, 5);
INSERT INTO 'dancesstepsmap' VALUES (13472, 11788, 1);
INSERT INTO 'dancesstepsmap' VALUES (13473, 11789, 2);
INSERT INTO 'dancesstepsmap' VALUES (13474, 11789, 1);
INSERT INTO 'dancesstepsmap' VALUES (13475, 11791, 1);
INSERT INTO 'dancesstepsmap' VALUES (13476, 11792, 1);
INSERT INTO 'dancesstepsmap' VALUES (13477, 11793, 1);
INSERT INTO 'dancesstepsmap' VALUES (13478, 11794, 1);
INSERT INTO 'dancesstepsmap' VALUES (13479, 11794, 3);
INSERT INTO 'dancesstepsmap' VALUES (13480, 11795, 3);
INSERT INTO 'dancesstepsmap' VALUES (13481, 11795, 1);
INSERT INTO 'dancesstepsmap' VALUES (13482, 11796, 1);
INSERT INTO 'dancesstepsmap' VALUES (13483, 11796, 3);
INSERT INTO 'dancesstepsmap' VALUES (13484, 11797, 2);
INSERT INTO 'dancesstepsmap' VALUES (13485, 11769, 2);
INSERT INTO 'dancesstepsmap' VALUES (13486, 11769, 1);
INSERT INTO 'dancesstepsmap' VALUES (13487, 11771, 2);
INSERT INTO 'dancesstepsmap' VALUES (13488, 11771, 1);
INSERT INTO 'dancesstepsmap' VALUES (13489, 11771, 3);
INSERT INTO 'dancesstepsmap' VALUES (13490, 11772, 4);
INSERT INTO 'dancesstepsmap' VALUES (13491, 11773, 2);
INSERT INTO 'dancesstepsmap' VALUES (13492, 11773, 1);
INSERT INTO 'dancesstepsmap' VALUES (13493, 11798, 2);
INSERT INTO 'dancesstepsmap' VALUES (13494, 11798, 1);
INSERT INTO 'dancesstepsmap' VALUES (13495, 11799, 2);
INSERT INTO 'dancesstepsmap' VALUES (13496, 11799, 1);
INSERT INTO 'dancesstepsmap' VALUES (13497, 11800, 1);
INSERT INTO 'dancesstepsmap' VALUES (13498, 11801, 5);
INSERT INTO 'dancesstepsmap' VALUES (13499, 11801, 4);
INSERT INTO 'dancesstepsmap' VALUES (13500, 11777, 2);
INSERT INTO 'dancesstepsmap' VALUES (13501, 11777, 1);
INSERT INTO 'dancesstepsmap' VALUES (13502, 10595, 2);
INSERT INTO 'dancesstepsmap' VALUES (9337, 7516, 2);
INSERT INTO 'dancesstepsmap' VALUES (9338, 8419, 2);
INSERT INTO 'dancesstepsmap' VALUES (9339, 8422, 2);
INSERT INTO 'dancesstepsmap' VALUES (9340, 247, 2);
INSERT INTO 'dancesstepsmap' VALUES (9341, 3021, 2);
INSERT INTO 'dancesstepsmap' VALUES (9342, 4668, 2);
INSERT INTO 'dancesstepsmap' VALUES (9343, 5512, 2);
INSERT INTO 'dancesstepsmap' VALUES (9344, 7124, 2);
INSERT INTO 'dancesstepsmap' VALUES (9345, 8426, 2);
INSERT INTO 'dancesstepsmap' VALUES (9346, 117, 5);
INSERT INTO 'dancesstepsmap' VALUES (9347, 1031, 5);
INSERT INTO 'dancesstepsmap' VALUES (9348, 4809, 5);
INSERT INTO 'dancesstepsmap' VALUES (9349, 5067, 5);
INSERT INTO 'dancesstepsmap' VALUES (9350, 5410, 5);
INSERT INTO 'dancesstepsmap' VALUES (9351, 6188, 5);
INSERT INTO 'dancesstepsmap' VALUES (9352, 6654, 5);
INSERT INTO 'dancesstepsmap' VALUES (9353, 708, 3);
INSERT INTO 'dancesstepsmap' VALUES (9354, 497, 4);
INSERT INTO 'dancesstepsmap' VALUES (9355, 497, 1);
INSERT INTO 'dancesstepsmap' VALUES (9356, 497, 3);
INSERT INTO 'dancesstepsmap' VALUES (9357, 651, 3);
INSERT INTO 'dancesstepsmap' VALUES (9358, 3567, 2);
INSERT INTO 'dancesstepsmap' VALUES (9359, 5741, 2);
INSERT INTO 'dancesstepsmap' VALUES (9360, 1593, 3);
INSERT INTO 'dancesstepsmap' VALUES (9361, 670, 4);
INSERT INTO 'dancesstepsmap' VALUES (9362, 670, 1);
INSERT INTO 'dancesstepsmap' VALUES (9363, 2842, 6);
INSERT INTO 'dancesstepsmap' VALUES (9364, 2842, 5);
INSERT INTO 'dancesstepsmap' VALUES (9365, 4175, 2);
INSERT INTO 'dancesstepsmap' VALUES (9366, 4069, 5);
INSERT INTO 'dancesstepsmap' VALUES (9367, 68, 2);
INSERT INTO 'dancesstepsmap' VALUES (9368, 1307, 5);
INSERT INTO 'dancesstepsmap' VALUES (9369, 1625, 2);
INSERT INTO 'dancesstepsmap' VALUES (9370, 1777, 5);
INSERT INTO 'dancesstepsmap' VALUES (9371, 3710, 5);
INSERT INTO 'dancesstepsmap' VALUES (9372, 4354, 3);
INSERT INTO 'dancesstepsmap' VALUES (9373, 4354, 2);
INSERT INTO 'dancesstepsmap' VALUES (9374, 3963, 2);
INSERT INTO 'dancesstepsmap' VALUES (9375, 4845, 5);
INSERT INTO 'dancesstepsmap' VALUES (9376, 5932, 2);
INSERT INTO 'dancesstepsmap' VALUES (9377, 5980, 5);
INSERT INTO 'dancesstepsmap' VALUES (9378, 6637, 2);
INSERT INTO 'dancesstepsmap' VALUES (9379, 7201, 2);
INSERT INTO 'dancesstepsmap' VALUES (9380, 6830, 2);
INSERT INTO 'dancesstepsmap' VALUES (9381, 7152, 2);
INSERT INTO 'dancesstepsmap' VALUES (9382, 7267, 5);
INSERT INTO 'dancesstepsmap' VALUES (9383, 4669, 2);
INSERT INTO 'dancesstepsmap' VALUES (9384, 6449, 3);
INSERT INTO 'dancesstepsmap' VALUES (9385, 105, 3);
INSERT INTO 'dancesstepsmap' VALUES (9386, 7011, 3);
INSERT INTO 'dancesstepsmap' VALUES (9387, 7208, 3);
INSERT INTO 'dancesstepsmap' VALUES (9388, 1479, 3);
INSERT INTO 'dancesstepsmap' VALUES (9389, 5575, 3);
INSERT INTO 'dancesstepsmap' VALUES (9390, 291, 2);
INSERT INTO 'dancesstepsmap' VALUES (9391, 4295, 3);
INSERT INTO 'dancesstepsmap' VALUES (9392, 1528, 3);
INSERT INTO 'dancesstepsmap' VALUES (9393, 3975, 3);
INSERT INTO 'dancesstepsmap' VALUES (9394, 8267, 1);
INSERT INTO 'dancesstepsmap' VALUES (9395, 8267, 2);
INSERT INTO 'dancesstepsmap' VALUES (9396, 8267, 3);
INSERT INTO 'dancesstepsmap' VALUES (9397, 8268, 3);
INSERT INTO 'dancesstepsmap' VALUES (9398, 8268, 1);
INSERT INTO 'dancesstepsmap' VALUES (9399, 8268, 2);
INSERT INTO 'dancesstepsmap' VALUES (9267, 4835, 2);
INSERT INTO 'dancesstepsmap' VALUES (9317, 7523, 2);
INSERT INTO 'dancesstepsmap' VALUES (9400, 8268, 10);
INSERT INTO 'dancesstepsmap' VALUES (9401, 8269, 5);
INSERT INTO 'dancesstepsmap' VALUES (9402, 8272, 5);
INSERT INTO 'dancesstepsmap' VALUES (9403, 8274, 2);
INSERT INTO 'dancesstepsmap' VALUES (9404, 8275, 5);
INSERT INTO 'dancesstepsmap' VALUES (9405, 8275, 10);
INSERT INTO 'dancesstepsmap' VALUES (9406, 8276, 10);
INSERT INTO 'dancesstepsmap' VALUES (9407, 8276, 2);
INSERT INTO 'dancesstepsmap' VALUES (9408, 8278, 10);
INSERT INTO 'dancesstepsmap' VALUES (9409, 8278, 5);
INSERT INTO 'dancesstepsmap' VALUES (9410, 8279, 5);
INSERT INTO 'dancesstepsmap' VALUES (9411, 8305, 8);
INSERT INTO 'dancesstepsmap' VALUES (9412, 8305, 2);
INSERT INTO 'dancesstepsmap' VALUES (9413, 8306, 5);
INSERT INTO 'dancesstepsmap' VALUES (9414, 8308, 5);
INSERT INTO 'dancesstepsmap' VALUES (9415, 8309, 2);
INSERT INTO 'dancesstepsmap' VALUES (9416, 8310, 5);
INSERT INTO 'dancesstepsmap' VALUES (9417, 8313, 2);
INSERT INTO 'dancesstepsmap' VALUES (9418, 8314, 5);
INSERT INTO 'dancesstepsmap' VALUES (9419, 8315, 2);
INSERT INTO 'dancesstepsmap' VALUES (9420, 8296, 5);
INSERT INTO 'dancesstepsmap' VALUES (9421, 8298, 5);
INSERT INTO 'dancesstepsmap' VALUES (9422, 8299, 2);
INSERT INTO 'dancesstepsmap' VALUES (9423, 8300, 5);
INSERT INTO 'dancesstepsmap' VALUES (9424, 8302, 6);
INSERT INTO 'dancesstepsmap' VALUES (9425, 8303, 10);
INSERT INTO 'dancesstepsmap' VALUES (9426, 8303, 2);
INSERT INTO 'dancesstepsmap' VALUES (9427, 8304, 2);
INSERT INTO 'dancesstepsmap' VALUES (9428, 8281, 5);
INSERT INTO 'dancesstepsmap' VALUES (9429, 8282, 8);
INSERT INTO 'dancesstepsmap' VALUES (13503, 10595, 1);
INSERT INTO 'dancesstepsmap' VALUES (13504, 11802, 3);
INSERT INTO 'dancesstepsmap' VALUES (13505, 11802, 1);
INSERT INTO 'dancesstepsmap' VALUES (13506, 11803, 2);
INSERT INTO 'dancesstepsmap' VALUES (13507, 11803, 1);
INSERT INTO 'dancesstepsmap' VALUES (13508, 11803, 3);
INSERT INTO 'dancesstepsmap' VALUES (13509, 11806, 2);
INSERT INTO 'dancesstepsmap' VALUES (13510, 11806, 10);
INSERT INTO 'dancesstepsmap' VALUES (13511, 11806, 1);
INSERT INTO 'dancesstepsmap' VALUES (13512, 11806, 3);
INSERT INTO 'dancesstepsmap' VALUES (13513, 11808, 1);
INSERT INTO 'dancesstepsmap' VALUES (13514, 11809, 1);
INSERT INTO 'dancesstepsmap' VALUES (13515, 11810, 1);
INSERT INTO 'dancesstepsmap' VALUES (13516, 11811, 4);
INSERT INTO 'dancesstepsmap' VALUES (13517, 11811, 5);
INSERT INTO 'dancesstepsmap' VALUES (13518, 11812, 4);
INSERT INTO 'dancesstepsmap' VALUES (13519, 11813, 2);
INSERT INTO 'dancesstepsmap' VALUES (13520, 11814, 4);
INSERT INTO 'dancesstepsmap' VALUES (13521, 2410, 5);
INSERT INTO 'dancesstepsmap' VALUES (13522, 2440, 2);
INSERT INTO 'dancesstepsmap' VALUES (13523, 2442, 3);
INSERT INTO 'dancesstepsmap' VALUES (13524, 11815, 4);
INSERT INTO 'dancesstepsmap' VALUES (13525, 11815, 5);
INSERT INTO 'dancesstepsmap' VALUES (13526, 11641, 3);
INSERT INTO 'dancesstepsmap' VALUES (13527, 11641, 1);
INSERT INTO 'dancesstepsmap' VALUES (13528, 11816, 1);
INSERT INTO 'dancesstepsmap' VALUES (13529, 11817, 1);
INSERT INTO 'dancesstepsmap' VALUES (13530, 11818, 4);
INSERT INTO 'dancesstepsmap' VALUES (13531, 11818, 5);
INSERT INTO 'dancesstepsmap' VALUES (13532, 11819, 1);
INSERT INTO 'dancesstepsmap' VALUES (13533, 11820, 2);
INSERT INTO 'dancesstepsmap' VALUES (13534, 11820, 1);
INSERT INTO 'dancesstepsmap' VALUES (13535, 11821, 1);
INSERT INTO 'dancesstepsmap' VALUES (13536, 11822, 6);
INSERT INTO 'dancesstepsmap' VALUES (13537, 11822, 4);
INSERT INTO 'dancesstepsmap' VALUES (13538, 11823, 2);
INSERT INTO 'dancesstepsmap' VALUES (13539, 11826, 2);
INSERT INTO 'dancesstepsmap' VALUES (13540, 11826, 1);
INSERT INTO 'dancesstepsmap' VALUES (13541, 11826, 3);
INSERT INTO 'dancesstepsmap' VALUES (13542, 11827, 4);
INSERT INTO 'dancesstepsmap' VALUES (13543, 11828, 2);
INSERT INTO 'dancesstepsmap' VALUES (13544, 11828, 1);
INSERT INTO 'dancesstepsmap' VALUES (13545, 11829, 4);
INSERT INTO 'dancesstepsmap' VALUES (13546, 11829, 5);
INSERT INTO 'dancesstepsmap' VALUES (13547, 11830, 1);
INSERT INTO 'dancesstepsmap' VALUES (13549, 11765, 3);
INSERT INTO 'dancesstepsmap' VALUES (13550, 1909, 2);
INSERT INTO 'dancesstepsmap' VALUES (13551, 7049, 2);
INSERT INTO 'dancesstepsmap' VALUES (13552, 11833, 1);
INSERT INTO 'dancesstepsmap' VALUES (13553, 11834, 4);
INSERT INTO 'dancesstepsmap' VALUES (13554, 11836, 1);
INSERT INTO 'dancesstepsmap' VALUES (13555, 11836, 2);
INSERT INTO 'dancesstepsmap' VALUES (13556, 11837, 1);
INSERT INTO 'dancesstepsmap' VALUES (9430, 8282, 1);
INSERT INTO 'dancesstepsmap' VALUES (9431, 8285, 5);
INSERT INTO 'dancesstepsmap' VALUES (9432, 8285, 10);
INSERT INTO 'dancesstepsmap' VALUES (9433, 8286, 10);
INSERT INTO 'dancesstepsmap' VALUES (9434, 8287, 9);
INSERT INTO 'dancesstepsmap' VALUES (9435, 8288, 10);
INSERT INTO 'dancesstepsmap' VALUES (9436, 8288, 9);
INSERT INTO 'dancesstepsmap' VALUES (9437, 8289, 8);
INSERT INTO 'dancesstepsmap' VALUES (9438, 8290, 9);
INSERT INTO 'dancesstepsmap' VALUES (9439, 8290, 10);
INSERT INTO 'dancesstepsmap' VALUES (9440, 8290, 1);
INSERT INTO 'dancesstepsmap' VALUES (9441, 8290, 4);
INSERT INTO 'dancesstepsmap' VALUES (9442, 8291, 6);
INSERT INTO 'dancesstepsmap' VALUES (9443, 8291, 4);
INSERT INTO 'dancesstepsmap' VALUES (9444, 8291, 9);
INSERT INTO 'dancesstepsmap' VALUES (9445, 8291, 1);
INSERT INTO 'dancesstepsmap' VALUES (9446, 8291, 2);
INSERT INTO 'dancesstepsmap' VALUES (9447, 8291, 8);
INSERT INTO 'dancesstepsmap' VALUES (9448, 8292, 10);
INSERT INTO 'dancesstepsmap' VALUES (9449, 8292, 6);
INSERT INTO 'dancesstepsmap' VALUES (9450, 8292, 5);
INSERT INTO 'dancesstepsmap' VALUES (9451, 8292, 4);
INSERT INTO 'dancesstepsmap' VALUES (9452, 8292, 1);
INSERT INTO 'dancesstepsmap' VALUES (9453, 8292, 2);
INSERT INTO 'dancesstepsmap' VALUES (9454, 8292, 8);
INSERT INTO 'dancesstepsmap' VALUES (9455, 8583, 4);
INSERT INTO 'dancesstepsmap' VALUES (9456, 8583, 5);
INSERT INTO 'dancesstepsmap' VALUES (9457, 8584, 1);
INSERT INTO 'dancesstepsmap' VALUES (9458, 8584, 3);
INSERT INTO 'dancesstepsmap' VALUES (9459, 8585, 4);
INSERT INTO 'dancesstepsmap' VALUES (9460, 8585, 5);
INSERT INTO 'dancesstepsmap' VALUES (9461, 8586, 8);
INSERT INTO 'dancesstepsmap' VALUES (9462, 8586, 1);
INSERT INTO 'dancesstepsmap' VALUES (9463, 8586, 2);
INSERT INTO 'dancesstepsmap' VALUES (9464, 8587, 10);
INSERT INTO 'dancesstepsmap' VALUES (9465, 8587, 1);
INSERT INTO 'dancesstepsmap' VALUES (9466, 8587, 3);
INSERT INTO 'dancesstepsmap' VALUES (9467, 8588, 4);
INSERT INTO 'dancesstepsmap' VALUES (9468, 8588, 5);
INSERT INTO 'dancesstepsmap' VALUES (9469, 8589, 1);
INSERT INTO 'dancesstepsmap' VALUES (9470, 8589, 2);
INSERT INTO 'dancesstepsmap' VALUES (9471, 8590, 6);
INSERT INTO 'dancesstepsmap' VALUES (9472, 8590, 9);
INSERT INTO 'dancesstepsmap' VALUES (9473, 8590, 4);
INSERT INTO 'dancesstepsmap' VALUES (9474, 8590, 5);
INSERT INTO 'dancesstepsmap' VALUES (9475, 8591, 4);
INSERT INTO 'dancesstepsmap' VALUES (9476, 8591, 5);
INSERT INTO 'dancesstepsmap' VALUES (9477, 8592, 1);
INSERT INTO 'dancesstepsmap' VALUES (9478, 8592, 2);
INSERT INTO 'dancesstepsmap' VALUES (9479, 8593, 4);
INSERT INTO 'dancesstepsmap' VALUES (9480, 8593, 9);
INSERT INTO 'dancesstepsmap' VALUES (9481, 8593, 8);
INSERT INTO 'dancesstepsmap' VALUES (9482, 8593, 10);
INSERT INTO 'dancesstepsmap' VALUES (9483, 8594, 4);
INSERT INTO 'dancesstepsmap' VALUES (9484, 8594, 5);
INSERT INTO 'dancesstepsmap' VALUES (9485, 8594, 9);
INSERT INTO 'dancesstepsmap' VALUES (9486, 8595, 8);
INSERT INTO 'dancesstepsmap' VALUES (9487, 8595, 1);
INSERT INTO 'dancesstepsmap' VALUES (9488, 8595, 2);
INSERT INTO 'dancesstepsmap' VALUES (9489, 8596, 2);
INSERT INTO 'dancesstepsmap' VALUES (9490, 8596, 3);
INSERT INTO 'dancesstepsmap' VALUES (9491, 8596, 1);
INSERT INTO 'dancesstepsmap' VALUES (9492, 8597, 4);
INSERT INTO 'dancesstepsmap' VALUES (9493, 8597, 5);
INSERT INTO 'dancesstepsmap' VALUES (9494, 8598, 4);
INSERT INTO 'dancesstepsmap' VALUES (9495, 8599, 2);
INSERT INTO 'dancesstepsmap' VALUES (9496, 8599, 3);
INSERT INTO 'dancesstepsmap' VALUES (9497, 8599, 1);
INSERT INTO 'dancesstepsmap' VALUES (9498, 8600, 4);
INSERT INTO 'dancesstepsmap' VALUES (9499, 8600, 5);
INSERT INTO 'dancesstepsmap' VALUES (9500, 8601, 5);
INSERT INTO 'dancesstepsmap' VALUES (9501, 8601, 4);
INSERT INTO 'dancesstepsmap' VALUES (9502, 8602, 4);
INSERT INTO 'dancesstepsmap' VALUES (9503, 8602, 5);
INSERT INTO 'dancesstepsmap' VALUES (9504, 8603, 2);
INSERT INTO 'dancesstepsmap' VALUES (9505, 8603, 1);
INSERT INTO 'dancesstepsmap' VALUES (9506, 8604, 2);
INSERT INTO 'dancesstepsmap' VALUES (9507, 8604, 3);
INSERT INTO 'dancesstepsmap' VALUES (9508, 8604, 1);
INSERT INTO 'dancesstepsmap' VALUES (9509, 8605, 1);
INSERT INTO 'dancesstepsmap' VALUES (9510, 8605, 2);
INSERT INTO 'dancesstepsmap' VALUES (9511, 8606, 1);
INSERT INTO 'dancesstepsmap' VALUES (9512, 8606, 3);
INSERT INTO 'dancesstepsmap' VALUES (9513, 8607, 2);
INSERT INTO 'dancesstepsmap' VALUES (9514, 8607, 1);
INSERT INTO 'dancesstepsmap' VALUES (9515, 8607, 8);
INSERT INTO 'dancesstepsmap' VALUES (9516, 8608, 1);
INSERT INTO 'dancesstepsmap' VALUES (9517, 8609, 8);
INSERT INTO 'dancesstepsmap' VALUES (9518, 8609, 2);
INSERT INTO 'dancesstepsmap' VALUES (9519, 8609, 1);
INSERT INTO 'dancesstepsmap' VALUES (9520, 8610, 1);
INSERT INTO 'dancesstepsmap' VALUES (9521, 8610, 2);
INSERT INTO 'dancesstepsmap' VALUES (9522, 8611, 1);
INSERT INTO 'dancesstepsmap' VALUES (9523, 8611, 2);
INSERT INTO 'dancesstepsmap' VALUES (9524, 8612, 3);
INSERT INTO 'dancesstepsmap' VALUES (9525, 8612, 2);
INSERT INTO 'dancesstepsmap' VALUES (9526, 8612, 1);
INSERT INTO 'dancesstepsmap' VALUES (9527, 8613, 1);
INSERT INTO 'dancesstepsmap' VALUES (9528, 8613, 2);
INSERT INTO 'dancesstepsmap' VALUES (9529, 8614, 4);
INSERT INTO 'dancesstepsmap' VALUES (9530, 8615, 4);
INSERT INTO 'dancesstepsmap' VALUES (9531, 8615, 5);
INSERT INTO 'dancesstepsmap' VALUES (9532, 8616, 4);
INSERT INTO 'dancesstepsmap' VALUES (9533, 8616, 5);
INSERT INTO 'dancesstepsmap' VALUES (9534, 8617, 4);
INSERT INTO 'dancesstepsmap' VALUES (9535, 8617, 5);
INSERT INTO 'dancesstepsmap' VALUES (9536, 8617, 10);
INSERT INTO 'dancesstepsmap' VALUES (9537, 8618, 6);
INSERT INTO 'dancesstepsmap' VALUES (9538, 8618, 9);
INSERT INTO 'dancesstepsmap' VALUES (9539, 8618, 4);
INSERT INTO 'dancesstepsmap' VALUES (9540, 8619, 4);
INSERT INTO 'dancesstepsmap' VALUES (9541, 8620, 9);
INSERT INTO 'dancesstepsmap' VALUES (9542, 8620, 4);
INSERT INTO 'dancesstepsmap' VALUES (9543, 4051, 5);
INSERT INTO 'dancesstepsmap' VALUES (9544, 2924, 3);
INSERT INTO 'dancesstepsmap' VALUES (9545, 2344, 2);
INSERT INTO 'dancesstepsmap' VALUES (9546, 2556, 2);
INSERT INTO 'dancesstepsmap' VALUES (9547, 8621, 3);
INSERT INTO 'dancesstepsmap' VALUES (9548, 8621, 1);
INSERT INTO 'dancesstepsmap' VALUES (9549, 8621, 4);
INSERT INTO 'dancesstepsmap' VALUES (9550, 2464, 5);
INSERT INTO 'dancesstepsmap' VALUES (9551, 8622, 1);
INSERT INTO 'dancesstepsmap' VALUES (9552, 8627, 4);
INSERT INTO 'dancesstepsmap' VALUES (9553, 8627, 5);
INSERT INTO 'dancesstepsmap' VALUES (9554, 8627, 1);
INSERT INTO 'dancesstepsmap' VALUES (9555, 8627, 2);
INSERT INTO 'dancesstepsmap' VALUES (9556, 8627, 3);
INSERT INTO 'dancesstepsmap' VALUES (9557, 8628, 4);
INSERT INTO 'dancesstepsmap' VALUES (9558, 8628, 5);
INSERT INTO 'dancesstepsmap' VALUES (9559, 8629, 1);
INSERT INTO 'dancesstepsmap' VALUES (9560, 8629, 3);
INSERT INTO 'dancesstepsmap' VALUES (9561, 8629, 2);
INSERT INTO 'dancesstepsmap' VALUES (9562, 8630, 4);
INSERT INTO 'dancesstepsmap' VALUES (9563, 8630, 5);
INSERT INTO 'dancesstepsmap' VALUES (9564, 3020, 1);
INSERT INTO 'dancesstepsmap' VALUES (9565, 3020, 2);
INSERT INTO 'dancesstepsmap' VALUES (9566, 3020, 3);
INSERT INTO 'dancesstepsmap' VALUES (9567, 3020, 4);
INSERT INTO 'dancesstepsmap' VALUES (9568, 3020, 5);
INSERT INTO 'dancesstepsmap' VALUES (9569, 4335, 2);
INSERT INTO 'dancesstepsmap' VALUES (9570, 4335, 3);
INSERT INTO 'dancesstepsmap' VALUES (9571, 4335, 1);
INSERT INTO 'dancesstepsmap' VALUES (9572, 7704, 3);
INSERT INTO 'dancesstepsmap' VALUES (9573, 7704, 1);
INSERT INTO 'dancesstepsmap' VALUES (9574, 7704, 2);
INSERT INTO 'dancesstepsmap' VALUES (9575, 8631, 1);
INSERT INTO 'dancesstepsmap' VALUES (9576, 8631, 2);
INSERT INTO 'dancesstepsmap' VALUES (9577, 8632, 2);
INSERT INTO 'dancesstepsmap' VALUES (9578, 8632, 1);
INSERT INTO 'dancesstepsmap' VALUES (9579, 8633, 1);
INSERT INTO 'dancesstepsmap' VALUES (9580, 8633, 3);
INSERT INTO 'dancesstepsmap' VALUES (9581, 8634, 4);
INSERT INTO 'dancesstepsmap' VALUES (9582, 8635, 5);
INSERT INTO 'dancesstepsmap' VALUES (9583, 8636, 5);
INSERT INTO 'dancesstepsmap' VALUES (9584, 8636, 4);
INSERT INTO 'dancesstepsmap' VALUES (9585, 8638, 1);
INSERT INTO 'dancesstepsmap' VALUES (9586, 8639, 1);
INSERT INTO 'dancesstepsmap' VALUES (9587, 8639, 2);
INSERT INTO 'dancesstepsmap' VALUES (9588, 8641, 4);
INSERT INTO 'dancesstepsmap' VALUES (9589, 8641, 5);
INSERT INTO 'dancesstepsmap' VALUES (9590, 8645, 1);
INSERT INTO 'dancesstepsmap' VALUES (9591, 8645, 2);
INSERT INTO 'dancesstepsmap' VALUES (9592, 8646, 2);
INSERT INTO 'dancesstepsmap' VALUES (9593, 8646, 1);
INSERT INTO 'dancesstepsmap' VALUES (9594, 8647, 1);
INSERT INTO 'dancesstepsmap' VALUES (9595, 8647, 2);
INSERT INTO 'dancesstepsmap' VALUES (9596, 8647, 3);
INSERT INTO 'dancesstepsmap' VALUES (9597, 3232, 5);
INSERT INTO 'dancesstepsmap' VALUES (9598, 3232, 4);
INSERT INTO 'dancesstepsmap' VALUES (9599, 8648, 4);
INSERT INTO 'dancesstepsmap' VALUES (9600, 8649, 1);
INSERT INTO 'dancesstepsmap' VALUES (9601, 8649, 3);
INSERT INTO 'dancesstepsmap' VALUES (9602, 8649, 2);
INSERT INTO 'dancesstepsmap' VALUES (9603, 8650, 1);
INSERT INTO 'dancesstepsmap' VALUES (9604, 8650, 2);
INSERT INTO 'dancesstepsmap' VALUES (9605, 8105, 2);
INSERT INTO 'dancesstepsmap' VALUES (9606, 8105, 3);
INSERT INTO 'dancesstepsmap' VALUES (9607, 8652, 1);
INSERT INTO 'dancesstepsmap' VALUES (9608, 8652, 2);
INSERT INTO 'dancesstepsmap' VALUES (9609, 8653, 1);
INSERT INTO 'dancesstepsmap' VALUES (9610, 8653, 2);
INSERT INTO 'dancesstepsmap' VALUES (9611, 8655, 4);
INSERT INTO 'dancesstepsmap' VALUES (9612, 8656, 1);
INSERT INTO 'dancesstepsmap' VALUES (9613, 8657, 4);
INSERT INTO 'dancesstepsmap' VALUES (9614, 8657, 5);
INSERT INTO 'dancesstepsmap' VALUES (9615, 8658, 1);
INSERT INTO 'dancesstepsmap' VALUES (9616, 8659, 1);
INSERT INTO 'dancesstepsmap' VALUES (9617, 8659, 3);
INSERT INTO 'dancesstepsmap' VALUES (9618, 8660, 6);
INSERT INTO 'dancesstepsmap' VALUES (9619, 8660, 4);
INSERT INTO 'dancesstepsmap' VALUES (9620, 8661, 1);
INSERT INTO 'dancesstepsmap' VALUES (9621, 8662, 1);
INSERT INTO 'dancesstepsmap' VALUES (9622, 8663, 1);
INSERT INTO 'dancesstepsmap' VALUES (9623, 8664, 10);
INSERT INTO 'dancesstepsmap' VALUES (9624, 8664, 3);
INSERT INTO 'dancesstepsmap' VALUES (9625, 8664, 1);
INSERT INTO 'dancesstepsmap' VALUES (9626, 8665, 3);
INSERT INTO 'dancesstepsmap' VALUES (9627, 8665, 1);
INSERT INTO 'dancesstepsmap' VALUES (9628, 8666, 1);
INSERT INTO 'dancesstepsmap' VALUES (9629, 8667, 2);
INSERT INTO 'dancesstepsmap' VALUES (9630, 8667, 1);
INSERT INTO 'dancesstepsmap' VALUES (9631, 8667, 3);
INSERT INTO 'dancesstepsmap' VALUES (9632, 8668, 1);
INSERT INTO 'dancesstepsmap' VALUES (9633, 8669, 6);
INSERT INTO 'dancesstepsmap' VALUES (9634, 8669, 4);
INSERT INTO 'dancesstepsmap' VALUES (9635, 8669, 5);
INSERT INTO 'dancesstepsmap' VALUES (9636, 8670, 1);
INSERT INTO 'dancesstepsmap' VALUES (9637, 8672, 4);
INSERT INTO 'dancesstepsmap' VALUES (9638, 8672, 5);
INSERT INTO 'dancesstepsmap' VALUES (9639, 8673, 1);
INSERT INTO 'dancesstepsmap' VALUES (9640, 8674, 2);
INSERT INTO 'dancesstepsmap' VALUES (9641, 8674, 1);
INSERT INTO 'dancesstepsmap' VALUES (9642, 8675, 1);
INSERT INTO 'dancesstepsmap' VALUES (9643, 8676, 4);
INSERT INTO 'dancesstepsmap' VALUES (9644, 8677, 4);
INSERT INTO 'dancesstepsmap' VALUES (9645, 8677, 5);
INSERT INTO 'dancesstepsmap' VALUES (9646, 8678, 1);
INSERT INTO 'dancesstepsmap' VALUES (9647, 8678, 2);
INSERT INTO 'dancesstepsmap' VALUES (9648, 8679, 1);
INSERT INTO 'dancesstepsmap' VALUES (9649, 8680, 3);
INSERT INTO 'dancesstepsmap' VALUES (9650, 8681, 4);
INSERT INTO 'dancesstepsmap' VALUES (9651, 8682, 1);
INSERT INTO 'dancesstepsmap' VALUES (9652, 8683, 1);
INSERT INTO 'dancesstepsmap' VALUES (9653, 8683, 2);
INSERT INTO 'dancesstepsmap' VALUES (9654, 8684, 1);
INSERT INTO 'dancesstepsmap' VALUES (9655, 8684, 3);
INSERT INTO 'dancesstepsmap' VALUES (9656, 8685, 1);
INSERT INTO 'dancesstepsmap' VALUES (9657, 8685, 2);
INSERT INTO 'dancesstepsmap' VALUES (9658, 8686, 4);
INSERT INTO 'dancesstepsmap' VALUES (9659, 8687, 1);
INSERT INTO 'dancesstepsmap' VALUES (9660, 8689, 4);
INSERT INTO 'dancesstepsmap' VALUES (9661, 8689, 5);
INSERT INTO 'dancesstepsmap' VALUES (9662, 8691, 2);
INSERT INTO 'dancesstepsmap' VALUES (9663, 8691, 1);
INSERT INTO 'dancesstepsmap' VALUES (9664, 8692, 1);
INSERT INTO 'dancesstepsmap' VALUES (9665, 8693, 4);
INSERT INTO 'dancesstepsmap' VALUES (9666, 8693, 5);
INSERT INTO 'dancesstepsmap' VALUES (9667, 8694, 4);
INSERT INTO 'dancesstepsmap' VALUES (9668, 8694, 5);
INSERT INTO 'dancesstepsmap' VALUES (9669, 8695, 1);
INSERT INTO 'dancesstepsmap' VALUES (9670, 8695, 3);
INSERT INTO 'dancesstepsmap' VALUES (9671, 8696, 4);
INSERT INTO 'dancesstepsmap' VALUES (9672, 8697, 1);
INSERT INTO 'dancesstepsmap' VALUES (9673, 8698, 1);
INSERT INTO 'dancesstepsmap' VALUES (9674, 8698, 3);
INSERT INTO 'dancesstepsmap' VALUES (9675, 8700, 1);
INSERT INTO 'dancesstepsmap' VALUES (9676, 8701, 1);
INSERT INTO 'dancesstepsmap' VALUES (9677, 8701, 3);
INSERT INTO 'dancesstepsmap' VALUES (9678, 8703, 1);
INSERT INTO 'dancesstepsmap' VALUES (9679, 8704, 3);
INSERT INTO 'dancesstepsmap' VALUES (9681, 8709, 1);
INSERT INTO 'dancesstepsmap' VALUES (9682, 8709, 2);
INSERT INTO 'dancesstepsmap' VALUES (9683, 8710, 1);
INSERT INTO 'dancesstepsmap' VALUES (9684, 8710, 2);
INSERT INTO 'dancesstepsmap' VALUES (9685, 8712, 1);
INSERT INTO 'dancesstepsmap' VALUES (9686, 8712, 2);
INSERT INTO 'dancesstepsmap' VALUES (9687, 8713, 4);
INSERT INTO 'dancesstepsmap' VALUES (9688, 8713, 5);
INSERT INTO 'dancesstepsmap' VALUES (9689, 8715, 1);
INSERT INTO 'dancesstepsmap' VALUES (9690, 8716, 1);
INSERT INTO 'dancesstepsmap' VALUES (9691, 8717, 4);
INSERT INTO 'dancesstepsmap' VALUES (9692, 8718, 4);
INSERT INTO 'dancesstepsmap' VALUES (9693, 8719, 4);
INSERT INTO 'dancesstepsmap' VALUES (9694, 8721, 2);
INSERT INTO 'dancesstepsmap' VALUES (9695, 8721, 1);
INSERT INTO 'dancesstepsmap' VALUES (9696, 929, 3);
INSERT INTO 'dancesstepsmap' VALUES (9697, 929, 2);
INSERT INTO 'dancesstepsmap' VALUES (9698, 964, 6);
INSERT INTO 'dancesstepsmap' VALUES (9699, 976, 1);
INSERT INTO 'dancesstepsmap' VALUES (9700, 1066, 5);
INSERT INTO 'dancesstepsmap' VALUES (9701, 1230, 2);
INSERT INTO 'dancesstepsmap' VALUES (9702, 1230, 3);
INSERT INTO 'dancesstepsmap' VALUES (9703, 1549, 3);
INSERT INTO 'dancesstepsmap' VALUES (9704, 1686, 10);
INSERT INTO 'dancesstepsmap' VALUES (9705, 1686, 2);
INSERT INTO 'dancesstepsmap' VALUES (9706, 1747, 10);
INSERT INTO 'dancesstepsmap' VALUES (9707, 1775, 6);
INSERT INTO 'dancesstepsmap' VALUES (9708, 1775, 5);
INSERT INTO 'dancesstepsmap' VALUES (9709, 1802, 6);
INSERT INTO 'dancesstepsmap' VALUES (9710, 1802, 10);
INSERT INTO 'dancesstepsmap' VALUES (9711, 1934, 2);
INSERT INTO 'dancesstepsmap' VALUES (9712, 1934, 3);
INSERT INTO 'dancesstepsmap' VALUES (9713, 2119, 3);
INSERT INTO 'dancesstepsmap' VALUES (9714, 2190, 3);
INSERT INTO 'dancesstepsmap' VALUES (9715, 2321, 5);
INSERT INTO 'dancesstepsmap' VALUES (9716, 2351, 3);
INSERT INTO 'dancesstepsmap' VALUES (9717, 2770, 2);
INSERT INTO 'dancesstepsmap' VALUES (9718, 2809, 3);
INSERT INTO 'dancesstepsmap' VALUES (9719, 2922, 2);
INSERT INTO 'dancesstepsmap' VALUES (9720, 2952, 2);
INSERT INTO 'dancesstepsmap' VALUES (9721, 3172, 2);
INSERT INTO 'dancesstepsmap' VALUES (9722, 3300, 3);
INSERT INTO 'dancesstepsmap' VALUES (9723, 3527, 5);
INSERT INTO 'dancesstepsmap' VALUES (9724, 3557, 3);
INSERT INTO 'dancesstepsmap' VALUES (9725, 3957, 3);
INSERT INTO 'dancesstepsmap' VALUES (9726, 4011, 10);
INSERT INTO 'dancesstepsmap' VALUES (9727, 4230, 3);
INSERT INTO 'dancesstepsmap' VALUES (9728, 4282, 6);
INSERT INTO 'dancesstepsmap' VALUES (9729, 4282, 10);
INSERT INTO 'dancesstepsmap' VALUES (9730, 4256, 6);
INSERT INTO 'dancesstepsmap' VALUES (9731, 4704, 2);
INSERT INTO 'dancesstepsmap' VALUES (9732, 4704, 3);
INSERT INTO 'dancesstepsmap' VALUES (9733, 5157, 2);
INSERT INTO 'dancesstepsmap' VALUES (9734, 5179, 3);
INSERT INTO 'dancesstepsmap' VALUES (9735, 5189, 3);
INSERT INTO 'dancesstepsmap' VALUES (9736, 5422, 1);
INSERT INTO 'dancesstepsmap' VALUES (9737, 5427, 2);
INSERT INTO 'dancesstepsmap' VALUES (9738, 5744, 2);
INSERT INTO 'dancesstepsmap' VALUES (9739, 5744, 3);
INSERT INTO 'dancesstepsmap' VALUES (9740, 5422, 10);
INSERT INTO 'dancesstepsmap' VALUES (9741, 5422, 2);
INSERT INTO 'dancesstepsmap' VALUES (9743, 6196, 5);
INSERT INTO 'dancesstepsmap' VALUES (9744, 6336, 5);
INSERT INTO 'dancesstepsmap' VALUES (9745, 6431, 3);
INSERT INTO 'dancesstepsmap' VALUES (9746, 1302, 4);
INSERT INTO 'dancesstepsmap' VALUES (9747, 3068, 5);
INSERT INTO 'dancesstepsmap' VALUES (9748, 3068, 4);
INSERT INTO 'dancesstepsmap' VALUES (9749, 7061, 2);
INSERT INTO 'dancesstepsmap' VALUES (9750, 7465, 2);
INSERT INTO 'dancesstepsmap' VALUES (9751, 7475, 3);
INSERT INTO 'dancesstepsmap' VALUES (9752, 7527, 2);
INSERT INTO 'dancesstepsmap' VALUES (9753, 7534, 5);
INSERT INTO 'dancesstepsmap' VALUES (9754, 7650, 2);
INSERT INTO 'dancesstepsmap' VALUES (9755, 7652, 2);
INSERT INTO 'dancesstepsmap' VALUES (9756, 7652, 3);
INSERT INTO 'dancesstepsmap' VALUES (9757, 7669, 10);
INSERT INTO 'dancesstepsmap' VALUES (9758, 7811, 2);
INSERT INTO 'dancesstepsmap' VALUES (9759, 7966, 3);
INSERT INTO 'dancesstepsmap' VALUES (9760, 7966, 2);
INSERT INTO 'dancesstepsmap' VALUES (9761, 7967, 10);
INSERT INTO 'dancesstepsmap' VALUES (9762, 7967, 3);
INSERT INTO 'dancesstepsmap' VALUES (9763, 7967, 2);
INSERT INTO 'dancesstepsmap' VALUES (9764, 7980, 5);
INSERT INTO 'dancesstepsmap' VALUES (9765, 8088, 2);
INSERT INTO 'dancesstepsmap' VALUES (9766, 8088, 3);
INSERT INTO 'dancesstepsmap' VALUES (9767, 8120, 5);
INSERT INTO 'dancesstepsmap' VALUES (9768, 8125, 5);
INSERT INTO 'dancesstepsmap' VALUES (9769, 8165, 2);
INSERT INTO 'dancesstepsmap' VALUES (9770, 8173, 2);
INSERT INTO 'dancesstepsmap' VALUES (9771, 8348, 5);
INSERT INTO 'dancesstepsmap' VALUES (9772, 8562, 5);
INSERT INTO 'dancesstepsmap' VALUES (9773, 2786, 2);
INSERT INTO 'dancesstepsmap' VALUES (9774, 2786, 1);
INSERT INTO 'dancesstepsmap' VALUES (9775, 5171, 1);
INSERT INTO 'dancesstepsmap' VALUES (9776, 6479, 1);
INSERT INTO 'dancesstepsmap' VALUES (9777, 6479, 2);
INSERT INTO 'dancesstepsmap' VALUES (9778, 6490, 1);
INSERT INTO 'dancesstepsmap' VALUES (9779, 6490, 3);
INSERT INTO 'dancesstepsmap' VALUES (9780, 6490, 2);
INSERT INTO 'dancesstepsmap' VALUES (9781, 8723, 1);
INSERT INTO 'dancesstepsmap' VALUES (9782, 8723, 2);
INSERT INTO 'dancesstepsmap' VALUES (9783, 8723, 3);
INSERT INTO 'dancesstepsmap' VALUES (9784, 5145, 1);
INSERT INTO 'dancesstepsmap' VALUES (9785, 8724, 1);
INSERT INTO 'dancesstepsmap' VALUES (9786, 8726, 3);
INSERT INTO 'dancesstepsmap' VALUES (9787, 8727, 1);
INSERT INTO 'dancesstepsmap' VALUES (9788, 8728, 1);
INSERT INTO 'dancesstepsmap' VALUES (9789, 8728, 2);
INSERT INTO 'dancesstepsmap' VALUES (9790, 8624, 4);
INSERT INTO 'dancesstepsmap' VALUES (9791, 7611, 1);
INSERT INTO 'dancesstepsmap' VALUES (9792, 7612, 1);
INSERT INTO 'dancesstepsmap' VALUES (9793, 7612, 2);
INSERT INTO 'dancesstepsmap' VALUES (9794, 7613, 3);
INSERT INTO 'dancesstepsmap' VALUES (9795, 7613, 1);
INSERT INTO 'dancesstepsmap' VALUES (9796, 7613, 2);
INSERT INTO 'dancesstepsmap' VALUES (9797, 8729, 1);
INSERT INTO 'dancesstepsmap' VALUES (9798, 8729, 3);
INSERT INTO 'dancesstepsmap' VALUES (9799, 8730, 4);
INSERT INTO 'dancesstepsmap' VALUES (9800, 8730, 5);
INSERT INTO 'dancesstepsmap' VALUES (9801, 8735, 1);
INSERT INTO 'dancesstepsmap' VALUES (9802, 8736, 1);
INSERT INTO 'dancesstepsmap' VALUES (9803, 8736, 2);
INSERT INTO 'dancesstepsmap' VALUES (9804, 8736, 3);
INSERT INTO 'dancesstepsmap' VALUES (9805, 8739, 1);
INSERT INTO 'dancesstepsmap' VALUES (9806, 8739, 2);
INSERT INTO 'dancesstepsmap' VALUES (9807, 8742, 4);
INSERT INTO 'dancesstepsmap' VALUES (9808, 8743, 1);
INSERT INTO 'dancesstepsmap' VALUES (9809, 684, 3);
INSERT INTO 'dancesstepsmap' VALUES (9810, 3119, 1);
INSERT INTO 'dancesstepsmap' VALUES (9811, 3119, 3);
INSERT INTO 'dancesstepsmap' VALUES (9812, 3119, 4);
INSERT INTO 'dancesstepsmap' VALUES (9813, 8792, 1);
INSERT INTO 'dancesstepsmap' VALUES (9814, 5536, 5);
INSERT INTO 'dancesstepsmap' VALUES (9815, 8734, 1);
INSERT INTO 'dancesstepsmap' VALUES (9816, 8793, 4);
INSERT INTO 'dancesstepsmap' VALUES (9817, 8796, 1);
INSERT INTO 'dancesstepsmap' VALUES (9818, 8797, 4);
INSERT INTO 'dancesstepsmap' VALUES (9819, 8798, 1);
INSERT INTO 'dancesstepsmap' VALUES (9820, 8799, 1);
INSERT INTO 'dancesstepsmap' VALUES (9821, 8800, 4);
INSERT INTO 'dancesstepsmap' VALUES (9822, 8801, 1);
INSERT INTO 'dancesstepsmap' VALUES (9823, 8805, 1);
INSERT INTO 'dancesstepsmap' VALUES (9824, 8806, 4);
INSERT INTO 'dancesstepsmap' VALUES (9825, 2419, 3);
INSERT INTO 'dancesstepsmap' VALUES (9826, 8809, 4);
INSERT INTO 'dancesstepsmap' VALUES (9827, 8809, 5);
INSERT INTO 'dancesstepsmap' VALUES (9828, 8810, 4);
INSERT INTO 'dancesstepsmap' VALUES (9829, 1203, 3);
INSERT INTO 'dancesstepsmap' VALUES (9830, 1203, 2);
INSERT INTO 'dancesstepsmap' VALUES (9831, 4819, 4);
INSERT INTO 'dancesstepsmap' VALUES (9832, 4819, 5);
INSERT INTO 'dancesstepsmap' VALUES (9833, 8811, 3);
INSERT INTO 'dancesstepsmap' VALUES (9834, 8811, 2);
INSERT INTO 'dancesstepsmap' VALUES (9835, 8812, 2);
INSERT INTO 'dancesstepsmap' VALUES (9836, 8812, 1);
INSERT INTO 'dancesstepsmap' VALUES (9837, 8813, 4);
INSERT INTO 'dancesstepsmap' VALUES (9838, 8814, 4);
INSERT INTO 'dancesstepsmap' VALUES (9839, 8817, 1);
INSERT INTO 'dancesstepsmap' VALUES (9840, 6899, 2);
INSERT INTO 'dancesstepsmap' VALUES (9841, 6563, 3);
INSERT INTO 'dancesstepsmap' VALUES (9842, 6563, 2);
INSERT INTO 'dancesstepsmap' VALUES (9843, 8811, 1);
INSERT INTO 'dancesstepsmap' VALUES (9844, 8829, 2);
INSERT INTO 'dancesstepsmap' VALUES (9845, 8829, 3);
INSERT INTO 'dancesstepsmap' VALUES (9846, 8829, 1);
INSERT INTO 'dancesstepsmap' VALUES (9847, 4144, 3);
INSERT INTO 'dancesstepsmap' VALUES (9848, 6657, 3);
INSERT INTO 'dancesstepsmap' VALUES (9849, 3197, 2);
INSERT INTO 'dancesstepsmap' VALUES (9850, 1044, 2);
INSERT INTO 'dancesstepsmap' VALUES (9851, 962, 5);
INSERT INTO 'dancesstepsmap' VALUES (9852, 6657, 2);
INSERT INTO 'dancesstepsmap' VALUES (9853, 2244, 5);
INSERT INTO 'dancesstepsmap' VALUES (9854, 4497, 3);
INSERT INTO 'dancesstepsmap' VALUES (9855, 4497, 4);
INSERT INTO 'dancesstepsmap' VALUES (9856, 4497, 5);
INSERT INTO 'dancesstepsmap' VALUES (9857, 4497, 8);
INSERT INTO 'dancesstepsmap' VALUES (9858, 4497, 1);
INSERT INTO 'dancesstepsmap' VALUES (9859, 4497, 2);
INSERT INTO 'dancesstepsmap' VALUES (9860, 6556, 2);
INSERT INTO 'dancesstepsmap' VALUES (9861, 5998, 2);
INSERT INTO 'dancesstepsmap' VALUES (9862, 5998, 1);
INSERT INTO 'dancesstepsmap' VALUES (9863, 5998, 3);
INSERT INTO 'dancesstepsmap' VALUES (9864, 5998, 4);
INSERT INTO 'dancesstepsmap' VALUES (9865, 5998, 5);
INSERT INTO 'dancesstepsmap' VALUES (9866, 3367, 2);
INSERT INTO 'dancesstepsmap' VALUES (9867, 6568, 2);
INSERT INTO 'dancesstepsmap' VALUES (9868, 6568, 4);
INSERT INTO 'dancesstepsmap' VALUES (9869, 6568, 5);
INSERT INTO 'dancesstepsmap' VALUES (9870, 6568, 10);
INSERT INTO 'dancesstepsmap' VALUES (9871, 6568, 3);
INSERT INTO 'dancesstepsmap' VALUES (9872, 6568, 1);
INSERT INTO 'dancesstepsmap' VALUES (9873, 7450, 1);
INSERT INTO 'dancesstepsmap' VALUES (9874, 8859, 4);
INSERT INTO 'dancesstepsmap' VALUES (9875, 8859, 5);
INSERT INTO 'dancesstepsmap' VALUES (9876, 7084, 4);
INSERT INTO 'dancesstepsmap' VALUES (9877, 7084, 5);
INSERT INTO 'dancesstepsmap' VALUES (9878, 8863, 3);
INSERT INTO 'dancesstepsmap' VALUES (9879, 6995, 2);
INSERT INTO 'dancesstepsmap' VALUES (9880, 8864, 2);
INSERT INTO 'dancesstepsmap' VALUES (9881, 8864, 1);
INSERT INTO 'dancesstepsmap' VALUES (9882, 8864, 3);
INSERT INTO 'dancesstepsmap' VALUES (9883, 8921, 4);
INSERT INTO 'dancesstepsmap' VALUES (9884, 8922, 1);
INSERT INTO 'dancesstepsmap' VALUES (9885, 8922, 2);
INSERT INTO 'dancesstepsmap' VALUES (9886, 8956, 2);
INSERT INTO 'dancesstepsmap' VALUES (9887, 8956, 1);
INSERT INTO 'dancesstepsmap' VALUES (9888, 8957, 2);
INSERT INTO 'dancesstepsmap' VALUES (9889, 8957, 10);
INSERT INTO 'dancesstepsmap' VALUES (9890, 8958, 4);
INSERT INTO 'dancesstepsmap' VALUES (9891, 8960, 1);
INSERT INTO 'dancesstepsmap' VALUES (9892, 8961, 1);
INSERT INTO 'dancesstepsmap' VALUES (9893, 8962, 4);
INSERT INTO 'dancesstepsmap' VALUES (9894, 8963, 3);
INSERT INTO 'dancesstepsmap' VALUES (9895, 8967, 4);
INSERT INTO 'dancesstepsmap' VALUES (9896, 8967, 5);
INSERT INTO 'dancesstepsmap' VALUES (9897, 8967, 1);
INSERT INTO 'dancesstepsmap' VALUES (9898, 8967, 2);
INSERT INTO 'dancesstepsmap' VALUES (9899, 8968, 4);
INSERT INTO 'dancesstepsmap' VALUES (9900, 8968, 5);
INSERT INTO 'dancesstepsmap' VALUES (9901, 8969, 2);
INSERT INTO 'dancesstepsmap' VALUES (9902, 8969, 1);
INSERT INTO 'dancesstepsmap' VALUES (9903, 8970, 1);
INSERT INTO 'dancesstepsmap' VALUES (9904, 8970, 2);
INSERT INTO 'dancesstepsmap' VALUES (9905, 8971, 1);
INSERT INTO 'dancesstepsmap' VALUES (9906, 8971, 2);
INSERT INTO 'dancesstepsmap' VALUES (9907, 8972, 4);
INSERT INTO 'dancesstepsmap' VALUES (9908, 8973, 1);
INSERT INTO 'dancesstepsmap' VALUES (9909, 8974, 1);
INSERT INTO 'dancesstepsmap' VALUES (9910, 8974, 2);
INSERT INTO 'dancesstepsmap' VALUES (9911, 6861, 2);
INSERT INTO 'dancesstepsmap' VALUES (9912, 6861, 3);
INSERT INTO 'dancesstepsmap' VALUES (9913, 8978, 3);
INSERT INTO 'dancesstepsmap' VALUES (9914, 8978, 1);
INSERT INTO 'dancesstepsmap' VALUES (9915, 8979, 1);
INSERT INTO 'dancesstepsmap' VALUES (9916, 8980, 1);
INSERT INTO 'dancesstepsmap' VALUES (9917, 8981, 3);
INSERT INTO 'dancesstepsmap' VALUES (9918, 8981, 2);
INSERT INTO 'dancesstepsmap' VALUES (9919, 8981, 1);
INSERT INTO 'dancesstepsmap' VALUES (9920, 8982, 4);
INSERT INTO 'dancesstepsmap' VALUES (9921, 8983, 1);
INSERT INTO 'dancesstepsmap' VALUES (9922, 8983, 3);
INSERT INTO 'dancesstepsmap' VALUES (9923, 8983, 2);
INSERT INTO 'dancesstepsmap' VALUES (9924, 8994, 4);
INSERT INTO 'dancesstepsmap' VALUES (9925, 8995, 1);
INSERT INTO 'dancesstepsmap' VALUES (9926, 8999, 4);
INSERT INTO 'dancesstepsmap' VALUES (9927, 9000, 1);
INSERT INTO 'dancesstepsmap' VALUES (9928, 9029, 1);
INSERT INTO 'dancesstepsmap' VALUES (9929, 9040, 1);
INSERT INTO 'dancesstepsmap' VALUES (9930, 9040, 2);
INSERT INTO 'dancesstepsmap' VALUES (13595, 11878, 2);
INSERT INTO 'dancesstepsmap' VALUES (13596, 11878, 1);
INSERT INTO 'dancesstepsmap' VALUES (13597, 11879, 5);
INSERT INTO 'dancesstepsmap' VALUES (13598, 11879, 4);
INSERT INTO 'dancesstepsmap' VALUES (13599, 11880, 2);
INSERT INTO 'dancesstepsmap' VALUES (13600, 11880, 1);
INSERT INTO 'dancesstepsmap' VALUES (13601, 11881, 5);
INSERT INTO 'dancesstepsmap' VALUES (13602, 11881, 4);
INSERT INTO 'dancesstepsmap' VALUES (13603, 11882, 2);
INSERT INTO 'dancesstepsmap' VALUES (13604, 11883, 4);
INSERT INTO 'dancesstepsmap' VALUES (13605, 11883, 5);
INSERT INTO 'dancesstepsmap' VALUES (13606, 11884, 1);
INSERT INTO 'dancesstepsmap' VALUES (13607, 11887, 1);
INSERT INTO 'dancesstepsmap' VALUES (13608, 11887, 2);
INSERT INTO 'dancesstepsmap' VALUES (13609, 11888, 5);
INSERT INTO 'dancesstepsmap' VALUES (13610, 11888, 4);
INSERT INTO 'dancesstepsmap' VALUES (13611, 11889, 10);
INSERT INTO 'dancesstepsmap' VALUES (13612, 11889, 1);
INSERT INTO 'dancesstepsmap' VALUES (13613, 11889, 2);
INSERT INTO 'dancesstepsmap' VALUES (13614, 11890, 1);
INSERT INTO 'dancesstepsmap' VALUES (13615, 6148, 2);
INSERT INTO 'dancesstepsmap' VALUES (13616, 11891, 2);
INSERT INTO 'dancesstepsmap' VALUES (13617, 11891, 1);
INSERT INTO 'dancesstepsmap' VALUES (13618, 11892, 2);
INSERT INTO 'dancesstepsmap' VALUES (13619, 11892, 1);
INSERT INTO 'dancesstepsmap' VALUES (13620, 11893, 1);
INSERT INTO 'dancesstepsmap' VALUES (13621, 11894, 2);
INSERT INTO 'dancesstepsmap' VALUES (13622, 11894, 1);
INSERT INTO 'dancesstepsmap' VALUES (13623, 11896, 1);
INSERT INTO 'dancesstepsmap' VALUES (13624, 11897, 1);
INSERT INTO 'dancesstepsmap' VALUES (13625, 11897, 3);
INSERT INTO 'dancesstepsmap' VALUES (13626, 11898, 2);
INSERT INTO 'dancesstepsmap' VALUES (13627, 11898, 1);
INSERT INTO 'dancesstepsmap' VALUES (13628, 7359, 4);
INSERT INTO 'dancesstepsmap' VALUES (13629, 7359, 5);
INSERT INTO 'dancesstepsmap' VALUES (13630, 7359, 1);
INSERT INTO 'dancesstepsmap' VALUES (13631, 7359, 3);
INSERT INTO 'dancesstepsmap' VALUES (13632, 7617, 2);
INSERT INTO 'dancesstepsmap' VALUES (13633, 5540, 2);
INSERT INTO 'dancesstepsmap' VALUES (13634, 8006, 2);
INSERT INTO 'dancesstepsmap' VALUES (13635, 8006, 3);
INSERT INTO 'dancesstepsmap' VALUES (13636, 11900, 2);
INSERT INTO 'dancesstepsmap' VALUES (13637, 11900, 1);
INSERT INTO 'dancesstepsmap' VALUES (13638, 11900, 4);
INSERT INTO 'dancesstepsmap' VALUES (13639, 11901, 1);
INSERT INTO 'dancesstepsmap' VALUES (13640, 11901, 3);
INSERT INTO 'dancesstepsmap' VALUES (13641, 11902, 1);
INSERT INTO 'dancesstepsmap' VALUES (13642, 11903, 1);
INSERT INTO 'dancesstepsmap' VALUES (13643, 11903, 3);
INSERT INTO 'dancesstepsmap' VALUES (13644, 3839, 3);
INSERT INTO 'dancesstepsmap' VALUES (13645, 3839, 1);
INSERT INTO 'dancesstepsmap' VALUES (13646, 3839, 2);
INSERT INTO 'dancesstepsmap' VALUES (13647, 6305, 3);
INSERT INTO 'dancesstepsmap' VALUES (13648, 6305, 2);
INSERT INTO 'dancesstepsmap' VALUES (13649, 6554, 2);
INSERT INTO 'dancesstepsmap' VALUES (13650, 6554, 1);
INSERT INTO 'dancesstepsmap' VALUES (13651, 6554, 3);
INSERT INTO 'dancesstepsmap' VALUES (13652, 1371, 4);
INSERT INTO 'dancesstepsmap' VALUES (13653, 1371, 1);
INSERT INTO 'dancesstepsmap' VALUES (13654, 1371, 2);
INSERT INTO 'dancesstepsmap' VALUES (13655, 1371, 3);
INSERT INTO 'dancesstepsmap' VALUES (13656, 7008, 5);
INSERT INTO 'dancesstepsmap' VALUES (13657, 255, 5);
INSERT INTO 'dancesstepsmap' VALUES (13658, 5337, 2);
INSERT INTO 'dancesstepsmap' VALUES (13659, 5634, 2);
INSERT INTO 'dancesstepsmap' VALUES (13660, 9168, 2);
INSERT INTO 'dancesstepsmap' VALUES (13661, 9168, 3);
INSERT INTO 'dancesstepsmap' VALUES (13662, 9168, 1);
INSERT INTO 'dancesstepsmap' VALUES (13663, 9778, 1);
INSERT INTO 'dancesstepsmap' VALUES (13664, 9779, 4);
INSERT INTO 'dancesstepsmap' VALUES (13665, 9779, 5);
INSERT INTO 'dancesstepsmap' VALUES (13666, 9780, 1);
INSERT INTO 'dancesstepsmap' VALUES (13667, 9781, 1);
INSERT INTO 'dancesstepsmap' VALUES (13668, 9781, 2);
INSERT INTO 'dancesstepsmap' VALUES (13669, 9781, 3);
INSERT INTO 'dancesstepsmap' VALUES (13670, 4841, 2);
INSERT INTO 'dancesstepsmap' VALUES (13671, 4841, 3);
INSERT INTO 'dancesstepsmap' VALUES (13672, 9782, 5);
INSERT INTO 'dancesstepsmap' VALUES (13673, 9782, 4);
INSERT INTO 'dancesstepsmap' VALUES (13674, 9783, 4);
INSERT INTO 'dancesstepsmap' VALUES (13675, 9783, 5);
INSERT INTO 'dancesstepsmap' VALUES (13676, 5777, 8);
INSERT INTO 'dancesstepsmap' VALUES (13677, 9784, 99);
INSERT INTO 'dancesstepsmap' VALUES (13678, 9784, 1);
INSERT INTO 'dancesstepsmap' VALUES (13679, 9785, 1);
INSERT INTO 'dancesstepsmap' VALUES (13680, 9785, 2);
INSERT INTO 'dancesstepsmap' VALUES (13681, 9786, 3);
INSERT INTO 'dancesstepsmap' VALUES (13682, 9786, 1);
INSERT INTO 'dancesstepsmap' VALUES (13683, 9786, 9);
INSERT INTO 'dancesstepsmap' VALUES (13684, 9786, 2);
INSERT INTO 'dancesstepsmap' VALUES (13685, 3839, 4);
INSERT INTO 'dancesstepsmap' VALUES (13686, 4451, 5);
INSERT INTO 'dancesstepsmap' VALUES (13687, 6323, 5);
INSERT INTO 'dancesstepsmap' VALUES (13688, 2427, 2);
INSERT INTO 'dancesstepsmap' VALUES (13689, 6532, 2);
INSERT INTO 'dancesstepsmap' VALUES (13690, 6532, 5);
INSERT INTO 'dancesstepsmap' VALUES (13691, 6048, 2);
INSERT INTO 'dancesstepsmap' VALUES (13692, 6885, 5);
INSERT INTO 'dancesstepsmap' VALUES (13693, 11904, 6);
INSERT INTO 'dancesstepsmap' VALUES (13694, 11904, 5);
INSERT INTO 'dancesstepsmap' VALUES (13695, 11904, 4);
INSERT INTO 'dancesstepsmap' VALUES (13696, 11905, 1);
INSERT INTO 'dancesstepsmap' VALUES (13697, 11905, 2);
INSERT INTO 'dancesstepsmap' VALUES (13698, 11906, 1);
INSERT INTO 'dancesstepsmap' VALUES (13699, 11906, 2);
INSERT INTO 'dancesstepsmap' VALUES (13700, 11907, 2);
INSERT INTO 'dancesstepsmap' VALUES (13701, 11907, 1);
INSERT INTO 'dancesstepsmap' VALUES (13702, 11907, 3);
INSERT INTO 'dancesstepsmap' VALUES (13703, 11908, 4);
INSERT INTO 'dancesstepsmap' VALUES (13704, 11909, 1);
INSERT INTO 'dancesstepsmap' VALUES (13705, 11909, 2);
INSERT INTO 'dancesstepsmap' VALUES (13706, 11909, 3);
INSERT INTO 'dancesstepsmap' VALUES (13707, 11910, 1);
INSERT INTO 'dancesstepsmap' VALUES (13708, 11911, 4);
INSERT INTO 'dancesstepsmap' VALUES (13709, 11911, 5);
INSERT INTO 'dancesstepsmap' VALUES (13710, 11912, 1);
INSERT INTO 'dancesstepsmap' VALUES (13711, 11912, 2);
INSERT INTO 'dancesstepsmap' VALUES (13712, 11913, 4);
INSERT INTO 'dancesstepsmap' VALUES (13713, 11913, 5);
INSERT INTO 'dancesstepsmap' VALUES (13714, 11914, 2);
INSERT INTO 'dancesstepsmap' VALUES (13715, 11914, 1);
INSERT INTO 'dancesstepsmap' VALUES (13717, 11915, 1);
INSERT INTO 'dancesstepsmap' VALUES (13718, 11916, 1);
INSERT INTO 'dancesstepsmap' VALUES (13719, 11916, 2);
INSERT INTO 'dancesstepsmap' VALUES (13720, 11917, 4);
INSERT INTO 'dancesstepsmap' VALUES (13721, 11918, 1);
INSERT INTO 'dancesstepsmap' VALUES (13722, 11921, 2);
INSERT INTO 'dancesstepsmap' VALUES (13723, 11921, 1);
INSERT INTO 'dancesstepsmap' VALUES (13724, 11921, 3);
INSERT INTO 'dancesstepsmap' VALUES (13725, 11923, 2);
INSERT INTO 'dancesstepsmap' VALUES (13726, 11923, 1);
INSERT INTO 'dancesstepsmap' VALUES (13727, 11923, 3);
INSERT INTO 'dancesstepsmap' VALUES (13728, 11924, 2);
INSERT INTO 'dancesstepsmap' VALUES (13729, 11924, 1);
INSERT INTO 'dancesstepsmap' VALUES (13730, 11925, 2);
INSERT INTO 'dancesstepsmap' VALUES (13731, 11925, 1);
INSERT INTO 'dancesstepsmap' VALUES (13732, 11926, 1);
INSERT INTO 'dancesstepsmap' VALUES (13733, 11927, 1);
INSERT INTO 'dancesstepsmap' VALUES (13734, 11927, 2);
INSERT INTO 'dancesstepsmap' VALUES (13735, 11919, 2);
INSERT INTO 'dancesstepsmap' VALUES (13736, 11919, 1);
INSERT INTO 'dancesstepsmap' VALUES (13737, 11928, 1);
INSERT INTO 'dancesstepsmap' VALUES (13738, 11928, 2);
INSERT INTO 'dancesstepsmap' VALUES (13739, 11929, 1);
INSERT INTO 'dancesstepsmap' VALUES (13740, 11937, 4);
INSERT INTO 'dancesstepsmap' VALUES (13741, 11938, 4);
INSERT INTO 'dancesstepsmap' VALUES (13742, 11938, 5);
INSERT INTO 'dancesstepsmap' VALUES (13744, 11934, 1);
INSERT INTO 'dancesstepsmap' VALUES (13745, 8839, 2);
INSERT INTO 'dancesstepsmap' VALUES (13746, 11940, 1);
INSERT INTO 'dancesstepsmap' VALUES (13747, 8834, 5);
INSERT INTO 'dancesstepsmap' VALUES (13748, 11941, 2);
INSERT INTO 'dancesstepsmap' VALUES (13749, 11941, 1);
INSERT INTO 'dancesstepsmap' VALUES (13750, 11942, 2);
INSERT INTO 'dancesstepsmap' VALUES (13751, 11942, 1);
INSERT INTO 'dancesstepsmap' VALUES (13752, 11943, 4);
INSERT INTO 'dancesstepsmap' VALUES (13753, 11944, 1);
INSERT INTO 'dancesstepsmap' VALUES (13754, 11945, 1);
INSERT INTO 'dancesstepsmap' VALUES (13755, 11945, 2);
INSERT INTO 'dancesstepsmap' VALUES (13756, 8838, 2);
INSERT INTO 'dancesstepsmap' VALUES (13757, 8838, 1);
INSERT INTO 'dancesstepsmap' VALUES (13758, 8840, 1);
INSERT INTO 'dancesstepsmap' VALUES (13759, 8840, 2);
INSERT INTO 'dancesstepsmap' VALUES (13760, 11946, 1);
INSERT INTO 'dancesstepsmap' VALUES (13761, 11946, 4);
INSERT INTO 'dancesstepsmap' VALUES (13762, 11947, 4);
INSERT INTO 'dancesstepsmap' VALUES (13763, 11947, 5);
INSERT INTO 'dancesstepsmap' VALUES (13764, 11948, 4);
INSERT INTO 'dancesstepsmap' VALUES (13765, 11948, 5);
INSERT INTO 'dancesstepsmap' VALUES (13766, 11949, 1);
INSERT INTO 'dancesstepsmap' VALUES (13767, 11949, 3);
INSERT INTO 'dancesstepsmap' VALUES (13768, 11950, 4);
INSERT INTO 'dancesstepsmap' VALUES (13769, 11950, 5);
INSERT INTO 'dancesstepsmap' VALUES (13770, 11951, 1);
INSERT INTO 'dancesstepsmap' VALUES (13771, 11951, 2);
INSERT INTO 'dancesstepsmap' VALUES (13772, 11952, 2);
INSERT INTO 'dancesstepsmap' VALUES (13773, 11952, 1);
INSERT INTO 'dancesstepsmap' VALUES (13774, 11953, 4);
INSERT INTO 'dancesstepsmap' VALUES (13775, 11953, 5);
INSERT INTO 'dancesstepsmap' VALUES (13776, 11954, 1);
INSERT INTO 'dancesstepsmap' VALUES (13777, 11954, 2);
INSERT INTO 'dancesstepsmap' VALUES (13778, 11955, 4);
INSERT INTO 'dancesstepsmap' VALUES (13779, 11956, 4);
INSERT INTO 'dancesstepsmap' VALUES (13780, 11956, 5);
INSERT INTO 'dancesstepsmap' VALUES (13781, 11957, 1);
INSERT INTO 'dancesstepsmap' VALUES (13782, 11957, 2);
INSERT INTO 'dancesstepsmap' VALUES (13783, 11958, 1);
INSERT INTO 'dancesstepsmap' VALUES (13784, 11959, 2);
INSERT INTO 'dancesstepsmap' VALUES (13785, 11959, 3);
INSERT INTO 'dancesstepsmap' VALUES (13786, 11960, 1);
INSERT INTO 'dancesstepsmap' VALUES (13787, 11960, 2);
INSERT INTO 'dancesstepsmap' VALUES (13788, 11961, 4);
INSERT INTO 'dancesstepsmap' VALUES (13789, 11961, 5);
INSERT INTO 'dancesstepsmap' VALUES (13790, 11962, 5);
INSERT INTO 'dancesstepsmap' VALUES (13791, 11962, 4);
INSERT INTO 'dancesstepsmap' VALUES (13792, 11963, 1);
INSERT INTO 'dancesstepsmap' VALUES (13793, 11963, 2);
INSERT INTO 'dancesstepsmap' VALUES (13794, 11964, 1);
INSERT INTO 'dancesstepsmap' VALUES (13795, 11964, 2);
INSERT INTO 'dancesstepsmap' VALUES (13796, 11965, 4);
INSERT INTO 'dancesstepsmap' VALUES (13797, 11966, 1);
INSERT INTO 'dancesstepsmap' VALUES (13798, 11968, 1);
INSERT INTO 'dancesstepsmap' VALUES (13799, 11968, 2);
INSERT INTO 'dancesstepsmap' VALUES (13800, 11968, 3);
INSERT INTO 'dancesstepsmap' VALUES (13801, 11969, 3);
INSERT INTO 'dancesstepsmap' VALUES (13802, 11969, 1);
INSERT INTO 'dancesstepsmap' VALUES (13803, 11970, 4);
INSERT INTO 'dancesstepsmap' VALUES (13804, 11970, 5);
INSERT INTO 'dancesstepsmap' VALUES (13805, 11971, 1);
INSERT INTO 'dancesstepsmap' VALUES (13806, 11971, 5);
INSERT INTO 'dancesstepsmap' VALUES (13807, 11971, 4);
INSERT INTO 'dancesstepsmap' VALUES (13808, 11971, 2);
INSERT INTO 'dancesstepsmap' VALUES (13809, 11972, 10);
INSERT INTO 'dancesstepsmap' VALUES (13810, 11972, 4);
INSERT INTO 'dancesstepsmap' VALUES (13811, 11972, 2);
INSERT INTO 'dancesstepsmap' VALUES (13812, 11972, 1);
INSERT INTO 'dancesstepsmap' VALUES (13813, 11631, 5);
INSERT INTO 'dancesstepsmap' VALUES (13814, 11631, 4);
INSERT INTO 'dancesstepsmap' VALUES (13815, 11632, 2);
INSERT INTO 'dancesstepsmap' VALUES (13816, 11632, 1);
INSERT INTO 'dancesstepsmap' VALUES (13817, 11633, 4);
INSERT INTO 'dancesstepsmap' VALUES (13818, 11633, 5);
INSERT INTO 'dancesstepsmap' VALUES (13819, 11634, 4);
INSERT INTO 'dancesstepsmap' VALUES (13820, 11635, 2);
INSERT INTO 'dancesstepsmap' VALUES (13821, 11635, 3);
INSERT INTO 'dancesstepsmap' VALUES (13822, 11636, 2);
INSERT INTO 'dancesstepsmap' VALUES (13823, 11636, 1);
INSERT INTO 'dancesstepsmap' VALUES (13824, 11637, 4);
INSERT INTO 'dancesstepsmap' VALUES (13825, 11637, 5);
INSERT INTO 'dancesstepsmap' VALUES (13826, 11638, 4);
INSERT INTO 'dancesstepsmap' VALUES (13827, 11638, 5);
INSERT INTO 'dancesstepsmap' VALUES (13828, 11639, 1);
INSERT INTO 'dancesstepsmap' VALUES (13829, 11640, 4);
INSERT INTO 'dancesstepsmap' VALUES (13830, 2372, 2);
INSERT INTO 'dancesstepsmap' VALUES (13831, 7213, 5);
INSERT INTO 'dancesstepsmap' VALUES (13832, 5589, 2);
INSERT INTO 'dancesstepsmap' VALUES (13833, 2281, 5);
INSERT INTO 'dancesstepsmap' VALUES (13834, 2571, 5);
INSERT INTO 'dancesstepsmap' VALUES (13835, 2571, 4);
INSERT INTO 'dancesstepsmap' VALUES (13836, 2571, 1);
INSERT INTO 'dancesstepsmap' VALUES (13837, 2571, 2);
INSERT INTO 'dancesstepsmap' VALUES (13838, 3957, 2);
INSERT INTO 'dancesstepsmap' VALUES (13839, 3945, 10);
INSERT INTO 'dancesstepsmap' VALUES (13840, 3945, 2);
INSERT INTO 'dancesstepsmap' VALUES (13841, 3945, 3);
INSERT INTO 'dancesstepsmap' VALUES (13842, 113, 3);
INSERT INTO 'dancesstepsmap' VALUES (13843, 2705, 5);
INSERT INTO 'dancesstepsmap' VALUES (13844, 5159, 5);
INSERT INTO 'dancesstepsmap' VALUES (13845, 6624, 4);
INSERT INTO 'dancesstepsmap' VALUES (13846, 7233, 2);
INSERT INTO 'dancesstepsmap' VALUES (13847, 1173, 5);
INSERT INTO 'dancesstepsmap' VALUES (13850, 7087, 2);
INSERT INTO 'dancesstepsmap' VALUES (13851, 6317, 2);
INSERT INTO 'dancesstepsmap' VALUES (13852, 2558, 3);
INSERT INTO 'dancesstepsmap' VALUES (13853, 7039, 5);
INSERT INTO 'dancesstepsmap' VALUES (13854, 6833, 3);
INSERT INTO 'dancesstepsmap' VALUES (13855, 4203, 10);
INSERT INTO 'dancesstepsmap' VALUES (13856, 4203, 3);
INSERT INTO 'dancesstepsmap' VALUES (13857, 6413, 5);
INSERT INTO 'dancesstepsmap' VALUES (13858, 11974, 3);
INSERT INTO 'dancesstepsmap' VALUES (13859, 11974, 1);
INSERT INTO 'dancesstepsmap' VALUES (13860, 3767, 2);
INSERT INTO 'dancesstepsmap' VALUES (13861, 3547, 3);
INSERT INTO 'dancesstepsmap' VALUES (13862, 5108, 2);
INSERT INTO 'dancesstepsmap' VALUES (13863, 5108, 3);
INSERT INTO 'dancesstepsmap' VALUES (13864, 1087, 2);
INSERT INTO 'dancesstepsmap' VALUES (13865, 7709, 2);
INSERT INTO 'dancesstepsmap' VALUES (13866, 8198, 4);
INSERT INTO 'dancesstepsmap' VALUES (13867, 8198, 1);
INSERT INTO 'dancesstepsmap' VALUES (13868, 8198, 3);
INSERT INTO 'dancesstepsmap' VALUES (13869, 8198, 2);
INSERT INTO 'dancesstepsmap' VALUES (13870, 8199, 2);
INSERT INTO 'dancesstepsmap' VALUES (13871, 2160, 2);
INSERT INTO 'dancesstepsmap' VALUES (13872, 2564, 5);
INSERT INTO 'dancesstepsmap' VALUES (13873, 3217, 10);
INSERT INTO 'dancesstepsmap' VALUES (13874, 5250, 6);
INSERT INTO 'dancesstepsmap' VALUES (13875, 6280, 2);
INSERT INTO 'dancesstepsmap' VALUES (13876, 8855, 4);
INSERT INTO 'dancesstepsmap' VALUES (13877, 5124, 2);
INSERT INTO 'dancesstepsmap' VALUES (13878, 5241, 3);
INSERT INTO 'dancesstepsmap' VALUES (13879, 11468, 1);
INSERT INTO 'dancesstepsmap' VALUES (13880, 5076, 1);
INSERT INTO 'dancesstepsmap' VALUES (13881, 5076, 4);
INSERT INTO 'dancesstepsmap' VALUES (13882, 5076, 5);
INSERT INTO 'dancesstepsmap' VALUES (13883, 5076, 3);
INSERT INTO 'dancesstepsmap' VALUES (13884, 2221, 2);
INSERT INTO 'dancesstepsmap' VALUES (13885, 5913, 2);
INSERT INTO 'dancesstepsmap' VALUES (13886, 6299, 4);
INSERT INTO 'dancesstepsmap' VALUES (13887, 6299, 1);
INSERT INTO 'dancesstepsmap' VALUES (13888, 600, 2);
INSERT INTO 'dancesstepsmap' VALUES (13889, 600, 3);
INSERT INTO 'dancesstepsmap' VALUES (13890, 6158, 5);
INSERT INTO 'dancesstepsmap' VALUES (13891, 6158, 4);
INSERT INTO 'dancesstepsmap' VALUES (13892, 2983, 3);
INSERT INTO 'dancesstepsmap' VALUES (13893, 6254, 3);
INSERT INTO 'dancesstepsmap' VALUES (13894, 1298, 3);
INSERT INTO 'dancesstepsmap' VALUES (13895, 3632, 2);
INSERT INTO 'dancesstepsmap' VALUES (13896, 1299, 3);
INSERT INTO 'dancesstepsmap' VALUES (13897, 4291, 3);
INSERT INTO 'dancesstepsmap' VALUES (13898, 17, 2);
INSERT INTO 'dancesstepsmap' VALUES (13899, 17, 1);
INSERT INTO 'dancesstepsmap' VALUES (13900, 17, 4);
INSERT INTO 'dancesstepsmap' VALUES (13901, 1548, 2);
INSERT INTO 'dancesstepsmap' VALUES (13849, 2657, 2);
INSERT INTO 'dancesstepsmap' VALUES (13902, 10152, 4);
INSERT INTO 'dancesstepsmap' VALUES (13903, 10495, 3);
INSERT INTO 'dancesstepsmap' VALUES (13904, 11832, 4);
INSERT INTO 'dancesstepsmap' VALUES (13905, 11835, 1);
INSERT INTO 'dancesstepsmap' VALUES (13906, 11973, 4);
INSERT INTO 'dancesstepsmap' VALUES (23167, 18254, 4);
INSERT INTO 'dancesstepsmap' VALUES (13908, 11976, 3);
INSERT INTO 'dancesstepsmap' VALUES (13909, 11979, 1);
INSERT INTO 'dancesstepsmap' VALUES (13910, 11981, 4);
INSERT INTO 'dancesstepsmap' VALUES (13911, 11981, 5);
INSERT INTO 'dancesstepsmap' VALUES (13912, 11982, 1);
INSERT INTO 'dancesstepsmap' VALUES (13913, 11982, 3);
INSERT INTO 'dancesstepsmap' VALUES (13914, 11984, 4);
INSERT INTO 'dancesstepsmap' VALUES (13915, 11984, 5);
INSERT INTO 'dancesstepsmap' VALUES (13916, 11985, 4);
INSERT INTO 'dancesstepsmap' VALUES (13917, 11985, 5);
INSERT INTO 'dancesstepsmap' VALUES (13918, 11986, 5);
INSERT INTO 'dancesstepsmap' VALUES (13919, 11986, 4);
INSERT INTO 'dancesstepsmap' VALUES (13920, 11987, 1);
INSERT INTO 'dancesstepsmap' VALUES (13921, 11987, 3);
INSERT INTO 'dancesstepsmap' VALUES (13922, 11988, 2);
INSERT INTO 'dancesstepsmap' VALUES (13923, 11988, 1);
INSERT INTO 'dancesstepsmap' VALUES (13924, 11989, 3);
INSERT INTO 'dancesstepsmap' VALUES (13925, 11989, 1);
INSERT INTO 'dancesstepsmap' VALUES (13926, 3490, 5);
INSERT INTO 'dancesstepsmap' VALUES (13927, 11987, 2);
INSERT INTO 'dancesstepsmap' VALUES (13928, 11990, 2);
INSERT INTO 'dancesstepsmap' VALUES (13929, 11990, 1);
INSERT INTO 'dancesstepsmap' VALUES (13930, 12003, 3);
INSERT INTO 'dancesstepsmap' VALUES (13931, 12003, 1);
INSERT INTO 'dancesstepsmap' VALUES (13932, 12005, 1);
INSERT INTO 'dancesstepsmap' VALUES (13933, 12005, 3);
INSERT INTO 'dancesstepsmap' VALUES (13934, 12006, 3);
INSERT INTO 'dancesstepsmap' VALUES (13935, 12006, 1);
INSERT INTO 'dancesstepsmap' VALUES (13936, 12007, 3);
INSERT INTO 'dancesstepsmap' VALUES (13937, 8359, 1);
INSERT INTO 'dancesstepsmap' VALUES (13938, 12008, 2);
INSERT INTO 'dancesstepsmap' VALUES (13939, 12008, 3);
INSERT INTO 'dancesstepsmap' VALUES (13940, 12014, 1);
INSERT INTO 'dancesstepsmap' VALUES (13941, 12015, 4);
INSERT INTO 'dancesstepsmap' VALUES (13942, 12015, 6);
INSERT INTO 'dancesstepsmap' VALUES (13943, 12015, 1);
INSERT INTO 'dancesstepsmap' VALUES (13944, 12015, 2);
INSERT INTO 'dancesstepsmap' VALUES (13945, 12016, 1);
INSERT INTO 'dancesstepsmap' VALUES (13946, 12017, 1);
INSERT INTO 'dancesstepsmap' VALUES (13947, 12017, 2);
INSERT INTO 'dancesstepsmap' VALUES (13948, 12018, 5);
INSERT INTO 'dancesstepsmap' VALUES (13949, 12018, 4);
INSERT INTO 'dancesstepsmap' VALUES (13950, 12021, 2);
INSERT INTO 'dancesstepsmap' VALUES (13951, 12021, 1);
INSERT INTO 'dancesstepsmap' VALUES (13952, 12022, 1);
INSERT INTO 'dancesstepsmap' VALUES (13953, 12022, 2);
INSERT INTO 'dancesstepsmap' VALUES (13954, 10102, 1);
INSERT INTO 'dancesstepsmap' VALUES (13955, 10102, 2);
INSERT INTO 'dancesstepsmap' VALUES (13956, 12023, 1);
INSERT INTO 'dancesstepsmap' VALUES (13957, 12024, 2);
INSERT INTO 'dancesstepsmap' VALUES (13958, 12031, 1);
INSERT INTO 'dancesstepsmap' VALUES (13959, 12029, 1);
INSERT INTO 'dancesstepsmap' VALUES (13960, 12033, 1);
INSERT INTO 'dancesstepsmap' VALUES (13961, 3996, 5);
INSERT INTO 'dancesstepsmap' VALUES (13962, 12052, 5);
INSERT INTO 'dancesstepsmap' VALUES (13963, 12052, 4);
INSERT INTO 'dancesstepsmap' VALUES (13964, 12053, 1);
INSERT INTO 'dancesstepsmap' VALUES (13965, 12053, 3);
INSERT INTO 'dancesstepsmap' VALUES (13966, 12054, 1);
INSERT INTO 'dancesstepsmap' VALUES (13967, 12055, 4);
INSERT INTO 'dancesstepsmap' VALUES (13968, 12056, 5);
INSERT INTO 'dancesstepsmap' VALUES (13969, 12056, 4);
INSERT INTO 'dancesstepsmap' VALUES (13970, 12057, 5);
INSERT INTO 'dancesstepsmap' VALUES (13971, 12057, 4);
INSERT INTO 'dancesstepsmap' VALUES (13972, 12058, 1);
INSERT INTO 'dancesstepsmap' VALUES (13973, 12059, 4);
INSERT INTO 'dancesstepsmap' VALUES (13974, 12059, 5);
INSERT INTO 'dancesstepsmap' VALUES (13975, 12060, 4);
INSERT INTO 'dancesstepsmap' VALUES (13976, 12061, 4);
INSERT INTO 'dancesstepsmap' VALUES (13977, 12061, 5);
INSERT INTO 'dancesstepsmap' VALUES (13978, 12062, 4);
INSERT INTO 'dancesstepsmap' VALUES (13979, 12062, 5);
INSERT INTO 'dancesstepsmap' VALUES (13980, 12063, 4);
INSERT INTO 'dancesstepsmap' VALUES (13981, 12064, 2);
INSERT INTO 'dancesstepsmap' VALUES (13982, 12064, 1);
INSERT INTO 'dancesstepsmap' VALUES (13983, 12064, 3);
INSERT INTO 'dancesstepsmap' VALUES (13984, 12065, 1);
INSERT INTO 'dancesstepsmap' VALUES (13985, 12066, 2);
INSERT INTO 'dancesstepsmap' VALUES (13986, 12067, 2);
INSERT INTO 'dancesstepsmap' VALUES (13987, 12068, 1);
INSERT INTO 'dancesstepsmap' VALUES (13988, 12069, 4);
INSERT INTO 'dancesstepsmap' VALUES (13989, 8934, 1);
INSERT INTO 'dancesstepsmap' VALUES (13990, 3144, 3);
INSERT INTO 'dancesstepsmap' VALUES (13991, 12072, 3);
INSERT INTO 'dancesstepsmap' VALUES (13992, 12072, 1);
INSERT INTO 'dancesstepsmap' VALUES (13993, 12073, 1);
INSERT INTO 'dancesstepsmap' VALUES (13994, 12073, 3);
INSERT INTO 'dancesstepsmap' VALUES (13995, 12074, 6);
INSERT INTO 'dancesstepsmap' VALUES (13996, 12074, 4);
INSERT INTO 'dancesstepsmap' VALUES (13997, 12074, 5);
INSERT INTO 'dancesstepsmap' VALUES (13998, 8927, 1);
INSERT INTO 'dancesstepsmap' VALUES (13999, 8927, 2);
INSERT INTO 'dancesstepsmap' VALUES (14000, 12075, 2);
INSERT INTO 'dancesstepsmap' VALUES (14001, 12075, 1);
INSERT INTO 'dancesstepsmap' VALUES (14002, 12076, 1);
INSERT INTO 'dancesstepsmap' VALUES (14003, 12076, 3);
INSERT INTO 'dancesstepsmap' VALUES (14004, 12077, 2);
INSERT INTO 'dancesstepsmap' VALUES (14005, 6701, 2);
INSERT INTO 'dancesstepsmap' VALUES (14006, 713, 3);
INSERT INTO 'dancesstepsmap' VALUES (14007, 10963, 1);
INSERT INTO 'dancesstepsmap' VALUES (14008, 10963, 2);
INSERT INTO 'dancesstepsmap' VALUES (14009, 12079, 1);
INSERT INTO 'dancesstepsmap' VALUES (14010, 12079, 3);
INSERT INTO 'dancesstepsmap' VALUES (14011, 12080, 4);
INSERT INTO 'dancesstepsmap' VALUES (14012, 12080, 5);
INSERT INTO 'dancesstepsmap' VALUES (14013, 3057, 2);
INSERT INTO 'dancesstepsmap' VALUES (14014, 4768, 6);
INSERT INTO 'dancesstepsmap' VALUES (14017, 7345, 5);
INSERT INTO 'dancesstepsmap' VALUES (14018, 7502, 5);
INSERT INTO 'dancesstepsmap' VALUES (14019, 7497, 2);
INSERT INTO 'dancesstepsmap' VALUES (14020, 7482, 4);
INSERT INTO 'dancesstepsmap' VALUES (14021, 7482, 3);
INSERT INTO 'dancesstepsmap' VALUES (14022, 7482, 1);
INSERT INTO 'dancesstepsmap' VALUES (14023, 7491, 2);
INSERT INTO 'dancesstepsmap' VALUES (14024, 7492, 5);
INSERT INTO 'dancesstepsmap' VALUES (14025, 7479, 5);
INSERT INTO 'dancesstepsmap' VALUES (14026, 7479, 4);
INSERT INTO 'dancesstepsmap' VALUES (14027, 7479, 1);
INSERT INTO 'dancesstepsmap' VALUES (14028, 7426, 2);
INSERT INTO 'dancesstepsmap' VALUES (14029, 7426, 3);
INSERT INTO 'dancesstepsmap' VALUES (14030, 7493, 5);
INSERT INTO 'dancesstepsmap' VALUES (14031, 7425, 5);
INSERT INTO 'dancesstepsmap' VALUES (14032, 7512, 3);
INSERT INTO 'dancesstepsmap' VALUES (14033, 7363, 5);
INSERT INTO 'dancesstepsmap' VALUES (14034, 7522, 2);
INSERT INTO 'dancesstepsmap' VALUES (14035, 12081, 1);
INSERT INTO 'dancesstepsmap' VALUES (14036, 10597, 4);
INSERT INTO 'dancesstepsmap' VALUES (14037, 10597, 5);
INSERT INTO 'dancesstepsmap' VALUES (14038, 9633, 4);
INSERT INTO 'dancesstepsmap' VALUES (14039, 12083, 4);
INSERT INTO 'dancesstepsmap' VALUES (14040, 12084, 5);
INSERT INTO 'dancesstepsmap' VALUES (14041, 12084, 4);
INSERT INTO 'dancesstepsmap' VALUES (14042, 12104, 2);
INSERT INTO 'dancesstepsmap' VALUES (14043, 12104, 1);
INSERT INTO 'dancesstepsmap' VALUES (14044, 12106, 4);
INSERT INTO 'dancesstepsmap' VALUES (14045, 7248, 2);
INSERT INTO 'dancesstepsmap' VALUES (14046, 6547, 2);
INSERT INTO 'dancesstepsmap' VALUES (14047, 253, 5);
INSERT INTO 'dancesstepsmap' VALUES (14048, 1487, 5);
INSERT INTO 'dancesstepsmap' VALUES (14049, 4377, 2);
INSERT INTO 'dancesstepsmap' VALUES (14050, 123, 5);
INSERT INTO 'dancesstepsmap' VALUES (14051, 406, 2);
INSERT INTO 'dancesstepsmap' VALUES (14052, 884, 5);
INSERT INTO 'dancesstepsmap' VALUES (14053, 2414, 2);
INSERT INTO 'dancesstepsmap' VALUES (14054, 2414, 3);
INSERT INTO 'dancesstepsmap' VALUES (14055, 12107, 1);
INSERT INTO 'dancesstepsmap' VALUES (14056, 12107, 3);
INSERT INTO 'dancesstepsmap' VALUES (14057, 10161, 3);
INSERT INTO 'dancesstepsmap' VALUES (14058, 11205, 1);
INSERT INTO 'dancesstepsmap' VALUES (14059, 12108, 1);
INSERT INTO 'dancesstepsmap' VALUES (14060, 12108, 3);
INSERT INTO 'dancesstepsmap' VALUES (14061, 2611, 6);
INSERT INTO 'dancesstepsmap' VALUES (14062, 10180, 2);
INSERT INTO 'dancesstepsmap' VALUES (14063, 10180, 1);
INSERT INTO 'dancesstepsmap' VALUES (14064, 2753, 3);
INSERT INTO 'dancesstepsmap' VALUES (14065, 10177, 3);
INSERT INTO 'dancesstepsmap' VALUES (14066, 10177, 1);
INSERT INTO 'dancesstepsmap' VALUES (14067, 10176, 2);
INSERT INTO 'dancesstepsmap' VALUES (14068, 10176, 1);
INSERT INTO 'dancesstepsmap' VALUES (14069, 11225, 1);
INSERT INTO 'dancesstepsmap' VALUES (14070, 3009, 6);
INSERT INTO 'dancesstepsmap' VALUES (14071, 12109, 1);
INSERT INTO 'dancesstepsmap' VALUES (14072, 12110, 5);
INSERT INTO 'dancesstepsmap' VALUES (14073, 12110, 4);
INSERT INTO 'dancesstepsmap' VALUES (14074, 12111, 2);
INSERT INTO 'dancesstepsmap' VALUES (14075, 12111, 1);
INSERT INTO 'dancesstepsmap' VALUES (14076, 12112, 5);
INSERT INTO 'dancesstepsmap' VALUES (14077, 12112, 4);
INSERT INTO 'dancesstepsmap' VALUES (14078, 12112, 1);
INSERT INTO 'dancesstepsmap' VALUES (14079, 12112, 2);
INSERT INTO 'dancesstepsmap' VALUES (14080, 12113, 3);
INSERT INTO 'dancesstepsmap' VALUES (14081, 12113, 1);
INSERT INTO 'dancesstepsmap' VALUES (14082, 12114, 4);
INSERT INTO 'dancesstepsmap' VALUES (14083, 12116, 4);
INSERT INTO 'dancesstepsmap' VALUES (14086, 12118, 5);
INSERT INTO 'dancesstepsmap' VALUES (14087, 12118, 4);
INSERT INTO 'dancesstepsmap' VALUES (14088, 12119, 4);
INSERT INTO 'dancesstepsmap' VALUES (14089, 11910, 2);
INSERT INTO 'dancesstepsmap' VALUES (14090, 1870, 2);
INSERT INTO 'dancesstepsmap' VALUES (14091, 1540, 5);
INSERT INTO 'dancesstepsmap' VALUES (14092, 2403, 4);
INSERT INTO 'dancesstepsmap' VALUES (14093, 2403, 1);
INSERT INTO 'dancesstepsmap' VALUES (14094, 2403, 2);
INSERT INTO 'dancesstepsmap' VALUES (14095, 5971, 5);
INSERT INTO 'dancesstepsmap' VALUES (14096, 3011, 5);
INSERT INTO 'dancesstepsmap' VALUES (14097, 5601, 3);
INSERT INTO 'dancesstepsmap' VALUES (14098, 1534, 5);
INSERT INTO 'dancesstepsmap' VALUES (14099, 6004, 3);
INSERT INTO 'dancesstepsmap' VALUES (14100, 7748, 2);
INSERT INTO 'dancesstepsmap' VALUES (14101, 8933, 6);
INSERT INTO 'dancesstepsmap' VALUES (14102, 8933, 4);
INSERT INTO 'dancesstepsmap' VALUES (14103, 9026, 3);
INSERT INTO 'dancesstepsmap' VALUES (14104, 9026, 1);
INSERT INTO 'dancesstepsmap' VALUES (14105, 12120, 2);
INSERT INTO 'dancesstepsmap' VALUES (14106, 10755, 1);
INSERT INTO 'dancesstepsmap' VALUES (14107, 10755, 2);
INSERT INTO 'dancesstepsmap' VALUES (14108, 3377, 3);
INSERT INTO 'dancesstepsmap' VALUES (14109, 10766, 4);
INSERT INTO 'dancesstepsmap' VALUES (14110, 10766, 5);
INSERT INTO 'dancesstepsmap' VALUES (14111, 12122, 2);
INSERT INTO 'dancesstepsmap' VALUES (14112, 12122, 1);
INSERT INTO 'dancesstepsmap' VALUES (14113, 6696, 2);
INSERT INTO 'dancesstepsmap' VALUES (14114, 1732, 5);
INSERT INTO 'dancesstepsmap' VALUES (14115, 538, 2);
INSERT INTO 'dancesstepsmap' VALUES (14116, 8235, 6);
INSERT INTO 'dancesstepsmap' VALUES (14117, 8235, 5);
INSERT INTO 'dancesstepsmap' VALUES (14118, 2917, 2);
INSERT INTO 'dancesstepsmap' VALUES (14119, 676, 5);
INSERT INTO 'dancesstepsmap' VALUES (14120, 6120, 2);
INSERT INTO 'dancesstepsmap' VALUES (14121, 6120, 3);
INSERT INTO 'dancesstepsmap' VALUES (14122, 2027, 4);
INSERT INTO 'dancesstepsmap' VALUES (14123, 2027, 5);
INSERT INTO 'dancesstepsmap' VALUES (14124, 4889, 2);
INSERT INTO 'dancesstepsmap' VALUES (14125, 883, 5);
INSERT INTO 'dancesstepsmap' VALUES (14126, 3807, 5);
INSERT INTO 'dancesstepsmap' VALUES (14127, 3015, 2);
INSERT INTO 'dancesstepsmap' VALUES (14128, 6688, 2);
INSERT INTO 'dancesstepsmap' VALUES (14129, 6688, 3);
INSERT INTO 'dancesstepsmap' VALUES (14130, 341, 2);
INSERT INTO 'dancesstepsmap' VALUES (14131, 2912, 4);
INSERT INTO 'dancesstepsmap' VALUES (14132, 2912, 1);
INSERT INTO 'dancesstepsmap' VALUES (14133, 2912, 2);
INSERT INTO 'dancesstepsmap' VALUES (14134, 7066, 2);
INSERT INTO 'dancesstepsmap' VALUES (14135, 3086, 2);
INSERT INTO 'dancesstepsmap' VALUES (14136, 4029, 2);
INSERT INTO 'dancesstepsmap' VALUES (14137, 561, 2);
INSERT INTO 'dancesstepsmap' VALUES (14138, 269, 2);
INSERT INTO 'dancesstepsmap' VALUES (14139, 12123, 1);
INSERT INTO 'dancesstepsmap' VALUES (14140, 6564, 5);
INSERT INTO 'dancesstepsmap' VALUES (14141, 10173, 4);
INSERT INTO 'dancesstepsmap' VALUES (14142, 9137, 3);
INSERT INTO 'dancesstepsmap' VALUES (14143, 11226, 5);
INSERT INTO 'dancesstepsmap' VALUES (14144, 11226, 4);
INSERT INTO 'dancesstepsmap' VALUES (14145, 7812, 5);
INSERT INTO 'dancesstepsmap' VALUES (14146, 3974, 3);
INSERT INTO 'dancesstepsmap' VALUES (14147, 4044, 8);
INSERT INTO 'dancesstepsmap' VALUES (14148, 4147, 3);
INSERT INTO 'dancesstepsmap' VALUES (14149, 4226, 1);
INSERT INTO 'dancesstepsmap' VALUES (14150, 4226, 4);
INSERT INTO 'dancesstepsmap' VALUES (14151, 9894, 2);
INSERT INTO 'dancesstepsmap' VALUES (14152, 3674, 5);
INSERT INTO 'dancesstepsmap' VALUES (14153, 3801, 5);
INSERT INTO 'dancesstepsmap' VALUES (14154, 4780, 3);
INSERT INTO 'dancesstepsmap' VALUES (14155, 6070, 5);
INSERT INTO 'dancesstepsmap' VALUES (14156, 3439, 5);
INSERT INTO 'dancesstepsmap' VALUES (14157, 5268, 2);
INSERT INTO 'dancesstepsmap' VALUES (14158, 5284, 2);
INSERT INTO 'dancesstepsmap' VALUES (14159, 5284, 3);
INSERT INTO 'dancesstepsmap' VALUES (14160, 8352, 5);
INSERT INTO 'dancesstepsmap' VALUES (14161, 1533, 3);
INSERT INTO 'dancesstepsmap' VALUES (14162, 1533, 1);
INSERT INTO 'dancesstepsmap' VALUES (14163, 1533, 2);
INSERT INTO 'dancesstepsmap' VALUES (14164, 11257, 5);
INSERT INTO 'dancesstepsmap' VALUES (14165, 11257, 4);
INSERT INTO 'dancesstepsmap' VALUES (14166, 10368, 1);
INSERT INTO 'dancesstepsmap' VALUES (14167, 12124, 2);
INSERT INTO 'dancesstepsmap' VALUES (14168, 12124, 1);
INSERT INTO 'dancesstepsmap' VALUES (14169, 12106, 5);
INSERT INTO 'dancesstepsmap' VALUES (14170, 11522, 2);
INSERT INTO 'dancesstepsmap' VALUES (14171, 7883, 5);
INSERT INTO 'dancesstepsmap' VALUES (14172, 4641, 2);
INSERT INTO 'dancesstepsmap' VALUES (14173, 12242, 1);
INSERT INTO 'dancesstepsmap' VALUES (14174, 12242, 3);
INSERT INTO 'dancesstepsmap' VALUES (14175, 12243, 3);
INSERT INTO 'dancesstepsmap' VALUES (14176, 12243, 1);
INSERT INTO 'dancesstepsmap' VALUES (14177, 12134, 1);
INSERT INTO 'dancesstepsmap' VALUES (14178, 12149, 1);
INSERT INTO 'dancesstepsmap' VALUES (14179, 12201, 1);
INSERT INTO 'dancesstepsmap' VALUES (14180, 12201, 2);
INSERT INTO 'dancesstepsmap' VALUES (14181, 12244, 1);
INSERT INTO 'dancesstepsmap' VALUES (14182, 12244, 3);
INSERT INTO 'dancesstepsmap' VALUES (14183, 12245, 4);
INSERT INTO 'dancesstepsmap' VALUES (14184, 12246, 4);
INSERT INTO 'dancesstepsmap' VALUES (23168, 18254, 2);
INSERT INTO 'dancesstepsmap' VALUES (14186, 12248, 1);
INSERT INTO 'dancesstepsmap' VALUES (14187, 12248, 2);
INSERT INTO 'dancesstepsmap' VALUES (14188, 12248, 3);
INSERT INTO 'dancesstepsmap' VALUES (14189, 12249, 1);
INSERT INTO 'dancesstepsmap' VALUES (14190, 12249, 2);
INSERT INTO 'dancesstepsmap' VALUES (14191, 12250, 4);
INSERT INTO 'dancesstepsmap' VALUES (14192, 12277, 1);
INSERT INTO 'dancesstepsmap' VALUES (14193, 12278, 1);
INSERT INTO 'dancesstepsmap' VALUES (14194, 12278, 2);
INSERT INTO 'dancesstepsmap' VALUES (14195, 12290, 4);
INSERT INTO 'dancesstepsmap' VALUES (14196, 12268, 5);
INSERT INTO 'dancesstepsmap' VALUES (14197, 12268, 4);
INSERT INTO 'dancesstepsmap' VALUES (14198, 12268, 6);
INSERT INTO 'dancesstepsmap' VALUES (14199, 12268, 10);
INSERT INTO 'dancesstepsmap' VALUES (14200, 12268, 1);
INSERT INTO 'dancesstepsmap' VALUES (14201, 12268, 2);
INSERT INTO 'dancesstepsmap' VALUES (14202, 12363, 1);
INSERT INTO 'dancesstepsmap' VALUES (14203, 12406, 1);
INSERT INTO 'dancesstepsmap' VALUES (14204, 10101, 4);
INSERT INTO 'dancesstepsmap' VALUES (14205, 10101, 5);
INSERT INTO 'dancesstepsmap' VALUES (14206, 3167, 2);
INSERT INTO 'dancesstepsmap' VALUES (14207, 3167, 3);
INSERT INTO 'dancesstepsmap' VALUES (14208, 2455, 2);
INSERT INTO 'dancesstepsmap' VALUES (14209, 5633, 2);
INSERT INTO 'dancesstepsmap' VALUES (14210, 832, 2);
INSERT INTO 'dancesstepsmap' VALUES (14211, 423, 3);
INSERT INTO 'dancesstepsmap' VALUES (14212, 3930, 2);
INSERT INTO 'dancesstepsmap' VALUES (14213, 5353, 5);
INSERT INTO 'dancesstepsmap' VALUES (14214, 1993, 2);
INSERT INTO 'dancesstepsmap' VALUES (14215, 5294, 5);
INSERT INTO 'dancesstepsmap' VALUES (14216, 5112, 4);
INSERT INTO 'dancesstepsmap' VALUES (14217, 6480, 5);
INSERT INTO 'dancesstepsmap' VALUES (14218, 12215, 3);
INSERT INTO 'dancesstepsmap' VALUES (14219, 11899, 2);
INSERT INTO 'dancesstepsmap' VALUES (14220, 11899, 10);
INSERT INTO 'dancesstepsmap' VALUES (14221, 11899, 1);
INSERT INTO 'dancesstepsmap' VALUES (14222, 11899, 3);
INSERT INTO 'dancesstepsmap' VALUES (14223, 6932, 2);
INSERT INTO 'dancesstepsmap' VALUES (14224, 2393, 5);
INSERT INTO 'dancesstepsmap' VALUES (14225, 5781, 2);
INSERT INTO 'dancesstepsmap' VALUES (14226, 5781, 3);
INSERT INTO 'dancesstepsmap' VALUES (14227, 5050, 2);
INSERT INTO 'dancesstepsmap' VALUES (14228, 5587, 2);
INSERT INTO 'dancesstepsmap' VALUES (14229, 133, 5);
INSERT INTO 'dancesstepsmap' VALUES (14230, 1917, 5);
INSERT INTO 'dancesstepsmap' VALUES (14231, 5815, 5);
INSERT INTO 'dancesstepsmap' VALUES (14232, 1583, 3);
INSERT INTO 'dancesstepsmap' VALUES (14233, 6538, 2);
INSERT INTO 'dancesstepsmap' VALUES (14234, 6100, 2);
INSERT INTO 'dancesstepsmap' VALUES (14235, 6154, 5);
INSERT INTO 'dancesstepsmap' VALUES (14236, 12427, 1);
INSERT INTO 'dancesstepsmap' VALUES (14237, 12427, 2);
INSERT INTO 'dancesstepsmap' VALUES (14238, 12428, 1);
INSERT INTO 'dancesstepsmap' VALUES (14239, 12429, 4);
INSERT INTO 'dancesstepsmap' VALUES (14240, 1198, 3);
INSERT INTO 'dancesstepsmap' VALUES (14241, 2402, 3);
INSERT INTO 'dancesstepsmap' VALUES (14242, 5088, 3);
INSERT INTO 'dancesstepsmap' VALUES (14243, 5213, 3);
INSERT INTO 'dancesstepsmap' VALUES (14244, 6399, 3);
INSERT INTO 'dancesstepsmap' VALUES (14245, 6683, 3);
INSERT INTO 'dancesstepsmap' VALUES (14246, 9319, 1);
INSERT INTO 'dancesstepsmap' VALUES (14247, 9320, 1);
INSERT INTO 'dancesstepsmap' VALUES (14248, 9320, 2);
INSERT INTO 'dancesstepsmap' VALUES (14249, 9319, 4);
INSERT INTO 'dancesstepsmap' VALUES (14250, 9319, 5);
INSERT INTO 'dancesstepsmap' VALUES (14251, 9321, 2);
INSERT INTO 'dancesstepsmap' VALUES (14252, 9321, 1);
INSERT INTO 'dancesstepsmap' VALUES (14253, 9321, 3);
INSERT INTO 'dancesstepsmap' VALUES (14254, 9322, 1);
INSERT INTO 'dancesstepsmap' VALUES (14255, 9322, 3);
INSERT INTO 'dancesstepsmap' VALUES (14256, 9323, 3);
INSERT INTO 'dancesstepsmap' VALUES (14257, 9323, 1);
INSERT INTO 'dancesstepsmap' VALUES (14258, 9324, 3);
INSERT INTO 'dancesstepsmap' VALUES (14259, 9324, 1);
INSERT INTO 'dancesstepsmap' VALUES (14260, 9325, 10);
INSERT INTO 'dancesstepsmap' VALUES (14261, 9325, 1);
INSERT INTO 'dancesstepsmap' VALUES (14262, 9325, 3);
INSERT INTO 'dancesstepsmap' VALUES (14264, 9326, 4);
INSERT INTO 'dancesstepsmap' VALUES (14265, 9326, 5);
INSERT INTO 'dancesstepsmap' VALUES (14266, 9327, 4);
INSERT INTO 'dancesstepsmap' VALUES (14267, 9328, 1);
INSERT INTO 'dancesstepsmap' VALUES (14268, 9330, 10);
INSERT INTO 'dancesstepsmap' VALUES (14269, 9330, 1);
INSERT INTO 'dancesstepsmap' VALUES (14270, 9330, 3);
INSERT INTO 'dancesstepsmap' VALUES (14271, 9329, 1);
INSERT INTO 'dancesstepsmap' VALUES (14272, 9243, 2);
INSERT INTO 'dancesstepsmap' VALUES (14273, 9243, 1);
INSERT INTO 'dancesstepsmap' VALUES (14274, 9243, 3);
INSERT INTO 'dancesstepsmap' VALUES (14275, 9244, 2);
INSERT INTO 'dancesstepsmap' VALUES (14276, 9244, 1);
INSERT INTO 'dancesstepsmap' VALUES (14277, 9245, 2);
INSERT INTO 'dancesstepsmap' VALUES (14278, 9245, 1);
INSERT INTO 'dancesstepsmap' VALUES (14279, 9246, 1);
INSERT INTO 'dancesstepsmap' VALUES (14280, 9247, 2);
INSERT INTO 'dancesstepsmap' VALUES (14281, 9247, 1);
INSERT INTO 'dancesstepsmap' VALUES (14282, 9248, 5);
INSERT INTO 'dancesstepsmap' VALUES (14283, 9248, 4);
INSERT INTO 'dancesstepsmap' VALUES (14284, 9249, 4);
INSERT INTO 'dancesstepsmap' VALUES (14285, 9250, 1);
INSERT INTO 'dancesstepsmap' VALUES (14286, 9250, 3);
INSERT INTO 'dancesstepsmap' VALUES (14287, 9252, 1);
INSERT INTO 'dancesstepsmap' VALUES (14288, 9253, 4);
INSERT INTO 'dancesstepsmap' VALUES (14289, 9254, 3);
INSERT INTO 'dancesstepsmap' VALUES (14290, 9254, 2);
INSERT INTO 'dancesstepsmap' VALUES (14291, 12401, 1);
INSERT INTO 'dancesstepsmap' VALUES (14292, 12401, 3);
INSERT INTO 'dancesstepsmap' VALUES (14293, 12402, 4);
INSERT INTO 'dancesstepsmap' VALUES (14294, 12403, 1);
INSERT INTO 'dancesstepsmap' VALUES (14295, 12400, 1);
INSERT INTO 'dancesstepsmap' VALUES (14296, 12400, 2);
INSERT INTO 'dancesstepsmap' VALUES (14297, 12404, 1);
INSERT INTO 'dancesstepsmap' VALUES (14298, 12404, 2);
INSERT INTO 'dancesstepsmap' VALUES (14299, 12404, 3);
INSERT INTO 'dancesstepsmap' VALUES (14300, 12405, 4);
INSERT INTO 'dancesstepsmap' VALUES (14301, 6504, 9);
INSERT INTO 'dancesstepsmap' VALUES (14302, 6293, 5);
INSERT INTO 'dancesstepsmap' VALUES (14303, 6049, 5);
INSERT INTO 'dancesstepsmap' VALUES (14304, 3673, 5);
INSERT INTO 'dancesstepsmap' VALUES (14305, 4003, 3);
INSERT INTO 'dancesstepsmap' VALUES (14306, 1536, 2);
INSERT INTO 'dancesstepsmap' VALUES (14307, 6806, 2);
INSERT INTO 'dancesstepsmap' VALUES (14308, 12430, 1);
INSERT INTO 'dancesstepsmap' VALUES (14309, 12430, 2);
INSERT INTO 'dancesstepsmap' VALUES (14310, 12430, 4);
INSERT INTO 'dancesstepsmap' VALUES (14311, 12430, 3);
INSERT INTO 'dancesstepsmap' VALUES (14312, 12431, 4);
INSERT INTO 'dancesstepsmap' VALUES (14313, 12432, 2);
INSERT INTO 'dancesstepsmap' VALUES (14314, 12432, 1);
INSERT INTO 'dancesstepsmap' VALUES (14315, 12433, 2);
INSERT INTO 'dancesstepsmap' VALUES (14316, 12433, 3);
INSERT INTO 'dancesstepsmap' VALUES (14317, 12433, 1);
INSERT INTO 'dancesstepsmap' VALUES (14318, 12434, 4);
INSERT INTO 'dancesstepsmap' VALUES (14319, 12435, 1);
INSERT INTO 'dancesstepsmap' VALUES (14320, 12435, 2);
INSERT INTO 'dancesstepsmap' VALUES (14321, 12019, 4);
INSERT INTO 'dancesstepsmap' VALUES (14322, 12436, 4);
INSERT INTO 'dancesstepsmap' VALUES (14323, 12437, 1);
INSERT INTO 'dancesstepsmap' VALUES (14324, 12437, 2);
INSERT INTO 'dancesstepsmap' VALUES (14325, 12437, 3);
INSERT INTO 'dancesstepsmap' VALUES (14326, 12438, 1);
INSERT INTO 'dancesstepsmap' VALUES (14327, 12439, 4);
INSERT INTO 'dancesstepsmap' VALUES (14328, 12440, 3);
INSERT INTO 'dancesstepsmap' VALUES (14329, 12440, 1);
INSERT INTO 'dancesstepsmap' VALUES (14330, 12441, 1);
INSERT INTO 'dancesstepsmap' VALUES (14331, 12442, 4);
INSERT INTO 'dancesstepsmap' VALUES (14332, 12442, 5);
INSERT INTO 'dancesstepsmap' VALUES (14333, 12443, 1);
INSERT INTO 'dancesstepsmap' VALUES (14334, 12444, 2);
INSERT INTO 'dancesstepsmap' VALUES (14335, 12444, 3);
INSERT INTO 'dancesstepsmap' VALUES (14336, 8238, 4);
INSERT INTO 'dancesstepsmap' VALUES (14337, 12426, 2);
INSERT INTO 'dancesstepsmap' VALUES (14338, 12426, 1);
INSERT INTO 'dancesstepsmap' VALUES (14339, 11977, 4);
INSERT INTO 'dancesstepsmap' VALUES (14340, 12445, 3);
INSERT INTO 'dancesstepsmap' VALUES (14341, 12447, 4);
INSERT INTO 'dancesstepsmap' VALUES (14342, 12448, 2);
INSERT INTO 'dancesstepsmap' VALUES (14343, 12448, 1);
INSERT INTO 'dancesstepsmap' VALUES (14344, 12449, 1);
INSERT INTO 'dancesstepsmap' VALUES (14345, 12450, 1);
INSERT INTO 'dancesstepsmap' VALUES (14346, 12451, 6);
INSERT INTO 'dancesstepsmap' VALUES (14347, 12453, 4);
INSERT INTO 'dancesstepsmap' VALUES (14348, 11977, 5);
INSERT INTO 'dancesstepsmap' VALUES (14349, 12445, 1);
INSERT INTO 'dancesstepsmap' VALUES (14350, 12445, 2);
INSERT INTO 'dancesstepsmap' VALUES (14351, 12446, 2);
INSERT INTO 'dancesstepsmap' VALUES (14352, 12446, 1);
INSERT INTO 'dancesstepsmap' VALUES (14353, 12447, 5);
INSERT INTO 'dancesstepsmap' VALUES (14354, 8727, 2);
INSERT INTO 'dancesstepsmap' VALUES (14355, 11756, 3);
INSERT INTO 'dancesstepsmap' VALUES (14356, 12449, 2);
INSERT INTO 'dancesstepsmap' VALUES (14357, 12451, 2);
INSERT INTO 'dancesstepsmap' VALUES (14358, 12451, 3);
INSERT INTO 'dancesstepsmap' VALUES (14359, 12451, 1);
INSERT INTO 'dancesstepsmap' VALUES (14360, 12451, 4);
INSERT INTO 'dancesstepsmap' VALUES (14361, 12451, 5);
INSERT INTO 'dancesstepsmap' VALUES (14362, 12452, 1);
INSERT INTO 'dancesstepsmap' VALUES (14363, 12452, 2);
INSERT INTO 'dancesstepsmap' VALUES (14364, 10663, 2);
INSERT INTO 'dancesstepsmap' VALUES (14365, 10663, 1);
INSERT INTO 'dancesstepsmap' VALUES (14366, 10663, 3);
INSERT INTO 'dancesstepsmap' VALUES (14367, 12454, 1);
INSERT INTO 'dancesstepsmap' VALUES (14368, 12454, 2);
INSERT INTO 'dancesstepsmap' VALUES (14369, 2039, 2);
INSERT INTO 'dancesstepsmap' VALUES (14370, 2039, 3);
INSERT INTO 'dancesstepsmap' VALUES (14371, 12456, 1);
INSERT INTO 'dancesstepsmap' VALUES (14372, 12457, 1);
INSERT INTO 'dancesstepsmap' VALUES (14373, 12459, 1);
INSERT INTO 'dancesstepsmap' VALUES (14374, 12460, 1);
INSERT INTO 'dancesstepsmap' VALUES (14375, 12462, 1);
INSERT INTO 'dancesstepsmap' VALUES (14376, 12463, 1);
INSERT INTO 'dancesstepsmap' VALUES (14377, 12464, 4);
INSERT INTO 'dancesstepsmap' VALUES (14378, 12455, 1);
INSERT INTO 'dancesstepsmap' VALUES (14379, 12456, 2);
INSERT INTO 'dancesstepsmap' VALUES (14380, 12458, 2);
INSERT INTO 'dancesstepsmap' VALUES (14381, 12458, 1);
INSERT INTO 'dancesstepsmap' VALUES (14382, 12459, 2);
INSERT INTO 'dancesstepsmap' VALUES (14383, 12461, 4);
INSERT INTO 'dancesstepsmap' VALUES (14384, 12461, 5);
INSERT INTO 'dancesstepsmap' VALUES (14385, 12462, 2);
INSERT INTO 'dancesstepsmap' VALUES (14386, 12465, 1);
INSERT INTO 'dancesstepsmap' VALUES (14387, 12465, 2);
INSERT INTO 'dancesstepsmap' VALUES (14388, 12467, 3);
INSERT INTO 'dancesstepsmap' VALUES (14389, 12467, 1);
INSERT INTO 'dancesstepsmap' VALUES (14390, 12468, 4);
INSERT INTO 'dancesstepsmap' VALUES (14391, 12469, 1);
INSERT INTO 'dancesstepsmap' VALUES (14392, 12469, 2);
INSERT INTO 'dancesstepsmap' VALUES (14393, 12472, 2);
INSERT INTO 'dancesstepsmap' VALUES (14394, 12472, 1);
INSERT INTO 'dancesstepsmap' VALUES (14395, 12473, 1);
INSERT INTO 'dancesstepsmap' VALUES (14396, 12473, 2);
INSERT INTO 'dancesstepsmap' VALUES (14397, 12474, 1);
INSERT INTO 'dancesstepsmap' VALUES (14398, 12466, 1);
INSERT INTO 'dancesstepsmap' VALUES (14399, 12466, 2);
INSERT INTO 'dancesstepsmap' VALUES (14400, 12468, 5);
INSERT INTO 'dancesstepsmap' VALUES (14401, 12470, 1);
INSERT INTO 'dancesstepsmap' VALUES (14402, 12470, 2);
INSERT INTO 'dancesstepsmap' VALUES (14403, 12471, 4);
INSERT INTO 'dancesstepsmap' VALUES (14404, 12471, 5);
INSERT INTO 'dancesstepsmap' VALUES (14405, 12474, 2);
INSERT INTO 'dancesstepsmap' VALUES (14406, 12475, 2);
INSERT INTO 'dancesstepsmap' VALUES (14407, 12475, 1);
INSERT INTO 'dancesstepsmap' VALUES (14408, 12476, 5);
INSERT INTO 'dancesstepsmap' VALUES (14409, 12476, 4);
INSERT INTO 'dancesstepsmap' VALUES (14410, 12477, 2);
INSERT INTO 'dancesstepsmap' VALUES (14411, 12477, 1);
INSERT INTO 'dancesstepsmap' VALUES (14412, 12478, 1);
INSERT INTO 'dancesstepsmap' VALUES (14413, 12478, 2);
INSERT INTO 'dancesstepsmap' VALUES (14416, 12480, 4);
INSERT INTO 'dancesstepsmap' VALUES (14417, 12481, 1);
INSERT INTO 'dancesstepsmap' VALUES (14418, 12482, 5);
INSERT INTO 'dancesstepsmap' VALUES (14419, 12482, 4);
INSERT INTO 'dancesstepsmap' VALUES (14420, 12484, 1);
INSERT INTO 'dancesstepsmap' VALUES (14421, 12484, 2);
INSERT INTO 'dancesstepsmap' VALUES (14422, 12485, 4);
INSERT INTO 'dancesstepsmap' VALUES (14423, 12485, 5);
INSERT INTO 'dancesstepsmap' VALUES (14424, 12486, 1);
INSERT INTO 'dancesstepsmap' VALUES (14425, 12488, 1);
INSERT INTO 'dancesstepsmap' VALUES (14426, 12489, 1);
INSERT INTO 'dancesstepsmap' VALUES (14427, 12489, 2);
INSERT INTO 'dancesstepsmap' VALUES (14428, 12490, 1);
INSERT INTO 'dancesstepsmap' VALUES (14429, 12490, 2);
INSERT INTO 'dancesstepsmap' VALUES (14430, 12491, 4);
INSERT INTO 'dancesstepsmap' VALUES (14431, 12491, 5);
INSERT INTO 'dancesstepsmap' VALUES (14432, 12492, 4);
INSERT INTO 'dancesstepsmap' VALUES (14433, 12493, 1);
INSERT INTO 'dancesstepsmap' VALUES (14434, 12142, 1);
INSERT INTO 'dancesstepsmap' VALUES (14435, 12173, 1);
INSERT INTO 'dancesstepsmap' VALUES (14436, 12495, 1);
INSERT INTO 'dancesstepsmap' VALUES (14437, 12487, 4);
INSERT INTO 'dancesstepsmap' VALUES (14438, 12496, 5);
INSERT INTO 'dancesstepsmap' VALUES (14439, 12496, 4);
INSERT INTO 'dancesstepsmap' VALUES (14440, 12497, 2);
INSERT INTO 'dancesstepsmap' VALUES (14441, 12497, 1);
INSERT INTO 'dancesstepsmap' VALUES (14442, 12499, 1);
INSERT INTO 'dancesstepsmap' VALUES (14443, 12499, 2);
INSERT INTO 'dancesstepsmap' VALUES (14444, 12500, 2);
INSERT INTO 'dancesstepsmap' VALUES (14445, 12500, 1);
INSERT INTO 'dancesstepsmap' VALUES (14446, 12501, 2);
INSERT INTO 'dancesstepsmap' VALUES (14447, 12498, 4);
INSERT INTO 'dancesstepsmap' VALUES (14448, 12498, 5);
INSERT INTO 'dancesstepsmap' VALUES (14449, 12502, 4);
INSERT INTO 'dancesstepsmap' VALUES (14450, 83, 2);
INSERT INTO 'dancesstepsmap' VALUES (14451, 887, 5);
INSERT INTO 'dancesstepsmap' VALUES (14452, 1588, 5);
INSERT INTO 'dancesstepsmap' VALUES (14453, 9638, 1);
INSERT INTO 'dancesstepsmap' VALUES (14454, 9638, 2);
INSERT INTO 'dancesstepsmap' VALUES (14455, 3660, 3);
INSERT INTO 'dancesstepsmap' VALUES (14456, 5443, 2);
INSERT INTO 'dancesstepsmap' VALUES (14457, 12503, 3);
INSERT INTO 'dancesstepsmap' VALUES (14458, 12504, 4);
INSERT INTO 'dancesstepsmap' VALUES (14459, 12504, 5);
INSERT INTO 'dancesstepsmap' VALUES (14460, 12505, 1);
INSERT INTO 'dancesstepsmap' VALUES (14461, 12506, 1);
INSERT INTO 'dancesstepsmap' VALUES (14462, 12506, 3);
INSERT INTO 'dancesstepsmap' VALUES (14463, 12507, 1);
INSERT INTO 'dancesstepsmap' VALUES (14464, 12508, 4);
INSERT INTO 'dancesstepsmap' VALUES (14465, 12508, 5);
INSERT INTO 'dancesstepsmap' VALUES (14466, 12509, 1);
INSERT INTO 'dancesstepsmap' VALUES (14467, 12509, 2);
INSERT INTO 'dancesstepsmap' VALUES (14468, 12510, 4);
INSERT INTO 'dancesstepsmap' VALUES (14469, 12510, 5);
INSERT INTO 'dancesstepsmap' VALUES (14470, 12511, 1);
INSERT INTO 'dancesstepsmap' VALUES (14471, 10632, 2);
INSERT INTO 'dancesstepsmap' VALUES (14472, 10632, 1);
INSERT INTO 'dancesstepsmap' VALUES (14473, 222, 2);
INSERT INTO 'dancesstepsmap' VALUES (14474, 521, 2);
INSERT INTO 'dancesstepsmap' VALUES (14475, 650, 2);
INSERT INTO 'dancesstepsmap' VALUES (14476, 1020, 2);
INSERT INTO 'dancesstepsmap' VALUES (14477, 1154, 2);
INSERT INTO 'dancesstepsmap' VALUES (14478, 1578, 2);
INSERT INTO 'dancesstepsmap' VALUES (14479, 1783, 2);
INSERT INTO 'dancesstepsmap' VALUES (14480, 980, 2);
INSERT INTO 'dancesstepsmap' VALUES (14481, 895, 2);
INSERT INTO 'dancesstepsmap' VALUES (14482, 40, 5);
INSERT INTO 'dancesstepsmap' VALUES (14483, 6311, 5);
INSERT INTO 'dancesstepsmap' VALUES (14484, 11100, 4);
INSERT INTO 'dancesstepsmap' VALUES (14485, 11100, 5);
INSERT INTO 'dancesstepsmap' VALUES (14486, 11101, 5);
INSERT INTO 'dancesstepsmap' VALUES (14487, 11101, 4);
INSERT INTO 'dancesstepsmap' VALUES (14488, 11102, 1);
INSERT INTO 'dancesstepsmap' VALUES (14489, 11103, 2);
INSERT INTO 'dancesstepsmap' VALUES (14490, 11103, 3);
INSERT INTO 'dancesstepsmap' VALUES (14491, 11103, 1);
INSERT INTO 'dancesstepsmap' VALUES (14492, 11104, 1);
INSERT INTO 'dancesstepsmap' VALUES (14493, 11105, 5);
INSERT INTO 'dancesstepsmap' VALUES (14494, 11105, 4);
INSERT INTO 'dancesstepsmap' VALUES (14495, 11105, 1);
INSERT INTO 'dancesstepsmap' VALUES (14496, 11105, 2);
INSERT INTO 'dancesstepsmap' VALUES (14497, 12514, 1);
INSERT INTO 'dancesstepsmap' VALUES (14498, 12514, 2);
INSERT INTO 'dancesstepsmap' VALUES (14499, 12515, 1);
INSERT INTO 'dancesstepsmap' VALUES (14500, 12515, 3);
INSERT INTO 'dancesstepsmap' VALUES (14501, 12516, 4);
INSERT INTO 'dancesstepsmap' VALUES (14502, 12516, 5);
INSERT INTO 'dancesstepsmap' VALUES (14503, 12517, 2);
INSERT INTO 'dancesstepsmap' VALUES (14504, 12518, 4);
INSERT INTO 'dancesstepsmap' VALUES (14505, 12519, 1);
INSERT INTO 'dancesstepsmap' VALUES (14506, 12520, 1);
INSERT INTO 'dancesstepsmap' VALUES (14507, 12521, 4);
INSERT INTO 'dancesstepsmap' VALUES (14508, 12521, 5);
INSERT INTO 'dancesstepsmap' VALUES (14509, 12522, 3);
INSERT INTO 'dancesstepsmap' VALUES (14510, 12522, 1);
INSERT INTO 'dancesstepsmap' VALUES (14511, 12523, 2);
INSERT INTO 'dancesstepsmap' VALUES (14512, 12523, 1);
INSERT INTO 'dancesstepsmap' VALUES (14513, 12524, 1);
INSERT INTO 'dancesstepsmap' VALUES (14514, 12525, 4);
INSERT INTO 'dancesstepsmap' VALUES (14515, 12526, 2);
INSERT INTO 'dancesstepsmap' VALUES (14516, 12526, 3);
INSERT INTO 'dancesstepsmap' VALUES (14517, 12526, 1);
INSERT INTO 'dancesstepsmap' VALUES (14518, 12527, 1);
INSERT INTO 'dancesstepsmap' VALUES (14519, 12527, 2);
INSERT INTO 'dancesstepsmap' VALUES (14520, 12529, 4);
INSERT INTO 'dancesstepsmap' VALUES (14521, 12530, 1);
INSERT INTO 'dancesstepsmap' VALUES (14522, 12531, 1);
INSERT INTO 'dancesstepsmap' VALUES (14523, 12532, 1);
INSERT INTO 'dancesstepsmap' VALUES (14524, 12532, 2);
INSERT INTO 'dancesstepsmap' VALUES (14525, 12532, 3);
INSERT INTO 'dancesstepsmap' VALUES (14526, 12533, 5);
INSERT INTO 'dancesstepsmap' VALUES (14527, 12533, 4);
INSERT INTO 'dancesstepsmap' VALUES (14528, 12534, 1);
INSERT INTO 'dancesstepsmap' VALUES (14529, 12534, 3);
INSERT INTO 'dancesstepsmap' VALUES (14530, 12528, 1);
INSERT INTO 'dancesstepsmap' VALUES (14531, 12535, 1);
INSERT INTO 'dancesstepsmap' VALUES (14532, 11997, 2);
INSERT INTO 'dancesstepsmap' VALUES (14533, 11998, 4);
INSERT INTO 'dancesstepsmap' VALUES (14534, 11999, 1);
INSERT INTO 'dancesstepsmap' VALUES (14535, 11999, 2);
INSERT INTO 'dancesstepsmap' VALUES (14536, 11999, 3);
INSERT INTO 'dancesstepsmap' VALUES (14537, 11994, 4);
INSERT INTO 'dancesstepsmap' VALUES (14538, 11994, 5);
INSERT INTO 'dancesstepsmap' VALUES (14539, 10501, 2);
INSERT INTO 'dancesstepsmap' VALUES (14540, 12000, 4);
INSERT INTO 'dancesstepsmap' VALUES (14541, 12001, 1);
INSERT INTO 'dancesstepsmap' VALUES (14542, 12001, 2);
INSERT INTO 'dancesstepsmap' VALUES (14543, 11992, 4);
INSERT INTO 'dancesstepsmap' VALUES (14544, 11992, 5);
INSERT INTO 'dancesstepsmap' VALUES (14545, 11993, 1);
INSERT INTO 'dancesstepsmap' VALUES (14546, 11993, 3);
INSERT INTO 'dancesstepsmap' VALUES (14547, 11991, 4);
INSERT INTO 'dancesstepsmap' VALUES (14548, 11991, 5);
INSERT INTO 'dancesstepsmap' VALUES (14549, 11995, 1);
INSERT INTO 'dancesstepsmap' VALUES (14550, 11996, 4);
INSERT INTO 'dancesstepsmap' VALUES (14551, 11996, 5);
INSERT INTO 'dancesstepsmap' VALUES (14552, 10589, 4);
INSERT INTO 'dancesstepsmap' VALUES (14553, 10589, 5);
INSERT INTO 'dancesstepsmap' VALUES (14554, 10591, 2);
INSERT INTO 'dancesstepsmap' VALUES (14555, 10591, 3);
INSERT INTO 'dancesstepsmap' VALUES (14556, 10591, 1);
INSERT INTO 'dancesstepsmap' VALUES (14557, 11747, 4);
INSERT INTO 'dancesstepsmap' VALUES (14558, 10590, 1);
INSERT INTO 'dancesstepsmap' VALUES (14559, 10590, 2);
INSERT INTO 'dancesstepsmap' VALUES (14560, 10588, 1);
INSERT INTO 'dancesstepsmap' VALUES (14561, 11748, 2);
INSERT INTO 'dancesstepsmap' VALUES (14562, 11748, 1);
INSERT INTO 'dancesstepsmap' VALUES (14563, 12536, 1);
INSERT INTO 'dancesstepsmap' VALUES (14564, 11739, 4);
INSERT INTO 'dancesstepsmap' VALUES (14565, 11740, 4);
INSERT INTO 'dancesstepsmap' VALUES (14566, 3587, 2);
INSERT INTO 'dancesstepsmap' VALUES (14567, 11741, 4);
INSERT INTO 'dancesstepsmap' VALUES (14568, 11742, 1);
INSERT INTO 'dancesstepsmap' VALUES (14569, 7760, 2);
INSERT INTO 'dancesstepsmap' VALUES (14570, 7760, 3);
INSERT INTO 'dancesstepsmap' VALUES (14571, 11743, 4);
INSERT INTO 'dancesstepsmap' VALUES (14572, 11743, 5);
INSERT INTO 'dancesstepsmap' VALUES (14573, 7856, 3);
INSERT INTO 'dancesstepsmap' VALUES (14574, 11744, 4);
INSERT INTO 'dancesstepsmap' VALUES (14575, 11745, 1);
INSERT INTO 'dancesstepsmap' VALUES (14576, 7290, 3);
INSERT INTO 'dancesstepsmap' VALUES (14577, 10435, 4);
INSERT INTO 'dancesstepsmap' VALUES (14578, 12537, 1);
INSERT INTO 'dancesstepsmap' VALUES (14579, 12539, 1);
INSERT INTO 'dancesstepsmap' VALUES (14580, 12540, 5);
INSERT INTO 'dancesstepsmap' VALUES (14581, 12540, 4);
INSERT INTO 'dancesstepsmap' VALUES (14582, 12416, 2);
INSERT INTO 'dancesstepsmap' VALUES (14583, 12416, 1);
INSERT INTO 'dancesstepsmap' VALUES (14584, 12289, 1);
INSERT INTO 'dancesstepsmap' VALUES (14585, 12541, 1);
INSERT INTO 'dancesstepsmap' VALUES (14586, 12541, 3);
INSERT INTO 'dancesstepsmap' VALUES (14587, 12216, 2);
INSERT INTO 'dancesstepsmap' VALUES (14588, 12216, 1);
INSERT INTO 'dancesstepsmap' VALUES (14589, 12542, 4);
INSERT INTO 'dancesstepsmap' VALUES (14590, 12542, 5);
INSERT INTO 'dancesstepsmap' VALUES (14591, 12543, 1);
INSERT INTO 'dancesstepsmap' VALUES (14592, 12544, 1);
INSERT INTO 'dancesstepsmap' VALUES (14593, 12544, 2);
INSERT INTO 'dancesstepsmap' VALUES (14594, 12538, 1);
INSERT INTO 'dancesstepsmap' VALUES (14595, 12566, 5);
INSERT INTO 'dancesstepsmap' VALUES (14596, 12566, 4);
INSERT INTO 'dancesstepsmap' VALUES (14597, 12567, 2);
INSERT INTO 'dancesstepsmap' VALUES (14598, 12567, 1);
INSERT INTO 'dancesstepsmap' VALUES (14599, 12568, 1);
INSERT INTO 'dancesstepsmap' VALUES (14600, 12569, 5);
INSERT INTO 'dancesstepsmap' VALUES (14601, 12569, 4);
INSERT INTO 'dancesstepsmap' VALUES (14602, 12570, 2);
INSERT INTO 'dancesstepsmap' VALUES (14603, 12570, 8);
INSERT INTO 'dancesstepsmap' VALUES (14604, 12570, 1);
INSERT INTO 'dancesstepsmap' VALUES (14606, 12166, 1);
INSERT INTO 'dancesstepsmap' VALUES (14607, 12571, 2);
INSERT INTO 'dancesstepsmap' VALUES (14608, 12571, 1);
INSERT INTO 'dancesstepsmap' VALUES (14609, 2447, 3);
INSERT INTO 'dancesstepsmap' VALUES (14610, 12572, 2);
INSERT INTO 'dancesstepsmap' VALUES (14611, 12572, 1);
INSERT INTO 'dancesstepsmap' VALUES (14612, 12573, 5);
INSERT INTO 'dancesstepsmap' VALUES (14613, 12573, 4);
INSERT INTO 'dancesstepsmap' VALUES (14614, 12574, 2);
INSERT INTO 'dancesstepsmap' VALUES (14615, 12574, 1);
INSERT INTO 'dancesstepsmap' VALUES (14616, 12575, 5);
INSERT INTO 'dancesstepsmap' VALUES (14617, 12575, 4);
INSERT INTO 'dancesstepsmap' VALUES (14618, 12576, 4);
INSERT INTO 'dancesstepsmap' VALUES (14619, 12577, 1);
INSERT INTO 'dancesstepsmap' VALUES (14620, 12577, 2);
INSERT INTO 'dancesstepsmap' VALUES (14621, 12578, 4);
INSERT INTO 'dancesstepsmap' VALUES (14622, 12579, 4);
INSERT INTO 'dancesstepsmap' VALUES (14623, 12580, 1);
INSERT INTO 'dancesstepsmap' VALUES (14624, 12580, 2);
INSERT INTO 'dancesstepsmap' VALUES (14625, 12581, 1);
INSERT INTO 'dancesstepsmap' VALUES (14626, 12583, 1);
INSERT INTO 'dancesstepsmap' VALUES (14627, 12584, 1);
INSERT INTO 'dancesstepsmap' VALUES (14628, 12585, 1);
INSERT INTO 'dancesstepsmap' VALUES (14629, 12586, 1);
INSERT INTO 'dancesstepsmap' VALUES (14630, 12587, 4);
INSERT INTO 'dancesstepsmap' VALUES (14631, 12588, 4);
INSERT INTO 'dancesstepsmap' VALUES (14632, 12589, 1);
INSERT INTO 'dancesstepsmap' VALUES (14633, 12589, 2);
INSERT INTO 'dancesstepsmap' VALUES (14634, 12590, 1);
INSERT INTO 'dancesstepsmap' VALUES (14635, 12590, 2);
INSERT INTO 'dancesstepsmap' VALUES (14636, 12591, 1);
INSERT INTO 'dancesstepsmap' VALUES (14637, 12591, 2);
INSERT INTO 'dancesstepsmap' VALUES (14638, 12592, 1);
INSERT INTO 'dancesstepsmap' VALUES (14639, 12592, 2);
INSERT INTO 'dancesstepsmap' VALUES (14640, 12593, 1);
INSERT INTO 'dancesstepsmap' VALUES (14641, 12593, 2);
INSERT INTO 'dancesstepsmap' VALUES (14642, 12594, 4);
INSERT INTO 'dancesstepsmap' VALUES (14643, 12595, 1);
INSERT INTO 'dancesstepsmap' VALUES (14644, 12597, 4);
INSERT INTO 'dancesstepsmap' VALUES (14645, 12599, 4);
INSERT INTO 'dancesstepsmap' VALUES (14646, 12599, 5);
INSERT INTO 'dancesstepsmap' VALUES (14647, 12600, 4);
INSERT INTO 'dancesstepsmap' VALUES (14648, 12601, 1);
INSERT INTO 'dancesstepsmap' VALUES (14649, 12602, 1);
INSERT INTO 'dancesstepsmap' VALUES (14650, 12603, 2);
INSERT INTO 'dancesstepsmap' VALUES (14651, 12603, 1);
INSERT INTO 'dancesstepsmap' VALUES (14652, 12604, 4);
INSERT INTO 'dancesstepsmap' VALUES (14653, 12604, 5);
INSERT INTO 'dancesstepsmap' VALUES (14654, 12605, 3);
INSERT INTO 'dancesstepsmap' VALUES (14655, 12605, 1);
INSERT INTO 'dancesstepsmap' VALUES (14656, 12605, 2);
INSERT INTO 'dancesstepsmap' VALUES (14658, 12638, 5);
INSERT INTO 'dancesstepsmap' VALUES (14659, 12638, 1);
INSERT INTO 'dancesstepsmap' VALUES (14660, 12638, 2);
INSERT INTO 'dancesstepsmap' VALUES (14661, 12638, 4);
INSERT INTO 'dancesstepsmap' VALUES (14662, 12638, 6);
INSERT INTO 'dancesstepsmap' VALUES (14664, 6172, 10);
INSERT INTO 'dancesstepsmap' VALUES (14665, 12640, 5);
INSERT INTO 'dancesstepsmap' VALUES (14666, 12640, 4);
INSERT INTO 'dancesstepsmap' VALUES (14667, 849, 2);
INSERT INTO 'dancesstepsmap' VALUES (14669, 12620, 4);
INSERT INTO 'dancesstepsmap' VALUES (14670, 12620, 5);
INSERT INTO 'dancesstepsmap' VALUES (14671, 12621, 1);
INSERT INTO 'dancesstepsmap' VALUES (14672, 12622, 4);
INSERT INTO 'dancesstepsmap' VALUES (14673, 12628, 1);
INSERT INTO 'dancesstepsmap' VALUES (14674, 12623, 1);
INSERT INTO 'dancesstepsmap' VALUES (14675, 12624, 1);
INSERT INTO 'dancesstepsmap' VALUES (14676, 12625, 4);
INSERT INTO 'dancesstepsmap' VALUES (14677, 12626, 5);
INSERT INTO 'dancesstepsmap' VALUES (14678, 12626, 4);
INSERT INTO 'dancesstepsmap' VALUES (14679, 12627, 2);
INSERT INTO 'dancesstepsmap' VALUES (14680, 12627, 1);
INSERT INTO 'dancesstepsmap' VALUES (14681, 12606, 4);
INSERT INTO 'dancesstepsmap' VALUES (14682, 12607, 4);
INSERT INTO 'dancesstepsmap' VALUES (14683, 12608, 4);
INSERT INTO 'dancesstepsmap' VALUES (14684, 12610, 1);
INSERT INTO 'dancesstepsmap' VALUES (14685, 12611, 2);
INSERT INTO 'dancesstepsmap' VALUES (14686, 12611, 1);
INSERT INTO 'dancesstepsmap' VALUES (14687, 12612, 1);
INSERT INTO 'dancesstepsmap' VALUES (14688, 12613, 5);
INSERT INTO 'dancesstepsmap' VALUES (14689, 12613, 4);
INSERT INTO 'dancesstepsmap' VALUES (14690, 12614, 1);
INSERT INTO 'dancesstepsmap' VALUES (14691, 12615, 2);
INSERT INTO 'dancesstepsmap' VALUES (14692, 12615, 1);
INSERT INTO 'dancesstepsmap' VALUES (14693, 12616, 4);
INSERT INTO 'dancesstepsmap' VALUES (14694, 12617, 2);
INSERT INTO 'dancesstepsmap' VALUES (14695, 12617, 3);
INSERT INTO 'dancesstepsmap' VALUES (14696, 12619, 2);
INSERT INTO 'dancesstepsmap' VALUES (14697, 12609, 2);
INSERT INTO 'dancesstepsmap' VALUES (14698, 12609, 1);
INSERT INTO 'dancesstepsmap' VALUES (14699, 3577, 2);
INSERT INTO 'dancesstepsmap' VALUES (14700, 12641, 5);
INSERT INTO 'dancesstepsmap' VALUES (14701, 12641, 4);
INSERT INTO 'dancesstepsmap' VALUES (14702, 12642, 1);
INSERT INTO 'dancesstepsmap' VALUES (14703, 12642, 3);
INSERT INTO 'dancesstepsmap' VALUES (14704, 2956, 2);
INSERT INTO 'dancesstepsmap' VALUES (14705, 2956, 3);
INSERT INTO 'dancesstepsmap' VALUES (14706, 8792, 2);
INSERT INTO 'dancesstepsmap' VALUES (14707, 12661, 1);
INSERT INTO 'dancesstepsmap' VALUES (14708, 12661, 3);
INSERT INTO 'dancesstepsmap' VALUES (14709, 12662, 4);
INSERT INTO 'dancesstepsmap' VALUES (14710, 12663, 1);
INSERT INTO 'dancesstepsmap' VALUES (14711, 12663, 3);
INSERT INTO 'dancesstepsmap' VALUES (14712, 12664, 1);
INSERT INTO 'dancesstepsmap' VALUES (14713, 12665, 1);
INSERT INTO 'dancesstepsmap' VALUES (14714, 9223, 4);
INSERT INTO 'dancesstepsmap' VALUES (14715, 12666, 4);
INSERT INTO 'dancesstepsmap' VALUES (14716, 12666, 5);
INSERT INTO 'dancesstepsmap' VALUES (14717, 12666, 1);
INSERT INTO 'dancesstepsmap' VALUES (14718, 12666, 2);
INSERT INTO 'dancesstepsmap' VALUES (14719, 12667, 2);
INSERT INTO 'dancesstepsmap' VALUES (14720, 12667, 3);
INSERT INTO 'dancesstepsmap' VALUES (14721, 11420, 4);
INSERT INTO 'dancesstepsmap' VALUES (14723, 12669, 1);
INSERT INTO 'dancesstepsmap' VALUES (14724, 12669, 3);
INSERT INTO 'dancesstepsmap' VALUES (14725, 12670, 4);
INSERT INTO 'dancesstepsmap' VALUES (14726, 12671, 4);
INSERT INTO 'dancesstepsmap' VALUES (14727, 12671, 5);
INSERT INTO 'dancesstepsmap' VALUES (14728, 12672, 4);
INSERT INTO 'dancesstepsmap' VALUES (14729, 12672, 5);
INSERT INTO 'dancesstepsmap' VALUES (14730, 12673, 2);
INSERT INTO 'dancesstepsmap' VALUES (14731, 12673, 1);
INSERT INTO 'dancesstepsmap' VALUES (14732, 12674, 1);
INSERT INTO 'dancesstepsmap' VALUES (14733, 12674, 3);
INSERT INTO 'dancesstepsmap' VALUES (14734, 12675, 5);
INSERT INTO 'dancesstepsmap' VALUES (14735, 12675, 4);
INSERT INTO 'dancesstepsmap' VALUES (14736, 12676, 4);
INSERT INTO 'dancesstepsmap' VALUES (14737, 12677, 4);
INSERT INTO 'dancesstepsmap' VALUES (14738, 12678, 1);
INSERT INTO 'dancesstepsmap' VALUES (14739, 12678, 3);
INSERT INTO 'dancesstepsmap' VALUES (14740, 12679, 2);
INSERT INTO 'dancesstepsmap' VALUES (14741, 12680, 1);
INSERT INTO 'dancesstepsmap' VALUES (14742, 12681, 4);
INSERT INTO 'dancesstepsmap' VALUES (14743, 12682, 2);
INSERT INTO 'dancesstepsmap' VALUES (14744, 12682, 1);
INSERT INTO 'dancesstepsmap' VALUES (14745, 12683, 4);
INSERT INTO 'dancesstepsmap' VALUES (14746, 12684, 1);
INSERT INTO 'dancesstepsmap' VALUES (14747, 12685, 2);
INSERT INTO 'dancesstepsmap' VALUES (14748, 12685, 1);
INSERT INTO 'dancesstepsmap' VALUES (14749, 12686, 1);
INSERT INTO 'dancesstepsmap' VALUES (14750, 12687, 4);
INSERT INTO 'dancesstepsmap' VALUES (14751, 12687, 5);
INSERT INTO 'dancesstepsmap' VALUES (14752, 12688, 1);
INSERT INTO 'dancesstepsmap' VALUES (14753, 12689, 5);
INSERT INTO 'dancesstepsmap' VALUES (14754, 12689, 4);
INSERT INTO 'dancesstepsmap' VALUES (14755, 12690, 1);
INSERT INTO 'dancesstepsmap' VALUES (14756, 12691, 4);
INSERT INTO 'dancesstepsmap' VALUES (14757, 12692, 5);
INSERT INTO 'dancesstepsmap' VALUES (14758, 12692, 4);
INSERT INTO 'dancesstepsmap' VALUES (14759, 12693, 1);
INSERT INTO 'dancesstepsmap' VALUES (14760, 12693, 2);
INSERT INTO 'dancesstepsmap' VALUES (14761, 12694, 4);
INSERT INTO 'dancesstepsmap' VALUES (14762, 12695, 1);
INSERT INTO 'dancesstepsmap' VALUES (14763, 12695, 2);
INSERT INTO 'dancesstepsmap' VALUES (14764, 11735, 5);
INSERT INTO 'dancesstepsmap' VALUES (14765, 11735, 4);
INSERT INTO 'dancesstepsmap' VALUES (14766, 11736, 1);
INSERT INTO 'dancesstepsmap' VALUES (14767, 11736, 3);
INSERT INTO 'dancesstepsmap' VALUES (14768, 11737, 4);
INSERT INTO 'dancesstepsmap' VALUES (14769, 11738, 1);
INSERT INTO 'dancesstepsmap' VALUES (14770, 10343, 3);
INSERT INTO 'dancesstepsmap' VALUES (14771, 7274, 2);
INSERT INTO 'dancesstepsmap' VALUES (14772, 7274, 1);
INSERT INTO 'dancesstepsmap' VALUES (14773, 7297, 4);
INSERT INTO 'dancesstepsmap' VALUES (14774, 7300, 2);
INSERT INTO 'dancesstepsmap' VALUES (14775, 7300, 1);
INSERT INTO 'dancesstepsmap' VALUES (14776, 7301, 4);
INSERT INTO 'dancesstepsmap' VALUES (14777, 7301, 5);
INSERT INTO 'dancesstepsmap' VALUES (14778, 7304, 2);
INSERT INTO 'dancesstepsmap' VALUES (14779, 7304, 1);
INSERT INTO 'dancesstepsmap' VALUES (14780, 7311, 4);
INSERT INTO 'dancesstepsmap' VALUES (14781, 7311, 5);
INSERT INTO 'dancesstepsmap' VALUES (14782, 7312, 1);
INSERT INTO 'dancesstepsmap' VALUES (14783, 7312, 3);
INSERT INTO 'dancesstepsmap' VALUES (14784, 7313, 1);
INSERT INTO 'dancesstepsmap' VALUES (14785, 7313, 2);
INSERT INTO 'dancesstepsmap' VALUES (14786, 7316, 3);
INSERT INTO 'dancesstepsmap' VALUES (14787, 7316, 1);
INSERT INTO 'dancesstepsmap' VALUES (14788, 7317, 2);
INSERT INTO 'dancesstepsmap' VALUES (14789, 7317, 1);
INSERT INTO 'dancesstepsmap' VALUES (14790, 7318, 1);
INSERT INTO 'dancesstepsmap' VALUES (14791, 7318, 2);
INSERT INTO 'dancesstepsmap' VALUES (14792, 7322, 1);
INSERT INTO 'dancesstepsmap' VALUES (14793, 7322, 2);
INSERT INTO 'dancesstepsmap' VALUES (14794, 7326, 4);
INSERT INTO 'dancesstepsmap' VALUES (14795, 7328, 1);
INSERT INTO 'dancesstepsmap' VALUES (14796, 8640, 1);
INSERT INTO 'dancesstepsmap' VALUES (14797, 8640, 3);
INSERT INTO 'dancesstepsmap' VALUES (14798, 12719, 4);
INSERT INTO 'dancesstepsmap' VALUES (14799, 6821, 4);
INSERT INTO 'dancesstepsmap' VALUES (14800, 6821, 5);
INSERT INTO 'dancesstepsmap' VALUES (14801, 6821, 1);
INSERT INTO 'dancesstepsmap' VALUES (14802, 6821, 2);
INSERT INTO 'dancesstepsmap' VALUES (14803, 961, 2);
INSERT INTO 'dancesstepsmap' VALUES (14804, 2634, 5);
INSERT INTO 'dancesstepsmap' VALUES (14805, 12720, 2);
INSERT INTO 'dancesstepsmap' VALUES (14806, 12720, 3);
INSERT INTO 'dancesstepsmap' VALUES (14807, 12720, 1);
INSERT INTO 'dancesstepsmap' VALUES (14808, 9864, 5);
INSERT INTO 'dancesstepsmap' VALUES (14809, 12722, 2);
INSERT INTO 'dancesstepsmap' VALUES (14810, 12722, 1);
INSERT INTO 'dancesstepsmap' VALUES (14811, 12723, 2);
INSERT INTO 'dancesstepsmap' VALUES (14812, 12723, 3);
INSERT INTO 'dancesstepsmap' VALUES (14813, 12723, 1);
INSERT INTO 'dancesstepsmap' VALUES (14814, 12724, 2);
INSERT INTO 'dancesstepsmap' VALUES (14815, 12724, 1);
INSERT INTO 'dancesstepsmap' VALUES (14816, 12724, 3);
INSERT INTO 'dancesstepsmap' VALUES (14817, 12725, 2);
INSERT INTO 'dancesstepsmap' VALUES (14818, 12725, 3);
INSERT INTO 'dancesstepsmap' VALUES (14819, 12725, 1);
INSERT INTO 'dancesstepsmap' VALUES (14820, 12726, 5);
INSERT INTO 'dancesstepsmap' VALUES (14821, 12727, 3);
INSERT INTO 'dancesstepsmap' VALUES (14822, 12727, 1);
INSERT INTO 'dancesstepsmap' VALUES (14823, 9893, 2);
INSERT INTO 'dancesstepsmap' VALUES (14824, 4133, 2);
INSERT INTO 'dancesstepsmap' VALUES (14825, 4716, 2);
INSERT INTO 'dancesstepsmap' VALUES (23169, 18254, 1);
INSERT INTO 'dancesstepsmap' VALUES (14827, 12728, 5);
INSERT INTO 'dancesstepsmap' VALUES (14828, 12728, 4);
INSERT INTO 'dancesstepsmap' VALUES (14829, 12730, 2);
INSERT INTO 'dancesstepsmap' VALUES (14830, 12730, 1);
INSERT INTO 'dancesstepsmap' VALUES (14657, 12638, 102);
INSERT INTO 'dancesstepsmap' VALUES (14831, 12730, 3);
INSERT INTO 'dancesstepsmap' VALUES (14832, 12731, 5);
INSERT INTO 'dancesstepsmap' VALUES (14833, 12731, 4);
INSERT INTO 'dancesstepsmap' VALUES (14834, 12732, 1);
INSERT INTO 'dancesstepsmap' VALUES (14835, 12732, 3);
INSERT INTO 'dancesstepsmap' VALUES (14836, 12732, 2);
INSERT INTO 'dancesstepsmap' VALUES (14837, 12733, 5);
INSERT INTO 'dancesstepsmap' VALUES (14838, 12733, 4);
INSERT INTO 'dancesstepsmap' VALUES (14839, 12734, 2);
INSERT INTO 'dancesstepsmap' VALUES (14840, 12734, 3);
INSERT INTO 'dancesstepsmap' VALUES (14841, 12734, 1);
INSERT INTO 'dancesstepsmap' VALUES (14842, 12735, 2);
INSERT INTO 'dancesstepsmap' VALUES (14843, 12736, 2);
INSERT INTO 'dancesstepsmap' VALUES (14844, 12736, 1);
INSERT INTO 'dancesstepsmap' VALUES (14845, 12736, 3);
INSERT INTO 'dancesstepsmap' VALUES (14846, 12737, 1);
INSERT INTO 'dancesstepsmap' VALUES (14847, 12738, 5);
INSERT INTO 'dancesstepsmap' VALUES (14848, 12738, 9);
INSERT INTO 'dancesstepsmap' VALUES (14849, 12738, 4);
INSERT INTO 'dancesstepsmap' VALUES (14850, 12739, 2);
INSERT INTO 'dancesstepsmap' VALUES (14851, 12739, 1);
INSERT INTO 'dancesstepsmap' VALUES (14855, 12741, 5);
INSERT INTO 'dancesstepsmap' VALUES (14856, 12741, 4);
INSERT INTO 'dancesstepsmap' VALUES (14857, 12742, 1);
INSERT INTO 'dancesstepsmap' VALUES (14858, 12743, 4);
INSERT INTO 'dancesstepsmap' VALUES (14859, 12743, 5);
INSERT INTO 'dancesstepsmap' VALUES (14860, 12744, 2);
INSERT INTO 'dancesstepsmap' VALUES (14861, 12744, 1);
INSERT INTO 'dancesstepsmap' VALUES (14862, 12745, 4);
INSERT INTO 'dancesstepsmap' VALUES (14863, 12746, 1);
INSERT INTO 'dancesstepsmap' VALUES (14864, 12746, 3);
INSERT INTO 'dancesstepsmap' VALUES (14865, 12747, 1);
INSERT INTO 'dancesstepsmap' VALUES (14866, 12748, 1);
INSERT INTO 'dancesstepsmap' VALUES (14867, 12748, 3);
INSERT INTO 'dancesstepsmap' VALUES (14868, 12749, 5);
INSERT INTO 'dancesstepsmap' VALUES (14869, 12749, 4);
INSERT INTO 'dancesstepsmap' VALUES (14870, 12750, 1);
INSERT INTO 'dancesstepsmap' VALUES (14871, 12750, 3);
INSERT INTO 'dancesstepsmap' VALUES (14872, 12751, 5);
INSERT INTO 'dancesstepsmap' VALUES (14873, 12751, 4);
INSERT INTO 'dancesstepsmap' VALUES (14874, 12752, 2);
INSERT INTO 'dancesstepsmap' VALUES (14875, 12752, 1);
INSERT INTO 'dancesstepsmap' VALUES (14876, 12753, 4);
INSERT INTO 'dancesstepsmap' VALUES (14877, 12754, 1);
INSERT INTO 'dancesstepsmap' VALUES (14878, 12755, 3);
INSERT INTO 'dancesstepsmap' VALUES (14879, 12755, 1);
INSERT INTO 'dancesstepsmap' VALUES (14880, 12756, 5);
INSERT INTO 'dancesstepsmap' VALUES (14881, 12756, 4);
INSERT INTO 'dancesstepsmap' VALUES (14882, 12757, 1);
INSERT INTO 'dancesstepsmap' VALUES (14883, 12757, 3);
INSERT INTO 'dancesstepsmap' VALUES (14884, 12758, 1);
INSERT INTO 'dancesstepsmap' VALUES (14885, 12759, 4);
INSERT INTO 'dancesstepsmap' VALUES (14886, 12760, 1);
INSERT INTO 'dancesstepsmap' VALUES (14887, 12760, 3);
INSERT INTO 'dancesstepsmap' VALUES (14888, 12761, 1);
INSERT INTO 'dancesstepsmap' VALUES (14889, 12761, 3);
INSERT INTO 'dancesstepsmap' VALUES (14890, 12762, 4);
INSERT INTO 'dancesstepsmap' VALUES (14891, 12762, 6);
INSERT INTO 'dancesstepsmap' VALUES (14892, 12763, 1);
INSERT INTO 'dancesstepsmap' VALUES (14893, 12764, 1);
INSERT INTO 'dancesstepsmap' VALUES (14895, 12765, 4);
INSERT INTO 'dancesstepsmap' VALUES (14896, 12766, 1);
INSERT INTO 'dancesstepsmap' VALUES (14898, 12767, 1);
INSERT INTO 'dancesstepsmap' VALUES (14899, 12768, 1);
INSERT INTO 'dancesstepsmap' VALUES (14900, 12768, 2);
INSERT INTO 'dancesstepsmap' VALUES (14901, 12768, 3);
INSERT INTO 'dancesstepsmap' VALUES (14902, 7296, 4);
INSERT INTO 'dancesstepsmap' VALUES (14905, 12769, 3);
INSERT INTO 'dancesstepsmap' VALUES (14906, 12769, 1);
INSERT INTO 'dancesstepsmap' VALUES (14907, 7293, 1);
INSERT INTO 'dancesstepsmap' VALUES (14908, 12772, 1);
INSERT INTO 'dancesstepsmap' VALUES (14909, 1072, 2);
INSERT INTO 'dancesstepsmap' VALUES (14910, 5888, 2);
INSERT INTO 'dancesstepsmap' VALUES (14911, 4617, 2);
INSERT INTO 'dancesstepsmap' VALUES (14912, 896, 3);
INSERT INTO 'dancesstepsmap' VALUES (14913, 5802, 2);
INSERT INTO 'dancesstepsmap' VALUES (14914, 10923, 1);
INSERT INTO 'dancesstepsmap' VALUES (14915, 10923, 3);
INSERT INTO 'dancesstepsmap' VALUES (14916, 5034, 3);
INSERT INTO 'dancesstepsmap' VALUES (14917, 12399, 1);
INSERT INTO 'dancesstepsmap' VALUES (14918, 12777, 1);
INSERT INTO 'dancesstepsmap' VALUES (14919, 12777, 3);
INSERT INTO 'dancesstepsmap' VALUES (14920, 12778, 1);
INSERT INTO 'dancesstepsmap' VALUES (14921, 12778, 3);
INSERT INTO 'dancesstepsmap' VALUES (14922, 12779, 1);
INSERT INTO 'dancesstepsmap' VALUES (14923, 12779, 3);
INSERT INTO 'dancesstepsmap' VALUES (14924, 12780, 1);
INSERT INTO 'dancesstepsmap' VALUES (14925, 12781, 1);
INSERT INTO 'dancesstepsmap' VALUES (14926, 12781, 3);
INSERT INTO 'dancesstepsmap' VALUES (14927, 12782, 4);
INSERT INTO 'dancesstepsmap' VALUES (14928, 12782, 1);
INSERT INTO 'dancesstepsmap' VALUES (14929, 12782, 2);
INSERT INTO 'dancesstepsmap' VALUES (14930, 12783, 5);
INSERT INTO 'dancesstepsmap' VALUES (14931, 12783, 4);
INSERT INTO 'dancesstepsmap' VALUES (14932, 12784, 2);
INSERT INTO 'dancesstepsmap' VALUES (14933, 12784, 1);
INSERT INTO 'dancesstepsmap' VALUES (14934, 12785, 4);
INSERT INTO 'dancesstepsmap' VALUES (14935, 12785, 1);
INSERT INTO 'dancesstepsmap' VALUES (14936, 12786, 1);
INSERT INTO 'dancesstepsmap' VALUES (14937, 12786, 2);
INSERT INTO 'dancesstepsmap' VALUES (14938, 12786, 3);
INSERT INTO 'dancesstepsmap' VALUES (14939, 12787, 5);
INSERT INTO 'dancesstepsmap' VALUES (14940, 12788, 4);
INSERT INTO 'dancesstepsmap' VALUES (14941, 12788, 5);
INSERT INTO 'dancesstepsmap' VALUES (14942, 12789, 1);
INSERT INTO 'dancesstepsmap' VALUES (14943, 12789, 2);
INSERT INTO 'dancesstepsmap' VALUES (14944, 841, 2);
INSERT INTO 'dancesstepsmap' VALUES (14945, 853, 3);
INSERT INTO 'dancesstepsmap' VALUES (14946, 1414, 2);
INSERT INTO 'dancesstepsmap' VALUES (14947, 1668, 3);
INSERT INTO 'dancesstepsmap' VALUES (14948, 2260, 3);
INSERT INTO 'dancesstepsmap' VALUES (14949, 2518, 3);
INSERT INTO 'dancesstepsmap' VALUES (14950, 2651, 3);
INSERT INTO 'dancesstepsmap' VALUES (14951, 2955, 3);
INSERT INTO 'dancesstepsmap' VALUES (14952, 3731, 2);
INSERT INTO 'dancesstepsmap' VALUES (14954, 4616, 3);
INSERT INTO 'dancesstepsmap' VALUES (14955, 4616, 2);
INSERT INTO 'dancesstepsmap' VALUES (14956, 5061, 2);
INSERT INTO 'dancesstepsmap' VALUES (14957, 5579, 3);
INSERT INTO 'dancesstepsmap' VALUES (14958, 5960, 3);
INSERT INTO 'dancesstepsmap' VALUES (14959, 6522, 3);
INSERT INTO 'dancesstepsmap' VALUES (14960, 6771, 3);
INSERT INTO 'dancesstepsmap' VALUES (14961, 8039, 3);
INSERT INTO 'dancesstepsmap' VALUES (14962, 8040, 3);
INSERT INTO 'dancesstepsmap' VALUES (14963, 8041, 3);
INSERT INTO 'dancesstepsmap' VALUES (14964, 7653, 3);
INSERT INTO 'dancesstepsmap' VALUES (14965, 8048, 3);
INSERT INTO 'dancesstepsmap' VALUES (14966, 8050, 3);
INSERT INTO 'dancesstepsmap' VALUES (14967, 8052, 2);
INSERT INTO 'dancesstepsmap' VALUES (14968, 8053, 3);
INSERT INTO 'dancesstepsmap' VALUES (14969, 8055, 5);
INSERT INTO 'dancesstepsmap' VALUES (14970, 8056, 2);
INSERT INTO 'dancesstepsmap' VALUES (14971, 8059, 3);
INSERT INTO 'dancesstepsmap' VALUES (14972, 8062, 3);
INSERT INTO 'dancesstepsmap' VALUES (14973, 8064, 5);
INSERT INTO 'dancesstepsmap' VALUES (14974, 8065, 2);
INSERT INTO 'dancesstepsmap' VALUES (14975, 8065, 3);
INSERT INTO 'dancesstepsmap' VALUES (14976, 8066, 5);
INSERT INTO 'dancesstepsmap' VALUES (14977, 8068, 5);
INSERT INTO 'dancesstepsmap' VALUES (14978, 8069, 3);
INSERT INTO 'dancesstepsmap' VALUES (14979, 8071, 3);
INSERT INTO 'dancesstepsmap' VALUES (14980, 8072, 2);
INSERT INTO 'dancesstepsmap' VALUES (14981, 8072, 3);
INSERT INTO 'dancesstepsmap' VALUES (14982, 8074, 3);
INSERT INTO 'dancesstepsmap' VALUES (14983, 8076, 3);
INSERT INTO 'dancesstepsmap' VALUES (14984, 7935, 3);
INSERT INTO 'dancesstepsmap' VALUES (14985, 1088, 2);
INSERT INTO 'dancesstepsmap' VALUES (14986, 1088, 3);
INSERT INTO 'dancesstepsmap' VALUES (14987, 1749, 3);
INSERT INTO 'dancesstepsmap' VALUES (14988, 5635, 2);
INSERT INTO 'dancesstepsmap' VALUES (14989, 8085, 2);
INSERT INTO 'dancesstepsmap' VALUES (14990, 6347, 3);
INSERT INTO 'dancesstepsmap' VALUES (14991, 8079, 3);
INSERT INTO 'dancesstepsmap' VALUES (14992, 8082, 3);
INSERT INTO 'dancesstepsmap' VALUES (14993, 8084, 2);
INSERT INTO 'dancesstepsmap' VALUES (14994, 8084, 3);
INSERT INTO 'dancesstepsmap' VALUES (14995, 12630, 4);
INSERT INTO 'dancesstepsmap' VALUES (14996, 12631, 4);
INSERT INTO 'dancesstepsmap' VALUES (14997, 12219, 1);
INSERT INTO 'dancesstepsmap' VALUES (14998, 12219, 2);
INSERT INTO 'dancesstepsmap' VALUES (14999, 12632, 2);
INSERT INTO 'dancesstepsmap' VALUES (15000, 12632, 1);
INSERT INTO 'dancesstepsmap' VALUES (15001, 12633, 4);
INSERT INTO 'dancesstepsmap' VALUES (15002, 12633, 5);
INSERT INTO 'dancesstepsmap' VALUES (15003, 12634, 2);
INSERT INTO 'dancesstepsmap' VALUES (15004, 12634, 1);
INSERT INTO 'dancesstepsmap' VALUES (15005, 12635, 1);
INSERT INTO 'dancesstepsmap' VALUES (15006, 12635, 2);
INSERT INTO 'dancesstepsmap' VALUES (15007, 12636, 4);
INSERT INTO 'dancesstepsmap' VALUES (15008, 12637, 1);
INSERT INTO 'dancesstepsmap' VALUES (15009, 12637, 3);
INSERT INTO 'dancesstepsmap' VALUES (15010, 7298, 10);
INSERT INTO 'dancesstepsmap' VALUES (15011, 7298, 3);
INSERT INTO 'dancesstepsmap' VALUES (15012, 7299, 3);
INSERT INTO 'dancesstepsmap' VALUES (15013, 12790, 1);
INSERT INTO 'dancesstepsmap' VALUES (15014, 12790, 2);
INSERT INTO 'dancesstepsmap' VALUES (15015, 12791, 4);
INSERT INTO 'dancesstepsmap' VALUES (15016, 12791, 5);
INSERT INTO 'dancesstepsmap' VALUES (14897, 12766, 2);
INSERT INTO 'dancesstepsmap' VALUES (14894, 12764, 2);
INSERT INTO 'dancesstepsmap' VALUES (14903, 1784, 1);
INSERT INTO 'dancesstepsmap' VALUES (14904, 1784, 2);
INSERT INTO 'dancesstepsmap' VALUES (15017, 12792, 1);
INSERT INTO 'dancesstepsmap' VALUES (15018, 12793, 2);
INSERT INTO 'dancesstepsmap' VALUES (15019, 12793, 1);
INSERT INTO 'dancesstepsmap' VALUES (15020, 12794, 4);
INSERT INTO 'dancesstepsmap' VALUES (15021, 12794, 5);
INSERT INTO 'dancesstepsmap' VALUES (15022, 12808, 2);
INSERT INTO 'dancesstepsmap' VALUES (15023, 12808, 1);
INSERT INTO 'dancesstepsmap' VALUES (15024, 12808, 3);
INSERT INTO 'dancesstepsmap' VALUES (15025, 2959, 2);
INSERT INTO 'dancesstepsmap' VALUES (15026, 2959, 8);
INSERT INTO 'dancesstepsmap' VALUES (15027, 2959, 3);
INSERT INTO 'dancesstepsmap' VALUES (15028, 12809, 1);
INSERT INTO 'dancesstepsmap' VALUES (15029, 12809, 3);
INSERT INTO 'dancesstepsmap' VALUES (15030, 12810, 4);
INSERT INTO 'dancesstepsmap' VALUES (15031, 12810, 5);
INSERT INTO 'dancesstepsmap' VALUES (15032, 5817, 2);
INSERT INTO 'dancesstepsmap' VALUES (15033, 12811, 1);
INSERT INTO 'dancesstepsmap' VALUES (15034, 12812, 1);
INSERT INTO 'dancesstepsmap' VALUES (15035, 12813, 1);
INSERT INTO 'dancesstepsmap' VALUES (15036, 10980, 1);
INSERT INTO 'dancesstepsmap' VALUES (15037, 10980, 2);
INSERT INTO 'dancesstepsmap' VALUES (15038, 12814, 1);
INSERT INTO 'dancesstepsmap' VALUES (15039, 12815, 4);
INSERT INTO 'dancesstepsmap' VALUES (15040, 12815, 5);
INSERT INTO 'dancesstepsmap' VALUES (15041, 10985, 5);
INSERT INTO 'dancesstepsmap' VALUES (15042, 10985, 4);
INSERT INTO 'dancesstepsmap' VALUES (15043, 7608, 3);
INSERT INTO 'dancesstepsmap' VALUES (15044, 705, 10);
INSERT INTO 'dancesstepsmap' VALUES (15045, 705, 3);
INSERT INTO 'dancesstepsmap' VALUES (15046, 12816, 4);
INSERT INTO 'dancesstepsmap' VALUES (15047, 1901, 10);
INSERT INTO 'dancesstepsmap' VALUES (15048, 1901, 4);
INSERT INTO 'dancesstepsmap' VALUES (15049, 1901, 6);
INSERT INTO 'dancesstepsmap' VALUES (15050, 12818, 3);
INSERT INTO 'dancesstepsmap' VALUES (15051, 12818, 1);
INSERT INTO 'dancesstepsmap' VALUES (15052, 2730, 2);
INSERT INTO 'dancesstepsmap' VALUES (15053, 3703, 10);
INSERT INTO 'dancesstepsmap' VALUES (15054, 5819, 3);
INSERT INTO 'dancesstepsmap' VALUES (15055, 6583, 3);
INSERT INTO 'dancesstepsmap' VALUES (15056, 12824, 1);
INSERT INTO 'dancesstepsmap' VALUES (15057, 12825, 4);
INSERT INTO 'dancesstepsmap' VALUES (15058, 7278, 2);
INSERT INTO 'dancesstepsmap' VALUES (15059, 7278, 1);
INSERT INTO 'dancesstepsmap' VALUES (15060, 10471, 1);
INSERT INTO 'dancesstepsmap' VALUES (15061, 12411, 2);
INSERT INTO 'dancesstepsmap' VALUES (15062, 12411, 1);
INSERT INTO 'dancesstepsmap' VALUES (15063, 11629, 2);
INSERT INTO 'dancesstepsmap' VALUES (15064, 11629, 1);
INSERT INTO 'dancesstepsmap' VALUES (15065, 12833, 2);
INSERT INTO 'dancesstepsmap' VALUES (15066, 12833, 1);
INSERT INTO 'dancesstepsmap' VALUES (15067, 12834, 3);
INSERT INTO 'dancesstepsmap' VALUES (15068, 12834, 1);
INSERT INTO 'dancesstepsmap' VALUES (15069, 12835, 1);
INSERT INTO 'dancesstepsmap' VALUES (15070, 12836, 2);
INSERT INTO 'dancesstepsmap' VALUES (15071, 12836, 1);
INSERT INTO 'dancesstepsmap' VALUES (15072, 12837, 2);
INSERT INTO 'dancesstepsmap' VALUES (15073, 12837, 1);
INSERT INTO 'dancesstepsmap' VALUES (15074, 12838, 1);
INSERT INTO 'dancesstepsmap' VALUES (15075, 12838, 2);
INSERT INTO 'dancesstepsmap' VALUES (15076, 12839, 4);
INSERT INTO 'dancesstepsmap' VALUES (15077, 12840, 5);
INSERT INTO 'dancesstepsmap' VALUES (15078, 12840, 4);
INSERT INTO 'dancesstepsmap' VALUES (15079, 12841, 5);
INSERT INTO 'dancesstepsmap' VALUES (15080, 12841, 4);
INSERT INTO 'dancesstepsmap' VALUES (15081, 12843, 4);
INSERT INTO 'dancesstepsmap' VALUES (15082, 12843, 5);
INSERT INTO 'dancesstepsmap' VALUES (15083, 12844, 1);
INSERT INTO 'dancesstepsmap' VALUES (15084, 12845, 1);
INSERT INTO 'dancesstepsmap' VALUES (15085, 12845, 2);
INSERT INTO 'dancesstepsmap' VALUES (15086, 12846, 1);
INSERT INTO 'dancesstepsmap' VALUES (15087, 12846, 2);
INSERT INTO 'dancesstepsmap' VALUES (15088, 12847, 1);
INSERT INTO 'dancesstepsmap' VALUES (15089, 12848, 1);
INSERT INTO 'dancesstepsmap' VALUES (15090, 12849, 1);
INSERT INTO 'dancesstepsmap' VALUES (15091, 12849, 2);
INSERT INTO 'dancesstepsmap' VALUES (15092, 12850, 1);
INSERT INTO 'dancesstepsmap' VALUES (15093, 12851, 1);
INSERT INTO 'dancesstepsmap' VALUES (15094, 12852, 4);
INSERT INTO 'dancesstepsmap' VALUES (15095, 12852, 5);
INSERT INTO 'dancesstepsmap' VALUES (15096, 12853, 1);
INSERT INTO 'dancesstepsmap' VALUES (15097, 12854, 1);
INSERT INTO 'dancesstepsmap' VALUES (15098, 12854, 2);
INSERT INTO 'dancesstepsmap' VALUES (15099, 12855, 1);
INSERT INTO 'dancesstepsmap' VALUES (15100, 12856, 5);
INSERT INTO 'dancesstepsmap' VALUES (15101, 12856, 4);
INSERT INTO 'dancesstepsmap' VALUES (15102, 12857, 1);
INSERT INTO 'dancesstepsmap' VALUES (15103, 12857, 2);
INSERT INTO 'dancesstepsmap' VALUES (15104, 12858, 1);
INSERT INTO 'dancesstepsmap' VALUES (15105, 12859, 4);
INSERT INTO 'dancesstepsmap' VALUES (15106, 12860, 1);
INSERT INTO 'dancesstepsmap' VALUES (15107, 12861, 4);
INSERT INTO 'dancesstepsmap' VALUES (15108, 12862, 1);
INSERT INTO 'dancesstepsmap' VALUES (15109, 12863, 1);
INSERT INTO 'dancesstepsmap' VALUES (15110, 12864, 4);
INSERT INTO 'dancesstepsmap' VALUES (15111, 12865, 1);
INSERT INTO 'dancesstepsmap' VALUES (15112, 12135, 1);
INSERT INTO 'dancesstepsmap' VALUES (15113, 12144, 2);
INSERT INTO 'dancesstepsmap' VALUES (15114, 12162, 4);
INSERT INTO 'dancesstepsmap' VALUES (15115, 12192, 1);
INSERT INTO 'dancesstepsmap' VALUES (15116, 12192, 3);
INSERT INTO 'dancesstepsmap' VALUES (15117, 12194, 3);
INSERT INTO 'dancesstepsmap' VALUES (15118, 12194, 1);
INSERT INTO 'dancesstepsmap' VALUES (15119, 12256, 1);
INSERT INTO 'dancesstepsmap' VALUES (15120, 12276, 4);
INSERT INTO 'dancesstepsmap' VALUES (15121, 12292, 5);
INSERT INTO 'dancesstepsmap' VALUES (15122, 12292, 4);
INSERT INTO 'dancesstepsmap' VALUES (15123, 12421, 5);
INSERT INTO 'dancesstepsmap' VALUES (15124, 12421, 4);
INSERT INTO 'dancesstepsmap' VALUES (15125, 12318, 1);
INSERT INTO 'dancesstepsmap' VALUES (15126, 12326, 5);
INSERT INTO 'dancesstepsmap' VALUES (15127, 12367, 1);
INSERT INTO 'dancesstepsmap' VALUES (15128, 12372, 1);
INSERT INTO 'dancesstepsmap' VALUES (15129, 12423, 1);
INSERT INTO 'dancesstepsmap' VALUES (15130, 12377, 1);
INSERT INTO 'dancesstepsmap' VALUES (15132, 12387, 10);
INSERT INTO 'dancesstepsmap' VALUES (15133, 12387, 6);
INSERT INTO 'dancesstepsmap' VALUES (15134, 12387, 4);
INSERT INTO 'dancesstepsmap' VALUES (15135, 12387, 5);
INSERT INTO 'dancesstepsmap' VALUES (15136, 12388, 1);
INSERT INTO 'dancesstepsmap' VALUES (15137, 12395, 1);
INSERT INTO 'dancesstepsmap' VALUES (15138, 12410, 8);
INSERT INTO 'dancesstepsmap' VALUES (15139, 12410, 1);
INSERT INTO 'dancesstepsmap' VALUES (15140, 12420, 5);
INSERT INTO 'dancesstepsmap' VALUES (15141, 12420, 4);
INSERT INTO 'dancesstepsmap' VALUES (15142, 11800, 2);
INSERT INTO 'dancesstepsmap' VALUES (15143, 12866, 1);
INSERT INTO 'dancesstepsmap' VALUES (15144, 12867, 5);
INSERT INTO 'dancesstepsmap' VALUES (15145, 12867, 4);
INSERT INTO 'dancesstepsmap' VALUES (15146, 12868, 1);
INSERT INTO 'dancesstepsmap' VALUES (15147, 12868, 2);
INSERT INTO 'dancesstepsmap' VALUES (15148, 12869, 1);
INSERT INTO 'dancesstepsmap' VALUES (15149, 12869, 3);
INSERT INTO 'dancesstepsmap' VALUES (15150, 12870, 1);
INSERT INTO 'dancesstepsmap' VALUES (15151, 12870, 2);
INSERT INTO 'dancesstepsmap' VALUES (15152, 12870, 3);
INSERT INTO 'dancesstepsmap' VALUES (15153, 12871, 1);
INSERT INTO 'dancesstepsmap' VALUES (15154, 12871, 2);
INSERT INTO 'dancesstepsmap' VALUES (15155, 12872, 1);
INSERT INTO 'dancesstepsmap' VALUES (15156, 12873, 5);
INSERT INTO 'dancesstepsmap' VALUES (15157, 12873, 4);
INSERT INTO 'dancesstepsmap' VALUES (15158, 12874, 4);
INSERT INTO 'dancesstepsmap' VALUES (15159, 12874, 5);
INSERT INTO 'dancesstepsmap' VALUES (15160, 12875, 3);
INSERT INTO 'dancesstepsmap' VALUES (15161, 12875, 1);
INSERT INTO 'dancesstepsmap' VALUES (15162, 12875, 2);
INSERT INTO 'dancesstepsmap' VALUES (15163, 12876, 1);
INSERT INTO 'dancesstepsmap' VALUES (15164, 12877, 4);
INSERT INTO 'dancesstepsmap' VALUES (15167, 12880, 1);
INSERT INTO 'dancesstepsmap' VALUES (15168, 12881, 2);
INSERT INTO 'dancesstepsmap' VALUES (15169, 12881, 3);
INSERT INTO 'dancesstepsmap' VALUES (15170, 12882, 2);
INSERT INTO 'dancesstepsmap' VALUES (15171, 12882, 1);
INSERT INTO 'dancesstepsmap' VALUES (15172, 12883, 2);
INSERT INTO 'dancesstepsmap' VALUES (15173, 12883, 1);
INSERT INTO 'dancesstepsmap' VALUES (15174, 12884, 1);
INSERT INTO 'dancesstepsmap' VALUES (15175, 12884, 3);
INSERT INTO 'dancesstepsmap' VALUES (15176, 12885, 1);
INSERT INTO 'dancesstepsmap' VALUES (15177, 12886, 2);
INSERT INTO 'dancesstepsmap' VALUES (15178, 12886, 1);
INSERT INTO 'dancesstepsmap' VALUES (15179, 12887, 3);
INSERT INTO 'dancesstepsmap' VALUES (15180, 12887, 1);
INSERT INTO 'dancesstepsmap' VALUES (15181, 12887, 2);
INSERT INTO 'dancesstepsmap' VALUES (15182, 12888, 1);
INSERT INTO 'dancesstepsmap' VALUES (15183, 12889, 2);
INSERT INTO 'dancesstepsmap' VALUES (15184, 12889, 1);
INSERT INTO 'dancesstepsmap' VALUES (15185, 12706, 1);
INSERT INTO 'dancesstepsmap' VALUES (15186, 12706, 2);
INSERT INTO 'dancesstepsmap' VALUES (15187, 12890, 5);
INSERT INTO 'dancesstepsmap' VALUES (15188, 12890, 4);
INSERT INTO 'dancesstepsmap' VALUES (15190, 10464, 2);
INSERT INTO 'dancesstepsmap' VALUES (15191, 10464, 1);
INSERT INTO 'dancesstepsmap' VALUES (15192, 10464, 3);
INSERT INTO 'dancesstepsmap' VALUES (15193, 12892, 1);
INSERT INTO 'dancesstepsmap' VALUES (15194, 12892, 3);
INSERT INTO 'dancesstepsmap' VALUES (15195, 12893, 2);
INSERT INTO 'dancesstepsmap' VALUES (15196, 12894, 1);
INSERT INTO 'dancesstepsmap' VALUES (15197, 12895, 1);
INSERT INTO 'dancesstepsmap' VALUES (15198, 12896, 2);
INSERT INTO 'dancesstepsmap' VALUES (15199, 12896, 1);
INSERT INTO 'dancesstepsmap' VALUES (15200, 12898, 1);
INSERT INTO 'dancesstepsmap' VALUES (15201, 12900, 4);
INSERT INTO 'dancesstepsmap' VALUES (15202, 12901, 1);
INSERT INTO 'dancesstepsmap' VALUES (15203, 12902, 1);
INSERT INTO 'dancesstepsmap' VALUES (15204, 12902, 2);
INSERT INTO 'dancesstepsmap' VALUES (15205, 12902, 3);
INSERT INTO 'dancesstepsmap' VALUES (15206, 12903, 4);
INSERT INTO 'dancesstepsmap' VALUES (15207, 12903, 5);
INSERT INTO 'dancesstepsmap' VALUES (15208, 12904, 6);
INSERT INTO 'dancesstepsmap' VALUES (15209, 12904, 4);
INSERT INTO 'dancesstepsmap' VALUES (15210, 12904, 5);
INSERT INTO 'dancesstepsmap' VALUES (15211, 12905, 1);
INSERT INTO 'dancesstepsmap' VALUES (15212, 12906, 2);
INSERT INTO 'dancesstepsmap' VALUES (15213, 12906, 1);
INSERT INTO 'dancesstepsmap' VALUES (15214, 12696, 1);
INSERT INTO 'dancesstepsmap' VALUES (15215, 12696, 2);
INSERT INTO 'dancesstepsmap' VALUES (15216, 12907, 1);
INSERT INTO 'dancesstepsmap' VALUES (15217, 12908, 1);
INSERT INTO 'dancesstepsmap' VALUES (15218, 12908, 2);
INSERT INTO 'dancesstepsmap' VALUES (15219, 12909, 2);
INSERT INTO 'dancesstepsmap' VALUES (15220, 12909, 1);
INSERT INTO 'dancesstepsmap' VALUES (15221, 12909, 3);
INSERT INTO 'dancesstepsmap' VALUES (15222, 10644, 5);
INSERT INTO 'dancesstepsmap' VALUES (15223, 12910, 4);
INSERT INTO 'dancesstepsmap' VALUES (15224, 12910, 5);
INSERT INTO 'dancesstepsmap' VALUES (15225, 12911, 4);
INSERT INTO 'dancesstepsmap' VALUES (15226, 12911, 5);
INSERT INTO 'dancesstepsmap' VALUES (15227, 12912, 2);
INSERT INTO 'dancesstepsmap' VALUES (15228, 12912, 1);
INSERT INTO 'dancesstepsmap' VALUES (15231, 12914, 1);
INSERT INTO 'dancesstepsmap' VALUES (15232, 12914, 2);
INSERT INTO 'dancesstepsmap' VALUES (15233, 12916, 5);
INSERT INTO 'dancesstepsmap' VALUES (15234, 12916, 4);
INSERT INTO 'dancesstepsmap' VALUES (15235, 12917, 1);
INSERT INTO 'dancesstepsmap' VALUES (15236, 12917, 2);
INSERT INTO 'dancesstepsmap' VALUES (15237, 12918, 2);
INSERT INTO 'dancesstepsmap' VALUES (15238, 12918, 1);
INSERT INTO 'dancesstepsmap' VALUES (15239, 12919, 1);
INSERT INTO 'dancesstepsmap' VALUES (15240, 12920, 1);
INSERT INTO 'dancesstepsmap' VALUES (15241, 12921, 1);
INSERT INTO 'dancesstepsmap' VALUES (15242, 12922, 1);
INSERT INTO 'dancesstepsmap' VALUES (15243, 12922, 2);
INSERT INTO 'dancesstepsmap' VALUES (15244, 12922, 3);
INSERT INTO 'dancesstepsmap' VALUES (15245, 12923, 2);
INSERT INTO 'dancesstepsmap' VALUES (15246, 12923, 1);
INSERT INTO 'dancesstepsmap' VALUES (15247, 12924, 2);
INSERT INTO 'dancesstepsmap' VALUES (15248, 12925, 4);
INSERT INTO 'dancesstepsmap' VALUES (15249, 12927, 4);
INSERT INTO 'dancesstepsmap' VALUES (15250, 12927, 5);
INSERT INTO 'dancesstepsmap' VALUES (15251, 12366, 2);
INSERT INTO 'dancesstepsmap' VALUES (15252, 12366, 1);
INSERT INTO 'dancesstepsmap' VALUES (15253, 12366, 3);
INSERT INTO 'dancesstepsmap' VALUES (15254, 12929, 1);
INSERT INTO 'dancesstepsmap' VALUES (15255, 12929, 2);
INSERT INTO 'dancesstepsmap' VALUES (15256, 12930, 4);
INSERT INTO 'dancesstepsmap' VALUES (15257, 12934, 4);
INSERT INTO 'dancesstepsmap' VALUES (15258, 12901, 2);
INSERT INTO 'dancesstepsmap' VALUES (15259, 12935, 2);
INSERT INTO 'dancesstepsmap' VALUES (15260, 12935, 1);
INSERT INTO 'dancesstepsmap' VALUES (15261, 12936, 2);
INSERT INTO 'dancesstepsmap' VALUES (15262, 12936, 1);
INSERT INTO 'dancesstepsmap' VALUES (15263, 12937, 2);
INSERT INTO 'dancesstepsmap' VALUES (15264, 12937, 1);
INSERT INTO 'dancesstepsmap' VALUES (15265, 12937, 3);
INSERT INTO 'dancesstepsmap' VALUES (15266, 12938, 1);
INSERT INTO 'dancesstepsmap' VALUES (15267, 12938, 3);
INSERT INTO 'dancesstepsmap' VALUES (15268, 12939, 4);
INSERT INTO 'dancesstepsmap' VALUES (15269, 12940, 2);
INSERT INTO 'dancesstepsmap' VALUES (15270, 12941, 4);
INSERT INTO 'dancesstepsmap' VALUES (15271, 12941, 5);
INSERT INTO 'dancesstepsmap' VALUES (15272, 12942, 1);
INSERT INTO 'dancesstepsmap' VALUES (15273, 9748, 2);
INSERT INTO 'dancesstepsmap' VALUES (15274, 12943, 1);
INSERT INTO 'dancesstepsmap' VALUES (15275, 12944, 4);
INSERT INTO 'dancesstepsmap' VALUES (15276, 12944, 5);
INSERT INTO 'dancesstepsmap' VALUES (15277, 12945, 4);
INSERT INTO 'dancesstepsmap' VALUES (15278, 12946, 6);
INSERT INTO 'dancesstepsmap' VALUES (15279, 12946, 4);
INSERT INTO 'dancesstepsmap' VALUES (15280, 12946, 5);
INSERT INTO 'dancesstepsmap' VALUES (15281, 12947, 4);
INSERT INTO 'dancesstepsmap' VALUES (15282, 12947, 5);
INSERT INTO 'dancesstepsmap' VALUES (15283, 12948, 2);
INSERT INTO 'dancesstepsmap' VALUES (15284, 12948, 1);
INSERT INTO 'dancesstepsmap' VALUES (15285, 9292, 4);
INSERT INTO 'dancesstepsmap' VALUES (15286, 8337, 5);
INSERT INTO 'dancesstepsmap' VALUES (15287, 8329, 2);
INSERT INTO 'dancesstepsmap' VALUES (15288, 4908, 2);
INSERT INTO 'dancesstepsmap' VALUES (15289, 10484, 2);
INSERT INTO 'dancesstepsmap' VALUES (15290, 9836, 1);
INSERT INTO 'dancesstepsmap' VALUES (15291, 9836, 2);
INSERT INTO 'dancesstepsmap' VALUES (15292, 12997, 1);
INSERT INTO 'dancesstepsmap' VALUES (15293, 12997, 2);
INSERT INTO 'dancesstepsmap' VALUES (15294, 12998, 4);
INSERT INTO 'dancesstepsmap' VALUES (15295, 12998, 5);
INSERT INTO 'dancesstepsmap' VALUES (15296, 12999, 4);
INSERT INTO 'dancesstepsmap' VALUES (15297, 12999, 5);
INSERT INTO 'dancesstepsmap' VALUES (15298, 12999, 1);
INSERT INTO 'dancesstepsmap' VALUES (15299, 13000, 2);
INSERT INTO 'dancesstepsmap' VALUES (15300, 13000, 1);
INSERT INTO 'dancesstepsmap' VALUES (15301, 13001, 1);
INSERT INTO 'dancesstepsmap' VALUES (15302, 13001, 3);
INSERT INTO 'dancesstepsmap' VALUES (15303, 13003, 2);
INSERT INTO 'dancesstepsmap' VALUES (15304, 13003, 1);
INSERT INTO 'dancesstepsmap' VALUES (15305, 12995, 4);
INSERT INTO 'dancesstepsmap' VALUES (15306, 12993, 3);
INSERT INTO 'dancesstepsmap' VALUES (15307, 12993, 1);
INSERT INTO 'dancesstepsmap' VALUES (15308, 12985, 4);
INSERT INTO 'dancesstepsmap' VALUES (15309, 12985, 5);
INSERT INTO 'dancesstepsmap' VALUES (15310, 12986, 4);
INSERT INTO 'dancesstepsmap' VALUES (15311, 12987, 1);
INSERT INTO 'dancesstepsmap' VALUES (15312, 12992, 1);
INSERT INTO 'dancesstepsmap' VALUES (15313, 12992, 3);
INSERT INTO 'dancesstepsmap' VALUES (15314, 12991, 4);
INSERT INTO 'dancesstepsmap' VALUES (15315, 12989, 4);
INSERT INTO 'dancesstepsmap' VALUES (15316, 12984, 4);
INSERT INTO 'dancesstepsmap' VALUES (15317, 13047, 1);
INSERT INTO 'dancesstepsmap' VALUES (15318, 13048, 1);
INSERT INTO 'dancesstepsmap' VALUES (15319, 13049, 1);
INSERT INTO 'dancesstepsmap' VALUES (15320, 13050, 4);
INSERT INTO 'dancesstepsmap' VALUES (15321, 13050, 5);
INSERT INTO 'dancesstepsmap' VALUES (15322, 13051, 1);
INSERT INTO 'dancesstepsmap' VALUES (15323, 13053, 4);
INSERT INTO 'dancesstepsmap' VALUES (15324, 13055, 1);
INSERT INTO 'dancesstepsmap' VALUES (15325, 12990, 4);
INSERT INTO 'dancesstepsmap' VALUES (15326, 12994, 3);
INSERT INTO 'dancesstepsmap' VALUES (15327, 12994, 1);
INSERT INTO 'dancesstepsmap' VALUES (15328, 12988, 3);
INSERT INTO 'dancesstepsmap' VALUES (15329, 13056, 1);
INSERT INTO 'dancesstepsmap' VALUES (15330, 13057, 1);
INSERT INTO 'dancesstepsmap' VALUES (15331, 13058, 1);
INSERT INTO 'dancesstepsmap' VALUES (15332, 13058, 2);
INSERT INTO 'dancesstepsmap' VALUES (15333, 13059, 4);
INSERT INTO 'dancesstepsmap' VALUES (15334, 13059, 5);
INSERT INTO 'dancesstepsmap' VALUES (15335, 13060, 1);
INSERT INTO 'dancesstepsmap' VALUES (15336, 13061, 2);
INSERT INTO 'dancesstepsmap' VALUES (15337, 13062, 5);
INSERT INTO 'dancesstepsmap' VALUES (15338, 13062, 4);
INSERT INTO 'dancesstepsmap' VALUES (15339, 13063, 1);
INSERT INTO 'dancesstepsmap' VALUES (15340, 13064, 1);
INSERT INTO 'dancesstepsmap' VALUES (15341, 13065, 1);
INSERT INTO 'dancesstepsmap' VALUES (15342, 12956, 1);
INSERT INTO 'dancesstepsmap' VALUES (15343, 12953, 4);
INSERT INTO 'dancesstepsmap' VALUES (15344, 12952, 3);
INSERT INTO 'dancesstepsmap' VALUES (15345, 12952, 1);
INSERT INTO 'dancesstepsmap' VALUES (15346, 12957, 2);
INSERT INTO 'dancesstepsmap' VALUES (15347, 12957, 1);
INSERT INTO 'dancesstepsmap' VALUES (15348, 12951, 5);
INSERT INTO 'dancesstepsmap' VALUES (15349, 12951, 4);
INSERT INTO 'dancesstepsmap' VALUES (15350, 12950, 1);
INSERT INTO 'dancesstepsmap' VALUES (15351, 12954, 1);
INSERT INTO 'dancesstepsmap' VALUES (15352, 12949, 4);
INSERT INTO 'dancesstepsmap' VALUES (15353, 12955, 1);
INSERT INTO 'dancesstepsmap' VALUES (15354, 12955, 3);
INSERT INTO 'dancesstepsmap' VALUES (15355, 12959, 4);
INSERT INTO 'dancesstepsmap' VALUES (15358, 13066, 4);
INSERT INTO 'dancesstepsmap' VALUES (15359, 13067, 4);
INSERT INTO 'dancesstepsmap' VALUES (15360, 13067, 5);
INSERT INTO 'dancesstepsmap' VALUES (15361, 13068, 1);
INSERT INTO 'dancesstepsmap' VALUES (15362, 13069, 1);
INSERT INTO 'dancesstepsmap' VALUES (15363, 13070, 1);
INSERT INTO 'dancesstepsmap' VALUES (15364, 13070, 2);
INSERT INTO 'dancesstepsmap' VALUES (15365, 13071, 1);
INSERT INTO 'dancesstepsmap' VALUES (15366, 13071, 3);
INSERT INTO 'dancesstepsmap' VALUES (15367, 13073, 1);
INSERT INTO 'dancesstepsmap' VALUES (15368, 13073, 2);
INSERT INTO 'dancesstepsmap' VALUES (15369, 13073, 3);
INSERT INTO 'dancesstepsmap' VALUES (15370, 13074, 3);
INSERT INTO 'dancesstepsmap' VALUES (15371, 12967, 4);
INSERT INTO 'dancesstepsmap' VALUES (15372, 12966, 3);
INSERT INTO 'dancesstepsmap' VALUES (15373, 12966, 1);
INSERT INTO 'dancesstepsmap' VALUES (15374, 12960, 1);
INSERT INTO 'dancesstepsmap' VALUES (15375, 12961, 4);
INSERT INTO 'dancesstepsmap' VALUES (15376, 12971, 1);
INSERT INTO 'dancesstepsmap' VALUES (15377, 12971, 3);
INSERT INTO 'dancesstepsmap' VALUES (15378, 12965, 1);
INSERT INTO 'dancesstepsmap' VALUES (15379, 12965, 4);
INSERT INTO 'dancesstepsmap' VALUES (15380, 12962, 4);
INSERT INTO 'dancesstepsmap' VALUES (15381, 12962, 5);
INSERT INTO 'dancesstepsmap' VALUES (15382, 12969, 1);
INSERT INTO 'dancesstepsmap' VALUES (15383, 12968, 1);
INSERT INTO 'dancesstepsmap' VALUES (15385, 12964, 1);
INSERT INTO 'dancesstepsmap' VALUES (15386, 12970, 1);
INSERT INTO 'dancesstepsmap' VALUES (15387, 13075, 4);
INSERT INTO 'dancesstepsmap' VALUES (15388, 13076, 1);
INSERT INTO 'dancesstepsmap' VALUES (15389, 13076, 3);
INSERT INTO 'dancesstepsmap' VALUES (15390, 13077, 1);
INSERT INTO 'dancesstepsmap' VALUES (15391, 13078, 4);
INSERT INTO 'dancesstepsmap' VALUES (15392, 13079, 1);
INSERT INTO 'dancesstepsmap' VALUES (15393, 13079, 2);
INSERT INTO 'dancesstepsmap' VALUES (15394, 13080, 4);
INSERT INTO 'dancesstepsmap' VALUES (15395, 13081, 1);
INSERT INTO 'dancesstepsmap' VALUES (15396, 13082, 4);
INSERT INTO 'dancesstepsmap' VALUES (15397, 13082, 5);
INSERT INTO 'dancesstepsmap' VALUES (15398, 13082, 1);
INSERT INTO 'dancesstepsmap' VALUES (15399, 13082, 2);
INSERT INTO 'dancesstepsmap' VALUES (15401, 2254, 5);
INSERT INTO 'dancesstepsmap' VALUES (15402, 13083, 1);
INSERT INTO 'dancesstepsmap' VALUES (15403, 13084, 4);
INSERT INTO 'dancesstepsmap' VALUES (15404, 13084, 5);
INSERT INTO 'dancesstepsmap' VALUES (15405, 13085, 4);
INSERT INTO 'dancesstepsmap' VALUES (15406, 13086, 6);
INSERT INTO 'dancesstepsmap' VALUES (15407, 13086, 4);
INSERT INTO 'dancesstepsmap' VALUES (15408, 12974, 1);
INSERT INTO 'dancesstepsmap' VALUES (15409, 12974, 3);
INSERT INTO 'dancesstepsmap' VALUES (15410, 12973, 4);
INSERT INTO 'dancesstepsmap' VALUES (15411, 13087, 1);
INSERT INTO 'dancesstepsmap' VALUES (15412, 13087, 3);
INSERT INTO 'dancesstepsmap' VALUES (15413, 13088, 1);
INSERT INTO 'dancesstepsmap' VALUES (15414, 13088, 2);
INSERT INTO 'dancesstepsmap' VALUES (15415, 13088, 3);
INSERT INTO 'dancesstepsmap' VALUES (15416, 13089, 2);
INSERT INTO 'dancesstepsmap' VALUES (15417, 13089, 1);
INSERT INTO 'dancesstepsmap' VALUES (15418, 10493, 4);
INSERT INTO 'dancesstepsmap' VALUES (15419, 7993, 2);
INSERT INTO 'dancesstepsmap' VALUES (15420, 13104, 1);
INSERT INTO 'dancesstepsmap' VALUES (15421, 13104, 2);
INSERT INTO 'dancesstepsmap' VALUES (15422, 12982, 1);
INSERT INTO 'dancesstepsmap' VALUES (15423, 12979, 4);
INSERT INTO 'dancesstepsmap' VALUES (15424, 12972, 1);
INSERT INTO 'dancesstepsmap' VALUES (15425, 12975, 2);
INSERT INTO 'dancesstepsmap' VALUES (15426, 12975, 1);
INSERT INTO 'dancesstepsmap' VALUES (15427, 12976, 4);
INSERT INTO 'dancesstepsmap' VALUES (15428, 12976, 5);
INSERT INTO 'dancesstepsmap' VALUES (15429, 12980, 1);
INSERT INTO 'dancesstepsmap' VALUES (15430, 8815, 5);
INSERT INTO 'dancesstepsmap' VALUES (15431, 8815, 4);
INSERT INTO 'dancesstepsmap' VALUES (15432, 8818, 5);
INSERT INTO 'dancesstepsmap' VALUES (15433, 8818, 4);
INSERT INTO 'dancesstepsmap' VALUES (15434, 8820, 4);
INSERT INTO 'dancesstepsmap' VALUES (15435, 8819, 5);
INSERT INTO 'dancesstepsmap' VALUES (15436, 8819, 4);
INSERT INTO 'dancesstepsmap' VALUES (15437, 8821, 1);
INSERT INTO 'dancesstepsmap' VALUES (15438, 8821, 2);
INSERT INTO 'dancesstepsmap' VALUES (15439, 8822, 4);
INSERT INTO 'dancesstepsmap' VALUES (15440, 13105, 4);
INSERT INTO 'dancesstepsmap' VALUES (15441, 13106, 1);
INSERT INTO 'dancesstepsmap' VALUES (15442, 13107, 1);
INSERT INTO 'dancesstepsmap' VALUES (15443, 13108, 1);
INSERT INTO 'dancesstepsmap' VALUES (15444, 13108, 3);
INSERT INTO 'dancesstepsmap' VALUES (15445, 13109, 1);
INSERT INTO 'dancesstepsmap' VALUES (15446, 13110, 1);
INSERT INTO 'dancesstepsmap' VALUES (15447, 13110, 3);
INSERT INTO 'dancesstepsmap' VALUES (15448, 13111, 1);
INSERT INTO 'dancesstepsmap' VALUES (15449, 13111, 3);
INSERT INTO 'dancesstepsmap' VALUES (15450, 13112, 1);
INSERT INTO 'dancesstepsmap' VALUES (15451, 13112, 2);
INSERT INTO 'dancesstepsmap' VALUES (15452, 13112, 3);
INSERT INTO 'dancesstepsmap' VALUES (15453, 13113, 4);
INSERT INTO 'dancesstepsmap' VALUES (15454, 13113, 5);
INSERT INTO 'dancesstepsmap' VALUES (15455, 13114, 4);
INSERT INTO 'dancesstepsmap' VALUES (15456, 13114, 5);
INSERT INTO 'dancesstepsmap' VALUES (15457, 13115, 4);
INSERT INTO 'dancesstepsmap' VALUES (15458, 13116, 1);
INSERT INTO 'dancesstepsmap' VALUES (15459, 13116, 3);
INSERT INTO 'dancesstepsmap' VALUES (15460, 13117, 1);
INSERT INTO 'dancesstepsmap' VALUES (15461, 13118, 3);
INSERT INTO 'dancesstepsmap' VALUES (15462, 13118, 1);
INSERT INTO 'dancesstepsmap' VALUES (15463, 13119, 1);
INSERT INTO 'dancesstepsmap' VALUES (15464, 13119, 2);
INSERT INTO 'dancesstepsmap' VALUES (15465, 4073, 5);
INSERT INTO 'dancesstepsmap' VALUES (15466, 2415, 2);
INSERT INTO 'dancesstepsmap' VALUES (15467, 4407, 3);
INSERT INTO 'dancesstepsmap' VALUES (15468, 13127, 4);
INSERT INTO 'dancesstepsmap' VALUES (15469, 13127, 5);
INSERT INTO 'dancesstepsmap' VALUES (15470, 13128, 1);
INSERT INTO 'dancesstepsmap' VALUES (15471, 13128, 2);
INSERT INTO 'dancesstepsmap' VALUES (15472, 13128, 3);
INSERT INTO 'dancesstepsmap' VALUES (15473, 13140, 3);
INSERT INTO 'dancesstepsmap' VALUES (15474, 13140, 1);
INSERT INTO 'dancesstepsmap' VALUES (15475, 13141, 1);
INSERT INTO 'dancesstepsmap' VALUES (15476, 13142, 4);
INSERT INTO 'dancesstepsmap' VALUES (15477, 13142, 5);
INSERT INTO 'dancesstepsmap' VALUES (15478, 13143, 6);
INSERT INTO 'dancesstepsmap' VALUES (15479, 13143, 4);
INSERT INTO 'dancesstepsmap' VALUES (15480, 13143, 5);
INSERT INTO 'dancesstepsmap' VALUES (15481, 13144, 1);
INSERT INTO 'dancesstepsmap' VALUES (15482, 13145, 10);
INSERT INTO 'dancesstepsmap' VALUES (15483, 13145, 1);
INSERT INTO 'dancesstepsmap' VALUES (15484, 13145, 2);
INSERT INTO 'dancesstepsmap' VALUES (15485, 13146, 5);
INSERT INTO 'dancesstepsmap' VALUES (15486, 13146, 4);
INSERT INTO 'dancesstepsmap' VALUES (15487, 13147, 2);
INSERT INTO 'dancesstepsmap' VALUES (15488, 13147, 5);
INSERT INTO 'dancesstepsmap' VALUES (15489, 13147, 4);
INSERT INTO 'dancesstepsmap' VALUES (15490, 13147, 1);
INSERT INTO 'dancesstepsmap' VALUES (15491, 13147, 3);
INSERT INTO 'dancesstepsmap' VALUES (15492, 13148, 1);
INSERT INTO 'dancesstepsmap' VALUES (15493, 13148, 2);
INSERT INTO 'dancesstepsmap' VALUES (15494, 584, 2);
INSERT INTO 'dancesstepsmap' VALUES (15495, 12978, 1);
INSERT INTO 'dancesstepsmap' VALUES (15496, 12981, 1);
INSERT INTO 'dancesstepsmap' VALUES (15497, 818, 2);
INSERT INTO 'dancesstepsmap' VALUES (15498, 1416, 3);
INSERT INTO 'dancesstepsmap' VALUES (15499, 5488, 2);
INSERT INTO 'dancesstepsmap' VALUES (15500, 3648, 2);
INSERT INTO 'dancesstepsmap' VALUES (15501, 2181, 5);
INSERT INTO 'dancesstepsmap' VALUES (15502, 6330, 4);
INSERT INTO 'dancesstepsmap' VALUES (15503, 6330, 1);
INSERT INTO 'dancesstepsmap' VALUES (15504, 6330, 2);
INSERT INTO 'dancesstepsmap' VALUES (15505, 53, 5);
INSERT INTO 'dancesstepsmap' VALUES (15506, 511, 3);
INSERT INTO 'dancesstepsmap' VALUES (15508, 9195, 1);
INSERT INTO 'dancesstepsmap' VALUES (15509, 11303, 4);
INSERT INTO 'dancesstepsmap' VALUES (15510, 11303, 5);
INSERT INTO 'dancesstepsmap' VALUES (15511, 1472, 5);
INSERT INTO 'dancesstepsmap' VALUES (15512, 1642, 2);
INSERT INTO 'dancesstepsmap' VALUES (15513, 1642, 3);
INSERT INTO 'dancesstepsmap' VALUES (15514, 1879, 3);
INSERT INTO 'dancesstepsmap' VALUES (15515, 1879, 2);
INSERT INTO 'dancesstepsmap' VALUES (15516, 13149, 4);
INSERT INTO 'dancesstepsmap' VALUES (15517, 13150, 4);
INSERT INTO 'dancesstepsmap' VALUES (15518, 13151, 2);
INSERT INTO 'dancesstepsmap' VALUES (15519, 13151, 1);
INSERT INTO 'dancesstepsmap' VALUES (15520, 13152, 1);
INSERT INTO 'dancesstepsmap' VALUES (15521, 13153, 4);
INSERT INTO 'dancesstepsmap' VALUES (15522, 13154, 4);
INSERT INTO 'dancesstepsmap' VALUES (15523, 13155, 1);
INSERT INTO 'dancesstepsmap' VALUES (15524, 13156, 2);
INSERT INTO 'dancesstepsmap' VALUES (15525, 13156, 1);
INSERT INTO 'dancesstepsmap' VALUES (15526, 13157, 4);
INSERT INTO 'dancesstepsmap' VALUES (15527, 13157, 5);
INSERT INTO 'dancesstepsmap' VALUES (15528, 13158, 1);
INSERT INTO 'dancesstepsmap' VALUES (15532, 13160, 1);
INSERT INTO 'dancesstepsmap' VALUES (15533, 13160, 2);
INSERT INTO 'dancesstepsmap' VALUES (15534, 13161, 1);
INSERT INTO 'dancesstepsmap' VALUES (15535, 13162, 1);
INSERT INTO 'dancesstepsmap' VALUES (15536, 13162, 3);
INSERT INTO 'dancesstepsmap' VALUES (15537, 13164, 1);
INSERT INTO 'dancesstepsmap' VALUES (15538, 13165, 1);
INSERT INTO 'dancesstepsmap' VALUES (15539, 13166, 4);
INSERT INTO 'dancesstepsmap' VALUES (15540, 13166, 5);
INSERT INTO 'dancesstepsmap' VALUES (15541, 13167, 1);
INSERT INTO 'dancesstepsmap' VALUES (15542, 13167, 2);
INSERT INTO 'dancesstepsmap' VALUES (15543, 13168, 5);
INSERT INTO 'dancesstepsmap' VALUES (15544, 13168, 4);
INSERT INTO 'dancesstepsmap' VALUES (15545, 13169, 1);
INSERT INTO 'dancesstepsmap' VALUES (15546, 13170, 4);
INSERT INTO 'dancesstepsmap' VALUES (15547, 13171, 1);
INSERT INTO 'dancesstepsmap' VALUES (15548, 13172, 4);
INSERT INTO 'dancesstepsmap' VALUES (15551, 13174, 1);
INSERT INTO 'dancesstepsmap' VALUES (15552, 13175, 1);
INSERT INTO 'dancesstepsmap' VALUES (15553, 13175, 3);
INSERT INTO 'dancesstepsmap' VALUES (15554, 13176, 1);
INSERT INTO 'dancesstepsmap' VALUES (15555, 13176, 3);
INSERT INTO 'dancesstepsmap' VALUES (15556, 13177, 1);
INSERT INTO 'dancesstepsmap' VALUES (15557, 13178, 1);
INSERT INTO 'dancesstepsmap' VALUES (15558, 13179, 1);
INSERT INTO 'dancesstepsmap' VALUES (15559, 13180, 3);
INSERT INTO 'dancesstepsmap' VALUES (15560, 13180, 1);
INSERT INTO 'dancesstepsmap' VALUES (15561, 13181, 1);
INSERT INTO 'dancesstepsmap' VALUES (15562, 13182, 4);
INSERT INTO 'dancesstepsmap' VALUES (15563, 13182, 5);
INSERT INTO 'dancesstepsmap' VALUES (15564, 13183, 4);
INSERT INTO 'dancesstepsmap' VALUES (15565, 13184, 1);
INSERT INTO 'dancesstepsmap' VALUES (15566, 13184, 2);
INSERT INTO 'dancesstepsmap' VALUES (15567, 13185, 1);
INSERT INTO 'dancesstepsmap' VALUES (15568, 13186, 4);
INSERT INTO 'dancesstepsmap' VALUES (15569, 13187, 4);
INSERT INTO 'dancesstepsmap' VALUES (15570, 13188, 1);
INSERT INTO 'dancesstepsmap' VALUES (15571, 13188, 2);
INSERT INTO 'dancesstepsmap' VALUES (15572, 13189, 4);
INSERT INTO 'dancesstepsmap' VALUES (15573, 13190, 1);
INSERT INTO 'dancesstepsmap' VALUES (15574, 13191, 1);
INSERT INTO 'dancesstepsmap' VALUES (15575, 13191, 2);
INSERT INTO 'dancesstepsmap' VALUES (15576, 13192, 1);
INSERT INTO 'dancesstepsmap' VALUES (15577, 13193, 4);
INSERT INTO 'dancesstepsmap' VALUES (15578, 13193, 5);
INSERT INTO 'dancesstepsmap' VALUES (15579, 13194, 1);
INSERT INTO 'dancesstepsmap' VALUES (15580, 13195, 1);
INSERT INTO 'dancesstepsmap' VALUES (15581, 13196, 1);
INSERT INTO 'dancesstepsmap' VALUES (15582, 13197, 4);
INSERT INTO 'dancesstepsmap' VALUES (15583, 13198, 2);
INSERT INTO 'dancesstepsmap' VALUES (15584, 13198, 1);
INSERT INTO 'dancesstepsmap' VALUES (15585, 13199, 1);
INSERT INTO 'dancesstepsmap' VALUES (15586, 13200, 1);
INSERT INTO 'dancesstepsmap' VALUES (15587, 13200, 2);
INSERT INTO 'dancesstepsmap' VALUES (15588, 13201, 4);
INSERT INTO 'dancesstepsmap' VALUES (15589, 13201, 5);
INSERT INTO 'dancesstepsmap' VALUES (15590, 13202, 5);
INSERT INTO 'dancesstepsmap' VALUES (15591, 13202, 4);
INSERT INTO 'dancesstepsmap' VALUES (15592, 13203, 1);
INSERT INTO 'dancesstepsmap' VALUES (15593, 13204, 1);
INSERT INTO 'dancesstepsmap' VALUES (15594, 13206, 1);
INSERT INTO 'dancesstepsmap' VALUES (15595, 3604, 2);
INSERT INTO 'dancesstepsmap' VALUES (15596, 4061, 2);
INSERT INTO 'dancesstepsmap' VALUES (15597, 13207, 4);
INSERT INTO 'dancesstepsmap' VALUES (15598, 13208, 5);
INSERT INTO 'dancesstepsmap' VALUES (15599, 13208, 4);
INSERT INTO 'dancesstepsmap' VALUES (15600, 4233, 2);
INSERT INTO 'dancesstepsmap' VALUES (15601, 7119, 2);
INSERT INTO 'dancesstepsmap' VALUES (15602, 7119, 3);
INSERT INTO 'dancesstepsmap' VALUES (15603, 13209, 4);
INSERT INTO 'dancesstepsmap' VALUES (15604, 13210, 1);
INSERT INTO 'dancesstepsmap' VALUES (15605, 13210, 2);
INSERT INTO 'dancesstepsmap' VALUES (15606, 13210, 3);
INSERT INTO 'dancesstepsmap' VALUES (15607, 13211, 5);
INSERT INTO 'dancesstepsmap' VALUES (15608, 13211, 4);
INSERT INTO 'dancesstepsmap' VALUES (15609, 13214, 1);
INSERT INTO 'dancesstepsmap' VALUES (15610, 13219, 4);
INSERT INTO 'dancesstepsmap' VALUES (15611, 13220, 5);
INSERT INTO 'dancesstepsmap' VALUES (15612, 13220, 4);
INSERT INTO 'dancesstepsmap' VALUES (15613, 13221, 1);
INSERT INTO 'dancesstepsmap' VALUES (15614, 13221, 3);
INSERT INTO 'dancesstepsmap' VALUES (15615, 13222, 1);
INSERT INTO 'dancesstepsmap' VALUES (15616, 13222, 2);
INSERT INTO 'dancesstepsmap' VALUES (15617, 13223, 1);
INSERT INTO 'dancesstepsmap' VALUES (15618, 13224, 3);
INSERT INTO 'dancesstepsmap' VALUES (15619, 13224, 1);
INSERT INTO 'dancesstepsmap' VALUES (15620, 13225, 1);
INSERT INTO 'dancesstepsmap' VALUES (15623, 13227, 4);
INSERT INTO 'dancesstepsmap' VALUES (15624, 9941, 4);
INSERT INTO 'dancesstepsmap' VALUES (15625, 13228, 2);
INSERT INTO 'dancesstepsmap' VALUES (15626, 13228, 1);
INSERT INTO 'dancesstepsmap' VALUES (15627, 3110, 2);
INSERT INTO 'dancesstepsmap' VALUES (15628, 13034, 4);
INSERT INTO 'dancesstepsmap' VALUES (15629, 13034, 5);
INSERT INTO 'dancesstepsmap' VALUES (15630, 13042, 1);
INSERT INTO 'dancesstepsmap' VALUES (15631, 13042, 3);
INSERT INTO 'dancesstepsmap' VALUES (15632, 13043, 1);
INSERT INTO 'dancesstepsmap' VALUES (15633, 13043, 2);
INSERT INTO 'dancesstepsmap' VALUES (15634, 13043, 3);
INSERT INTO 'dancesstepsmap' VALUES (15635, 13044, 4);
INSERT INTO 'dancesstepsmap' VALUES (15636, 9976, 5);
INSERT INTO 'dancesstepsmap' VALUES (15637, 9976, 4);
INSERT INTO 'dancesstepsmap' VALUES (15638, 10584, 1);
INSERT INTO 'dancesstepsmap' VALUES (15639, 13045, 4);
INSERT INTO 'dancesstepsmap' VALUES (15640, 13035, 1);
INSERT INTO 'dancesstepsmap' VALUES (15641, 13036, 4);
INSERT INTO 'dancesstepsmap' VALUES (15642, 13037, 2);
INSERT INTO 'dancesstepsmap' VALUES (15643, 13037, 3);
INSERT INTO 'dancesstepsmap' VALUES (15644, 13037, 1);
INSERT INTO 'dancesstepsmap' VALUES (15645, 13007, 1);
INSERT INTO 'dancesstepsmap' VALUES (15646, 13038, 1);
INSERT INTO 'dancesstepsmap' VALUES (15647, 13040, 2);
INSERT INTO 'dancesstepsmap' VALUES (15648, 13041, 4);
INSERT INTO 'dancesstepsmap' VALUES (15649, 13230, 1);
INSERT INTO 'dancesstepsmap' VALUES (15650, 13230, 2);
INSERT INTO 'dancesstepsmap' VALUES (15651, 13230, 3);
INSERT INTO 'dancesstepsmap' VALUES (15652, 13231, 5);
INSERT INTO 'dancesstepsmap' VALUES (15653, 13231, 4);
INSERT INTO 'dancesstepsmap' VALUES (15654, 13232, 3);
INSERT INTO 'dancesstepsmap' VALUES (15655, 13232, 1);
INSERT INTO 'dancesstepsmap' VALUES (15656, 9420, 4);
INSERT INTO 'dancesstepsmap' VALUES (15657, 3230, 2);
INSERT INTO 'dancesstepsmap' VALUES (15658, 3230, 3);
INSERT INTO 'dancesstepsmap' VALUES (15659, 13233, 1);
INSERT INTO 'dancesstepsmap' VALUES (15660, 13233, 3);
INSERT INTO 'dancesstepsmap' VALUES (15661, 8701, 10);
INSERT INTO 'dancesstepsmap' VALUES (15662, 13244, 3);
INSERT INTO 'dancesstepsmap' VALUES (15663, 13244, 2);
INSERT INTO 'dancesstepsmap' VALUES (15664, 13245, 1);
INSERT INTO 'dancesstepsmap' VALUES (15665, 13246, 1);
INSERT INTO 'dancesstepsmap' VALUES (15666, 13247, 1);
INSERT INTO 'dancesstepsmap' VALUES (15667, 13247, 2);
INSERT INTO 'dancesstepsmap' VALUES (15668, 13247, 3);
INSERT INTO 'dancesstepsmap' VALUES (15669, 13249, 3);
INSERT INTO 'dancesstepsmap' VALUES (15670, 7887, 2);
INSERT INTO 'dancesstepsmap' VALUES (15671, 7982, 5);
INSERT INTO 'dancesstepsmap' VALUES (15672, 7813, 5);
INSERT INTO 'dancesstepsmap' VALUES (15549, 13173, 4);
INSERT INTO 'dancesstepsmap' VALUES (15550, 13173, 5);
INSERT INTO 'dancesstepsmap' VALUES (15673, 7920, 2);
INSERT INTO 'dancesstepsmap' VALUES (15674, 7673, 2);
INSERT INTO 'dancesstepsmap' VALUES (15675, 7806, 5);
INSERT INTO 'dancesstepsmap' VALUES (15676, 7832, 2);
INSERT INTO 'dancesstepsmap' VALUES (15677, 7706, 2);
INSERT INTO 'dancesstepsmap' VALUES (15678, 7706, 3);
INSERT INTO 'dancesstepsmap' VALUES (15679, 13027, 1);
INSERT INTO 'dancesstepsmap' VALUES (15680, 13023, 1);
INSERT INTO 'dancesstepsmap' VALUES (15681, 13023, 3);
INSERT INTO 'dancesstepsmap' VALUES (15682, 13026, 2);
INSERT INTO 'dancesstepsmap' VALUES (15683, 13026, 1);
INSERT INTO 'dancesstepsmap' VALUES (15684, 13024, 2);
INSERT INTO 'dancesstepsmap' VALUES (15685, 13024, 1);
INSERT INTO 'dancesstepsmap' VALUES (15686, 13025, 2);
INSERT INTO 'dancesstepsmap' VALUES (15687, 13025, 4);
INSERT INTO 'dancesstepsmap' VALUES (15688, 13025, 1);
INSERT INTO 'dancesstepsmap' VALUES (15689, 13025, 5);
INSERT INTO 'dancesstepsmap' VALUES (15690, 13008, 1);
INSERT INTO 'dancesstepsmap' VALUES (15691, 13250, 1);
INSERT INTO 'dancesstepsmap' VALUES (15692, 13251, 1);
INSERT INTO 'dancesstepsmap' VALUES (15693, 13252, 1);
INSERT INTO 'dancesstepsmap' VALUES (15694, 13252, 3);
INSERT INTO 'dancesstepsmap' VALUES (15695, 13253, 4);
INSERT INTO 'dancesstepsmap' VALUES (15696, 13254, 4);
INSERT INTO 'dancesstepsmap' VALUES (15697, 13255, 4);
INSERT INTO 'dancesstepsmap' VALUES (15698, 13256, 4);
INSERT INTO 'dancesstepsmap' VALUES (15699, 13257, 4);
INSERT INTO 'dancesstepsmap' VALUES (15700, 13258, 4);
INSERT INTO 'dancesstepsmap' VALUES (15701, 13258, 5);
INSERT INTO 'dancesstepsmap' VALUES (15702, 13259, 1);
INSERT INTO 'dancesstepsmap' VALUES (15703, 13269, 3);
INSERT INTO 'dancesstepsmap' VALUES (15704, 13269, 1);
INSERT INTO 'dancesstepsmap' VALUES (15705, 10611, 4);
INSERT INTO 'dancesstepsmap' VALUES (15706, 10611, 5);
INSERT INTO 'dancesstepsmap' VALUES (15707, 10612, 2);
INSERT INTO 'dancesstepsmap' VALUES (15708, 10613, 2);
INSERT INTO 'dancesstepsmap' VALUES (15709, 10613, 1);
INSERT INTO 'dancesstepsmap' VALUES (15710, 10613, 4);
INSERT INTO 'dancesstepsmap' VALUES (15711, 10613, 5);
INSERT INTO 'dancesstepsmap' VALUES (15712, 10613, 3);
INSERT INTO 'dancesstepsmap' VALUES (15713, 10614, 4);
INSERT INTO 'dancesstepsmap' VALUES (15714, 10990, 10);
INSERT INTO 'dancesstepsmap' VALUES (15715, 10990, 1);
INSERT INTO 'dancesstepsmap' VALUES (15716, 10991, 2);
INSERT INTO 'dancesstepsmap' VALUES (15717, 10991, 1);
INSERT INTO 'dancesstepsmap' VALUES (15718, 10992, 3);
INSERT INTO 'dancesstepsmap' VALUES (15719, 10992, 1);
INSERT INTO 'dancesstepsmap' VALUES (15720, 10992, 2);
INSERT INTO 'dancesstepsmap' VALUES (15721, 10993, 4);
INSERT INTO 'dancesstepsmap' VALUES (15722, 13270, 1);
INSERT INTO 'dancesstepsmap' VALUES (15723, 13272, 2);
INSERT INTO 'dancesstepsmap' VALUES (15724, 13272, 1);
INSERT INTO 'dancesstepsmap' VALUES (15725, 13273, 1);
INSERT INTO 'dancesstepsmap' VALUES (15726, 13274, 1);
INSERT INTO 'dancesstepsmap' VALUES (15727, 13274, 3);
INSERT INTO 'dancesstepsmap' VALUES (15728, 13275, 1);
INSERT INTO 'dancesstepsmap' VALUES (15729, 127, 4);
INSERT INTO 'dancesstepsmap' VALUES (15730, 127, 5);
INSERT INTO 'dancesstepsmap' VALUES (15731, 10366, 1);
INSERT INTO 'dancesstepsmap' VALUES (15732, 10366, 2);
INSERT INTO 'dancesstepsmap' VALUES (15733, 10366, 4);
INSERT INTO 'dancesstepsmap' VALUES (15734, 10366, 5);
INSERT INTO 'dancesstepsmap' VALUES (15735, 11807, 1);
INSERT INTO 'dancesstepsmap' VALUES (15736, 13218, 4);
INSERT INTO 'dancesstepsmap' VALUES (15737, 13276, 4);
INSERT INTO 'dancesstepsmap' VALUES (15738, 13277, 5);
INSERT INTO 'dancesstepsmap' VALUES (15739, 13277, 4);
INSERT INTO 'dancesstepsmap' VALUES (15740, 13278, 1);
INSERT INTO 'dancesstepsmap' VALUES (15741, 13278, 2);
INSERT INTO 'dancesstepsmap' VALUES (15742, 13279, 5);
INSERT INTO 'dancesstepsmap' VALUES (15743, 13279, 4);
INSERT INTO 'dancesstepsmap' VALUES (15744, 13279, 6);
INSERT INTO 'dancesstepsmap' VALUES (15745, 13280, 2);
INSERT INTO 'dancesstepsmap' VALUES (15746, 13281, 1);
INSERT INTO 'dancesstepsmap' VALUES (15747, 13282, 4);
INSERT INTO 'dancesstepsmap' VALUES (15748, 13282, 5);
INSERT INTO 'dancesstepsmap' VALUES (15749, 13283, 1);
INSERT INTO 'dancesstepsmap' VALUES (15750, 13299, 4);
INSERT INTO 'dancesstepsmap' VALUES (15751, 13299, 5);
INSERT INTO 'dancesstepsmap' VALUES (15752, 2565, 5);
INSERT INTO 'dancesstepsmap' VALUES (15753, 8841, 4);
INSERT INTO 'dancesstepsmap' VALUES (23173, 18256, 5);
INSERT INTO 'dancesstepsmap' VALUES (15755, 5273, 5);
INSERT INTO 'dancesstepsmap' VALUES (15756, 5606, 6);
INSERT INTO 'dancesstepsmap' VALUES (15757, 5606, 5);
INSERT INTO 'dancesstepsmap' VALUES (15758, 7122, 4);
INSERT INTO 'dancesstepsmap' VALUES (15759, 13300, 1);
INSERT INTO 'dancesstepsmap' VALUES (15760, 13301, 4);
INSERT INTO 'dancesstepsmap' VALUES (15761, 13302, 2);
INSERT INTO 'dancesstepsmap' VALUES (15762, 13302, 1);
INSERT INTO 'dancesstepsmap' VALUES (15763, 13302, 3);
INSERT INTO 'dancesstepsmap' VALUES (15764, 13303, 1);
INSERT INTO 'dancesstepsmap' VALUES (15765, 13303, 2);
INSERT INTO 'dancesstepsmap' VALUES (15766, 13304, 2);
INSERT INTO 'dancesstepsmap' VALUES (15767, 13304, 1);
INSERT INTO 'dancesstepsmap' VALUES (15768, 13305, 4);
INSERT INTO 'dancesstepsmap' VALUES (15769, 13305, 5);
INSERT INTO 'dancesstepsmap' VALUES (15770, 13306, 4);
INSERT INTO 'dancesstepsmap' VALUES (15771, 13306, 5);
INSERT INTO 'dancesstepsmap' VALUES (15772, 13307, 4);
INSERT INTO 'dancesstepsmap' VALUES (15773, 13307, 5);
INSERT INTO 'dancesstepsmap' VALUES (15774, 13308, 1);
INSERT INTO 'dancesstepsmap' VALUES (15775, 13308, 3);
INSERT INTO 'dancesstepsmap' VALUES (15776, 13309, 4);
INSERT INTO 'dancesstepsmap' VALUES (15777, 13310, 1);
INSERT INTO 'dancesstepsmap' VALUES (15778, 13311, 1);
INSERT INTO 'dancesstepsmap' VALUES (15779, 13312, 4);
INSERT INTO 'dancesstepsmap' VALUES (15780, 13312, 5);
INSERT INTO 'dancesstepsmap' VALUES (15781, 13313, 1);
INSERT INTO 'dancesstepsmap' VALUES (15782, 13313, 2);
INSERT INTO 'dancesstepsmap' VALUES (15783, 13314, 4);
INSERT INTO 'dancesstepsmap' VALUES (15784, 13315, 1);
INSERT INTO 'dancesstepsmap' VALUES (15785, 13316, 5);
INSERT INTO 'dancesstepsmap' VALUES (15786, 13316, 6);
INSERT INTO 'dancesstepsmap' VALUES (15787, 13316, 4);
INSERT INTO 'dancesstepsmap' VALUES (15788, 13316, 1);
INSERT INTO 'dancesstepsmap' VALUES (15789, 13317, 3);
INSERT INTO 'dancesstepsmap' VALUES (15790, 13317, 1);
INSERT INTO 'dancesstepsmap' VALUES (15791, 13318, 1);
INSERT INTO 'dancesstepsmap' VALUES (15792, 13319, 1);
INSERT INTO 'dancesstepsmap' VALUES (15793, 13319, 2);
INSERT INTO 'dancesstepsmap' VALUES (15794, 13320, 2);
INSERT INTO 'dancesstepsmap' VALUES (15795, 13320, 1);
INSERT INTO 'dancesstepsmap' VALUES (15796, 13321, 1);
INSERT INTO 'dancesstepsmap' VALUES (15797, 13322, 4);
INSERT INTO 'dancesstepsmap' VALUES (15798, 13322, 5);
INSERT INTO 'dancesstepsmap' VALUES (15799, 13323, 4);
INSERT INTO 'dancesstepsmap' VALUES (15800, 13323, 5);
INSERT INTO 'dancesstepsmap' VALUES (15801, 13324, 4);
INSERT INTO 'dancesstepsmap' VALUES (15802, 13325, 2);
INSERT INTO 'dancesstepsmap' VALUES (15803, 13325, 1);
INSERT INTO 'dancesstepsmap' VALUES (15804, 13326, 4);
INSERT INTO 'dancesstepsmap' VALUES (15805, 13326, 5);
INSERT INTO 'dancesstepsmap' VALUES (15806, 13327, 1);
INSERT INTO 'dancesstepsmap' VALUES (15807, 941, 3);
INSERT INTO 'dancesstepsmap' VALUES (15808, 5836, 3);
INSERT INTO 'dancesstepsmap' VALUES (15809, 13333, 3);
INSERT INTO 'dancesstepsmap' VALUES (15810, 13333, 1);
INSERT INTO 'dancesstepsmap' VALUES (15811, 13333, 2);
INSERT INTO 'dancesstepsmap' VALUES (15812, 13334, 4);
INSERT INTO 'dancesstepsmap' VALUES (15813, 13335, 2);
INSERT INTO 'dancesstepsmap' VALUES (15814, 13335, 1);
INSERT INTO 'dancesstepsmap' VALUES (15815, 9752, 2);
INSERT INTO 'dancesstepsmap' VALUES (15816, 9745, 3);
INSERT INTO 'dancesstepsmap' VALUES (15817, 13336, 1);
INSERT INTO 'dancesstepsmap' VALUES (15818, 13336, 2);
INSERT INTO 'dancesstepsmap' VALUES (15819, 13336, 3);
INSERT INTO 'dancesstepsmap' VALUES (15820, 13337, 3);
INSERT INTO 'dancesstepsmap' VALUES (15821, 13337, 1);
INSERT INTO 'dancesstepsmap' VALUES (15822, 13337, 2);
INSERT INTO 'dancesstepsmap' VALUES (15823, 13339, 3);
INSERT INTO 'dancesstepsmap' VALUES (15824, 13340, 4);
INSERT INTO 'dancesstepsmap' VALUES (15825, 13341, 4);
INSERT INTO 'dancesstepsmap' VALUES (15826, 13342, 4);
INSERT INTO 'dancesstepsmap' VALUES (15827, 13343, 1);
INSERT INTO 'dancesstepsmap' VALUES (15828, 13344, 1);
INSERT INTO 'dancesstepsmap' VALUES (15829, 13344, 2);
INSERT INTO 'dancesstepsmap' VALUES (15830, 13345, 1);
INSERT INTO 'dancesstepsmap' VALUES (15831, 13346, 2);
INSERT INTO 'dancesstepsmap' VALUES (15832, 13347, 4);
INSERT INTO 'dancesstepsmap' VALUES (15834, 13349, 4);
INSERT INTO 'dancesstepsmap' VALUES (15835, 13350, 2);
INSERT INTO 'dancesstepsmap' VALUES (15836, 13351, 3);
INSERT INTO 'dancesstepsmap' VALUES (15837, 13352, 5);
INSERT INTO 'dancesstepsmap' VALUES (15838, 13352, 4);
INSERT INTO 'dancesstepsmap' VALUES (15839, 13352, 1);
INSERT INTO 'dancesstepsmap' VALUES (15840, 13353, 5);
INSERT INTO 'dancesstepsmap' VALUES (15841, 13353, 4);
INSERT INTO 'dancesstepsmap' VALUES (15842, 13354, 4);
INSERT INTO 'dancesstepsmap' VALUES (15843, 13354, 5);
INSERT INTO 'dancesstepsmap' VALUES (15844, 3878, 1);
INSERT INTO 'dancesstepsmap' VALUES (15845, 3878, 3);
INSERT INTO 'dancesstepsmap' VALUES (15846, 13373, 1);
INSERT INTO 'dancesstepsmap' VALUES (15847, 13373, 2);
INSERT INTO 'dancesstepsmap' VALUES (15848, 13449, 4);
INSERT INTO 'dancesstepsmap' VALUES (15849, 13449, 5);
INSERT INTO 'dancesstepsmap' VALUES (23174, 18256, 4);
INSERT INTO 'dancesstepsmap' VALUES (23226, 12183, 1);
INSERT INTO 'dancesstepsmap' VALUES (23227, 12183, 2);
INSERT INTO 'dancesstepsmap' VALUES (15853, 13544, 1);
INSERT INTO 'dancesstepsmap' VALUES (15854, 13544, 2);
INSERT INTO 'dancesstepsmap' VALUES (15855, 13547, 5);
INSERT INTO 'dancesstepsmap' VALUES (15856, 13547, 4);
INSERT INTO 'dancesstepsmap' VALUES (15857, 13547, 2);
INSERT INTO 'dancesstepsmap' VALUES (15858, 13547, 1);
INSERT INTO 'dancesstepsmap' VALUES (15859, 13547, 3);
INSERT INTO 'dancesstepsmap' VALUES (15860, 13575, 2);
INSERT INTO 'dancesstepsmap' VALUES (15861, 13575, 1);
INSERT INTO 'dancesstepsmap' VALUES (15862, 13575, 3);
INSERT INTO 'dancesstepsmap' VALUES (15863, 13576, 4);
INSERT INTO 'dancesstepsmap' VALUES (15864, 13576, 5);
INSERT INTO 'dancesstepsmap' VALUES (15865, 13577, 2);
INSERT INTO 'dancesstepsmap' VALUES (15866, 13577, 1);
INSERT INTO 'dancesstepsmap' VALUES (15867, 13578, 1);
INSERT INTO 'dancesstepsmap' VALUES (15868, 13578, 3);
INSERT INTO 'dancesstepsmap' VALUES (15869, 13602, 4);
INSERT INTO 'dancesstepsmap' VALUES (15870, 13598, 1);
INSERT INTO 'dancesstepsmap' VALUES (15871, 13600, 1);
INSERT INTO 'dancesstepsmap' VALUES (15872, 13600, 2);
INSERT INTO 'dancesstepsmap' VALUES (15873, 13611, 1);
INSERT INTO 'dancesstepsmap' VALUES (15874, 13611, 2);
INSERT INTO 'dancesstepsmap' VALUES (15875, 13597, 4);
INSERT INTO 'dancesstepsmap' VALUES (15876, 13597, 5);
INSERT INTO 'dancesstepsmap' VALUES (15877, 13603, 1);
INSERT INTO 'dancesstepsmap' VALUES (15878, 13603, 2);
INSERT INTO 'dancesstepsmap' VALUES (15879, 13610, 1);
INSERT INTO 'dancesstepsmap' VALUES (15880, 13605, 4);
INSERT INTO 'dancesstepsmap' VALUES (15881, 13601, 1);
INSERT INTO 'dancesstepsmap' VALUES (15882, 13601, 2);
INSERT INTO 'dancesstepsmap' VALUES (15883, 13612, 1);
INSERT INTO 'dancesstepsmap' VALUES (15884, 13612, 2);
INSERT INTO 'dancesstepsmap' VALUES (15885, 13608, 4);
INSERT INTO 'dancesstepsmap' VALUES (15886, 13608, 5);
INSERT INTO 'dancesstepsmap' VALUES (15887, 13599, 4);
INSERT INTO 'dancesstepsmap' VALUES (15888, 13599, 5);
INSERT INTO 'dancesstepsmap' VALUES (15889, 13606, 1);
INSERT INTO 'dancesstepsmap' VALUES (15890, 13606, 2);
INSERT INTO 'dancesstepsmap' VALUES (15891, 13609, 1);
INSERT INTO 'dancesstepsmap' VALUES (15892, 13609, 2);
INSERT INTO 'dancesstepsmap' VALUES (15893, 13604, 4);
INSERT INTO 'dancesstepsmap' VALUES (15894, 13604, 5);
INSERT INTO 'dancesstepsmap' VALUES (15895, 13617, 1);
INSERT INTO 'dancesstepsmap' VALUES (15896, 13617, 3);
INSERT INTO 'dancesstepsmap' VALUES (15897, 13618, 1);
INSERT INTO 'dancesstepsmap' VALUES (15898, 13618, 3);
INSERT INTO 'dancesstepsmap' VALUES (15899, 13619, 1);
INSERT INTO 'dancesstepsmap' VALUES (15900, 13620, 2);
INSERT INTO 'dancesstepsmap' VALUES (15901, 13620, 1);
INSERT INTO 'dancesstepsmap' VALUES (15902, 13621, 1);
INSERT INTO 'dancesstepsmap' VALUES (15903, 13621, 3);
INSERT INTO 'dancesstepsmap' VALUES (15904, 6037, 10);
INSERT INTO 'dancesstepsmap' VALUES (15905, 13626, 1);
INSERT INTO 'dancesstepsmap' VALUES (15906, 13626, 2);
INSERT INTO 'dancesstepsmap' VALUES (15907, 13627, 4);
INSERT INTO 'dancesstepsmap' VALUES (15908, 13628, 4);
INSERT INTO 'dancesstepsmap' VALUES (15909, 13628, 5);
INSERT INTO 'dancesstepsmap' VALUES (15910, 13628, 1);
INSERT INTO 'dancesstepsmap' VALUES (15911, 13628, 2);
INSERT INTO 'dancesstepsmap' VALUES (15912, 13628, 3);
INSERT INTO 'dancesstepsmap' VALUES (15913, 13628, 6);
INSERT INTO 'dancesstepsmap' VALUES (15914, 13628, 10);
INSERT INTO 'dancesstepsmap' VALUES (15915, 13631, 4);
INSERT INTO 'dancesstepsmap' VALUES (15916, 13631, 1);
INSERT INTO 'dancesstepsmap' VALUES (15917, 13631, 2);
INSERT INTO 'dancesstepsmap' VALUES (15918, 13643, 2);
INSERT INTO 'dancesstepsmap' VALUES (15919, 13643, 1);
INSERT INTO 'dancesstepsmap' VALUES (15920, 13640, 4);
INSERT INTO 'dancesstepsmap' VALUES (15921, 13640, 1);
INSERT INTO 'dancesstepsmap' VALUES (15922, 13644, 1);
INSERT INTO 'dancesstepsmap' VALUES (15923, 13644, 2);
INSERT INTO 'dancesstepsmap' VALUES (15924, 13645, 1);
INSERT INTO 'dancesstepsmap' VALUES (15925, 13645, 2);
INSERT INTO 'dancesstepsmap' VALUES (15926, 619, 2);
INSERT INTO 'dancesstepsmap' VALUES (15927, 619, 3);
INSERT INTO 'dancesstepsmap' VALUES (15928, 5794, 2);
INSERT INTO 'dancesstepsmap' VALUES (15929, 8887, 1);
INSERT INTO 'dancesstepsmap' VALUES (15932, 13647, 5);
INSERT INTO 'dancesstepsmap' VALUES (15933, 13647, 4);
INSERT INTO 'dancesstepsmap' VALUES (15934, 13450, 5);
INSERT INTO 'dancesstepsmap' VALUES (15935, 13450, 4);
INSERT INTO 'dancesstepsmap' VALUES (15936, 13648, 5);
INSERT INTO 'dancesstepsmap' VALUES (15937, 13648, 4);
INSERT INTO 'dancesstepsmap' VALUES (15938, 13649, 1);
INSERT INTO 'dancesstepsmap' VALUES (15939, 13649, 2);
INSERT INTO 'dancesstepsmap' VALUES (15940, 5891, 5);
INSERT INTO 'dancesstepsmap' VALUES (15941, 13587, 1);
INSERT INTO 'dancesstepsmap' VALUES (15942, 13587, 2);
INSERT INTO 'dancesstepsmap' VALUES (15943, 13650, 2);
INSERT INTO 'dancesstepsmap' VALUES (15944, 13650, 1);
INSERT INTO 'dancesstepsmap' VALUES (15945, 13650, 3);
INSERT INTO 'dancesstepsmap' VALUES (15946, 8991, 1);
INSERT INTO 'dancesstepsmap' VALUES (15947, 13651, 2);
INSERT INTO 'dancesstepsmap' VALUES (15948, 13651, 1);
INSERT INTO 'dancesstepsmap' VALUES (15949, 13651, 3);
INSERT INTO 'dancesstepsmap' VALUES (15950, 13652, 5);
INSERT INTO 'dancesstepsmap' VALUES (15951, 13652, 4);
INSERT INTO 'dancesstepsmap' VALUES (15952, 13653, 5);
INSERT INTO 'dancesstepsmap' VALUES (15953, 13653, 4);
INSERT INTO 'dancesstepsmap' VALUES (15954, 13654, 4);
INSERT INTO 'dancesstepsmap' VALUES (15955, 13655, 1);
INSERT INTO 'dancesstepsmap' VALUES (15956, 13655, 3);
INSERT INTO 'dancesstepsmap' VALUES (15959, 13657, 5);
INSERT INTO 'dancesstepsmap' VALUES (15960, 13657, 4);
INSERT INTO 'dancesstepsmap' VALUES (15961, 13658, 1);
INSERT INTO 'dancesstepsmap' VALUES (15962, 13659, 1);
INSERT INTO 'dancesstepsmap' VALUES (15963, 13659, 2);
INSERT INTO 'dancesstepsmap' VALUES (15964, 13660, 5);
INSERT INTO 'dancesstepsmap' VALUES (15965, 13660, 4);
INSERT INTO 'dancesstepsmap' VALUES (15966, 13661, 1);
INSERT INTO 'dancesstepsmap' VALUES (15967, 8985, 5);
INSERT INTO 'dancesstepsmap' VALUES (15968, 8985, 4);
INSERT INTO 'dancesstepsmap' VALUES (15969, 13662, 1);
INSERT INTO 'dancesstepsmap' VALUES (15970, 13663, 1);
INSERT INTO 'dancesstepsmap' VALUES (15971, 13663, 3);
INSERT INTO 'dancesstepsmap' VALUES (15972, 13664, 1);
INSERT INTO 'dancesstepsmap' VALUES (15973, 13664, 3);
INSERT INTO 'dancesstepsmap' VALUES (15974, 13664, 2);
INSERT INTO 'dancesstepsmap' VALUES (15975, 13665, 1);
INSERT INTO 'dancesstepsmap' VALUES (15976, 13666, 4);
INSERT INTO 'dancesstepsmap' VALUES (15977, 13667, 1);
INSERT INTO 'dancesstepsmap' VALUES (15978, 13668, 5);
INSERT INTO 'dancesstepsmap' VALUES (15979, 13668, 4);
INSERT INTO 'dancesstepsmap' VALUES (15980, 13669, 5);
INSERT INTO 'dancesstepsmap' VALUES (15981, 13669, 4);
INSERT INTO 'dancesstepsmap' VALUES (15982, 13670, 4);
INSERT INTO 'dancesstepsmap' VALUES (15983, 13670, 5);
INSERT INTO 'dancesstepsmap' VALUES (15984, 13671, 1);
INSERT INTO 'dancesstepsmap' VALUES (15985, 13671, 2);
INSERT INTO 'dancesstepsmap' VALUES (15986, 13672, 1);
INSERT INTO 'dancesstepsmap' VALUES (15987, 13672, 3);
INSERT INTO 'dancesstepsmap' VALUES (15988, 13673, 1);
INSERT INTO 'dancesstepsmap' VALUES (15989, 13673, 3);
INSERT INTO 'dancesstepsmap' VALUES (15990, 13674, 2);
INSERT INTO 'dancesstepsmap' VALUES (15991, 13674, 1);
INSERT INTO 'dancesstepsmap' VALUES (23175, 18257, 1);
INSERT INTO 'dancesstepsmap' VALUES (23176, 18257, 8);
INSERT INTO 'dancesstepsmap' VALUES (23177, 18258, 4);
INSERT INTO 'dancesstepsmap' VALUES (15995, 13676, 4);
INSERT INTO 'dancesstepsmap' VALUES (15996, 13676, 5);
INSERT INTO 'dancesstepsmap' VALUES (15997, 13448, 1);
INSERT INTO 'dancesstepsmap' VALUES (15998, 13448, 2);
INSERT INTO 'dancesstepsmap' VALUES (15999, 13447, 5);
INSERT INTO 'dancesstepsmap' VALUES (16000, 13447, 4);
INSERT INTO 'dancesstepsmap' VALUES (16001, 13446, 1);
INSERT INTO 'dancesstepsmap' VALUES (16002, 13446, 3);
INSERT INTO 'dancesstepsmap' VALUES (16003, 13445, 5);
INSERT INTO 'dancesstepsmap' VALUES (16004, 13445, 4);
INSERT INTO 'dancesstepsmap' VALUES (16005, 13444, 2);
INSERT INTO 'dancesstepsmap' VALUES (16006, 13444, 1);
INSERT INTO 'dancesstepsmap' VALUES (16007, 13443, 1);
INSERT INTO 'dancesstepsmap' VALUES (16008, 13442, 2);
INSERT INTO 'dancesstepsmap' VALUES (16009, 13442, 1);
INSERT INTO 'dancesstepsmap' VALUES (16011, 13441, 1);
INSERT INTO 'dancesstepsmap' VALUES (16012, 13441, 2);
INSERT INTO 'dancesstepsmap' VALUES (16013, 13440, 5);
INSERT INTO 'dancesstepsmap' VALUES (16014, 13440, 4);
INSERT INTO 'dancesstepsmap' VALUES (16015, 13439, 1);
INSERT INTO 'dancesstepsmap' VALUES (16016, 13439, 2);
INSERT INTO 'dancesstepsmap' VALUES (16017, 13438, 2);
INSERT INTO 'dancesstepsmap' VALUES (16018, 13438, 1);
INSERT INTO 'dancesstepsmap' VALUES (16019, 13437, 2);
INSERT INTO 'dancesstepsmap' VALUES (16020, 13437, 1);
INSERT INTO 'dancesstepsmap' VALUES (16021, 13436, 2);
INSERT INTO 'dancesstepsmap' VALUES (16022, 13436, 1);
INSERT INTO 'dancesstepsmap' VALUES (16023, 13436, 3);
INSERT INTO 'dancesstepsmap' VALUES (16024, 775, 6);
INSERT INTO 'dancesstepsmap' VALUES (16025, 775, 5);
INSERT INTO 'dancesstepsmap' VALUES (16026, 13522, 1);
INSERT INTO 'dancesstepsmap' VALUES (16027, 13522, 3);
INSERT INTO 'dancesstepsmap' VALUES (16028, 13522, 2);
INSERT INTO 'dancesstepsmap' VALUES (16029, 13677, 1);
INSERT INTO 'dancesstepsmap' VALUES (16030, 13677, 3);
INSERT INTO 'dancesstepsmap' VALUES (16031, 13679, 4);
INSERT INTO 'dancesstepsmap' VALUES (16032, 13679, 5);
INSERT INTO 'dancesstepsmap' VALUES (16033, 13679, 1);
INSERT INTO 'dancesstepsmap' VALUES (16034, 13679, 2);
INSERT INTO 'dancesstepsmap' VALUES (16035, 13680, 5);
INSERT INTO 'dancesstepsmap' VALUES (16036, 13680, 4);
INSERT INTO 'dancesstepsmap' VALUES (16037, 13589, 5);
INSERT INTO 'dancesstepsmap' VALUES (16038, 13589, 4);
INSERT INTO 'dancesstepsmap' VALUES (16039, 13681, 1);
INSERT INTO 'dancesstepsmap' VALUES (16040, 13681, 2);
INSERT INTO 'dancesstepsmap' VALUES (16041, 13681, 3);
INSERT INTO 'dancesstepsmap' VALUES (16042, 13682, 1);
INSERT INTO 'dancesstepsmap' VALUES (16043, 13682, 2);
INSERT INTO 'dancesstepsmap' VALUES (16044, 13683, 4);
INSERT INTO 'dancesstepsmap' VALUES (16045, 13683, 5);
INSERT INTO 'dancesstepsmap' VALUES (16046, 13328, 2);
INSERT INTO 'dancesstepsmap' VALUES (16047, 13328, 1);
INSERT INTO 'dancesstepsmap' VALUES (16048, 13328, 3);
INSERT INTO 'dancesstepsmap' VALUES (16049, 13684, 4);
INSERT INTO 'dancesstepsmap' VALUES (16050, 13684, 5);
INSERT INTO 'dancesstepsmap' VALUES (16051, 13685, 1);
INSERT INTO 'dancesstepsmap' VALUES (16052, 13685, 2);
INSERT INTO 'dancesstepsmap' VALUES (16053, 13686, 1);
INSERT INTO 'dancesstepsmap' VALUES (16054, 13686, 2);
INSERT INTO 'dancesstepsmap' VALUES (16055, 13687, 4);
INSERT INTO 'dancesstepsmap' VALUES (16056, 13688, 1);
INSERT INTO 'dancesstepsmap' VALUES (16057, 13688, 2);
INSERT INTO 'dancesstepsmap' VALUES (16058, 13688, 3);
INSERT INTO 'dancesstepsmap' VALUES (16059, 13689, 4);
INSERT INTO 'dancesstepsmap' VALUES (16060, 13689, 5);
INSERT INTO 'dancesstepsmap' VALUES (16061, 13690, 1);
INSERT INTO 'dancesstepsmap' VALUES (16062, 13690, 2);
INSERT INTO 'dancesstepsmap' VALUES (16063, 13591, 1);
INSERT INTO 'dancesstepsmap' VALUES (16064, 13591, 2);
INSERT INTO 'dancesstepsmap' VALUES (16065, 11833, 2);
INSERT INTO 'dancesstepsmap' VALUES (16066, 11834, 5);
INSERT INTO 'dancesstepsmap' VALUES (16067, 11838, 99);
INSERT INTO 'dancesstepsmap' VALUES (16068, 13691, 4);
INSERT INTO 'dancesstepsmap' VALUES (16069, 13692, 1);
INSERT INTO 'dancesstepsmap' VALUES (16070, 13692, 2);
INSERT INTO 'dancesstepsmap' VALUES (16071, 13692, 3);
INSERT INTO 'dancesstepsmap' VALUES (16072, 13693, 1);
INSERT INTO 'dancesstepsmap' VALUES (16073, 13694, 5);
INSERT INTO 'dancesstepsmap' VALUES (16074, 13694, 4);
INSERT INTO 'dancesstepsmap' VALUES (16075, 10496, 5);
INSERT INTO 'dancesstepsmap' VALUES (16076, 11839, 2);
INSERT INTO 'dancesstepsmap' VALUES (16077, 11840, 5);
INSERT INTO 'dancesstepsmap' VALUES (16078, 11842, 3);
INSERT INTO 'dancesstepsmap' VALUES (16079, 11842, 1);
INSERT INTO 'dancesstepsmap' VALUES (16080, 11845, 2);
INSERT INTO 'dancesstepsmap' VALUES (16081, 11845, 1);
INSERT INTO 'dancesstepsmap' VALUES (16082, 11849, 3);
INSERT INTO 'dancesstepsmap' VALUES (16083, 11847, 5);
INSERT INTO 'dancesstepsmap' VALUES (16084, 11852, 2);
INSERT INTO 'dancesstepsmap' VALUES (16085, 11852, 1);
INSERT INTO 'dancesstepsmap' VALUES (16086, 11850, 5);
INSERT INTO 'dancesstepsmap' VALUES (16087, 11851, 4);
INSERT INTO 'dancesstepsmap' VALUES (16088, 11853, 2);
INSERT INTO 'dancesstepsmap' VALUES (16089, 11856, 2);
INSERT INTO 'dancesstepsmap' VALUES (16090, 11856, 1);
INSERT INTO 'dancesstepsmap' VALUES (16091, 11857, 4);
INSERT INTO 'dancesstepsmap' VALUES (16092, 11857, 5);
INSERT INTO 'dancesstepsmap' VALUES (16093, 11858, 2);
INSERT INTO 'dancesstepsmap' VALUES (16094, 11865, 1);
INSERT INTO 'dancesstepsmap' VALUES (16095, 11865, 2);
INSERT INTO 'dancesstepsmap' VALUES (16096, 13696, 5);
INSERT INTO 'dancesstepsmap' VALUES (16097, 13696, 4);
INSERT INTO 'dancesstepsmap' VALUES (16098, 13697, 1);
INSERT INTO 'dancesstepsmap' VALUES (16099, 13697, 2);
INSERT INTO 'dancesstepsmap' VALUES (16100, 13698, 1);
INSERT INTO 'dancesstepsmap' VALUES (16101, 13698, 2);
INSERT INTO 'dancesstepsmap' VALUES (16102, 13596, 1);
INSERT INTO 'dancesstepsmap' VALUES (16103, 13596, 2);
INSERT INTO 'dancesstepsmap' VALUES (16104, 13273, 2);
INSERT INTO 'dancesstepsmap' VALUES (16105, 11160, 4);
INSERT INTO 'dancesstepsmap' VALUES (16108, 13707, 1);
INSERT INTO 'dancesstepsmap' VALUES (16109, 13707, 2);
INSERT INTO 'dancesstepsmap' VALUES (16110, 13708, 4);
INSERT INTO 'dancesstepsmap' VALUES (16111, 13709, 1);
INSERT INTO 'dancesstepsmap' VALUES (16112, 13709, 2);
INSERT INTO 'dancesstepsmap' VALUES (16113, 13709, 3);
INSERT INTO 'dancesstepsmap' VALUES (16114, 13710, 2);
INSERT INTO 'dancesstepsmap' VALUES (16115, 13710, 1);
INSERT INTO 'dancesstepsmap' VALUES (16118, 13374, 5);
INSERT INTO 'dancesstepsmap' VALUES (16119, 13374, 4);
INSERT INTO 'dancesstepsmap' VALUES (16120, 13374, 2);
INSERT INTO 'dancesstepsmap' VALUES (16121, 13374, 1);
INSERT INTO 'dancesstepsmap' VALUES (16122, 13374, 3);
INSERT INTO 'dancesstepsmap' VALUES (16123, 13376, 4);
INSERT INTO 'dancesstepsmap' VALUES (16124, 13376, 6);
INSERT INTO 'dancesstepsmap' VALUES (16125, 13373, 3);
INSERT INTO 'dancesstepsmap' VALUES (16126, 1204, 2);
INSERT INTO 'dancesstepsmap' VALUES (16127, 13700, 1);
INSERT INTO 'dancesstepsmap' VALUES (16128, 13700, 2);
INSERT INTO 'dancesstepsmap' VALUES (16129, 13424, 1);
INSERT INTO 'dancesstepsmap' VALUES (16130, 13424, 2);
INSERT INTO 'dancesstepsmap' VALUES (16131, 13424, 8);
INSERT INTO 'dancesstepsmap' VALUES (16132, 13377, 5);
INSERT INTO 'dancesstepsmap' VALUES (16133, 13377, 4);
INSERT INTO 'dancesstepsmap' VALUES (16134, 13377, 1);
INSERT INTO 'dancesstepsmap' VALUES (16135, 13377, 3);
INSERT INTO 'dancesstepsmap' VALUES (16136, 13377, 2);
INSERT INTO 'dancesstepsmap' VALUES (16137, 13701, 4);
INSERT INTO 'dancesstepsmap' VALUES (16138, 13701, 5);
INSERT INTO 'dancesstepsmap' VALUES (16139, 13701, 2);
INSERT INTO 'dancesstepsmap' VALUES (16140, 13701, 1);
INSERT INTO 'dancesstepsmap' VALUES (15992, 13675, 5);
INSERT INTO 'dancesstepsmap' VALUES (15993, 13675, 4);
INSERT INTO 'dancesstepsmap' VALUES (16141, 13701, 3);
INSERT INTO 'dancesstepsmap' VALUES (16142, 13378, 2);
INSERT INTO 'dancesstepsmap' VALUES (16143, 13378, 1);
INSERT INTO 'dancesstepsmap' VALUES (16144, 9261, 1);
INSERT INTO 'dancesstepsmap' VALUES (16145, 9261, 2);
INSERT INTO 'dancesstepsmap' VALUES (16146, 13379, 5);
INSERT INTO 'dancesstepsmap' VALUES (16147, 13379, 4);
INSERT INTO 'dancesstepsmap' VALUES (16148, 13380, 4);
INSERT INTO 'dancesstepsmap' VALUES (16149, 13380, 5);
INSERT INTO 'dancesstepsmap' VALUES (16150, 13512, 1);
INSERT INTO 'dancesstepsmap' VALUES (16151, 13512, 2);
INSERT INTO 'dancesstepsmap' VALUES (16152, 13702, 4);
INSERT INTO 'dancesstepsmap' VALUES (16153, 13702, 5);
INSERT INTO 'dancesstepsmap' VALUES (16154, 11874, 2);
INSERT INTO 'dancesstepsmap' VALUES (16155, 11874, 1);
INSERT INTO 'dancesstepsmap' VALUES (16156, 11874, 3);
INSERT INTO 'dancesstepsmap' VALUES (16157, 11873, 5);
INSERT INTO 'dancesstepsmap' VALUES (16158, 11873, 4);
INSERT INTO 'dancesstepsmap' VALUES (16159, 13703, 4);
INSERT INTO 'dancesstepsmap' VALUES (16160, 13381, 1);
INSERT INTO 'dancesstepsmap' VALUES (16161, 13381, 2);
INSERT INTO 'dancesstepsmap' VALUES (16162, 13704, 1);
INSERT INTO 'dancesstepsmap' VALUES (16163, 13704, 2);
INSERT INTO 'dancesstepsmap' VALUES (16164, 13704, 3);
INSERT INTO 'dancesstepsmap' VALUES (16165, 13706, 3);
INSERT INTO 'dancesstepsmap' VALUES (16166, 13706, 1);
INSERT INTO 'dancesstepsmap' VALUES (16167, 13706, 2);
INSERT INTO 'dancesstepsmap' VALUES (16168, 13513, 2);
INSERT INTO 'dancesstepsmap' VALUES (16169, 13513, 1);
INSERT INTO 'dancesstepsmap' VALUES (16170, 13705, 1);
INSERT INTO 'dancesstepsmap' VALUES (16172, 13695, 4);
INSERT INTO 'dancesstepsmap' VALUES (16173, 13695, 5);
INSERT INTO 'dancesstepsmap' VALUES (16174, 13712, 5);
INSERT INTO 'dancesstepsmap' VALUES (16175, 13712, 4);
INSERT INTO 'dancesstepsmap' VALUES (16176, 13713, 1);
INSERT INTO 'dancesstepsmap' VALUES (16177, 13714, 2);
INSERT INTO 'dancesstepsmap' VALUES (16178, 13714, 1);
INSERT INTO 'dancesstepsmap' VALUES (16179, 13715, 1);
INSERT INTO 'dancesstepsmap' VALUES (16180, 13716, 5);
INSERT INTO 'dancesstepsmap' VALUES (16181, 13716, 4);
INSERT INTO 'dancesstepsmap' VALUES (16182, 13717, 2);
INSERT INTO 'dancesstepsmap' VALUES (16183, 13717, 1);
INSERT INTO 'dancesstepsmap' VALUES (16184, 13718, 1);
INSERT INTO 'dancesstepsmap' VALUES (16185, 13718, 2);
INSERT INTO 'dancesstepsmap' VALUES (16186, 13719, 4);
INSERT INTO 'dancesstepsmap' VALUES (16187, 13719, 5);
INSERT INTO 'dancesstepsmap' VALUES (16188, 1410, 5);
INSERT INTO 'dancesstepsmap' VALUES (16189, 13720, 5);
INSERT INTO 'dancesstepsmap' VALUES (16190, 13720, 4);
INSERT INTO 'dancesstepsmap' VALUES (16191, 13721, 1);
INSERT INTO 'dancesstepsmap' VALUES (16192, 13722, 2);
INSERT INTO 'dancesstepsmap' VALUES (16193, 13722, 1);
INSERT INTO 'dancesstepsmap' VALUES (16194, 13723, 1);
INSERT INTO 'dancesstepsmap' VALUES (16196, 13615, 1);
INSERT INTO 'dancesstepsmap' VALUES (16197, 13511, 1);
INSERT INTO 'dancesstepsmap' VALUES (16198, 13511, 2);
INSERT INTO 'dancesstepsmap' VALUES (16199, 13725, 4);
INSERT INTO 'dancesstepsmap' VALUES (16200, 13726, 1);
INSERT INTO 'dancesstepsmap' VALUES (16201, 13726, 2);
INSERT INTO 'dancesstepsmap' VALUES (16202, 13727, 4);
INSERT INTO 'dancesstepsmap' VALUES (16203, 13728, 1);
INSERT INTO 'dancesstepsmap' VALUES (16204, 13728, 2);
INSERT INTO 'dancesstepsmap' VALUES (16205, 6150, 4);
INSERT INTO 'dancesstepsmap' VALUES (16206, 3397, 5);
INSERT INTO 'dancesstepsmap' VALUES (16207, 13730, 1);
INSERT INTO 'dancesstepsmap' VALUES (16208, 13731, 4);
INSERT INTO 'dancesstepsmap' VALUES (16209, 13731, 5);
INSERT INTO 'dancesstepsmap' VALUES (16210, 13732, 2);
INSERT INTO 'dancesstepsmap' VALUES (16211, 13732, 1);
INSERT INTO 'dancesstepsmap' VALUES (16212, 13733, 4);
INSERT INTO 'dancesstepsmap' VALUES (16213, 13733, 5);
INSERT INTO 'dancesstepsmap' VALUES (16214, 13733, 1);
INSERT INTO 'dancesstepsmap' VALUES (16215, 13733, 2);
INSERT INTO 'dancesstepsmap' VALUES (16216, 13733, 3);
INSERT INTO 'dancesstepsmap' VALUES (16217, 13734, 5);
INSERT INTO 'dancesstepsmap' VALUES (16218, 13734, 4);
INSERT INTO 'dancesstepsmap' VALUES (16219, 13735, 2);
INSERT INTO 'dancesstepsmap' VALUES (16220, 13735, 1);
INSERT INTO 'dancesstepsmap' VALUES (16221, 13735, 3);
INSERT INTO 'dancesstepsmap' VALUES (16222, 13736, 1);
INSERT INTO 'dancesstepsmap' VALUES (16223, 13736, 2);
INSERT INTO 'dancesstepsmap' VALUES (16224, 13736, 3);
INSERT INTO 'dancesstepsmap' VALUES (16225, 13737, 4);
INSERT INTO 'dancesstepsmap' VALUES (16226, 13737, 5);
INSERT INTO 'dancesstepsmap' VALUES (16227, 13738, 4);
INSERT INTO 'dancesstepsmap' VALUES (16228, 13738, 5);
INSERT INTO 'dancesstepsmap' VALUES (16229, 13738, 1);
INSERT INTO 'dancesstepsmap' VALUES (16230, 13738, 2);
INSERT INTO 'dancesstepsmap' VALUES (16231, 13739, 1);
INSERT INTO 'dancesstepsmap' VALUES (16234, 13741, 4);
INSERT INTO 'dancesstepsmap' VALUES (16235, 13740, 1);
INSERT INTO 'dancesstepsmap' VALUES (16236, 13742, 1);
INSERT INTO 'dancesstepsmap' VALUES (16237, 13742, 2);
INSERT INTO 'dancesstepsmap' VALUES (16238, 13742, 3);
INSERT INTO 'dancesstepsmap' VALUES (16239, 13745, 1);
INSERT INTO 'dancesstepsmap' VALUES (16240, 13746, 1);
INSERT INTO 'dancesstepsmap' VALUES (16241, 13747, 1);
INSERT INTO 'dancesstepsmap' VALUES (16242, 13748, 1);
INSERT INTO 'dancesstepsmap' VALUES (16243, 13748, 2);
INSERT INTO 'dancesstepsmap' VALUES (16244, 13749, 1);
INSERT INTO 'dancesstepsmap' VALUES (16245, 13749, 2);
INSERT INTO 'dancesstepsmap' VALUES (16246, 13750, 4);
INSERT INTO 'dancesstepsmap' VALUES (16247, 13750, 5);
INSERT INTO 'dancesstepsmap' VALUES (16248, 13751, 4);
INSERT INTO 'dancesstepsmap' VALUES (16249, 13753, 4);
INSERT INTO 'dancesstepsmap' VALUES (16250, 13755, 4);
INSERT INTO 'dancesstepsmap' VALUES (16251, 13755, 5);
INSERT INTO 'dancesstepsmap' VALUES (16252, 12364, 2);
INSERT INTO 'dancesstepsmap' VALUES (16253, 12364, 1);
INSERT INTO 'dancesstepsmap' VALUES (16254, 13460, 1);
INSERT INTO 'dancesstepsmap' VALUES (16255, 13460, 3);
INSERT INTO 'dancesstepsmap' VALUES (16256, 13463, 1);
INSERT INTO 'dancesstepsmap' VALUES (16257, 4223, 5);
INSERT INTO 'dancesstepsmap' VALUES (16258, 13465, 1);
INSERT INTO 'dancesstepsmap' VALUES (16259, 13468, 1);
INSERT INTO 'dancesstepsmap' VALUES (16260, 13471, 1);
INSERT INTO 'dancesstepsmap' VALUES (16261, 13472, 1);
INSERT INTO 'dancesstepsmap' VALUES (16262, 13472, 3);
INSERT INTO 'dancesstepsmap' VALUES (16263, 13462, 1);
INSERT INTO 'dancesstepsmap' VALUES (16264, 13462, 3);
INSERT INTO 'dancesstepsmap' VALUES (16265, 13464, 2);
INSERT INTO 'dancesstepsmap' VALUES (16266, 13464, 1);
INSERT INTO 'dancesstepsmap' VALUES (16267, 13756, 1);
INSERT INTO 'dancesstepsmap' VALUES (16268, 13756, 2);
INSERT INTO 'dancesstepsmap' VALUES (16269, 13756, 3);
INSERT INTO 'dancesstepsmap' VALUES (16270, 13467, 1);
INSERT INTO 'dancesstepsmap' VALUES (16271, 13470, 1);
INSERT INTO 'dancesstepsmap' VALUES (16272, 13473, 1);
INSERT INTO 'dancesstepsmap' VALUES (16273, 13461, 5);
INSERT INTO 'dancesstepsmap' VALUES (16274, 13461, 4);
INSERT INTO 'dancesstepsmap' VALUES (16275, 13466, 4);
INSERT INTO 'dancesstepsmap' VALUES (16276, 13469, 4);
INSERT INTO 'dancesstepsmap' VALUES (16277, 13469, 5);
INSERT INTO 'dancesstepsmap' VALUES (16278, 10624, 1);
INSERT INTO 'dancesstepsmap' VALUES (16279, 10624, 4);
INSERT INTO 'dancesstepsmap' VALUES (16280, 13757, 2);
INSERT INTO 'dancesstepsmap' VALUES (16281, 13757, 1);
INSERT INTO 'dancesstepsmap' VALUES (16282, 13757, 3);
INSERT INTO 'dancesstepsmap' VALUES (16283, 13758, 1);
INSERT INTO 'dancesstepsmap' VALUES (16284, 13758, 2);
INSERT INTO 'dancesstepsmap' VALUES (16285, 13758, 3);
INSERT INTO 'dancesstepsmap' VALUES (16286, 13759, 1);
INSERT INTO 'dancesstepsmap' VALUES (16287, 13759, 3);
INSERT INTO 'dancesstepsmap' VALUES (16288, 13760, 1);
INSERT INTO 'dancesstepsmap' VALUES (16289, 13760, 3);
INSERT INTO 'dancesstepsmap' VALUES (16290, 13764, 1);
INSERT INTO 'dancesstepsmap' VALUES (16291, 13764, 2);
INSERT INTO 'dancesstepsmap' VALUES (16292, 13388, 3);
INSERT INTO 'dancesstepsmap' VALUES (16293, 13388, 2);
INSERT INTO 'dancesstepsmap' VALUES (16294, 13388, 1);
INSERT INTO 'dancesstepsmap' VALUES (16295, 13389, 3);
INSERT INTO 'dancesstepsmap' VALUES (16296, 13389, 1);
INSERT INTO 'dancesstepsmap' VALUES (16297, 13389, 2);
INSERT INTO 'dancesstepsmap' VALUES (16298, 13286, 4);
INSERT INTO 'dancesstepsmap' VALUES (16299, 13286, 5);
INSERT INTO 'dancesstepsmap' VALUES (16300, 13390, 2);
INSERT INTO 'dancesstepsmap' VALUES (16301, 13390, 1);
INSERT INTO 'dancesstepsmap' VALUES (16302, 13387, 4);
INSERT INTO 'dancesstepsmap' VALUES (16303, 13391, 4);
INSERT INTO 'dancesstepsmap' VALUES (16304, 13391, 5);
INSERT INTO 'dancesstepsmap' VALUES (16305, 13392, 4);
INSERT INTO 'dancesstepsmap' VALUES (16306, 13392, 5);
INSERT INTO 'dancesstepsmap' VALUES (16307, 13392, 3);
INSERT INTO 'dancesstepsmap' VALUES (16308, 13392, 1);
INSERT INTO 'dancesstepsmap' VALUES (16309, 13392, 2);
INSERT INTO 'dancesstepsmap' VALUES (16310, 13766, 4);
INSERT INTO 'dancesstepsmap' VALUES (16311, 13766, 5);
INSERT INTO 'dancesstepsmap' VALUES (16312, 13393, 1);
INSERT INTO 'dancesstepsmap' VALUES (16313, 13393, 2);
INSERT INTO 'dancesstepsmap' VALUES (16314, 13394, 4);
INSERT INTO 'dancesstepsmap' VALUES (16315, 13394, 5);
INSERT INTO 'dancesstepsmap' VALUES (16316, 13395, 4);
INSERT INTO 'dancesstepsmap' VALUES (16317, 13395, 5);
INSERT INTO 'dancesstepsmap' VALUES (16318, 13396, 2);
INSERT INTO 'dancesstepsmap' VALUES (16319, 13396, 1);
INSERT INTO 'dancesstepsmap' VALUES (16320, 13767, 4);
INSERT INTO 'dancesstepsmap' VALUES (16321, 13768, 1);
INSERT INTO 'dancesstepsmap' VALUES (16322, 13768, 2);
INSERT INTO 'dancesstepsmap' VALUES (16323, 13768, 3);
INSERT INTO 'dancesstepsmap' VALUES (16324, 13769, 1);
INSERT INTO 'dancesstepsmap' VALUES (16325, 13769, 3);
INSERT INTO 'dancesstepsmap' VALUES (16326, 13770, 4);
INSERT INTO 'dancesstepsmap' VALUES (16327, 13770, 5);
INSERT INTO 'dancesstepsmap' VALUES (16328, 13770, 1);
INSERT INTO 'dancesstepsmap' VALUES (16329, 13770, 2);
INSERT INTO 'dancesstepsmap' VALUES (16330, 13770, 3);
INSERT INTO 'dancesstepsmap' VALUES (16331, 13771, 4);
INSERT INTO 'dancesstepsmap' VALUES (16332, 13771, 5);
INSERT INTO 'dancesstepsmap' VALUES (16333, 13772, 4);
INSERT INTO 'dancesstepsmap' VALUES (16334, 13772, 1);
INSERT INTO 'dancesstepsmap' VALUES (16336, 13773, 4);
INSERT INTO 'dancesstepsmap' VALUES (16337, 13773, 5);
INSERT INTO 'dancesstepsmap' VALUES (16338, 74, 5);
INSERT INTO 'dancesstepsmap' VALUES (16339, 4180, 2);
INSERT INTO 'dancesstepsmap' VALUES (16340, 13774, 1);
INSERT INTO 'dancesstepsmap' VALUES (16341, 3042, 5);
INSERT INTO 'dancesstepsmap' VALUES (16342, 4903, 2);
INSERT INTO 'dancesstepsmap' VALUES (16343, 6513, 2);
INSERT INTO 'dancesstepsmap' VALUES (16344, 6513, 99);
INSERT INTO 'dancesstepsmap' VALUES (16345, 6513, 10);
INSERT INTO 'dancesstepsmap' VALUES (16346, 2640, 5);
INSERT INTO 'dancesstepsmap' VALUES (16347, 6168, 5);
INSERT INTO 'dancesstepsmap' VALUES (16348, 2635, 1);
INSERT INTO 'dancesstepsmap' VALUES (16349, 2635, 2);
INSERT INTO 'dancesstepsmap' VALUES (16350, 5005, 1);
INSERT INTO 'dancesstepsmap' VALUES (16351, 5238, 2);
INSERT INTO 'dancesstepsmap' VALUES (16352, 6417, 5);
INSERT INTO 'dancesstepsmap' VALUES (16353, 6834, 5);
INSERT INTO 'dancesstepsmap' VALUES (16354, 5521, 2);
INSERT INTO 'dancesstepsmap' VALUES (16355, 4965, 2);
INSERT INTO 'dancesstepsmap' VALUES (16356, 5327, 1);
INSERT INTO 'dancesstepsmap' VALUES (16357, 2401, 4);
INSERT INTO 'dancesstepsmap' VALUES (16358, 5605, 5);
INSERT INTO 'dancesstepsmap' VALUES (16359, 5620, 5);
INSERT INTO 'dancesstepsmap' VALUES (16360, 5388, 6);
INSERT INTO 'dancesstepsmap' VALUES (16361, 5388, 5);
INSERT INTO 'dancesstepsmap' VALUES (16362, 10858, 5);
INSERT INTO 'dancesstepsmap' VALUES (16363, 8702, 4);
INSERT INTO 'dancesstepsmap' VALUES (16364, 10049, 2);
INSERT INTO 'dancesstepsmap' VALUES (16365, 8162, 99);
INSERT INTO 'dancesstepsmap' VALUES (16366, 12795, 1);
INSERT INTO 'dancesstepsmap' VALUES (16367, 2364, 4);
INSERT INTO 'dancesstepsmap' VALUES (16368, 13780, 1);
INSERT INTO 'dancesstepsmap' VALUES (16369, 13780, 3);
INSERT INTO 'dancesstepsmap' VALUES (16370, 13779, 3);
INSERT INTO 'dancesstepsmap' VALUES (16371, 13779, 1);
INSERT INTO 'dancesstepsmap' VALUES (16372, 13781, 1);
INSERT INTO 'dancesstepsmap' VALUES (16373, 13781, 2);
INSERT INTO 'dancesstepsmap' VALUES (16232, 13739, 2);
INSERT INTO 'dancesstepsmap' VALUES (16374, 13782, 1);
INSERT INTO 'dancesstepsmap' VALUES (16375, 13783, 1);
INSERT INTO 'dancesstepsmap' VALUES (16376, 13783, 2);
INSERT INTO 'dancesstepsmap' VALUES (16377, 13784, 4);
INSERT INTO 'dancesstepsmap' VALUES (16378, 13784, 5);
INSERT INTO 'dancesstepsmap' VALUES (16379, 13785, 4);
INSERT INTO 'dancesstepsmap' VALUES (16380, 13785, 5);
INSERT INTO 'dancesstepsmap' VALUES (16381, 13786, 4);
INSERT INTO 'dancesstepsmap' VALUES (16382, 13786, 5);
INSERT INTO 'dancesstepsmap' VALUES (16383, 13787, 4);
INSERT INTO 'dancesstepsmap' VALUES (16384, 13787, 5);
INSERT INTO 'dancesstepsmap' VALUES (16385, 13788, 4);
INSERT INTO 'dancesstepsmap' VALUES (16386, 13788, 5);
INSERT INTO 'dancesstepsmap' VALUES (16387, 13789, 4);
INSERT INTO 'dancesstepsmap' VALUES (16388, 13789, 5);
INSERT INTO 'dancesstepsmap' VALUES (16389, 13790, 1);
INSERT INTO 'dancesstepsmap' VALUES (16391, 13791, 1);
INSERT INTO 'dancesstepsmap' VALUES (16392, 13791, 2);
INSERT INTO 'dancesstepsmap' VALUES (16393, 13792, 1);
INSERT INTO 'dancesstepsmap' VALUES (16394, 13792, 2);
INSERT INTO 'dancesstepsmap' VALUES (16395, 13792, 3);
INSERT INTO 'dancesstepsmap' VALUES (16396, 13793, 1);
INSERT INTO 'dancesstepsmap' VALUES (16397, 13793, 2);
INSERT INTO 'dancesstepsmap' VALUES (16398, 13794, 4);
INSERT INTO 'dancesstepsmap' VALUES (16399, 13795, 1);
INSERT INTO 'dancesstepsmap' VALUES (16400, 13795, 2);
INSERT INTO 'dancesstepsmap' VALUES (16401, 13796, 1);
INSERT INTO 'dancesstepsmap' VALUES (16402, 13797, 5);
INSERT INTO 'dancesstepsmap' VALUES (16403, 13797, 4);
INSERT INTO 'dancesstepsmap' VALUES (16404, 13798, 4);
INSERT INTO 'dancesstepsmap' VALUES (16405, 13798, 5);
INSERT INTO 'dancesstepsmap' VALUES (16406, 13799, 4);
INSERT INTO 'dancesstepsmap' VALUES (16407, 13799, 5);
INSERT INTO 'dancesstepsmap' VALUES (16408, 13800, 1);
INSERT INTO 'dancesstepsmap' VALUES (16409, 13800, 2);
INSERT INTO 'dancesstepsmap' VALUES (16410, 13801, 1);
INSERT INTO 'dancesstepsmap' VALUES (16411, 13801, 2);
INSERT INTO 'dancesstepsmap' VALUES (16412, 13802, 1);
INSERT INTO 'dancesstepsmap' VALUES (16413, 13802, 2);
INSERT INTO 'dancesstepsmap' VALUES (16414, 13803, 1);
INSERT INTO 'dancesstepsmap' VALUES (16415, 13804, 1);
INSERT INTO 'dancesstepsmap' VALUES (16416, 12787, 4);
INSERT INTO 'dancesstepsmap' VALUES (16417, 868, 2);
INSERT INTO 'dancesstepsmap' VALUES (16418, 13807, 2);
INSERT INTO 'dancesstepsmap' VALUES (16419, 13807, 1);
INSERT INTO 'dancesstepsmap' VALUES (16420, 13807, 3);
INSERT INTO 'dancesstepsmap' VALUES (16421, 13822, 4);
INSERT INTO 'dancesstepsmap' VALUES (16422, 13822, 5);
INSERT INTO 'dancesstepsmap' VALUES (16423, 13805, 2);
INSERT INTO 'dancesstepsmap' VALUES (16424, 13805, 1);
INSERT INTO 'dancesstepsmap' VALUES (23178, 18258, 5);
INSERT INTO 'dancesstepsmap' VALUES (23228, 12226, 1);
INSERT INTO 'dancesstepsmap' VALUES (23229, 12230, 1);
INSERT INTO 'dancesstepsmap' VALUES (16428, 13808, 2);
INSERT INTO 'dancesstepsmap' VALUES (16429, 13808, 1);
INSERT INTO 'dancesstepsmap' VALUES (16430, 13808, 3);
INSERT INTO 'dancesstepsmap' VALUES (16431, 13808, 5);
INSERT INTO 'dancesstepsmap' VALUES (16432, 13808, 4);
INSERT INTO 'dancesstepsmap' VALUES (16433, 13809, 4);
INSERT INTO 'dancesstepsmap' VALUES (16434, 13809, 5);
INSERT INTO 'dancesstepsmap' VALUES (16440, 13812, 2);
INSERT INTO 'dancesstepsmap' VALUES (16390, 13790, 2);
INSERT INTO 'dancesstepsmap' VALUES (16437, 13811, 2);
INSERT INTO 'dancesstepsmap' VALUES (16438, 13811, 1);
INSERT INTO 'dancesstepsmap' VALUES (16439, 13812, 1);
INSERT INTO 'dancesstepsmap' VALUES (16441, 13813, 1);
INSERT INTO 'dancesstepsmap' VALUES (16442, 13814, 4);
INSERT INTO 'dancesstepsmap' VALUES (16443, 13814, 5);
INSERT INTO 'dancesstepsmap' VALUES (16444, 13815, 5);
INSERT INTO 'dancesstepsmap' VALUES (16445, 13815, 4);
INSERT INTO 'dancesstepsmap' VALUES (16446, 13815, 6);
INSERT INTO 'dancesstepsmap' VALUES (16447, 13816, 4);
INSERT INTO 'dancesstepsmap' VALUES (16448, 13816, 6);
INSERT INTO 'dancesstepsmap' VALUES (16449, 13816, 5);
INSERT INTO 'dancesstepsmap' VALUES (16450, 13817, 4);
INSERT INTO 'dancesstepsmap' VALUES (16451, 13817, 6);
INSERT INTO 'dancesstepsmap' VALUES (16452, 13818, 2);
INSERT INTO 'dancesstepsmap' VALUES (16453, 13818, 1);
INSERT INTO 'dancesstepsmap' VALUES (16454, 13819, 1);
INSERT INTO 'dancesstepsmap' VALUES (16455, 13819, 2);
INSERT INTO 'dancesstepsmap' VALUES (16456, 13819, 3);
INSERT INTO 'dancesstepsmap' VALUES (16457, 13820, 1);
INSERT INTO 'dancesstepsmap' VALUES (16458, 13820, 2);
INSERT INTO 'dancesstepsmap' VALUES (16459, 13821, 4);
INSERT INTO 'dancesstepsmap' VALUES (16460, 13821, 5);
INSERT INTO 'dancesstepsmap' VALUES (16461, 13821, 6);
INSERT INTO 'dancesstepsmap' VALUES (16462, 13827, 2);
INSERT INTO 'dancesstepsmap' VALUES (16463, 13827, 1);
INSERT INTO 'dancesstepsmap' VALUES (16464, 13828, 4);
INSERT INTO 'dancesstepsmap' VALUES (16465, 13828, 5);
INSERT INTO 'dancesstepsmap' VALUES (16466, 11436, 1);
INSERT INTO 'dancesstepsmap' VALUES (16467, 13829, 1);
INSERT INTO 'dancesstepsmap' VALUES (16471, 13831, 5);
INSERT INTO 'dancesstepsmap' VALUES (16472, 13831, 4);
INSERT INTO 'dancesstepsmap' VALUES (16473, 13832, 2);
INSERT INTO 'dancesstepsmap' VALUES (16474, 13832, 1);
INSERT INTO 'dancesstepsmap' VALUES (16475, 13832, 3);
INSERT INTO 'dancesstepsmap' VALUES (16478, 13834, 4);
INSERT INTO 'dancesstepsmap' VALUES (16479, 13834, 5);
INSERT INTO 'dancesstepsmap' VALUES (16480, 5232, 5);
INSERT INTO 'dancesstepsmap' VALUES (16481, 7862, 5);
INSERT INTO 'dancesstepsmap' VALUES (16482, 4399, 5);
INSERT INTO 'dancesstepsmap' VALUES (16483, 1273, 5);
INSERT INTO 'dancesstepsmap' VALUES (16484, 7103, 2);
INSERT INTO 'dancesstepsmap' VALUES (16485, 1383, 5);
INSERT INTO 'dancesstepsmap' VALUES (16486, 5275, 2);
INSERT INTO 'dancesstepsmap' VALUES (16488, 5469, 5);
INSERT INTO 'dancesstepsmap' VALUES (16489, 2853, 5);
INSERT INTO 'dancesstepsmap' VALUES (16490, 2503, 2);
INSERT INTO 'dancesstepsmap' VALUES (16491, 5690, 2);
INSERT INTO 'dancesstepsmap' VALUES (16492, 6395, 5);
INSERT INTO 'dancesstepsmap' VALUES (16493, 75, 5);
INSERT INTO 'dancesstepsmap' VALUES (16494, 595, 2);
INSERT INTO 'dancesstepsmap' VALUES (16495, 13910, 4);
INSERT INTO 'dancesstepsmap' VALUES (16496, 13910, 5);
INSERT INTO 'dancesstepsmap' VALUES (16497, 14243, 4);
INSERT INTO 'dancesstepsmap' VALUES (16498, 14243, 5);
INSERT INTO 'dancesstepsmap' VALUES (16499, 14261, 5);
INSERT INTO 'dancesstepsmap' VALUES (16500, 14261, 4);
INSERT INTO 'dancesstepsmap' VALUES (16501, 14260, 1);
INSERT INTO 'dancesstepsmap' VALUES (16502, 14262, 1);
INSERT INTO 'dancesstepsmap' VALUES (16503, 14262, 2);
INSERT INTO 'dancesstepsmap' VALUES (16504, 14264, 4);
INSERT INTO 'dancesstepsmap' VALUES (16505, 14265, 1);
INSERT INTO 'dancesstepsmap' VALUES (16506, 14266, 4);
INSERT INTO 'dancesstepsmap' VALUES (16507, 14267, 4);
INSERT INTO 'dancesstepsmap' VALUES (16508, 14267, 5);
INSERT INTO 'dancesstepsmap' VALUES (16509, 11902, 4);
INSERT INTO 'dancesstepsmap' VALUES (16510, 11902, 2);
INSERT INTO 'dancesstepsmap' VALUES (16511, 11902, 5);
INSERT INTO 'dancesstepsmap' VALUES (16512, 14269, 4);
INSERT INTO 'dancesstepsmap' VALUES (16513, 14270, 1);
INSERT INTO 'dancesstepsmap' VALUES (16514, 14270, 2);
INSERT INTO 'dancesstepsmap' VALUES (16425, 13806, 5);
INSERT INTO 'dancesstepsmap' VALUES (16426, 13806, 4);
INSERT INTO 'dancesstepsmap' VALUES (16515, 14271, 2);
INSERT INTO 'dancesstepsmap' VALUES (16516, 14271, 1);
INSERT INTO 'dancesstepsmap' VALUES (16517, 14272, 4);
INSERT INTO 'dancesstepsmap' VALUES (16518, 14272, 5);
INSERT INTO 'dancesstepsmap' VALUES (16519, 14273, 2);
INSERT INTO 'dancesstepsmap' VALUES (16520, 14273, 1);
INSERT INTO 'dancesstepsmap' VALUES (16521, 14274, 4);
INSERT INTO 'dancesstepsmap' VALUES (16522, 14274, 5);
INSERT INTO 'dancesstepsmap' VALUES (16523, 14275, 1);
INSERT INTO 'dancesstepsmap' VALUES (16524, 14275, 2);
INSERT INTO 'dancesstepsmap' VALUES (16525, 14275, 8);
INSERT INTO 'dancesstepsmap' VALUES (16526, 14276, 5);
INSERT INTO 'dancesstepsmap' VALUES (16527, 14276, 4);
INSERT INTO 'dancesstepsmap' VALUES (16528, 14277, 2);
INSERT INTO 'dancesstepsmap' VALUES (16529, 14277, 1);
INSERT INTO 'dancesstepsmap' VALUES (23179, 18259, 2);
INSERT INTO 'dancesstepsmap' VALUES (23180, 18259, 1);
INSERT INTO 'dancesstepsmap' VALUES (23181, 18259, 3);
INSERT INTO 'dancesstepsmap' VALUES (16533, 14279, 1);
INSERT INTO 'dancesstepsmap' VALUES (16534, 14279, 2);
INSERT INTO 'dancesstepsmap' VALUES (16535, 14280, 2);
INSERT INTO 'dancesstepsmap' VALUES (16536, 14280, 1);
INSERT INTO 'dancesstepsmap' VALUES (16537, 13131, 1);
INSERT INTO 'dancesstepsmap' VALUES (16538, 13131, 3);
INSERT INTO 'dancesstepsmap' VALUES (16539, 13424, 3);
INSERT INTO 'dancesstepsmap' VALUES (16540, 12290, 5);
INSERT INTO 'dancesstepsmap' VALUES (16541, 14281, 3);
INSERT INTO 'dancesstepsmap' VALUES (16542, 14281, 1);
INSERT INTO 'dancesstepsmap' VALUES (16543, 14281, 2);
INSERT INTO 'dancesstepsmap' VALUES (16544, 14282, 1);
INSERT INTO 'dancesstepsmap' VALUES (16545, 14282, 2);
INSERT INTO 'dancesstepsmap' VALUES (16546, 14283, 4);
INSERT INTO 'dancesstepsmap' VALUES (16547, 14283, 5);
INSERT INTO 'dancesstepsmap' VALUES (16548, 14284, 5);
INSERT INTO 'dancesstepsmap' VALUES (16549, 14284, 4);
INSERT INTO 'dancesstepsmap' VALUES (16550, 14284, 2);
INSERT INTO 'dancesstepsmap' VALUES (16551, 14284, 1);
INSERT INTO 'dancesstepsmap' VALUES (16552, 14284, 3);
INSERT INTO 'dancesstepsmap' VALUES (16553, 14285, 1);
INSERT INTO 'dancesstepsmap' VALUES (16554, 14285, 3);
INSERT INTO 'dancesstepsmap' VALUES (16555, 14286, 5);
INSERT INTO 'dancesstepsmap' VALUES (16556, 14286, 4);
INSERT INTO 'dancesstepsmap' VALUES (16557, 14286, 6);
INSERT INTO 'dancesstepsmap' VALUES (16558, 14287, 1);
INSERT INTO 'dancesstepsmap' VALUES (16559, 14287, 3);
INSERT INTO 'dancesstepsmap' VALUES (16560, 14287, 2);
INSERT INTO 'dancesstepsmap' VALUES (16561, 14288, 4);
INSERT INTO 'dancesstepsmap' VALUES (16562, 14289, 2);
INSERT INTO 'dancesstepsmap' VALUES (16563, 14289, 1);
INSERT INTO 'dancesstepsmap' VALUES (16564, 14290, 1);
INSERT INTO 'dancesstepsmap' VALUES (16565, 14290, 3);
INSERT INTO 'dancesstepsmap' VALUES (16566, 14291, 4);
INSERT INTO 'dancesstepsmap' VALUES (16567, 14292, 3);
INSERT INTO 'dancesstepsmap' VALUES (16568, 14292, 1);
INSERT INTO 'dancesstepsmap' VALUES (16569, 14292, 2);
INSERT INTO 'dancesstepsmap' VALUES (16570, 2459, 5);
INSERT INTO 'dancesstepsmap' VALUES (16571, 14134, 99);
INSERT INTO 'dancesstepsmap' VALUES (16572, 14134, 8);
INSERT INTO 'dancesstepsmap' VALUES (16573, 10507, 2);
INSERT INTO 'dancesstepsmap' VALUES (16574, 10935, 2);
INSERT INTO 'dancesstepsmap' VALUES (16575, 14135, 1);
INSERT INTO 'dancesstepsmap' VALUES (16576, 14135, 3);
INSERT INTO 'dancesstepsmap' VALUES (16577, 11762, 2);
INSERT INTO 'dancesstepsmap' VALUES (16579, 842, 5);
INSERT INTO 'dancesstepsmap' VALUES (16580, 3700, 5);
INSERT INTO 'dancesstepsmap' VALUES (16581, 7104, 2);
INSERT INTO 'dancesstepsmap' VALUES (16582, 3486, 2);
INSERT INTO 'dancesstepsmap' VALUES (16583, 11766, 1);
INSERT INTO 'dancesstepsmap' VALUES (16584, 11766, 2);
INSERT INTO 'dancesstepsmap' VALUES (16585, 11766, 3);
INSERT INTO 'dancesstepsmap' VALUES (16586, 11599, 2);
INSERT INTO 'dancesstepsmap' VALUES (16587, 7544, 2);
INSERT INTO 'dancesstepsmap' VALUES (16588, 13368, 1);
INSERT INTO 'dancesstepsmap' VALUES (16589, 13368, 2);
INSERT INTO 'dancesstepsmap' VALUES (16590, 14317, 4);
INSERT INTO 'dancesstepsmap' VALUES (16591, 14317, 5);
INSERT INTO 'dancesstepsmap' VALUES (16592, 14317, 2);
INSERT INTO 'dancesstepsmap' VALUES (16593, 14317, 1);
INSERT INTO 'dancesstepsmap' VALUES (16594, 7626, 2);
INSERT INTO 'dancesstepsmap' VALUES (16595, 5409, 2);
INSERT INTO 'dancesstepsmap' VALUES (16596, 3727, 2);
INSERT INTO 'dancesstepsmap' VALUES (16597, 8992, 1);
INSERT INTO 'dancesstepsmap' VALUES (16598, 8992, 2);
INSERT INTO 'dancesstepsmap' VALUES (16599, 14320, 5);
INSERT INTO 'dancesstepsmap' VALUES (16600, 14320, 4);
INSERT INTO 'dancesstepsmap' VALUES (16601, 14321, 1);
INSERT INTO 'dancesstepsmap' VALUES (16602, 14321, 2);
INSERT INTO 'dancesstepsmap' VALUES (16603, 14322, 2);
INSERT INTO 'dancesstepsmap' VALUES (16604, 14322, 1);
INSERT INTO 'dancesstepsmap' VALUES (16605, 14322, 3);
INSERT INTO 'dancesstepsmap' VALUES (16606, 439, 5);
INSERT INTO 'dancesstepsmap' VALUES (16607, 13577, 3);
INSERT INTO 'dancesstepsmap' VALUES (16608, 13581, 2);
INSERT INTO 'dancesstepsmap' VALUES (16609, 13581, 1);
INSERT INTO 'dancesstepsmap' VALUES (16610, 11512, 5);
INSERT INTO 'dancesstepsmap' VALUES (16611, 11512, 6);
INSERT INTO 'dancesstepsmap' VALUES (16612, 2077, 2);
INSERT INTO 'dancesstepsmap' VALUES (16613, 11367, 2);
INSERT INTO 'dancesstepsmap' VALUES (16614, 12803, 2);
INSERT INTO 'dancesstepsmap' VALUES (16615, 12803, 1);
INSERT INTO 'dancesstepsmap' VALUES (16616, 12803, 3);
INSERT INTO 'dancesstepsmap' VALUES (16619, 2604, 3);
INSERT INTO 'dancesstepsmap' VALUES (16620, 13580, 3);
INSERT INTO 'dancesstepsmap' VALUES (16621, 13580, 1);
INSERT INTO 'dancesstepsmap' VALUES (16622, 9332, 2);
INSERT INTO 'dancesstepsmap' VALUES (16623, 12802, 2);
INSERT INTO 'dancesstepsmap' VALUES (16624, 12802, 1);
INSERT INTO 'dancesstepsmap' VALUES (16625, 13579, 2);
INSERT INTO 'dancesstepsmap' VALUES (16626, 13579, 1);
INSERT INTO 'dancesstepsmap' VALUES (16627, 13579, 3);
INSERT INTO 'dancesstepsmap' VALUES (16628, 9636, 1);
INSERT INTO 'dancesstepsmap' VALUES (16629, 7560, 5);
INSERT INTO 'dancesstepsmap' VALUES (16630, 11890, 2);
INSERT INTO 'dancesstepsmap' VALUES (16631, 3593, 3);
INSERT INTO 'dancesstepsmap' VALUES (16632, 11524, 1);
INSERT INTO 'dancesstepsmap' VALUES (16633, 11814, 5);
INSERT INTO 'dancesstepsmap' VALUES (16634, 4692, 2);
INSERT INTO 'dancesstepsmap' VALUES (16635, 12538, 2);
INSERT INTO 'dancesstepsmap' VALUES (16636, 12538, 3);
INSERT INTO 'dancesstepsmap' VALUES (16637, 5355, 2);
INSERT INTO 'dancesstepsmap' VALUES (16638, 5885, 5);
INSERT INTO 'dancesstepsmap' VALUES (16639, 6177, 2);
INSERT INTO 'dancesstepsmap' VALUES (16640, 6393, 5);
INSERT INTO 'dancesstepsmap' VALUES (16643, 7227, 2);
INSERT INTO 'dancesstepsmap' VALUES (16645, 6797, 101);
INSERT INTO 'dancesstepsmap' VALUES (16647, 7247, 101);
INSERT INTO 'dancesstepsmap' VALUES (16649, 13583, 1);
INSERT INTO 'dancesstepsmap' VALUES (16650, 13583, 2);
INSERT INTO 'dancesstepsmap' VALUES (16651, 7793, 101);
INSERT INTO 'dancesstepsmap' VALUES (16653, 13569, 5);
INSERT INTO 'dancesstepsmap' VALUES (16654, 13569, 4);
INSERT INTO 'dancesstepsmap' VALUES (16655, 3729, 1);
INSERT INTO 'dancesstepsmap' VALUES (16656, 7289, 5);
INSERT INTO 'dancesstepsmap' VALUES (16657, 7289, 4);
INSERT INTO 'dancesstepsmap' VALUES (16658, 7296, 5);
INSERT INTO 'dancesstepsmap' VALUES (16659, 7293, 2);
INSERT INTO 'dancesstepsmap' VALUES (16660, 14323, 1);
INSERT INTO 'dancesstepsmap' VALUES (16662, 14324, 4);
INSERT INTO 'dancesstepsmap' VALUES (16663, 14324, 5);
INSERT INTO 'dancesstepsmap' VALUES (16669, 14325, 2);
INSERT INTO 'dancesstepsmap' VALUES (16670, 14325, 1);
INSERT INTO 'dancesstepsmap' VALUES (16671, 14325, 3);
INSERT INTO 'dancesstepsmap' VALUES (16673, 13359, 1);
INSERT INTO 'dancesstepsmap' VALUES (16674, 13359, 2);
INSERT INTO 'dancesstepsmap' VALUES (16676, 13364, 1);
INSERT INTO 'dancesstepsmap' VALUES (16677, 13364, 2);
INSERT INTO 'dancesstepsmap' VALUES (16686, 9676, 1);
INSERT INTO 'dancesstepsmap' VALUES (16687, 9676, 2);
INSERT INTO 'dancesstepsmap' VALUES (16689, 14327, 1);
INSERT INTO 'dancesstepsmap' VALUES (16690, 14327, 2);
INSERT INTO 'dancesstepsmap' VALUES (16692, 13363, 4);
INSERT INTO 'dancesstepsmap' VALUES (16641, 13582, 5);
INSERT INTO 'dancesstepsmap' VALUES (16642, 13582, 4);
INSERT INTO 'dancesstepsmap' VALUES (16694, 13366, 1);
INSERT INTO 'dancesstepsmap' VALUES (16695, 13366, 2);
INSERT INTO 'dancesstepsmap' VALUES (16697, 13358, 1);
INSERT INTO 'dancesstepsmap' VALUES (16698, 13358, 2);
INSERT INTO 'dancesstepsmap' VALUES (16700, 13362, 1);
INSERT INTO 'dancesstepsmap' VALUES (16701, 13362, 2);
INSERT INTO 'dancesstepsmap' VALUES (16703, 13360, 1);
INSERT INTO 'dancesstepsmap' VALUES (16704, 13360, 2);
INSERT INTO 'dancesstepsmap' VALUES (16706, 13361, 4);
INSERT INTO 'dancesstepsmap' VALUES (16707, 13361, 5);
INSERT INTO 'dancesstepsmap' VALUES (16709, 13365, 4);
INSERT INTO 'dancesstepsmap' VALUES (16710, 13365, 5);
INSERT INTO 'dancesstepsmap' VALUES (16712, 13729, 1);
INSERT INTO 'dancesstepsmap' VALUES (16713, 13262, 1);
INSERT INTO 'dancesstepsmap' VALUES (16715, 13260, 1);
INSERT INTO 'dancesstepsmap' VALUES (16717, 13261, 1);
INSERT INTO 'dancesstepsmap' VALUES (16718, 13261, 3);
INSERT INTO 'dancesstepsmap' VALUES (16720, 13263, 1);
INSERT INTO 'dancesstepsmap' VALUES (16722, 13264, 1);
INSERT INTO 'dancesstepsmap' VALUES (16724, 13266, 1);
INSERT INTO 'dancesstepsmap' VALUES (16726, 13267, 4);
INSERT INTO 'dancesstepsmap' VALUES (16727, 13267, 1);
INSERT INTO 'dancesstepsmap' VALUES (16728, 13267, 3);
INSERT INTO 'dancesstepsmap' VALUES (16730, 13268, 1);
INSERT INTO 'dancesstepsmap' VALUES (16731, 13268, 3);
INSERT INTO 'dancesstepsmap' VALUES (16733, 13357, 2);
INSERT INTO 'dancesstepsmap' VALUES (16734, 13357, 1);
INSERT INTO 'dancesstepsmap' VALUES (16735, 13357, 3);
INSERT INTO 'dancesstepsmap' VALUES (16736, 14328, 99);
INSERT INTO 'dancesstepsmap' VALUES (16737, 14329, 1);
INSERT INTO 'dancesstepsmap' VALUES (16738, 13355, 1);
INSERT INTO 'dancesstepsmap' VALUES (16739, 13355, 3);
INSERT INTO 'dancesstepsmap' VALUES (16740, 13356, 1);
INSERT INTO 'dancesstepsmap' VALUES (16741, 13356, 2);
INSERT INTO 'dancesstepsmap' VALUES (16742, 13356, 3);
INSERT INTO 'dancesstepsmap' VALUES (16743, 12996, 5);
INSERT INTO 'dancesstepsmap' VALUES (16744, 12996, 4);
INSERT INTO 'dancesstepsmap' VALUES (16745, 14330, 1);
INSERT INTO 'dancesstepsmap' VALUES (16746, 14330, 2);
INSERT INTO 'dancesstepsmap' VALUES (16747, 14330, 3);
INSERT INTO 'dancesstepsmap' VALUES (16750, 14332, 4);
INSERT INTO 'dancesstepsmap' VALUES (16751, 14332, 5);
INSERT INTO 'dancesstepsmap' VALUES (16752, 14337, 1);
INSERT INTO 'dancesstepsmap' VALUES (16753, 14338, 1);
INSERT INTO 'dancesstepsmap' VALUES (16754, 14338, 2);
INSERT INTO 'dancesstepsmap' VALUES (16755, 11308, 1);
INSERT INTO 'dancesstepsmap' VALUES (16756, 14339, 1);
INSERT INTO 'dancesstepsmap' VALUES (16757, 14339, 3);
INSERT INTO 'dancesstepsmap' VALUES (16758, 14339, 2);
INSERT INTO 'dancesstepsmap' VALUES (16759, 11296, 2);
INSERT INTO 'dancesstepsmap' VALUES (16760, 13964, 1);
INSERT INTO 'dancesstepsmap' VALUES (16761, 13964, 2);
INSERT INTO 'dancesstepsmap' VALUES (16762, 13964, 3);
INSERT INTO 'dancesstepsmap' VALUES (16763, 13965, 4);
INSERT INTO 'dancesstepsmap' VALUES (16764, 13965, 5);
INSERT INTO 'dancesstepsmap' VALUES (16765, 13975, 1);
INSERT INTO 'dancesstepsmap' VALUES (16766, 11285, 5);
INSERT INTO 'dancesstepsmap' VALUES (16767, 11285, 4);
INSERT INTO 'dancesstepsmap' VALUES (16768, 14333, 1);
INSERT INTO 'dancesstepsmap' VALUES (16769, 13984, 1);
INSERT INTO 'dancesstepsmap' VALUES (16770, 13984, 2);
INSERT INTO 'dancesstepsmap' VALUES (23182, 17754, 1);
INSERT INTO 'dancesstepsmap' VALUES (16772, 14055, 4);
INSERT INTO 'dancesstepsmap' VALUES (16773, 14340, 1);
INSERT INTO 'dancesstepsmap' VALUES (16774, 14341, 1);
INSERT INTO 'dancesstepsmap' VALUES (16775, 14341, 2);
INSERT INTO 'dancesstepsmap' VALUES (16776, 14341, 3);
INSERT INTO 'dancesstepsmap' VALUES (16777, 14342, 1);
INSERT INTO 'dancesstepsmap' VALUES (16778, 14342, 3);
INSERT INTO 'dancesstepsmap' VALUES (16779, 14342, 2);
INSERT INTO 'dancesstepsmap' VALUES (16780, 14343, 2);
INSERT INTO 'dancesstepsmap' VALUES (16781, 14343, 1);
INSERT INTO 'dancesstepsmap' VALUES (16782, 14343, 3);
INSERT INTO 'dancesstepsmap' VALUES (16783, 14344, 2);
INSERT INTO 'dancesstepsmap' VALUES (16784, 14344, 3);
INSERT INTO 'dancesstepsmap' VALUES (16785, 14345, 4);
INSERT INTO 'dancesstepsmap' VALUES (16786, 14345, 5);
INSERT INTO 'dancesstepsmap' VALUES (16787, 14347, 1);
INSERT INTO 'dancesstepsmap' VALUES (16788, 14347, 2);
INSERT INTO 'dancesstepsmap' VALUES (16789, 14347, 3);
INSERT INTO 'dancesstepsmap' VALUES (16790, 14348, 2);
INSERT INTO 'dancesstepsmap' VALUES (16791, 14348, 1);
INSERT INTO 'dancesstepsmap' VALUES (16792, 14349, 1);
INSERT INTO 'dancesstepsmap' VALUES (16793, 14349, 2);
INSERT INTO 'dancesstepsmap' VALUES (16794, 14350, 1);
INSERT INTO 'dancesstepsmap' VALUES (16795, 14350, 2);
INSERT INTO 'dancesstepsmap' VALUES (16796, 14351, 5);
INSERT INTO 'dancesstepsmap' VALUES (16797, 14351, 4);
INSERT INTO 'dancesstepsmap' VALUES (16798, 14353, 5);
INSERT INTO 'dancesstepsmap' VALUES (16799, 14353, 4);
INSERT INTO 'dancesstepsmap' VALUES (16800, 14354, 1);
INSERT INTO 'dancesstepsmap' VALUES (16801, 14354, 3);
INSERT INTO 'dancesstepsmap' VALUES (16802, 14356, 4);
INSERT INTO 'dancesstepsmap' VALUES (16803, 14356, 5);
INSERT INTO 'dancesstepsmap' VALUES (16804, 14357, 4);
INSERT INTO 'dancesstepsmap' VALUES (16805, 14357, 5);
INSERT INTO 'dancesstepsmap' VALUES (16806, 14358, 4);
INSERT INTO 'dancesstepsmap' VALUES (16807, 14358, 5);
INSERT INTO 'dancesstepsmap' VALUES (16808, 14355, 1);
INSERT INTO 'dancesstepsmap' VALUES (16809, 14355, 2);
INSERT INTO 'dancesstepsmap' VALUES (16810, 14359, 1);
INSERT INTO 'dancesstepsmap' VALUES (16811, 14359, 2);
INSERT INTO 'dancesstepsmap' VALUES (16812, 14360, 4);
INSERT INTO 'dancesstepsmap' VALUES (16813, 14361, 4);
INSERT INTO 'dancesstepsmap' VALUES (16814, 14361, 5);
INSERT INTO 'dancesstepsmap' VALUES (16815, 14362, 1);
INSERT INTO 'dancesstepsmap' VALUES (16816, 14362, 3);
INSERT INTO 'dancesstepsmap' VALUES (16817, 14363, 2);
INSERT INTO 'dancesstepsmap' VALUES (16818, 14363, 1);
INSERT INTO 'dancesstepsmap' VALUES (16819, 14364, 1);
INSERT INTO 'dancesstepsmap' VALUES (16820, 14364, 2);
INSERT INTO 'dancesstepsmap' VALUES (16821, 14365, 3);
INSERT INTO 'dancesstepsmap' VALUES (16822, 14365, 1);
INSERT INTO 'dancesstepsmap' VALUES (16823, 14365, 2);
INSERT INTO 'dancesstepsmap' VALUES (16824, 14366, 4);
INSERT INTO 'dancesstepsmap' VALUES (16825, 14366, 5);
INSERT INTO 'dancesstepsmap' VALUES (16826, 14367, 1);
INSERT INTO 'dancesstepsmap' VALUES (16827, 14367, 3);
INSERT INTO 'dancesstepsmap' VALUES (16828, 14368, 1);
INSERT INTO 'dancesstepsmap' VALUES (16829, 14333, 3);
INSERT INTO 'dancesstepsmap' VALUES (16830, 14376, 4);
INSERT INTO 'dancesstepsmap' VALUES (16831, 14374, 1);
INSERT INTO 'dancesstepsmap' VALUES (16832, 14374, 2);
INSERT INTO 'dancesstepsmap' VALUES (16833, 14374, 3);
INSERT INTO 'dancesstepsmap' VALUES (16834, 14377, 1);
INSERT INTO 'dancesstepsmap' VALUES (16835, 14377, 2);
INSERT INTO 'dancesstepsmap' VALUES (16836, 14377, 3);
INSERT INTO 'dancesstepsmap' VALUES (16837, 14375, 1);
INSERT INTO 'dancesstepsmap' VALUES (16838, 14369, 1);
INSERT INTO 'dancesstepsmap' VALUES (16839, 14369, 2);
INSERT INTO 'dancesstepsmap' VALUES (16840, 14372, 1);
INSERT INTO 'dancesstepsmap' VALUES (16841, 14372, 2);
INSERT INTO 'dancesstepsmap' VALUES (16842, 14379, 4);
INSERT INTO 'dancesstepsmap' VALUES (16843, 14381, 4);
INSERT INTO 'dancesstepsmap' VALUES (16844, 14381, 5);
INSERT INTO 'dancesstepsmap' VALUES (16845, 14381, 6);
INSERT INTO 'dancesstepsmap' VALUES (16849, 14385, 1);
INSERT INTO 'dancesstepsmap' VALUES (16850, 14385, 2);
INSERT INTO 'dancesstepsmap' VALUES (16851, 14385, 3);
INSERT INTO 'dancesstepsmap' VALUES (16852, 14386, 2);
INSERT INTO 'dancesstepsmap' VALUES (16853, 14386, 1);
INSERT INTO 'dancesstepsmap' VALUES (16854, 14387, 1);
INSERT INTO 'dancesstepsmap' VALUES (16855, 14387, 3);
INSERT INTO 'dancesstepsmap' VALUES (16856, 14388, 1);
INSERT INTO 'dancesstepsmap' VALUES (16857, 14388, 2);
INSERT INTO 'dancesstepsmap' VALUES (16858, 14388, 3);
INSERT INTO 'dancesstepsmap' VALUES (16859, 14389, 1);
INSERT INTO 'dancesstepsmap' VALUES (16860, 14390, 1);
INSERT INTO 'dancesstepsmap' VALUES (16861, 14390, 2);
INSERT INTO 'dancesstepsmap' VALUES (16862, 14391, 4);
INSERT INTO 'dancesstepsmap' VALUES (16863, 14391, 5);
INSERT INTO 'dancesstepsmap' VALUES (16864, 14392, 1);
INSERT INTO 'dancesstepsmap' VALUES (16865, 14392, 3);
INSERT INTO 'dancesstepsmap' VALUES (16866, 14392, 2);
INSERT INTO 'dancesstepsmap' VALUES (16867, 14393, 4);
INSERT INTO 'dancesstepsmap' VALUES (16868, 14393, 5);
INSERT INTO 'dancesstepsmap' VALUES (16869, 14394, 1);
INSERT INTO 'dancesstepsmap' VALUES (16870, 14394, 2);
INSERT INTO 'dancesstepsmap' VALUES (16871, 14394, 3);
INSERT INTO 'dancesstepsmap' VALUES (16872, 14395, 4);
INSERT INTO 'dancesstepsmap' VALUES (16873, 14395, 5);
INSERT INTO 'dancesstepsmap' VALUES (16874, 14396, 4);
INSERT INTO 'dancesstepsmap' VALUES (16875, 14249, 4);
INSERT INTO 'dancesstepsmap' VALUES (16876, 14249, 5);
INSERT INTO 'dancesstepsmap' VALUES (16877, 14397, 4);
INSERT INTO 'dancesstepsmap' VALUES (16878, 14397, 5);
INSERT INTO 'dancesstepsmap' VALUES (16879, 14398, 1);
INSERT INTO 'dancesstepsmap' VALUES (16880, 4366, 1);
INSERT INTO 'dancesstepsmap' VALUES (16881, 14399, 4);
INSERT INTO 'dancesstepsmap' VALUES (16882, 14399, 5);
INSERT INTO 'dancesstepsmap' VALUES (16883, 14399, 1);
INSERT INTO 'dancesstepsmap' VALUES (16884, 14399, 2);
INSERT INTO 'dancesstepsmap' VALUES (16885, 9675, 99);
INSERT INTO 'dancesstepsmap' VALUES (16886, 14400, 1);
INSERT INTO 'dancesstepsmap' VALUES (17469, 2037, 5);
INSERT INTO 'dancesstepsmap' VALUES (17470, 5403, 5);
INSERT INTO 'dancesstepsmap' VALUES (17471, 14719, 1);
INSERT INTO 'dancesstepsmap' VALUES (17472, 14719, 2);
INSERT INTO 'dancesstepsmap' VALUES (17473, 6577, 5);
INSERT INTO 'dancesstepsmap' VALUES (17474, 14720, 1);
INSERT INTO 'dancesstepsmap' VALUES (17475, 14720, 2);
INSERT INTO 'dancesstepsmap' VALUES (17476, 14738, 5);
INSERT INTO 'dancesstepsmap' VALUES (17477, 14738, 4);
INSERT INTO 'dancesstepsmap' VALUES (17478, 14739, 1);
INSERT INTO 'dancesstepsmap' VALUES (17479, 14740, 3);
INSERT INTO 'dancesstepsmap' VALUES (17480, 2508, 5);
INSERT INTO 'dancesstepsmap' VALUES (17481, 13847, 4);
INSERT INTO 'dancesstepsmap' VALUES (17482, 13847, 5);
INSERT INTO 'dancesstepsmap' VALUES (17483, 14749, 1);
INSERT INTO 'dancesstepsmap' VALUES (17484, 14749, 2);
INSERT INTO 'dancesstepsmap' VALUES (17485, 14750, 1);
INSERT INTO 'dancesstepsmap' VALUES (17486, 14750, 2);
INSERT INTO 'dancesstepsmap' VALUES (17487, 14744, 1);
INSERT INTO 'dancesstepsmap' VALUES (17489, 14744, 3);
INSERT INTO 'dancesstepsmap' VALUES (17490, 14742, 1);
INSERT INTO 'dancesstepsmap' VALUES (17491, 14742, 2);
INSERT INTO 'dancesstepsmap' VALUES (17492, 14742, 3);
INSERT INTO 'dancesstepsmap' VALUES (17493, 14743, 5);
INSERT INTO 'dancesstepsmap' VALUES (17494, 14743, 4);
INSERT INTO 'dancesstepsmap' VALUES (17495, 12520, 2);
INSERT INTO 'dancesstepsmap' VALUES (17496, 2222, 2);
INSERT INTO 'dancesstepsmap' VALUES (17497, 7745, 1);
INSERT INTO 'dancesstepsmap' VALUES (17498, 14799, 2);
INSERT INTO 'dancesstepsmap' VALUES (17499, 14799, 1);
INSERT INTO 'dancesstepsmap' VALUES (17500, 11397, 2);
INSERT INTO 'dancesstepsmap' VALUES (17501, 8158, 2);
INSERT INTO 'dancesstepsmap' VALUES (17502, 14809, 3);
INSERT INTO 'dancesstepsmap' VALUES (17503, 14809, 1);
INSERT INTO 'dancesstepsmap' VALUES (17504, 14810, 1);
INSERT INTO 'dancesstepsmap' VALUES (16847, 14384, 1);
INSERT INTO 'dancesstepsmap' VALUES (17488, 14744, 2);
INSERT INTO 'dancesstepsmap' VALUES (17505, 14810, 3);
INSERT INTO 'dancesstepsmap' VALUES (17506, 14811, 1);
INSERT INTO 'dancesstepsmap' VALUES (17507, 14812, 4);
INSERT INTO 'dancesstepsmap' VALUES (17508, 14812, 5);
INSERT INTO 'dancesstepsmap' VALUES (17509, 4847, 5);
INSERT INTO 'dancesstepsmap' VALUES (17510, 743, 5);
INSERT INTO 'dancesstepsmap' VALUES (17511, 4433, 2);
INSERT INTO 'dancesstepsmap' VALUES (17512, 4434, 5);
INSERT INTO 'dancesstepsmap' VALUES (17513, 5111, 5);
INSERT INTO 'dancesstepsmap' VALUES (17514, 13138, 5);
INSERT INTO 'dancesstepsmap' VALUES (17515, 13138, 4);
INSERT INTO 'dancesstepsmap' VALUES (17516, 14890, 1);
INSERT INTO 'dancesstepsmap' VALUES (17517, 14890, 3);
INSERT INTO 'dancesstepsmap' VALUES (17518, 13223, 2);
INSERT INTO 'dancesstepsmap' VALUES (17519, 14891, 1);
INSERT INTO 'dancesstepsmap' VALUES (17520, 14891, 3);
INSERT INTO 'dancesstepsmap' VALUES (17521, 14892, 2);
INSERT INTO 'dancesstepsmap' VALUES (17522, 14892, 1);
INSERT INTO 'dancesstepsmap' VALUES (17523, 6267, 2);
INSERT INTO 'dancesstepsmap' VALUES (17524, 14909, 4);
INSERT INTO 'dancesstepsmap' VALUES (17525, 14910, 1);
INSERT INTO 'dancesstepsmap' VALUES (17526, 14910, 2);
INSERT INTO 'dancesstepsmap' VALUES (17527, 14911, 4);
INSERT INTO 'dancesstepsmap' VALUES (17528, 14912, 1);
INSERT INTO 'dancesstepsmap' VALUES (17529, 14912, 2);
INSERT INTO 'dancesstepsmap' VALUES (17530, 14913, 1);
INSERT INTO 'dancesstepsmap' VALUES (17531, 14913, 2);
INSERT INTO 'dancesstepsmap' VALUES (17532, 14914, 1);
INSERT INTO 'dancesstepsmap' VALUES (17533, 14914, 2);
INSERT INTO 'dancesstepsmap' VALUES (17534, 14915, 5);
INSERT INTO 'dancesstepsmap' VALUES (17535, 14915, 4);
INSERT INTO 'dancesstepsmap' VALUES (17536, 14916, 5);
INSERT INTO 'dancesstepsmap' VALUES (17537, 14916, 4);
INSERT INTO 'dancesstepsmap' VALUES (17538, 14917, 1);
INSERT INTO 'dancesstepsmap' VALUES (17539, 14917, 2);
INSERT INTO 'dancesstepsmap' VALUES (17540, 14918, 1);
INSERT INTO 'dancesstepsmap' VALUES (17541, 14919, 2);
INSERT INTO 'dancesstepsmap' VALUES (17542, 14919, 10);
INSERT INTO 'dancesstepsmap' VALUES (17543, 14919, 1);
INSERT INTO 'dancesstepsmap' VALUES (17544, 14919, 3);
INSERT INTO 'dancesstepsmap' VALUES (17545, 14920, 4);
INSERT INTO 'dancesstepsmap' VALUES (17546, 14921, 1);
INSERT INTO 'dancesstepsmap' VALUES (17547, 14922, 4);
INSERT INTO 'dancesstepsmap' VALUES (17548, 14922, 5);
INSERT INTO 'dancesstepsmap' VALUES (17549, 14923, 1);
INSERT INTO 'dancesstepsmap' VALUES (17550, 14923, 2);
INSERT INTO 'dancesstepsmap' VALUES (17551, 14924, 5);
INSERT INTO 'dancesstepsmap' VALUES (17552, 14924, 4);
INSERT INTO 'dancesstepsmap' VALUES (17553, 14924, 1);
INSERT INTO 'dancesstepsmap' VALUES (17554, 14924, 2);
INSERT INTO 'dancesstepsmap' VALUES (17555, 14925, 1);
INSERT INTO 'dancesstepsmap' VALUES (17556, 14925, 2);
INSERT INTO 'dancesstepsmap' VALUES (17557, 14926, 1);
INSERT INTO 'dancesstepsmap' VALUES (17558, 14927, 5);
INSERT INTO 'dancesstepsmap' VALUES (17559, 14927, 4);
INSERT INTO 'dancesstepsmap' VALUES (17560, 10482, 2);
INSERT INTO 'dancesstepsmap' VALUES (17561, 14928, 2);
INSERT INTO 'dancesstepsmap' VALUES (17562, 14928, 1);
INSERT INTO 'dancesstepsmap' VALUES (17563, 14929, 4);
INSERT INTO 'dancesstepsmap' VALUES (17564, 14929, 5);
INSERT INTO 'dancesstepsmap' VALUES (17565, 13099, 1);
INSERT INTO 'dancesstepsmap' VALUES (17566, 13099, 2);
INSERT INTO 'dancesstepsmap' VALUES (17567, 8704, 1);
INSERT INTO 'dancesstepsmap' VALUES (17568, 14930, 4);
INSERT INTO 'dancesstepsmap' VALUES (17569, 14931, 1);
INSERT INTO 'dancesstepsmap' VALUES (17570, 14931, 2);
INSERT INTO 'dancesstepsmap' VALUES (17571, 13090, 1);
INSERT INTO 'dancesstepsmap' VALUES (17572, 3725, 2);
INSERT INTO 'dancesstepsmap' VALUES (17573, 13091, 3);
INSERT INTO 'dancesstepsmap' VALUES (17574, 13091, 2);
INSERT INTO 'dancesstepsmap' VALUES (17575, 13091, 1);
INSERT INTO 'dancesstepsmap' VALUES (17576, 13092, 1);
INSERT INTO 'dancesstepsmap' VALUES (17577, 13092, 2);
INSERT INTO 'dancesstepsmap' VALUES (17578, 13092, 3);
INSERT INTO 'dancesstepsmap' VALUES (17579, 13093, 1);
INSERT INTO 'dancesstepsmap' VALUES (17580, 13093, 2);
INSERT INTO 'dancesstepsmap' VALUES (17581, 13093, 3);
INSERT INTO 'dancesstepsmap' VALUES (17582, 13094, 1);
INSERT INTO 'dancesstepsmap' VALUES (17583, 13094, 2);
INSERT INTO 'dancesstepsmap' VALUES (17584, 13094, 3);
INSERT INTO 'dancesstepsmap' VALUES (17585, 13095, 4);
INSERT INTO 'dancesstepsmap' VALUES (17586, 13095, 5);
INSERT INTO 'dancesstepsmap' VALUES (17587, 13096, 4);
INSERT INTO 'dancesstepsmap' VALUES (17588, 13096, 5);
INSERT INTO 'dancesstepsmap' VALUES (17589, 13097, 1);
INSERT INTO 'dancesstepsmap' VALUES (17590, 13097, 2);
INSERT INTO 'dancesstepsmap' VALUES (17591, 13098, 1);
INSERT INTO 'dancesstepsmap' VALUES (17592, 13098, 2);
INSERT INTO 'dancesstepsmap' VALUES (17593, 13100, 4);
INSERT INTO 'dancesstepsmap' VALUES (17594, 13100, 5);
INSERT INTO 'dancesstepsmap' VALUES (17595, 13101, 1);
INSERT INTO 'dancesstepsmap' VALUES (17596, 13102, 1);
INSERT INTO 'dancesstepsmap' VALUES (17597, 13102, 2);
INSERT INTO 'dancesstepsmap' VALUES (17598, 4759, 5);
INSERT INTO 'dancesstepsmap' VALUES (17599, 14932, 1);
INSERT INTO 'dancesstepsmap' VALUES (17600, 14933, 4);
INSERT INTO 'dancesstepsmap' VALUES (17601, 14934, 1);
INSERT INTO 'dancesstepsmap' VALUES (17602, 14935, 1);
INSERT INTO 'dancesstepsmap' VALUES (17603, 14935, 3);
INSERT INTO 'dancesstepsmap' VALUES (17604, 14936, 1);
INSERT INTO 'dancesstepsmap' VALUES (17605, 14937, 4);
INSERT INTO 'dancesstepsmap' VALUES (17606, 14938, 1);
INSERT INTO 'dancesstepsmap' VALUES (17607, 14938, 2);
INSERT INTO 'dancesstepsmap' VALUES (17608, 14939, 1);
INSERT INTO 'dancesstepsmap' VALUES (17609, 14939, 4);
INSERT INTO 'dancesstepsmap' VALUES (17610, 13103, 1);
INSERT INTO 'dancesstepsmap' VALUES (17611, 12177, 10);
INSERT INTO 'dancesstepsmap' VALUES (17612, 392, 5);
INSERT INTO 'dancesstepsmap' VALUES (17613, 5100, 2);
INSERT INTO 'dancesstepsmap' VALUES (17614, 8782, 2);
INSERT INTO 'dancesstepsmap' VALUES (17615, 8782, 1);
INSERT INTO 'dancesstepsmap' VALUES (17616, 8782, 3);
INSERT INTO 'dancesstepsmap' VALUES (17617, 14940, 2);
INSERT INTO 'dancesstepsmap' VALUES (17618, 14940, 1);
INSERT INTO 'dancesstepsmap' VALUES (17619, 14940, 3);
INSERT INTO 'dancesstepsmap' VALUES (17620, 14940, 5);
INSERT INTO 'dancesstepsmap' VALUES (17621, 14940, 4);
INSERT INTO 'dancesstepsmap' VALUES (17622, 14940, 10);
INSERT INTO 'dancesstepsmap' VALUES (17623, 14941, 4);
INSERT INTO 'dancesstepsmap' VALUES (17624, 14941, 5);
INSERT INTO 'dancesstepsmap' VALUES (17625, 6756, 6);
INSERT INTO 'dancesstepsmap' VALUES (17626, 14611, 4);
INSERT INTO 'dancesstepsmap' VALUES (17627, 14611, 5);
INSERT INTO 'dancesstepsmap' VALUES (17628, 14610, 1);
INSERT INTO 'dancesstepsmap' VALUES (17629, 6057, 5);
INSERT INTO 'dancesstepsmap' VALUES (17630, 14942, 1);
INSERT INTO 'dancesstepsmap' VALUES (17631, 14942, 3);
INSERT INTO 'dancesstepsmap' VALUES (17632, 682, 5);
INSERT INTO 'dancesstepsmap' VALUES (17633, 6532, 3);
INSERT INTO 'dancesstepsmap' VALUES (17634, 14955, 5);
INSERT INTO 'dancesstepsmap' VALUES (17635, 14955, 4);
INSERT INTO 'dancesstepsmap' VALUES (17636, 14973, 5);
INSERT INTO 'dancesstepsmap' VALUES (17637, 14973, 4);
INSERT INTO 'dancesstepsmap' VALUES (17638, 14974, 5);
INSERT INTO 'dancesstepsmap' VALUES (17639, 14974, 4);
INSERT INTO 'dancesstepsmap' VALUES (17640, 14975, 1);
INSERT INTO 'dancesstepsmap' VALUES (17641, 14975, 2);
INSERT INTO 'dancesstepsmap' VALUES (17642, 14976, 5);
INSERT INTO 'dancesstepsmap' VALUES (17643, 14976, 4);
INSERT INTO 'dancesstepsmap' VALUES (17644, 14977, 1);
INSERT INTO 'dancesstepsmap' VALUES (17645, 14977, 2);
INSERT INTO 'dancesstepsmap' VALUES (17646, 3165, 2);
INSERT INTO 'dancesstepsmap' VALUES (17647, 14978, 5);
INSERT INTO 'dancesstepsmap' VALUES (17648, 14978, 4);
INSERT INTO 'dancesstepsmap' VALUES (17649, 14979, 1);
INSERT INTO 'dancesstepsmap' VALUES (17650, 14979, 2);
INSERT INTO 'dancesstepsmap' VALUES (17651, 14979, 3);
INSERT INTO 'dancesstepsmap' VALUES (17652, 14980, 5);
INSERT INTO 'dancesstepsmap' VALUES (17653, 14980, 4);
INSERT INTO 'dancesstepsmap' VALUES (17654, 14980, 1);
INSERT INTO 'dancesstepsmap' VALUES (17655, 14981, 4);
INSERT INTO 'dancesstepsmap' VALUES (17656, 14981, 5);
INSERT INTO 'dancesstepsmap' VALUES (17657, 14982, 1);
INSERT INTO 'dancesstepsmap' VALUES (17658, 14982, 3);
INSERT INTO 'dancesstepsmap' VALUES (17659, 14983, 5);
INSERT INTO 'dancesstepsmap' VALUES (17660, 14983, 4);
INSERT INTO 'dancesstepsmap' VALUES (17661, 14984, 1);
INSERT INTO 'dancesstepsmap' VALUES (17662, 14984, 3);
INSERT INTO 'dancesstepsmap' VALUES (17663, 13586, 4);
INSERT INTO 'dancesstepsmap' VALUES (17664, 11897, 2);
INSERT INTO 'dancesstepsmap' VALUES (17665, 14986, 1);
INSERT INTO 'dancesstepsmap' VALUES (17666, 14987, 5);
INSERT INTO 'dancesstepsmap' VALUES (17667, 14987, 4);
INSERT INTO 'dancesstepsmap' VALUES (17668, 14988, 4);
INSERT INTO 'dancesstepsmap' VALUES (17669, 14989, 5);
INSERT INTO 'dancesstepsmap' VALUES (17670, 14989, 4);
INSERT INTO 'dancesstepsmap' VALUES (23183, 4808, 2);
INSERT INTO 'dancesstepsmap' VALUES (23184, 18260, 1);
INSERT INTO 'dancesstepsmap' VALUES (17673, 14991, 1);
INSERT INTO 'dancesstepsmap' VALUES (17674, 14991, 3);
INSERT INTO 'dancesstepsmap' VALUES (17677, 14993, 2);
INSERT INTO 'dancesstepsmap' VALUES (17678, 14993, 1);
INSERT INTO 'dancesstepsmap' VALUES (17679, 14994, 5);
INSERT INTO 'dancesstepsmap' VALUES (17680, 14994, 4);
INSERT INTO 'dancesstepsmap' VALUES (17681, 1323, 5);
INSERT INTO 'dancesstepsmap' VALUES (17682, 2602, 5);
INSERT INTO 'dancesstepsmap' VALUES (17683, 15003, 1);
INSERT INTO 'dancesstepsmap' VALUES (17684, 15003, 2);
INSERT INTO 'dancesstepsmap' VALUES (17685, 11170, 5);
INSERT INTO 'dancesstepsmap' VALUES (17686, 15020, 1);
INSERT INTO 'dancesstepsmap' VALUES (17687, 15020, 2);
INSERT INTO 'dancesstepsmap' VALUES (16846, 14382, 1);
INSERT INTO 'dancesstepsmap' VALUES (17688, 15021, 2);
INSERT INTO 'dancesstepsmap' VALUES (17689, 15021, 1);
INSERT INTO 'dancesstepsmap' VALUES (17690, 14382, 2);
INSERT INTO 'dancesstepsmap' VALUES (17691, 15022, 1);
INSERT INTO 'dancesstepsmap' VALUES (17692, 15023, 4);
INSERT INTO 'dancesstepsmap' VALUES (17693, 14741, 5);
INSERT INTO 'dancesstepsmap' VALUES (17694, 14741, 4);
INSERT INTO 'dancesstepsmap' VALUES (17695, 15044, 1);
INSERT INTO 'dancesstepsmap' VALUES (17696, 15045, 1);
INSERT INTO 'dancesstepsmap' VALUES (17697, 15045, 2);
INSERT INTO 'dancesstepsmap' VALUES (17698, 15046, 4);
INSERT INTO 'dancesstepsmap' VALUES (17700, 15047, 2);
INSERT INTO 'dancesstepsmap' VALUES (17701, 15047, 1);
INSERT INTO 'dancesstepsmap' VALUES (17702, 15048, 4);
INSERT INTO 'dancesstepsmap' VALUES (17703, 15048, 5);
INSERT INTO 'dancesstepsmap' VALUES (17704, 15049, 1);
INSERT INTO 'dancesstepsmap' VALUES (17705, 15049, 2);
INSERT INTO 'dancesstepsmap' VALUES (23185, 18260, 2);
INSERT INTO 'dancesstepsmap' VALUES (17708, 15052, 1);
INSERT INTO 'dancesstepsmap' VALUES (17709, 15052, 2);
INSERT INTO 'dancesstepsmap' VALUES (17710, 15053, 1);
INSERT INTO 'dancesstepsmap' VALUES (17711, 15053, 3);
INSERT INTO 'dancesstepsmap' VALUES (17712, 15053, 2);
INSERT INTO 'dancesstepsmap' VALUES (17713, 15054, 5);
INSERT INTO 'dancesstepsmap' VALUES (17714, 15054, 4);
INSERT INTO 'dancesstepsmap' VALUES (17715, 15055, 1);
INSERT INTO 'dancesstepsmap' VALUES (17716, 15055, 2);
INSERT INTO 'dancesstepsmap' VALUES (17717, 15055, 5);
INSERT INTO 'dancesstepsmap' VALUES (17718, 15055, 4);
INSERT INTO 'dancesstepsmap' VALUES (17719, 15056, 4);
INSERT INTO 'dancesstepsmap' VALUES (17720, 15056, 5);
INSERT INTO 'dancesstepsmap' VALUES (17721, 15056, 9);
INSERT INTO 'dancesstepsmap' VALUES (17722, 15056, 1);
INSERT INTO 'dancesstepsmap' VALUES (17723, 15056, 2);
INSERT INTO 'dancesstepsmap' VALUES (17725, 15056, 3);
INSERT INTO 'dancesstepsmap' VALUES (17726, 15057, 4);
INSERT INTO 'dancesstepsmap' VALUES (17727, 15057, 5);
INSERT INTO 'dancesstepsmap' VALUES (17728, 50, 2);
INSERT INTO 'dancesstepsmap' VALUES (17729, 56, 2);
INSERT INTO 'dancesstepsmap' VALUES (17730, 77, 2);
INSERT INTO 'dancesstepsmap' VALUES (17731, 13629, 1);
INSERT INTO 'dancesstepsmap' VALUES (17732, 13629, 3);
INSERT INTO 'dancesstepsmap' VALUES (17733, 118, 5);
INSERT INTO 'dancesstepsmap' VALUES (17734, 14546, 5);
INSERT INTO 'dancesstepsmap' VALUES (17735, 14546, 4);
INSERT INTO 'dancesstepsmap' VALUES (17736, 5060, 5);
INSERT INTO 'dancesstepsmap' VALUES (17737, 15074, 1);
INSERT INTO 'dancesstepsmap' VALUES (17738, 15074, 3);
INSERT INTO 'dancesstepsmap' VALUES (17739, 15075, 4);
INSERT INTO 'dancesstepsmap' VALUES (17740, 15075, 5);
INSERT INTO 'dancesstepsmap' VALUES (17741, 15076, 1);
INSERT INTO 'dancesstepsmap' VALUES (17744, 15078, 1);
INSERT INTO 'dancesstepsmap' VALUES (17745, 15078, 2);
INSERT INTO 'dancesstepsmap' VALUES (17746, 15079, 1);
INSERT INTO 'dancesstepsmap' VALUES (17747, 15079, 2);
INSERT INTO 'dancesstepsmap' VALUES (17748, 15080, 4);
INSERT INTO 'dancesstepsmap' VALUES (17749, 15080, 5);
INSERT INTO 'dancesstepsmap' VALUES (17750, 15081, 4);
INSERT INTO 'dancesstepsmap' VALUES (17751, 15082, 2);
INSERT INTO 'dancesstepsmap' VALUES (17752, 15082, 1);
INSERT INTO 'dancesstepsmap' VALUES (17753, 15083, 4);
INSERT INTO 'dancesstepsmap' VALUES (17754, 15083, 5);
INSERT INTO 'dancesstepsmap' VALUES (17755, 15083, 6);
INSERT INTO 'dancesstepsmap' VALUES (17756, 15084, 5);
INSERT INTO 'dancesstepsmap' VALUES (17757, 15084, 4);
INSERT INTO 'dancesstepsmap' VALUES (17758, 15085, 2);
INSERT INTO 'dancesstepsmap' VALUES (17759, 15085, 1);
INSERT INTO 'dancesstepsmap' VALUES (17760, 15086, 5);
INSERT INTO 'dancesstepsmap' VALUES (17761, 15086, 4);
INSERT INTO 'dancesstepsmap' VALUES (17762, 15087, 5);
INSERT INTO 'dancesstepsmap' VALUES (17763, 15087, 4);
INSERT INTO 'dancesstepsmap' VALUES (17764, 15087, 1);
INSERT INTO 'dancesstepsmap' VALUES (17765, 15087, 2);
INSERT INTO 'dancesstepsmap' VALUES (17766, 15088, 5);
INSERT INTO 'dancesstepsmap' VALUES (17767, 15088, 4);
INSERT INTO 'dancesstepsmap' VALUES (17768, 15089, 2);
INSERT INTO 'dancesstepsmap' VALUES (17769, 15089, 1);
INSERT INTO 'dancesstepsmap' VALUES (17771, 15091, 4);
INSERT INTO 'dancesstepsmap' VALUES (17772, 15092, 5);
INSERT INTO 'dancesstepsmap' VALUES (17773, 15092, 4);
INSERT INTO 'dancesstepsmap' VALUES (17776, 15094, 4);
INSERT INTO 'dancesstepsmap' VALUES (17777, 15095, 5);
INSERT INTO 'dancesstepsmap' VALUES (17778, 15095, 4);
INSERT INTO 'dancesstepsmap' VALUES (17779, 15096, 1);
INSERT INTO 'dancesstepsmap' VALUES (17780, 15096, 3);
INSERT INTO 'dancesstepsmap' VALUES (17781, 15096, 2);
INSERT INTO 'dancesstepsmap' VALUES (17782, 15096, 5);
INSERT INTO 'dancesstepsmap' VALUES (17783, 15096, 4);
INSERT INTO 'dancesstepsmap' VALUES (17784, 2388, 2);
INSERT INTO 'dancesstepsmap' VALUES (17785, 15097, 1);
INSERT INTO 'dancesstepsmap' VALUES (17786, 15097, 3);
INSERT INTO 'dancesstepsmap' VALUES (17787, 10649, 1);
INSERT INTO 'dancesstepsmap' VALUES (17788, 7415, 5);
INSERT INTO 'dancesstepsmap' VALUES (17789, 498, 3);
INSERT INTO 'dancesstepsmap' VALUES (17790, 4925, 5);
INSERT INTO 'dancesstepsmap' VALUES (17742, 15077, 4);
INSERT INTO 'dancesstepsmap' VALUES (17743, 15077, 5);
INSERT INTO 'dancesstepsmap' VALUES (17791, 15098, 1);
INSERT INTO 'dancesstepsmap' VALUES (17792, 15098, 2);
INSERT INTO 'dancesstepsmap' VALUES (17793, 15098, 3);
INSERT INTO 'dancesstepsmap' VALUES (17794, 633, 10);
INSERT INTO 'dancesstepsmap' VALUES (17795, 14247, 5);
INSERT INTO 'dancesstepsmap' VALUES (17796, 14247, 4);
INSERT INTO 'dancesstepsmap' VALUES (17797, 373, 5);
INSERT INTO 'dancesstepsmap' VALUES (17798, 9583, 5);
INSERT INTO 'dancesstepsmap' VALUES (17799, 15125, 5);
INSERT INTO 'dancesstepsmap' VALUES (17800, 15125, 4);
INSERT INTO 'dancesstepsmap' VALUES (17801, 15126, 5);
INSERT INTO 'dancesstepsmap' VALUES (17802, 15126, 4);
INSERT INTO 'dancesstepsmap' VALUES (17803, 195, 5);
INSERT INTO 'dancesstepsmap' VALUES (17804, 195, 4);
INSERT INTO 'dancesstepsmap' VALUES (17805, 195, 6);
INSERT INTO 'dancesstepsmap' VALUES (17806, 195, 2);
INSERT INTO 'dancesstepsmap' VALUES (17807, 195, 1);
INSERT INTO 'dancesstepsmap' VALUES (17808, 11375, 2);
INSERT INTO 'dancesstepsmap' VALUES (17809, 6711, 2);
INSERT INTO 'dancesstepsmap' VALUES (17810, 6736, 2);
INSERT INTO 'dancesstepsmap' VALUES (17811, 183, 2);
INSERT INTO 'dancesstepsmap' VALUES (17812, 223, 2);
INSERT INTO 'dancesstepsmap' VALUES (17813, 611, 2);
INSERT INTO 'dancesstepsmap' VALUES (17814, 655, 2);
INSERT INTO 'dancesstepsmap' VALUES (17815, 773, 2);
INSERT INTO 'dancesstepsmap' VALUES (17816, 909, 2);
INSERT INTO 'dancesstepsmap' VALUES (17817, 1019, 2);
INSERT INTO 'dancesstepsmap' VALUES (17818, 1283, 2);
INSERT INTO 'dancesstepsmap' VALUES (17819, 1428, 2);
INSERT INTO 'dancesstepsmap' VALUES (17820, 10860, 4);
INSERT INTO 'dancesstepsmap' VALUES (17821, 10860, 1);
INSERT INTO 'dancesstepsmap' VALUES (17822, 9077, 4);
INSERT INTO 'dancesstepsmap' VALUES (17823, 9077, 1);
INSERT INTO 'dancesstepsmap' VALUES (17824, 8635, 4);
INSERT INTO 'dancesstepsmap' VALUES (17825, 12726, 4);
INSERT INTO 'dancesstepsmap' VALUES (17826, 11029, 4);
INSERT INTO 'dancesstepsmap' VALUES (17827, 11029, 1);
INSERT INTO 'dancesstepsmap' VALUES (17828, 9709, 4);
INSERT INTO 'dancesstepsmap' VALUES (17829, 12326, 4);
INSERT INTO 'dancesstepsmap' VALUES (17830, 11695, 4);
INSERT INTO 'dancesstepsmap' VALUES (17831, 11611, 1);
INSERT INTO 'dancesstepsmap' VALUES (17832, 15128, 5);
INSERT INTO 'dancesstepsmap' VALUES (17833, 15128, 4);
INSERT INTO 'dancesstepsmap' VALUES (17834, 12619, 1);
INSERT INTO 'dancesstepsmap' VALUES (17835, 10823, 1);
INSERT INTO 'dancesstepsmap' VALUES (17836, 10917, 1);
INSERT INTO 'dancesstepsmap' VALUES (17837, 12940, 1);
INSERT INTO 'dancesstepsmap' VALUES (17838, 9056, 1);
INSERT INTO 'dancesstepsmap' VALUES (17839, 10151, 1);
INSERT INTO 'dancesstepsmap' VALUES (17840, 116, 3);
INSERT INTO 'dancesstepsmap' VALUES (17841, 15129, 1);
INSERT INTO 'dancesstepsmap' VALUES (17842, 15129, 2);
INSERT INTO 'dancesstepsmap' VALUES (17843, 15130, 3);
INSERT INTO 'dancesstepsmap' VALUES (17844, 15130, 1);
INSERT INTO 'dancesstepsmap' VALUES (17845, 15131, 1);
INSERT INTO 'dancesstepsmap' VALUES (17846, 15132, 4);
INSERT INTO 'dancesstepsmap' VALUES (17847, 15132, 5);
INSERT INTO 'dancesstepsmap' VALUES (17848, 15133, 1);
INSERT INTO 'dancesstepsmap' VALUES (17849, 15134, 4);
INSERT INTO 'dancesstepsmap' VALUES (17850, 15134, 5);
INSERT INTO 'dancesstepsmap' VALUES (17851, 15135, 4);
INSERT INTO 'dancesstepsmap' VALUES (17852, 15135, 5);
INSERT INTO 'dancesstepsmap' VALUES (17853, 15136, 1);
INSERT INTO 'dancesstepsmap' VALUES (17854, 15136, 2);
INSERT INTO 'dancesstepsmap' VALUES (17855, 15137, 2);
INSERT INTO 'dancesstepsmap' VALUES (17856, 15137, 1);
INSERT INTO 'dancesstepsmap' VALUES (17857, 15137, 3);
INSERT INTO 'dancesstepsmap' VALUES (17858, 15138, 4);
INSERT INTO 'dancesstepsmap' VALUES (17859, 15138, 6);
INSERT INTO 'dancesstepsmap' VALUES (17860, 15140, 4);
INSERT INTO 'dancesstepsmap' VALUES (17861, 15140, 5);
INSERT INTO 'dancesstepsmap' VALUES (23231, 12254, 5);
INSERT INTO 'dancesstepsmap' VALUES (23244, 12095, 5);
INSERT INTO 'dancesstepsmap' VALUES (17864, 15142, 5);
INSERT INTO 'dancesstepsmap' VALUES (17865, 15142, 4);
INSERT INTO 'dancesstepsmap' VALUES (17866, 15143, 2);
INSERT INTO 'dancesstepsmap' VALUES (17867, 15143, 1);
INSERT INTO 'dancesstepsmap' VALUES (17868, 15144, 4);
INSERT INTO 'dancesstepsmap' VALUES (17869, 15144, 5);
INSERT INTO 'dancesstepsmap' VALUES (17870, 15145, 4);
INSERT INTO 'dancesstepsmap' VALUES (17871, 15145, 5);
INSERT INTO 'dancesstepsmap' VALUES (17872, 15145, 2);
INSERT INTO 'dancesstepsmap' VALUES (17873, 15145, 1);
INSERT INTO 'dancesstepsmap' VALUES (17874, 15146, 1);
INSERT INTO 'dancesstepsmap' VALUES (17875, 15146, 8);
INSERT INTO 'dancesstepsmap' VALUES (17876, 15147, 1);
INSERT INTO 'dancesstepsmap' VALUES (23251, 13896, 1);
INSERT INTO 'dancesstepsmap' VALUES (17724, 15056, 103);
INSERT INTO 'dancesstepsmap' VALUES (17877, 15147, 2);
INSERT INTO 'dancesstepsmap' VALUES (17878, 462, 5);
INSERT INTO 'dancesstepsmap' VALUES (17879, 9340, 1);
INSERT INTO 'dancesstepsmap' VALUES (17880, 745, 5);
INSERT INTO 'dancesstepsmap' VALUES (17881, 745, 6);
INSERT INTO 'dancesstepsmap' VALUES (17882, 1260, 6);
INSERT INTO 'dancesstepsmap' VALUES (17883, 14484, 1);
INSERT INTO 'dancesstepsmap' VALUES (17884, 14484, 2);
INSERT INTO 'dancesstepsmap' VALUES (17885, 14541, 1);
INSERT INTO 'dancesstepsmap' VALUES (17886, 14541, 2);
INSERT INTO 'dancesstepsmap' VALUES (23186, 18261, 1);
INSERT INTO 'dancesstepsmap' VALUES (23187, 18261, 2);
INSERT INTO 'dancesstepsmap' VALUES (17889, 209, 2);
INSERT INTO 'dancesstepsmap' VALUES (17890, 974, 5);
INSERT INTO 'dancesstepsmap' VALUES (17891, 1295, 5);
INSERT INTO 'dancesstepsmap' VALUES (17892, 1179, 5);
INSERT INTO 'dancesstepsmap' VALUES (17893, 5441, 5);
INSERT INTO 'dancesstepsmap' VALUES (17894, 5982, 5);
INSERT INTO 'dancesstepsmap' VALUES (17895, 1315, 5);
INSERT INTO 'dancesstepsmap' VALUES (17896, 5520, 5);
INSERT INTO 'dancesstepsmap' VALUES (17897, 749, 5);
INSERT INTO 'dancesstepsmap' VALUES (17898, 4857, 5);
INSERT INTO 'dancesstepsmap' VALUES (17899, 3934, 5);
INSERT INTO 'dancesstepsmap' VALUES (17900, 14818, 1);
INSERT INTO 'dancesstepsmap' VALUES (17901, 15148, 1);
INSERT INTO 'dancesstepsmap' VALUES (17902, 15148, 3);
INSERT INTO 'dancesstepsmap' VALUES (17903, 699, 2);
INSERT INTO 'dancesstepsmap' VALUES (17904, 15149, 1);
INSERT INTO 'dancesstepsmap' VALUES (17905, 15149, 2);
INSERT INTO 'dancesstepsmap' VALUES (17906, 15149, 3);
INSERT INTO 'dancesstepsmap' VALUES (23188, 18261, 3);
INSERT INTO 'dancesstepsmap' VALUES (23189, 17755, 1);
INSERT INTO 'dancesstepsmap' VALUES (17909, 15152, 1);
INSERT INTO 'dancesstepsmap' VALUES (17910, 15153, 1);
INSERT INTO 'dancesstepsmap' VALUES (17911, 15153, 3);
INSERT INTO 'dancesstepsmap' VALUES (17912, 15154, 1);
INSERT INTO 'dancesstepsmap' VALUES (17913, 15155, 1);
INSERT INTO 'dancesstepsmap' VALUES (17914, 15155, 2);
INSERT INTO 'dancesstepsmap' VALUES (17915, 15156, 2);
INSERT INTO 'dancesstepsmap' VALUES (17916, 15156, 1);
INSERT INTO 'dancesstepsmap' VALUES (23190, 17756, 5);
INSERT INTO 'dancesstepsmap' VALUES (23191, 17756, 4);
INSERT INTO 'dancesstepsmap' VALUES (17919, 15158, 4);
INSERT INTO 'dancesstepsmap' VALUES (17920, 15159, 4);
INSERT INTO 'dancesstepsmap' VALUES (17921, 15159, 5);
INSERT INTO 'dancesstepsmap' VALUES (17922, 15160, 4);
INSERT INTO 'dancesstepsmap' VALUES (17923, 15160, 5);
INSERT INTO 'dancesstepsmap' VALUES (17924, 15161, 1);
INSERT INTO 'dancesstepsmap' VALUES (17925, 15161, 2);
INSERT INTO 'dancesstepsmap' VALUES (17926, 15162, 4);
INSERT INTO 'dancesstepsmap' VALUES (17927, 15163, 1);
INSERT INTO 'dancesstepsmap' VALUES (17932, 15168, 1);
INSERT INTO 'dancesstepsmap' VALUES (17933, 15168, 2);
INSERT INTO 'dancesstepsmap' VALUES (17934, 15169, 1);
INSERT INTO 'dancesstepsmap' VALUES (17935, 15169, 2);
INSERT INTO 'dancesstepsmap' VALUES (17936, 15170, 1);
INSERT INTO 'dancesstepsmap' VALUES (17937, 15170, 2);
INSERT INTO 'dancesstepsmap' VALUES (17938, 15171, 1);
INSERT INTO 'dancesstepsmap' VALUES (17939, 15172, 4);
INSERT INTO 'dancesstepsmap' VALUES (17940, 15173, 4);
INSERT INTO 'dancesstepsmap' VALUES (17941, 15173, 5);
INSERT INTO 'dancesstepsmap' VALUES (17942, 15174, 5);
INSERT INTO 'dancesstepsmap' VALUES (17943, 15174, 4);
INSERT INTO 'dancesstepsmap' VALUES (17944, 15175, 4);
INSERT INTO 'dancesstepsmap' VALUES (17945, 15176, 4);
INSERT INTO 'dancesstepsmap' VALUES (17946, 15176, 1);
INSERT INTO 'dancesstepsmap' VALUES (17947, 15177, 1);
INSERT INTO 'dancesstepsmap' VALUES (17948, 15178, 5);
INSERT INTO 'dancesstepsmap' VALUES (17949, 15178, 4);
INSERT INTO 'dancesstepsmap' VALUES (17950, 15179, 2);
INSERT INTO 'dancesstepsmap' VALUES (17951, 15179, 1);
INSERT INTO 'dancesstepsmap' VALUES (17952, 15180, 1);
INSERT INTO 'dancesstepsmap' VALUES (17953, 15180, 2);
INSERT INTO 'dancesstepsmap' VALUES (17954, 15180, 3);
INSERT INTO 'dancesstepsmap' VALUES (17955, 3188, 2);
INSERT INTO 'dancesstepsmap' VALUES (17956, 5277, 5);
INSERT INTO 'dancesstepsmap' VALUES (17957, 3131, 2);
INSERT INTO 'dancesstepsmap' VALUES (17959, 5992, 5);
INSERT INTO 'dancesstepsmap' VALUES (17960, 694, 5);
INSERT INTO 'dancesstepsmap' VALUES (17961, 6774, 2);
INSERT INTO 'dancesstepsmap' VALUES (17962, 2056, 5);
INSERT INTO 'dancesstepsmap' VALUES (17963, 1946, 2);
INSERT INTO 'dancesstepsmap' VALUES (17964, 4975, 2);
INSERT INTO 'dancesstepsmap' VALUES (17965, 4750, 5);
INSERT INTO 'dancesstepsmap' VALUES (17966, 5373, 2);
INSERT INTO 'dancesstepsmap' VALUES (17967, 1743, 2);
INSERT INTO 'dancesstepsmap' VALUES (17968, 6, 3);
INSERT INTO 'dancesstepsmap' VALUES (17969, 2493, 4);
INSERT INTO 'dancesstepsmap' VALUES (17970, 2493, 5);
INSERT INTO 'dancesstepsmap' VALUES (17971, 2493, 1);
INSERT INTO 'dancesstepsmap' VALUES (17972, 2493, 2);
INSERT INTO 'dancesstepsmap' VALUES (17973, 2294, 2);
INSERT INTO 'dancesstepsmap' VALUES (17974, 13555, 1);
INSERT INTO 'dancesstepsmap' VALUES (17975, 13555, 3);
INSERT INTO 'dancesstepsmap' VALUES (17976, 13555, 2);
INSERT INTO 'dancesstepsmap' VALUES (17977, 2315, 5);
INSERT INTO 'dancesstepsmap' VALUES (17978, 5628, 2);
INSERT INTO 'dancesstepsmap' VALUES (17979, 6798, 3);
INSERT INTO 'dancesstepsmap' VALUES (17980, 6798, 2);
INSERT INTO 'dancesstepsmap' VALUES (17981, 7705, 5);
INSERT INTO 'dancesstepsmap' VALUES (17982, 3646, 5);
INSERT INTO 'dancesstepsmap' VALUES (17983, 12023, 2);
INSERT INTO 'dancesstepsmap' VALUES (17984, 4470, 5);
INSERT INTO 'dancesstepsmap' VALUES (17985, 3654, 5);
INSERT INTO 'dancesstepsmap' VALUES (17986, 6448, 3);
INSERT INTO 'dancesstepsmap' VALUES (17987, 287, 5);
INSERT INTO 'dancesstepsmap' VALUES (17988, 1704, 2);
INSERT INTO 'dancesstepsmap' VALUES (17989, 755, 5);
INSERT INTO 'dancesstepsmap' VALUES (17990, 4822, 2);
INSERT INTO 'dancesstepsmap' VALUES (17991, 2525, 5);
INSERT INTO 'dancesstepsmap' VALUES (17992, 4885, 5);
INSERT INTO 'dancesstepsmap' VALUES (17993, 6086, 2);
INSERT INTO 'dancesstepsmap' VALUES (17994, 1551, 5);
INSERT INTO 'dancesstepsmap' VALUES (17995, 4112, 2);
INSERT INTO 'dancesstepsmap' VALUES (17996, 4821, 5);
INSERT INTO 'dancesstepsmap' VALUES (17998, 6609, 2);
INSERT INTO 'dancesstepsmap' VALUES (17999, 5623, 2);
INSERT INTO 'dancesstepsmap' VALUES (18000, 4065, 2);
INSERT INTO 'dancesstepsmap' VALUES (18001, 1781, 2);
INSERT INTO 'dancesstepsmap' VALUES (18002, 5730, 5);
INSERT INTO 'dancesstepsmap' VALUES (18003, 1192, 2);
INSERT INTO 'dancesstepsmap' VALUES (18004, 7197, 2);
INSERT INTO 'dancesstepsmap' VALUES (18005, 10650, 1);
INSERT INTO 'dancesstepsmap' VALUES (18006, 10650, 2);
INSERT INTO 'dancesstepsmap' VALUES (18007, 10650, 3);
INSERT INTO 'dancesstepsmap' VALUES (18008, 975, 2);
INSERT INTO 'dancesstepsmap' VALUES (18009, 9381, 5);
INSERT INTO 'dancesstepsmap' VALUES (18010, 14295, 5);
INSERT INTO 'dancesstepsmap' VALUES (18011, 14295, 4);
INSERT INTO 'dancesstepsmap' VALUES (18012, 3866, 2);
INSERT INTO 'dancesstepsmap' VALUES (18013, 7362, 2);
INSERT INTO 'dancesstepsmap' VALUES (18014, 1100, 5);
INSERT INTO 'dancesstepsmap' VALUES (18015, 1100, 4);
INSERT INTO 'dancesstepsmap' VALUES (18016, 1100, 1);
INSERT INTO 'dancesstepsmap' VALUES (18017, 1100, 2);
INSERT INTO 'dancesstepsmap' VALUES (18018, 8569, 2);
INSERT INTO 'dancesstepsmap' VALUES (18019, 314, 5);
INSERT INTO 'dancesstepsmap' VALUES (18020, 15181, 1);
INSERT INTO 'dancesstepsmap' VALUES (18021, 15181, 3);
INSERT INTO 'dancesstepsmap' VALUES (18022, 15182, 3);
INSERT INTO 'dancesstepsmap' VALUES (18023, 15182, 1);
INSERT INTO 'dancesstepsmap' VALUES (18024, 15183, 1);
INSERT INTO 'dancesstepsmap' VALUES (18025, 15183, 3);
INSERT INTO 'dancesstepsmap' VALUES (18026, 15184, 1);
INSERT INTO 'dancesstepsmap' VALUES (18027, 15184, 3);
INSERT INTO 'dancesstepsmap' VALUES (18030, 15186, 1);
INSERT INTO 'dancesstepsmap' VALUES (18031, 15186, 3);
INSERT INTO 'dancesstepsmap' VALUES (18034, 15188, 1);
INSERT INTO 'dancesstepsmap' VALUES (18035, 15188, 3);
INSERT INTO 'dancesstepsmap' VALUES (18036, 15189, 3);
INSERT INTO 'dancesstepsmap' VALUES (18037, 15189, 1);
INSERT INTO 'dancesstepsmap' VALUES (18038, 15189, 2);
INSERT INTO 'dancesstepsmap' VALUES (18039, 14674, 1);
INSERT INTO 'dancesstepsmap' VALUES (18040, 14674, 2);
INSERT INTO 'dancesstepsmap' VALUES (18041, 14239, 3);
INSERT INTO 'dancesstepsmap' VALUES (18042, 14239, 1);
INSERT INTO 'dancesstepsmap' VALUES (18043, 14239, 2);
INSERT INTO 'dancesstepsmap' VALUES (18044, 15190, 1);
INSERT INTO 'dancesstepsmap' VALUES (18045, 15191, 1);
INSERT INTO 'dancesstepsmap' VALUES (18046, 15192, 1);
INSERT INTO 'dancesstepsmap' VALUES (18047, 15193, 1);
INSERT INTO 'dancesstepsmap' VALUES (18048, 15194, 1);
INSERT INTO 'dancesstepsmap' VALUES (18049, 15194, 3);
INSERT INTO 'dancesstepsmap' VALUES (18050, 15195, 1);
INSERT INTO 'dancesstepsmap' VALUES (18051, 13118, 8);
INSERT INTO 'dancesstepsmap' VALUES (18052, 13118, 2);
INSERT INTO 'dancesstepsmap' VALUES (18053, 15196, 1);
INSERT INTO 'dancesstepsmap' VALUES (18054, 15197, 1);
INSERT INTO 'dancesstepsmap' VALUES (18055, 15198, 1);
INSERT INTO 'dancesstepsmap' VALUES (18056, 15198, 2);
INSERT INTO 'dancesstepsmap' VALUES (18059, 15200, 1);
INSERT INTO 'dancesstepsmap' VALUES (18060, 15200, 2);
INSERT INTO 'dancesstepsmap' VALUES (18061, 15200, 3);
INSERT INTO 'dancesstepsmap' VALUES (18062, 13117, 2);
INSERT INTO 'dancesstepsmap' VALUES (18063, 15201, 2);
INSERT INTO 'dancesstepsmap' VALUES (18064, 15201, 1);
INSERT INTO 'dancesstepsmap' VALUES (18065, 15202, 1);
INSERT INTO 'dancesstepsmap' VALUES (18066, 15202, 2);
INSERT INTO 'dancesstepsmap' VALUES (18067, 15202, 8);
INSERT INTO 'dancesstepsmap' VALUES (18068, 15203, 1);
INSERT INTO 'dancesstepsmap' VALUES (18069, 15203, 2);
INSERT INTO 'dancesstepsmap' VALUES (18070, 9940, 2);
INSERT INTO 'dancesstepsmap' VALUES (18071, 9940, 1);
INSERT INTO 'dancesstepsmap' VALUES (18072, 8852, 1);
INSERT INTO 'dancesstepsmap' VALUES (18073, 8852, 2);
INSERT INTO 'dancesstepsmap' VALUES (18074, 9929, 1);
INSERT INTO 'dancesstepsmap' VALUES (18075, 9929, 2);
INSERT INTO 'dancesstepsmap' VALUES (18080, 324, 2);
INSERT INTO 'dancesstepsmap' VALUES (18082, 950, 2);
INSERT INTO 'dancesstepsmap' VALUES (18083, 1077, 5);
INSERT INTO 'dancesstepsmap' VALUES (18084, 2383, 2);
INSERT INTO 'dancesstepsmap' VALUES (18085, 15206, 1);
INSERT INTO 'dancesstepsmap' VALUES (18086, 15206, 2);
INSERT INTO 'dancesstepsmap' VALUES (18087, 15207, 1);
INSERT INTO 'dancesstepsmap' VALUES (18088, 15207, 3);
INSERT INTO 'dancesstepsmap' VALUES (18089, 15207, 2);
INSERT INTO 'dancesstepsmap' VALUES (18090, 15208, 1);
INSERT INTO 'dancesstepsmap' VALUES (18091, 15208, 2);
INSERT INTO 'dancesstepsmap' VALUES (18092, 15209, 1);
INSERT INTO 'dancesstepsmap' VALUES (18093, 15210, 1);
INSERT INTO 'dancesstepsmap' VALUES (18094, 15211, 1);
INSERT INTO 'dancesstepsmap' VALUES (18095, 15211, 2);
INSERT INTO 'dancesstepsmap' VALUES (18096, 15212, 1);
INSERT INTO 'dancesstepsmap' VALUES (18097, 15212, 2);
INSERT INTO 'dancesstepsmap' VALUES (18099, 15213, 2);
INSERT INTO 'dancesstepsmap' VALUES (18100, 15213, 1);
INSERT INTO 'dancesstepsmap' VALUES (18101, 15213, 3);
INSERT INTO 'dancesstepsmap' VALUES (18102, 15214, 2);
INSERT INTO 'dancesstepsmap' VALUES (18103, 15214, 1);
INSERT INTO 'dancesstepsmap' VALUES (18104, 15215, 1);
INSERT INTO 'dancesstepsmap' VALUES (18105, 15215, 2);
INSERT INTO 'dancesstepsmap' VALUES (18106, 15216, 3);
INSERT INTO 'dancesstepsmap' VALUES (18107, 15216, 2);
INSERT INTO 'dancesstepsmap' VALUES (18108, 15216, 1);
INSERT INTO 'dancesstepsmap' VALUES (18109, 15217, 1);
INSERT INTO 'dancesstepsmap' VALUES (18110, 15217, 2);
INSERT INTO 'dancesstepsmap' VALUES (18111, 15218, 1);
INSERT INTO 'dancesstepsmap' VALUES (18112, 15218, 2);
INSERT INTO 'dancesstepsmap' VALUES (18113, 3080, 5);
INSERT INTO 'dancesstepsmap' VALUES (18114, 3320, 2);
INSERT INTO 'dancesstepsmap' VALUES (18115, 3325, 5);
INSERT INTO 'dancesstepsmap' VALUES (18116, 4863, 2);
INSERT INTO 'dancesstepsmap' VALUES (18117, 11830, 2);
INSERT INTO 'dancesstepsmap' VALUES (18118, 4246, 2);
INSERT INTO 'dancesstepsmap' VALUES (18119, 4873, 2);
INSERT INTO 'dancesstepsmap' VALUES (18120, 7065, 2);
INSERT INTO 'dancesstepsmap' VALUES (18121, 14465, 1);
INSERT INTO 'dancesstepsmap' VALUES (18122, 6130, 8);
INSERT INTO 'dancesstepsmap' VALUES (18123, 3176, 2);
INSERT INTO 'dancesstepsmap' VALUES (18124, 3176, 3);
INSERT INTO 'dancesstepsmap' VALUES (18125, 5688, 2);
INSERT INTO 'dancesstepsmap' VALUES (18126, 6384, 5);
INSERT INTO 'dancesstepsmap' VALUES (18127, 4662, 5);
INSERT INTO 'dancesstepsmap' VALUES (18128, 3509, 2);
INSERT INTO 'dancesstepsmap' VALUES (18129, 3509, 3);
INSERT INTO 'dancesstepsmap' VALUES (18131, 2632, 5);
INSERT INTO 'dancesstepsmap' VALUES (18132, 3472, 5);
INSERT INTO 'dancesstepsmap' VALUES (18133, 14022, 5);
INSERT INTO 'dancesstepsmap' VALUES (18134, 14022, 4);
INSERT INTO 'dancesstepsmap' VALUES (18135, 7738, 2);
INSERT INTO 'dancesstepsmap' VALUES (18136, 5898, 5);
INSERT INTO 'dancesstepsmap' VALUES (18137, 15219, 5);
INSERT INTO 'dancesstepsmap' VALUES (18138, 15219, 4);
INSERT INTO 'dancesstepsmap' VALUES (18139, 908, 2);
INSERT INTO 'dancesstepsmap' VALUES (18140, 6250, 2);
INSERT INTO 'dancesstepsmap' VALUES (18141, 15220, 1);
INSERT INTO 'dancesstepsmap' VALUES (18142, 15220, 2);
INSERT INTO 'dancesstepsmap' VALUES (18143, 15221, 2);
INSERT INTO 'dancesstepsmap' VALUES (18144, 15221, 1);
INSERT INTO 'dancesstepsmap' VALUES (18145, 15222, 1);
INSERT INTO 'dancesstepsmap' VALUES (18146, 15222, 2);
INSERT INTO 'dancesstepsmap' VALUES (18147, 15223, 1);
INSERT INTO 'dancesstepsmap' VALUES (18148, 15224, 4);
INSERT INTO 'dancesstepsmap' VALUES (18149, 15224, 5);
INSERT INTO 'dancesstepsmap' VALUES (18150, 15225, 4);
INSERT INTO 'dancesstepsmap' VALUES (18151, 15225, 5);
INSERT INTO 'dancesstepsmap' VALUES (18152, 15226, 1);
INSERT INTO 'dancesstepsmap' VALUES (18153, 15226, 2);
INSERT INTO 'dancesstepsmap' VALUES (18154, 15227, 1);
INSERT INTO 'dancesstepsmap' VALUES (18155, 15228, 5);
INSERT INTO 'dancesstepsmap' VALUES (18156, 15228, 4);
INSERT INTO 'dancesstepsmap' VALUES (18157, 15228, 2);
INSERT INTO 'dancesstepsmap' VALUES (18158, 15228, 1);
INSERT INTO 'dancesstepsmap' VALUES (18159, 4209, 5);
INSERT INTO 'dancesstepsmap' VALUES (18160, 9160, 2);
INSERT INTO 'dancesstepsmap' VALUES (18163, 12368, 1);
INSERT INTO 'dancesstepsmap' VALUES (18164, 12368, 2);
INSERT INTO 'dancesstepsmap' VALUES (18165, 5830, 2);
INSERT INTO 'dancesstepsmap' VALUES (18166, 41, 2);
INSERT INTO 'dancesstepsmap' VALUES (18167, 41, 3);
INSERT INTO 'dancesstepsmap' VALUES (18168, 3561, 3);
INSERT INTO 'dancesstepsmap' VALUES (18169, 15229, 5);
INSERT INTO 'dancesstepsmap' VALUES (18170, 15229, 4);
INSERT INTO 'dancesstepsmap' VALUES (18171, 15230, 1);
INSERT INTO 'dancesstepsmap' VALUES (18172, 15230, 3);
INSERT INTO 'dancesstepsmap' VALUES (18173, 15231, 2);
INSERT INTO 'dancesstepsmap' VALUES (18174, 15231, 1);
INSERT INTO 'dancesstepsmap' VALUES (18175, 15231, 3);
INSERT INTO 'dancesstepsmap' VALUES (18176, 5921, 2);
INSERT INTO 'dancesstepsmap' VALUES (18177, 2125, 2);
INSERT INTO 'dancesstepsmap' VALUES (18178, 15248, 5);
INSERT INTO 'dancesstepsmap' VALUES (18179, 15248, 4);
INSERT INTO 'dancesstepsmap' VALUES (18180, 9109, 2);
INSERT INTO 'dancesstepsmap' VALUES (18181, 9109, 1);
INSERT INTO 'dancesstepsmap' VALUES (18182, 15263, 1);
INSERT INTO 'dancesstepsmap' VALUES (18183, 15263, 2);
INSERT INTO 'dancesstepsmap' VALUES (18184, 10926, 99);
INSERT INTO 'dancesstepsmap' VALUES (18185, 2168, 5);
INSERT INTO 'dancesstepsmap' VALUES (18186, 4931, 5);
INSERT INTO 'dancesstepsmap' VALUES (18187, 12893, 1);
INSERT INTO 'dancesstepsmap' VALUES (18188, 8203, 3);
INSERT INTO 'dancesstepsmap' VALUES (18191, 6451, 3);
INSERT INTO 'dancesstepsmap' VALUES (18192, 3770, 2);
INSERT INTO 'dancesstepsmap' VALUES (18193, 13585, 5);
INSERT INTO 'dancesstepsmap' VALUES (18194, 13585, 4);
INSERT INTO 'dancesstepsmap' VALUES (18197, 7548, 99);
INSERT INTO 'dancesstepsmap' VALUES (18198, 7548, 5);
INSERT INTO 'dancesstepsmap' VALUES (18199, 15265, 1);
INSERT INTO 'dancesstepsmap' VALUES (18200, 15265, 2);
INSERT INTO 'dancesstepsmap' VALUES (18201, 15266, 4);
INSERT INTO 'dancesstepsmap' VALUES (18202, 15266, 5);
INSERT INTO 'dancesstepsmap' VALUES (18203, 540, 2);
INSERT INTO 'dancesstepsmap' VALUES (18204, 1485, 5);
INSERT INTO 'dancesstepsmap' VALUES (18205, 15267, 4);
INSERT INTO 'dancesstepsmap' VALUES (18206, 15267, 5);
INSERT INTO 'dancesstepsmap' VALUES (18207, 2531, 2);
INSERT INTO 'dancesstepsmap' VALUES (18208, 15268, 1);
INSERT INTO 'dancesstepsmap' VALUES (18209, 15268, 2);
INSERT INTO 'dancesstepsmap' VALUES (18210, 15269, 5);
INSERT INTO 'dancesstepsmap' VALUES (18211, 15269, 4);
INSERT INTO 'dancesstepsmap' VALUES (18212, 15270, 5);
INSERT INTO 'dancesstepsmap' VALUES (18213, 15270, 4);
INSERT INTO 'dancesstepsmap' VALUES (18214, 5786, 5);
INSERT INTO 'dancesstepsmap' VALUES (18215, 5786, 6);
INSERT INTO 'dancesstepsmap' VALUES (18216, 15271, 4);
INSERT INTO 'dancesstepsmap' VALUES (18217, 15271, 5);
INSERT INTO 'dancesstepsmap' VALUES (18218, 15271, 1);
INSERT INTO 'dancesstepsmap' VALUES (18219, 15271, 3);
INSERT INTO 'dancesstepsmap' VALUES (18220, 15272, 1);
INSERT INTO 'dancesstepsmap' VALUES (18221, 13153, 5);
INSERT INTO 'dancesstepsmap' VALUES (18222, 7473, 5);
INSERT INTO 'dancesstepsmap' VALUES (18223, 15273, 1);
INSERT INTO 'dancesstepsmap' VALUES (18224, 15273, 2);
INSERT INTO 'dancesstepsmap' VALUES (18225, 15274, 5);
INSERT INTO 'dancesstepsmap' VALUES (18226, 15274, 4);
INSERT INTO 'dancesstepsmap' VALUES (18227, 15275, 1);
INSERT INTO 'dancesstepsmap' VALUES (18228, 15276, 3);
INSERT INTO 'dancesstepsmap' VALUES (18229, 15276, 2);
INSERT INTO 'dancesstepsmap' VALUES (18230, 15276, 1);
INSERT INTO 'dancesstepsmap' VALUES (18231, 15277, 4);
INSERT INTO 'dancesstepsmap' VALUES (18232, 15277, 5);
INSERT INTO 'dancesstepsmap' VALUES (18233, 15278, 1);
INSERT INTO 'dancesstepsmap' VALUES (18234, 15278, 3);
INSERT INTO 'dancesstepsmap' VALUES (18235, 15279, 1);
INSERT INTO 'dancesstepsmap' VALUES (18236, 15280, 2);
INSERT INTO 'dancesstepsmap' VALUES (18237, 15280, 1);
INSERT INTO 'dancesstepsmap' VALUES (18238, 15280, 3);
INSERT INTO 'dancesstepsmap' VALUES (18239, 15281, 4);
INSERT INTO 'dancesstepsmap' VALUES (18240, 15281, 5);
INSERT INTO 'dancesstepsmap' VALUES (18241, 15282, 2);
INSERT INTO 'dancesstepsmap' VALUES (18242, 15282, 1);
INSERT INTO 'dancesstepsmap' VALUES (18243, 15282, 3);
INSERT INTO 'dancesstepsmap' VALUES (18244, 15283, 2);
INSERT INTO 'dancesstepsmap' VALUES (18245, 15283, 1);
INSERT INTO 'dancesstepsmap' VALUES (18246, 15283, 3);
INSERT INTO 'dancesstepsmap' VALUES (18247, 15284, 1);
INSERT INTO 'dancesstepsmap' VALUES (18248, 15284, 2);
INSERT INTO 'dancesstepsmap' VALUES (18249, 15285, 1);
INSERT INTO 'dancesstepsmap' VALUES (18250, 15286, 1);
INSERT INTO 'dancesstepsmap' VALUES (18251, 15286, 2);
INSERT INTO 'dancesstepsmap' VALUES (18252, 3636, 2);
INSERT INTO 'dancesstepsmap' VALUES (18253, 6629, 3);
INSERT INTO 'dancesstepsmap' VALUES (18254, 6629, 2);
INSERT INTO 'dancesstepsmap' VALUES (18255, 3607, 5);
INSERT INTO 'dancesstepsmap' VALUES (18256, 12892, 2);
INSERT INTO 'dancesstepsmap' VALUES (18257, 9011, 4);
INSERT INTO 'dancesstepsmap' VALUES (18258, 9011, 5);
INSERT INTO 'dancesstepsmap' VALUES (18259, 15313, 4);
INSERT INTO 'dancesstepsmap' VALUES (18260, 15313, 5);
INSERT INTO 'dancesstepsmap' VALUES (18261, 15314, 5);
INSERT INTO 'dancesstepsmap' VALUES (18262, 15314, 4);
INSERT INTO 'dancesstepsmap' VALUES (18263, 14472, 1);
INSERT INTO 'dancesstepsmap' VALUES (18264, 14472, 2);
INSERT INTO 'dancesstepsmap' VALUES (18265, 15329, 3);
INSERT INTO 'dancesstepsmap' VALUES (18266, 15330, 2);
INSERT INTO 'dancesstepsmap' VALUES (18267, 15330, 1);
INSERT INTO 'dancesstepsmap' VALUES (18268, 15330, 3);
INSERT INTO 'dancesstepsmap' VALUES (18269, 3083, 2);
INSERT INTO 'dancesstepsmap' VALUES (18270, 161, 5);
INSERT INTO 'dancesstepsmap' VALUES (18271, 313, 3);
INSERT INTO 'dancesstepsmap' VALUES (18272, 11216, 2);
INSERT INTO 'dancesstepsmap' VALUES (18273, 15331, 1);
INSERT INTO 'dancesstepsmap' VALUES (18274, 15331, 2);
INSERT INTO 'dancesstepsmap' VALUES (18275, 15332, 4);
INSERT INTO 'dancesstepsmap' VALUES (18276, 9166, 2);
INSERT INTO 'dancesstepsmap' VALUES (18277, 14996, 1);
INSERT INTO 'dancesstepsmap' VALUES (18278, 14995, 4);
INSERT INTO 'dancesstepsmap' VALUES (18279, 14997, 1);
INSERT INTO 'dancesstepsmap' VALUES (18280, 14997, 2);
INSERT INTO 'dancesstepsmap' VALUES (18281, 14998, 2);
INSERT INTO 'dancesstepsmap' VALUES (18282, 14998, 1);
INSERT INTO 'dancesstepsmap' VALUES (18283, 14999, 5);
INSERT INTO 'dancesstepsmap' VALUES (18284, 14999, 4);
INSERT INTO 'dancesstepsmap' VALUES (18285, 15000, 4);
INSERT INTO 'dancesstepsmap' VALUES (18286, 15000, 5);
INSERT INTO 'dancesstepsmap' VALUES (18287, 15001, 3);
INSERT INTO 'dancesstepsmap' VALUES (18288, 15001, 1);
INSERT INTO 'dancesstepsmap' VALUES (18289, 15001, 2);
INSERT INTO 'dancesstepsmap' VALUES (18290, 15002, 2);
INSERT INTO 'dancesstepsmap' VALUES (18291, 15002, 1);
INSERT INTO 'dancesstepsmap' VALUES (18292, 15002, 3);
INSERT INTO 'dancesstepsmap' VALUES (18293, 15017, 2);
INSERT INTO 'dancesstepsmap' VALUES (18294, 15017, 1);
INSERT INTO 'dancesstepsmap' VALUES (18295, 15017, 3);
INSERT INTO 'dancesstepsmap' VALUES (18296, 15004, 5);
INSERT INTO 'dancesstepsmap' VALUES (18297, 15004, 4);
INSERT INTO 'dancesstepsmap' VALUES (18298, 15005, 3);
INSERT INTO 'dancesstepsmap' VALUES (18299, 15005, 1);
INSERT INTO 'dancesstepsmap' VALUES (18300, 15005, 2);
INSERT INTO 'dancesstepsmap' VALUES (18301, 15006, 1);
INSERT INTO 'dancesstepsmap' VALUES (18302, 15007, 1);
INSERT INTO 'dancesstepsmap' VALUES (18303, 15007, 2);
INSERT INTO 'dancesstepsmap' VALUES (18304, 15008, 5);
INSERT INTO 'dancesstepsmap' VALUES (18305, 15008, 4);
INSERT INTO 'dancesstepsmap' VALUES (18306, 15009, 1);
INSERT INTO 'dancesstepsmap' VALUES (18307, 15009, 2);
INSERT INTO 'dancesstepsmap' VALUES (18308, 15010, 4);
INSERT INTO 'dancesstepsmap' VALUES (18309, 15010, 5);
INSERT INTO 'dancesstepsmap' VALUES (18310, 15011, 5);
INSERT INTO 'dancesstepsmap' VALUES (18311, 15011, 4);
INSERT INTO 'dancesstepsmap' VALUES (18312, 15012, 4);
INSERT INTO 'dancesstepsmap' VALUES (18313, 15012, 5);
INSERT INTO 'dancesstepsmap' VALUES (18314, 15013, 1);
INSERT INTO 'dancesstepsmap' VALUES (18315, 15013, 2);
INSERT INTO 'dancesstepsmap' VALUES (18316, 15013, 3);
INSERT INTO 'dancesstepsmap' VALUES (18317, 15014, 2);
INSERT INTO 'dancesstepsmap' VALUES (18318, 15014, 1);
INSERT INTO 'dancesstepsmap' VALUES (18319, 15014, 3);
INSERT INTO 'dancesstepsmap' VALUES (18320, 15015, 4);
INSERT INTO 'dancesstepsmap' VALUES (18321, 15015, 2);
INSERT INTO 'dancesstepsmap' VALUES (18322, 15015, 3);
INSERT INTO 'dancesstepsmap' VALUES (18323, 15015, 1);
INSERT INTO 'dancesstepsmap' VALUES (18324, 15016, 1);
INSERT INTO 'dancesstepsmap' VALUES (18325, 3436, 5);
INSERT INTO 'dancesstepsmap' VALUES (18326, 2408, 2);
INSERT INTO 'dancesstepsmap' VALUES (18327, 4514, 5);
INSERT INTO 'dancesstepsmap' VALUES (18328, 7075, 2);
INSERT INTO 'dancesstepsmap' VALUES (18329, 4707, 2);
INSERT INTO 'dancesstepsmap' VALUES (18330, 1876, 5);
INSERT INTO 'dancesstepsmap' VALUES (18331, 4553, 2);
INSERT INTO 'dancesstepsmap' VALUES (18332, 4553, 3);
INSERT INTO 'dancesstepsmap' VALUES (18333, 11590, 3);
INSERT INTO 'dancesstepsmap' VALUES (18334, 15041, 1);
INSERT INTO 'dancesstepsmap' VALUES (18335, 15041, 2);
INSERT INTO 'dancesstepsmap' VALUES (18336, 6255, 2);
INSERT INTO 'dancesstepsmap' VALUES (18337, 6255, 3);
INSERT INTO 'dancesstepsmap' VALUES (18338, 9390, 2);
INSERT INTO 'dancesstepsmap' VALUES (18339, 15333, 1);
INSERT INTO 'dancesstepsmap' VALUES (18340, 5697, 2);
INSERT INTO 'dancesstepsmap' VALUES (18341, 1942, 99);
INSERT INTO 'dancesstepsmap' VALUES (18342, 1559, 5);
INSERT INTO 'dancesstepsmap' VALUES (18343, 13983, 5);
INSERT INTO 'dancesstepsmap' VALUES (18344, 13983, 4);
INSERT INTO 'dancesstepsmap' VALUES (18345, 9948, 2);
INSERT INTO 'dancesstepsmap' VALUES (18346, 9948, 1);
INSERT INTO 'dancesstepsmap' VALUES (18347, 14813, 1);
INSERT INTO 'dancesstepsmap' VALUES (18348, 14813, 2);
INSERT INTO 'dancesstepsmap' VALUES (18349, 15336, 1);
INSERT INTO 'dancesstepsmap' VALUES (18350, 15336, 2);
INSERT INTO 'dancesstepsmap' VALUES (18351, 15336, 3);
INSERT INTO 'dancesstepsmap' VALUES (18352, 15337, 5);
INSERT INTO 'dancesstepsmap' VALUES (18353, 15337, 4);
INSERT INTO 'dancesstepsmap' VALUES (18354, 15338, 4);
INSERT INTO 'dancesstepsmap' VALUES (18355, 15338, 5);
INSERT INTO 'dancesstepsmap' VALUES (18356, 10504, 5);
INSERT INTO 'dancesstepsmap' VALUES (18357, 11389, 2);
INSERT INTO 'dancesstepsmap' VALUES (18358, 11389, 3);
INSERT INTO 'dancesstepsmap' VALUES (18359, 13077, 2);
INSERT INTO 'dancesstepsmap' VALUES (18360, 9641, 1);
INSERT INTO 'dancesstepsmap' VALUES (18361, 9641, 2);
INSERT INTO 'dancesstepsmap' VALUES (18362, 9641, 3);
INSERT INTO 'dancesstepsmap' VALUES (18363, 15358, 1);
INSERT INTO 'dancesstepsmap' VALUES (18364, 8514, 2);
INSERT INTO 'dancesstepsmap' VALUES (18365, 2263, 2);
INSERT INTO 'dancesstepsmap' VALUES (18366, 13135, 5);
INSERT INTO 'dancesstepsmap' VALUES (18367, 13135, 4);
INSERT INTO 'dancesstepsmap' VALUES (18368, 13132, 2);
INSERT INTO 'dancesstepsmap' VALUES (18369, 13132, 1);
INSERT INTO 'dancesstepsmap' VALUES (18371, 13133, 5);
INSERT INTO 'dancesstepsmap' VALUES (18372, 13133, 4);
INSERT INTO 'dancesstepsmap' VALUES (18373, 13134, 1);
INSERT INTO 'dancesstepsmap' VALUES (18374, 13134, 2);
INSERT INTO 'dancesstepsmap' VALUES (18375, 679, 5);
INSERT INTO 'dancesstepsmap' VALUES (18376, 11398, 5);
INSERT INTO 'dancesstepsmap' VALUES (18377, 10088, 2);
INSERT INTO 'dancesstepsmap' VALUES (18378, 10088, 1);
INSERT INTO 'dancesstepsmap' VALUES (18379, 10088, 3);
INSERT INTO 'dancesstepsmap' VALUES (18380, 10080, 5);
INSERT INTO 'dancesstepsmap' VALUES (18381, 10080, 2);
INSERT INTO 'dancesstepsmap' VALUES (18382, 10080, 1);
INSERT INTO 'dancesstepsmap' VALUES (18383, 10081, 2);
INSERT INTO 'dancesstepsmap' VALUES (18384, 10081, 1);
INSERT INTO 'dancesstepsmap' VALUES (18385, 10081, 3);
INSERT INTO 'dancesstepsmap' VALUES (18386, 15374, 1);
INSERT INTO 'dancesstepsmap' VALUES (18387, 15374, 2);
INSERT INTO 'dancesstepsmap' VALUES (18388, 15375, 5);
INSERT INTO 'dancesstepsmap' VALUES (18389, 15375, 4);
INSERT INTO 'dancesstepsmap' VALUES (18390, 15376, 2);
INSERT INTO 'dancesstepsmap' VALUES (18391, 15376, 1);
INSERT INTO 'dancesstepsmap' VALUES (18392, 15377, 1);
INSERT INTO 'dancesstepsmap' VALUES (18393, 15377, 2);
INSERT INTO 'dancesstepsmap' VALUES (18394, 15361, 1);
INSERT INTO 'dancesstepsmap' VALUES (18395, 15361, 2);
INSERT INTO 'dancesstepsmap' VALUES (18396, 12517, 1);
INSERT INTO 'dancesstepsmap' VALUES (18397, 15362, 5);
INSERT INTO 'dancesstepsmap' VALUES (18398, 15362, 4);
INSERT INTO 'dancesstepsmap' VALUES (18399, 15363, 4);
INSERT INTO 'dancesstepsmap' VALUES (18400, 15363, 5);
INSERT INTO 'dancesstepsmap' VALUES (18401, 15364, 5);
INSERT INTO 'dancesstepsmap' VALUES (18402, 15364, 4);
INSERT INTO 'dancesstepsmap' VALUES (18403, 15365, 1);
INSERT INTO 'dancesstepsmap' VALUES (18404, 15365, 2);
INSERT INTO 'dancesstepsmap' VALUES (18405, 15365, 3);
INSERT INTO 'dancesstepsmap' VALUES (18406, 15366, 5);
INSERT INTO 'dancesstepsmap' VALUES (18407, 15366, 4);
INSERT INTO 'dancesstepsmap' VALUES (18408, 15367, 1);
INSERT INTO 'dancesstepsmap' VALUES (18409, 15378, 1);
INSERT INTO 'dancesstepsmap' VALUES (18410, 15378, 2);
INSERT INTO 'dancesstepsmap' VALUES (18411, 15368, 2);
INSERT INTO 'dancesstepsmap' VALUES (18412, 15368, 1);
INSERT INTO 'dancesstepsmap' VALUES (18413, 15368, 3);
INSERT INTO 'dancesstepsmap' VALUES (18414, 15370, 2);
INSERT INTO 'dancesstepsmap' VALUES (18415, 15370, 1);
INSERT INTO 'dancesstepsmap' VALUES (18416, 15371, 1);
INSERT INTO 'dancesstepsmap' VALUES (18417, 15371, 3);
INSERT INTO 'dancesstepsmap' VALUES (18418, 15372, 4);
INSERT INTO 'dancesstepsmap' VALUES (18419, 15372, 5);
INSERT INTO 'dancesstepsmap' VALUES (18420, 15379, 2);
INSERT INTO 'dancesstepsmap' VALUES (18421, 15379, 1);
INSERT INTO 'dancesstepsmap' VALUES (18422, 15380, 1);
INSERT INTO 'dancesstepsmap' VALUES (18423, 15380, 2);
INSERT INTO 'dancesstepsmap' VALUES (18424, 15381, 5);
INSERT INTO 'dancesstepsmap' VALUES (18425, 15381, 4);
INSERT INTO 'dancesstepsmap' VALUES (18426, 15382, 2);
INSERT INTO 'dancesstepsmap' VALUES (18427, 15382, 1);
INSERT INTO 'dancesstepsmap' VALUES (18428, 15383, 2);
INSERT INTO 'dancesstepsmap' VALUES (18429, 15383, 1);
INSERT INTO 'dancesstepsmap' VALUES (18430, 15384, 4);
INSERT INTO 'dancesstepsmap' VALUES (18431, 15384, 5);
INSERT INTO 'dancesstepsmap' VALUES (18432, 15385, 2);
INSERT INTO 'dancesstepsmap' VALUES (18433, 15385, 1);
INSERT INTO 'dancesstepsmap' VALUES (18434, 15386, 1);
INSERT INTO 'dancesstepsmap' VALUES (18435, 15386, 2);
INSERT INTO 'dancesstepsmap' VALUES (18436, 15387, 4);
INSERT INTO 'dancesstepsmap' VALUES (18437, 15387, 5);
INSERT INTO 'dancesstepsmap' VALUES (18439, 15389, 1);
INSERT INTO 'dancesstepsmap' VALUES (18440, 15390, 2);
INSERT INTO 'dancesstepsmap' VALUES (18441, 15390, 1);
INSERT INTO 'dancesstepsmap' VALUES (18442, 15391, 1);
INSERT INTO 'dancesstepsmap' VALUES (18443, 15391, 2);
INSERT INTO 'dancesstepsmap' VALUES (18444, 15392, 5);
INSERT INTO 'dancesstepsmap' VALUES (18445, 15392, 4);
INSERT INTO 'dancesstepsmap' VALUES (18446, 15393, 2);
INSERT INTO 'dancesstepsmap' VALUES (18447, 15393, 1);
INSERT INTO 'dancesstepsmap' VALUES (18448, 15394, 4);
INSERT INTO 'dancesstepsmap' VALUES (18449, 15394, 1);
INSERT INTO 'dancesstepsmap' VALUES (18450, 15395, 2);
INSERT INTO 'dancesstepsmap' VALUES (18451, 15395, 1);
INSERT INTO 'dancesstepsmap' VALUES (18452, 15395, 99);
INSERT INTO 'dancesstepsmap' VALUES (18453, 15396, 4);
INSERT INTO 'dancesstepsmap' VALUES (18454, 15396, 1);
INSERT INTO 'dancesstepsmap' VALUES (18455, 15396, 3);
INSERT INTO 'dancesstepsmap' VALUES (18456, 15397, 1);
INSERT INTO 'dancesstepsmap' VALUES (18457, 15397, 2);
INSERT INTO 'dancesstepsmap' VALUES (18458, 15373, 2);
INSERT INTO 'dancesstepsmap' VALUES (18459, 15373, 1);
INSERT INTO 'dancesstepsmap' VALUES (18460, 15373, 3);
INSERT INTO 'dancesstepsmap' VALUES (18461, 15398, 1);
INSERT INTO 'dancesstepsmap' VALUES (18462, 15398, 3);
INSERT INTO 'dancesstepsmap' VALUES (18463, 15399, 1);
INSERT INTO 'dancesstepsmap' VALUES (18464, 15399, 2);
INSERT INTO 'dancesstepsmap' VALUES (18465, 14014, 1);
INSERT INTO 'dancesstepsmap' VALUES (18466, 14014, 2);
INSERT INTO 'dancesstepsmap' VALUES (18467, 10069, 5);
INSERT INTO 'dancesstepsmap' VALUES (18468, 1749, 2);
INSERT INTO 'dancesstepsmap' VALUES (18469, 15400, 1);
INSERT INTO 'dancesstepsmap' VALUES (18470, 15400, 2);
INSERT INTO 'dancesstepsmap' VALUES (18471, 7162, 5);
INSERT INTO 'dancesstepsmap' VALUES (18472, 3265, 2);
INSERT INTO 'dancesstepsmap' VALUES (18473, 15401, 2);
INSERT INTO 'dancesstepsmap' VALUES (18474, 15401, 1);
INSERT INTO 'dancesstepsmap' VALUES (23192, 17758, 1);
INSERT INTO 'dancesstepsmap' VALUES (23193, 17758, 2);
INSERT INTO 'dancesstepsmap' VALUES (18477, 15403, 1);
INSERT INTO 'dancesstepsmap' VALUES (18478, 15403, 2);
INSERT INTO 'dancesstepsmap' VALUES (18479, 15404, 1);
INSERT INTO 'dancesstepsmap' VALUES (18480, 15404, 2);
INSERT INTO 'dancesstepsmap' VALUES (18481, 15405, 2);
INSERT INTO 'dancesstepsmap' VALUES (18482, 15405, 1);
INSERT INTO 'dancesstepsmap' VALUES (18485, 4749, 2);
INSERT INTO 'dancesstepsmap' VALUES (18486, 164, 5);
INSERT INTO 'dancesstepsmap' VALUES (18487, 3257, 3);
INSERT INTO 'dancesstepsmap' VALUES (18488, 15407, 1);
INSERT INTO 'dancesstepsmap' VALUES (18489, 15407, 2);
INSERT INTO 'dancesstepsmap' VALUES (18490, 6859, 5);
INSERT INTO 'dancesstepsmap' VALUES (18491, 4464, 2);
INSERT INTO 'dancesstepsmap' VALUES (18492, 1227, 2);
INSERT INTO 'dancesstepsmap' VALUES (18493, 5894, 2);
INSERT INTO 'dancesstepsmap' VALUES (18494, 2746, 2);
INSERT INTO 'dancesstepsmap' VALUES (18495, 3431, 2);
INSERT INTO 'dancesstepsmap' VALUES (18496, 5558, 2);
INSERT INTO 'dancesstepsmap' VALUES (18497, 367, 2);
INSERT INTO 'dancesstepsmap' VALUES (18498, 15395, 3);
INSERT INTO 'dancesstepsmap' VALUES (18499, 4920, 2);
INSERT INTO 'dancesstepsmap' VALUES (18500, 2927, 2);
INSERT INTO 'dancesstepsmap' VALUES (18501, 15359, 1);
INSERT INTO 'dancesstepsmap' VALUES (18502, 15359, 2);
INSERT INTO 'dancesstepsmap' VALUES (18503, 15359, 3);
INSERT INTO 'dancesstepsmap' VALUES (18504, 3323, 5);
INSERT INTO 'dancesstepsmap' VALUES (18505, 13934, 4);
INSERT INTO 'dancesstepsmap' VALUES (18506, 13934, 5);
INSERT INTO 'dancesstepsmap' VALUES (18507, 693, 2);
INSERT INTO 'dancesstepsmap' VALUES (18508, 10477, 2);
INSERT INTO 'dancesstepsmap' VALUES (18509, 10481, 5);
INSERT INTO 'dancesstepsmap' VALUES (18510, 10483, 6);
INSERT INTO 'dancesstepsmap' VALUES (18512, 15411, 5);
INSERT INTO 'dancesstepsmap' VALUES (18513, 15411, 4);
INSERT INTO 'dancesstepsmap' VALUES (18514, 15412, 1);
INSERT INTO 'dancesstepsmap' VALUES (18515, 816, 2);
INSERT INTO 'dancesstepsmap' VALUES (18516, 816, 3);
INSERT INTO 'dancesstepsmap' VALUES (18517, 12035, 2);
INSERT INTO 'dancesstepsmap' VALUES (18518, 12035, 1);
INSERT INTO 'dancesstepsmap' VALUES (18519, 12036, 5);
INSERT INTO 'dancesstepsmap' VALUES (18520, 12036, 4);
INSERT INTO 'dancesstepsmap' VALUES (18521, 12037, 2);
INSERT INTO 'dancesstepsmap' VALUES (18522, 12037, 1);
INSERT INTO 'dancesstepsmap' VALUES (18523, 12020, 4);
INSERT INTO 'dancesstepsmap' VALUES (18524, 12020, 1);
INSERT INTO 'dancesstepsmap' VALUES (18525, 12038, 2);
INSERT INTO 'dancesstepsmap' VALUES (18526, 12038, 1);
INSERT INTO 'dancesstepsmap' VALUES (18527, 12039, 2);
INSERT INTO 'dancesstepsmap' VALUES (18528, 12039, 1);
INSERT INTO 'dancesstepsmap' VALUES (18529, 12040, 4);
INSERT INTO 'dancesstepsmap' VALUES (18530, 12040, 5);
INSERT INTO 'dancesstepsmap' VALUES (18531, 9336, 2);
INSERT INTO 'dancesstepsmap' VALUES (18532, 12041, 5);
INSERT INTO 'dancesstepsmap' VALUES (18533, 12041, 4);
INSERT INTO 'dancesstepsmap' VALUES (18534, 12042, 1);
INSERT INTO 'dancesstepsmap' VALUES (18535, 12043, 1);
INSERT INTO 'dancesstepsmap' VALUES (18536, 12043, 3);
INSERT INTO 'dancesstepsmap' VALUES (18537, 12044, 1);
INSERT INTO 'dancesstepsmap' VALUES (18538, 12044, 3);
INSERT INTO 'dancesstepsmap' VALUES (18539, 12045, 1);
INSERT INTO 'dancesstepsmap' VALUES (18540, 12045, 2);
INSERT INTO 'dancesstepsmap' VALUES (18541, 12046, 4);
INSERT INTO 'dancesstepsmap' VALUES (18542, 12047, 2);
INSERT INTO 'dancesstepsmap' VALUES (18543, 12047, 1);
INSERT INTO 'dancesstepsmap' VALUES (18544, 12048, 4);
INSERT INTO 'dancesstepsmap' VALUES (18545, 12048, 2);
INSERT INTO 'dancesstepsmap' VALUES (18546, 12048, 1);
INSERT INTO 'dancesstepsmap' VALUES (18547, 12049, 1);
INSERT INTO 'dancesstepsmap' VALUES (18548, 12049, 2);
INSERT INTO 'dancesstepsmap' VALUES (18549, 12050, 4);
INSERT INTO 'dancesstepsmap' VALUES (18550, 12050, 5);
INSERT INTO 'dancesstepsmap' VALUES (18551, 12051, 2);
INSERT INTO 'dancesstepsmap' VALUES (18552, 12051, 1);
INSERT INTO 'dancesstepsmap' VALUES (18553, 12051, 3);
INSERT INTO 'dancesstepsmap' VALUES (18554, 10048, 2);
INSERT INTO 'dancesstepsmap' VALUES (18555, 10048, 1);
INSERT INTO 'dancesstepsmap' VALUES (18556, 10048, 3);
INSERT INTO 'dancesstepsmap' VALUES (18557, 15414, 1);
INSERT INTO 'dancesstepsmap' VALUES (18558, 15414, 3);
INSERT INTO 'dancesstepsmap' VALUES (18559, 15415, 4);
INSERT INTO 'dancesstepsmap' VALUES (18560, 15416, 5);
INSERT INTO 'dancesstepsmap' VALUES (18561, 15416, 4);
INSERT INTO 'dancesstepsmap' VALUES (18562, 15417, 5);
INSERT INTO 'dancesstepsmap' VALUES (18563, 15417, 4);
INSERT INTO 'dancesstepsmap' VALUES (18564, 15418, 1);
INSERT INTO 'dancesstepsmap' VALUES (18565, 15419, 5);
INSERT INTO 'dancesstepsmap' VALUES (18566, 15419, 4);
INSERT INTO 'dancesstepsmap' VALUES (18567, 15419, 2);
INSERT INTO 'dancesstepsmap' VALUES (18568, 15419, 1);
INSERT INTO 'dancesstepsmap' VALUES (18569, 15420, 5);
INSERT INTO 'dancesstepsmap' VALUES (18570, 15420, 4);
INSERT INTO 'dancesstepsmap' VALUES (18571, 14548, 2);
INSERT INTO 'dancesstepsmap' VALUES (18572, 14548, 1);
INSERT INTO 'dancesstepsmap' VALUES (18573, 14548, 3);
INSERT INTO 'dancesstepsmap' VALUES (18577, 15421, 1);
INSERT INTO 'dancesstepsmap' VALUES (18578, 15421, 3);
INSERT INTO 'dancesstepsmap' VALUES (18579, 15421, 2);
INSERT INTO 'dancesstepsmap' VALUES (18580, 6894, 2);
INSERT INTO 'dancesstepsmap' VALUES (18581, 15422, 1);
INSERT INTO 'dancesstepsmap' VALUES (18582, 15422, 2);
INSERT INTO 'dancesstepsmap' VALUES (18583, 15423, 5);
INSERT INTO 'dancesstepsmap' VALUES (18584, 15423, 4);
INSERT INTO 'dancesstepsmap' VALUES (18585, 15424, 5);
INSERT INTO 'dancesstepsmap' VALUES (18586, 15424, 4);
INSERT INTO 'dancesstepsmap' VALUES (18587, 15027, 1);
INSERT INTO 'dancesstepsmap' VALUES (18588, 15027, 3);
INSERT INTO 'dancesstepsmap' VALUES (18589, 15425, 1);
INSERT INTO 'dancesstepsmap' VALUES (18590, 15425, 2);
INSERT INTO 'dancesstepsmap' VALUES (18591, 15425, 3);
INSERT INTO 'dancesstepsmap' VALUES (18592, 2521, 2);
INSERT INTO 'dancesstepsmap' VALUES (18593, 5667, 5);
INSERT INTO 'dancesstepsmap' VALUES (18594, 5667, 4);
INSERT INTO 'dancesstepsmap' VALUES (18595, 5667, 2);
INSERT INTO 'dancesstepsmap' VALUES (18596, 5667, 1);
INSERT INTO 'dancesstepsmap' VALUES (18597, 5667, 3);
INSERT INTO 'dancesstepsmap' VALUES (18598, 949, 2);
INSERT INTO 'dancesstepsmap' VALUES (18599, 1242, 5);
INSERT INTO 'dancesstepsmap' VALUES (18600, 1293, 5);
INSERT INTO 'dancesstepsmap' VALUES (18601, 1848, 2);
INSERT INTO 'dancesstepsmap' VALUES (18602, 2110, 2);
INSERT INTO 'dancesstepsmap' VALUES (18603, 2289, 2);
INSERT INTO 'dancesstepsmap' VALUES (18604, 2607, 2);
INSERT INTO 'dancesstepsmap' VALUES (18605, 3240, 5);
INSERT INTO 'dancesstepsmap' VALUES (18606, 3885, 5);
INSERT INTO 'dancesstepsmap' VALUES (18607, 4939, 5);
INSERT INTO 'dancesstepsmap' VALUES (18608, 5054, 2);
INSERT INTO 'dancesstepsmap' VALUES (18609, 5129, 2);
INSERT INTO 'dancesstepsmap' VALUES (18610, 5139, 2);
INSERT INTO 'dancesstepsmap' VALUES (18611, 5139, 3);
INSERT INTO 'dancesstepsmap' VALUES (18612, 6080, 2);
INSERT INTO 'dancesstepsmap' VALUES (18613, 6461, 3);
INSERT INTO 'dancesstepsmap' VALUES (18614, 7041, 2);
INSERT INTO 'dancesstepsmap' VALUES (18615, 7041, 3);
INSERT INTO 'dancesstepsmap' VALUES (18616, 7230, 5);
INSERT INTO 'dancesstepsmap' VALUES (18617, 5215, 2);
INSERT INTO 'dancesstepsmap' VALUES (18618, 15426, 5);
INSERT INTO 'dancesstepsmap' VALUES (18619, 15426, 4);
INSERT INTO 'dancesstepsmap' VALUES (18620, 15426, 1);
INSERT INTO 'dancesstepsmap' VALUES (18621, 2437, 5);
INSERT INTO 'dancesstepsmap' VALUES (18622, 3974, 2);
INSERT INTO 'dancesstepsmap' VALUES (18623, 10588, 2);
INSERT INTO 'dancesstepsmap' VALUES (18624, 15427, 1);
INSERT INTO 'dancesstepsmap' VALUES (18625, 15427, 3);
INSERT INTO 'dancesstepsmap' VALUES (18626, 15428, 1);
INSERT INTO 'dancesstepsmap' VALUES (18627, 15428, 2);
INSERT INTO 'dancesstepsmap' VALUES (18628, 15430, 2);
INSERT INTO 'dancesstepsmap' VALUES (18629, 15430, 1);
INSERT INTO 'dancesstepsmap' VALUES (18630, 7043, 5);
INSERT INTO 'dancesstepsmap' VALUES (18631, 1635, 2);
INSERT INTO 'dancesstepsmap' VALUES (18632, 1177, 5);
INSERT INTO 'dancesstepsmap' VALUES (18633, 1291, 2);
INSERT INTO 'dancesstepsmap' VALUES (18634, 5120, 5);
INSERT INTO 'dancesstepsmap' VALUES (18635, 3315, 5);
INSERT INTO 'dancesstepsmap' VALUES (18636, 13, 5);
INSERT INTO 'dancesstepsmap' VALUES (18637, 7088, 2);
INSERT INTO 'dancesstepsmap' VALUES (18638, 5158, 5);
INSERT INTO 'dancesstepsmap' VALUES (18639, 1406, 5);
INSERT INTO 'dancesstepsmap' VALUES (18640, 7874, 2);
INSERT INTO 'dancesstepsmap' VALUES (18641, 15444, 4);
INSERT INTO 'dancesstepsmap' VALUES (18642, 15444, 5);
INSERT INTO 'dancesstepsmap' VALUES (18643, 15448, 1);
INSERT INTO 'dancesstepsmap' VALUES (18644, 15447, 4);
INSERT INTO 'dancesstepsmap' VALUES (18645, 15452, 2);
INSERT INTO 'dancesstepsmap' VALUES (18646, 15452, 1);
INSERT INTO 'dancesstepsmap' VALUES (18647, 15452, 3);
INSERT INTO 'dancesstepsmap' VALUES (18648, 15443, 2);
INSERT INTO 'dancesstepsmap' VALUES (18649, 15443, 1);
INSERT INTO 'dancesstepsmap' VALUES (18650, 15442, 2);
INSERT INTO 'dancesstepsmap' VALUES (18651, 15442, 1);
INSERT INTO 'dancesstepsmap' VALUES (18652, 15441, 4);
INSERT INTO 'dancesstepsmap' VALUES (18653, 15441, 5);
INSERT INTO 'dancesstepsmap' VALUES (18654, 15441, 6);
INSERT INTO 'dancesstepsmap' VALUES (18655, 15440, 2);
INSERT INTO 'dancesstepsmap' VALUES (18656, 15440, 1);
INSERT INTO 'dancesstepsmap' VALUES (18657, 15431, 1);
INSERT INTO 'dancesstepsmap' VALUES (18658, 15431, 2);
INSERT INTO 'dancesstepsmap' VALUES (18659, 15432, 5);
INSERT INTO 'dancesstepsmap' VALUES (18660, 15432, 4);
INSERT INTO 'dancesstepsmap' VALUES (18661, 15439, 1);
INSERT INTO 'dancesstepsmap' VALUES (18662, 15438, 5);
INSERT INTO 'dancesstepsmap' VALUES (18663, 15438, 4);
INSERT INTO 'dancesstepsmap' VALUES (18664, 15434, 2);
INSERT INTO 'dancesstepsmap' VALUES (18665, 15434, 1);
INSERT INTO 'dancesstepsmap' VALUES (18666, 15434, 3);
INSERT INTO 'dancesstepsmap' VALUES (18667, 15437, 1);
INSERT INTO 'dancesstepsmap' VALUES (18668, 15435, 4);
INSERT INTO 'dancesstepsmap' VALUES (18669, 15435, 5);
INSERT INTO 'dancesstepsmap' VALUES (18670, 15436, 1);
INSERT INTO 'dancesstepsmap' VALUES (18671, 15455, 1);
INSERT INTO 'dancesstepsmap' VALUES (18672, 15450, 1);
INSERT INTO 'dancesstepsmap' VALUES (18673, 15450, 2);
INSERT INTO 'dancesstepsmap' VALUES (18674, 15450, 3);
INSERT INTO 'dancesstepsmap' VALUES (18675, 801, 5);
INSERT INTO 'dancesstepsmap' VALUES (18676, 635, 2);
INSERT INTO 'dancesstepsmap' VALUES (18677, 202, 5);
INSERT INTO 'dancesstepsmap' VALUES (18678, 6813, 5);
INSERT INTO 'dancesstepsmap' VALUES (18679, 804, 5);
INSERT INTO 'dancesstepsmap' VALUES (18680, 360, 5);
INSERT INTO 'dancesstepsmap' VALUES (18681, 5759, 3);
INSERT INTO 'dancesstepsmap' VALUES (18682, 6627, 2);
INSERT INTO 'dancesstepsmap' VALUES (18683, 2476, 5);
INSERT INTO 'dancesstepsmap' VALUES (18684, 1969, 2);
INSERT INTO 'dancesstepsmap' VALUES (18685, 6811, 2);
INSERT INTO 'dancesstepsmap' VALUES (18686, 5357, 2);
INSERT INTO 'dancesstepsmap' VALUES (18687, 2592, 5);
INSERT INTO 'dancesstepsmap' VALUES (18688, 2135, 2);
INSERT INTO 'dancesstepsmap' VALUES (10301, 1725, 5);
INSERT INTO 'dancesstepsmap' VALUES (18689, 1725, 6);
INSERT INTO 'dancesstepsmap' VALUES (18690, 2814, 5);
INSERT INTO 'dancesstepsmap' VALUES (18691, 694, 9);
INSERT INTO 'dancesstepsmap' VALUES (18692, 15456, 1);
INSERT INTO 'dancesstepsmap' VALUES (18693, 15456, 2);
INSERT INTO 'dancesstepsmap' VALUES (18694, 5644, 5);
INSERT INTO 'dancesstepsmap' VALUES (18695, 5644, 6);
INSERT INTO 'dancesstepsmap' VALUES (18696, 3422, 2);
INSERT INTO 'dancesstepsmap' VALUES (18697, 5752, 3);
INSERT INTO 'dancesstepsmap' VALUES (18698, 867, 5);
INSERT INTO 'dancesstepsmap' VALUES (18699, 11720, 2);
INSERT INTO 'dancesstepsmap' VALUES (18700, 13638, 2);
INSERT INTO 'dancesstepsmap' VALUES (18701, 13638, 1);
INSERT INTO 'dancesstepsmap' VALUES (18702, 8410, 2);
INSERT INTO 'dancesstepsmap' VALUES (18703, 4086, 2);
INSERT INTO 'dancesstepsmap' VALUES (18704, 15457, 2);
INSERT INTO 'dancesstepsmap' VALUES (18705, 15457, 1);
INSERT INTO 'dancesstepsmap' VALUES (18708, 15459, 5);
INSERT INTO 'dancesstepsmap' VALUES (18709, 15459, 4);
INSERT INTO 'dancesstepsmap' VALUES (18711, 15460, 3);
INSERT INTO 'dancesstepsmap' VALUES (18710, 15460, 1);
INSERT INTO 'dancesstepsmap' VALUES (18712, 4424, 2);
INSERT INTO 'dancesstepsmap' VALUES (18713, 15470, 1);
INSERT INTO 'dancesstepsmap' VALUES (18714, 15470, 2);
INSERT INTO 'dancesstepsmap' VALUES (18715, 15472, 4);
INSERT INTO 'dancesstepsmap' VALUES (18716, 15472, 5);
INSERT INTO 'dancesstepsmap' VALUES (18717, 15478, 2);
INSERT INTO 'dancesstepsmap' VALUES (18718, 15478, 1);
INSERT INTO 'dancesstepsmap' VALUES (18719, 15478, 3);
INSERT INTO 'dancesstepsmap' VALUES (18720, 15479, 2);
INSERT INTO 'dancesstepsmap' VALUES (18721, 15479, 1);
INSERT INTO 'dancesstepsmap' VALUES (18722, 15480, 4);
INSERT INTO 'dancesstepsmap' VALUES (18723, 15480, 5);
INSERT INTO 'dancesstepsmap' VALUES (18724, 8987, 1);
INSERT INTO 'dancesstepsmap' VALUES (18725, 8987, 2);
INSERT INTO 'dancesstepsmap' VALUES (18726, 15494, 4);
INSERT INTO 'dancesstepsmap' VALUES (18727, 15494, 5);
INSERT INTO 'dancesstepsmap' VALUES (23194, 17759, 1);
INSERT INTO 'dancesstepsmap' VALUES (18730, 15526, 1);
INSERT INTO 'dancesstepsmap' VALUES (18731, 15526, 3);
INSERT INTO 'dancesstepsmap' VALUES (18732, 15526, 10);
INSERT INTO 'dancesstepsmap' VALUES (18733, 15527, 4);
INSERT INTO 'dancesstepsmap' VALUES (18734, 15527, 5);
INSERT INTO 'dancesstepsmap' VALUES (18735, 14183, 1);
INSERT INTO 'dancesstepsmap' VALUES (18736, 14183, 2);
INSERT INTO 'dancesstepsmap' VALUES (18737, 15538, 2);
INSERT INTO 'dancesstepsmap' VALUES (18738, 15538, 1);
INSERT INTO 'dancesstepsmap' VALUES (18739, 15538, 3);
INSERT INTO 'dancesstepsmap' VALUES (18740, 15539, 4);
INSERT INTO 'dancesstepsmap' VALUES (18741, 5696, 5);
INSERT INTO 'dancesstepsmap' VALUES (18742, 15540, 1);
INSERT INTO 'dancesstepsmap' VALUES (18743, 15540, 2);
INSERT INTO 'dancesstepsmap' VALUES (18744, 488, 2);
INSERT INTO 'dancesstepsmap' VALUES (18745, 1158, 5);
INSERT INTO 'dancesstepsmap' VALUES (15400, 13083, 2);
INSERT INTO 'dancesstepsmap' VALUES (18746, 15541, 4);
INSERT INTO 'dancesstepsmap' VALUES (18747, 15541, 5);
INSERT INTO 'dancesstepsmap' VALUES (18748, 15542, 1);
INSERT INTO 'dancesstepsmap' VALUES (18749, 15543, 4);
INSERT INTO 'dancesstepsmap' VALUES (18750, 15543, 5);
INSERT INTO 'dancesstepsmap' VALUES (18751, 15544, 1);
INSERT INTO 'dancesstepsmap' VALUES (18752, 15545, 4);
INSERT INTO 'dancesstepsmap' VALUES (18753, 15545, 5);
INSERT INTO 'dancesstepsmap' VALUES (18754, 15546, 5);
INSERT INTO 'dancesstepsmap' VALUES (18755, 15546, 4);
INSERT INTO 'dancesstepsmap' VALUES (18756, 15547, 1);
INSERT INTO 'dancesstepsmap' VALUES (18757, 15547, 2);
INSERT INTO 'dancesstepsmap' VALUES (18758, 15547, 10);
INSERT INTO 'dancesstepsmap' VALUES (18759, 15548, 1);
INSERT INTO 'dancesstepsmap' VALUES (18760, 15548, 2);
INSERT INTO 'dancesstepsmap' VALUES (18761, 15549, 1);
INSERT INTO 'dancesstepsmap' VALUES (18762, 15549, 2);
INSERT INTO 'dancesstepsmap' VALUES (18763, 15550, 1);
INSERT INTO 'dancesstepsmap' VALUES (18764, 15550, 10);
INSERT INTO 'dancesstepsmap' VALUES (18765, 15550, 3);
INSERT INTO 'dancesstepsmap' VALUES (18766, 15551, 3);
INSERT INTO 'dancesstepsmap' VALUES (18767, 15551, 10);
INSERT INTO 'dancesstepsmap' VALUES (18768, 15551, 1);
INSERT INTO 'dancesstepsmap' VALUES (18769, 15552, 5);
INSERT INTO 'dancesstepsmap' VALUES (18770, 15552, 4);
INSERT INTO 'dancesstepsmap' VALUES (18771, 15553, 4);
INSERT INTO 'dancesstepsmap' VALUES (18772, 15554, 1);
INSERT INTO 'dancesstepsmap' VALUES (18773, 15554, 3);
INSERT INTO 'dancesstepsmap' VALUES (18774, 15555, 3);
INSERT INTO 'dancesstepsmap' VALUES (18775, 15555, 2);
INSERT INTO 'dancesstepsmap' VALUES (18776, 15555, 8);
INSERT INTO 'dancesstepsmap' VALUES (18777, 15555, 1);
INSERT INTO 'dancesstepsmap' VALUES (18778, 15556, 2);
INSERT INTO 'dancesstepsmap' VALUES (18779, 15556, 8);
INSERT INTO 'dancesstepsmap' VALUES (18780, 15556, 1);
INSERT INTO 'dancesstepsmap' VALUES (18781, 15557, 4);
INSERT INTO 'dancesstepsmap' VALUES (18782, 15557, 5);
INSERT INTO 'dancesstepsmap' VALUES (18783, 15558, 1);
INSERT INTO 'dancesstepsmap' VALUES (18784, 15559, 2);
INSERT INTO 'dancesstepsmap' VALUES (18785, 15559, 1);
INSERT INTO 'dancesstepsmap' VALUES (18786, 15560, 1);
INSERT INTO 'dancesstepsmap' VALUES (18787, 15560, 2);
INSERT INTO 'dancesstepsmap' VALUES (18788, 15561, 4);
INSERT INTO 'dancesstepsmap' VALUES (18789, 15561, 5);
INSERT INTO 'dancesstepsmap' VALUES (18790, 15562, 4);
INSERT INTO 'dancesstepsmap' VALUES (18791, 15562, 5);
INSERT INTO 'dancesstepsmap' VALUES (18792, 15563, 2);
INSERT INTO 'dancesstepsmap' VALUES (18793, 15563, 1);
INSERT INTO 'dancesstepsmap' VALUES (18794, 15563, 3);
INSERT INTO 'dancesstepsmap' VALUES (18795, 15563, 8);
INSERT INTO 'dancesstepsmap' VALUES (18796, 8930, 2);
INSERT INTO 'dancesstepsmap' VALUES (18797, 5330, 2);
INSERT INTO 'dancesstepsmap' VALUES (18798, 13624, 2);
INSERT INTO 'dancesstepsmap' VALUES (18799, 13624, 1);
INSERT INTO 'dancesstepsmap' VALUES (18800, 13624, 3);
INSERT INTO 'dancesstepsmap' VALUES (18801, 15564, 1);
INSERT INTO 'dancesstepsmap' VALUES (18802, 15565, 1);
INSERT INTO 'dancesstepsmap' VALUES (18803, 15565, 2);
INSERT INTO 'dancesstepsmap' VALUES (18804, 15566, 5);
INSERT INTO 'dancesstepsmap' VALUES (18805, 15566, 4);
INSERT INTO 'dancesstepsmap' VALUES (18806, 15567, 1);
INSERT INTO 'dancesstepsmap' VALUES (18807, 15567, 2);
INSERT INTO 'dancesstepsmap' VALUES (18808, 15568, 1);
INSERT INTO 'dancesstepsmap' VALUES (18809, 15569, 1);
INSERT INTO 'dancesstepsmap' VALUES (18810, 15569, 3);
INSERT INTO 'dancesstepsmap' VALUES (18811, 15570, 4);
INSERT INTO 'dancesstepsmap' VALUES (18812, 15570, 5);
INSERT INTO 'dancesstepsmap' VALUES (18813, 15571, 1);
INSERT INTO 'dancesstepsmap' VALUES (18814, 15571, 2);
INSERT INTO 'dancesstepsmap' VALUES (18815, 15571, 3);
INSERT INTO 'dancesstepsmap' VALUES (18816, 15572, 1);
INSERT INTO 'dancesstepsmap' VALUES (18817, 15572, 2);
INSERT INTO 'dancesstepsmap' VALUES (18818, 15573, 4);
INSERT INTO 'dancesstepsmap' VALUES (18819, 15573, 5);
INSERT INTO 'dancesstepsmap' VALUES (18820, 15341, 4);
INSERT INTO 'dancesstepsmap' VALUES (18821, 15341, 5);
INSERT INTO 'dancesstepsmap' VALUES (18822, 15574, 1);
INSERT INTO 'dancesstepsmap' VALUES (18823, 15574, 2);
INSERT INTO 'dancesstepsmap' VALUES (18824, 8576, 5);
INSERT INTO 'dancesstepsmap' VALUES (18825, 1125, 2);
INSERT INTO 'dancesstepsmap' VALUES (18826, 2809, 2);
INSERT INTO 'dancesstepsmap' VALUES (18827, 1479, 8);
INSERT INTO 'dancesstepsmap' VALUES (18828, 15575, 1);
INSERT INTO 'dancesstepsmap' VALUES (18829, 15575, 2);
INSERT INTO 'dancesstepsmap' VALUES (18830, 15575, 3);
INSERT INTO 'dancesstepsmap' VALUES (18831, 15576, 5);
INSERT INTO 'dancesstepsmap' VALUES (18832, 15576, 4);
INSERT INTO 'dancesstepsmap' VALUES (18833, 15577, 1);
INSERT INTO 'dancesstepsmap' VALUES (18834, 15578, 5);
INSERT INTO 'dancesstepsmap' VALUES (18835, 15578, 4);
INSERT INTO 'dancesstepsmap' VALUES (18836, 15578, 1);
INSERT INTO 'dancesstepsmap' VALUES (18837, 15578, 2);
INSERT INTO 'dancesstepsmap' VALUES (18838, 15578, 3);
INSERT INTO 'dancesstepsmap' VALUES (18839, 15578, 8);
INSERT INTO 'dancesstepsmap' VALUES (18840, 15579, 1);
INSERT INTO 'dancesstepsmap' VALUES (18841, 15579, 2);
INSERT INTO 'dancesstepsmap' VALUES (18842, 15580, 5);
INSERT INTO 'dancesstepsmap' VALUES (18843, 15580, 4);
INSERT INTO 'dancesstepsmap' VALUES (18844, 15581, 5);
INSERT INTO 'dancesstepsmap' VALUES (18845, 15581, 4);
INSERT INTO 'dancesstepsmap' VALUES (18846, 15581, 6);
INSERT INTO 'dancesstepsmap' VALUES (18847, 15582, 1);
INSERT INTO 'dancesstepsmap' VALUES (18848, 15583, 5);
INSERT INTO 'dancesstepsmap' VALUES (18849, 15583, 4);
INSERT INTO 'dancesstepsmap' VALUES (18850, 15584, 2);
INSERT INTO 'dancesstepsmap' VALUES (18851, 15584, 1);
INSERT INTO 'dancesstepsmap' VALUES (18852, 13595, 1);
INSERT INTO 'dancesstepsmap' VALUES (18853, 15589, 4);
INSERT INTO 'dancesstepsmap' VALUES (18854, 10327, 1);
INSERT INTO 'dancesstepsmap' VALUES (18855, 10327, 3);
INSERT INTO 'dancesstepsmap' VALUES (18856, 15590, 1);
INSERT INTO 'dancesstepsmap' VALUES (18857, 15590, 4);
INSERT INTO 'dancesstepsmap' VALUES (18858, 15590, 5);
INSERT INTO 'dancesstepsmap' VALUES (18859, 15590, 2);
INSERT INTO 'dancesstepsmap' VALUES (18860, 15481, 1);
INSERT INTO 'dancesstepsmap' VALUES (18861, 15481, 2);
INSERT INTO 'dancesstepsmap' VALUES (18862, 15600, 2);
INSERT INTO 'dancesstepsmap' VALUES (18863, 15600, 1);
INSERT INTO 'dancesstepsmap' VALUES (18864, 15340, 1);
INSERT INTO 'dancesstepsmap' VALUES (18865, 15340, 2);
INSERT INTO 'dancesstepsmap' VALUES (18866, 15619, 2);
INSERT INTO 'dancesstepsmap' VALUES (18867, 15619, 1);
INSERT INTO 'dancesstepsmap' VALUES (18868, 15619, 8);
INSERT INTO 'dancesstepsmap' VALUES (18869, 15621, 1);
INSERT INTO 'dancesstepsmap' VALUES (18870, 15621, 2);
INSERT INTO 'dancesstepsmap' VALUES (18871, 15621, 3);
INSERT INTO 'dancesstepsmap' VALUES (18872, 15622, 2);
INSERT INTO 'dancesstepsmap' VALUES (18873, 15622, 1);
INSERT INTO 'dancesstepsmap' VALUES (18874, 15623, 2);
INSERT INTO 'dancesstepsmap' VALUES (18875, 15623, 1);
INSERT INTO 'dancesstepsmap' VALUES (18876, 5386, 2);
INSERT INTO 'dancesstepsmap' VALUES (18877, 12335, 4);
INSERT INTO 'dancesstepsmap' VALUES (18878, 7543, 2);
INSERT INTO 'dancesstepsmap' VALUES (18879, 2933, 2);
INSERT INTO 'dancesstepsmap' VALUES (18880, 15638, 5);
INSERT INTO 'dancesstepsmap' VALUES (18881, 15638, 4);
INSERT INTO 'dancesstepsmap' VALUES (18882, 15652, 4);
INSERT INTO 'dancesstepsmap' VALUES (18883, 15653, 1);
INSERT INTO 'dancesstepsmap' VALUES (18884, 15653, 3);
INSERT INTO 'dancesstepsmap' VALUES (18885, 15653, 2);
INSERT INTO 'dancesstepsmap' VALUES (18886, 15655, 5);
INSERT INTO 'dancesstepsmap' VALUES (18887, 15655, 4);
INSERT INTO 'dancesstepsmap' VALUES (18888, 15655, 1);
INSERT INTO 'dancesstepsmap' VALUES (18889, 15655, 2);
INSERT INTO 'dancesstepsmap' VALUES (18890, 15655, 3);
INSERT INTO 'dancesstepsmap' VALUES (18891, 10288, 8);
INSERT INTO 'dancesstepsmap' VALUES (18892, 14216, 5);
INSERT INTO 'dancesstepsmap' VALUES (18893, 14216, 4);
INSERT INTO 'dancesstepsmap' VALUES (18895, 15635, 2);
INSERT INTO 'dancesstepsmap' VALUES (18896, 15635, 1);
INSERT INTO 'dancesstepsmap' VALUES (18897, 10423, 2);
INSERT INTO 'dancesstepsmap' VALUES (18898, 15656, 5);
INSERT INTO 'dancesstepsmap' VALUES (18899, 15656, 4);
INSERT INTO 'dancesstepsmap' VALUES (18900, 15631, 5);
INSERT INTO 'dancesstepsmap' VALUES (18901, 15631, 4);
INSERT INTO 'dancesstepsmap' VALUES (18902, 15634, 2);
INSERT INTO 'dancesstepsmap' VALUES (18903, 15634, 1);
INSERT INTO 'dancesstepsmap' VALUES (18904, 15634, 3);
INSERT INTO 'dancesstepsmap' VALUES (18905, 15654, 1);
INSERT INTO 'dancesstepsmap' VALUES (18906, 15654, 2);
INSERT INTO 'dancesstepsmap' VALUES (18908, 5596, 3);
INSERT INTO 'dancesstepsmap' VALUES (18909, 15659, 4);
INSERT INTO 'dancesstepsmap' VALUES (18910, 15659, 5);
INSERT INTO 'dancesstepsmap' VALUES (18911, 6349, 5);
INSERT INTO 'dancesstepsmap' VALUES (18912, 2357, 5);
INSERT INTO 'dancesstepsmap' VALUES (18913, 2494, 4);
INSERT INTO 'dancesstepsmap' VALUES (18914, 2494, 1);
INSERT INTO 'dancesstepsmap' VALUES (18915, 8953, 4);
INSERT INTO 'dancesstepsmap' VALUES (18916, 13499, 5);
INSERT INTO 'dancesstepsmap' VALUES (18917, 13499, 4);
INSERT INTO 'dancesstepsmap' VALUES (18918, 15413, 5);
INSERT INTO 'dancesstepsmap' VALUES (18919, 15413, 4);
INSERT INTO 'dancesstepsmap' VALUES (18920, 13884, 2);
INSERT INTO 'dancesstepsmap' VALUES (18921, 13884, 1);
INSERT INTO 'dancesstepsmap' VALUES (18922, 13884, 3);
INSERT INTO 'dancesstepsmap' VALUES (18923, 12796, 1);
INSERT INTO 'dancesstepsmap' VALUES (18924, 15678, 1);
INSERT INTO 'dancesstepsmap' VALUES (18925, 15678, 2);
INSERT INTO 'dancesstepsmap' VALUES (18926, 6532, 8);
INSERT INTO 'dancesstepsmap' VALUES (18927, 6381, 2);
INSERT INTO 'dancesstepsmap' VALUES (18928, 13225, 2);
INSERT INTO 'dancesstepsmap' VALUES (18929, 13567, 5);
INSERT INTO 'dancesstepsmap' VALUES (18930, 13567, 4);
INSERT INTO 'dancesstepsmap' VALUES (18931, 645, 5);
INSERT INTO 'dancesstepsmap' VALUES (18932, 15684, 5);
INSERT INTO 'dancesstepsmap' VALUES (18933, 15684, 4);
INSERT INTO 'dancesstepsmap' VALUES (18934, 15685, 4);
INSERT INTO 'dancesstepsmap' VALUES (18935, 15686, 1);
INSERT INTO 'dancesstepsmap' VALUES (18936, 15686, 2);
INSERT INTO 'dancesstepsmap' VALUES (18937, 5797, 5);
INSERT INTO 'dancesstepsmap' VALUES (18939, 15697, 2);
INSERT INTO 'dancesstepsmap' VALUES (18940, 15697, 1);
INSERT INTO 'dancesstepsmap' VALUES (18941, 9287, 2);
INSERT INTO 'dancesstepsmap' VALUES (18907, 15658, 4);
INSERT INTO 'dancesstepsmap' VALUES (18942, 9287, 1);
INSERT INTO 'dancesstepsmap' VALUES (18943, 9287, 3);
INSERT INTO 'dancesstepsmap' VALUES (18944, 9288, 2);
INSERT INTO 'dancesstepsmap' VALUES (18945, 9288, 1);
INSERT INTO 'dancesstepsmap' VALUES (18946, 9288, 3);
INSERT INTO 'dancesstepsmap' VALUES (18947, 10693, 2);
INSERT INTO 'dancesstepsmap' VALUES (18948, 10693, 1);
INSERT INTO 'dancesstepsmap' VALUES (18949, 15698, 5);
INSERT INTO 'dancesstepsmap' VALUES (18950, 15698, 4);
INSERT INTO 'dancesstepsmap' VALUES (18951, 15701, 5);
INSERT INTO 'dancesstepsmap' VALUES (18952, 15701, 4);
INSERT INTO 'dancesstepsmap' VALUES (18953, 15701, 6);
INSERT INTO 'dancesstepsmap' VALUES (18954, 15702, 1);
INSERT INTO 'dancesstepsmap' VALUES (18955, 15702, 2);
INSERT INTO 'dancesstepsmap' VALUES (18956, 15703, 4);
INSERT INTO 'dancesstepsmap' VALUES (18957, 15703, 5);
INSERT INTO 'dancesstepsmap' VALUES (18958, 15704, 4);
INSERT INTO 'dancesstepsmap' VALUES (18959, 15704, 5);
INSERT INTO 'dancesstepsmap' VALUES (18960, 7316, 2);
INSERT INTO 'dancesstepsmap' VALUES (18961, 15705, 5);
INSERT INTO 'dancesstepsmap' VALUES (18962, 15705, 4);
INSERT INTO 'dancesstepsmap' VALUES (18963, 15706, 5);
INSERT INTO 'dancesstepsmap' VALUES (18964, 15706, 4);
INSERT INTO 'dancesstepsmap' VALUES (18966, 12089, 4);
INSERT INTO 'dancesstepsmap' VALUES (18967, 15707, 4);
INSERT INTO 'dancesstepsmap' VALUES (18968, 15707, 5);
INSERT INTO 'dancesstepsmap' VALUES (18969, 15708, 5);
INSERT INTO 'dancesstepsmap' VALUES (18970, 15708, 4);
INSERT INTO 'dancesstepsmap' VALUES (18971, 15709, 5);
INSERT INTO 'dancesstepsmap' VALUES (18972, 15709, 4);
INSERT INTO 'dancesstepsmap' VALUES (18973, 15709, 2);
INSERT INTO 'dancesstepsmap' VALUES (18974, 15709, 1);
INSERT INTO 'dancesstepsmap' VALUES (18975, 15710, 5);
INSERT INTO 'dancesstepsmap' VALUES (18976, 15710, 4);
INSERT INTO 'dancesstepsmap' VALUES (18977, 5842, 5);
INSERT INTO 'dancesstepsmap' VALUES (18978, 6709, 2);
INSERT INTO 'dancesstepsmap' VALUES (18979, 10962, 2);
INSERT INTO 'dancesstepsmap' VALUES (18980, 10962, 1);
INSERT INTO 'dancesstepsmap' VALUES (18981, 10962, 3);
INSERT INTO 'dancesstepsmap' VALUES (18982, 15323, 1);
INSERT INTO 'dancesstepsmap' VALUES (18983, 15323, 2);
INSERT INTO 'dancesstepsmap' VALUES (18984, 15713, 4);
INSERT INTO 'dancesstepsmap' VALUES (18985, 15713, 5);
INSERT INTO 'dancesstepsmap' VALUES (18986, 13429, 1);
INSERT INTO 'dancesstepsmap' VALUES (18987, 13429, 3);
INSERT INTO 'dancesstepsmap' VALUES (18988, 13435, 1);
INSERT INTO 'dancesstepsmap' VALUES (18989, 13435, 2);
INSERT INTO 'dancesstepsmap' VALUES (18990, 13435, 3);
INSERT INTO 'dancesstepsmap' VALUES (18991, 15714, 4);
INSERT INTO 'dancesstepsmap' VALUES (18992, 15714, 5);
INSERT INTO 'dancesstepsmap' VALUES (18993, 15715, 5);
INSERT INTO 'dancesstepsmap' VALUES (18994, 15715, 4);
INSERT INTO 'dancesstepsmap' VALUES (18995, 15716, 5);
INSERT INTO 'dancesstepsmap' VALUES (18996, 15716, 4);
INSERT INTO 'dancesstepsmap' VALUES (18997, 15717, 4);
INSERT INTO 'dancesstepsmap' VALUES (18998, 15717, 5);
INSERT INTO 'dancesstepsmap' VALUES (18999, 15718, 4);
INSERT INTO 'dancesstepsmap' VALUES (19000, 15719, 4);
INSERT INTO 'dancesstepsmap' VALUES (19001, 15719, 5);
INSERT INTO 'dancesstepsmap' VALUES (19002, 15720, 4);
INSERT INTO 'dancesstepsmap' VALUES (19003, 15720, 5);
INSERT INTO 'dancesstepsmap' VALUES (19004, 15721, 4);
INSERT INTO 'dancesstepsmap' VALUES (19005, 15721, 5);
INSERT INTO 'dancesstepsmap' VALUES (19006, 15722, 4);
INSERT INTO 'dancesstepsmap' VALUES (19007, 15722, 5);
INSERT INTO 'dancesstepsmap' VALUES (19008, 15723, 4);
INSERT INTO 'dancesstepsmap' VALUES (19009, 15723, 5);
INSERT INTO 'dancesstepsmap' VALUES (19010, 15724, 4);
INSERT INTO 'dancesstepsmap' VALUES (19011, 15725, 5);
INSERT INTO 'dancesstepsmap' VALUES (23230, 12254, 4);
INSERT INTO 'dancesstepsmap' VALUES (19012, 15725, 4);
INSERT INTO 'dancesstepsmap' VALUES (19013, 2947, 2);
INSERT INTO 'dancesstepsmap' VALUES (19016, 15727, 1);
INSERT INTO 'dancesstepsmap' VALUES (19017, 8264, 5);
INSERT INTO 'dancesstepsmap' VALUES (19018, 15728, 3);
INSERT INTO 'dancesstepsmap' VALUES (19019, 15728, 1);
INSERT INTO 'dancesstepsmap' VALUES (19020, 15728, 2);
INSERT INTO 'dancesstepsmap' VALUES (19021, 15729, 4);
INSERT INTO 'dancesstepsmap' VALUES (19022, 15729, 5);
INSERT INTO 'dancesstepsmap' VALUES (19023, 15730, 1);
INSERT INTO 'dancesstepsmap' VALUES (19024, 14680, 1);
INSERT INTO 'dancesstepsmap' VALUES (19025, 14680, 3);
INSERT INTO 'dancesstepsmap' VALUES (19026, 15731, 99);
INSERT INTO 'dancesstepsmap' VALUES (19027, 15733, 3);
INSERT INTO 'dancesstepsmap' VALUES (19028, 15733, 1);
INSERT INTO 'dancesstepsmap' VALUES (19029, 15733, 2);
INSERT INTO 'dancesstepsmap' VALUES (19030, 15732, 1);
INSERT INTO 'dancesstepsmap' VALUES (19031, 15734, 2);
INSERT INTO 'dancesstepsmap' VALUES (19032, 15734, 1);
INSERT INTO 'dancesstepsmap' VALUES (19033, 15735, 2);
INSERT INTO 'dancesstepsmap' VALUES (19034, 15735, 1);
INSERT INTO 'dancesstepsmap' VALUES (19035, 15735, 3);
INSERT INTO 'dancesstepsmap' VALUES (19036, 15736, 2);
INSERT INTO 'dancesstepsmap' VALUES (19037, 15736, 1);
INSERT INTO 'dancesstepsmap' VALUES (19038, 15736, 3);
INSERT INTO 'dancesstepsmap' VALUES (19039, 15737, 2);
INSERT INTO 'dancesstepsmap' VALUES (19040, 15737, 1);
INSERT INTO 'dancesstepsmap' VALUES (19041, 15738, 2);
INSERT INTO 'dancesstepsmap' VALUES (19042, 15738, 1);
INSERT INTO 'dancesstepsmap' VALUES (19043, 15739, 5);
INSERT INTO 'dancesstepsmap' VALUES (19044, 15739, 4);
INSERT INTO 'dancesstepsmap' VALUES (19045, 15740, 5);
INSERT INTO 'dancesstepsmap' VALUES (19046, 15740, 4);
INSERT INTO 'dancesstepsmap' VALUES (19047, 15741, 5);
INSERT INTO 'dancesstepsmap' VALUES (19048, 15741, 4);
INSERT INTO 'dancesstepsmap' VALUES (19049, 14740, 1);
INSERT INTO 'dancesstepsmap' VALUES (19050, 15742, 2);
INSERT INTO 'dancesstepsmap' VALUES (19051, 15742, 1);
INSERT INTO 'dancesstepsmap' VALUES (19052, 15742, 3);
INSERT INTO 'dancesstepsmap' VALUES (19053, 15743, 1);
INSERT INTO 'dancesstepsmap' VALUES (19054, 15743, 2);
INSERT INTO 'dancesstepsmap' VALUES (19055, 15743, 3);
INSERT INTO 'dancesstepsmap' VALUES (19056, 15744, 4);
INSERT INTO 'dancesstepsmap' VALUES (19057, 15744, 5);
INSERT INTO 'dancesstepsmap' VALUES (19058, 15744, 1);
INSERT INTO 'dancesstepsmap' VALUES (19059, 15745, 2);
INSERT INTO 'dancesstepsmap' VALUES (19060, 15745, 1);
INSERT INTO 'dancesstepsmap' VALUES (19061, 15746, 2);
INSERT INTO 'dancesstepsmap' VALUES (19062, 15746, 1);
INSERT INTO 'dancesstepsmap' VALUES (19063, 15747, 5);
INSERT INTO 'dancesstepsmap' VALUES (19064, 15747, 4);
INSERT INTO 'dancesstepsmap' VALUES (19065, 15748, 4);
INSERT INTO 'dancesstepsmap' VALUES (19066, 15748, 5);
INSERT INTO 'dancesstepsmap' VALUES (19067, 15749, 4);
INSERT INTO 'dancesstepsmap' VALUES (19068, 15749, 5);
INSERT INTO 'dancesstepsmap' VALUES (19069, 15750, 1);
INSERT INTO 'dancesstepsmap' VALUES (19070, 15751, 1);
INSERT INTO 'dancesstepsmap' VALUES (19071, 15751, 2);
INSERT INTO 'dancesstepsmap' VALUES (19072, 15752, 1);
INSERT INTO 'dancesstepsmap' VALUES (19073, 15752, 2);
INSERT INTO 'dancesstepsmap' VALUES (19074, 15753, 1);
INSERT INTO 'dancesstepsmap' VALUES (19075, 15753, 2);
INSERT INTO 'dancesstepsmap' VALUES (19076, 15754, 1);
INSERT INTO 'dancesstepsmap' VALUES (19077, 15754, 2);
INSERT INTO 'dancesstepsmap' VALUES (19078, 15755, 1);
INSERT INTO 'dancesstepsmap' VALUES (19079, 15755, 2);
INSERT INTO 'dancesstepsmap' VALUES (19080, 15756, 5);
INSERT INTO 'dancesstepsmap' VALUES (19081, 15756, 4);
INSERT INTO 'dancesstepsmap' VALUES (19082, 15757, 1);
INSERT INTO 'dancesstepsmap' VALUES (19083, 15757, 2);
INSERT INTO 'dancesstepsmap' VALUES (19084, 15758, 1);
INSERT INTO 'dancesstepsmap' VALUES (19085, 15758, 2);
INSERT INTO 'dancesstepsmap' VALUES (19086, 15759, 1);
INSERT INTO 'dancesstepsmap' VALUES (19087, 15759, 2);
INSERT INTO 'dancesstepsmap' VALUES (19088, 15760, 1);
INSERT INTO 'dancesstepsmap' VALUES (19089, 15760, 2);
INSERT INTO 'dancesstepsmap' VALUES (19090, 15761, 5);
INSERT INTO 'dancesstepsmap' VALUES (19091, 15761, 4);
INSERT INTO 'dancesstepsmap' VALUES (19092, 15762, 5);
INSERT INTO 'dancesstepsmap' VALUES (19093, 15762, 4);
INSERT INTO 'dancesstepsmap' VALUES (19094, 15763, 1);
INSERT INTO 'dancesstepsmap' VALUES (19095, 15763, 2);
INSERT INTO 'dancesstepsmap' VALUES (14826, 12729, 2);
INSERT INTO 'dancesstepsmap' VALUES (19098, 12729, 1);
INSERT INTO 'dancesstepsmap' VALUES (19103, 15767, 1);
INSERT INTO 'dancesstepsmap' VALUES (19104, 15767, 2);
INSERT INTO 'dancesstepsmap' VALUES (19105, 15768, 4);
INSERT INTO 'dancesstepsmap' VALUES (19106, 15768, 5);
INSERT INTO 'dancesstepsmap' VALUES (19107, 15769, 1);
INSERT INTO 'dancesstepsmap' VALUES (19108, 15769, 2);
INSERT INTO 'dancesstepsmap' VALUES (19109, 15769, 3);
INSERT INTO 'dancesstepsmap' VALUES (19110, 15770, 1);
INSERT INTO 'dancesstepsmap' VALUES (19111, 15771, 4);
INSERT INTO 'dancesstepsmap' VALUES (19112, 15771, 5);
INSERT INTO 'dancesstepsmap' VALUES (19113, 15772, 1);
INSERT INTO 'dancesstepsmap' VALUES (23195, 15321, 5);
INSERT INTO 'dancesstepsmap' VALUES (19115, 15773, 1);
INSERT INTO 'dancesstepsmap' VALUES (19119, 15775, 1);
INSERT INTO 'dancesstepsmap' VALUES (19120, 15775, 2);
INSERT INTO 'dancesstepsmap' VALUES (19123, 15777, 10);
INSERT INTO 'dancesstepsmap' VALUES (19124, 15781, 10);
INSERT INTO 'dancesstepsmap' VALUES (19125, 15781, 6);
INSERT INTO 'dancesstepsmap' VALUES (19126, 15783, 10);
INSERT INTO 'dancesstepsmap' VALUES (19127, 15763, 3);
INSERT INTO 'dancesstepsmap' VALUES (19128, 15784, 4);
INSERT INTO 'dancesstepsmap' VALUES (19129, 15784, 5);
INSERT INTO 'dancesstepsmap' VALUES (19130, 15785, 1);
INSERT INTO 'dancesstepsmap' VALUES (19131, 15785, 3);
INSERT INTO 'dancesstepsmap' VALUES (19133, 15787, 1);
INSERT INTO 'dancesstepsmap' VALUES (19134, 15787, 2);
INSERT INTO 'dancesstepsmap' VALUES (19135, 15788, 1);
INSERT INTO 'dancesstepsmap' VALUES (19136, 15788, 2);
INSERT INTO 'dancesstepsmap' VALUES (19137, 15789, 4);
INSERT INTO 'dancesstepsmap' VALUES (19138, 15789, 5);
INSERT INTO 'dancesstepsmap' VALUES (19139, 15790, 1);
INSERT INTO 'dancesstepsmap' VALUES (19140, 15790, 2);
INSERT INTO 'dancesstepsmap' VALUES (19141, 15791, 1);
INSERT INTO 'dancesstepsmap' VALUES (19142, 15791, 2);
INSERT INTO 'dancesstepsmap' VALUES (19143, 15791, 99);
INSERT INTO 'dancesstepsmap' VALUES (19144, 15792, 4);
INSERT INTO 'dancesstepsmap' VALUES (19145, 15792, 5);
INSERT INTO 'dancesstepsmap' VALUES (19146, 15793, 4);
INSERT INTO 'dancesstepsmap' VALUES (19147, 15794, 1);
INSERT INTO 'dancesstepsmap' VALUES (19148, 15794, 2);
INSERT INTO 'dancesstepsmap' VALUES (19149, 15795, 5);
INSERT INTO 'dancesstepsmap' VALUES (19150, 15795, 4);
INSERT INTO 'dancesstepsmap' VALUES (19151, 15796, 2);
INSERT INTO 'dancesstepsmap' VALUES (19152, 15796, 1);
INSERT INTO 'dancesstepsmap' VALUES (19153, 15797, 4);
INSERT INTO 'dancesstepsmap' VALUES (19154, 15798, 1);
INSERT INTO 'dancesstepsmap' VALUES (19155, 15799, 1);
INSERT INTO 'dancesstepsmap' VALUES (19156, 15799, 2);
INSERT INTO 'dancesstepsmap' VALUES (19157, 15799, 3);
INSERT INTO 'dancesstepsmap' VALUES (19158, 5122, 5);
INSERT INTO 'dancesstepsmap' VALUES (19159, 15800, 4);
INSERT INTO 'dancesstepsmap' VALUES (19160, 15801, 1);
INSERT INTO 'dancesstepsmap' VALUES (19161, 15801, 2);
INSERT INTO 'dancesstepsmap' VALUES (19162, 15802, 1);
INSERT INTO 'dancesstepsmap' VALUES (19163, 15802, 2);
INSERT INTO 'dancesstepsmap' VALUES (19164, 15802, 3);
INSERT INTO 'dancesstepsmap' VALUES (19165, 15803, 5);
INSERT INTO 'dancesstepsmap' VALUES (19166, 15803, 4);
INSERT INTO 'dancesstepsmap' VALUES (19167, 15804, 2);
INSERT INTO 'dancesstepsmap' VALUES (19168, 15804, 1);
INSERT INTO 'dancesstepsmap' VALUES (19171, 15806, 1);
INSERT INTO 'dancesstepsmap' VALUES (19172, 15807, 1);
INSERT INTO 'dancesstepsmap' VALUES (19173, 15807, 2);
INSERT INTO 'dancesstepsmap' VALUES (19174, 15808, 4);
INSERT INTO 'dancesstepsmap' VALUES (19175, 15808, 5);
INSERT INTO 'dancesstepsmap' VALUES (19176, 15809, 1);
INSERT INTO 'dancesstepsmap' VALUES (19177, 15810, 1);
INSERT INTO 'dancesstepsmap' VALUES (19178, 15810, 2);
INSERT INTO 'dancesstepsmap' VALUES (19179, 15811, 99);
INSERT INTO 'dancesstepsmap' VALUES (19180, 15812, 10);
INSERT INTO 'dancesstepsmap' VALUES (19181, 15814, 10);
INSERT INTO 'dancesstepsmap' VALUES (19182, 15815, 10);
INSERT INTO 'dancesstepsmap' VALUES (19183, 15816, 1);
INSERT INTO 'dancesstepsmap' VALUES (19184, 15816, 2);
INSERT INTO 'dancesstepsmap' VALUES (19185, 15816, 10);
INSERT INTO 'dancesstepsmap' VALUES (19186, 15817, 10);
INSERT INTO 'dancesstepsmap' VALUES (19187, 8750, 10);
INSERT INTO 'dancesstepsmap' VALUES (19188, 15819, 10);
INSERT INTO 'dancesstepsmap' VALUES (19189, 15820, 10);
INSERT INTO 'dancesstepsmap' VALUES (19190, 13351, 1);
INSERT INTO 'dancesstepsmap' VALUES (19191, 15822, 1);
INSERT INTO 'dancesstepsmap' VALUES (19192, 15822, 2);
INSERT INTO 'dancesstepsmap' VALUES (19193, 15822, 3);
INSERT INTO 'dancesstepsmap' VALUES (19194, 15823, 1);
INSERT INTO 'dancesstepsmap' VALUES (19195, 15823, 2);
INSERT INTO 'dancesstepsmap' VALUES (23090, 17469, 5);
INSERT INTO 'dancesstepsmap' VALUES (23232, 12347, 5);
INSERT INTO 'dancesstepsmap' VALUES (23233, 12347, 4);
INSERT INTO 'dancesstepsmap' VALUES (19199, 15825, 1);
INSERT INTO 'dancesstepsmap' VALUES (19200, 15825, 2);
INSERT INTO 'dancesstepsmap' VALUES (19201, 15826, 1);
INSERT INTO 'dancesstepsmap' VALUES (19202, 15827, 1);
INSERT INTO 'dancesstepsmap' VALUES (19203, 15827, 2);
INSERT INTO 'dancesstepsmap' VALUES (19204, 15827, 3);
INSERT INTO 'dancesstepsmap' VALUES (19205, 15828, 1);
INSERT INTO 'dancesstepsmap' VALUES (19206, 15828, 3);
INSERT INTO 'dancesstepsmap' VALUES (19207, 15829, 5);
INSERT INTO 'dancesstepsmap' VALUES (19208, 15829, 4);
INSERT INTO 'dancesstepsmap' VALUES (19209, 15830, 1);
INSERT INTO 'dancesstepsmap' VALUES (19210, 15830, 2);
INSERT INTO 'dancesstepsmap' VALUES (19211, 15830, 3);
INSERT INTO 'dancesstepsmap' VALUES (19212, 15831, 4);
INSERT INTO 'dancesstepsmap' VALUES (19213, 15831, 5);
INSERT INTO 'dancesstepsmap' VALUES (19214, 15832, 1);
INSERT INTO 'dancesstepsmap' VALUES (19215, 15832, 3);
INSERT INTO 'dancesstepsmap' VALUES (19216, 15833, 3);
INSERT INTO 'dancesstepsmap' VALUES (19217, 15833, 1);
INSERT INTO 'dancesstepsmap' VALUES (19218, 15834, 3);
INSERT INTO 'dancesstepsmap' VALUES (19219, 15834, 1);
INSERT INTO 'dancesstepsmap' VALUES (19220, 15834, 2);
INSERT INTO 'dancesstepsmap' VALUES (19221, 15835, 2);
INSERT INTO 'dancesstepsmap' VALUES (19222, 15835, 1);
INSERT INTO 'dancesstepsmap' VALUES (19223, 15836, 4);
INSERT INTO 'dancesstepsmap' VALUES (19224, 15836, 5);
INSERT INTO 'dancesstepsmap' VALUES (19225, 15836, 1);
INSERT INTO 'dancesstepsmap' VALUES (19226, 15836, 2);
INSERT INTO 'dancesstepsmap' VALUES (19227, 15836, 3);
INSERT INTO 'dancesstepsmap' VALUES (19228, 15837, 1);
INSERT INTO 'dancesstepsmap' VALUES (19229, 15838, 1);
INSERT INTO 'dancesstepsmap' VALUES (19230, 15838, 3);
INSERT INTO 'dancesstepsmap' VALUES (19231, 15839, 3);
INSERT INTO 'dancesstepsmap' VALUES (19232, 15839, 2);
INSERT INTO 'dancesstepsmap' VALUES (19233, 15839, 1);
INSERT INTO 'dancesstepsmap' VALUES (19234, 13458, 4);
INSERT INTO 'dancesstepsmap' VALUES (19235, 13458, 5);
INSERT INTO 'dancesstepsmap' VALUES (19236, 15840, 4);
INSERT INTO 'dancesstepsmap' VALUES (19237, 15840, 5);
INSERT INTO 'dancesstepsmap' VALUES (19238, 15841, 1);
INSERT INTO 'dancesstepsmap' VALUES (19239, 15841, 3);
INSERT INTO 'dancesstepsmap' VALUES (19240, 15842, 1);
INSERT INTO 'dancesstepsmap' VALUES (19241, 15843, 1);
INSERT INTO 'dancesstepsmap' VALUES (19242, 15843, 2);
INSERT INTO 'dancesstepsmap' VALUES (19243, 15843, 3);
INSERT INTO 'dancesstepsmap' VALUES (19244, 15844, 1);
INSERT INTO 'dancesstepsmap' VALUES (19245, 15844, 3);
INSERT INTO 'dancesstepsmap' VALUES (19246, 15844, 2);
INSERT INTO 'dancesstepsmap' VALUES (19247, 15845, 1);
INSERT INTO 'dancesstepsmap' VALUES (19248, 15845, 2);
INSERT INTO 'dancesstepsmap' VALUES (19249, 15845, 3);
INSERT INTO 'dancesstepsmap' VALUES (19250, 15846, 4);
INSERT INTO 'dancesstepsmap' VALUES (19169, 15805, 4);
INSERT INTO 'dancesstepsmap' VALUES (19116, 15774, 4);
INSERT INTO 'dancesstepsmap' VALUES (19117, 15774, 5);
INSERT INTO 'dancesstepsmap' VALUES (19096, 15764, 1);
INSERT INTO 'dancesstepsmap' VALUES (19097, 15764, 3);
INSERT INTO 'dancesstepsmap' VALUES (19101, 15766, 1);
INSERT INTO 'dancesstepsmap' VALUES (19102, 15766, 2);
INSERT INTO 'dancesstepsmap' VALUES (19121, 15776, 1);
INSERT INTO 'dancesstepsmap' VALUES (19122, 15776, 2);
INSERT INTO 'dancesstepsmap' VALUES (19099, 15765, 2);
INSERT INTO 'dancesstepsmap' VALUES (19100, 15765, 1);
INSERT INTO 'dancesstepsmap' VALUES (19251, 15846, 5);
INSERT INTO 'dancesstepsmap' VALUES (19252, 15847, 4);
INSERT INTO 'dancesstepsmap' VALUES (19253, 15847, 5);
INSERT INTO 'dancesstepsmap' VALUES (19254, 12228, 1);
INSERT INTO 'dancesstepsmap' VALUES (19255, 7715, 5);
INSERT INTO 'dancesstepsmap' VALUES (19256, 12206, 4);
INSERT INTO 'dancesstepsmap' VALUES (19257, 12206, 5);
INSERT INTO 'dancesstepsmap' VALUES (19258, 15849, 1);
INSERT INTO 'dancesstepsmap' VALUES (19259, 15849, 2);
INSERT INTO 'dancesstepsmap' VALUES (19260, 15850, 4);
INSERT INTO 'dancesstepsmap' VALUES (19261, 15851, 1);
INSERT INTO 'dancesstepsmap' VALUES (19262, 15851, 2);
INSERT INTO 'dancesstepsmap' VALUES (19263, 15852, 1);
INSERT INTO 'dancesstepsmap' VALUES (19264, 15853, 99);
INSERT INTO 'dancesstepsmap' VALUES (19265, 15854, 1);
INSERT INTO 'dancesstepsmap' VALUES (19266, 15854, 2);
INSERT INTO 'dancesstepsmap' VALUES (19267, 15856, 2);
INSERT INTO 'dancesstepsmap' VALUES (19268, 15856, 1);
INSERT INTO 'dancesstepsmap' VALUES (19269, 15856, 3);
INSERT INTO 'dancesstepsmap' VALUES (19270, 15857, 3);
INSERT INTO 'dancesstepsmap' VALUES (19271, 15857, 1);
INSERT INTO 'dancesstepsmap' VALUES (19272, 15858, 5);
INSERT INTO 'dancesstepsmap' VALUES (19273, 15858, 4);
INSERT INTO 'dancesstepsmap' VALUES (19274, 15859, 1);
INSERT INTO 'dancesstepsmap' VALUES (19275, 15859, 2);
INSERT INTO 'dancesstepsmap' VALUES (19276, 15860, 1);
INSERT INTO 'dancesstepsmap' VALUES (19277, 15861, 5);
INSERT INTO 'dancesstepsmap' VALUES (19278, 15861, 4);
INSERT INTO 'dancesstepsmap' VALUES (19279, 15862, 5);
INSERT INTO 'dancesstepsmap' VALUES (19280, 15862, 4);
INSERT INTO 'dancesstepsmap' VALUES (19281, 15863, 1);
INSERT INTO 'dancesstepsmap' VALUES (19282, 15586, 1);
INSERT INTO 'dancesstepsmap' VALUES (19283, 15864, 1);
INSERT INTO 'dancesstepsmap' VALUES (19284, 15864, 2);
INSERT INTO 'dancesstepsmap' VALUES (19285, 15865, 1);
INSERT INTO 'dancesstepsmap' VALUES (19286, 15865, 2);
INSERT INTO 'dancesstepsmap' VALUES (19287, 15866, 4);
INSERT INTO 'dancesstepsmap' VALUES (19288, 15866, 5);
INSERT INTO 'dancesstepsmap' VALUES (19289, 15867, 1);
INSERT INTO 'dancesstepsmap' VALUES (19290, 15867, 2);
INSERT INTO 'dancesstepsmap' VALUES (19291, 15868, 5);
INSERT INTO 'dancesstepsmap' VALUES (19292, 15868, 4);
INSERT INTO 'dancesstepsmap' VALUES (19293, 15869, 4);
INSERT INTO 'dancesstepsmap' VALUES (19294, 15869, 5);
INSERT INTO 'dancesstepsmap' VALUES (19295, 15870, 5);
INSERT INTO 'dancesstepsmap' VALUES (19296, 15870, 4);
INSERT INTO 'dancesstepsmap' VALUES (19297, 15871, 1);
INSERT INTO 'dancesstepsmap' VALUES (19298, 15872, 2);
INSERT INTO 'dancesstepsmap' VALUES (19299, 15872, 1);
INSERT INTO 'dancesstepsmap' VALUES (19300, 15873, 5);
INSERT INTO 'dancesstepsmap' VALUES (19301, 15873, 4);
INSERT INTO 'dancesstepsmap' VALUES (19302, 15874, 1);
INSERT INTO 'dancesstepsmap' VALUES (19303, 15875, 1);
INSERT INTO 'dancesstepsmap' VALUES (19304, 15875, 2);
INSERT INTO 'dancesstepsmap' VALUES (19305, 15876, 2);
INSERT INTO 'dancesstepsmap' VALUES (19306, 15876, 1);
INSERT INTO 'dancesstepsmap' VALUES (19307, 15877, 4);
INSERT INTO 'dancesstepsmap' VALUES (19308, 15877, 5);
INSERT INTO 'dancesstepsmap' VALUES (19309, 15878, 2);
INSERT INTO 'dancesstepsmap' VALUES (19310, 15878, 1);
INSERT INTO 'dancesstepsmap' VALUES (19311, 15879, 1);
INSERT INTO 'dancesstepsmap' VALUES (19312, 15879, 2);
INSERT INTO 'dancesstepsmap' VALUES (19315, 15881, 2);
INSERT INTO 'dancesstepsmap' VALUES (19316, 15881, 1);
INSERT INTO 'dancesstepsmap' VALUES (19317, 15882, 4);
INSERT INTO 'dancesstepsmap' VALUES (19318, 15882, 5);
INSERT INTO 'dancesstepsmap' VALUES (19319, 15883, 2);
INSERT INTO 'dancesstepsmap' VALUES (19320, 15883, 1);
INSERT INTO 'dancesstepsmap' VALUES (19321, 15884, 1);
INSERT INTO 'dancesstepsmap' VALUES (19322, 15885, 5);
INSERT INTO 'dancesstepsmap' VALUES (19323, 15885, 4);
INSERT INTO 'dancesstepsmap' VALUES (19324, 15886, 2);
INSERT INTO 'dancesstepsmap' VALUES (19325, 15886, 1);
INSERT INTO 'dancesstepsmap' VALUES (19326, 15886, 3);
INSERT INTO 'dancesstepsmap' VALUES (19327, 15887, 4);
INSERT INTO 'dancesstepsmap' VALUES (19328, 15887, 5);
INSERT INTO 'dancesstepsmap' VALUES (19329, 15888, 1);
INSERT INTO 'dancesstepsmap' VALUES (19330, 15888, 2);
INSERT INTO 'dancesstepsmap' VALUES (19331, 15889, 1);
INSERT INTO 'dancesstepsmap' VALUES (19332, 15889, 3);
INSERT INTO 'dancesstepsmap' VALUES (19333, 15890, 5);
INSERT INTO 'dancesstepsmap' VALUES (19334, 15890, 4);
INSERT INTO 'dancesstepsmap' VALUES (19335, 10077, 2);
INSERT INTO 'dancesstepsmap' VALUES (19336, 7053, 5);
INSERT INTO 'dancesstepsmap' VALUES (19337, 15891, 4);
INSERT INTO 'dancesstepsmap' VALUES (19338, 15891, 1);
INSERT INTO 'dancesstepsmap' VALUES (19339, 15891, 3);
INSERT INTO 'dancesstepsmap' VALUES (19340, 15892, 2);
INSERT INTO 'dancesstepsmap' VALUES (19341, 15892, 1);
INSERT INTO 'dancesstepsmap' VALUES (19342, 15892, 3);
INSERT INTO 'dancesstepsmap' VALUES (19343, 15893, 5);
INSERT INTO 'dancesstepsmap' VALUES (19344, 15893, 4);
INSERT INTO 'dancesstepsmap' VALUES (19345, 15895, 5);
INSERT INTO 'dancesstepsmap' VALUES (19346, 15895, 4);
INSERT INTO 'dancesstepsmap' VALUES (19347, 15896, 5);
INSERT INTO 'dancesstepsmap' VALUES (19348, 15896, 4);
INSERT INTO 'dancesstepsmap' VALUES (19349, 15897, 5);
INSERT INTO 'dancesstepsmap' VALUES (19350, 15897, 4);
INSERT INTO 'dancesstepsmap' VALUES (19351, 15897, 2);
INSERT INTO 'dancesstepsmap' VALUES (19352, 15897, 1);
INSERT INTO 'dancesstepsmap' VALUES (19353, 15897, 3);
INSERT INTO 'dancesstepsmap' VALUES (19354, 15898, 4);
INSERT INTO 'dancesstepsmap' VALUES (19355, 15898, 5);
INSERT INTO 'dancesstepsmap' VALUES (19356, 15899, 3);
INSERT INTO 'dancesstepsmap' VALUES (19357, 15899, 2);
INSERT INTO 'dancesstepsmap' VALUES (19358, 15899, 1);
INSERT INTO 'dancesstepsmap' VALUES (19359, 15900, 1);
INSERT INTO 'dancesstepsmap' VALUES (19360, 15900, 2);
INSERT INTO 'dancesstepsmap' VALUES (19361, 15900, 3);
INSERT INTO 'dancesstepsmap' VALUES (19362, 15901, 2);
INSERT INTO 'dancesstepsmap' VALUES (19363, 15901, 1);
INSERT INTO 'dancesstepsmap' VALUES (19364, 15901, 3);
INSERT INTO 'dancesstepsmap' VALUES (19365, 15902, 5);
INSERT INTO 'dancesstepsmap' VALUES (19366, 15902, 4);
INSERT INTO 'dancesstepsmap' VALUES (19367, 15903, 2);
INSERT INTO 'dancesstepsmap' VALUES (19368, 15903, 1);
INSERT INTO 'dancesstepsmap' VALUES (19369, 15903, 3);
INSERT INTO 'dancesstepsmap' VALUES (19370, 15904, 1);
INSERT INTO 'dancesstepsmap' VALUES (19371, 15904, 2);
INSERT INTO 'dancesstepsmap' VALUES (19372, 15904, 3);
INSERT INTO 'dancesstepsmap' VALUES (19373, 15905, 1);
INSERT INTO 'dancesstepsmap' VALUES (23234, 12347, 2);
INSERT INTO 'dancesstepsmap' VALUES (19375, 15905, 3);
INSERT INTO 'dancesstepsmap' VALUES (19376, 15906, 1);
INSERT INTO 'dancesstepsmap' VALUES (19377, 15906, 2);
INSERT INTO 'dancesstepsmap' VALUES (19378, 15906, 3);
INSERT INTO 'dancesstepsmap' VALUES (19379, 15907, 1);
INSERT INTO 'dancesstepsmap' VALUES (19380, 15907, 3);
INSERT INTO 'dancesstepsmap' VALUES (19381, 8154, 99);
INSERT INTO 'dancesstepsmap' VALUES (19382, 5527, 2);
INSERT INTO 'dancesstepsmap' VALUES (19383, 15908, 4);
INSERT INTO 'dancesstepsmap' VALUES (19384, 15908, 5);
INSERT INTO 'dancesstepsmap' VALUES (19385, 15909, 2);
INSERT INTO 'dancesstepsmap' VALUES (19386, 15909, 1);
INSERT INTO 'dancesstepsmap' VALUES (19387, 15910, 4);
INSERT INTO 'dancesstepsmap' VALUES (19388, 15910, 5);
INSERT INTO 'dancesstepsmap' VALUES (19389, 15911, 5);
INSERT INTO 'dancesstepsmap' VALUES (19390, 15911, 4);
INSERT INTO 'dancesstepsmap' VALUES (19391, 15911, 2);
INSERT INTO 'dancesstepsmap' VALUES (19392, 15911, 1);
INSERT INTO 'dancesstepsmap' VALUES (19393, 15912, 4);
INSERT INTO 'dancesstepsmap' VALUES (19395, 15912, 1);
INSERT INTO 'dancesstepsmap' VALUES (19396, 15912, 3);
INSERT INTO 'dancesstepsmap' VALUES (19397, 15913, 4);
INSERT INTO 'dancesstepsmap' VALUES (19398, 15913, 5);
INSERT INTO 'dancesstepsmap' VALUES (19399, 12179, 1);
INSERT INTO 'dancesstepsmap' VALUES (19400, 12179, 2);
INSERT INTO 'dancesstepsmap' VALUES (19401, 12179, 4);
INSERT INTO 'dancesstepsmap' VALUES (19402, 12179, 5);
INSERT INTO 'dancesstepsmap' VALUES (19403, 15914, 99);
INSERT INTO 'dancesstepsmap' VALUES (19404, 15914, 4);
INSERT INTO 'dancesstepsmap' VALUES (19405, 15914, 5);
INSERT INTO 'dancesstepsmap' VALUES (19406, 15914, 3);
INSERT INTO 'dancesstepsmap' VALUES (19407, 15914, 1);
INSERT INTO 'dancesstepsmap' VALUES (19408, 15914, 2);
INSERT INTO 'dancesstepsmap' VALUES (19409, 15915, 1);
INSERT INTO 'dancesstepsmap' VALUES (19410, 15915, 2);
INSERT INTO 'dancesstepsmap' VALUES (19411, 15915, 3);
INSERT INTO 'dancesstepsmap' VALUES (19412, 15916, 4);
INSERT INTO 'dancesstepsmap' VALUES (19413, 15917, 1);
INSERT INTO 'dancesstepsmap' VALUES (19414, 15917, 2);
INSERT INTO 'dancesstepsmap' VALUES (19415, 15918, 4);
INSERT INTO 'dancesstepsmap' VALUES (19416, 15918, 5);
INSERT INTO 'dancesstepsmap' VALUES (19417, 15919, 1);
INSERT INTO 'dancesstepsmap' VALUES (19418, 15919, 3);
INSERT INTO 'dancesstepsmap' VALUES (19419, 15920, 1);
INSERT INTO 'dancesstepsmap' VALUES (19420, 15920, 3);
INSERT INTO 'dancesstepsmap' VALUES (19421, 15921, 1);
INSERT INTO 'dancesstepsmap' VALUES (19422, 15921, 2);
INSERT INTO 'dancesstepsmap' VALUES (19423, 15922, 5);
INSERT INTO 'dancesstepsmap' VALUES (19424, 15922, 4);
INSERT INTO 'dancesstepsmap' VALUES (19425, 15923, 1);
INSERT INTO 'dancesstepsmap' VALUES (19426, 15924, 1);
INSERT INTO 'dancesstepsmap' VALUES (19427, 15924, 2);
INSERT INTO 'dancesstepsmap' VALUES (19428, 15925, 1);
INSERT INTO 'dancesstepsmap' VALUES (19429, 15925, 2);
INSERT INTO 'dancesstepsmap' VALUES (19430, 15925, 3);
INSERT INTO 'dancesstepsmap' VALUES (19431, 15926, 1);
INSERT INTO 'dancesstepsmap' VALUES (19432, 15926, 2);
INSERT INTO 'dancesstepsmap' VALUES (19433, 15926, 3);
INSERT INTO 'dancesstepsmap' VALUES (19434, 15927, 2);
INSERT INTO 'dancesstepsmap' VALUES (19435, 15927, 1);
INSERT INTO 'dancesstepsmap' VALUES (19313, 15880, 1);
INSERT INTO 'dancesstepsmap' VALUES (19436, 15927, 3);
INSERT INTO 'dancesstepsmap' VALUES (19437, 15928, 1);
INSERT INTO 'dancesstepsmap' VALUES (19438, 15928, 2);
INSERT INTO 'dancesstepsmap' VALUES (19439, 15930, 5);
INSERT INTO 'dancesstepsmap' VALUES (19440, 15930, 4);
INSERT INTO 'dancesstepsmap' VALUES (19441, 15931, 2);
INSERT INTO 'dancesstepsmap' VALUES (19442, 15931, 1);
INSERT INTO 'dancesstepsmap' VALUES (19443, 15932, 1);
INSERT INTO 'dancesstepsmap' VALUES (19444, 15932, 2);
INSERT INTO 'dancesstepsmap' VALUES (19445, 15933, 4);
INSERT INTO 'dancesstepsmap' VALUES (19446, 15934, 1);
INSERT INTO 'dancesstepsmap' VALUES (19447, 15934, 2);
INSERT INTO 'dancesstepsmap' VALUES (19448, 15935, 1);
INSERT INTO 'dancesstepsmap' VALUES (19449, 15935, 2);
INSERT INTO 'dancesstepsmap' VALUES (19450, 15935, 3);
INSERT INTO 'dancesstepsmap' VALUES (19451, 15937, 4);
INSERT INTO 'dancesstepsmap' VALUES (19452, 15937, 5);
INSERT INTO 'dancesstepsmap' VALUES (19453, 15938, 1);
INSERT INTO 'dancesstepsmap' VALUES (19454, 15939, 3);
INSERT INTO 'dancesstepsmap' VALUES (19455, 15939, 1);
INSERT INTO 'dancesstepsmap' VALUES (19456, 15939, 2);
INSERT INTO 'dancesstepsmap' VALUES (19457, 15940, 4);
INSERT INTO 'dancesstepsmap' VALUES (19458, 15940, 5);
INSERT INTO 'dancesstepsmap' VALUES (19459, 15941, 1);
INSERT INTO 'dancesstepsmap' VALUES (19460, 15941, 3);
INSERT INTO 'dancesstepsmap' VALUES (19461, 15942, 4);
INSERT INTO 'dancesstepsmap' VALUES (19462, 15942, 5);
INSERT INTO 'dancesstepsmap' VALUES (19463, 15943, 1);
INSERT INTO 'dancesstepsmap' VALUES (19464, 15943, 2);
INSERT INTO 'dancesstepsmap' VALUES (19465, 15944, 5);
INSERT INTO 'dancesstepsmap' VALUES (19466, 15944, 4);
INSERT INTO 'dancesstepsmap' VALUES (19467, 15945, 5);
INSERT INTO 'dancesstepsmap' VALUES (19468, 15945, 4);
INSERT INTO 'dancesstepsmap' VALUES (19469, 15946, 1);
INSERT INTO 'dancesstepsmap' VALUES (19470, 15946, 2);
INSERT INTO 'dancesstepsmap' VALUES (19471, 15946, 3);
INSERT INTO 'dancesstepsmap' VALUES (19472, 15947, 5);
INSERT INTO 'dancesstepsmap' VALUES (19473, 15947, 4);
INSERT INTO 'dancesstepsmap' VALUES (19474, 15948, 4);
INSERT INTO 'dancesstepsmap' VALUES (19475, 15948, 5);
INSERT INTO 'dancesstepsmap' VALUES (19476, 15948, 1);
INSERT INTO 'dancesstepsmap' VALUES (19477, 15948, 2);
INSERT INTO 'dancesstepsmap' VALUES (19478, 15948, 3);
INSERT INTO 'dancesstepsmap' VALUES (19479, 15949, 1);
INSERT INTO 'dancesstepsmap' VALUES (19480, 15949, 3);
INSERT INTO 'dancesstepsmap' VALUES (19481, 15950, 2);
INSERT INTO 'dancesstepsmap' VALUES (19482, 15950, 1);
INSERT INTO 'dancesstepsmap' VALUES (19483, 15950, 3);
INSERT INTO 'dancesstepsmap' VALUES (19484, 15951, 1);
INSERT INTO 'dancesstepsmap' VALUES (19485, 15951, 2);
INSERT INTO 'dancesstepsmap' VALUES (19486, 15952, 2);
INSERT INTO 'dancesstepsmap' VALUES (19487, 15952, 1);
INSERT INTO 'dancesstepsmap' VALUES (19488, 15952, 3);
INSERT INTO 'dancesstepsmap' VALUES (19489, 15953, 1);
INSERT INTO 'dancesstepsmap' VALUES (19490, 15954, 1);
INSERT INTO 'dancesstepsmap' VALUES (19491, 15954, 2);
INSERT INTO 'dancesstepsmap' VALUES (19492, 15955, 1);
INSERT INTO 'dancesstepsmap' VALUES (19493, 15929, 2);
INSERT INTO 'dancesstepsmap' VALUES (19494, 15929, 1);
INSERT INTO 'dancesstepsmap' VALUES (19495, 15956, 5);
INSERT INTO 'dancesstepsmap' VALUES (19496, 15956, 4);
INSERT INTO 'dancesstepsmap' VALUES (19497, 15957, 3);
INSERT INTO 'dancesstepsmap' VALUES (19498, 15957, 1);
INSERT INTO 'dancesstepsmap' VALUES (19499, 15957, 2);
INSERT INTO 'dancesstepsmap' VALUES (19500, 15958, 5);
INSERT INTO 'dancesstepsmap' VALUES (19501, 15958, 4);
INSERT INTO 'dancesstepsmap' VALUES (19502, 14447, 5);
INSERT INTO 'dancesstepsmap' VALUES (19503, 14447, 4);
INSERT INTO 'dancesstepsmap' VALUES (19504, 8546, 2);
INSERT INTO 'dancesstepsmap' VALUES (19505, 9050, 1);
INSERT INTO 'dancesstepsmap' VALUES (19506, 15959, 4);
INSERT INTO 'dancesstepsmap' VALUES (19507, 109, 5);
INSERT INTO 'dancesstepsmap' VALUES (19508, 15960, 2);
INSERT INTO 'dancesstepsmap' VALUES (19509, 15960, 1);
INSERT INTO 'dancesstepsmap' VALUES (19510, 15960, 3);
INSERT INTO 'dancesstepsmap' VALUES (23197, 7751, 5);
INSERT INTO 'dancesstepsmap' VALUES (23198, 17432, 1);
INSERT INTO 'dancesstepsmap' VALUES (19513, 15962, 3);
INSERT INTO 'dancesstepsmap' VALUES (19514, 15962, 1);
INSERT INTO 'dancesstepsmap' VALUES (19515, 15962, 2);
INSERT INTO 'dancesstepsmap' VALUES (19516, 15963, 5);
INSERT INTO 'dancesstepsmap' VALUES (19517, 15963, 4);
INSERT INTO 'dancesstepsmap' VALUES (19518, 15964, 1);
INSERT INTO 'dancesstepsmap' VALUES (19519, 15964, 2);
INSERT INTO 'dancesstepsmap' VALUES (19520, 15965, 4);
INSERT INTO 'dancesstepsmap' VALUES (19521, 15965, 5);
INSERT INTO 'dancesstepsmap' VALUES (19522, 15966, 2);
INSERT INTO 'dancesstepsmap' VALUES (19523, 15966, 1);
INSERT INTO 'dancesstepsmap' VALUES (19524, 15967, 1);
INSERT INTO 'dancesstepsmap' VALUES (19525, 15967, 2);
INSERT INTO 'dancesstepsmap' VALUES (19526, 6644, 3);
INSERT INTO 'dancesstepsmap' VALUES (19527, 15968, 1);
INSERT INTO 'dancesstepsmap' VALUES (19528, 15969, 2);
INSERT INTO 'dancesstepsmap' VALUES (19529, 15969, 1);
INSERT INTO 'dancesstepsmap' VALUES (19530, 15969, 3);
INSERT INTO 'dancesstepsmap' VALUES (19531, 15970, 1);
INSERT INTO 'dancesstepsmap' VALUES (19532, 15970, 2);
INSERT INTO 'dancesstepsmap' VALUES (19533, 15971, 4);
INSERT INTO 'dancesstepsmap' VALUES (19534, 15971, 5);
INSERT INTO 'dancesstepsmap' VALUES (19535, 15971, 6);
INSERT INTO 'dancesstepsmap' VALUES (19536, 15972, 1);
INSERT INTO 'dancesstepsmap' VALUES (19537, 15972, 2);
INSERT INTO 'dancesstepsmap' VALUES (19538, 15972, 3);
INSERT INTO 'dancesstepsmap' VALUES (19539, 15973, 3);
INSERT INTO 'dancesstepsmap' VALUES (19540, 15973, 1);
INSERT INTO 'dancesstepsmap' VALUES (19541, 15973, 2);
INSERT INTO 'dancesstepsmap' VALUES (19542, 15974, 1);
INSERT INTO 'dancesstepsmap' VALUES (19543, 15974, 2);
INSERT INTO 'dancesstepsmap' VALUES (19544, 15974, 3);
INSERT INTO 'dancesstepsmap' VALUES (19545, 15975, 4);
INSERT INTO 'dancesstepsmap' VALUES (19546, 15980, 1);
INSERT INTO 'dancesstepsmap' VALUES (19547, 15980, 2);
INSERT INTO 'dancesstepsmap' VALUES (19548, 15981, 4);
INSERT INTO 'dancesstepsmap' VALUES (19549, 15981, 1);
INSERT INTO 'dancesstepsmap' VALUES (19550, 15982, 1);
INSERT INTO 'dancesstepsmap' VALUES (19551, 15982, 2);
INSERT INTO 'dancesstepsmap' VALUES (19552, 15983, 1);
INSERT INTO 'dancesstepsmap' VALUES (19553, 15983, 2);
INSERT INTO 'dancesstepsmap' VALUES (19554, 15984, 4);
INSERT INTO 'dancesstepsmap' VALUES (19555, 15984, 5);
INSERT INTO 'dancesstepsmap' VALUES (19556, 15985, 2);
INSERT INTO 'dancesstepsmap' VALUES (19557, 15985, 1);
INSERT INTO 'dancesstepsmap' VALUES (19558, 15986, 5);
INSERT INTO 'dancesstepsmap' VALUES (19559, 15986, 4);
INSERT INTO 'dancesstepsmap' VALUES (19560, 15987, 1);
INSERT INTO 'dancesstepsmap' VALUES (19561, 15987, 2);
INSERT INTO 'dancesstepsmap' VALUES (19562, 15988, 4);
INSERT INTO 'dancesstepsmap' VALUES (19563, 15988, 5);
INSERT INTO 'dancesstepsmap' VALUES (19564, 15989, 1);
INSERT INTO 'dancesstepsmap' VALUES (19565, 15989, 2);
INSERT INTO 'dancesstepsmap' VALUES (19566, 15990, 1);
INSERT INTO 'dancesstepsmap' VALUES (19567, 15991, 1);
INSERT INTO 'dancesstepsmap' VALUES (19568, 15992, 2);
INSERT INTO 'dancesstepsmap' VALUES (19569, 15992, 1);
INSERT INTO 'dancesstepsmap' VALUES (19570, 15993, 4);
INSERT INTO 'dancesstepsmap' VALUES (19571, 15993, 5);
INSERT INTO 'dancesstepsmap' VALUES (19572, 15994, 4);
INSERT INTO 'dancesstepsmap' VALUES (19573, 15994, 5);
INSERT INTO 'dancesstepsmap' VALUES (19574, 15995, 4);
INSERT INTO 'dancesstepsmap' VALUES (19575, 15995, 5);
INSERT INTO 'dancesstepsmap' VALUES (19576, 15996, 1);
INSERT INTO 'dancesstepsmap' VALUES (19577, 15996, 2);
INSERT INTO 'dancesstepsmap' VALUES (19578, 15997, 5);
INSERT INTO 'dancesstepsmap' VALUES (19579, 15997, 4);
INSERT INTO 'dancesstepsmap' VALUES (19580, 15998, 2);
INSERT INTO 'dancesstepsmap' VALUES (19581, 15998, 1);
INSERT INTO 'dancesstepsmap' VALUES (19582, 15999, 2);
INSERT INTO 'dancesstepsmap' VALUES (19583, 15999, 1);
INSERT INTO 'dancesstepsmap' VALUES (19584, 16000, 1);
INSERT INTO 'dancesstepsmap' VALUES (19585, 16000, 2);
INSERT INTO 'dancesstepsmap' VALUES (19586, 16001, 2);
INSERT INTO 'dancesstepsmap' VALUES (19587, 16001, 1);
INSERT INTO 'dancesstepsmap' VALUES (19588, 16002, 1);
INSERT INTO 'dancesstepsmap' VALUES (19589, 16002, 2);
INSERT INTO 'dancesstepsmap' VALUES (23199, 17432, 2);
INSERT INTO 'dancesstepsmap' VALUES (19591, 16004, 1);
INSERT INTO 'dancesstepsmap' VALUES (19592, 16004, 2);
INSERT INTO 'dancesstepsmap' VALUES (19593, 16005, 4);
INSERT INTO 'dancesstepsmap' VALUES (19594, 16005, 5);
INSERT INTO 'dancesstepsmap' VALUES (19595, 16006, 1);
INSERT INTO 'dancesstepsmap' VALUES (19596, 16006, 2);
INSERT INTO 'dancesstepsmap' VALUES (19597, 16007, 3);
INSERT INTO 'dancesstepsmap' VALUES (19598, 16007, 1);
INSERT INTO 'dancesstepsmap' VALUES (19601, 16009, 1);
INSERT INTO 'dancesstepsmap' VALUES (19602, 16009, 3);
INSERT INTO 'dancesstepsmap' VALUES (19603, 16010, 1);
INSERT INTO 'dancesstepsmap' VALUES (19604, 16010, 3);
INSERT INTO 'dancesstepsmap' VALUES (19605, 16011, 1);
INSERT INTO 'dancesstepsmap' VALUES (19606, 16011, 3);
INSERT INTO 'dancesstepsmap' VALUES (19607, 16012, 1);
INSERT INTO 'dancesstepsmap' VALUES (19608, 16012, 3);
INSERT INTO 'dancesstepsmap' VALUES (19609, 16013, 1);
INSERT INTO 'dancesstepsmap' VALUES (19610, 16014, 1);
INSERT INTO 'dancesstepsmap' VALUES (19611, 16014, 2);
INSERT INTO 'dancesstepsmap' VALUES (19612, 16015, 1);
INSERT INTO 'dancesstepsmap' VALUES (19613, 16015, 2);
INSERT INTO 'dancesstepsmap' VALUES (19614, 16015, 3);
INSERT INTO 'dancesstepsmap' VALUES (19615, 16016, 5);
INSERT INTO 'dancesstepsmap' VALUES (19616, 16016, 4);
INSERT INTO 'dancesstepsmap' VALUES (19617, 16017, 3);
INSERT INTO 'dancesstepsmap' VALUES (19618, 16017, 1);
INSERT INTO 'dancesstepsmap' VALUES (19619, 16017, 2);
INSERT INTO 'dancesstepsmap' VALUES (19620, 16018, 4);
INSERT INTO 'dancesstepsmap' VALUES (19621, 16018, 5);
INSERT INTO 'dancesstepsmap' VALUES (19622, 16019, 1);
INSERT INTO 'dancesstepsmap' VALUES (19623, 16020, 4);
INSERT INTO 'dancesstepsmap' VALUES (19624, 16021, 1);
INSERT INTO 'dancesstepsmap' VALUES (19625, 16022, 5);
INSERT INTO 'dancesstepsmap' VALUES (19626, 16022, 4);
INSERT INTO 'dancesstepsmap' VALUES (19627, 16023, 1);
INSERT INTO 'dancesstepsmap' VALUES (19628, 16024, 5);
INSERT INTO 'dancesstepsmap' VALUES (19629, 16024, 4);
INSERT INTO 'dancesstepsmap' VALUES (19630, 16025, 1);
INSERT INTO 'dancesstepsmap' VALUES (19631, 16025, 2);
INSERT INTO 'dancesstepsmap' VALUES (19632, 16026, 3);
INSERT INTO 'dancesstepsmap' VALUES (19633, 16026, 1);
INSERT INTO 'dancesstepsmap' VALUES (19634, 16026, 2);
INSERT INTO 'dancesstepsmap' VALUES (19635, 16025, 3);
INSERT INTO 'dancesstepsmap' VALUES (19636, 16027, 1);
INSERT INTO 'dancesstepsmap' VALUES (19637, 16027, 2);
INSERT INTO 'dancesstepsmap' VALUES (19638, 2394, 5);
INSERT INTO 'dancesstepsmap' VALUES (19639, 16028, 2);
INSERT INTO 'dancesstepsmap' VALUES (19640, 16028, 1);
INSERT INTO 'dancesstepsmap' VALUES (19641, 16028, 3);
INSERT INTO 'dancesstepsmap' VALUES (19642, 16029, 1);
INSERT INTO 'dancesstepsmap' VALUES (19643, 16029, 2);
INSERT INTO 'dancesstepsmap' VALUES (19644, 16030, 2);
INSERT INTO 'dancesstepsmap' VALUES (19645, 16030, 1);
INSERT INTO 'dancesstepsmap' VALUES (19646, 16030, 3);
INSERT INTO 'dancesstepsmap' VALUES (19647, 16031, 1);
INSERT INTO 'dancesstepsmap' VALUES (19648, 16031, 2);
INSERT INTO 'dancesstepsmap' VALUES (19649, 16032, 2);
INSERT INTO 'dancesstepsmap' VALUES (19650, 16032, 1);
INSERT INTO 'dancesstepsmap' VALUES (19651, 16033, 5);
INSERT INTO 'dancesstepsmap' VALUES (19652, 16033, 4);
INSERT INTO 'dancesstepsmap' VALUES (19653, 16034, 5);
INSERT INTO 'dancesstepsmap' VALUES (19654, 16034, 4);
INSERT INTO 'dancesstepsmap' VALUES (19655, 16035, 5);
INSERT INTO 'dancesstepsmap' VALUES (19656, 16035, 4);
INSERT INTO 'dancesstepsmap' VALUES (19657, 16036, 4);
INSERT INTO 'dancesstepsmap' VALUES (19658, 16036, 5);
INSERT INTO 'dancesstepsmap' VALUES (19659, 16037, 3);
INSERT INTO 'dancesstepsmap' VALUES (19660, 16037, 2);
INSERT INTO 'dancesstepsmap' VALUES (19661, 16037, 1);
INSERT INTO 'dancesstepsmap' VALUES (19662, 16038, 2);
INSERT INTO 'dancesstepsmap' VALUES (19663, 16038, 1);
INSERT INTO 'dancesstepsmap' VALUES (19664, 16039, 1);
INSERT INTO 'dancesstepsmap' VALUES (19665, 16040, 2);
INSERT INTO 'dancesstepsmap' VALUES (19666, 16040, 1);
INSERT INTO 'dancesstepsmap' VALUES (19667, 16040, 3);
INSERT INTO 'dancesstepsmap' VALUES (19668, 16041, 2);
INSERT INTO 'dancesstepsmap' VALUES (19669, 16041, 1);
INSERT INTO 'dancesstepsmap' VALUES (19670, 16041, 3);
INSERT INTO 'dancesstepsmap' VALUES (19671, 16042, 2);
INSERT INTO 'dancesstepsmap' VALUES (19672, 16042, 1);
INSERT INTO 'dancesstepsmap' VALUES (19673, 16043, 1);
INSERT INTO 'dancesstepsmap' VALUES (19674, 16044, 1);
INSERT INTO 'dancesstepsmap' VALUES (19675, 14582, 5);
INSERT INTO 'dancesstepsmap' VALUES (19676, 14582, 4);
INSERT INTO 'dancesstepsmap' VALUES (19677, 10105, 2);
INSERT INTO 'dancesstepsmap' VALUES (19678, 16045, 5);
INSERT INTO 'dancesstepsmap' VALUES (19679, 16045, 4);
INSERT INTO 'dancesstepsmap' VALUES (19680, 16045, 2);
INSERT INTO 'dancesstepsmap' VALUES (19681, 16045, 1);
INSERT INTO 'dancesstepsmap' VALUES (19682, 16046, 2);
INSERT INTO 'dancesstepsmap' VALUES (19683, 16046, 1);
INSERT INTO 'dancesstepsmap' VALUES (19684, 16047, 1);
INSERT INTO 'dancesstepsmap' VALUES (19685, 15360, 1);
INSERT INTO 'dancesstepsmap' VALUES (19686, 15360, 2);
INSERT INTO 'dancesstepsmap' VALUES (19687, 15360, 3);
INSERT INTO 'dancesstepsmap' VALUES (19600, 16008, 3);
INSERT INTO 'dancesstepsmap' VALUES (19688, 16048, 4);
INSERT INTO 'dancesstepsmap' VALUES (19689, 16048, 1);
INSERT INTO 'dancesstepsmap' VALUES (19690, 16048, 3);
INSERT INTO 'dancesstepsmap' VALUES (19691, 16049, 4);
INSERT INTO 'dancesstepsmap' VALUES (19692, 16049, 5);
INSERT INTO 'dancesstepsmap' VALUES (19693, 16050, 4);
INSERT INTO 'dancesstepsmap' VALUES (19694, 16050, 5);
INSERT INTO 'dancesstepsmap' VALUES (19695, 16051, 4);
INSERT INTO 'dancesstepsmap' VALUES (19696, 16051, 5);
INSERT INTO 'dancesstepsmap' VALUES (19697, 16052, 2);
INSERT INTO 'dancesstepsmap' VALUES (19698, 16052, 3);
INSERT INTO 'dancesstepsmap' VALUES (19699, 16052, 1);
INSERT INTO 'dancesstepsmap' VALUES (19700, 13487, 1);
INSERT INTO 'dancesstepsmap' VALUES (19701, 13487, 2);
INSERT INTO 'dancesstepsmap' VALUES (19702, 13487, 3);
INSERT INTO 'dancesstepsmap' VALUES (19703, 13476, 2);
INSERT INTO 'dancesstepsmap' VALUES (19704, 13476, 1);
INSERT INTO 'dancesstepsmap' VALUES (19705, 13476, 3);
INSERT INTO 'dancesstepsmap' VALUES (19706, 13485, 2);
INSERT INTO 'dancesstepsmap' VALUES (19707, 13485, 1);
INSERT INTO 'dancesstepsmap' VALUES (19708, 13480, 3);
INSERT INTO 'dancesstepsmap' VALUES (19709, 13480, 2);
INSERT INTO 'dancesstepsmap' VALUES (19710, 13480, 1);
INSERT INTO 'dancesstepsmap' VALUES (19711, 13483, 4);
INSERT INTO 'dancesstepsmap' VALUES (19712, 13483, 5);
INSERT INTO 'dancesstepsmap' VALUES (19713, 13483, 6);
INSERT INTO 'dancesstepsmap' VALUES (19714, 13481, 5);
INSERT INTO 'dancesstepsmap' VALUES (19715, 13481, 4);
INSERT INTO 'dancesstepsmap' VALUES (19716, 13489, 2);
INSERT INTO 'dancesstepsmap' VALUES (19717, 13489, 1);
INSERT INTO 'dancesstepsmap' VALUES (19718, 13489, 3);
INSERT INTO 'dancesstepsmap' VALUES (19719, 13489, 5);
INSERT INTO 'dancesstepsmap' VALUES (19720, 13489, 4);
INSERT INTO 'dancesstepsmap' VALUES (19721, 13486, 4);
INSERT INTO 'dancesstepsmap' VALUES (19722, 13486, 5);
INSERT INTO 'dancesstepsmap' VALUES (19723, 13486, 6);
INSERT INTO 'dancesstepsmap' VALUES (19724, 13488, 4);
INSERT INTO 'dancesstepsmap' VALUES (19725, 13488, 2);
INSERT INTO 'dancesstepsmap' VALUES (19726, 13488, 1);
INSERT INTO 'dancesstepsmap' VALUES (19727, 11228, 1);
INSERT INTO 'dancesstepsmap' VALUES (19728, 11228, 3);
INSERT INTO 'dancesstepsmap' VALUES (19729, 14962, 1);
INSERT INTO 'dancesstepsmap' VALUES (19730, 14962, 2);
INSERT INTO 'dancesstepsmap' VALUES (19731, 15665, 1);
INSERT INTO 'dancesstepsmap' VALUES (19732, 15665, 2);
INSERT INTO 'dancesstepsmap' VALUES (19733, 16053, 1);
INSERT INTO 'dancesstepsmap' VALUES (19734, 16054, 4);
INSERT INTO 'dancesstepsmap' VALUES (19735, 16054, 5);
INSERT INTO 'dancesstepsmap' VALUES (19736, 16055, 1);
INSERT INTO 'dancesstepsmap' VALUES (19737, 16055, 2);
INSERT INTO 'dancesstepsmap' VALUES (19738, 16055, 3);
INSERT INTO 'dancesstepsmap' VALUES (19739, 2475, 2);
INSERT INTO 'dancesstepsmap' VALUES (19740, 2475, 3);
INSERT INTO 'dancesstepsmap' VALUES (19741, 13478, 2);
INSERT INTO 'dancesstepsmap' VALUES (19742, 13478, 1);
INSERT INTO 'dancesstepsmap' VALUES (19743, 13478, 3);
INSERT INTO 'dancesstepsmap' VALUES (19744, 13475, 5);
INSERT INTO 'dancesstepsmap' VALUES (19745, 13475, 4);
INSERT INTO 'dancesstepsmap' VALUES (19746, 13479, 1);
INSERT INTO 'dancesstepsmap' VALUES (19747, 16056, 5);
INSERT INTO 'dancesstepsmap' VALUES (19748, 16056, 4);
INSERT INTO 'dancesstepsmap' VALUES (19749, 13477, 5);
INSERT INTO 'dancesstepsmap' VALUES (19750, 13477, 4);
INSERT INTO 'dancesstepsmap' VALUES (19751, 16057, 2);
INSERT INTO 'dancesstepsmap' VALUES (19752, 16057, 1);
INSERT INTO 'dancesstepsmap' VALUES (19753, 16057, 3);
INSERT INTO 'dancesstepsmap' VALUES (19754, 16058, 2);
INSERT INTO 'dancesstepsmap' VALUES (19755, 16058, 1);
INSERT INTO 'dancesstepsmap' VALUES (19756, 16058, 3);
INSERT INTO 'dancesstepsmap' VALUES (19757, 4256, 5);
INSERT INTO 'dancesstepsmap' VALUES (19758, 15308, 1);
INSERT INTO 'dancesstepsmap' VALUES (19759, 15308, 2);
INSERT INTO 'dancesstepsmap' VALUES (19760, 16059, 5);
INSERT INTO 'dancesstepsmap' VALUES (19761, 16059, 4);
INSERT INTO 'dancesstepsmap' VALUES (19763, 16060, 4);
INSERT INTO 'dancesstepsmap' VALUES (19764, 16060, 5);
INSERT INTO 'dancesstepsmap' VALUES (19765, 16061, 3);
INSERT INTO 'dancesstepsmap' VALUES (19766, 16061, 1);
INSERT INTO 'dancesstepsmap' VALUES (19767, 16061, 7);
INSERT INTO 'dancesstepsmap' VALUES (19768, 16062, 7);
INSERT INTO 'dancesstepsmap' VALUES (19769, 16062, 1);
INSERT INTO 'dancesstepsmap' VALUES (19770, 16063, 2);
INSERT INTO 'dancesstepsmap' VALUES (19771, 16063, 1);
INSERT INTO 'dancesstepsmap' VALUES (19772, 16064, 2);
INSERT INTO 'dancesstepsmap' VALUES (19773, 16064, 1);
INSERT INTO 'dancesstepsmap' VALUES (19774, 16064, 10);
INSERT INTO 'dancesstepsmap' VALUES (19775, 16065, 1);
INSERT INTO 'dancesstepsmap' VALUES (19776, 16065, 2);
INSERT INTO 'dancesstepsmap' VALUES (19777, 16065, 3);
INSERT INTO 'dancesstepsmap' VALUES (19778, 16066, 4);
INSERT INTO 'dancesstepsmap' VALUES (19779, 16066, 5);
INSERT INTO 'dancesstepsmap' VALUES (19780, 16067, 2);
INSERT INTO 'dancesstepsmap' VALUES (19781, 16067, 1);
INSERT INTO 'dancesstepsmap' VALUES (19782, 16068, 1);
INSERT INTO 'dancesstepsmap' VALUES (19783, 16068, 3);
INSERT INTO 'dancesstepsmap' VALUES (19784, 16069, 1);
INSERT INTO 'dancesstepsmap' VALUES (19785, 16069, 2);
INSERT INTO 'dancesstepsmap' VALUES (19786, 13614, 2);
INSERT INTO 'dancesstepsmap' VALUES (19787, 13614, 1);
INSERT INTO 'dancesstepsmap' VALUES (19788, 16070, 4);
INSERT INTO 'dancesstepsmap' VALUES (19789, 16070, 5);
INSERT INTO 'dancesstepsmap' VALUES (19790, 16070, 1);
INSERT INTO 'dancesstepsmap' VALUES (19791, 16070, 2);
INSERT INTO 'dancesstepsmap' VALUES (19792, 16071, 2);
INSERT INTO 'dancesstepsmap' VALUES (19793, 16071, 1);
INSERT INTO 'dancesstepsmap' VALUES (19794, 16072, 5);
INSERT INTO 'dancesstepsmap' VALUES (19795, 16072, 4);
INSERT INTO 'dancesstepsmap' VALUES (19796, 16073, 5);
INSERT INTO 'dancesstepsmap' VALUES (19797, 16073, 4);
INSERT INTO 'dancesstepsmap' VALUES (19798, 16074, 1);
INSERT INTO 'dancesstepsmap' VALUES (19799, 16074, 2);
INSERT INTO 'dancesstepsmap' VALUES (19800, 16074, 3);
INSERT INTO 'dancesstepsmap' VALUES (19801, 16075, 5);
INSERT INTO 'dancesstepsmap' VALUES (19802, 16075, 4);
INSERT INTO 'dancesstepsmap' VALUES (19803, 16076, 2);
INSERT INTO 'dancesstepsmap' VALUES (19804, 16076, 1);
INSERT INTO 'dancesstepsmap' VALUES (19805, 16077, 1);
INSERT INTO 'dancesstepsmap' VALUES (19806, 16078, 4);
INSERT INTO 'dancesstepsmap' VALUES (19807, 16078, 5);
INSERT INTO 'dancesstepsmap' VALUES (19808, 16079, 4);
INSERT INTO 'dancesstepsmap' VALUES (19809, 16079, 5);
INSERT INTO 'dancesstepsmap' VALUES (19810, 16080, 1);
INSERT INTO 'dancesstepsmap' VALUES (19811, 16081, 2);
INSERT INTO 'dancesstepsmap' VALUES (19812, 16081, 1);
INSERT INTO 'dancesstepsmap' VALUES (19813, 16082, 3);
INSERT INTO 'dancesstepsmap' VALUES (19814, 16082, 1);
INSERT INTO 'dancesstepsmap' VALUES (19815, 16083, 1);
INSERT INTO 'dancesstepsmap' VALUES (19816, 16083, 2);
INSERT INTO 'dancesstepsmap' VALUES (19817, 16084, 4);
INSERT INTO 'dancesstepsmap' VALUES (19818, 16085, 1);
INSERT INTO 'dancesstepsmap' VALUES (19819, 16085, 2);
INSERT INTO 'dancesstepsmap' VALUES (19820, 16086, 5);
INSERT INTO 'dancesstepsmap' VALUES (19821, 16086, 4);
INSERT INTO 'dancesstepsmap' VALUES (19822, 1758, 5);
INSERT INTO 'dancesstepsmap' VALUES (19823, 16087, 1);
INSERT INTO 'dancesstepsmap' VALUES (19824, 16088, 1);
INSERT INTO 'dancesstepsmap' VALUES (19825, 16089, 3);
INSERT INTO 'dancesstepsmap' VALUES (19826, 16089, 1);
INSERT INTO 'dancesstepsmap' VALUES (19827, 16091, 1);
INSERT INTO 'dancesstepsmap' VALUES (19828, 16092, 1);
INSERT INTO 'dancesstepsmap' VALUES (19829, 16093, 1);
INSERT INTO 'dancesstepsmap' VALUES (19830, 16094, 2);
INSERT INTO 'dancesstepsmap' VALUES (19831, 16094, 1);
INSERT INTO 'dancesstepsmap' VALUES (19832, 16095, 1);
INSERT INTO 'dancesstepsmap' VALUES (19833, 16096, 1);
INSERT INTO 'dancesstepsmap' VALUES (19834, 16097, 5);
INSERT INTO 'dancesstepsmap' VALUES (19835, 16097, 4);
INSERT INTO 'dancesstepsmap' VALUES (19836, 16098, 5);
INSERT INTO 'dancesstepsmap' VALUES (19837, 16098, 4);
INSERT INTO 'dancesstepsmap' VALUES (19838, 16099, 1);
INSERT INTO 'dancesstepsmap' VALUES (19839, 16099, 2);
INSERT INTO 'dancesstepsmap' VALUES (19840, 16099, 3);
INSERT INTO 'dancesstepsmap' VALUES (19841, 16100, 1);
INSERT INTO 'dancesstepsmap' VALUES (19842, 16100, 2);
INSERT INTO 'dancesstepsmap' VALUES (19843, 16101, 1);
INSERT INTO 'dancesstepsmap' VALUES (19844, 16101, 2);
INSERT INTO 'dancesstepsmap' VALUES (19845, 16102, 4);
INSERT INTO 'dancesstepsmap' VALUES (19846, 16102, 5);
INSERT INTO 'dancesstepsmap' VALUES (19847, 16103, 4);
INSERT INTO 'dancesstepsmap' VALUES (19848, 16103, 5);
INSERT INTO 'dancesstepsmap' VALUES (19849, 16104, 2);
INSERT INTO 'dancesstepsmap' VALUES (19850, 16104, 1);
INSERT INTO 'dancesstepsmap' VALUES (19851, 16105, 1);
INSERT INTO 'dancesstepsmap' VALUES (19852, 16108, 5);
INSERT INTO 'dancesstepsmap' VALUES (19853, 16108, 4);
INSERT INTO 'dancesstepsmap' VALUES (19854, 16107, 1);
INSERT INTO 'dancesstepsmap' VALUES (19855, 16107, 3);
INSERT INTO 'dancesstepsmap' VALUES (19858, 16109, 1);
INSERT INTO 'dancesstepsmap' VALUES (19859, 16110, 5);
INSERT INTO 'dancesstepsmap' VALUES (19860, 16110, 4);
INSERT INTO 'dancesstepsmap' VALUES (19861, 16111, 2);
INSERT INTO 'dancesstepsmap' VALUES (19862, 16111, 1);
INSERT INTO 'dancesstepsmap' VALUES (19863, 9815, 2);
INSERT INTO 'dancesstepsmap' VALUES (19864, 16112, 1);
INSERT INTO 'dancesstepsmap' VALUES (19865, 16113, 4);
INSERT INTO 'dancesstepsmap' VALUES (19866, 16113, 5);
INSERT INTO 'dancesstepsmap' VALUES (19867, 16114, 4);
INSERT INTO 'dancesstepsmap' VALUES (19868, 16114, 5);
INSERT INTO 'dancesstepsmap' VALUES (19869, 16115, 1);
INSERT INTO 'dancesstepsmap' VALUES (11102, 9224, 1);
INSERT INTO 'dancesstepsmap' VALUES (11103, 9224, 2);
INSERT INTO 'dancesstepsmap' VALUES (19870, 1872, 4);
INSERT INTO 'dancesstepsmap' VALUES (19871, 1872, 5);
INSERT INTO 'dancesstepsmap' VALUES (19872, 1872, 1);
INSERT INTO 'dancesstepsmap' VALUES (19873, 1872, 2);
INSERT INTO 'dancesstepsmap' VALUES (19874, 16116, 1);
INSERT INTO 'dancesstepsmap' VALUES (3708, 4010, 5);
INSERT INTO 'dancesstepsmap' VALUES (19875, 4010, 4);
INSERT INTO 'dancesstepsmap' VALUES (19876, 8366, 2);
INSERT INTO 'dancesstepsmap' VALUES (2317, 2509, 5);
INSERT INTO 'dancesstepsmap' VALUES (19877, 2509, 4);
INSERT INTO 'dancesstepsmap' VALUES (19878, 16117, 1);
INSERT INTO 'dancesstepsmap' VALUES (19879, 16117, 2);
INSERT INTO 'dancesstepsmap' VALUES (19880, 16118, 5);
INSERT INTO 'dancesstepsmap' VALUES (19881, 16118, 4);
INSERT INTO 'dancesstepsmap' VALUES (19882, 16119, 2);
INSERT INTO 'dancesstepsmap' VALUES (19883, 16119, 1);
INSERT INTO 'dancesstepsmap' VALUES (19884, 16119, 3);
INSERT INTO 'dancesstepsmap' VALUES (19885, 16120, 1);
INSERT INTO 'dancesstepsmap' VALUES (19886, 16121, 4);
INSERT INTO 'dancesstepsmap' VALUES (19887, 16121, 5);
INSERT INTO 'dancesstepsmap' VALUES (19888, 16122, 2);
INSERT INTO 'dancesstepsmap' VALUES (19889, 16122, 1);
INSERT INTO 'dancesstepsmap' VALUES (19890, 16123, 1);
INSERT INTO 'dancesstepsmap' VALUES (19891, 16123, 2);
INSERT INTO 'dancesstepsmap' VALUES (19892, 16123, 3);
INSERT INTO 'dancesstepsmap' VALUES (19893, 16124, 4);
INSERT INTO 'dancesstepsmap' VALUES (19894, 16124, 5);
INSERT INTO 'dancesstepsmap' VALUES (19895, 16125, 1);
INSERT INTO 'dancesstepsmap' VALUES (19896, 16125, 3);
INSERT INTO 'dancesstepsmap' VALUES (19897, 16126, 1);
INSERT INTO 'dancesstepsmap' VALUES (19898, 16126, 2);
INSERT INTO 'dancesstepsmap' VALUES (19899, 16126, 3);
INSERT INTO 'dancesstepsmap' VALUES (19900, 6689, 2);
INSERT INTO 'dancesstepsmap' VALUES (19901, 15023, 5);
INSERT INTO 'dancesstepsmap' VALUES (19902, 224, 3);
INSERT INTO 'dancesstepsmap' VALUES (19903, 6073, 2);
INSERT INTO 'dancesstepsmap' VALUES (19904, 16127, 4);
INSERT INTO 'dancesstepsmap' VALUES (19905, 16127, 5);
INSERT INTO 'dancesstepsmap' VALUES (19906, 16128, 4);
INSERT INTO 'dancesstepsmap' VALUES (19907, 16128, 5);
INSERT INTO 'dancesstepsmap' VALUES (19908, 14673, 1);
INSERT INTO 'dancesstepsmap' VALUES (19909, 14673, 2);
INSERT INTO 'dancesstepsmap' VALUES (19910, 16129, 2);
INSERT INTO 'dancesstepsmap' VALUES (19911, 16129, 1);
INSERT INTO 'dancesstepsmap' VALUES (19912, 16130, 5);
INSERT INTO 'dancesstepsmap' VALUES (19913, 16130, 4);
INSERT INTO 'dancesstepsmap' VALUES (19914, 16131, 1);
INSERT INTO 'dancesstepsmap' VALUES (19915, 16131, 3);
INSERT INTO 'dancesstepsmap' VALUES (19916, 16131, 2);
INSERT INTO 'dancesstepsmap' VALUES (19917, 16132, 4);
INSERT INTO 'dancesstepsmap' VALUES (19918, 16132, 5);
INSERT INTO 'dancesstepsmap' VALUES (19919, 16133, 1);
INSERT INTO 'dancesstepsmap' VALUES (19920, 16133, 2);
INSERT INTO 'dancesstepsmap' VALUES (19921, 16133, 3);
INSERT INTO 'dancesstepsmap' VALUES (19922, 16134, 1);
INSERT INTO 'dancesstepsmap' VALUES (19923, 16134, 2);
INSERT INTO 'dancesstepsmap' VALUES (19924, 16134, 3);
INSERT INTO 'dancesstepsmap' VALUES (19925, 16135, 4);
INSERT INTO 'dancesstepsmap' VALUES (19926, 16135, 5);
INSERT INTO 'dancesstepsmap' VALUES (19927, 4943, 2);
INSERT INTO 'dancesstepsmap' VALUES (19928, 9931, 1);
INSERT INTO 'dancesstepsmap' VALUES (19929, 9931, 2);
INSERT INTO 'dancesstepsmap' VALUES (19930, 16136, 4);
INSERT INTO 'dancesstepsmap' VALUES (19931, 16136, 5);
INSERT INTO 'dancesstepsmap' VALUES (19932, 16137, 1);
INSERT INTO 'dancesstepsmap' VALUES (19933, 16137, 2);
INSERT INTO 'dancesstepsmap' VALUES (19934, 16138, 1);
INSERT INTO 'dancesstepsmap' VALUES (19935, 16139, 4);
INSERT INTO 'dancesstepsmap' VALUES (19936, 16140, 1);
INSERT INTO 'dancesstepsmap' VALUES (19937, 16140, 2);
INSERT INTO 'dancesstepsmap' VALUES (19938, 16141, 3);
INSERT INTO 'dancesstepsmap' VALUES (19939, 16141, 2);
INSERT INTO 'dancesstepsmap' VALUES (19940, 16141, 1);
INSERT INTO 'dancesstepsmap' VALUES (19941, 16142, 1);
INSERT INTO 'dancesstepsmap' VALUES (19942, 16142, 2);
INSERT INTO 'dancesstepsmap' VALUES (19943, 16143, 3);
INSERT INTO 'dancesstepsmap' VALUES (19944, 16143, 1);
INSERT INTO 'dancesstepsmap' VALUES (19945, 16144, 4);
INSERT INTO 'dancesstepsmap' VALUES (19946, 16144, 5);
INSERT INTO 'dancesstepsmap' VALUES (19947, 1943, 5);
INSERT INTO 'dancesstepsmap' VALUES (19948, 16145, 1);
INSERT INTO 'dancesstepsmap' VALUES (19949, 16146, 1);
INSERT INTO 'dancesstepsmap' VALUES (19950, 16146, 2);
INSERT INTO 'dancesstepsmap' VALUES (19951, 16147, 1);
INSERT INTO 'dancesstepsmap' VALUES (19952, 16148, 2);
INSERT INTO 'dancesstepsmap' VALUES (19953, 16148, 1);
INSERT INTO 'dancesstepsmap' VALUES (19954, 16148, 3);
INSERT INTO 'dancesstepsmap' VALUES (19955, 16149, 1);
INSERT INTO 'dancesstepsmap' VALUES (19956, 16149, 3);
INSERT INTO 'dancesstepsmap' VALUES (19957, 16149, 2);
INSERT INTO 'dancesstepsmap' VALUES (19958, 16150, 4);
INSERT INTO 'dancesstepsmap' VALUES (19959, 16150, 1);
INSERT INTO 'dancesstepsmap' VALUES (19960, 16150, 2);
INSERT INTO 'dancesstepsmap' VALUES (19961, 16151, 1);
INSERT INTO 'dancesstepsmap' VALUES (19962, 16151, 3);
INSERT INTO 'dancesstepsmap' VALUES (19963, 9817, 2);
INSERT INTO 'dancesstepsmap' VALUES (19964, 9817, 3);
INSERT INTO 'dancesstepsmap' VALUES (19965, 4038, 2);
INSERT INTO 'dancesstepsmap' VALUES (16771, 5209, 2);
INSERT INTO 'dancesstepsmap' VALUES (6921, 6915, 99);
INSERT INTO 'dancesstepsmap' VALUES (19966, 1791, 99);
INSERT INTO 'dancesstepsmap' VALUES (18475, 15402, 4);
INSERT INTO 'dancesstepsmap' VALUES (18476, 15402, 5);
INSERT INTO 'dancesstepsmap' VALUES (10901, 10074, 2);
INSERT INTO 'dancesstepsmap' VALUES (19967, 10074, 1);
INSERT INTO 'dancesstepsmap' VALUES (16435, 13810, 1);
INSERT INTO 'dancesstepsmap' VALUES (16436, 13810, 2);
INSERT INTO 'dancesstepsmap' VALUES (19968, 13810, 3);
INSERT INTO 'dancesstepsmap' VALUES (16848, 14384, 2);
INSERT INTO 'dancesstepsmap' VALUES (17887, 12699, 1);
INSERT INTO 'dancesstepsmap' VALUES (17888, 12699, 2);
INSERT INTO 'dancesstepsmap' VALUES (19969, 12699, 3);
INSERT INTO 'dancesstepsmap' VALUES (14852, 12740, 1);
INSERT INTO 'dancesstepsmap' VALUES (14853, 12740, 2);
INSERT INTO 'dancesstepsmap' VALUES (17284, 14616, 2);
INSERT INTO 'dancesstepsmap' VALUES (19374, 15905, 2);
INSERT INTO 'dancesstepsmap' VALUES (4473, 4836, 2);
INSERT INTO 'dancesstepsmap' VALUES (19970, 4836, 1);
INSERT INTO 'dancesstepsmap' VALUES (10477, 9731, 2);
INSERT INTO 'dancesstepsmap' VALUES (19971, 9731, 1);
INSERT INTO 'dancesstepsmap' VALUES (16106, 13711, 1);
INSERT INTO 'dancesstepsmap' VALUES (16107, 13711, 2);
INSERT INTO 'dancesstepsmap' VALUES (19972, 13711, 3);
INSERT INTO 'dancesstepsmap' VALUES (18728, 15483, 1);
INSERT INTO 'dancesstepsmap' VALUES (18729, 15483, 2);
INSERT INTO 'dancesstepsmap' VALUES (16530, 14278, 5);
INSERT INTO 'dancesstepsmap' VALUES (16531, 14278, 4);
INSERT INTO 'dancesstepsmap' VALUES (12463, 11192, 5);
INSERT INTO 'dancesstepsmap' VALUES (12464, 11192, 4);
INSERT INTO 'dancesstepsmap' VALUES (19973, 16153, 1);
INSERT INTO 'dancesstepsmap' VALUES (19974, 16153, 2);
INSERT INTO 'dancesstepsmap' VALUES (19975, 16154, 1);
INSERT INTO 'dancesstepsmap' VALUES (19976, 16155, 5);
INSERT INTO 'dancesstepsmap' VALUES (19977, 16155, 4);
INSERT INTO 'dancesstepsmap' VALUES (19978, 11500, 3);
INSERT INTO 'dancesstepsmap' VALUES (19114, 15772, 2);
INSERT INTO 'dancesstepsmap' VALUES (19979, 13557, 2);
INSERT INTO 'dancesstepsmap' VALUES (19980, 13557, 1);
INSERT INTO 'dancesstepsmap' VALUES (19981, 5936, 2);
INSERT INTO 'dancesstepsmap' VALUES (19982, 16156, 1);
INSERT INTO 'dancesstepsmap' VALUES (19983, 16156, 2);
INSERT INTO 'dancesstepsmap' VALUES (19984, 16156, 3);
INSERT INTO 'dancesstepsmap' VALUES (19985, 16157, 4);
INSERT INTO 'dancesstepsmap' VALUES (19986, 16157, 5);
INSERT INTO 'dancesstepsmap' VALUES (19987, 14964, 5);
INSERT INTO 'dancesstepsmap' VALUES (19988, 14964, 4);
INSERT INTO 'dancesstepsmap' VALUES (19989, 1176, 5);
INSERT INTO 'dancesstepsmap' VALUES (19990, 12394, 1);
INSERT INTO 'dancesstepsmap' VALUES (19991, 12394, 2);
INSERT INTO 'dancesstepsmap' VALUES (19992, 16158, 2);
INSERT INTO 'dancesstepsmap' VALUES (19993, 16158, 1);
INSERT INTO 'dancesstepsmap' VALUES (19994, 16160, 1);
INSERT INTO 'dancesstepsmap' VALUES (19995, 16160, 2);
INSERT INTO 'dancesstepsmap' VALUES (19996, 16161, 1);
INSERT INTO 'dancesstepsmap' VALUES (19997, 16161, 2);
INSERT INTO 'dancesstepsmap' VALUES (19998, 16161, 3);
INSERT INTO 'dancesstepsmap' VALUES (19999, 16161, 4);
INSERT INTO 'dancesstepsmap' VALUES (20000, 16161, 5);
INSERT INTO 'dancesstepsmap' VALUES (20001, 16159, 2);
INSERT INTO 'dancesstepsmap' VALUES (20002, 16159, 1);
INSERT INTO 'dancesstepsmap' VALUES (20003, 15762, 2);
INSERT INTO 'dancesstepsmap' VALUES (20004, 15762, 3);
INSERT INTO 'dancesstepsmap' VALUES (20005, 15762, 1);
INSERT INTO 'dancesstepsmap' VALUES (20006, 3665, 5);
INSERT INTO 'dancesstepsmap' VALUES (20007, 12669, 2);
INSERT INTO 'dancesstepsmap' VALUES (20008, 16176, 1);
INSERT INTO 'dancesstepsmap' VALUES (20009, 16177, 2);
INSERT INTO 'dancesstepsmap' VALUES (20010, 16177, 1);
INSERT INTO 'dancesstepsmap' VALUES (20011, 16178, 10);
INSERT INTO 'dancesstepsmap' VALUES (20012, 4046, 2);
INSERT INTO 'dancesstepsmap' VALUES (20013, 16182, 1);
INSERT INTO 'dancesstepsmap' VALUES (20014, 16182, 2);
INSERT INTO 'dancesstepsmap' VALUES (20015, 16181, 1);
INSERT INTO 'dancesstepsmap' VALUES (20016, 16181, 2);
INSERT INTO 'dancesstepsmap' VALUES (20017, 6051, 2);
INSERT INTO 'dancesstepsmap' VALUES (20018, 16183, 5);
INSERT INTO 'dancesstepsmap' VALUES (20019, 16183, 4);
INSERT INTO 'dancesstepsmap' VALUES (20020, 9114, 5);
INSERT INTO 'dancesstepsmap' VALUES (20021, 14672, 5);
INSERT INTO 'dancesstepsmap' VALUES (20022, 14672, 4);
INSERT INTO 'dancesstepsmap' VALUES (20023, 16184, 5);
INSERT INTO 'dancesstepsmap' VALUES (20024, 16184, 4);
INSERT INTO 'dancesstepsmap' VALUES (11893, 10681, 1);
INSERT INTO 'dancesstepsmap' VALUES (11894, 10681, 2);
INSERT INTO 'dancesstepsmap' VALUES (20025, 14514, 1);
INSERT INTO 'dancesstepsmap' VALUES (20026, 14514, 2);
INSERT INTO 'dancesstepsmap' VALUES (20027, 16185, 5);
INSERT INTO 'dancesstepsmap' VALUES (20028, 16185, 4);
INSERT INTO 'dancesstepsmap' VALUES (20029, 13205, 4);
INSERT INTO 'dancesstepsmap' VALUES (20030, 16186, 4);
INSERT INTO 'dancesstepsmap' VALUES (20031, 16186, 5);
INSERT INTO 'dancesstepsmap' VALUES (20032, 16187, 5);
INSERT INTO 'dancesstepsmap' VALUES (20033, 16187, 4);
INSERT INTO 'dancesstepsmap' VALUES (20034, 16188, 1);
INSERT INTO 'dancesstepsmap' VALUES (20035, 16189, 5);
INSERT INTO 'dancesstepsmap' VALUES (20036, 16189, 4);
INSERT INTO 'dancesstepsmap' VALUES (20037, 16190, 1);
INSERT INTO 'dancesstepsmap' VALUES (20038, 16191, 2);
INSERT INTO 'dancesstepsmap' VALUES (20039, 16191, 1);
INSERT INTO 'dancesstepsmap' VALUES (20040, 16192, 4);
INSERT INTO 'dancesstepsmap' VALUES (20041, 5110, 5);
INSERT INTO 'dancesstepsmap' VALUES (20042, 16193, 3);
INSERT INTO 'dancesstepsmap' VALUES (20043, 16193, 2);
INSERT INTO 'dancesstepsmap' VALUES (20044, 16193, 1);
INSERT INTO 'dancesstepsmap' VALUES (20045, 16194, 1);
INSERT INTO 'dancesstepsmap' VALUES (20046, 16194, 3);
INSERT INTO 'dancesstepsmap' VALUES (20047, 16195, 2);
INSERT INTO 'dancesstepsmap' VALUES (20048, 16195, 1);
INSERT INTO 'dancesstepsmap' VALUES (20049, 16196, 2);
INSERT INTO 'dancesstepsmap' VALUES (20050, 16196, 1);
INSERT INTO 'dancesstepsmap' VALUES (20051, 16196, 3);
INSERT INTO 'dancesstepsmap' VALUES (20052, 16197, 2);
INSERT INTO 'dancesstepsmap' VALUES (20053, 16197, 1);
INSERT INTO 'dancesstepsmap' VALUES (20054, 16198, 1);
INSERT INTO 'dancesstepsmap' VALUES (20055, 16198, 3);
INSERT INTO 'dancesstepsmap' VALUES (20056, 16199, 3);
INSERT INTO 'dancesstepsmap' VALUES (20057, 16199, 1);
INSERT INTO 'dancesstepsmap' VALUES (20058, 16200, 2);
INSERT INTO 'dancesstepsmap' VALUES (20059, 16200, 1);
INSERT INTO 'dancesstepsmap' VALUES (20060, 16201, 5);
INSERT INTO 'dancesstepsmap' VALUES (20061, 16201, 4);
INSERT INTO 'dancesstepsmap' VALUES (20062, 16201, 2);
INSERT INTO 'dancesstepsmap' VALUES (20063, 16201, 1);
INSERT INTO 'dancesstepsmap' VALUES (20064, 16201, 3);
INSERT INTO 'dancesstepsmap' VALUES (20065, 16202, 1);
INSERT INTO 'dancesstepsmap' VALUES (20066, 16202, 2);
INSERT INTO 'dancesstepsmap' VALUES (20067, 16202, 3);
INSERT INTO 'dancesstepsmap' VALUES (20068, 16203, 3);
INSERT INTO 'dancesstepsmap' VALUES (20069, 16203, 1);
INSERT INTO 'dancesstepsmap' VALUES (20070, 16203, 2);
INSERT INTO 'dancesstepsmap' VALUES (20071, 16204, 1);
INSERT INTO 'dancesstepsmap' VALUES (20072, 16204, 2);
INSERT INTO 'dancesstepsmap' VALUES (20073, 16204, 3);
INSERT INTO 'dancesstepsmap' VALUES (20074, 9224, 3);
INSERT INTO 'dancesstepsmap' VALUES (20075, 3972, 5);
INSERT INTO 'dancesstepsmap' VALUES (20076, 16205, 1);
INSERT INTO 'dancesstepsmap' VALUES (20077, 16205, 3);
INSERT INTO 'dancesstepsmap' VALUES (20078, 16206, 1);
INSERT INTO 'dancesstepsmap' VALUES (20079, 16207, 3);
INSERT INTO 'dancesstepsmap' VALUES (20080, 16207, 1);
INSERT INTO 'dancesstepsmap' VALUES (20081, 16207, 2);
INSERT INTO 'dancesstepsmap' VALUES (20082, 16208, 3);
INSERT INTO 'dancesstepsmap' VALUES (20083, 16208, 1);
INSERT INTO 'dancesstepsmap' VALUES (20084, 16208, 2);
INSERT INTO 'dancesstepsmap' VALUES (20085, 16209, 1);
INSERT INTO 'dancesstepsmap' VALUES (20086, 16209, 2);
INSERT INTO 'dancesstepsmap' VALUES (20087, 16210, 1);
INSERT INTO 'dancesstepsmap' VALUES (20088, 16210, 2);
INSERT INTO 'dancesstepsmap' VALUES (20089, 16211, 1);
INSERT INTO 'dancesstepsmap' VALUES (20090, 16211, 3);
INSERT INTO 'dancesstepsmap' VALUES (20091, 16211, 2);
INSERT INTO 'dancesstepsmap' VALUES (20092, 2439, 2);
INSERT INTO 'dancesstepsmap' VALUES (20093, 16212, 10);
INSERT INTO 'dancesstepsmap' VALUES (20094, 16213, 10);
INSERT INTO 'dancesstepsmap' VALUES (20095, 16214, 1);
INSERT INTO 'dancesstepsmap' VALUES (20096, 16214, 2);
INSERT INTO 'dancesstepsmap' VALUES (20097, 1949, 2);
INSERT INTO 'dancesstepsmap' VALUES (20098, 16215, 5);
INSERT INTO 'dancesstepsmap' VALUES (20099, 16215, 4);
INSERT INTO 'dancesstepsmap' VALUES (20100, 16216, 5);
INSERT INTO 'dancesstepsmap' VALUES (20101, 16216, 4);
INSERT INTO 'dancesstepsmap' VALUES (20102, 16216, 10);
INSERT INTO 'dancesstepsmap' VALUES (23200, 7828, 2);
INSERT INTO 'dancesstepsmap' VALUES (23201, 7589, 2);
INSERT INTO 'dancesstepsmap' VALUES (20105, 16220, 1);
INSERT INTO 'dancesstepsmap' VALUES (20106, 16220, 2);
INSERT INTO 'dancesstepsmap' VALUES (20107, 16221, 1);
INSERT INTO 'dancesstepsmap' VALUES (20108, 16221, 2);
INSERT INTO 'dancesstepsmap' VALUES (20109, 16221, 3);
INSERT INTO 'dancesstepsmap' VALUES (20110, 16222, 2);
INSERT INTO 'dancesstepsmap' VALUES (20111, 16222, 1);
INSERT INTO 'dancesstepsmap' VALUES (20112, 16223, 5);
INSERT INTO 'dancesstepsmap' VALUES (20113, 16223, 4);
INSERT INTO 'dancesstepsmap' VALUES (20114, 5444, 2);
INSERT INTO 'dancesstepsmap' VALUES (20115, 5013, 2);
INSERT INTO 'dancesstepsmap' VALUES (20116, 16224, 1);
INSERT INTO 'dancesstepsmap' VALUES (20117, 16224, 2);
INSERT INTO 'dancesstepsmap' VALUES (20118, 16225, 2);
INSERT INTO 'dancesstepsmap' VALUES (20119, 16225, 1);
INSERT INTO 'dancesstepsmap' VALUES (20120, 16226, 4);
INSERT INTO 'dancesstepsmap' VALUES (20121, 16226, 5);
INSERT INTO 'dancesstepsmap' VALUES (20122, 16227, 1);
INSERT INTO 'dancesstepsmap' VALUES (20123, 16228, 5);
INSERT INTO 'dancesstepsmap' VALUES (20124, 16228, 4);
INSERT INTO 'dancesstepsmap' VALUES (20125, 16229, 5);
INSERT INTO 'dancesstepsmap' VALUES (20126, 16229, 4);
INSERT INTO 'dancesstepsmap' VALUES (20127, 16230, 4);
INSERT INTO 'dancesstepsmap' VALUES (20128, 16231, 4);
INSERT INTO 'dancesstepsmap' VALUES (20129, 16231, 5);
INSERT INTO 'dancesstepsmap' VALUES (20130, 16232, 1);
INSERT INTO 'dancesstepsmap' VALUES (20131, 16232, 2);
INSERT INTO 'dancesstepsmap' VALUES (20132, 16233, 1);
INSERT INTO 'dancesstepsmap' VALUES (20133, 16233, 2);
INSERT INTO 'dancesstepsmap' VALUES (20134, 16234, 4);
INSERT INTO 'dancesstepsmap' VALUES (20135, 16234, 5);
INSERT INTO 'dancesstepsmap' VALUES (20136, 16235, 1);
INSERT INTO 'dancesstepsmap' VALUES (20137, 16235, 2);
INSERT INTO 'dancesstepsmap' VALUES (20138, 16236, 4);
INSERT INTO 'dancesstepsmap' VALUES (20139, 16236, 5);
INSERT INTO 'dancesstepsmap' VALUES (20140, 16237, 5);
INSERT INTO 'dancesstepsmap' VALUES (20141, 16237, 4);
INSERT INTO 'dancesstepsmap' VALUES (20142, 16238, 4);
INSERT INTO 'dancesstepsmap' VALUES (20143, 16239, 1);
INSERT INTO 'dancesstepsmap' VALUES (20144, 16239, 2);
INSERT INTO 'dancesstepsmap' VALUES (20147, 16240, 4);
INSERT INTO 'dancesstepsmap' VALUES (20148, 16240, 5);
INSERT INTO 'dancesstepsmap' VALUES (20149, 16241, 4);
INSERT INTO 'dancesstepsmap' VALUES (20150, 16241, 5);
INSERT INTO 'dancesstepsmap' VALUES (20151, 16242, 1);
INSERT INTO 'dancesstepsmap' VALUES (20152, 16243, 5);
INSERT INTO 'dancesstepsmap' VALUES (20153, 16243, 4);
INSERT INTO 'dancesstepsmap' VALUES (20154, 16244, 5);
INSERT INTO 'dancesstepsmap' VALUES (20155, 16244, 4);
INSERT INTO 'dancesstepsmap' VALUES (20156, 16245, 5);
INSERT INTO 'dancesstepsmap' VALUES (20157, 16245, 4);
INSERT INTO 'dancesstepsmap' VALUES (20158, 16246, 1);
INSERT INTO 'dancesstepsmap' VALUES (20159, 16247, 1);
INSERT INTO 'dancesstepsmap' VALUES (20160, 16247, 2);
INSERT INTO 'dancesstepsmap' VALUES (20161, 16248, 4);
INSERT INTO 'dancesstepsmap' VALUES (20162, 16248, 5);
INSERT INTO 'dancesstepsmap' VALUES (20163, 16249, 2);
INSERT INTO 'dancesstepsmap' VALUES (20164, 16249, 1);
INSERT INTO 'dancesstepsmap' VALUES (20165, 16250, 1);
INSERT INTO 'dancesstepsmap' VALUES (20166, 16251, 1);
INSERT INTO 'dancesstepsmap' VALUES (20167, 16251, 2);
INSERT INTO 'dancesstepsmap' VALUES (20168, 16252, 2);
INSERT INTO 'dancesstepsmap' VALUES (20169, 16252, 1);
INSERT INTO 'dancesstepsmap' VALUES (20170, 16253, 5);
INSERT INTO 'dancesstepsmap' VALUES (20171, 16253, 4);
INSERT INTO 'dancesstepsmap' VALUES (20172, 16254, 1);
INSERT INTO 'dancesstepsmap' VALUES (20173, 6152, 2);
INSERT INTO 'dancesstepsmap' VALUES (20174, 16255, 1);
INSERT INTO 'dancesstepsmap' VALUES (20175, 16255, 3);
INSERT INTO 'dancesstepsmap' VALUES (8616, 2723, 4);
INSERT INTO 'dancesstepsmap' VALUES (20177, 16256, 2);
INSERT INTO 'dancesstepsmap' VALUES (20178, 16256, 1);
INSERT INTO 'dancesstepsmap' VALUES (5874, 6367, 2);
INSERT INTO 'dancesstepsmap' VALUES (20179, 6367, 1);
INSERT INTO 'dancesstepsmap' VALUES (20180, 5440, 5);
INSERT INTO 'dancesstepsmap' VALUES (20181, 5440, 4);
INSERT INTO 'dancesstepsmap' VALUES (20182, 5440, 1);
INSERT INTO 'dancesstepsmap' VALUES (20183, 5440, 2);
INSERT INTO 'dancesstepsmap' VALUES (20184, 7469, 2);
INSERT INTO 'dancesstepsmap' VALUES (20185, 16257, 1);
INSERT INTO 'dancesstepsmap' VALUES (20186, 16258, 1);
INSERT INTO 'dancesstepsmap' VALUES (20187, 16258, 2);
INSERT INTO 'dancesstepsmap' VALUES (20188, 16259, 1);
INSERT INTO 'dancesstepsmap' VALUES (20189, 16259, 3);
INSERT INTO 'dancesstepsmap' VALUES (20190, 16259, 2);
INSERT INTO 'dancesstepsmap' VALUES (20191, 16260, 1);
INSERT INTO 'dancesstepsmap' VALUES (20192, 5524, 5);
INSERT INTO 'dancesstepsmap' VALUES (20193, 16261, 2);
INSERT INTO 'dancesstepsmap' VALUES (20194, 16261, 1);
INSERT INTO 'dancesstepsmap' VALUES (20195, 16262, 2);
INSERT INTO 'dancesstepsmap' VALUES (20196, 16262, 1);
INSERT INTO 'dancesstepsmap' VALUES (20197, 16263, 2);
INSERT INTO 'dancesstepsmap' VALUES (20198, 16263, 1);
INSERT INTO 'dancesstepsmap' VALUES (20199, 16264, 4);
INSERT INTO 'dancesstepsmap' VALUES (20200, 16265, 1);
INSERT INTO 'dancesstepsmap' VALUES (20201, 16265, 2);
INSERT INTO 'dancesstepsmap' VALUES (20202, 16266, 2);
INSERT INTO 'dancesstepsmap' VALUES (20203, 16266, 1);
INSERT INTO 'dancesstepsmap' VALUES (20204, 16267, 4);
INSERT INTO 'dancesstepsmap' VALUES (20205, 16267, 5);
INSERT INTO 'dancesstepsmap' VALUES (20206, 16268, 1);
INSERT INTO 'dancesstepsmap' VALUES (20207, 16269, 4);
INSERT INTO 'dancesstepsmap' VALUES (20208, 16269, 5);
INSERT INTO 'dancesstepsmap' VALUES (20209, 16270, 1);
INSERT INTO 'dancesstepsmap' VALUES (20210, 16270, 2);
INSERT INTO 'dancesstepsmap' VALUES (20211, 16271, 5);
INSERT INTO 'dancesstepsmap' VALUES (20212, 16271, 4);
INSERT INTO 'dancesstepsmap' VALUES (20213, 16272, 3);
INSERT INTO 'dancesstepsmap' VALUES (20214, 16272, 1);
INSERT INTO 'dancesstepsmap' VALUES (20215, 16273, 2);
INSERT INTO 'dancesstepsmap' VALUES (20216, 16273, 1);
INSERT INTO 'dancesstepsmap' VALUES (20217, 16274, 4);
INSERT INTO 'dancesstepsmap' VALUES (20218, 16274, 5);
INSERT INTO 'dancesstepsmap' VALUES (20219, 15618, 2);
INSERT INTO 'dancesstepsmap' VALUES (20220, 15618, 1);
INSERT INTO 'dancesstepsmap' VALUES (20221, 16275, 1);
INSERT INTO 'dancesstepsmap' VALUES (20222, 16275, 2);
INSERT INTO 'dancesstepsmap' VALUES (20223, 16276, 4);
INSERT INTO 'dancesstepsmap' VALUES (20224, 16277, 1);
INSERT INTO 'dancesstepsmap' VALUES (20225, 16277, 2);
INSERT INTO 'dancesstepsmap' VALUES (20226, 16278, 1);
INSERT INTO 'dancesstepsmap' VALUES (20227, 16279, 5);
INSERT INTO 'dancesstepsmap' VALUES (20228, 16279, 4);
INSERT INTO 'dancesstepsmap' VALUES (20229, 16280, 1);
INSERT INTO 'dancesstepsmap' VALUES (20230, 16281, 1);
INSERT INTO 'dancesstepsmap' VALUES (20231, 16281, 2);
INSERT INTO 'dancesstepsmap' VALUES (20232, 16282, 2);
INSERT INTO 'dancesstepsmap' VALUES (20233, 16282, 1);
INSERT INTO 'dancesstepsmap' VALUES (20234, 16283, 1);
INSERT INTO 'dancesstepsmap' VALUES (20235, 16284, 5);
INSERT INTO 'dancesstepsmap' VALUES (20236, 16284, 4);
INSERT INTO 'dancesstepsmap' VALUES (20237, 16285, 1);
INSERT INTO 'dancesstepsmap' VALUES (20238, 16285, 2);
INSERT INTO 'dancesstepsmap' VALUES (20239, 16285, 99);
INSERT INTO 'dancesstepsmap' VALUES (20240, 16286, 1);
INSERT INTO 'dancesstepsmap' VALUES (20241, 16287, 5);
INSERT INTO 'dancesstepsmap' VALUES (20242, 16287, 4);
INSERT INTO 'dancesstepsmap' VALUES (20243, 16288, 4);
INSERT INTO 'dancesstepsmap' VALUES (20244, 16288, 5);
INSERT INTO 'dancesstepsmap' VALUES (20245, 16289, 2);
INSERT INTO 'dancesstepsmap' VALUES (20246, 16289, 1);
INSERT INTO 'dancesstepsmap' VALUES (20247, 16290, 1);
INSERT INTO 'dancesstepsmap' VALUES (20248, 16291, 1);
INSERT INTO 'dancesstepsmap' VALUES (20249, 16291, 2);
INSERT INTO 'dancesstepsmap' VALUES (20250, 16292, 5);
INSERT INTO 'dancesstepsmap' VALUES (20251, 16292, 4);
INSERT INTO 'dancesstepsmap' VALUES (20252, 16293, 1);
INSERT INTO 'dancesstepsmap' VALUES (20253, 16294, 1);
INSERT INTO 'dancesstepsmap' VALUES (20254, 16295, 1);
INSERT INTO 'dancesstepsmap' VALUES (20255, 16296, 4);
INSERT INTO 'dancesstepsmap' VALUES (20256, 16296, 5);
INSERT INTO 'dancesstepsmap' VALUES (20257, 16297, 5);
INSERT INTO 'dancesstepsmap' VALUES (20258, 16297, 4);
INSERT INTO 'dancesstepsmap' VALUES (20259, 16297, 2);
INSERT INTO 'dancesstepsmap' VALUES (20260, 16297, 1);
INSERT INTO 'dancesstepsmap' VALUES (20261, 16298, 2);
INSERT INTO 'dancesstepsmap' VALUES (20262, 16298, 1);
INSERT INTO 'dancesstepsmap' VALUES (20263, 16298, 3);
INSERT INTO 'dancesstepsmap' VALUES (20264, 16299, 2);
INSERT INTO 'dancesstepsmap' VALUES (20265, 16299, 1);
INSERT INTO 'dancesstepsmap' VALUES (20266, 16299, 3);
INSERT INTO 'dancesstepsmap' VALUES (20267, 16300, 2);
INSERT INTO 'dancesstepsmap' VALUES (20268, 16300, 1);
INSERT INTO 'dancesstepsmap' VALUES (20269, 16300, 3);
INSERT INTO 'dancesstepsmap' VALUES (20270, 16301, 3);
INSERT INTO 'dancesstepsmap' VALUES (20271, 16301, 1);
INSERT INTO 'dancesstepsmap' VALUES (20272, 16301, 2);
INSERT INTO 'dancesstepsmap' VALUES (20273, 16302, 1);
INSERT INTO 'dancesstepsmap' VALUES (20274, 16302, 3);
INSERT INTO 'dancesstepsmap' VALUES (20275, 16302, 2);
INSERT INTO 'dancesstepsmap' VALUES (20276, 16303, 4);
INSERT INTO 'dancesstepsmap' VALUES (20277, 16304, 1);
INSERT INTO 'dancesstepsmap' VALUES (20278, 16304, 2);
INSERT INTO 'dancesstepsmap' VALUES (20279, 16305, 2);
INSERT INTO 'dancesstepsmap' VALUES (20280, 16305, 1);
INSERT INTO 'dancesstepsmap' VALUES (20281, 16306, 1);
INSERT INTO 'dancesstepsmap' VALUES (20282, 16307, 1);
INSERT INTO 'dancesstepsmap' VALUES (20283, 16307, 2);
INSERT INTO 'dancesstepsmap' VALUES (20284, 16308, 2);
INSERT INTO 'dancesstepsmap' VALUES (20285, 16308, 1);
INSERT INTO 'dancesstepsmap' VALUES (20286, 16309, 1);
INSERT INTO 'dancesstepsmap' VALUES (20287, 16309, 2);
INSERT INTO 'dancesstepsmap' VALUES (20288, 16310, 1);
INSERT INTO 'dancesstepsmap' VALUES (20289, 16310, 2);
INSERT INTO 'dancesstepsmap' VALUES (20290, 16311, 1);
INSERT INTO 'dancesstepsmap' VALUES (20291, 16311, 3);
INSERT INTO 'dancesstepsmap' VALUES (20292, 16312, 4);
INSERT INTO 'dancesstepsmap' VALUES (20293, 16312, 5);
INSERT INTO 'dancesstepsmap' VALUES (20296, 16314, 2);
INSERT INTO 'dancesstepsmap' VALUES (20297, 16314, 1);
INSERT INTO 'dancesstepsmap' VALUES (20299, 16316, 1);
INSERT INTO 'dancesstepsmap' VALUES (20300, 16316, 2);
INSERT INTO 'dancesstepsmap' VALUES (20301, 16317, 1);
INSERT INTO 'dancesstepsmap' VALUES (20302, 16319, 1);
INSERT INTO 'dancesstepsmap' VALUES (20303, 16319, 2);
INSERT INTO 'dancesstepsmap' VALUES (20304, 16320, 5);
INSERT INTO 'dancesstepsmap' VALUES (20305, 16320, 4);
INSERT INTO 'dancesstepsmap' VALUES (20306, 16321, 1);
INSERT INTO 'dancesstepsmap' VALUES (20307, 16321, 2);
INSERT INTO 'dancesstepsmap' VALUES (20308, 16322, 1);
INSERT INTO 'dancesstepsmap' VALUES (20309, 16322, 4);
INSERT INTO 'dancesstepsmap' VALUES (20310, 16322, 2);
INSERT INTO 'dancesstepsmap' VALUES (20311, 16322, 5);
INSERT INTO 'dancesstepsmap' VALUES (20312, 16323, 1);
INSERT INTO 'dancesstepsmap' VALUES (20313, 16324, 1);
INSERT INTO 'dancesstepsmap' VALUES (20314, 16324, 2);
INSERT INTO 'dancesstepsmap' VALUES (20315, 16325, 2);
INSERT INTO 'dancesstepsmap' VALUES (20316, 16325, 1);
INSERT INTO 'dancesstepsmap' VALUES (20317, 16326, 4);
INSERT INTO 'dancesstepsmap' VALUES (20318, 16326, 5);
INSERT INTO 'dancesstepsmap' VALUES (20319, 16327, 1);
INSERT INTO 'dancesstepsmap' VALUES (20320, 16327, 3);
INSERT INTO 'dancesstepsmap' VALUES (20321, 16327, 2);
INSERT INTO 'dancesstepsmap' VALUES (20322, 16328, 4);
INSERT INTO 'dancesstepsmap' VALUES (20323, 16328, 5);
INSERT INTO 'dancesstepsmap' VALUES (20324, 16329, 1);
INSERT INTO 'dancesstepsmap' VALUES (20325, 16329, 3);
INSERT INTO 'dancesstepsmap' VALUES (20326, 16330, 1);
INSERT INTO 'dancesstepsmap' VALUES (20327, 16330, 2);
INSERT INTO 'dancesstepsmap' VALUES (20328, 16330, 3);
INSERT INTO 'dancesstepsmap' VALUES (20329, 16331, 1);
INSERT INTO 'dancesstepsmap' VALUES (20330, 16331, 2);
INSERT INTO 'dancesstepsmap' VALUES (20298, 16315, 4);
INSERT INTO 'dancesstepsmap' VALUES (20331, 16331, 3);
INSERT INTO 'dancesstepsmap' VALUES (20332, 16332, 4);
INSERT INTO 'dancesstepsmap' VALUES (20333, 16332, 5);
INSERT INTO 'dancesstepsmap' VALUES (20334, 16333, 5);
INSERT INTO 'dancesstepsmap' VALUES (20335, 16333, 4);
INSERT INTO 'dancesstepsmap' VALUES (20336, 16334, 1);
INSERT INTO 'dancesstepsmap' VALUES (20337, 16335, 1);
INSERT INTO 'dancesstepsmap' VALUES (20338, 16335, 2);
INSERT INTO 'dancesstepsmap' VALUES (20339, 16335, 3);
INSERT INTO 'dancesstepsmap' VALUES (20340, 16336, 5);
INSERT INTO 'dancesstepsmap' VALUES (20341, 16336, 4);
INSERT INTO 'dancesstepsmap' VALUES (20342, 16337, 4);
INSERT INTO 'dancesstepsmap' VALUES (20343, 16337, 5);
INSERT INTO 'dancesstepsmap' VALUES (20344, 2242, 5);
INSERT INTO 'dancesstepsmap' VALUES (20345, 16339, 1);
INSERT INTO 'dancesstepsmap' VALUES (20346, 16339, 2);
INSERT INTO 'dancesstepsmap' VALUES (20347, 16340, 4);
INSERT INTO 'dancesstepsmap' VALUES (20348, 16340, 5);
INSERT INTO 'dancesstepsmap' VALUES (20349, 16341, 1);
INSERT INTO 'dancesstepsmap' VALUES (20350, 16341, 2);
INSERT INTO 'dancesstepsmap' VALUES (20351, 16342, 4);
INSERT INTO 'dancesstepsmap' VALUES (20352, 16342, 5);
INSERT INTO 'dancesstepsmap' VALUES (20353, 16343, 2);
INSERT INTO 'dancesstepsmap' VALUES (20354, 16343, 1);
INSERT INTO 'dancesstepsmap' VALUES (20355, 16344, 4);
INSERT INTO 'dancesstepsmap' VALUES (20356, 16345, 1);
INSERT INTO 'dancesstepsmap' VALUES (20357, 16345, 2);
INSERT INTO 'dancesstepsmap' VALUES (20358, 16346, 9);
INSERT INTO 'dancesstepsmap' VALUES (20359, 16346, 4);
INSERT INTO 'dancesstepsmap' VALUES (20360, 16346, 5);
INSERT INTO 'dancesstepsmap' VALUES (20361, 16346, 6);
INSERT INTO 'dancesstepsmap' VALUES (20362, 16348, 4);
INSERT INTO 'dancesstepsmap' VALUES (20363, 16349, 1);
INSERT INTO 'dancesstepsmap' VALUES (20364, 16350, 4);
INSERT INTO 'dancesstepsmap' VALUES (20365, 16351, 1);
INSERT INTO 'dancesstepsmap' VALUES (20366, 16351, 2);
INSERT INTO 'dancesstepsmap' VALUES (20367, 16352, 4);
INSERT INTO 'dancesstepsmap' VALUES (20368, 16352, 5);
INSERT INTO 'dancesstepsmap' VALUES (20369, 16353, 1);
INSERT INTO 'dancesstepsmap' VALUES (20370, 16353, 2);
INSERT INTO 'dancesstepsmap' VALUES (20371, 15691, 1);
INSERT INTO 'dancesstepsmap' VALUES (20372, 15691, 2);
INSERT INTO 'dancesstepsmap' VALUES (20373, 2631, 5);
INSERT INTO 'dancesstepsmap' VALUES (20374, 1084, 5);
INSERT INTO 'dancesstepsmap' VALUES (20375, 16354, 5);
INSERT INTO 'dancesstepsmap' VALUES (20376, 16354, 4);
INSERT INTO 'dancesstepsmap' VALUES (20377, 16355, 1);
INSERT INTO 'dancesstepsmap' VALUES (20378, 16355, 2);
INSERT INTO 'dancesstepsmap' VALUES (20379, 16356, 1);
INSERT INTO 'dancesstepsmap' VALUES (20380, 16356, 2);
INSERT INTO 'dancesstepsmap' VALUES (20381, 16357, 4);
INSERT INTO 'dancesstepsmap' VALUES (20382, 16357, 5);
INSERT INTO 'dancesstepsmap' VALUES (20383, 16358, 1);
INSERT INTO 'dancesstepsmap' VALUES (20384, 16359, 4);
INSERT INTO 'dancesstepsmap' VALUES (20385, 16360, 4);
INSERT INTO 'dancesstepsmap' VALUES (20386, 16361, 2);
INSERT INTO 'dancesstepsmap' VALUES (20387, 16361, 1);
INSERT INTO 'dancesstepsmap' VALUES (20388, 11751, 4);
INSERT INTO 'dancesstepsmap' VALUES (20389, 11751, 5);
INSERT INTO 'dancesstepsmap' VALUES (20390, 16362, 4);
INSERT INTO 'dancesstepsmap' VALUES (20391, 16363, 1);
INSERT INTO 'dancesstepsmap' VALUES (20392, 16363, 2);
INSERT INTO 'dancesstepsmap' VALUES (20393, 16364, 4);
INSERT INTO 'dancesstepsmap' VALUES (20394, 16364, 5);
INSERT INTO 'dancesstepsmap' VALUES (20395, 16315, 5);
INSERT INTO 'dancesstepsmap' VALUES (20396, 16365, 4);
INSERT INTO 'dancesstepsmap' VALUES (20397, 16365, 5);
INSERT INTO 'dancesstepsmap' VALUES (20398, 16366, 1);
INSERT INTO 'dancesstepsmap' VALUES (20399, 16366, 2);
INSERT INTO 'dancesstepsmap' VALUES (20400, 16367, 4);
INSERT INTO 'dancesstepsmap' VALUES (20401, 16367, 5);
INSERT INTO 'dancesstepsmap' VALUES (20402, 16368, 1);
INSERT INTO 'dancesstepsmap' VALUES (20403, 16368, 3);
INSERT INTO 'dancesstepsmap' VALUES (20404, 16368, 2);
INSERT INTO 'dancesstepsmap' VALUES (20405, 11659, 5);
INSERT INTO 'dancesstepsmap' VALUES (20406, 11659, 4);
INSERT INTO 'dancesstepsmap' VALUES (20407, 16369, 1);
INSERT INTO 'dancesstepsmap' VALUES (20408, 16369, 2);
INSERT INTO 'dancesstepsmap' VALUES (20409, 16370, 5);
INSERT INTO 'dancesstepsmap' VALUES (20410, 16370, 4);
INSERT INTO 'dancesstepsmap' VALUES (20411, 16371, 1);
INSERT INTO 'dancesstepsmap' VALUES (20412, 16371, 2);
INSERT INTO 'dancesstepsmap' VALUES (20413, 16372, 4);
INSERT INTO 'dancesstepsmap' VALUES (20414, 16373, 3);
INSERT INTO 'dancesstepsmap' VALUES (20415, 16373, 1);
INSERT INTO 'dancesstepsmap' VALUES (20416, 16374, 5);
INSERT INTO 'dancesstepsmap' VALUES (20417, 16374, 4);
INSERT INTO 'dancesstepsmap' VALUES (20418, 16375, 1);
INSERT INTO 'dancesstepsmap' VALUES (20419, 16376, 5);
INSERT INTO 'dancesstepsmap' VALUES (20420, 16376, 4);
INSERT INTO 'dancesstepsmap' VALUES (20421, 16377, 2);
INSERT INTO 'dancesstepsmap' VALUES (20422, 16377, 1);
INSERT INTO 'dancesstepsmap' VALUES (20423, 16378, 5);
INSERT INTO 'dancesstepsmap' VALUES (20424, 16378, 4);
INSERT INTO 'dancesstepsmap' VALUES (20425, 16379, 2);
INSERT INTO 'dancesstepsmap' VALUES (20426, 16379, 1);
INSERT INTO 'dancesstepsmap' VALUES (20427, 16380, 1);
INSERT INTO 'dancesstepsmap' VALUES (20428, 16381, 2);
INSERT INTO 'dancesstepsmap' VALUES (20429, 16381, 1);
INSERT INTO 'dancesstepsmap' VALUES (20430, 16382, 1);
INSERT INTO 'dancesstepsmap' VALUES (20431, 16382, 2);
INSERT INTO 'dancesstepsmap' VALUES (20432, 16382, 3);
INSERT INTO 'dancesstepsmap' VALUES (20433, 16383, 4);
INSERT INTO 'dancesstepsmap' VALUES (20434, 16383, 5);
INSERT INTO 'dancesstepsmap' VALUES (20435, 16384, 4);
INSERT INTO 'dancesstepsmap' VALUES (20436, 16384, 5);
INSERT INTO 'dancesstepsmap' VALUES (20437, 16385, 1);
INSERT INTO 'dancesstepsmap' VALUES (20438, 16385, 2);
INSERT INTO 'dancesstepsmap' VALUES (20439, 16386, 2);
INSERT INTO 'dancesstepsmap' VALUES (20440, 16386, 1);
INSERT INTO 'dancesstepsmap' VALUES (20441, 16387, 4);
INSERT INTO 'dancesstepsmap' VALUES (20442, 16387, 5);
INSERT INTO 'dancesstepsmap' VALUES (20443, 16388, 1);
INSERT INTO 'dancesstepsmap' VALUES (20444, 16388, 2);
INSERT INTO 'dancesstepsmap' VALUES (20445, 16388, 3);
INSERT INTO 'dancesstepsmap' VALUES (20446, 16389, 5);
INSERT INTO 'dancesstepsmap' VALUES (20447, 16389, 4);
INSERT INTO 'dancesstepsmap' VALUES (20448, 16390, 9);
INSERT INTO 'dancesstepsmap' VALUES (20449, 16390, 4);
INSERT INTO 'dancesstepsmap' VALUES (20450, 16391, 4);
INSERT INTO 'dancesstepsmap' VALUES (20451, 16391, 5);
INSERT INTO 'dancesstepsmap' VALUES (20452, 16392, 1);
INSERT INTO 'dancesstepsmap' VALUES (20453, 16392, 2);
INSERT INTO 'dancesstepsmap' VALUES (20454, 16393, 1);
INSERT INTO 'dancesstepsmap' VALUES (20455, 16393, 2);
INSERT INTO 'dancesstepsmap' VALUES (20456, 16394, 4);
INSERT INTO 'dancesstepsmap' VALUES (20457, 16395, 4);
INSERT INTO 'dancesstepsmap' VALUES (20458, 16395, 5);
INSERT INTO 'dancesstepsmap' VALUES (20459, 16396, 2);
INSERT INTO 'dancesstepsmap' VALUES (20460, 16396, 1);
INSERT INTO 'dancesstepsmap' VALUES (20461, 16397, 4);
INSERT INTO 'dancesstepsmap' VALUES (20462, 16397, 5);
INSERT INTO 'dancesstepsmap' VALUES (20463, 16398, 4);
INSERT INTO 'dancesstepsmap' VALUES (20464, 16399, 2);
INSERT INTO 'dancesstepsmap' VALUES (20465, 16399, 1);
INSERT INTO 'dancesstepsmap' VALUES (20467, 16400, 4);
INSERT INTO 'dancesstepsmap' VALUES (20468, 16400, 5);
INSERT INTO 'dancesstepsmap' VALUES (20469, 16401, 1);
INSERT INTO 'dancesstepsmap' VALUES (20470, 16401, 2);
INSERT INTO 'dancesstepsmap' VALUES (20471, 16402, 1);
INSERT INTO 'dancesstepsmap' VALUES (20472, 16402, 99);
INSERT INTO 'dancesstepsmap' VALUES (20473, 16402, 2);
INSERT INTO 'dancesstepsmap' VALUES (20474, 16403, 1);
INSERT INTO 'dancesstepsmap' VALUES (20475, 16403, 2);
INSERT INTO 'dancesstepsmap' VALUES (20476, 16404, 5);
INSERT INTO 'dancesstepsmap' VALUES (20477, 16404, 4);
INSERT INTO 'dancesstepsmap' VALUES (20478, 16405, 1);
INSERT INTO 'dancesstepsmap' VALUES (20479, 16405, 2);
INSERT INTO 'dancesstepsmap' VALUES (20480, 16406, 5);
INSERT INTO 'dancesstepsmap' VALUES (20481, 16406, 4);
INSERT INTO 'dancesstepsmap' VALUES (20482, 16407, 1);
INSERT INTO 'dancesstepsmap' VALUES (20483, 16407, 2);
INSERT INTO 'dancesstepsmap' VALUES (20484, 16408, 1);
INSERT INTO 'dancesstepsmap' VALUES (20485, 16409, 1);
INSERT INTO 'dancesstepsmap' VALUES (20486, 16409, 2);
INSERT INTO 'dancesstepsmap' VALUES (20487, 16410, 1);
INSERT INTO 'dancesstepsmap' VALUES (20488, 16410, 3);
INSERT INTO 'dancesstepsmap' VALUES (20489, 16411, 5);
INSERT INTO 'dancesstepsmap' VALUES (20490, 16411, 4);
INSERT INTO 'dancesstepsmap' VALUES (20491, 16412, 1);
INSERT INTO 'dancesstepsmap' VALUES (20492, 16413, 1);
INSERT INTO 'dancesstepsmap' VALUES (20493, 16413, 3);
INSERT INTO 'dancesstepsmap' VALUES (20494, 16414, 2);
INSERT INTO 'dancesstepsmap' VALUES (20495, 16414, 1);
INSERT INTO 'dancesstepsmap' VALUES (20496, 16415, 5);
INSERT INTO 'dancesstepsmap' VALUES (20497, 16415, 4);
INSERT INTO 'dancesstepsmap' VALUES (20498, 16416, 3);
INSERT INTO 'dancesstepsmap' VALUES (20499, 16416, 2);
INSERT INTO 'dancesstepsmap' VALUES (20500, 16416, 1);
INSERT INTO 'dancesstepsmap' VALUES (20501, 16417, 2);
INSERT INTO 'dancesstepsmap' VALUES (20502, 16417, 1);
INSERT INTO 'dancesstepsmap' VALUES (20503, 16418, 5);
INSERT INTO 'dancesstepsmap' VALUES (20504, 16418, 4);
INSERT INTO 'dancesstepsmap' VALUES (20505, 16419, 5);
INSERT INTO 'dancesstepsmap' VALUES (20506, 16419, 4);
INSERT INTO 'dancesstepsmap' VALUES (20507, 16420, 1);
INSERT INTO 'dancesstepsmap' VALUES (20508, 16420, 3);
INSERT INTO 'dancesstepsmap' VALUES (20509, 16420, 2);
INSERT INTO 'dancesstepsmap' VALUES (20510, 16421, 5);
INSERT INTO 'dancesstepsmap' VALUES (20511, 16421, 4);
INSERT INTO 'dancesstepsmap' VALUES (20512, 16422, 1);
INSERT INTO 'dancesstepsmap' VALUES (20513, 16422, 3);
INSERT INTO 'dancesstepsmap' VALUES (20514, 16423, 1);
INSERT INTO 'dancesstepsmap' VALUES (20515, 16423, 2);
INSERT INTO 'dancesstepsmap' VALUES (20516, 16423, 3);
INSERT INTO 'dancesstepsmap' VALUES (20517, 16424, 2);
INSERT INTO 'dancesstepsmap' VALUES (20518, 16424, 1);
INSERT INTO 'dancesstepsmap' VALUES (20519, 16424, 3);
INSERT INTO 'dancesstepsmap' VALUES (20520, 16425, 4);
INSERT INTO 'dancesstepsmap' VALUES (20521, 16425, 5);
INSERT INTO 'dancesstepsmap' VALUES (20522, 16427, 5);
INSERT INTO 'dancesstepsmap' VALUES (20523, 16427, 4);
INSERT INTO 'dancesstepsmap' VALUES (20524, 16428, 1);
INSERT INTO 'dancesstepsmap' VALUES (20525, 16429, 3);
INSERT INTO 'dancesstepsmap' VALUES (20526, 16429, 1);
INSERT INTO 'dancesstepsmap' VALUES (20527, 16430, 4);
INSERT INTO 'dancesstepsmap' VALUES (20528, 16431, 4);
INSERT INTO 'dancesstepsmap' VALUES (20529, 16431, 5);
INSERT INTO 'dancesstepsmap' VALUES (20530, 16432, 1);
INSERT INTO 'dancesstepsmap' VALUES (20531, 16432, 2);
INSERT INTO 'dancesstepsmap' VALUES (20532, 16433, 1);
INSERT INTO 'dancesstepsmap' VALUES (20533, 16433, 2);
INSERT INTO 'dancesstepsmap' VALUES (20534, 16434, 2);
INSERT INTO 'dancesstepsmap' VALUES (20535, 16434, 1);
INSERT INTO 'dancesstepsmap' VALUES (20536, 16434, 3);
INSERT INTO 'dancesstepsmap' VALUES (20537, 15679, 1);
INSERT INTO 'dancesstepsmap' VALUES (20538, 15679, 2);
INSERT INTO 'dancesstepsmap' VALUES (20539, 15679, 3);
INSERT INTO 'dancesstepsmap' VALUES (20540, 16436, 2);
INSERT INTO 'dancesstepsmap' VALUES (20541, 16436, 1);
INSERT INTO 'dancesstepsmap' VALUES (20542, 16436, 3);
INSERT INTO 'dancesstepsmap' VALUES (20543, 16437, 4);
INSERT INTO 'dancesstepsmap' VALUES (20544, 16438, 3);
INSERT INTO 'dancesstepsmap' VALUES (20545, 16438, 1);
INSERT INTO 'dancesstepsmap' VALUES (20546, 16438, 2);
INSERT INTO 'dancesstepsmap' VALUES (20547, 16440, 4);
INSERT INTO 'dancesstepsmap' VALUES (20548, 16440, 5);
INSERT INTO 'dancesstepsmap' VALUES (20549, 16441, 1);
INSERT INTO 'dancesstepsmap' VALUES (20550, 16442, 4);
INSERT INTO 'dancesstepsmap' VALUES (20551, 16442, 5);
INSERT INTO 'dancesstepsmap' VALUES (20552, 16443, 4);
INSERT INTO 'dancesstepsmap' VALUES (20553, 16443, 5);
INSERT INTO 'dancesstepsmap' VALUES (20554, 16444, 1);
INSERT INTO 'dancesstepsmap' VALUES (20555, 16445, 2);
INSERT INTO 'dancesstepsmap' VALUES (20556, 16445, 1);
INSERT INTO 'dancesstepsmap' VALUES (20557, 16446, 1);
INSERT INTO 'dancesstepsmap' VALUES (20558, 16447, 5);
INSERT INTO 'dancesstepsmap' VALUES (20559, 16447, 4);
INSERT INTO 'dancesstepsmap' VALUES (20560, 16448, 4);
INSERT INTO 'dancesstepsmap' VALUES (20561, 16448, 5);
INSERT INTO 'dancesstepsmap' VALUES (20562, 16449, 1);
INSERT INTO 'dancesstepsmap' VALUES (20563, 16449, 2);
INSERT INTO 'dancesstepsmap' VALUES (20564, 16450, 1);
INSERT INTO 'dancesstepsmap' VALUES (20565, 16450, 2);
INSERT INTO 'dancesstepsmap' VALUES (20566, 16450, 3);
INSERT INTO 'dancesstepsmap' VALUES (20567, 16451, 4);
INSERT INTO 'dancesstepsmap' VALUES (20568, 16451, 5);
INSERT INTO 'dancesstepsmap' VALUES (20569, 7161, 5);
INSERT INTO 'dancesstepsmap' VALUES (20570, 1430, 5);
INSERT INTO 'dancesstepsmap' VALUES (20571, 16452, 4);
INSERT INTO 'dancesstepsmap' VALUES (20572, 16452, 5);
INSERT INTO 'dancesstepsmap' VALUES (20573, 16453, 4);
INSERT INTO 'dancesstepsmap' VALUES (20574, 16454, 4);
INSERT INTO 'dancesstepsmap' VALUES (20575, 16454, 5);
INSERT INTO 'dancesstepsmap' VALUES (20576, 4179, 2);
INSERT INTO 'dancesstepsmap' VALUES (20577, 16455, 1);
INSERT INTO 'dancesstepsmap' VALUES (20578, 16455, 2);
INSERT INTO 'dancesstepsmap' VALUES (20579, 5580, 5);
INSERT INTO 'dancesstepsmap' VALUES (23202, 7681, 5);
INSERT INTO 'dancesstepsmap' VALUES (20581, 16456, 1);
INSERT INTO 'dancesstepsmap' VALUES (20582, 16456, 2);
INSERT INTO 'dancesstepsmap' VALUES (20583, 16458, 5);
INSERT INTO 'dancesstepsmap' VALUES (20584, 16458, 4);
INSERT INTO 'dancesstepsmap' VALUES (20585, 16457, 5);
INSERT INTO 'dancesstepsmap' VALUES (20586, 16457, 4);
INSERT INTO 'dancesstepsmap' VALUES (15754, 12320, 4);
INSERT INTO 'dancesstepsmap' VALUES (20587, 5255, 3);
INSERT INTO 'dancesstepsmap' VALUES (20588, 16459, 2);
INSERT INTO 'dancesstepsmap' VALUES (20589, 16459, 1);
INSERT INTO 'dancesstepsmap' VALUES (20590, 16459, 3);
INSERT INTO 'dancesstepsmap' VALUES (20591, 16459, 8);
INSERT INTO 'dancesstepsmap' VALUES (20592, 16460, 3);
INSERT INTO 'dancesstepsmap' VALUES (20593, 16460, 1);
INSERT INTO 'dancesstepsmap' VALUES (20594, 16460, 2);
INSERT INTO 'dancesstepsmap' VALUES (20595, 16461, 5);
INSERT INTO 'dancesstepsmap' VALUES (20596, 16461, 4);
INSERT INTO 'dancesstepsmap' VALUES (20597, 16306, 3);
INSERT INTO 'dancesstepsmap' VALUES (20598, 8128, 5);
INSERT INTO 'dancesstepsmap' VALUES (20599, 16462, 1);
INSERT INTO 'dancesstepsmap' VALUES (20600, 16462, 2);
INSERT INTO 'dancesstepsmap' VALUES (20601, 16462, 3);
INSERT INTO 'dancesstepsmap' VALUES (20602, 559, 2);
INSERT INTO 'dancesstepsmap' VALUES (20603, 1672, 5);
INSERT INTO 'dancesstepsmap' VALUES (23235, 12347, 1);
INSERT INTO 'dancesstepsmap' VALUES (20605, 10880, 1);
INSERT INTO 'dancesstepsmap' VALUES (20606, 190, 5);
INSERT INTO 'dancesstepsmap' VALUES (20607, 10881, 1);
INSERT INTO 'dancesstepsmap' VALUES (20608, 6792, 2);
INSERT INTO 'dancesstepsmap' VALUES (20610, 7020, 2);
INSERT INTO 'dancesstepsmap' VALUES (20611, 13869, 5);
INSERT INTO 'dancesstepsmap' VALUES (20612, 13869, 4);
INSERT INTO 'dancesstepsmap' VALUES (20613, 16464, 1);
INSERT INTO 'dancesstepsmap' VALUES (20614, 16464, 2);
INSERT INTO 'dancesstepsmap' VALUES (20615, 6848, 5);
INSERT INTO 'dancesstepsmap' VALUES (20616, 16465, 2);
INSERT INTO 'dancesstepsmap' VALUES (20617, 16465, 1);
INSERT INTO 'dancesstepsmap' VALUES (20618, 16466, 1);
INSERT INTO 'dancesstepsmap' VALUES (20619, 16466, 2);
INSERT INTO 'dancesstepsmap' VALUES (23245, 18272, 1);
INSERT INTO 'dancesstepsmap' VALUES (23246, 18272, 2);
INSERT INTO 'dancesstepsmap' VALUES (23247, 18272, 3);
INSERT INTO 'dancesstepsmap' VALUES (20624, 16469, 4);
INSERT INTO 'dancesstepsmap' VALUES (20625, 16469, 5);
INSERT INTO 'dancesstepsmap' VALUES (20626, 16470, 4);
INSERT INTO 'dancesstepsmap' VALUES (20627, 16471, 4);
INSERT INTO 'dancesstepsmap' VALUES (20628, 16472, 1);
INSERT INTO 'dancesstepsmap' VALUES (20629, 16472, 2);
INSERT INTO 'dancesstepsmap' VALUES (20630, 16473, 2);
INSERT INTO 'dancesstepsmap' VALUES (20631, 16473, 1);
INSERT INTO 'dancesstepsmap' VALUES (20632, 16473, 3);
INSERT INTO 'dancesstepsmap' VALUES (20633, 16474, 2);
INSERT INTO 'dancesstepsmap' VALUES (20634, 16474, 1);
INSERT INTO 'dancesstepsmap' VALUES (20635, 16475, 4);
INSERT INTO 'dancesstepsmap' VALUES (20636, 16475, 5);
INSERT INTO 'dancesstepsmap' VALUES (20637, 16476, 2);
INSERT INTO 'dancesstepsmap' VALUES (20638, 16476, 1);
INSERT INTO 'dancesstepsmap' VALUES (20639, 16477, 5);
INSERT INTO 'dancesstepsmap' VALUES (20640, 16477, 4);
INSERT INTO 'dancesstepsmap' VALUES (20641, 16478, 4);
INSERT INTO 'dancesstepsmap' VALUES (20642, 16478, 5);
INSERT INTO 'dancesstepsmap' VALUES (20643, 16478, 1);
INSERT INTO 'dancesstepsmap' VALUES (20644, 16478, 2);
INSERT INTO 'dancesstepsmap' VALUES (20645, 16478, 3);
INSERT INTO 'dancesstepsmap' VALUES (20646, 991, 5);
INSERT INTO 'dancesstepsmap' VALUES (20647, 14601, 5);
INSERT INTO 'dancesstepsmap' VALUES (20648, 14601, 4);
INSERT INTO 'dancesstepsmap' VALUES (20649, 11627, 5);
INSERT INTO 'dancesstepsmap' VALUES (20650, 14566, 1);
INSERT INTO 'dancesstepsmap' VALUES (20651, 14566, 3);
INSERT INTO 'dancesstepsmap' VALUES (20652, 14566, 2);
INSERT INTO 'dancesstepsmap' VALUES (20653, 14797, 1);
INSERT INTO 'dancesstepsmap' VALUES (20654, 14797, 3);
INSERT INTO 'dancesstepsmap' VALUES (20655, 14797, 2);
INSERT INTO 'dancesstepsmap' VALUES (20656, 14798, 5);
INSERT INTO 'dancesstepsmap' VALUES (20657, 14798, 4);
INSERT INTO 'dancesstepsmap' VALUES (20658, 14793, 1);
INSERT INTO 'dancesstepsmap' VALUES (20659, 14793, 2);
INSERT INTO 'dancesstepsmap' VALUES (20660, 14793, 3);
INSERT INTO 'dancesstepsmap' VALUES (20661, 14796, 1);
INSERT INTO 'dancesstepsmap' VALUES (20662, 14796, 2);
INSERT INTO 'dancesstepsmap' VALUES (20663, 14790, 5);
INSERT INTO 'dancesstepsmap' VALUES (20664, 14790, 4);
INSERT INTO 'dancesstepsmap' VALUES (20665, 16480, 1);
INSERT INTO 'dancesstepsmap' VALUES (20666, 16480, 3);
INSERT INTO 'dancesstepsmap' VALUES (20669, 16481, 4);
INSERT INTO 'dancesstepsmap' VALUES (20670, 16482, 4);
INSERT INTO 'dancesstepsmap' VALUES (20671, 16482, 6);
INSERT INTO 'dancesstepsmap' VALUES (20672, 11550, 1);
INSERT INTO 'dancesstepsmap' VALUES (20673, 11550, 2);
INSERT INTO 'dancesstepsmap' VALUES (13378, 11717, 5);
INSERT INTO 'dancesstepsmap' VALUES (20674, 11717, 4);
INSERT INTO 'dancesstepsmap' VALUES (20675, 3432, 2);
INSERT INTO 'dancesstepsmap' VALUES (20676, 16483, 1);
INSERT INTO 'dancesstepsmap' VALUES (20677, 16483, 2);
INSERT INTO 'dancesstepsmap' VALUES (20678, 16484, 1);
INSERT INTO 'dancesstepsmap' VALUES (20679, 16484, 2);
INSERT INTO 'dancesstepsmap' VALUES (20680, 16484, 3);
INSERT INTO 'dancesstepsmap' VALUES (20681, 16485, 1);
INSERT INTO 'dancesstepsmap' VALUES (20682, 16485, 2);
INSERT INTO 'dancesstepsmap' VALUES (20683, 16486, 2);
INSERT INTO 'dancesstepsmap' VALUES (20684, 16486, 1);
INSERT INTO 'dancesstepsmap' VALUES (20685, 16487, 2);
INSERT INTO 'dancesstepsmap' VALUES (20686, 16487, 1);
INSERT INTO 'dancesstepsmap' VALUES (20687, 16487, 3);
INSERT INTO 'dancesstepsmap' VALUES (20688, 16488, 4);
INSERT INTO 'dancesstepsmap' VALUES (20689, 16488, 5);
INSERT INTO 'dancesstepsmap' VALUES (20690, 16489, 5);
INSERT INTO 'dancesstepsmap' VALUES (20691, 16489, 4);
INSERT INTO 'dancesstepsmap' VALUES (20692, 16490, 1);
INSERT INTO 'dancesstepsmap' VALUES (20693, 16490, 2);
INSERT INTO 'dancesstepsmap' VALUES (20694, 16491, 2);
INSERT INTO 'dancesstepsmap' VALUES (20695, 16491, 1);
INSERT INTO 'dancesstepsmap' VALUES (20696, 16491, 3);
INSERT INTO 'dancesstepsmap' VALUES (20697, 16492, 3);
INSERT INTO 'dancesstepsmap' VALUES (20698, 16492, 1);
INSERT INTO 'dancesstepsmap' VALUES (20699, 16492, 2);
INSERT INTO 'dancesstepsmap' VALUES (20700, 16493, 4);
INSERT INTO 'dancesstepsmap' VALUES (20701, 16493, 1);
INSERT INTO 'dancesstepsmap' VALUES (20702, 16493, 3);
INSERT INTO 'dancesstepsmap' VALUES (20703, 16494, 4);
INSERT INTO 'dancesstepsmap' VALUES (20704, 16494, 5);
INSERT INTO 'dancesstepsmap' VALUES (20705, 16495, 4);
INSERT INTO 'dancesstepsmap' VALUES (20706, 16495, 5);
INSERT INTO 'dancesstepsmap' VALUES (20707, 16495, 1);
INSERT INTO 'dancesstepsmap' VALUES (20708, 16495, 2);
INSERT INTO 'dancesstepsmap' VALUES (20709, 16496, 2);
INSERT INTO 'dancesstepsmap' VALUES (20710, 16496, 1);
INSERT INTO 'dancesstepsmap' VALUES (20711, 16497, 1);
INSERT INTO 'dancesstepsmap' VALUES (20712, 16498, 1);
INSERT INTO 'dancesstepsmap' VALUES (20713, 16498, 2);
INSERT INTO 'dancesstepsmap' VALUES (20714, 16498, 3);
INSERT INTO 'dancesstepsmap' VALUES (20715, 16499, 5);
INSERT INTO 'dancesstepsmap' VALUES (20716, 16499, 4);
INSERT INTO 'dancesstepsmap' VALUES (20717, 16500, 1);
INSERT INTO 'dancesstepsmap' VALUES (20718, 16501, 1);
INSERT INTO 'dancesstepsmap' VALUES (20719, 16501, 3);
INSERT INTO 'dancesstepsmap' VALUES (20667, 11716, 2);
INSERT INTO 'dancesstepsmap' VALUES (20721, 16502, 1);
INSERT INTO 'dancesstepsmap' VALUES (20722, 16503, 1);
INSERT INTO 'dancesstepsmap' VALUES (20723, 16504, 1);
INSERT INTO 'dancesstepsmap' VALUES (20724, 16504, 2);
INSERT INTO 'dancesstepsmap' VALUES (20725, 16505, 2);
INSERT INTO 'dancesstepsmap' VALUES (20726, 16505, 1);
INSERT INTO 'dancesstepsmap' VALUES (20727, 16506, 1);
INSERT INTO 'dancesstepsmap' VALUES (20728, 16506, 3);
INSERT INTO 'dancesstepsmap' VALUES (20729, 16507, 1);
INSERT INTO 'dancesstepsmap' VALUES (20730, 16507, 3);
INSERT INTO 'dancesstepsmap' VALUES (20731, 16508, 4);
INSERT INTO 'dancesstepsmap' VALUES (20732, 16508, 5);
INSERT INTO 'dancesstepsmap' VALUES (20733, 16509, 4);
INSERT INTO 'dancesstepsmap' VALUES (20734, 16509, 5);
INSERT INTO 'dancesstepsmap' VALUES (20735, 224, 2);
INSERT INTO 'dancesstepsmap' VALUES (20736, 16510, 3);
INSERT INTO 'dancesstepsmap' VALUES (20737, 16510, 1);
INSERT INTO 'dancesstepsmap' VALUES (20738, 16511, 1);
INSERT INTO 'dancesstepsmap' VALUES (20739, 16511, 2);
INSERT INTO 'dancesstepsmap' VALUES (20740, 16512, 1);
INSERT INTO 'dancesstepsmap' VALUES (20741, 16512, 2);
INSERT INTO 'dancesstepsmap' VALUES (20742, 16514, 2);
INSERT INTO 'dancesstepsmap' VALUES (20743, 16514, 1);
INSERT INTO 'dancesstepsmap' VALUES (20744, 16515, 5);
INSERT INTO 'dancesstepsmap' VALUES (20745, 16515, 4);
INSERT INTO 'dancesstepsmap' VALUES (20746, 16516, 2);
INSERT INTO 'dancesstepsmap' VALUES (20747, 16516, 1);
INSERT INTO 'dancesstepsmap' VALUES (20748, 16517, 5);
INSERT INTO 'dancesstepsmap' VALUES (20749, 16517, 4);
INSERT INTO 'dancesstepsmap' VALUES (20750, 16521, 2);
INSERT INTO 'dancesstepsmap' VALUES (20751, 16521, 1);
INSERT INTO 'dancesstepsmap' VALUES (20752, 16538, 5);
INSERT INTO 'dancesstepsmap' VALUES (20753, 16538, 4);
INSERT INTO 'dancesstepsmap' VALUES (20754, 9465, 3);
INSERT INTO 'dancesstepsmap' VALUES (20755, 16502, 2);
INSERT INTO 'dancesstepsmap' VALUES (20756, 3524, 1);
INSERT INTO 'dancesstepsmap' VALUES (20757, 3524, 2);
INSERT INTO 'dancesstepsmap' VALUES (20758, 3524, 4);
INSERT INTO 'dancesstepsmap' VALUES (20759, 3524, 6);
INSERT INTO 'dancesstepsmap' VALUES (20760, 16567, 5);
INSERT INTO 'dancesstepsmap' VALUES (20761, 16567, 4);
INSERT INTO 'dancesstepsmap' VALUES (20762, 16568, 1);
INSERT INTO 'dancesstepsmap' VALUES (20763, 16568, 2);
INSERT INTO 'dancesstepsmap' VALUES (20764, 16569, 1);
INSERT INTO 'dancesstepsmap' VALUES (20765, 16569, 2);
INSERT INTO 'dancesstepsmap' VALUES (20766, 16570, 2);
INSERT INTO 'dancesstepsmap' VALUES (20767, 16570, 1);
INSERT INTO 'dancesstepsmap' VALUES (20768, 16571, 4);
INSERT INTO 'dancesstepsmap' VALUES (20769, 16571, 5);
INSERT INTO 'dancesstepsmap' VALUES (20770, 16580, 2);
INSERT INTO 'dancesstepsmap' VALUES (20771, 16580, 1);
INSERT INTO 'dancesstepsmap' VALUES (20772, 16580, 3);
INSERT INTO 'dancesstepsmap' VALUES (20773, 16581, 1);
INSERT INTO 'dancesstepsmap' VALUES (20774, 16581, 2);
INSERT INTO 'dancesstepsmap' VALUES (20775, 16582, 5);
INSERT INTO 'dancesstepsmap' VALUES (20776, 16582, 4);
INSERT INTO 'dancesstepsmap' VALUES (20777, 16583, 1);
INSERT INTO 'dancesstepsmap' VALUES (20778, 16583, 2);
INSERT INTO 'dancesstepsmap' VALUES (20779, 16584, 4);
INSERT INTO 'dancesstepsmap' VALUES (20780, 16584, 5);
INSERT INTO 'dancesstepsmap' VALUES (20781, 16584, 1);
INSERT INTO 'dancesstepsmap' VALUES (20782, 16584, 2);
INSERT INTO 'dancesstepsmap' VALUES (20783, 16584, 3);
INSERT INTO 'dancesstepsmap' VALUES (20784, 16585, 1);
INSERT INTO 'dancesstepsmap' VALUES (20785, 16585, 2);
INSERT INTO 'dancesstepsmap' VALUES (20786, 16586, 1);
INSERT INTO 'dancesstepsmap' VALUES (20787, 16586, 2);
INSERT INTO 'dancesstepsmap' VALUES (20788, 16587, 4);
INSERT INTO 'dancesstepsmap' VALUES (20789, 16587, 5);
INSERT INTO 'dancesstepsmap' VALUES (20790, 16588, 4);
INSERT INTO 'dancesstepsmap' VALUES (20791, 16588, 5);
INSERT INTO 'dancesstepsmap' VALUES (20792, 16589, 1);
INSERT INTO 'dancesstepsmap' VALUES (20793, 16589, 2);
INSERT INTO 'dancesstepsmap' VALUES (20794, 16589, 3);
INSERT INTO 'dancesstepsmap' VALUES (20795, 16590, 1);
INSERT INTO 'dancesstepsmap' VALUES (20796, 16590, 2);
INSERT INTO 'dancesstepsmap' VALUES (20797, 16591, 5);
INSERT INTO 'dancesstepsmap' VALUES (20798, 16591, 4);
INSERT INTO 'dancesstepsmap' VALUES (20799, 16592, 1);
INSERT INTO 'dancesstepsmap' VALUES (20800, 16592, 2);
INSERT INTO 'dancesstepsmap' VALUES (20801, 16592, 3);
INSERT INTO 'dancesstepsmap' VALUES (20802, 16593, 1);
INSERT INTO 'dancesstepsmap' VALUES (20803, 16593, 2);
INSERT INTO 'dancesstepsmap' VALUES (20804, 16593, 3);
INSERT INTO 'dancesstepsmap' VALUES (20805, 16594, 1);
INSERT INTO 'dancesstepsmap' VALUES (20806, 16594, 2);
INSERT INTO 'dancesstepsmap' VALUES (20807, 9933, 4);
INSERT INTO 'dancesstepsmap' VALUES (20808, 9933, 6);
INSERT INTO 'dancesstepsmap' VALUES (20809, 16617, 4);
INSERT INTO 'dancesstepsmap' VALUES (20810, 16617, 5);
INSERT INTO 'dancesstepsmap' VALUES (20811, 15455, 4);
INSERT INTO 'dancesstepsmap' VALUES (20812, 16618, 1);
INSERT INTO 'dancesstepsmap' VALUES (20813, 16618, 2);
INSERT INTO 'dancesstepsmap' VALUES (20814, 16619, 4);
INSERT INTO 'dancesstepsmap' VALUES (20815, 16620, 1);
INSERT INTO 'dancesstepsmap' VALUES (20816, 16621, 4);
INSERT INTO 'dancesstepsmap' VALUES (20817, 16621, 5);
INSERT INTO 'dancesstepsmap' VALUES (20818, 16622, 1);
INSERT INTO 'dancesstepsmap' VALUES (20819, 16623, 1);
INSERT INTO 'dancesstepsmap' VALUES (20820, 16623, 2);
INSERT INTO 'dancesstepsmap' VALUES (20821, 16673, 4);
INSERT INTO 'dancesstepsmap' VALUES (20822, 16674, 1);
INSERT INTO 'dancesstepsmap' VALUES (20823, 16674, 2);
INSERT INTO 'dancesstepsmap' VALUES (20824, 16675, 1);
INSERT INTO 'dancesstepsmap' VALUES (20825, 16675, 2);
INSERT INTO 'dancesstepsmap' VALUES (20826, 16676, 1);
INSERT INTO 'dancesstepsmap' VALUES (20827, 16676, 2);
INSERT INTO 'dancesstepsmap' VALUES (20828, 16677, 1);
INSERT INTO 'dancesstepsmap' VALUES (20829, 16677, 2);
INSERT INTO 'dancesstepsmap' VALUES (20831, 16678, 1);
INSERT INTO 'dancesstepsmap' VALUES (20832, 16678, 3);
INSERT INTO 'dancesstepsmap' VALUES (20833, 16679, 1);
INSERT INTO 'dancesstepsmap' VALUES (20834, 16679, 2);
INSERT INTO 'dancesstepsmap' VALUES (20835, 16679, 3);
INSERT INTO 'dancesstepsmap' VALUES (20836, 16680, 1);
INSERT INTO 'dancesstepsmap' VALUES (20837, 16681, 5);
INSERT INTO 'dancesstepsmap' VALUES (20838, 16681, 4);
INSERT INTO 'dancesstepsmap' VALUES (20839, 16682, 2);
INSERT INTO 'dancesstepsmap' VALUES (20840, 16682, 1);
INSERT INTO 'dancesstepsmap' VALUES (20841, 16682, 3);
INSERT INTO 'dancesstepsmap' VALUES (20842, 16684, 4);
INSERT INTO 'dancesstepsmap' VALUES (20843, 16684, 5);
INSERT INTO 'dancesstepsmap' VALUES (20844, 16685, 1);
INSERT INTO 'dancesstepsmap' VALUES (20845, 16685, 2);
INSERT INTO 'dancesstepsmap' VALUES (20846, 16686, 1);
INSERT INTO 'dancesstepsmap' VALUES (20847, 16686, 2);
INSERT INTO 'dancesstepsmap' VALUES (20848, 16686, 3);
INSERT INTO 'dancesstepsmap' VALUES (20849, 16687, 1);
INSERT INTO 'dancesstepsmap' VALUES (20850, 16688, 1);
INSERT INTO 'dancesstepsmap' VALUES (20851, 16688, 3);
INSERT INTO 'dancesstepsmap' VALUES (20852, 16688, 2);
INSERT INTO 'dancesstepsmap' VALUES (20853, 16689, 4);
INSERT INTO 'dancesstepsmap' VALUES (20854, 16690, 1);
INSERT INTO 'dancesstepsmap' VALUES (20855, 16690, 2);
INSERT INTO 'dancesstepsmap' VALUES (20856, 16691, 5);
INSERT INTO 'dancesstepsmap' VALUES (20857, 16691, 4);
INSERT INTO 'dancesstepsmap' VALUES (20858, 16692, 4);
INSERT INTO 'dancesstepsmap' VALUES (20859, 16692, 5);
INSERT INTO 'dancesstepsmap' VALUES (20860, 16693, 4);
INSERT INTO 'dancesstepsmap' VALUES (20861, 16693, 10);
INSERT INTO 'dancesstepsmap' VALUES (20862, 16693, 1);
INSERT INTO 'dancesstepsmap' VALUES (20863, 16693, 2);
INSERT INTO 'dancesstepsmap' VALUES (20864, 16694, 4);
INSERT INTO 'dancesstepsmap' VALUES (20865, 16694, 5);
INSERT INTO 'dancesstepsmap' VALUES (20866, 16695, 1);
INSERT INTO 'dancesstepsmap' VALUES (20867, 16695, 2);
INSERT INTO 'dancesstepsmap' VALUES (20868, 16696, 4);
INSERT INTO 'dancesstepsmap' VALUES (20869, 16696, 5);
INSERT INTO 'dancesstepsmap' VALUES (20870, 16697, 1);
INSERT INTO 'dancesstepsmap' VALUES (20871, 16698, 4);
INSERT INTO 'dancesstepsmap' VALUES (20872, 16698, 5);
INSERT INTO 'dancesstepsmap' VALUES (20873, 984, 2);
INSERT INTO 'dancesstepsmap' VALUES (20874, 454, 2);
INSERT INTO 'dancesstepsmap' VALUES (20875, 1038, 2);
INSERT INTO 'dancesstepsmap' VALUES (20876, 16699, 1);
INSERT INTO 'dancesstepsmap' VALUES (20877, 16699, 3);
INSERT INTO 'dancesstepsmap' VALUES (20878, 16700, 1);
INSERT INTO 'dancesstepsmap' VALUES (20879, 16700, 2);
INSERT INTO 'dancesstepsmap' VALUES (20880, 16701, 2);
INSERT INTO 'dancesstepsmap' VALUES (20881, 16701, 3);
INSERT INTO 'dancesstepsmap' VALUES (20882, 16701, 1);
INSERT INTO 'dancesstepsmap' VALUES (20883, 16702, 2);
INSERT INTO 'dancesstepsmap' VALUES (20884, 16702, 1);
INSERT INTO 'dancesstepsmap' VALUES (20885, 16702, 3);
INSERT INTO 'dancesstepsmap' VALUES (20886, 16703, 2);
INSERT INTO 'dancesstepsmap' VALUES (20887, 16703, 1);
INSERT INTO 'dancesstepsmap' VALUES (20888, 16704, 2);
INSERT INTO 'dancesstepsmap' VALUES (20889, 16704, 1);
INSERT INTO 'dancesstepsmap' VALUES (20890, 16704, 99);
INSERT INTO 'dancesstepsmap' VALUES (20891, 16705, 2);
INSERT INTO 'dancesstepsmap' VALUES (20892, 16705, 1);
INSERT INTO 'dancesstepsmap' VALUES (23203, 7686, 2);
INSERT INTO 'dancesstepsmap' VALUES (23204, 12148, 1);
INSERT INTO 'dancesstepsmap' VALUES (20895, 16707, 1);
INSERT INTO 'dancesstepsmap' VALUES (20896, 16708, 3);
INSERT INTO 'dancesstepsmap' VALUES (20897, 16708, 1);
INSERT INTO 'dancesstepsmap' VALUES (20898, 16708, 2);
INSERT INTO 'dancesstepsmap' VALUES (20899, 16710, 2);
INSERT INTO 'dancesstepsmap' VALUES (20900, 16710, 1);
INSERT INTO 'dancesstepsmap' VALUES (20901, 16711, 2);
INSERT INTO 'dancesstepsmap' VALUES (20902, 16711, 1);
INSERT INTO 'dancesstepsmap' VALUES (20903, 16712, 2);
INSERT INTO 'dancesstepsmap' VALUES (20904, 16712, 1);
INSERT INTO 'dancesstepsmap' VALUES (20905, 16712, 3);
INSERT INTO 'dancesstepsmap' VALUES (20906, 16713, 1);
INSERT INTO 'dancesstepsmap' VALUES (20907, 16713, 2);
INSERT INTO 'dancesstepsmap' VALUES (20908, 16714, 1);
INSERT INTO 'dancesstepsmap' VALUES (20909, 16714, 2);
INSERT INTO 'dancesstepsmap' VALUES (20910, 16714, 3);
INSERT INTO 'dancesstepsmap' VALUES (20911, 16715, 2);
INSERT INTO 'dancesstepsmap' VALUES (20912, 16715, 1);
INSERT INTO 'dancesstepsmap' VALUES (20913, 16716, 1);
INSERT INTO 'dancesstepsmap' VALUES (20914, 16717, 3);
INSERT INTO 'dancesstepsmap' VALUES (20915, 16717, 1);
INSERT INTO 'dancesstepsmap' VALUES (20916, 16718, 5);
INSERT INTO 'dancesstepsmap' VALUES (20917, 16718, 4);
INSERT INTO 'dancesstepsmap' VALUES (20918, 16719, 4);
INSERT INTO 'dancesstepsmap' VALUES (20919, 16720, 6);
INSERT INTO 'dancesstepsmap' VALUES (20920, 16720, 4);
INSERT INTO 'dancesstepsmap' VALUES (20921, 16720, 5);
INSERT INTO 'dancesstepsmap' VALUES (20922, 16721, 4);
INSERT INTO 'dancesstepsmap' VALUES (20923, 16722, 4);
INSERT INTO 'dancesstepsmap' VALUES (20924, 16722, 5);
INSERT INTO 'dancesstepsmap' VALUES (20925, 16723, 4);
INSERT INTO 'dancesstepsmap' VALUES (20926, 16723, 5);
INSERT INTO 'dancesstepsmap' VALUES (20927, 16724, 5);
INSERT INTO 'dancesstepsmap' VALUES (20928, 16724, 4);
INSERT INTO 'dancesstepsmap' VALUES (20929, 16726, 2);
INSERT INTO 'dancesstepsmap' VALUES (20930, 16726, 1);
INSERT INTO 'dancesstepsmap' VALUES (20931, 16727, 4);
INSERT INTO 'dancesstepsmap' VALUES (20932, 16727, 5);
INSERT INTO 'dancesstepsmap' VALUES (20933, 16728, 2);
INSERT INTO 'dancesstepsmap' VALUES (20934, 16728, 1);
INSERT INTO 'dancesstepsmap' VALUES (20937, 16730, 1);
INSERT INTO 'dancesstepsmap' VALUES (20938, 16730, 3);
INSERT INTO 'dancesstepsmap' VALUES (20939, 16536, 1);
INSERT INTO 'dancesstepsmap' VALUES (20940, 16536, 2);
INSERT INTO 'dancesstepsmap' VALUES (20941, 16536, 5);
INSERT INTO 'dancesstepsmap' VALUES (20942, 16536, 4);
INSERT INTO 'dancesstepsmap' VALUES (20943, 16725, 4);
INSERT INTO 'dancesstepsmap' VALUES (20944, 16725, 5);
INSERT INTO 'dancesstepsmap' VALUES (20945, 2084, 2);
INSERT INTO 'dancesstepsmap' VALUES (20946, 2084, 3);
INSERT INTO 'dancesstepsmap' VALUES (20947, 14679, 3);
INSERT INTO 'dancesstepsmap' VALUES (20948, 16731, 2);
INSERT INTO 'dancesstepsmap' VALUES (20949, 16731, 1);
INSERT INTO 'dancesstepsmap' VALUES (20950, 2585, 2);
INSERT INTO 'dancesstepsmap' VALUES (20951, 1957, 5);
INSERT INTO 'dancesstepsmap' VALUES (20952, 7436, 1);
INSERT INTO 'dancesstepsmap' VALUES (20953, 7436, 2);
INSERT INTO 'dancesstepsmap' VALUES (20954, 16733, 2);
INSERT INTO 'dancesstepsmap' VALUES (20955, 16733, 1);
INSERT INTO 'dancesstepsmap' VALUES (20956, 16734, 1);
INSERT INTO 'dancesstepsmap' VALUES (20957, 16734, 2);
INSERT INTO 'dancesstepsmap' VALUES (20958, 16735, 1);
INSERT INTO 'dancesstepsmap' VALUES (20959, 16735, 2);
INSERT INTO 'dancesstepsmap' VALUES (20960, 13705, 2);
INSERT INTO 'dancesstepsmap' VALUES (20961, 16736, 1);
INSERT INTO 'dancesstepsmap' VALUES (20962, 16736, 2);
INSERT INTO 'dancesstepsmap' VALUES (20964, 16737, 1);
INSERT INTO 'dancesstepsmap' VALUES (20965, 2769, 5);
INSERT INTO 'dancesstepsmap' VALUES (20966, 2769, 4);
INSERT INTO 'dancesstepsmap' VALUES (20967, 2769, 1);
INSERT INTO 'dancesstepsmap' VALUES (20968, 2769, 2);
INSERT INTO 'dancesstepsmap' VALUES (20969, 16738, 1);
INSERT INTO 'dancesstepsmap' VALUES (20970, 16738, 3);
INSERT INTO 'dancesstepsmap' VALUES (20103, 16217, 1);
INSERT INTO 'dancesstepsmap' VALUES (20104, 16217, 2);
INSERT INTO 'dancesstepsmap' VALUES (20971, 13831, 1);
INSERT INTO 'dancesstepsmap' VALUES (20972, 13831, 2);
INSERT INTO 'dancesstepsmap' VALUES (10769, 9980, 5);
INSERT INTO 'dancesstepsmap' VALUES (20973, 16739, 1);
INSERT INTO 'dancesstepsmap' VALUES (20974, 16740, 1);
INSERT INTO 'dancesstepsmap' VALUES (20975, 16741, 1);
INSERT INTO 'dancesstepsmap' VALUES (20976, 16741, 2);
INSERT INTO 'dancesstepsmap' VALUES (20977, 16742, 5);
INSERT INTO 'dancesstepsmap' VALUES (20978, 16742, 4);
INSERT INTO 'dancesstepsmap' VALUES (20979, 16743, 4);
INSERT INTO 'dancesstepsmap' VALUES (20980, 16743, 5);
INSERT INTO 'dancesstepsmap' VALUES (20981, 16744, 5);
INSERT INTO 'dancesstepsmap' VALUES (20982, 16744, 4);
INSERT INTO 'dancesstepsmap' VALUES (20983, 16745, 1);
INSERT INTO 'dancesstepsmap' VALUES (20984, 16745, 2);
INSERT INTO 'dancesstepsmap' VALUES (20985, 16746, 2);
INSERT INTO 'dancesstepsmap' VALUES (20986, 16746, 1);
INSERT INTO 'dancesstepsmap' VALUES (20987, 16746, 3);
INSERT INTO 'dancesstepsmap' VALUES (20988, 16747, 1);
INSERT INTO 'dancesstepsmap' VALUES (20989, 16748, 1);
INSERT INTO 'dancesstepsmap' VALUES (20990, 16748, 2);
INSERT INTO 'dancesstepsmap' VALUES (20991, 16749, 2);
INSERT INTO 'dancesstepsmap' VALUES (20992, 16749, 1);
INSERT INTO 'dancesstepsmap' VALUES (20993, 16738, 2);
INSERT INTO 'dancesstepsmap' VALUES (20994, 16522, 1);
INSERT INTO 'dancesstepsmap' VALUES (20995, 16522, 2);
INSERT INTO 'dancesstepsmap' VALUES (20996, 16523, 2);
INSERT INTO 'dancesstepsmap' VALUES (20997, 16523, 1);
INSERT INTO 'dancesstepsmap' VALUES (20998, 16524, 5);
INSERT INTO 'dancesstepsmap' VALUES (20999, 16524, 4);
INSERT INTO 'dancesstepsmap' VALUES (21000, 16750, 1);
INSERT INTO 'dancesstepsmap' VALUES (21001, 16751, 2);
INSERT INTO 'dancesstepsmap' VALUES (21002, 16751, 1);
INSERT INTO 'dancesstepsmap' VALUES (21003, 16752, 5);
INSERT INTO 'dancesstepsmap' VALUES (21004, 16752, 4);
INSERT INTO 'dancesstepsmap' VALUES (21005, 16753, 4);
INSERT INTO 'dancesstepsmap' VALUES (21006, 16753, 5);
INSERT INTO 'dancesstepsmap' VALUES (21007, 16754, 2);
INSERT INTO 'dancesstepsmap' VALUES (21008, 16754, 1);
INSERT INTO 'dancesstepsmap' VALUES (21009, 16755, 4);
INSERT INTO 'dancesstepsmap' VALUES (21010, 16756, 1);
INSERT INTO 'dancesstepsmap' VALUES (21011, 16756, 2);
INSERT INTO 'dancesstepsmap' VALUES (21012, 16757, 5);
INSERT INTO 'dancesstepsmap' VALUES (21013, 16757, 4);
INSERT INTO 'dancesstepsmap' VALUES (21014, 16758, 4);
INSERT INTO 'dancesstepsmap' VALUES (21015, 16758, 5);
INSERT INTO 'dancesstepsmap' VALUES (21016, 16758, 1);
INSERT INTO 'dancesstepsmap' VALUES (21017, 16758, 2);
INSERT INTO 'dancesstepsmap' VALUES (21018, 16759, 2);
INSERT INTO 'dancesstepsmap' VALUES (21019, 16759, 1);
INSERT INTO 'dancesstepsmap' VALUES (21020, 16759, 3);
INSERT INTO 'dancesstepsmap' VALUES (21021, 16760, 4);
INSERT INTO 'dancesstepsmap' VALUES (21022, 16760, 5);
INSERT INTO 'dancesstepsmap' VALUES (21023, 16525, 1);
INSERT INTO 'dancesstepsmap' VALUES (23205, 12148, 2);
INSERT INTO 'dancesstepsmap' VALUES (21024, 16525, 2);
INSERT INTO 'dancesstepsmap' VALUES (21025, 16526, 4);
INSERT INTO 'dancesstepsmap' VALUES (21026, 16526, 5);
INSERT INTO 'dancesstepsmap' VALUES (21027, 16761, 1);
INSERT INTO 'dancesstepsmap' VALUES (21028, 16761, 2);
INSERT INTO 'dancesstepsmap' VALUES (21029, 16762, 3);
INSERT INTO 'dancesstepsmap' VALUES (21030, 16762, 1);
INSERT INTO 'dancesstepsmap' VALUES (21031, 16763, 2);
INSERT INTO 'dancesstepsmap' VALUES (21032, 16763, 1);
INSERT INTO 'dancesstepsmap' VALUES (21033, 16763, 3);
INSERT INTO 'dancesstepsmap' VALUES (21034, 16764, 3);
INSERT INTO 'dancesstepsmap' VALUES (21035, 16764, 1);
INSERT INTO 'dancesstepsmap' VALUES (23206, 12148, 3);
INSERT INTO 'dancesstepsmap' VALUES (23236, 12171, 4);
INSERT INTO 'dancesstepsmap' VALUES (21038, 6143, 2);
INSERT INTO 'dancesstepsmap' VALUES (21039, 16767, 2);
INSERT INTO 'dancesstepsmap' VALUES (21040, 16767, 1);
INSERT INTO 'dancesstepsmap' VALUES (21041, 16527, 2);
INSERT INTO 'dancesstepsmap' VALUES (21042, 16527, 1);
INSERT INTO 'dancesstepsmap' VALUES (21043, 16771, 5);
INSERT INTO 'dancesstepsmap' VALUES (21044, 16771, 4);
INSERT INTO 'dancesstepsmap' VALUES (21045, 16772, 4);
INSERT INTO 'dancesstepsmap' VALUES (21046, 8775, 2);
INSERT INTO 'dancesstepsmap' VALUES (21047, 8775, 1);
INSERT INTO 'dancesstepsmap' VALUES (21048, 8775, 3);
INSERT INTO 'dancesstepsmap' VALUES (21049, 16773, 5);
INSERT INTO 'dancesstepsmap' VALUES (21050, 16773, 4);
INSERT INTO 'dancesstepsmap' VALUES (21051, 16774, 5);
INSERT INTO 'dancesstepsmap' VALUES (21052, 16774, 4);
INSERT INTO 'dancesstepsmap' VALUES (21053, 9540, 1);
INSERT INTO 'dancesstepsmap' VALUES (21054, 9540, 2);
INSERT INTO 'dancesstepsmap' VALUES (21055, 16776, 2);
INSERT INTO 'dancesstepsmap' VALUES (21056, 16776, 1);
INSERT INTO 'dancesstepsmap' VALUES (21057, 16776, 3);
INSERT INTO 'dancesstepsmap' VALUES (21058, 5000, 5);
INSERT INTO 'dancesstepsmap' VALUES (21059, 16633, 5);
INSERT INTO 'dancesstepsmap' VALUES (21060, 16633, 4);
INSERT INTO 'dancesstepsmap' VALUES (21061, 16634, 1);
INSERT INTO 'dancesstepsmap' VALUES (21062, 16634, 2);
INSERT INTO 'dancesstepsmap' VALUES (21063, 16785, 1);
INSERT INTO 'dancesstepsmap' VALUES (21064, 16785, 3);
INSERT INTO 'dancesstepsmap' VALUES (21065, 16786, 5);
INSERT INTO 'dancesstepsmap' VALUES (21066, 16786, 4);
INSERT INTO 'dancesstepsmap' VALUES (21067, 16537, 1);
INSERT INTO 'dancesstepsmap' VALUES (21068, 16537, 2);
INSERT INTO 'dancesstepsmap' VALUES (21069, 7501, 5);
INSERT INTO 'dancesstepsmap' VALUES (21070, 14985, 1);
INSERT INTO 'dancesstepsmap' VALUES (21071, 14985, 2);
INSERT INTO 'dancesstepsmap' VALUES (21072, 15032, 1);
INSERT INTO 'dancesstepsmap' VALUES (23237, 4057, 2);
INSERT INTO 'dancesstepsmap' VALUES (23238, 18267, 5);
INSERT INTO 'dancesstepsmap' VALUES (21077, 12579, 5);
INSERT INTO 'dancesstepsmap' VALUES (21078, 15326, 5);
INSERT INTO 'dancesstepsmap' VALUES (21079, 15326, 4);
INSERT INTO 'dancesstepsmap' VALUES (21080, 16802, 2);
INSERT INTO 'dancesstepsmap' VALUES (21081, 16802, 1);
INSERT INTO 'dancesstepsmap' VALUES (21082, 16803, 1);
INSERT INTO 'dancesstepsmap' VALUES (21083, 16803, 3);
INSERT INTO 'dancesstepsmap' VALUES (21084, 16804, 2);
INSERT INTO 'dancesstepsmap' VALUES (21085, 16804, 1);
INSERT INTO 'dancesstepsmap' VALUES (21086, 16804, 3);
INSERT INTO 'dancesstepsmap' VALUES (21087, 3483, 5);
INSERT INTO 'dancesstepsmap' VALUES (21088, 3466, 2);
INSERT INTO 'dancesstepsmap' VALUES (21089, 9640, 1);
INSERT INTO 'dancesstepsmap' VALUES (21090, 10737, 4);
INSERT INTO 'dancesstepsmap' VALUES (21091, 10737, 5);
INSERT INTO 'dancesstepsmap' VALUES (21092, 8335, 2);
INSERT INTO 'dancesstepsmap' VALUES (21093, 16815, 1);
INSERT INTO 'dancesstepsmap' VALUES (21094, 16815, 2);
INSERT INTO 'dancesstepsmap' VALUES (21095, 16815, 3);
INSERT INTO 'dancesstepsmap' VALUES (21096, 16816, 5);
INSERT INTO 'dancesstepsmap' VALUES (21097, 16816, 4);
INSERT INTO 'dancesstepsmap' VALUES (21100, 16820, 4);
INSERT INTO 'dancesstepsmap' VALUES (21101, 16709, 2);
INSERT INTO 'dancesstepsmap' VALUES (21102, 16709, 1);
INSERT INTO 'dancesstepsmap' VALUES (21103, 10028, 2);
INSERT INTO 'dancesstepsmap' VALUES (21104, 10028, 1);
INSERT INTO 'dancesstepsmap' VALUES (21105, 4266, 6);
INSERT INTO 'dancesstepsmap' VALUES (21106, 13931, 1);
INSERT INTO 'dancesstepsmap' VALUES (21107, 16822, 5);
INSERT INTO 'dancesstepsmap' VALUES (21108, 16822, 4);
INSERT INTO 'dancesstepsmap' VALUES (21109, 16823, 2);
INSERT INTO 'dancesstepsmap' VALUES (21110, 16823, 1);
INSERT INTO 'dancesstepsmap' VALUES (21111, 14025, 1);
INSERT INTO 'dancesstepsmap' VALUES (21112, 16824, 1);
INSERT INTO 'dancesstepsmap' VALUES (21113, 16824, 3);
INSERT INTO 'dancesstepsmap' VALUES (21114, 16824, 2);
INSERT INTO 'dancesstepsmap' VALUES (21115, 3695, 2);
INSERT INTO 'dancesstepsmap' VALUES (21116, 16825, 1);
INSERT INTO 'dancesstepsmap' VALUES (21117, 16827, 1);
INSERT INTO 'dancesstepsmap' VALUES (21118, 16828, 2);
INSERT INTO 'dancesstepsmap' VALUES (21119, 16828, 1);
INSERT INTO 'dancesstepsmap' VALUES (21120, 16828, 3);
INSERT INTO 'dancesstepsmap' VALUES (21121, 16829, 1);
INSERT INTO 'dancesstepsmap' VALUES (21122, 16829, 2);
INSERT INTO 'dancesstepsmap' VALUES (21123, 16838, 4);
INSERT INTO 'dancesstepsmap' VALUES (21124, 16838, 1);
INSERT INTO 'dancesstepsmap' VALUES (21125, 16838, 3);
INSERT INTO 'dancesstepsmap' VALUES (21126, 9927, 1);
INSERT INTO 'dancesstepsmap' VALUES (21127, 9927, 2);
INSERT INTO 'dancesstepsmap' VALUES (21128, 9928, 4);
INSERT INTO 'dancesstepsmap' VALUES (21129, 9928, 5);
INSERT INTO 'dancesstepsmap' VALUES (21130, 9932, 2);
INSERT INTO 'dancesstepsmap' VALUES (21131, 9932, 1);
INSERT INTO 'dancesstepsmap' VALUES (21133, 16635, 5);
INSERT INTO 'dancesstepsmap' VALUES (21134, 16635, 4);
INSERT INTO 'dancesstepsmap' VALUES (21135, 16636, 5);
INSERT INTO 'dancesstepsmap' VALUES (21136, 16636, 4);
INSERT INTO 'dancesstepsmap' VALUES (21137, 16637, 1);
INSERT INTO 'dancesstepsmap' VALUES (21138, 16637, 3);
INSERT INTO 'dancesstepsmap' VALUES (21139, 16672, 4);
INSERT INTO 'dancesstepsmap' VALUES (21140, 16639, 1);
INSERT INTO 'dancesstepsmap' VALUES (21141, 16639, 2);
INSERT INTO 'dancesstepsmap' VALUES (21142, 16640, 2);
INSERT INTO 'dancesstepsmap' VALUES (21143, 16640, 1);
INSERT INTO 'dancesstepsmap' VALUES (21144, 16640, 3);
INSERT INTO 'dancesstepsmap' VALUES (21145, 16641, 1);
INSERT INTO 'dancesstepsmap' VALUES (21146, 16641, 3);
INSERT INTO 'dancesstepsmap' VALUES (21147, 16642, 1);
INSERT INTO 'dancesstepsmap' VALUES (21148, 16642, 2);
INSERT INTO 'dancesstepsmap' VALUES (21149, 16643, 1);
INSERT INTO 'dancesstepsmap' VALUES (21150, 16643, 3);
INSERT INTO 'dancesstepsmap' VALUES (21151, 16643, 2);
INSERT INTO 'dancesstepsmap' VALUES (21152, 16644, 1);
INSERT INTO 'dancesstepsmap' VALUES (21153, 16645, 1);
INSERT INTO 'dancesstepsmap' VALUES (21154, 16645, 2);
INSERT INTO 'dancesstepsmap' VALUES (21155, 16645, 3);
INSERT INTO 'dancesstepsmap' VALUES (21156, 16646, 5);
INSERT INTO 'dancesstepsmap' VALUES (21157, 16646, 4);
INSERT INTO 'dancesstepsmap' VALUES (21158, 4832, 2);
INSERT INTO 'dancesstepsmap' VALUES (21160, 16647, 1);
INSERT INTO 'dancesstepsmap' VALUES (21161, 16647, 2);
INSERT INTO 'dancesstepsmap' VALUES (21162, 16647, 3);
INSERT INTO 'dancesstepsmap' VALUES (21163, 16648, 4);
INSERT INTO 'dancesstepsmap' VALUES (21164, 16648, 5);
INSERT INTO 'dancesstepsmap' VALUES (21165, 16649, 5);
INSERT INTO 'dancesstepsmap' VALUES (21166, 16649, 4);
INSERT INTO 'dancesstepsmap' VALUES (21167, 16650, 1);
INSERT INTO 'dancesstepsmap' VALUES (21168, 16650, 3);
INSERT INTO 'dancesstepsmap' VALUES (21169, 16839, 4);
INSERT INTO 'dancesstepsmap' VALUES (21170, 16839, 5);
INSERT INTO 'dancesstepsmap' VALUES (21171, 16840, 3);
INSERT INTO 'dancesstepsmap' VALUES (21172, 16840, 1);
INSERT INTO 'dancesstepsmap' VALUES (21173, 16840, 2);
INSERT INTO 'dancesstepsmap' VALUES (21174, 16838, 8);
INSERT INTO 'dancesstepsmap' VALUES (21175, 15410, 1);
INSERT INTO 'dancesstepsmap' VALUES (21176, 15410, 3);
INSERT INTO 'dancesstepsmap' VALUES (21177, 15410, 2);
INSERT INTO 'dancesstepsmap' VALUES (21178, 16843, 1);
INSERT INTO 'dancesstepsmap' VALUES (21179, 16842, 5);
INSERT INTO 'dancesstepsmap' VALUES (21180, 16842, 4);
INSERT INTO 'dancesstepsmap' VALUES (21181, 1985, 2);
INSERT INTO 'dancesstepsmap' VALUES (21182, 16844, 1);
INSERT INTO 'dancesstepsmap' VALUES (21183, 16844, 3);
INSERT INTO 'dancesstepsmap' VALUES (21184, 16845, 4);
INSERT INTO 'dancesstepsmap' VALUES (21185, 16845, 5);
INSERT INTO 'dancesstepsmap' VALUES (21186, 16846, 1);
INSERT INTO 'dancesstepsmap' VALUES (21187, 16846, 2);
INSERT INTO 'dancesstepsmap' VALUES (21188, 16846, 3);
INSERT INTO 'dancesstepsmap' VALUES (21189, 16848, 1);
INSERT INTO 'dancesstepsmap' VALUES (21190, 16848, 2);
INSERT INTO 'dancesstepsmap' VALUES (21191, 16849, 2);
INSERT INTO 'dancesstepsmap' VALUES (21192, 16849, 1);
INSERT INTO 'dancesstepsmap' VALUES (21193, 16849, 3);
INSERT INTO 'dancesstepsmap' VALUES (21194, 16850, 2);
INSERT INTO 'dancesstepsmap' VALUES (21195, 16850, 1);
INSERT INTO 'dancesstepsmap' VALUES (21198, 16852, 4);
INSERT INTO 'dancesstepsmap' VALUES (21199, 16852, 5);
INSERT INTO 'dancesstepsmap' VALUES (21200, 16853, 5);
INSERT INTO 'dancesstepsmap' VALUES (21201, 16853, 4);
INSERT INTO 'dancesstepsmap' VALUES (21202, 16854, 2);
INSERT INTO 'dancesstepsmap' VALUES (21203, 16854, 1);
INSERT INTO 'dancesstepsmap' VALUES (23207, 12157, 1);
INSERT INTO 'dancesstepsmap' VALUES (23208, 12157, 2);
INSERT INTO 'dancesstepsmap' VALUES (23209, 12346, 4);
INSERT INTO 'dancesstepsmap' VALUES (21207, 16856, 2);
INSERT INTO 'dancesstepsmap' VALUES (21208, 16856, 1);
INSERT INTO 'dancesstepsmap' VALUES (21209, 8856, 2);
INSERT INTO 'dancesstepsmap' VALUES (21210, 8856, 1);
INSERT INTO 'dancesstepsmap' VALUES (21211, 16535, 1);
INSERT INTO 'dancesstepsmap' VALUES (21212, 16535, 8);
INSERT INTO 'dancesstepsmap' VALUES (21213, 16857, 5);
INSERT INTO 'dancesstepsmap' VALUES (21214, 16857, 4);
INSERT INTO 'dancesstepsmap' VALUES (21215, 16857, 1);
INSERT INTO 'dancesstepsmap' VALUES (21216, 16857, 2);
INSERT INTO 'dancesstepsmap' VALUES (21217, 16857, 3);
INSERT INTO 'dancesstepsmap' VALUES (21218, 14457, 1);
INSERT INTO 'dancesstepsmap' VALUES (21219, 14457, 2);
INSERT INTO 'dancesstepsmap' VALUES (21220, 14457, 3);
INSERT INTO 'dancesstepsmap' VALUES (21221, 16858, 5);
INSERT INTO 'dancesstepsmap' VALUES (21222, 16858, 4);
INSERT INTO 'dancesstepsmap' VALUES (21223, 16858, 1);
INSERT INTO 'dancesstepsmap' VALUES (21224, 16858, 2);
INSERT INTO 'dancesstepsmap' VALUES (21225, 7637, 5);
INSERT INTO 'dancesstepsmap' VALUES (21226, 15613, 2);
INSERT INTO 'dancesstepsmap' VALUES (21227, 15613, 1);
INSERT INTO 'dancesstepsmap' VALUES (21228, 15613, 3);
INSERT INTO 'dancesstepsmap' VALUES (21229, 15038, 1);
INSERT INTO 'dancesstepsmap' VALUES (21230, 16868, 5);
INSERT INTO 'dancesstepsmap' VALUES (21231, 16868, 4);
INSERT INTO 'dancesstepsmap' VALUES (21232, 16868, 1);
INSERT INTO 'dancesstepsmap' VALUES (21233, 16868, 3);
INSERT INTO 'dancesstepsmap' VALUES (21234, 16868, 2);
INSERT INTO 'dancesstepsmap' VALUES (21235, 8492, 5);
INSERT INTO 'dancesstepsmap' VALUES (21236, 16869, 1);
INSERT INTO 'dancesstepsmap' VALUES (21237, 16869, 2);
INSERT INTO 'dancesstepsmap' VALUES (21238, 7559, 2);
INSERT INTO 'dancesstepsmap' VALUES (21239, 7559, 3);
INSERT INTO 'dancesstepsmap' VALUES (21240, 16870, 1);
INSERT INTO 'dancesstepsmap' VALUES (21241, 16870, 2);
INSERT INTO 'dancesstepsmap' VALUES (21242, 16871, 1);
INSERT INTO 'dancesstepsmap' VALUES (21243, 16871, 2);
INSERT INTO 'dancesstepsmap' VALUES (21244, 16871, 5);
INSERT INTO 'dancesstepsmap' VALUES (21245, 16871, 4);
INSERT INTO 'dancesstepsmap' VALUES (21246, 16872, 1);
INSERT INTO 'dancesstepsmap' VALUES (21247, 10610, 1);
INSERT INTO 'dancesstepsmap' VALUES (21248, 10610, 2);
INSERT INTO 'dancesstepsmap' VALUES (21249, 10610, 3);
INSERT INTO 'dancesstepsmap' VALUES (21250, 10596, 1);
INSERT INTO 'dancesstepsmap' VALUES (21251, 10609, 5);
INSERT INTO 'dancesstepsmap' VALUES (21252, 10609, 4);
INSERT INTO 'dancesstepsmap' VALUES (21253, 10608, 2);
INSERT INTO 'dancesstepsmap' VALUES (21254, 10608, 1);
INSERT INTO 'dancesstepsmap' VALUES (21255, 2673, 2);
INSERT INTO 'dancesstepsmap' VALUES (21256, 2673, 8);
INSERT INTO 'dancesstepsmap' VALUES (21257, 2673, 3);
INSERT INTO 'dancesstepsmap' VALUES (21258, 3739, 2);
INSERT INTO 'dancesstepsmap' VALUES (21259, 16888, 1);
INSERT INTO 'dancesstepsmap' VALUES (21260, 16888, 2);
INSERT INTO 'dancesstepsmap' VALUES (21261, 16885, 2);
INSERT INTO 'dancesstepsmap' VALUES (21262, 16885, 1);
INSERT INTO 'dancesstepsmap' VALUES (21263, 16889, 2);
INSERT INTO 'dancesstepsmap' VALUES (21264, 16889, 1);
INSERT INTO 'dancesstepsmap' VALUES (21265, 16886, 2);
INSERT INTO 'dancesstepsmap' VALUES (21266, 16886, 1);
INSERT INTO 'dancesstepsmap' VALUES (21267, 16890, 5);
INSERT INTO 'dancesstepsmap' VALUES (21268, 16890, 4);
INSERT INTO 'dancesstepsmap' VALUES (21269, 16884, 5);
INSERT INTO 'dancesstepsmap' VALUES (21270, 16884, 4);
INSERT INTO 'dancesstepsmap' VALUES (21271, 16887, 2);
INSERT INTO 'dancesstepsmap' VALUES (21272, 16887, 1);
INSERT INTO 'dancesstepsmap' VALUES (21273, 16891, 1);
INSERT INTO 'dancesstepsmap' VALUES (21274, 16891, 2);
INSERT INTO 'dancesstepsmap' VALUES (21275, 6078, 5);
INSERT INTO 'dancesstepsmap' VALUES (21276, 16892, 99);
INSERT INTO 'dancesstepsmap' VALUES (21277, 10698, 1);
INSERT INTO 'dancesstepsmap' VALUES (21278, 10698, 2);
INSERT INTO 'dancesstepsmap' VALUES (21279, 16893, 5);
INSERT INTO 'dancesstepsmap' VALUES (21280, 16893, 4);
INSERT INTO 'dancesstepsmap' VALUES (21281, 16894, 5);
INSERT INTO 'dancesstepsmap' VALUES (21282, 16894, 4);
INSERT INTO 'dancesstepsmap' VALUES (21283, 16896, 4);
INSERT INTO 'dancesstepsmap' VALUES (21284, 16896, 5);
INSERT INTO 'dancesstepsmap' VALUES (21285, 16897, 1);
INSERT INTO 'dancesstepsmap' VALUES (21286, 16897, 2);
INSERT INTO 'dancesstepsmap' VALUES (21287, 16898, 2);
INSERT INTO 'dancesstepsmap' VALUES (21288, 16898, 1);
INSERT INTO 'dancesstepsmap' VALUES (21291, 16900, 1);
INSERT INTO 'dancesstepsmap' VALUES (21292, 16901, 1);
INSERT INTO 'dancesstepsmap' VALUES (21295, 16895, 5);
INSERT INTO 'dancesstepsmap' VALUES (21296, 16895, 4);
INSERT INTO 'dancesstepsmap' VALUES (21297, 9417, 5);
INSERT INTO 'dancesstepsmap' VALUES (21298, 16903, 1);
INSERT INTO 'dancesstepsmap' VALUES (21299, 16904, 5);
INSERT INTO 'dancesstepsmap' VALUES (21300, 16904, 4);
INSERT INTO 'dancesstepsmap' VALUES (21301, 16904, 1);
INSERT INTO 'dancesstepsmap' VALUES (21302, 16904, 2);
INSERT INTO 'dancesstepsmap' VALUES (21303, 16905, 2);
INSERT INTO 'dancesstepsmap' VALUES (21304, 16905, 1);
INSERT INTO 'dancesstepsmap' VALUES (21305, 16906, 5);
INSERT INTO 'dancesstepsmap' VALUES (21306, 16906, 4);
INSERT INTO 'dancesstepsmap' VALUES (21307, 15607, 5);
INSERT INTO 'dancesstepsmap' VALUES (21308, 15607, 4);
INSERT INTO 'dancesstepsmap' VALUES (21309, 2833, 5);
INSERT INTO 'dancesstepsmap' VALUES (21310, 16907, 2);
INSERT INTO 'dancesstepsmap' VALUES (21311, 16907, 1);
INSERT INTO 'dancesstepsmap' VALUES (21312, 14453, 5);
INSERT INTO 'dancesstepsmap' VALUES (21313, 14453, 4);
INSERT INTO 'dancesstepsmap' VALUES (21314, 14453, 1);
INSERT INTO 'dancesstepsmap' VALUES (21315, 14453, 2);
INSERT INTO 'dancesstepsmap' VALUES (21316, 14453, 3);
INSERT INTO 'dancesstepsmap' VALUES (23210, 12346, 5);
INSERT INTO 'dancesstepsmap' VALUES (21318, 859, 3);
INSERT INTO 'dancesstepsmap' VALUES (21319, 859, 2);
INSERT INTO 'dancesstepsmap' VALUES (21320, 16732, 2);
INSERT INTO 'dancesstepsmap' VALUES (21321, 16732, 1);
INSERT INTO 'dancesstepsmap' VALUES (21322, 9470, 1);
INSERT INTO 'dancesstepsmap' VALUES (21323, 3174, 2);
INSERT INTO 'dancesstepsmap' VALUES (21324, 5170, 5);
INSERT INTO 'dancesstepsmap' VALUES (21325, 16908, 5);
INSERT INTO 'dancesstepsmap' VALUES (21326, 16908, 4);
INSERT INTO 'dancesstepsmap' VALUES (21327, 16909, 1);
INSERT INTO 'dancesstepsmap' VALUES (21328, 16909, 2);
INSERT INTO 'dancesstepsmap' VALUES (21329, 16910, 2);
INSERT INTO 'dancesstepsmap' VALUES (21330, 16910, 3);
INSERT INTO 'dancesstepsmap' VALUES (21331, 16910, 1);
INSERT INTO 'dancesstepsmap' VALUES (21332, 16911, 2);
INSERT INTO 'dancesstepsmap' VALUES (21333, 16911, 1);
INSERT INTO 'dancesstepsmap' VALUES (21334, 16912, 2);
INSERT INTO 'dancesstepsmap' VALUES (21335, 16912, 1);
INSERT INTO 'dancesstepsmap' VALUES (21336, 16913, 5);
INSERT INTO 'dancesstepsmap' VALUES (21337, 16913, 4);
INSERT INTO 'dancesstepsmap' VALUES (21340, 16916, 1);
INSERT INTO 'dancesstepsmap' VALUES (21341, 16917, 5);
INSERT INTO 'dancesstepsmap' VALUES (21342, 16917, 4);
INSERT INTO 'dancesstepsmap' VALUES (21343, 16918, 1);
INSERT INTO 'dancesstepsmap' VALUES (21344, 16919, 1);
INSERT INTO 'dancesstepsmap' VALUES (21345, 16920, 5);
INSERT INTO 'dancesstepsmap' VALUES (21346, 16920, 4);
INSERT INTO 'dancesstepsmap' VALUES (21347, 16921, 1);
INSERT INTO 'dancesstepsmap' VALUES (21348, 16922, 2);
INSERT INTO 'dancesstepsmap' VALUES (21349, 16922, 1);
INSERT INTO 'dancesstepsmap' VALUES (21350, 16923, 1);
INSERT INTO 'dancesstepsmap' VALUES (21353, 16925, 1);
INSERT INTO 'dancesstepsmap' VALUES (21354, 16927, 5);
INSERT INTO 'dancesstepsmap' VALUES (21355, 16927, 4);
INSERT INTO 'dancesstepsmap' VALUES (21356, 16927, 2);
INSERT INTO 'dancesstepsmap' VALUES (21357, 16927, 1);
INSERT INTO 'dancesstepsmap' VALUES (21358, 16927, 3);
INSERT INTO 'dancesstepsmap' VALUES (21359, 16928, 5);
INSERT INTO 'dancesstepsmap' VALUES (21360, 16928, 4);
INSERT INTO 'dancesstepsmap' VALUES (21363, 16930, 2);
INSERT INTO 'dancesstepsmap' VALUES (21364, 16930, 1);
INSERT INTO 'dancesstepsmap' VALUES (21365, 16930, 3);
INSERT INTO 'dancesstepsmap' VALUES (21366, 16931, 2);
INSERT INTO 'dancesstepsmap' VALUES (21367, 16931, 1);
INSERT INTO 'dancesstepsmap' VALUES (21368, 16931, 3);
INSERT INTO 'dancesstepsmap' VALUES (21369, 16932, 2);
INSERT INTO 'dancesstepsmap' VALUES (21370, 16932, 1);
INSERT INTO 'dancesstepsmap' VALUES (21371, 16933, 1);
INSERT INTO 'dancesstepsmap' VALUES (21372, 16934, 2);
INSERT INTO 'dancesstepsmap' VALUES (21373, 16934, 1);
INSERT INTO 'dancesstepsmap' VALUES (21374, 16934, 3);
INSERT INTO 'dancesstepsmap' VALUES (21375, 16935, 2);
INSERT INTO 'dancesstepsmap' VALUES (21376, 16935, 1);
INSERT INTO 'dancesstepsmap' VALUES (21377, 16935, 3);
INSERT INTO 'dancesstepsmap' VALUES (21378, 16935, 5);
INSERT INTO 'dancesstepsmap' VALUES (21379, 16935, 4);
INSERT INTO 'dancesstepsmap' VALUES (21380, 16936, 1);
INSERT INTO 'dancesstepsmap' VALUES (21381, 16937, 2);
INSERT INTO 'dancesstepsmap' VALUES (21382, 16937, 1);
INSERT INTO 'dancesstepsmap' VALUES (21383, 16938, 3);
INSERT INTO 'dancesstepsmap' VALUES (21384, 16938, 1);
INSERT INTO 'dancesstepsmap' VALUES (21385, 2436, 2);
INSERT INTO 'dancesstepsmap' VALUES (21386, 16939, 4);
INSERT INTO 'dancesstepsmap' VALUES (21387, 16939, 5);
INSERT INTO 'dancesstepsmap' VALUES (21293, 16902, 4);
INSERT INTO 'dancesstepsmap' VALUES (21289, 16899, 4);
INSERT INTO 'dancesstepsmap' VALUES (21290, 16899, 5);
INSERT INTO 'dancesstepsmap' VALUES (21388, 5723, 2);
INSERT INTO 'dancesstepsmap' VALUES (21389, 5473, 5);
INSERT INTO 'dancesstepsmap' VALUES (21390, 11759, 5);
INSERT INTO 'dancesstepsmap' VALUES (21391, 51, 5);
INSERT INTO 'dancesstepsmap' VALUES (21392, 9581, 5);
INSERT INTO 'dancesstepsmap' VALUES (21393, 91, 5);
INSERT INTO 'dancesstepsmap' VALUES (21394, 9223, 5);
INSERT INTO 'dancesstepsmap' VALUES (21395, 10956, 4);
INSERT INTO 'dancesstepsmap' VALUES (21396, 10956, 5);
INSERT INTO 'dancesstepsmap' VALUES (21397, 16941, 1);
INSERT INTO 'dancesstepsmap' VALUES (23211, 18263, 1);
INSERT INTO 'dancesstepsmap' VALUES (21399, 10745, 1);
INSERT INTO 'dancesstepsmap' VALUES (21400, 10745, 2);
INSERT INTO 'dancesstepsmap' VALUES (21402, 10744, 5);
INSERT INTO 'dancesstepsmap' VALUES (21403, 10744, 4);
INSERT INTO 'dancesstepsmap' VALUES (21404, 3123, 5);
INSERT INTO 'dancesstepsmap' VALUES (21405, 16942, 4);
INSERT INTO 'dancesstepsmap' VALUES (21406, 16943, 5);
INSERT INTO 'dancesstepsmap' VALUES (21407, 16943, 4);
INSERT INTO 'dancesstepsmap' VALUES (21408, 16944, 1);
INSERT INTO 'dancesstepsmap' VALUES (21409, 16945, 1);
INSERT INTO 'dancesstepsmap' VALUES (21410, 16946, 1);
INSERT INTO 'dancesstepsmap' VALUES (21411, 16947, 1);
INSERT INTO 'dancesstepsmap' VALUES (21412, 16949, 1);
INSERT INTO 'dancesstepsmap' VALUES (21413, 16949, 2);
INSERT INTO 'dancesstepsmap' VALUES (21414, 16950, 5);
INSERT INTO 'dancesstepsmap' VALUES (21415, 16950, 4);
INSERT INTO 'dancesstepsmap' VALUES (21416, 16951, 5);
INSERT INTO 'dancesstepsmap' VALUES (21417, 16951, 4);
INSERT INTO 'dancesstepsmap' VALUES (21418, 16482, 5);
INSERT INTO 'dancesstepsmap' VALUES (21419, 8421, 5);
INSERT INTO 'dancesstepsmap' VALUES (21420, 8425, 2);
INSERT INTO 'dancesstepsmap' VALUES (21421, 8423, 2);
INSERT INTO 'dancesstepsmap' VALUES (21422, 8417, 2);
INSERT INTO 'dancesstepsmap' VALUES (21423, 9788, 1);
INSERT INTO 'dancesstepsmap' VALUES (21424, 9788, 2);
INSERT INTO 'dancesstepsmap' VALUES (21425, 9788, 3);
INSERT INTO 'dancesstepsmap' VALUES (21426, 14005, 1);
INSERT INTO 'dancesstepsmap' VALUES (21427, 14005, 2);
INSERT INTO 'dancesstepsmap' VALUES (21428, 14005, 3);
INSERT INTO 'dancesstepsmap' VALUES (21429, 16954, 4);
INSERT INTO 'dancesstepsmap' VALUES (21430, 16954, 5);
INSERT INTO 'dancesstepsmap' VALUES (21431, 16954, 1);
INSERT INTO 'dancesstepsmap' VALUES (21432, 16954, 2);
INSERT INTO 'dancesstepsmap' VALUES (21433, 14789, 1);
INSERT INTO 'dancesstepsmap' VALUES (21434, 14789, 2);
INSERT INTO 'dancesstepsmap' VALUES (21435, 6170, 5);
INSERT INTO 'dancesstepsmap' VALUES (21436, 6170, 10);
INSERT INTO 'dancesstepsmap' VALUES (21437, 14613, 4);
INSERT INTO 'dancesstepsmap' VALUES (21438, 14613, 5);
INSERT INTO 'dancesstepsmap' VALUES (21439, 16806, 4);
INSERT INTO 'dancesstepsmap' VALUES (21440, 16959, 1);
INSERT INTO 'dancesstepsmap' VALUES (21441, 16959, 2);
INSERT INTO 'dancesstepsmap' VALUES (21442, 16960, 4);
INSERT INTO 'dancesstepsmap' VALUES (21443, 9210, 101);
INSERT INTO 'dancesstepsmap' VALUES (21444, 2831, 6);
INSERT INTO 'dancesstepsmap' VALUES (21445, 8740, 4);
INSERT INTO 'dancesstepsmap' VALUES (21446, 8740, 5);
INSERT INTO 'dancesstepsmap' VALUES (21447, 6220, 2);
INSERT INTO 'dancesstepsmap' VALUES (21448, 6715, 2);
INSERT INTO 'dancesstepsmap' VALUES (21449, 6717, 2);
INSERT INTO 'dancesstepsmap' VALUES (21361, 16929, 2);
INSERT INTO 'dancesstepsmap' VALUES (21362, 16929, 1);
INSERT INTO 'dancesstepsmap' VALUES (21450, 6717, 10);
INSERT INTO 'dancesstepsmap' VALUES (21451, 10932, 4);
INSERT INTO 'dancesstepsmap' VALUES (21452, 10932, 5);
INSERT INTO 'dancesstepsmap' VALUES (21453, 8332, 2);
INSERT INTO 'dancesstepsmap' VALUES (21454, 8332, 3);
INSERT INTO 'dancesstepsmap' VALUES (21455, 16964, 1);
INSERT INTO 'dancesstepsmap' VALUES (21456, 16964, 2);
INSERT INTO 'dancesstepsmap' VALUES (21457, 16964, 8);
INSERT INTO 'dancesstepsmap' VALUES (21458, 6294, 3);
INSERT INTO 'dancesstepsmap' VALUES (21459, 16965, 1);
INSERT INTO 'dancesstepsmap' VALUES (21460, 16965, 2);
INSERT INTO 'dancesstepsmap' VALUES (21461, 231, 5);
INSERT INTO 'dancesstepsmap' VALUES (21462, 16952, 5);
INSERT INTO 'dancesstepsmap' VALUES (21463, 16952, 4);
INSERT INTO 'dancesstepsmap' VALUES (21464, 4043, 8);
INSERT INTO 'dancesstepsmap' VALUES (21465, 4043, 2);
INSERT INTO 'dancesstepsmap' VALUES (21466, 4043, 3);
INSERT INTO 'dancesstepsmap' VALUES (21467, 16966, 4);
INSERT INTO 'dancesstepsmap' VALUES (21468, 16966, 5);
INSERT INTO 'dancesstepsmap' VALUES (21469, 16967, 3);
INSERT INTO 'dancesstepsmap' VALUES (21470, 16967, 1);
INSERT INTO 'dancesstepsmap' VALUES (21471, 16967, 2);
INSERT INTO 'dancesstepsmap' VALUES (21472, 16968, 4);
INSERT INTO 'dancesstepsmap' VALUES (21473, 16968, 5);
INSERT INTO 'dancesstepsmap' VALUES (21474, 16969, 1);
INSERT INTO 'dancesstepsmap' VALUES (21475, 16970, 2);
INSERT INTO 'dancesstepsmap' VALUES (21476, 16970, 1);
INSERT INTO 'dancesstepsmap' VALUES (21477, 16971, 1);
INSERT INTO 'dancesstepsmap' VALUES (21478, 16971, 2);
INSERT INTO 'dancesstepsmap' VALUES (21479, 16972, 4);
INSERT INTO 'dancesstepsmap' VALUES (21480, 16973, 1);
INSERT INTO 'dancesstepsmap' VALUES (21481, 16973, 2);
INSERT INTO 'dancesstepsmap' VALUES (21482, 16974, 4);
INSERT INTO 'dancesstepsmap' VALUES (21483, 16974, 5);
INSERT INTO 'dancesstepsmap' VALUES (21484, 16975, 1);
INSERT INTO 'dancesstepsmap' VALUES (21485, 3520, 2);
INSERT INTO 'dancesstepsmap' VALUES (21486, 16976, 2);
INSERT INTO 'dancesstepsmap' VALUES (21487, 16976, 1);
INSERT INTO 'dancesstepsmap' VALUES (21488, 16977, 1);
INSERT INTO 'dancesstepsmap' VALUES (21489, 16977, 2);
INSERT INTO 'dancesstepsmap' VALUES (21490, 16978, 2);
INSERT INTO 'dancesstepsmap' VALUES (21491, 16978, 1);
INSERT INTO 'dancesstepsmap' VALUES (21492, 16979, 4);
INSERT INTO 'dancesstepsmap' VALUES (21493, 16979, 5);
INSERT INTO 'dancesstepsmap' VALUES (21494, 16980, 2);
INSERT INTO 'dancesstepsmap' VALUES (21495, 16980, 1);
INSERT INTO 'dancesstepsmap' VALUES (21496, 16980, 3);
INSERT INTO 'dancesstepsmap' VALUES (21497, 16981, 4);
INSERT INTO 'dancesstepsmap' VALUES (21498, 16981, 5);
INSERT INTO 'dancesstepsmap' VALUES (21499, 16982, 1);
INSERT INTO 'dancesstepsmap' VALUES (21500, 16982, 2);
INSERT INTO 'dancesstepsmap' VALUES (21501, 16983, 4);
INSERT INTO 'dancesstepsmap' VALUES (21502, 16983, 5);
INSERT INTO 'dancesstepsmap' VALUES (21503, 16984, 5);
INSERT INTO 'dancesstepsmap' VALUES (21504, 16984, 4);
INSERT INTO 'dancesstepsmap' VALUES (21505, 16985, 5);
INSERT INTO 'dancesstepsmap' VALUES (21506, 16985, 4);
INSERT INTO 'dancesstepsmap' VALUES (21507, 16986, 4);
INSERT INTO 'dancesstepsmap' VALUES (21508, 16986, 5);
INSERT INTO 'dancesstepsmap' VALUES (21509, 16987, 4);
INSERT INTO 'dancesstepsmap' VALUES (21510, 16987, 5);
INSERT INTO 'dancesstepsmap' VALUES (21511, 16988, 1);
INSERT INTO 'dancesstepsmap' VALUES (21512, 16988, 2);
INSERT INTO 'dancesstepsmap' VALUES (21513, 16989, 4);
INSERT INTO 'dancesstepsmap' VALUES (21514, 16989, 5);
INSERT INTO 'dancesstepsmap' VALUES (21515, 16990, 1);
INSERT INTO 'dancesstepsmap' VALUES (21516, 16990, 2);
INSERT INTO 'dancesstepsmap' VALUES (21517, 16990, 3);
INSERT INTO 'dancesstepsmap' VALUES (21518, 16991, 3);
INSERT INTO 'dancesstepsmap' VALUES (21519, 16991, 2);
INSERT INTO 'dancesstepsmap' VALUES (21520, 16991, 1);
INSERT INTO 'dancesstepsmap' VALUES (21521, 16992, 1);
INSERT INTO 'dancesstepsmap' VALUES (21522, 16992, 2);
INSERT INTO 'dancesstepsmap' VALUES (21523, 16993, 2);
INSERT INTO 'dancesstepsmap' VALUES (21524, 16993, 1);
INSERT INTO 'dancesstepsmap' VALUES (21525, 16994, 4);
INSERT INTO 'dancesstepsmap' VALUES (21526, 16994, 5);
INSERT INTO 'dancesstepsmap' VALUES (21527, 16995, 1);
INSERT INTO 'dancesstepsmap' VALUES (21528, 16995, 2);
INSERT INTO 'dancesstepsmap' VALUES (21529, 16996, 4);
INSERT INTO 'dancesstepsmap' VALUES (21530, 16996, 6);
INSERT INTO 'dancesstepsmap' VALUES (21531, 16997, 1);
INSERT INTO 'dancesstepsmap' VALUES (21532, 16997, 3);
INSERT INTO 'dancesstepsmap' VALUES (21533, 16998, 1);
INSERT INTO 'dancesstepsmap' VALUES (21534, 16998, 2);
INSERT INTO 'dancesstepsmap' VALUES (21535, 16999, 1);
INSERT INTO 'dancesstepsmap' VALUES (21536, 16999, 2);
INSERT INTO 'dancesstepsmap' VALUES (21537, 17000, 1);
INSERT INTO 'dancesstepsmap' VALUES (21538, 17001, 4);
INSERT INTO 'dancesstepsmap' VALUES (21539, 17001, 5);
INSERT INTO 'dancesstepsmap' VALUES (21540, 17002, 2);
INSERT INTO 'dancesstepsmap' VALUES (21541, 17002, 1);
INSERT INTO 'dancesstepsmap' VALUES (21542, 17003, 1);
INSERT INTO 'dancesstepsmap' VALUES (21543, 17003, 2);
INSERT INTO 'dancesstepsmap' VALUES (21544, 17003, 3);
INSERT INTO 'dancesstepsmap' VALUES (21545, 17004, 2);
INSERT INTO 'dancesstepsmap' VALUES (21546, 17004, 1);
INSERT INTO 'dancesstepsmap' VALUES (21547, 17005, 1);
INSERT INTO 'dancesstepsmap' VALUES (21548, 17005, 2);
INSERT INTO 'dancesstepsmap' VALUES (21549, 17006, 4);
INSERT INTO 'dancesstepsmap' VALUES (21550, 17006, 5);
INSERT INTO 'dancesstepsmap' VALUES (21551, 17007, 5);
INSERT INTO 'dancesstepsmap' VALUES (21552, 17007, 4);
INSERT INTO 'dancesstepsmap' VALUES (21553, 17008, 1);
INSERT INTO 'dancesstepsmap' VALUES (21554, 17008, 2);
INSERT INTO 'dancesstepsmap' VALUES (21555, 17009, 5);
INSERT INTO 'dancesstepsmap' VALUES (21556, 17009, 4);
INSERT INTO 'dancesstepsmap' VALUES (21557, 17010, 2);
INSERT INTO 'dancesstepsmap' VALUES (21558, 17010, 1);
INSERT INTO 'dancesstepsmap' VALUES (21559, 17011, 4);
INSERT INTO 'dancesstepsmap' VALUES (21560, 17011, 5);
INSERT INTO 'dancesstepsmap' VALUES (21561, 17012, 2);
INSERT INTO 'dancesstepsmap' VALUES (21562, 17012, 1);
INSERT INTO 'dancesstepsmap' VALUES (21563, 17013, 5);
INSERT INTO 'dancesstepsmap' VALUES (21564, 17013, 4);
INSERT INTO 'dancesstepsmap' VALUES (21565, 17014, 2);
INSERT INTO 'dancesstepsmap' VALUES (21566, 17014, 1);
INSERT INTO 'dancesstepsmap' VALUES (21567, 17014, 3);
INSERT INTO 'dancesstepsmap' VALUES (21568, 17015, 4);
INSERT INTO 'dancesstepsmap' VALUES (21569, 17015, 5);
INSERT INTO 'dancesstepsmap' VALUES (21570, 17016, 1);
INSERT INTO 'dancesstepsmap' VALUES (21571, 17016, 2);
INSERT INTO 'dancesstepsmap' VALUES (21572, 17017, 1);
INSERT INTO 'dancesstepsmap' VALUES (21573, 17018, 1);
INSERT INTO 'dancesstepsmap' VALUES (21574, 17018, 2);
INSERT INTO 'dancesstepsmap' VALUES (21615, 17046, 2);
INSERT INTO 'dancesstepsmap' VALUES (21616, 17046, 3);
INSERT INTO 'dancesstepsmap' VALUES (21577, 17020, 1);
INSERT INTO 'dancesstepsmap' VALUES (21578, 17020, 2);
INSERT INTO 'dancesstepsmap' VALUES (21606, 17043, 1);
INSERT INTO 'dancesstepsmap' VALUES (21607, 17043, 2);
INSERT INTO 'dancesstepsmap' VALUES (21581, 17022, 1);
INSERT INTO 'dancesstepsmap' VALUES (21582, 17023, 5);
INSERT INTO 'dancesstepsmap' VALUES (21583, 17023, 4);
INSERT INTO 'dancesstepsmap' VALUES (21584, 17024, 4);
INSERT INTO 'dancesstepsmap' VALUES (21585, 17024, 5);
INSERT INTO 'dancesstepsmap' VALUES (21612, 17045, 1);
INSERT INTO 'dancesstepsmap' VALUES (21613, 17045, 3);
INSERT INTO 'dancesstepsmap' VALUES (21579, 17021, 5);
INSERT INTO 'dancesstepsmap' VALUES (21580, 17021, 4);
INSERT INTO 'dancesstepsmap' VALUES (21588, 17026, 3);
INSERT INTO 'dancesstepsmap' VALUES (21589, 17026, 1);
INSERT INTO 'dancesstepsmap' VALUES (21590, 17026, 2);
INSERT INTO 'dancesstepsmap' VALUES (21591, 17028, 1);
INSERT INTO 'dancesstepsmap' VALUES (21592, 17028, 2);
INSERT INTO 'dancesstepsmap' VALUES (21593, 17037, 1);
INSERT INTO 'dancesstepsmap' VALUES (21594, 17037, 3);
INSERT INTO 'dancesstepsmap' VALUES (21595, 17041, 5);
INSERT INTO 'dancesstepsmap' VALUES (21596, 17041, 4);
INSERT INTO 'dancesstepsmap' VALUES (21597, 17041, 6);
INSERT INTO 'dancesstepsmap' VALUES (21598, 9392, 4);
INSERT INTO 'dancesstepsmap' VALUES (21599, 9392, 5);
INSERT INTO 'dancesstepsmap' VALUES (21600, 1883, 5);
INSERT INTO 'dancesstepsmap' VALUES (21601, 5955, 2);
INSERT INTO 'dancesstepsmap' VALUES (21608, 17043, 3);
INSERT INTO 'dancesstepsmap' VALUES (21611, 17045, 2);
INSERT INTO 'dancesstepsmap' VALUES (21614, 17046, 1);
INSERT INTO 'dancesstepsmap' VALUES (21619, 13639, 1);
INSERT INTO 'dancesstepsmap' VALUES (21620, 13639, 3);
INSERT INTO 'dancesstepsmap' VALUES (21621, 13639, 2);
INSERT INTO 'dancesstepsmap' VALUES (21622, 17048, 1);
INSERT INTO 'dancesstepsmap' VALUES (21623, 17048, 2);
INSERT INTO 'dancesstepsmap' VALUES (21624, 17049, 5);
INSERT INTO 'dancesstepsmap' VALUES (21626, 17050, 1);
INSERT INTO 'dancesstepsmap' VALUES (21627, 17050, 2);
INSERT INTO 'dancesstepsmap' VALUES (21628, 17051, 5);
INSERT INTO 'dancesstepsmap' VALUES (21629, 17051, 4);
INSERT INTO 'dancesstepsmap' VALUES (21630, 17052, 1);
INSERT INTO 'dancesstepsmap' VALUES (21631, 17052, 2);
INSERT INTO 'dancesstepsmap' VALUES (21632, 17053, 4);
INSERT INTO 'dancesstepsmap' VALUES (21633, 17053, 5);
INSERT INTO 'dancesstepsmap' VALUES (21634, 17054, 1);
INSERT INTO 'dancesstepsmap' VALUES (21635, 17054, 3);
INSERT INTO 'dancesstepsmap' VALUES (21636, 17055, 1);
INSERT INTO 'dancesstepsmap' VALUES (21637, 17055, 2);
INSERT INTO 'dancesstepsmap' VALUES (21638, 17056, 2);
INSERT INTO 'dancesstepsmap' VALUES (21639, 17056, 1);
INSERT INTO 'dancesstepsmap' VALUES (21640, 17057, 1);
INSERT INTO 'dancesstepsmap' VALUES (21641, 17057, 8);
INSERT INTO 'dancesstepsmap' VALUES (21642, 17067, 1);
INSERT INTO 'dancesstepsmap' VALUES (21643, 17068, 1);
INSERT INTO 'dancesstepsmap' VALUES (21644, 17068, 2);
INSERT INTO 'dancesstepsmap' VALUES (21645, 17069, 4);
INSERT INTO 'dancesstepsmap' VALUES (21646, 17069, 6);
INSERT INTO 'dancesstepsmap' VALUES (21647, 17070, 1);
INSERT INTO 'dancesstepsmap' VALUES (21648, 17070, 2);
INSERT INTO 'dancesstepsmap' VALUES (21649, 17071, 1);
INSERT INTO 'dancesstepsmap' VALUES (21650, 17071, 2);
INSERT INTO 'dancesstepsmap' VALUES (21651, 17101, 2);
INSERT INTO 'dancesstepsmap' VALUES (21652, 17101, 1);
INSERT INTO 'dancesstepsmap' VALUES (21653, 17102, 4);
INSERT INTO 'dancesstepsmap' VALUES (21654, 17102, 5);
INSERT INTO 'dancesstepsmap' VALUES (21655, 17121, 1);
INSERT INTO 'dancesstepsmap' VALUES (21656, 17121, 2);
INSERT INTO 'dancesstepsmap' VALUES (21657, 17122, 4);
INSERT INTO 'dancesstepsmap' VALUES (21662, 17103, 2);
INSERT INTO 'dancesstepsmap' VALUES (21663, 17103, 1);
INSERT INTO 'dancesstepsmap' VALUES (21664, 17123, 2);
INSERT INTO 'dancesstepsmap' VALUES (21665, 17123, 1);
INSERT INTO 'dancesstepsmap' VALUES (21666, 17124, 1);
INSERT INTO 'dancesstepsmap' VALUES (21667, 17124, 2);
INSERT INTO 'dancesstepsmap' VALUES (21668, 17125, 1);
INSERT INTO 'dancesstepsmap' VALUES (21669, 17125, 2);
INSERT INTO 'dancesstepsmap' VALUES (21670, 17126, 1);
INSERT INTO 'dancesstepsmap' VALUES (21671, 17126, 3);
INSERT INTO 'dancesstepsmap' VALUES (21672, 17127, 4);
INSERT INTO 'dancesstepsmap' VALUES (21673, 17127, 5);
INSERT INTO 'dancesstepsmap' VALUES (21674, 17128, 1);
INSERT INTO 'dancesstepsmap' VALUES (21675, 17128, 2);
INSERT INTO 'dancesstepsmap' VALUES (21676, 17128, 3);
INSERT INTO 'dancesstepsmap' VALUES (21677, 17129, 4);
INSERT INTO 'dancesstepsmap' VALUES (21678, 17129, 5);
INSERT INTO 'dancesstepsmap' VALUES (21679, 17130, 1);
INSERT INTO 'dancesstepsmap' VALUES (21680, 17130, 2);
INSERT INTO 'dancesstepsmap' VALUES (21681, 17130, 3);
INSERT INTO 'dancesstepsmap' VALUES (21682, 17131, 4);
INSERT INTO 'dancesstepsmap' VALUES (21683, 17132, 1);
INSERT INTO 'dancesstepsmap' VALUES (21684, 17132, 2);
INSERT INTO 'dancesstepsmap' VALUES (21685, 14723, 1);
INSERT INTO 'dancesstepsmap' VALUES (21686, 17133, 1);
INSERT INTO 'dancesstepsmap' VALUES (21687, 17133, 2);
INSERT INTO 'dancesstepsmap' VALUES (21688, 17133, 3);
INSERT INTO 'dancesstepsmap' VALUES (21689, 17134, 5);
INSERT INTO 'dancesstepsmap' VALUES (21690, 17135, 4);
INSERT INTO 'dancesstepsmap' VALUES (21691, 17135, 5);
INSERT INTO 'dancesstepsmap' VALUES (21692, 17136, 1);
INSERT INTO 'dancesstepsmap' VALUES (21693, 17136, 3);
INSERT INTO 'dancesstepsmap' VALUES (21694, 12321, 2);
INSERT INTO 'dancesstepsmap' VALUES (21695, 12321, 1);
INSERT INTO 'dancesstepsmap' VALUES (21696, 12321, 3);
INSERT INTO 'dancesstepsmap' VALUES (21697, 4302, 5);
INSERT INTO 'dancesstepsmap' VALUES (21698, 5053, 2);
INSERT INTO 'dancesstepsmap' VALUES (21699, 846, 5);
INSERT INTO 'dancesstepsmap' VALUES (21700, 970, 2);
INSERT INTO 'dancesstepsmap' VALUES (21701, 2113, 5);
INSERT INTO 'dancesstepsmap' VALUES (21702, 1605, 2);
INSERT INTO 'dancesstepsmap' VALUES (21703, 6841, 2);
INSERT INTO 'dancesstepsmap' VALUES (21704, 4037, 2);
INSERT INTO 'dancesstepsmap' VALUES (21705, 2654, 5);
INSERT INTO 'dancesstepsmap' VALUES (21706, 7057, 2);
INSERT INTO 'dancesstepsmap' VALUES (21707, 5089, 5);
INSERT INTO 'dancesstepsmap' VALUES (21708, 6223, 2);
INSERT INTO 'dancesstepsmap' VALUES (21709, 6676, 5);
INSERT INTO 'dancesstepsmap' VALUES (21710, 5126, 2);
INSERT INTO 'dancesstepsmap' VALUES (21711, 1062, 2);
INSERT INTO 'dancesstepsmap' VALUES (21712, 5750, 2);
INSERT INTO 'dancesstepsmap' VALUES (21713, 319, 5);
INSERT INTO 'dancesstepsmap' VALUES (21714, 1489, 2);
INSERT INTO 'dancesstepsmap' VALUES (21715, 965, 2);
INSERT INTO 'dancesstepsmap' VALUES (21716, 286, 5);
INSERT INTO 'dancesstepsmap' VALUES (21717, 2206, 2);
INSERT INTO 'dancesstepsmap' VALUES (21718, 2290, 2);
INSERT INTO 'dancesstepsmap' VALUES (21719, 1979, 5);
INSERT INTO 'dancesstepsmap' VALUES (21720, 1458, 2);
INSERT INTO 'dancesstepsmap' VALUES (21721, 14201, 1);
INSERT INTO 'dancesstepsmap' VALUES (21722, 14201, 2);
INSERT INTO 'dancesstepsmap' VALUES (21723, 14201, 3);
INSERT INTO 'dancesstepsmap' VALUES (21724, 16656, 1);
INSERT INTO 'dancesstepsmap' VALUES (21725, 16656, 2);
INSERT INTO 'dancesstepsmap' VALUES (21726, 16657, 5);
INSERT INTO 'dancesstepsmap' VALUES (21727, 16657, 4);
INSERT INTO 'dancesstepsmap' VALUES (21728, 16658, 1);
INSERT INTO 'dancesstepsmap' VALUES (21729, 16658, 3);
INSERT INTO 'dancesstepsmap' VALUES (21730, 16658, 2);
INSERT INTO 'dancesstepsmap' VALUES (21731, 16659, 1);
INSERT INTO 'dancesstepsmap' VALUES (21732, 16659, 2);
INSERT INTO 'dancesstepsmap' VALUES (21733, 16659, 3);
INSERT INTO 'dancesstepsmap' VALUES (21737, 16660, 1);
INSERT INTO 'dancesstepsmap' VALUES (21738, 5426, 2);
INSERT INTO 'dancesstepsmap' VALUES (21739, 11388, 2);
INSERT INTO 'dancesstepsmap' VALUES (21740, 11388, 1);
INSERT INTO 'dancesstepsmap' VALUES (21741, 13827, 3);
INSERT INTO 'dancesstepsmap' VALUES (21742, 9029, 2);
INSERT INTO 'dancesstepsmap' VALUES (21743, 17150, 4);
INSERT INTO 'dancesstepsmap' VALUES (21744, 17150, 5);
INSERT INTO 'dancesstepsmap' VALUES (21745, 13545, 2);
INSERT INTO 'dancesstepsmap' VALUES (21746, 13545, 1);
INSERT INTO 'dancesstepsmap' VALUES (21747, 13516, 1);
INSERT INTO 'dancesstepsmap' VALUES (21748, 17151, 2);
INSERT INTO 'dancesstepsmap' VALUES (21749, 17151, 1);
INSERT INTO 'dancesstepsmap' VALUES (21750, 17152, 2);
INSERT INTO 'dancesstepsmap' VALUES (21751, 17152, 1);
INSERT INTO 'dancesstepsmap' VALUES (21752, 17144, 1);
INSERT INTO 'dancesstepsmap' VALUES (21753, 17144, 2);
INSERT INTO 'dancesstepsmap' VALUES (21754, 17144, 3);
INSERT INTO 'dancesstepsmap' VALUES (21755, 17153, 1);
INSERT INTO 'dancesstepsmap' VALUES (21756, 17153, 2);
INSERT INTO 'dancesstepsmap' VALUES (21757, 17154, 1);
INSERT INTO 'dancesstepsmap' VALUES (21758, 17154, 2);
INSERT INTO 'dancesstepsmap' VALUES (21761, 17166, 5);
INSERT INTO 'dancesstepsmap' VALUES (21602, 17042, 4);
INSERT INTO 'dancesstepsmap' VALUES (21609, 17044, 4);
INSERT INTO 'dancesstepsmap' VALUES (21610, 17044, 5);
INSERT INTO 'dancesstepsmap' VALUES (21658, 17113, 1);
INSERT INTO 'dancesstepsmap' VALUES (21659, 17113, 2);
INSERT INTO 'dancesstepsmap' VALUES (21660, 17106, 1);
INSERT INTO 'dancesstepsmap' VALUES (21661, 17106, 2);
INSERT INTO 'dancesstepsmap' VALUES (21759, 17155, 4);
INSERT INTO 'dancesstepsmap' VALUES (21760, 17155, 5);
INSERT INTO 'dancesstepsmap' VALUES (21762, 17166, 4);
INSERT INTO 'dancesstepsmap' VALUES (21763, 17176, 5);
INSERT INTO 'dancesstepsmap' VALUES (21764, 17176, 4);
INSERT INTO 'dancesstepsmap' VALUES (21765, 17172, 1);
INSERT INTO 'dancesstepsmap' VALUES (21766, 17172, 2);
INSERT INTO 'dancesstepsmap' VALUES (21769, 17194, 3);
INSERT INTO 'dancesstepsmap' VALUES (21770, 17194, 1);
INSERT INTO 'dancesstepsmap' VALUES (21771, 17194, 2);
INSERT INTO 'dancesstepsmap' VALUES (21772, 17195, 5);
INSERT INTO 'dancesstepsmap' VALUES (21773, 17195, 4);
INSERT INTO 'dancesstepsmap' VALUES (21774, 13623, 4);
INSERT INTO 'dancesstepsmap' VALUES (21775, 13623, 5);
INSERT INTO 'dancesstepsmap' VALUES (21776, 13120, 2);
INSERT INTO 'dancesstepsmap' VALUES (21777, 13120, 1);
INSERT INTO 'dancesstepsmap' VALUES (21778, 13120, 3);
INSERT INTO 'dancesstepsmap' VALUES (21779, 13121, 5);
INSERT INTO 'dancesstepsmap' VALUES (21780, 13121, 4);
INSERT INTO 'dancesstepsmap' VALUES (21781, 13121, 2);
INSERT INTO 'dancesstepsmap' VALUES (21782, 13121, 1);
INSERT INTO 'dancesstepsmap' VALUES (21783, 13121, 3);
INSERT INTO 'dancesstepsmap' VALUES (21784, 17236, 1);
INSERT INTO 'dancesstepsmap' VALUES (21785, 3406, 10);
INSERT INTO 'dancesstepsmap' VALUES (21786, 17304, 1);
INSERT INTO 'dancesstepsmap' VALUES (21787, 17304, 2);
INSERT INTO 'dancesstepsmap' VALUES (21788, 17316, 1);
INSERT INTO 'dancesstepsmap' VALUES (21789, 17316, 3);
INSERT INTO 'dancesstepsmap' VALUES (21790, 17316, 2);
INSERT INTO 'dancesstepsmap' VALUES (23212, 18263, 2);
INSERT INTO 'dancesstepsmap' VALUES (23239, 18267, 4);
INSERT INTO 'dancesstepsmap' VALUES (21793, 14879, 1);
INSERT INTO 'dancesstepsmap' VALUES (21794, 14879, 2);
INSERT INTO 'dancesstepsmap' VALUES (21795, 14879, 3);
INSERT INTO 'dancesstepsmap' VALUES (21796, 8714, 4);
INSERT INTO 'dancesstepsmap' VALUES (21797, 8714, 1);
INSERT INTO 'dancesstepsmap' VALUES (21798, 8714, 2);
INSERT INTO 'dancesstepsmap' VALUES (21799, 8714, 3);
INSERT INTO 'dancesstepsmap' VALUES (21800, 17331, 4);
INSERT INTO 'dancesstepsmap' VALUES (21801, 17333, 4);
INSERT INTO 'dancesstepsmap' VALUES (21802, 17333, 5);
INSERT INTO 'dancesstepsmap' VALUES (21803, 17333, 10);
INSERT INTO 'dancesstepsmap' VALUES (21804, 17333, 6);
INSERT INTO 'dancesstepsmap' VALUES (21805, 17333, 1);
INSERT INTO 'dancesstepsmap' VALUES (21806, 17333, 2);
INSERT INTO 'dancesstepsmap' VALUES (21807, 17333, 8);
INSERT INTO 'dancesstepsmap' VALUES (21808, 10398, 99);
INSERT INTO 'dancesstepsmap' VALUES (21809, 10398, 1);
INSERT INTO 'dancesstepsmap' VALUES (21810, 17233, 1);
INSERT INTO 'dancesstepsmap' VALUES (21811, 17233, 2);
INSERT INTO 'dancesstepsmap' VALUES (21812, 17335, 1);
INSERT INTO 'dancesstepsmap' VALUES (21813, 17335, 3);
INSERT INTO 'dancesstepsmap' VALUES (21814, 458, 1);
INSERT INTO 'dancesstepsmap' VALUES (21815, 458, 2);
INSERT INTO 'dancesstepsmap' VALUES (21816, 458, 5);
INSERT INTO 'dancesstepsmap' VALUES (21817, 458, 4);
INSERT INTO 'dancesstepsmap' VALUES (21818, 6728, 2);
INSERT INTO 'dancesstepsmap' VALUES (21819, 6728, 3);
INSERT INTO 'dancesstepsmap' VALUES (21820, 17382, 1);
INSERT INTO 'dancesstepsmap' VALUES (21821, 17382, 2);
INSERT INTO 'dancesstepsmap' VALUES (21822, 17383, 2);
INSERT INTO 'dancesstepsmap' VALUES (21823, 17383, 1);
INSERT INTO 'dancesstepsmap' VALUES (21824, 17265, 1);
INSERT INTO 'dancesstepsmap' VALUES (21825, 17265, 3);
INSERT INTO 'dancesstepsmap' VALUES (21826, 17265, 2);
INSERT INTO 'dancesstepsmap' VALUES (21827, 17384, 4);
INSERT INTO 'dancesstepsmap' VALUES (21828, 17384, 5);
INSERT INTO 'dancesstepsmap' VALUES (21829, 17384, 1);
INSERT INTO 'dancesstepsmap' VALUES (21830, 17384, 2);
INSERT INTO 'dancesstepsmap' VALUES (21831, 17385, 5);
INSERT INTO 'dancesstepsmap' VALUES (21832, 17385, 4);
INSERT INTO 'dancesstepsmap' VALUES (21833, 2179, 3);
INSERT INTO 'dancesstepsmap' VALUES (21834, 13872, 1);
INSERT INTO 'dancesstepsmap' VALUES (21835, 13872, 2);
INSERT INTO 'dancesstepsmap' VALUES (21836, 13870, 1);
INSERT INTO 'dancesstepsmap' VALUES (21837, 13870, 2);
INSERT INTO 'dancesstepsmap' VALUES (21838, 13870, 3);
INSERT INTO 'dancesstepsmap' VALUES (21839, 13871, 5);
INSERT INTO 'dancesstepsmap' VALUES (21840, 13871, 4);
INSERT INTO 'dancesstepsmap' VALUES (21841, 13873, 5);
INSERT INTO 'dancesstepsmap' VALUES (21842, 13873, 4);
INSERT INTO 'dancesstepsmap' VALUES (21843, 17386, 4);
INSERT INTO 'dancesstepsmap' VALUES (21844, 17386, 5);
INSERT INTO 'dancesstepsmap' VALUES (23248, 18273, 2);
INSERT INTO 'dancesstepsmap' VALUES (21846, 17388, 4);
INSERT INTO 'dancesstepsmap' VALUES (21847, 17388, 5);
INSERT INTO 'dancesstepsmap' VALUES (21848, 15051, 5);
INSERT INTO 'dancesstepsmap' VALUES (21849, 15051, 4);
INSERT INTO 'dancesstepsmap' VALUES (23249, 18273, 1);
INSERT INTO 'dancesstepsmap' VALUES (21853, 16614, 5);
INSERT INTO 'dancesstepsmap' VALUES (21854, 16614, 4);
INSERT INTO 'dancesstepsmap' VALUES (21855, 16613, 1);
INSERT INTO 'dancesstepsmap' VALUES (21856, 16613, 2);
INSERT INTO 'dancesstepsmap' VALUES (21857, 17143, 2);
INSERT INTO 'dancesstepsmap' VALUES (21858, 17143, 1);
INSERT INTO 'dancesstepsmap' VALUES (21859, 17137, 2);
INSERT INTO 'dancesstepsmap' VALUES (21860, 17137, 1);
INSERT INTO 'dancesstepsmap' VALUES (21861, 2931, 3);
INSERT INTO 'dancesstepsmap' VALUES (21862, 17139, 3);
INSERT INTO 'dancesstepsmap' VALUES (21863, 17139, 1);
INSERT INTO 'dancesstepsmap' VALUES (21864, 17139, 2);
INSERT INTO 'dancesstepsmap' VALUES (21865, 17391, 5);
INSERT INTO 'dancesstepsmap' VALUES (21866, 17391, 4);
INSERT INTO 'dancesstepsmap' VALUES (21867, 17392, 2);
INSERT INTO 'dancesstepsmap' VALUES (21868, 17392, 1);
INSERT INTO 'dancesstepsmap' VALUES (21869, 17393, 2);
INSERT INTO 'dancesstepsmap' VALUES (21870, 17393, 1);
INSERT INTO 'dancesstepsmap' VALUES (21871, 17392, 99);
INSERT INTO 'dancesstepsmap' VALUES (21872, 9906, 99);
INSERT INTO 'dancesstepsmap' VALUES (21873, 9906, 2);
INSERT INTO 'dancesstepsmap' VALUES (21874, 17394, 4);
INSERT INTO 'dancesstepsmap' VALUES (21875, 17395, 4);
INSERT INTO 'dancesstepsmap' VALUES (21876, 17396, 4);
INSERT INTO 'dancesstepsmap' VALUES (21877, 17396, 5);
INSERT INTO 'dancesstepsmap' VALUES (21878, 17397, 1);
INSERT INTO 'dancesstepsmap' VALUES (21879, 17397, 2);
INSERT INTO 'dancesstepsmap' VALUES (21880, 17398, 1);
INSERT INTO 'dancesstepsmap' VALUES (21881, 17398, 2);
INSERT INTO 'dancesstepsmap' VALUES (21882, 14901, 1);
INSERT INTO 'dancesstepsmap' VALUES (21883, 14901, 2);
INSERT INTO 'dancesstepsmap' VALUES (21884, 17399, 2);
INSERT INTO 'dancesstepsmap' VALUES (21885, 17399, 1);
INSERT INTO 'dancesstepsmap' VALUES (21886, 17400, 1);
INSERT INTO 'dancesstepsmap' VALUES (21887, 17400, 2);
INSERT INTO 'dancesstepsmap' VALUES (21888, 17401, 1);
INSERT INTO 'dancesstepsmap' VALUES (21889, 17401, 2);
INSERT INTO 'dancesstepsmap' VALUES (21890, 17402, 1);
INSERT INTO 'dancesstepsmap' VALUES (21891, 17402, 3);
INSERT INTO 'dancesstepsmap' VALUES (21892, 17402, 2);
INSERT INTO 'dancesstepsmap' VALUES (21893, 2661, 5);
INSERT INTO 'dancesstepsmap' VALUES (21894, 5207, 5);
INSERT INTO 'dancesstepsmap' VALUES (21895, 17409, 1);
INSERT INTO 'dancesstepsmap' VALUES (21896, 17409, 2);
INSERT INTO 'dancesstepsmap' VALUES (21897, 17347, 1);
INSERT INTO 'dancesstepsmap' VALUES (21898, 17347, 2);
INSERT INTO 'dancesstepsmap' VALUES (21899, 17406, 2);
INSERT INTO 'dancesstepsmap' VALUES (21900, 17406, 1);
INSERT INTO 'dancesstepsmap' VALUES (21901, 16801, 2);
INSERT INTO 'dancesstepsmap' VALUES (21902, 16801, 1);
INSERT INTO 'dancesstepsmap' VALUES (21903, 16817, 5);
INSERT INTO 'dancesstepsmap' VALUES (21904, 16817, 4);
INSERT INTO 'dancesstepsmap' VALUES (21905, 17410, 5);
INSERT INTO 'dancesstepsmap' VALUES (21906, 17410, 4);
INSERT INTO 'dancesstepsmap' VALUES (21910, 16855, 1);
INSERT INTO 'dancesstepsmap' VALUES (21911, 16855, 3);
INSERT INTO 'dancesstepsmap' VALUES (21912, 16855, 4);
INSERT INTO 'dancesstepsmap' VALUES (21913, 17349, 4);
INSERT INTO 'dancesstepsmap' VALUES (21914, 17411, 1);
INSERT INTO 'dancesstepsmap' VALUES (21915, 17411, 2);
INSERT INTO 'dancesstepsmap' VALUES (21916, 17412, 1);
INSERT INTO 'dancesstepsmap' VALUES (21917, 17412, 2);
INSERT INTO 'dancesstepsmap' VALUES (21918, 17349, 5);
INSERT INTO 'dancesstepsmap' VALUES (21919, 17413, 1);
INSERT INTO 'dancesstepsmap' VALUES (21920, 17413, 2);
INSERT INTO 'dancesstepsmap' VALUES (21923, 17415, 1);
INSERT INTO 'dancesstepsmap' VALUES (21924, 17415, 2);
INSERT INTO 'dancesstepsmap' VALUES (21925, 17415, 4);
INSERT INTO 'dancesstepsmap' VALUES (21926, 17415, 5);
INSERT INTO 'dancesstepsmap' VALUES (21927, 17415, 6);
INSERT INTO 'dancesstepsmap' VALUES (21929, 17417, 1);
INSERT INTO 'dancesstepsmap' VALUES (21930, 17418, 3);
INSERT INTO 'dancesstepsmap' VALUES (21931, 17419, 2);
INSERT INTO 'dancesstepsmap' VALUES (21932, 17419, 1);
INSERT INTO 'dancesstepsmap' VALUES (21933, 17419, 3);
INSERT INTO 'dancesstepsmap' VALUES (21934, 17420, 2);
INSERT INTO 'dancesstepsmap' VALUES (21935, 17420, 1);
INSERT INTO 'dancesstepsmap' VALUES (21936, 17421, 2);
INSERT INTO 'dancesstepsmap' VALUES (21937, 17421, 1);
INSERT INTO 'dancesstepsmap' VALUES (21938, 17422, 1);
INSERT INTO 'dancesstepsmap' VALUES (21939, 17422, 2);
INSERT INTO 'dancesstepsmap' VALUES (21942, 17424, 4);
INSERT INTO 'dancesstepsmap' VALUES (21943, 17424, 5);
INSERT INTO 'dancesstepsmap' VALUES (21944, 15606, 2);
INSERT INTO 'dancesstepsmap' VALUES (21945, 15606, 1);
INSERT INTO 'dancesstepsmap' VALUES (21946, 17120, 4);
INSERT INTO 'dancesstepsmap' VALUES (21947, 17120, 5);
INSERT INTO 'dancesstepsmap' VALUES (21948, 17425, 2);
INSERT INTO 'dancesstepsmap' VALUES (21949, 17425, 1);
INSERT INTO 'dancesstepsmap' VALUES (21950, 8676, 5);
INSERT INTO 'dancesstepsmap' VALUES (21953, 17283, 2);
INSERT INTO 'dancesstepsmap' VALUES (21954, 17283, 1);
INSERT INTO 'dancesstepsmap' VALUES (21955, 17283, 3);
INSERT INTO 'dancesstepsmap' VALUES (21956, 17282, 1);
INSERT INTO 'dancesstepsmap' VALUES (21957, 4136, 5);
INSERT INTO 'dancesstepsmap' VALUES (23213, 12349, 1);
INSERT INTO 'dancesstepsmap' VALUES (21958, 546, 5);
INSERT INTO 'dancesstepsmap' VALUES (21959, 220, 2);
INSERT INTO 'dancesstepsmap' VALUES (21960, 6405, 5);
INSERT INTO 'dancesstepsmap' VALUES (21961, 17458, 1);
INSERT INTO 'dancesstepsmap' VALUES (21962, 17458, 2);
INSERT INTO 'dancesstepsmap' VALUES (21963, 17459, 1);
INSERT INTO 'dancesstepsmap' VALUES (21964, 17459, 2);
INSERT INTO 'dancesstepsmap' VALUES (23214, 12349, 2);
INSERT INTO 'dancesstepsmap' VALUES (22016, 17530, 1);
INSERT INTO 'dancesstepsmap' VALUES (22017, 17530, 2);
INSERT INTO 'dancesstepsmap' VALUES (21965, 17460, 5);
INSERT INTO 'dancesstepsmap' VALUES (21966, 17460, 4);
INSERT INTO 'dancesstepsmap' VALUES (21970, 9802, 1);
INSERT INTO 'dancesstepsmap' VALUES (21971, 9802, 2);
INSERT INTO 'dancesstepsmap' VALUES (21972, 17463, 5);
INSERT INTO 'dancesstepsmap' VALUES (21973, 17463, 4);
INSERT INTO 'dancesstepsmap' VALUES (21974, 17479, 4);
INSERT INTO 'dancesstepsmap' VALUES (21975, 17479, 5);
INSERT INTO 'dancesstepsmap' VALUES (21976, 17138, 5);
INSERT INTO 'dancesstepsmap' VALUES (21977, 17138, 4);
INSERT INTO 'dancesstepsmap' VALUES (21978, 1729, 5);
INSERT INTO 'dancesstepsmap' VALUES (21979, 17404, 1);
INSERT INTO 'dancesstepsmap' VALUES (21980, 17480, 1);
INSERT INTO 'dancesstepsmap' VALUES (21982, 12457, 2);
INSERT INTO 'dancesstepsmap' VALUES (21983, 17481, 1);
INSERT INTO 'dancesstepsmap' VALUES (21984, 17481, 2);
INSERT INTO 'dancesstepsmap' VALUES (21985, 2010, 2);
INSERT INTO 'dancesstepsmap' VALUES (21986, 4804, 2);
INSERT INTO 'dancesstepsmap' VALUES (21987, 6244, 5);
INSERT INTO 'dancesstepsmap' VALUES (21988, 17482, 1);
INSERT INTO 'dancesstepsmap' VALUES (21989, 17482, 2);
INSERT INTO 'dancesstepsmap' VALUES (21990, 17482, 3);
INSERT INTO 'dancesstepsmap' VALUES (21991, 17483, 4);
INSERT INTO 'dancesstepsmap' VALUES (21992, 17483, 5);
INSERT INTO 'dancesstepsmap' VALUES (21993, 12365, 5);
INSERT INTO 'dancesstepsmap' VALUES (21994, 12365, 4);
INSERT INTO 'dancesstepsmap' VALUES (21995, 11393, 5);
INSERT INTO 'dancesstepsmap' VALUES (21996, 17484, 2);
INSERT INTO 'dancesstepsmap' VALUES (21997, 17484, 1);
INSERT INTO 'dancesstepsmap' VALUES (21998, 17484, 3);
INSERT INTO 'dancesstepsmap' VALUES (21999, 17485, 5);
INSERT INTO 'dancesstepsmap' VALUES (22000, 17485, 4);
INSERT INTO 'dancesstepsmap' VALUES (22003, 15605, 5);
INSERT INTO 'dancesstepsmap' VALUES (22004, 15605, 4);
INSERT INTO 'dancesstepsmap' VALUES (22005, 17526, 2);
INSERT INTO 'dancesstepsmap' VALUES (22006, 17526, 1);
INSERT INTO 'dancesstepsmap' VALUES (22007, 17526, 3);
INSERT INTO 'dancesstepsmap' VALUES (22008, 17527, 2);
INSERT INTO 'dancesstepsmap' VALUES (22009, 17527, 1);
INSERT INTO 'dancesstepsmap' VALUES (22010, 17528, 2);
INSERT INTO 'dancesstepsmap' VALUES (22011, 17528, 1);
INSERT INTO 'dancesstepsmap' VALUES (22012, 17528, 5);
INSERT INTO 'dancesstepsmap' VALUES (22013, 17528, 4);
INSERT INTO 'dancesstepsmap' VALUES (22014, 17529, 2);
INSERT INTO 'dancesstepsmap' VALUES (22015, 17529, 1);
INSERT INTO 'dancesstepsmap' VALUES (22018, 17531, 5);
INSERT INTO 'dancesstepsmap' VALUES (22019, 17531, 4);
INSERT INTO 'dancesstepsmap' VALUES (22020, 17532, 2);
INSERT INTO 'dancesstepsmap' VALUES (22021, 17532, 1);
INSERT INTO 'dancesstepsmap' VALUES (22022, 17533, 5);
INSERT INTO 'dancesstepsmap' VALUES (22023, 17533, 4);
INSERT INTO 'dancesstepsmap' VALUES (22024, 17534, 1);
INSERT INTO 'dancesstepsmap' VALUES (22025, 17534, 3);
INSERT INTO 'dancesstepsmap' VALUES (22026, 17535, 2);
INSERT INTO 'dancesstepsmap' VALUES (22027, 17535, 1);
INSERT INTO 'dancesstepsmap' VALUES (22030, 17536, 3);
INSERT INTO 'dancesstepsmap' VALUES (22031, 17537, 5);
INSERT INTO 'dancesstepsmap' VALUES (22032, 17537, 4);
INSERT INTO 'dancesstepsmap' VALUES (22033, 17538, 5);
INSERT INTO 'dancesstepsmap' VALUES (22034, 17538, 4);
INSERT INTO 'dancesstepsmap' VALUES (22035, 6151, 2);
INSERT INTO 'dancesstepsmap' VALUES (22036, 6151, 3);
INSERT INTO 'dancesstepsmap' VALUES (22037, 17495, 4);
INSERT INTO 'dancesstepsmap' VALUES (22038, 17495, 5);
INSERT INTO 'dancesstepsmap' VALUES (22039, 17488, 1);
INSERT INTO 'dancesstepsmap' VALUES (22040, 17488, 2);
INSERT INTO 'dancesstepsmap' VALUES (22041, 17488, 3);
INSERT INTO 'dancesstepsmap' VALUES (22042, 16519, 2);
INSERT INTO 'dancesstepsmap' VALUES (22043, 16519, 1);
INSERT INTO 'dancesstepsmap' VALUES (22044, 16520, 5);
INSERT INTO 'dancesstepsmap' VALUES (22045, 16520, 4);
INSERT INTO 'dancesstepsmap' VALUES (22046, 17539, 1);
INSERT INTO 'dancesstepsmap' VALUES (22047, 17540, 5);
INSERT INTO 'dancesstepsmap' VALUES (22048, 17540, 4);
INSERT INTO 'dancesstepsmap' VALUES (22049, 9014, 4);
INSERT INTO 'dancesstepsmap' VALUES (22050, 9014, 5);
INSERT INTO 'dancesstepsmap' VALUES (22051, 4365, 2);
INSERT INTO 'dancesstepsmap' VALUES (22052, 13654, 5);
INSERT INTO 'dancesstepsmap' VALUES (22053, 10370, 5);
INSERT INTO 'dancesstepsmap' VALUES (22054, 17570, 3);
INSERT INTO 'dancesstepsmap' VALUES (22055, 17570, 1);
INSERT INTO 'dancesstepsmap' VALUES (22056, 17570, 2);
INSERT INTO 'dancesstepsmap' VALUES (22057, 17574, 1);
INSERT INTO 'dancesstepsmap' VALUES (22058, 17574, 2);
INSERT INTO 'dancesstepsmap' VALUES (22059, 17575, 5);
INSERT INTO 'dancesstepsmap' VALUES (22060, 17575, 4);
INSERT INTO 'dancesstepsmap' VALUES (22061, 13311, 2);
INSERT INTO 'dancesstepsmap' VALUES (22062, 17576, 5);
INSERT INTO 'dancesstepsmap' VALUES (22063, 17576, 4);
INSERT INTO 'dancesstepsmap' VALUES (22064, 17576, 6);
INSERT INTO 'dancesstepsmap' VALUES (22065, 16789, 2);
INSERT INTO 'dancesstepsmap' VALUES (22066, 16789, 1);
INSERT INTO 'dancesstepsmap' VALUES (22067, 17578, 5);
INSERT INTO 'dancesstepsmap' VALUES (22068, 17578, 4);
INSERT INTO 'dancesstepsmap' VALUES (22069, 15245, 1);
INSERT INTO 'dancesstepsmap' VALUES (22070, 15245, 2);
INSERT INTO 'dancesstepsmap' VALUES (22071, 17186, 5);
INSERT INTO 'dancesstepsmap' VALUES (22072, 17186, 4);
INSERT INTO 'dancesstepsmap' VALUES (22073, 12895, 2);
INSERT INTO 'dancesstepsmap' VALUES (22074, 5466, 3);
INSERT INTO 'dancesstepsmap' VALUES (22075, 6615, 2);
INSERT INTO 'dancesstepsmap' VALUES (22076, 986, 5);
INSERT INTO 'dancesstepsmap' VALUES (22077, 6271, 5);
INSERT INTO 'dancesstepsmap' VALUES (22078, 10089, 5);
INSERT INTO 'dancesstepsmap' VALUES (22079, 17582, 2);
INSERT INTO 'dancesstepsmap' VALUES (22080, 17582, 1);
INSERT INTO 'dancesstepsmap' VALUES (22081, 17582, 3);
INSERT INTO 'dancesstepsmap' VALUES (22082, 9137, 2);
INSERT INTO 'dancesstepsmap' VALUES (22083, 9137, 1);
INSERT INTO 'dancesstepsmap' VALUES (22084, 17583, 2);
INSERT INTO 'dancesstepsmap' VALUES (22085, 17583, 1);
INSERT INTO 'dancesstepsmap' VALUES (22086, 17613, 1);
INSERT INTO 'dancesstepsmap' VALUES (22087, 17613, 2);
INSERT INTO 'dancesstepsmap' VALUES (22088, 17614, 1);
INSERT INTO 'dancesstepsmap' VALUES (22089, 17614, 2);
INSERT INTO 'dancesstepsmap' VALUES (22092, 17615, 4);
INSERT INTO 'dancesstepsmap' VALUES (22093, 17615, 5);
INSERT INTO 'dancesstepsmap' VALUES (22094, 17616, 5);
INSERT INTO 'dancesstepsmap' VALUES (22095, 17616, 4);
INSERT INTO 'dancesstepsmap' VALUES (22096, 17617, 2);
INSERT INTO 'dancesstepsmap' VALUES (22097, 17617, 3);
INSERT INTO 'dancesstepsmap' VALUES (22098, 17617, 1);
INSERT INTO 'dancesstepsmap' VALUES (22099, 11782, 2);
INSERT INTO 'dancesstepsmap' VALUES (22100, 8453, 5);
INSERT INTO 'dancesstepsmap' VALUES (22101, 17618, 4);
INSERT INTO 'dancesstepsmap' VALUES (22102, 17618, 5);
INSERT INTO 'dancesstepsmap' VALUES (22103, 17619, 5);
INSERT INTO 'dancesstepsmap' VALUES (22104, 17619, 4);
INSERT INTO 'dancesstepsmap' VALUES (22105, 15599, 5);
INSERT INTO 'dancesstepsmap' VALUES (22106, 15599, 4);
INSERT INTO 'dancesstepsmap' VALUES (22110, 17034, 4);
INSERT INTO 'dancesstepsmap' VALUES (22111, 17034, 5);
INSERT INTO 'dancesstepsmap' VALUES (22112, 17620, 1);
INSERT INTO 'dancesstepsmap' VALUES (22113, 17620, 3);
INSERT INTO 'dancesstepsmap' VALUES (22114, 11796, 2);
INSERT INTO 'dancesstepsmap' VALUES (22115, 11796, 5);
INSERT INTO 'dancesstepsmap' VALUES (22116, 11796, 4);
INSERT INTO 'dancesstepsmap' VALUES (22117, 8720, 5);
INSERT INTO 'dancesstepsmap' VALUES (22118, 8720, 4);
INSERT INTO 'dancesstepsmap' VALUES (22119, 17621, 5);
INSERT INTO 'dancesstepsmap' VALUES (22120, 17621, 4);
INSERT INTO 'dancesstepsmap' VALUES (22121, 5256, 2);
INSERT INTO 'dancesstepsmap' VALUES (22122, 17622, 1);
INSERT INTO 'dancesstepsmap' VALUES (22123, 17622, 2);
INSERT INTO 'dancesstepsmap' VALUES (22124, 7389, 5);
INSERT INTO 'dancesstepsmap' VALUES (22125, 13385, 3);
INSERT INTO 'dancesstepsmap' VALUES (22126, 13385, 1);
INSERT INTO 'dancesstepsmap' VALUES (22127, 13316, 2);
INSERT INTO 'dancesstepsmap' VALUES (22128, 17626, 1);
INSERT INTO 'dancesstepsmap' VALUES (22129, 17626, 2);
INSERT INTO 'dancesstepsmap' VALUES (22130, 17627, 2);
INSERT INTO 'dancesstepsmap' VALUES (22131, 17627, 1);
INSERT INTO 'dancesstepsmap' VALUES (22132, 17629, 1);
INSERT INTO 'dancesstepsmap' VALUES (22133, 17629, 2);
INSERT INTO 'dancesstepsmap' VALUES (22134, 17629, 3);
INSERT INTO 'dancesstepsmap' VALUES (22135, 8472, 5);
INSERT INTO 'dancesstepsmap' VALUES (22138, 17630, 1);
INSERT INTO 'dancesstepsmap' VALUES (22139, 17630, 2);
INSERT INTO 'dancesstepsmap' VALUES (7425, 8468, 2);
INSERT INTO 'dancesstepsmap' VALUES (22140, 8468, 3);
INSERT INTO 'dancesstepsmap' VALUES (22141, 17631, 1);
INSERT INTO 'dancesstepsmap' VALUES (22143, 8475, 5);
INSERT INTO 'dancesstepsmap' VALUES (22146, 16608, 1);
INSERT INTO 'dancesstepsmap' VALUES (22147, 17637, 2);
INSERT INTO 'dancesstepsmap' VALUES (22148, 17637, 1);
INSERT INTO 'dancesstepsmap' VALUES (22149, 17657, 4);
INSERT INTO 'dancesstepsmap' VALUES (22150, 17657, 5);
INSERT INTO 'dancesstepsmap' VALUES (22151, 17658, 1);
INSERT INTO 'dancesstepsmap' VALUES (20893, 16706, 5);
INSERT INTO 'dancesstepsmap' VALUES (20894, 16706, 4);
INSERT INTO 'dancesstepsmap' VALUES (22152, 17659, 5);
INSERT INTO 'dancesstepsmap' VALUES (22153, 17659, 4);
INSERT INTO 'dancesstepsmap' VALUES (22156, 17661, 1);
INSERT INTO 'dancesstepsmap' VALUES (22157, 17661, 2);
INSERT INTO 'dancesstepsmap' VALUES (22158, 17661, 3);
INSERT INTO 'dancesstepsmap' VALUES (22159, 17662, 1);
INSERT INTO 'dancesstepsmap' VALUES (22160, 17663, 1);
INSERT INTO 'dancesstepsmap' VALUES (22161, 17663, 2);
INSERT INTO 'dancesstepsmap' VALUES (22162, 4763, 5);
INSERT INTO 'dancesstepsmap' VALUES (22163, 7572, 6);
INSERT INTO 'dancesstepsmap' VALUES (22164, 7572, 4);
INSERT INTO 'dancesstepsmap' VALUES (22165, 7572, 2);
INSERT INTO 'dancesstepsmap' VALUES (22166, 7572, 1);
INSERT INTO 'dancesstepsmap' VALUES (22167, 7572, 3);
INSERT INTO 'dancesstepsmap' VALUES (22168, 5272, 5);
INSERT INTO 'dancesstepsmap' VALUES (22169, 17664, 2);
INSERT INTO 'dancesstepsmap' VALUES (22170, 17664, 1);
INSERT INTO 'dancesstepsmap' VALUES (22171, 17664, 3);
INSERT INTO 'dancesstepsmap' VALUES (22172, 17665, 4);
INSERT INTO 'dancesstepsmap' VALUES (22173, 17665, 5);
INSERT INTO 'dancesstepsmap' VALUES (22174, 17666, 1);
INSERT INTO 'dancesstepsmap' VALUES (22175, 17666, 2);
INSERT INTO 'dancesstepsmap' VALUES (22176, 17667, 1);
INSERT INTO 'dancesstepsmap' VALUES (22177, 17667, 2);
INSERT INTO 'dancesstepsmap' VALUES (22178, 17668, 1);
INSERT INTO 'dancesstepsmap' VALUES (22179, 17669, 2);
INSERT INTO 'dancesstepsmap' VALUES (22180, 17669, 1);
INSERT INTO 'dancesstepsmap' VALUES (22181, 17670, 1);
INSERT INTO 'dancesstepsmap' VALUES (5588, 6056, 2);
INSERT INTO 'dancesstepsmap' VALUES (22182, 6056, 1);
INSERT INTO 'dancesstepsmap' VALUES (14185, 12247, 5);
INSERT INTO 'dancesstepsmap' VALUES (22183, 12247, 4);
INSERT INTO 'dancesstepsmap' VALUES (22184, 2413, 5);
INSERT INTO 'dancesstepsmap' VALUES (22185, 2413, 4);
INSERT INTO 'dancesstepsmap' VALUES (22186, 2413, 1);
INSERT INTO 'dancesstepsmap' VALUES (22187, 2413, 2);
INSERT INTO 'dancesstepsmap' VALUES (22188, 2413, 3);
INSERT INTO 'dancesstepsmap' VALUES (22189, 2413, 9);
INSERT INTO 'dancesstepsmap' VALUES (22190, 2413, 6);
INSERT INTO 'dancesstepsmap' VALUES (22191, 2413, 99);
INSERT INTO 'dancesstepsmap' VALUES (22192, 17671, 10);
INSERT INTO 'dancesstepsmap' VALUES (22193, 17671, 4);
INSERT INTO 'dancesstepsmap' VALUES (22194, 17671, 5);
INSERT INTO 'dancesstepsmap' VALUES (22195, 17671, 1);
INSERT INTO 'dancesstepsmap' VALUES (22196, 17671, 2);
INSERT INTO 'dancesstepsmap' VALUES (22197, 17671, 3);
INSERT INTO 'dancesstepsmap' VALUES (22198, 17672, 4);
INSERT INTO 'dancesstepsmap' VALUES (22199, 17672, 5);
INSERT INTO 'dancesstepsmap' VALUES (22200, 17672, 10);
INSERT INTO 'dancesstepsmap' VALUES (22201, 17672, 1);
INSERT INTO 'dancesstepsmap' VALUES (22202, 17672, 2);
INSERT INTO 'dancesstepsmap' VALUES (22203, 17673, 5);
INSERT INTO 'dancesstepsmap' VALUES (22204, 17673, 4);
INSERT INTO 'dancesstepsmap' VALUES (22205, 17673, 1);
INSERT INTO 'dancesstepsmap' VALUES (22206, 17673, 2);
INSERT INTO 'dancesstepsmap' VALUES (22207, 17674, 2);
INSERT INTO 'dancesstepsmap' VALUES (22208, 17674, 1);
INSERT INTO 'dancesstepsmap' VALUES (22209, 17675, 5);
INSERT INTO 'dancesstepsmap' VALUES (22210, 17675, 4);
INSERT INTO 'dancesstepsmap' VALUES (22211, 6633, 2);
INSERT INTO 'dancesstepsmap' VALUES (22212, 17676, 1);
INSERT INTO 'dancesstepsmap' VALUES (22213, 17676, 3);
INSERT INTO 'dancesstepsmap' VALUES (22214, 17676, 2);
INSERT INTO 'dancesstepsmap' VALUES (22215, 15440, 3);
INSERT INTO 'dancesstepsmap' VALUES (22216, 17685, 1);
INSERT INTO 'dancesstepsmap' VALUES (22107, 17030, 5);
INSERT INTO 'dancesstepsmap' VALUES (22108, 17030, 4);
INSERT INTO 'dancesstepsmap' VALUES (22217, 17685, 2);
INSERT INTO 'dancesstepsmap' VALUES (22218, 8484, 2);
INSERT INTO 'dancesstepsmap' VALUES (22219, 17686, 1);
INSERT INTO 'dancesstepsmap' VALUES (22220, 17686, 2);
INSERT INTO 'dancesstepsmap' VALUES (22221, 17687, 1);
INSERT INTO 'dancesstepsmap' VALUES (22222, 17687, 2);
INSERT INTO 'dancesstepsmap' VALUES (22223, 17677, 1);
INSERT INTO 'dancesstepsmap' VALUES (22224, 17677, 3);
INSERT INTO 'dancesstepsmap' VALUES (22225, 17678, 5);
INSERT INTO 'dancesstepsmap' VALUES (22226, 17678, 4);
INSERT INTO 'dancesstepsmap' VALUES (22227, 17679, 2);
INSERT INTO 'dancesstepsmap' VALUES (22228, 17679, 1);
INSERT INTO 'dancesstepsmap' VALUES (22229, 17680, 1);
INSERT INTO 'dancesstepsmap' VALUES (22230, 17680, 3);
INSERT INTO 'dancesstepsmap' VALUES (22231, 17681, 1);
INSERT INTO 'dancesstepsmap' VALUES (22232, 17681, 2);
INSERT INTO 'dancesstepsmap' VALUES (22233, 17682, 4);
INSERT INTO 'dancesstepsmap' VALUES (22234, 17683, 2);
INSERT INTO 'dancesstepsmap' VALUES (22235, 17683, 1);
INSERT INTO 'dancesstepsmap' VALUES (22236, 17684, 4);
INSERT INTO 'dancesstepsmap' VALUES (22237, 17684, 5);
INSERT INTO 'dancesstepsmap' VALUES (22238, 17688, 5);
INSERT INTO 'dancesstepsmap' VALUES (22239, 17688, 4);
INSERT INTO 'dancesstepsmap' VALUES (22240, 15677, 2);
INSERT INTO 'dancesstepsmap' VALUES (22241, 15677, 1);
INSERT INTO 'dancesstepsmap' VALUES (22242, 15677, 3);
INSERT INTO 'dancesstepsmap' VALUES (22243, 16963, 5);
INSERT INTO 'dancesstepsmap' VALUES (22244, 16963, 4);
INSERT INTO 'dancesstepsmap' VALUES (22245, 17679, 3);
INSERT INTO 'dancesstepsmap' VALUES (22246, 17704, 5);
INSERT INTO 'dancesstepsmap' VALUES (22247, 17704, 4);
INSERT INTO 'dancesstepsmap' VALUES (22248, 17705, 4);
INSERT INTO 'dancesstepsmap' VALUES (22249, 17705, 5);
INSERT INTO 'dancesstepsmap' VALUES (22250, 17706, 4);
INSERT INTO 'dancesstepsmap' VALUES (22251, 17706, 5);
INSERT INTO 'dancesstepsmap' VALUES (22252, 17706, 2);
INSERT INTO 'dancesstepsmap' VALUES (22253, 17706, 1);
INSERT INTO 'dancesstepsmap' VALUES (22254, 17706, 6);
INSERT INTO 'dancesstepsmap' VALUES (22255, 17706, 10);
INSERT INTO 'dancesstepsmap' VALUES (22256, 17707, 1);
INSERT INTO 'dancesstepsmap' VALUES (22257, 17707, 2);
INSERT INTO 'dancesstepsmap' VALUES (22258, 17707, 3);
INSERT INTO 'dancesstepsmap' VALUES (22259, 17708, 1);
INSERT INTO 'dancesstepsmap' VALUES (22260, 17708, 2);
INSERT INTO 'dancesstepsmap' VALUES (22261, 17709, 4);
INSERT INTO 'dancesstepsmap' VALUES (22262, 17709, 5);
INSERT INTO 'dancesstepsmap' VALUES (22263, 17710, 1);
INSERT INTO 'dancesstepsmap' VALUES (22264, 17710, 2);
INSERT INTO 'dancesstepsmap' VALUES (22265, 17711, 5);
INSERT INTO 'dancesstepsmap' VALUES (22266, 17711, 4);
INSERT INTO 'dancesstepsmap' VALUES (22267, 17712, 4);
INSERT INTO 'dancesstepsmap' VALUES (22268, 17712, 5);
INSERT INTO 'dancesstepsmap' VALUES (22269, 17712, 1);
INSERT INTO 'dancesstepsmap' VALUES (22270, 17712, 3);
INSERT INTO 'dancesstepsmap' VALUES (22271, 2719, 2);
INSERT INTO 'dancesstepsmap' VALUES (22272, 5579, 2);
INSERT INTO 'dancesstepsmap' VALUES (22273, 1372, 3);
INSERT INTO 'dancesstepsmap' VALUES (22274, 17715, 5);
INSERT INTO 'dancesstepsmap' VALUES (22275, 17715, 4);
INSERT INTO 'dancesstepsmap' VALUES (6745, 5915, 6);
INSERT INTO 'dancesstepsmap' VALUES (22276, 5915, 10);
INSERT INTO 'dancesstepsmap' VALUES (22277, 17716, 1);
INSERT INTO 'dancesstepsmap' VALUES (22278, 17716, 2);
INSERT INTO 'dancesstepsmap' VALUES (22279, 17716, 3);
INSERT INTO 'dancesstepsmap' VALUES (22280, 17717, 1);
INSERT INTO 'dancesstepsmap' VALUES (22281, 17717, 2);
INSERT INTO 'dancesstepsmap' VALUES (22282, 17717, 3);
INSERT INTO 'dancesstepsmap' VALUES (22283, 17718, 1);
INSERT INTO 'dancesstepsmap' VALUES (22284, 17718, 3);
INSERT INTO 'dancesstepsmap' VALUES (22285, 17719, 2);
INSERT INTO 'dancesstepsmap' VALUES (22286, 17719, 1);
INSERT INTO 'dancesstepsmap' VALUES (22287, 17720, 1);
INSERT INTO 'dancesstepsmap' VALUES (22288, 17726, 1);
INSERT INTO 'dancesstepsmap' VALUES (22289, 17727, 1);
INSERT INTO 'dancesstepsmap' VALUES (22290, 17727, 2);
INSERT INTO 'dancesstepsmap' VALUES (22291, 17728, 2);
INSERT INTO 'dancesstepsmap' VALUES (22292, 17728, 1);
INSERT INTO 'dancesstepsmap' VALUES (22293, 8526, 2);
INSERT INTO 'dancesstepsmap' VALUES (22294, 17729, 1);
INSERT INTO 'dancesstepsmap' VALUES (22295, 17429, 4);
INSERT INTO 'dancesstepsmap' VALUES (22296, 17429, 5);
INSERT INTO 'dancesstepsmap' VALUES (22297, 4563, 2);
INSERT INTO 'dancesstepsmap' VALUES (22298, 17736, 4);
INSERT INTO 'dancesstepsmap' VALUES (22299, 17736, 5);
INSERT INTO 'dancesstepsmap' VALUES (22300, 17737, 4);
INSERT INTO 'dancesstepsmap' VALUES (22301, 17737, 5);
INSERT INTO 'dancesstepsmap' VALUES (22302, 17648, 1);
INSERT INTO 'dancesstepsmap' VALUES (22303, 17648, 2);
INSERT INTO 'dancesstepsmap' VALUES (22304, 17648, 3);
INSERT INTO 'dancesstepsmap' VALUES (22305, 17738, 4);
INSERT INTO 'dancesstepsmap' VALUES (22306, 17649, 4);
INSERT INTO 'dancesstepsmap' VALUES (22307, 17649, 5);
INSERT INTO 'dancesstepsmap' VALUES (22308, 17649, 1);
INSERT INTO 'dancesstepsmap' VALUES (22309, 17649, 3);
INSERT INTO 'dancesstepsmap' VALUES (22310, 17649, 2);
INSERT INTO 'dancesstepsmap' VALUES (22311, 17650, 1);
INSERT INTO 'dancesstepsmap' VALUES (22312, 17650, 2);
INSERT INTO 'dancesstepsmap' VALUES (22313, 17650, 3);
INSERT INTO 'dancesstepsmap' VALUES (22314, 17654, 1);
INSERT INTO 'dancesstepsmap' VALUES (22315, 17654, 3);
INSERT INTO 'dancesstepsmap' VALUES (22316, 17739, 1);
INSERT INTO 'dancesstepsmap' VALUES (22317, 17142, 1);
INSERT INTO 'dancesstepsmap' VALUES (22318, 17142, 2);
INSERT INTO 'dancesstepsmap' VALUES (22319, 17651, 4);
INSERT INTO 'dancesstepsmap' VALUES (22320, 17651, 5);
INSERT INTO 'dancesstepsmap' VALUES (22321, 17655, 4);
INSERT INTO 'dancesstepsmap' VALUES (22322, 17740, 2);
INSERT INTO 'dancesstepsmap' VALUES (22323, 17740, 1);
INSERT INTO 'dancesstepsmap' VALUES (22324, 17652, 5);
INSERT INTO 'dancesstepsmap' VALUES (22325, 17652, 4);
INSERT INTO 'dancesstepsmap' VALUES (22326, 17653, 4);
INSERT INTO 'dancesstepsmap' VALUES (22327, 17653, 5);
INSERT INTO 'dancesstepsmap' VALUES (22328, 17741, 5);
INSERT INTO 'dancesstepsmap' VALUES (22329, 17741, 4);
INSERT INTO 'dancesstepsmap' VALUES (22330, 17742, 1);
INSERT INTO 'dancesstepsmap' VALUES (22331, 17742, 2);
INSERT INTO 'dancesstepsmap' VALUES (22332, 17647, 4);
INSERT INTO 'dancesstepsmap' VALUES (22333, 17647, 5);
INSERT INTO 'dancesstepsmap' VALUES (22334, 17743, 5);
INSERT INTO 'dancesstepsmap' VALUES (22335, 17743, 4);
INSERT INTO 'dancesstepsmap' VALUES (22336, 9800, 1);
INSERT INTO 'dancesstepsmap' VALUES (22337, 9800, 2);
INSERT INTO 'dancesstepsmap' VALUES (22338, 17744, 1);
INSERT INTO 'dancesstepsmap' VALUES (22339, 17744, 2);
INSERT INTO 'dancesstepsmap' VALUES (22340, 17749, 4);
INSERT INTO 'dancesstepsmap' VALUES (22341, 17749, 5);
INSERT INTO 'dancesstepsmap' VALUES (22342, 10402, 5);
INSERT INTO 'dancesstepsmap' VALUES (22343, 14335, 1);
INSERT INTO 'dancesstepsmap' VALUES (22344, 17750, 1);
INSERT INTO 'dancesstepsmap' VALUES (22345, 17750, 3);
INSERT INTO 'dancesstepsmap' VALUES (22346, 17751, 1);
INSERT INTO 'dancesstepsmap' VALUES (22347, 17751, 3);
INSERT INTO 'dancesstepsmap' VALUES (22348, 14073, 4);
INSERT INTO 'dancesstepsmap' VALUES (22349, 14073, 5);
INSERT INTO 'dancesstepsmap' VALUES (22350, 4646, 5);
INSERT INTO 'dancesstepsmap' VALUES (22351, 16497, 2);
INSERT INTO 'dancesstepsmap' VALUES (22352, 10652, 4);
INSERT INTO 'dancesstepsmap' VALUES (22353, 10652, 5);
INSERT INTO 'dancesstepsmap' VALUES (22354, 10654, 1);
INSERT INTO 'dancesstepsmap' VALUES (22355, 10654, 2);
INSERT INTO 'dancesstepsmap' VALUES (22356, 10661, 1);
INSERT INTO 'dancesstepsmap' VALUES (22357, 10661, 2);
INSERT INTO 'dancesstepsmap' VALUES (22358, 10659, 4);
INSERT INTO 'dancesstepsmap' VALUES (22359, 10659, 5);
INSERT INTO 'dancesstepsmap' VALUES (22360, 17752, 4);
INSERT INTO 'dancesstepsmap' VALUES (22361, 17752, 5);
INSERT INTO 'dancesstepsmap' VALUES (22362, 10662, 4);
INSERT INTO 'dancesstepsmap' VALUES (22363, 10662, 5);
INSERT INTO 'dancesstepsmap' VALUES (22364, 10660, 1);
INSERT INTO 'dancesstepsmap' VALUES (22365, 10660, 2);
INSERT INTO 'dancesstepsmap' VALUES (22366, 10658, 1);
INSERT INTO 'dancesstepsmap' VALUES (22367, 10658, 2);
INSERT INTO 'dancesstepsmap' VALUES (22368, 17760, 4);
INSERT INTO 'dancesstepsmap' VALUES (22369, 17760, 5);
INSERT INTO 'dancesstepsmap' VALUES (23215, 12349, 3);
INSERT INTO 'dancesstepsmap' VALUES (22371, 17767, 2);
INSERT INTO 'dancesstepsmap' VALUES (22372, 17767, 1);
INSERT INTO 'dancesstepsmap' VALUES (22373, 14040, 1);
INSERT INTO 'dancesstepsmap' VALUES (22374, 14040, 2);
INSERT INTO 'dancesstepsmap' VALUES (22375, 13558, 1);
INSERT INTO 'dancesstepsmap' VALUES (22376, 13558, 2);
INSERT INTO 'dancesstepsmap' VALUES (22377, 13554, 1);
INSERT INTO 'dancesstepsmap' VALUES (22378, 13554, 2);
INSERT INTO 'dancesstepsmap' VALUES (22379, 8559, 5);
INSERT INTO 'dancesstepsmap' VALUES (22380, 17770, 5);
INSERT INTO 'dancesstepsmap' VALUES (22381, 17770, 4);
INSERT INTO 'dancesstepsmap' VALUES (22382, 17689, 1);
INSERT INTO 'dancesstepsmap' VALUES (22383, 17689, 2);
INSERT INTO 'dancesstepsmap' VALUES (22384, 17690, 1);
INSERT INTO 'dancesstepsmap' VALUES (22385, 17690, 2);
INSERT INTO 'dancesstepsmap' VALUES (22386, 17773, 2);
INSERT INTO 'dancesstepsmap' VALUES (22387, 17773, 1);
INSERT INTO 'dancesstepsmap' VALUES (22388, 17775, 5);
INSERT INTO 'dancesstepsmap' VALUES (22389, 17775, 4);
INSERT INTO 'dancesstepsmap' VALUES (22390, 17776, 1);
INSERT INTO 'dancesstepsmap' VALUES (22391, 17776, 3);
INSERT INTO 'dancesstepsmap' VALUES (22392, 17580, 1);
INSERT INTO 'dancesstepsmap' VALUES (22393, 17580, 2);
INSERT INTO 'dancesstepsmap' VALUES (22394, 17778, 1);
INSERT INTO 'dancesstepsmap' VALUES (22395, 17778, 2);
INSERT INTO 'dancesstepsmap' VALUES (22396, 17781, 4);
INSERT INTO 'dancesstepsmap' VALUES (22397, 17781, 5);
INSERT INTO 'dancesstepsmap' VALUES (22398, 17781, 1);
INSERT INTO 'dancesstepsmap' VALUES (22399, 17781, 2);
INSERT INTO 'dancesstepsmap' VALUES (22400, 17781, 3);
INSERT INTO 'dancesstepsmap' VALUES (22401, 17782, 1);
INSERT INTO 'dancesstepsmap' VALUES (22402, 14728, 5);
INSERT INTO 'dancesstepsmap' VALUES (22403, 14728, 4);
INSERT INTO 'dancesstepsmap' VALUES (22404, 14726, 3);
INSERT INTO 'dancesstepsmap' VALUES (22405, 14726, 1);
INSERT INTO 'dancesstepsmap' VALUES (22406, 14726, 2);
INSERT INTO 'dancesstepsmap' VALUES (22407, 14722, 5);
INSERT INTO 'dancesstepsmap' VALUES (22408, 14722, 4);
INSERT INTO 'dancesstepsmap' VALUES (22409, 17786, 1);
INSERT INTO 'dancesstepsmap' VALUES (22410, 17786, 2);
INSERT INTO 'dancesstepsmap' VALUES (22411, 5292, 2);
INSERT INTO 'dancesstepsmap' VALUES (22412, 1744, 1);
INSERT INTO 'dancesstepsmap' VALUES (22413, 1744, 2);
INSERT INTO 'dancesstepsmap' VALUES (22414, 1744, 4);
INSERT INTO 'dancesstepsmap' VALUES (22415, 1744, 5);
INSERT INTO 'dancesstepsmap' VALUES (22416, 14724, 2);
INSERT INTO 'dancesstepsmap' VALUES (22417, 14724, 1);
INSERT INTO 'dancesstepsmap' VALUES (22418, 1148, 2);
INSERT INTO 'dancesstepsmap' VALUES (22419, 1148, 3);
INSERT INTO 'dancesstepsmap' VALUES (22420, 14725, 4);
INSERT INTO 'dancesstepsmap' VALUES (22421, 14725, 5);
INSERT INTO 'dancesstepsmap' VALUES (22422, 14727, 2);
INSERT INTO 'dancesstepsmap' VALUES (22423, 14727, 1);
INSERT INTO 'dancesstepsmap' VALUES (22424, 14723, 2);
INSERT INTO 'dancesstepsmap' VALUES (22425, 17787, 1);
INSERT INTO 'dancesstepsmap' VALUES (22426, 7074, 5);
INSERT INTO 'dancesstepsmap' VALUES (22427, 14600, 1);
INSERT INTO 'dancesstepsmap' VALUES (22428, 14600, 2);
INSERT INTO 'dancesstepsmap' VALUES (22429, 15302, 2);
INSERT INTO 'dancesstepsmap' VALUES (22430, 15302, 1);
INSERT INTO 'dancesstepsmap' VALUES (22431, 15302, 3);
INSERT INTO 'dancesstepsmap' VALUES (22432, 11163, 5);
INSERT INTO 'dancesstepsmap' VALUES (22433, 17788, 4);
INSERT INTO 'dancesstepsmap' VALUES (22434, 17788, 5);
INSERT INTO 'dancesstepsmap' VALUES (22435, 15297, 2);
INSERT INTO 'dancesstepsmap' VALUES (22436, 15297, 1);
INSERT INTO 'dancesstepsmap' VALUES (22437, 17791, 99);
INSERT INTO 'dancesstepsmap' VALUES (22440, 17792, 2);
INSERT INTO 'dancesstepsmap' VALUES (22441, 17792, 1);
INSERT INTO 'dancesstepsmap' VALUES (22442, 17797, 2);
INSERT INTO 'dancesstepsmap' VALUES (22443, 17797, 1);
INSERT INTO 'dancesstepsmap' VALUES (22444, 17799, 5);
INSERT INTO 'dancesstepsmap' VALUES (22445, 17799, 4);
INSERT INTO 'dancesstepsmap' VALUES (22446, 17800, 1);
INSERT INTO 'dancesstepsmap' VALUES (22447, 7204, 5);
INSERT INTO 'dancesstepsmap' VALUES (22448, 17801, 1);
INSERT INTO 'dancesstepsmap' VALUES (22449, 17801, 2);
INSERT INTO 'dancesstepsmap' VALUES (22450, 17802, 1);
INSERT INTO 'dancesstepsmap' VALUES (22451, 17802, 2);
INSERT INTO 'dancesstepsmap' VALUES (22452, 17879, 1);
INSERT INTO 'dancesstepsmap' VALUES (22453, 17879, 2);
INSERT INTO 'dancesstepsmap' VALUES (22454, 17880, 5);
INSERT INTO 'dancesstepsmap' VALUES (22455, 17880, 4);
INSERT INTO 'dancesstepsmap' VALUES (22456, 17793, 1);
INSERT INTO 'dancesstepsmap' VALUES (22457, 17794, 5);
INSERT INTO 'dancesstepsmap' VALUES (22458, 17794, 4);
INSERT INTO 'dancesstepsmap' VALUES (22459, 17795, 1);
INSERT INTO 'dancesstepsmap' VALUES (22460, 17795, 3);
INSERT INTO 'dancesstepsmap' VALUES (22461, 17796, 5);
INSERT INTO 'dancesstepsmap' VALUES (22462, 17796, 4);
INSERT INTO 'dancesstepsmap' VALUES (22463, 17881, 1);
INSERT INTO 'dancesstepsmap' VALUES (22464, 17881, 2);
INSERT INTO 'dancesstepsmap' VALUES (22465, 17793, 2);
INSERT INTO 'dancesstepsmap' VALUES (22466, 3277, 5);
INSERT INTO 'dancesstepsmap' VALUES (22467, 17797, 3);
INSERT INTO 'dancesstepsmap' VALUES (22468, 17798, 4);
INSERT INTO 'dancesstepsmap' VALUES (22469, 17798, 1);
INSERT INTO 'dancesstepsmap' VALUES (22470, 6858, 2);
INSERT INTO 'dancesstepsmap' VALUES (22471, 17801, 3);
INSERT INTO 'dancesstepsmap' VALUES (22472, 17802, 3);
INSERT INTO 'dancesstepsmap' VALUES (22475, 17882, 1);
INSERT INTO 'dancesstepsmap' VALUES (22476, 17882, 2);
INSERT INTO 'dancesstepsmap' VALUES (22477, 17882, 3);
INSERT INTO 'dancesstepsmap' VALUES (22478, 17883, 5);
INSERT INTO 'dancesstepsmap' VALUES (22479, 17883, 4);
INSERT INTO 'dancesstepsmap' VALUES (22480, 17884, 4);
INSERT INTO 'dancesstepsmap' VALUES (22481, 17884, 5);
INSERT INTO 'dancesstepsmap' VALUES (22482, 15299, 1);
INSERT INTO 'dancesstepsmap' VALUES (22483, 15299, 2);
INSERT INTO 'dancesstepsmap' VALUES (22484, 5026, 2);
INSERT INTO 'dancesstepsmap' VALUES (22485, 17886, 1);
INSERT INTO 'dancesstepsmap' VALUES (22486, 17886, 2);
INSERT INTO 'dancesstepsmap' VALUES (22487, 17886, 3);
INSERT INTO 'dancesstepsmap' VALUES (22488, 17887, 4);
INSERT INTO 'dancesstepsmap' VALUES (22489, 17887, 5);
INSERT INTO 'dancesstepsmap' VALUES (22490, 11183, 4);
INSERT INTO 'dancesstepsmap' VALUES (22491, 17888, 1);
INSERT INTO 'dancesstepsmap' VALUES (22492, 17888, 2);
INSERT INTO 'dancesstepsmap' VALUES (23240, 18271, 1);
INSERT INTO 'dancesstepsmap' VALUES (22495, 14077, 1);
INSERT INTO 'dancesstepsmap' VALUES (22496, 14077, 2);
INSERT INTO 'dancesstepsmap' VALUES (22497, 14074, 2);
INSERT INTO 'dancesstepsmap' VALUES (22498, 14074, 1);
INSERT INTO 'dancesstepsmap' VALUES (22499, 17890, 4);
INSERT INTO 'dancesstepsmap' VALUES (22500, 17890, 6);
INSERT INTO 'dancesstepsmap' VALUES (22501, 11536, 2);
INSERT INTO 'dancesstepsmap' VALUES (22502, 17891, 2);
INSERT INTO 'dancesstepsmap' VALUES (22503, 17891, 1);
INSERT INTO 'dancesstepsmap' VALUES (22504, 17891, 3);
INSERT INTO 'dancesstepsmap' VALUES (22505, 17892, 1);
INSERT INTO 'dancesstepsmap' VALUES (22506, 17892, 2);
INSERT INTO 'dancesstepsmap' VALUES (22507, 17892, 3);
INSERT INTO 'dancesstepsmap' VALUES (22508, 17893, 5);
INSERT INTO 'dancesstepsmap' VALUES (22509, 17893, 4);
INSERT INTO 'dancesstepsmap' VALUES (22512, 17895, 1);
INSERT INTO 'dancesstepsmap' VALUES (22513, 17895, 2);
INSERT INTO 'dancesstepsmap' VALUES (22514, 17896, 1);
INSERT INTO 'dancesstepsmap' VALUES (22515, 17897, 5);
INSERT INTO 'dancesstepsmap' VALUES (22516, 17897, 4);
INSERT INTO 'dancesstepsmap' VALUES (22517, 17898, 1);
INSERT INTO 'dancesstepsmap' VALUES (22518, 17899, 5);
INSERT INTO 'dancesstepsmap' VALUES (22519, 17899, 4);
INSERT INTO 'dancesstepsmap' VALUES (22520, 17900, 1);
INSERT INTO 'dancesstepsmap' VALUES (22521, 17901, 1);
INSERT INTO 'dancesstepsmap' VALUES (22522, 17901, 2);
INSERT INTO 'dancesstepsmap' VALUES (22523, 17832, 2);
INSERT INTO 'dancesstepsmap' VALUES (22524, 17832, 3);
INSERT INTO 'dancesstepsmap' VALUES (22525, 14667, 1);
INSERT INTO 'dancesstepsmap' VALUES (22526, 14667, 2);
INSERT INTO 'dancesstepsmap' VALUES (22527, 17902, 1);
INSERT INTO 'dancesstepsmap' VALUES (22528, 17902, 2);
INSERT INTO 'dancesstepsmap' VALUES (22531, 17904, 2);
INSERT INTO 'dancesstepsmap' VALUES (22532, 17904, 1);
INSERT INTO 'dancesstepsmap' VALUES (22533, 17905, 4);
INSERT INTO 'dancesstepsmap' VALUES (22534, 17918, 5);
INSERT INTO 'dancesstepsmap' VALUES (22535, 17918, 4);
INSERT INTO 'dancesstepsmap' VALUES (22536, 17919, 1);
INSERT INTO 'dancesstepsmap' VALUES (22537, 1646, 5);
INSERT INTO 'dancesstepsmap' VALUES (22538, 1646, 4);
INSERT INTO 'dancesstepsmap' VALUES (22539, 1646, 1);
INSERT INTO 'dancesstepsmap' VALUES (22540, 1646, 2);
INSERT INTO 'dancesstepsmap' VALUES (22541, 3855, 2);
INSERT INTO 'dancesstepsmap' VALUES (22542, 17920, 5);
INSERT INTO 'dancesstepsmap' VALUES (22543, 17920, 4);
INSERT INTO 'dancesstepsmap' VALUES (22544, 17921, 2);
INSERT INTO 'dancesstepsmap' VALUES (22545, 17921, 1);
INSERT INTO 'dancesstepsmap' VALUES (22546, 17922, 4);
INSERT INTO 'dancesstepsmap' VALUES (22547, 17922, 5);
INSERT INTO 'dancesstepsmap' VALUES (23216, 11320, 1);
INSERT INTO 'dancesstepsmap' VALUES (23217, 18265, 2);
INSERT INTO 'dancesstepsmap' VALUES (22550, 8732, 1);
INSERT INTO 'dancesstepsmap' VALUES (22551, 8732, 2);
INSERT INTO 'dancesstepsmap' VALUES (22552, 1298, 2);
INSERT INTO 'dancesstepsmap' VALUES (22553, 17780, 1);
INSERT INTO 'dancesstepsmap' VALUES (22554, 17780, 2);
INSERT INTO 'dancesstepsmap' VALUES (22555, 17924, 1);
INSERT INTO 'dancesstepsmap' VALUES (22556, 17924, 2);
INSERT INTO 'dancesstepsmap' VALUES (22557, 17924, 3);
INSERT INTO 'dancesstepsmap' VALUES (22558, 17925, 4);
INSERT INTO 'dancesstepsmap' VALUES (22559, 7866, 2);
INSERT INTO 'dancesstepsmap' VALUES (22560, 15102, 4);
INSERT INTO 'dancesstepsmap' VALUES (22561, 15102, 5);
INSERT INTO 'dancesstepsmap' VALUES (22562, 15099, 4);
INSERT INTO 'dancesstepsmap' VALUES (22563, 15099, 5);
INSERT INTO 'dancesstepsmap' VALUES (22564, 15100, 2);
INSERT INTO 'dancesstepsmap' VALUES (22565, 15100, 1);
INSERT INTO 'dancesstepsmap' VALUES (22566, 15107, 1);
INSERT INTO 'dancesstepsmap' VALUES (22567, 17926, 4);
INSERT INTO 'dancesstepsmap' VALUES (22568, 17926, 5);
INSERT INTO 'dancesstepsmap' VALUES (22569, 17927, 5);
INSERT INTO 'dancesstepsmap' VALUES (22570, 17927, 4);
INSERT INTO 'dancesstepsmap' VALUES (22571, 3264, 2);
INSERT INTO 'dancesstepsmap' VALUES (22572, 3264, 3);
INSERT INTO 'dancesstepsmap' VALUES (22573, 15115, 1);
INSERT INTO 'dancesstepsmap' VALUES (22574, 15115, 2);
INSERT INTO 'dancesstepsmap' VALUES (22575, 15120, 5);
INSERT INTO 'dancesstepsmap' VALUES (22576, 15120, 4);
INSERT INTO 'dancesstepsmap' VALUES (22577, 15112, 2);
INSERT INTO 'dancesstepsmap' VALUES (22578, 15112, 1);
INSERT INTO 'dancesstepsmap' VALUES (22579, 15119, 1);
INSERT INTO 'dancesstepsmap' VALUES (22580, 17948, 1);
INSERT INTO 'dancesstepsmap' VALUES (22581, 17948, 2);
INSERT INTO 'dancesstepsmap' VALUES (22582, 17948, 3);
INSERT INTO 'dancesstepsmap' VALUES (22583, 2643, 5);
INSERT INTO 'dancesstepsmap' VALUES (22584, 17949, 5);
INSERT INTO 'dancesstepsmap' VALUES (22585, 17949, 4);
INSERT INTO 'dancesstepsmap' VALUES (22586, 17949, 1);
INSERT INTO 'dancesstepsmap' VALUES (22587, 17949, 2);
INSERT INTO 'dancesstepsmap' VALUES (22588, 17949, 3);
INSERT INTO 'dancesstepsmap' VALUES (22438, 14156, 4);
INSERT INTO 'dancesstepsmap' VALUES (22439, 14156, 5);
INSERT INTO 'dancesstepsmap' VALUES (22529, 17903, 4);
INSERT INTO 'dancesstepsmap' VALUES (22589, 17949, 8);
INSERT INTO 'dancesstepsmap' VALUES (22590, 3817, 2);
INSERT INTO 'dancesstepsmap' VALUES (22591, 4349, 2);
INSERT INTO 'dancesstepsmap' VALUES (22592, 4887, 5);
INSERT INTO 'dancesstepsmap' VALUES (22593, 5070, 5);
INSERT INTO 'dancesstepsmap' VALUES (22594, 5082, 2);
INSERT INTO 'dancesstepsmap' VALUES (22595, 5082, 3);
INSERT INTO 'dancesstepsmap' VALUES (22596, 5478, 5);
INSERT INTO 'dancesstepsmap' VALUES (22597, 6222, 2);
INSERT INTO 'dancesstepsmap' VALUES (22598, 6222, 3);
INSERT INTO 'dancesstepsmap' VALUES (22599, 17950, 1);
INSERT INTO 'dancesstepsmap' VALUES (22600, 17950, 2);
INSERT INTO 'dancesstepsmap' VALUES (22603, 17952, 4);
INSERT INTO 'dancesstepsmap' VALUES (22604, 17952, 5);
INSERT INTO 'dancesstepsmap' VALUES (22605, 17953, 5);
INSERT INTO 'dancesstepsmap' VALUES (22606, 17953, 4);
INSERT INTO 'dancesstepsmap' VALUES (22607, 17953, 1);
INSERT INTO 'dancesstepsmap' VALUES (22608, 17953, 2);
INSERT INTO 'dancesstepsmap' VALUES (22612, 17955, 4);
INSERT INTO 'dancesstepsmap' VALUES (22613, 17955, 5);
INSERT INTO 'dancesstepsmap' VALUES (22614, 17955, 2);
INSERT INTO 'dancesstepsmap' VALUES (22615, 17955, 1);
INSERT INTO 'dancesstepsmap' VALUES (22619, 17957, 1);
INSERT INTO 'dancesstepsmap' VALUES (22620, 17957, 2);
INSERT INTO 'dancesstepsmap' VALUES (22621, 17958, 4);
INSERT INTO 'dancesstepsmap' VALUES (22622, 17958, 5);
INSERT INTO 'dancesstepsmap' VALUES (22623, 17958, 1);
INSERT INTO 'dancesstepsmap' VALUES (22624, 17958, 2);
INSERT INTO 'dancesstepsmap' VALUES (22625, 17958, 3);
INSERT INTO 'dancesstepsmap' VALUES (22626, 17959, 1);
INSERT INTO 'dancesstepsmap' VALUES (22627, 17959, 3);
INSERT INTO 'dancesstepsmap' VALUES (22628, 17960, 4);
INSERT INTO 'dancesstepsmap' VALUES (22629, 17960, 5);
INSERT INTO 'dancesstepsmap' VALUES (22630, 17961, 4);
INSERT INTO 'dancesstepsmap' VALUES (22631, 17961, 5);
INSERT INTO 'dancesstepsmap' VALUES (22632, 17961, 1);
INSERT INTO 'dancesstepsmap' VALUES (22633, 17961, 2);
INSERT INTO 'dancesstepsmap' VALUES (22634, 4355, 5);
INSERT INTO 'dancesstepsmap' VALUES (22635, 17962, 1);
INSERT INTO 'dancesstepsmap' VALUES (22636, 17962, 3);
INSERT INTO 'dancesstepsmap' VALUES (22637, 17978, 2);
INSERT INTO 'dancesstepsmap' VALUES (22638, 17978, 1);
INSERT INTO 'dancesstepsmap' VALUES (22639, 4555, 5);
INSERT INTO 'dancesstepsmap' VALUES (22640, 17991, 4);
INSERT INTO 'dancesstepsmap' VALUES (22641, 17991, 5);
INSERT INTO 'dancesstepsmap' VALUES (22493, 17889, 1);
INSERT INTO 'dancesstepsmap' VALUES (22494, 17889, 2);
INSERT INTO 'dancesstepsmap' VALUES (22642, 10982, 5);
INSERT INTO 'dancesstepsmap' VALUES (22643, 10982, 4);
INSERT INTO 'dancesstepsmap' VALUES (22644, 17980, 2);
INSERT INTO 'dancesstepsmap' VALUES (22645, 17980, 1);
INSERT INTO 'dancesstepsmap' VALUES (22646, 17980, 3);
INSERT INTO 'dancesstepsmap' VALUES (22647, 10082, 5);
INSERT INTO 'dancesstepsmap' VALUES (22648, 17992, 1);
INSERT INTO 'dancesstepsmap' VALUES (22649, 17992, 3);
INSERT INTO 'dancesstepsmap' VALUES (22650, 17992, 2);
INSERT INTO 'dancesstepsmap' VALUES (22651, 17993, 2);
INSERT INTO 'dancesstepsmap' VALUES (22652, 17993, 1);
INSERT INTO 'dancesstepsmap' VALUES (22653, 17993, 3);
INSERT INTO 'dancesstepsmap' VALUES (22654, 17941, 1);
INSERT INTO 'dancesstepsmap' VALUES (22655, 17941, 2);
INSERT INTO 'dancesstepsmap' VALUES (22662, 17997, 4);
INSERT INTO 'dancesstepsmap' VALUES (22663, 17997, 5);
INSERT INTO 'dancesstepsmap' VALUES (22664, 17943, 4);
INSERT INTO 'dancesstepsmap' VALUES (22665, 17943, 5);
INSERT INTO 'dancesstepsmap' VALUES (22666, 17944, 2);
INSERT INTO 'dancesstepsmap' VALUES (22667, 17944, 1);
INSERT INTO 'dancesstepsmap' VALUES (22668, 17946, 4);
INSERT INTO 'dancesstepsmap' VALUES (22669, 17946, 6);
INSERT INTO 'dancesstepsmap' VALUES (22670, 17947, 2);
INSERT INTO 'dancesstepsmap' VALUES (22671, 17947, 1);
INSERT INTO 'dancesstepsmap' VALUES (22672, 17947, 3);
INSERT INTO 'dancesstepsmap' VALUES (22673, 16775, 3);
INSERT INTO 'dancesstepsmap' VALUES (22674, 16775, 1);
INSERT INTO 'dancesstepsmap' VALUES (22675, 17999, 1);
INSERT INTO 'dancesstepsmap' VALUES (22676, 17999, 2);
INSERT INTO 'dancesstepsmap' VALUES (22677, 18000, 1);
INSERT INTO 'dancesstepsmap' VALUES (22678, 18000, 2);
INSERT INTO 'dancesstepsmap' VALUES (22679, 18000, 3);
INSERT INTO 'dancesstepsmap' VALUES (22680, 18001, 5);
INSERT INTO 'dancesstepsmap' VALUES (22681, 18001, 4);
INSERT INTO 'dancesstepsmap' VALUES (22682, 18002, 5);
INSERT INTO 'dancesstepsmap' VALUES (22683, 18002, 4);
INSERT INTO 'dancesstepsmap' VALUES (22684, 18003, 1);
INSERT INTO 'dancesstepsmap' VALUES (22685, 18003, 2);
INSERT INTO 'dancesstepsmap' VALUES (22686, 18004, 2);
INSERT INTO 'dancesstepsmap' VALUES (22687, 18004, 1);
INSERT INTO 'dancesstepsmap' VALUES (22688, 18004, 3);
INSERT INTO 'dancesstepsmap' VALUES (22689, 18005, 5);
INSERT INTO 'dancesstepsmap' VALUES (22690, 18005, 4);
INSERT INTO 'dancesstepsmap' VALUES (22691, 18006, 3);
INSERT INTO 'dancesstepsmap' VALUES (22692, 18006, 10);
INSERT INTO 'dancesstepsmap' VALUES (22693, 18006, 1);
INSERT INTO 'dancesstepsmap' VALUES (22694, 18006, 2);
INSERT INTO 'dancesstepsmap' VALUES (22695, 18007, 1);
INSERT INTO 'dancesstepsmap' VALUES (22696, 18008, 2);
INSERT INTO 'dancesstepsmap' VALUES (22697, 18008, 1);
INSERT INTO 'dancesstepsmap' VALUES (22698, 18009, 1);
INSERT INTO 'dancesstepsmap' VALUES (22699, 18009, 2);
INSERT INTO 'dancesstepsmap' VALUES (22700, 18010, 1);
INSERT INTO 'dancesstepsmap' VALUES (22701, 18011, 1);
INSERT INTO 'dancesstepsmap' VALUES (22702, 18012, 5);
INSERT INTO 'dancesstepsmap' VALUES (22703, 18012, 4);
INSERT INTO 'dancesstepsmap' VALUES (22704, 18013, 4);
INSERT INTO 'dancesstepsmap' VALUES (22705, 18013, 5);
INSERT INTO 'dancesstepsmap' VALUES (22706, 18014, 1);
INSERT INTO 'dancesstepsmap' VALUES (22707, 18014, 3);
INSERT INTO 'dancesstepsmap' VALUES (22708, 18015, 1);
INSERT INTO 'dancesstepsmap' VALUES (22709, 18015, 2);
INSERT INTO 'dancesstepsmap' VALUES (22710, 18016, 2);
INSERT INTO 'dancesstepsmap' VALUES (22711, 18016, 1);
INSERT INTO 'dancesstepsmap' VALUES (22712, 18017, 2);
INSERT INTO 'dancesstepsmap' VALUES (22713, 18017, 1);
INSERT INTO 'dancesstepsmap' VALUES (22714, 18017, 3);
INSERT INTO 'dancesstepsmap' VALUES (22717, 18019, 2);
INSERT INTO 'dancesstepsmap' VALUES (22718, 18019, 1);
INSERT INTO 'dancesstepsmap' VALUES (22719, 18022, 1);
INSERT INTO 'dancesstepsmap' VALUES (22720, 18022, 2);
INSERT INTO 'dancesstepsmap' VALUES (22721, 18023, 1);
INSERT INTO 'dancesstepsmap' VALUES (22722, 18023, 2);
INSERT INTO 'dancesstepsmap' VALUES (22723, 18034, 3);
INSERT INTO 'dancesstepsmap' VALUES (22724, 18034, 1);
INSERT INTO 'dancesstepsmap' VALUES (22725, 3943, 2);
INSERT INTO 'dancesstepsmap' VALUES (22726, 18035, 5);
INSERT INTO 'dancesstepsmap' VALUES (22727, 18035, 4);
INSERT INTO 'dancesstepsmap' VALUES (22728, 1125, 3);
INSERT INTO 'dancesstepsmap' VALUES (22729, 16955, 2);
INSERT INTO 'dancesstepsmap' VALUES (22730, 16955, 1);
INSERT INTO 'dancesstepsmap' VALUES (22731, 18036, 5);
INSERT INTO 'dancesstepsmap' VALUES (22732, 18036, 4);
INSERT INTO 'dancesstepsmap' VALUES (22733, 16956, 2);
INSERT INTO 'dancesstepsmap' VALUES (22734, 16956, 1);
INSERT INTO 'dancesstepsmap' VALUES (22735, 16956, 3);
INSERT INTO 'dancesstepsmap' VALUES (22736, 16957, 5);
INSERT INTO 'dancesstepsmap' VALUES (22737, 16957, 4);
INSERT INTO 'dancesstepsmap' VALUES (22738, 16958, 5);
INSERT INTO 'dancesstepsmap' VALUES (22739, 16958, 4);
INSERT INTO 'dancesstepsmap' VALUES (22740, 18037, 3);
INSERT INTO 'dancesstepsmap' VALUES (22741, 18037, 1);
INSERT INTO 'dancesstepsmap' VALUES (22742, 18038, 1);
INSERT INTO 'dancesstepsmap' VALUES (22743, 18038, 2);
INSERT INTO 'dancesstepsmap' VALUES (22746, 18039, 2);
INSERT INTO 'dancesstepsmap' VALUES (22747, 18039, 1);
INSERT INTO 'dancesstepsmap' VALUES (22748, 18039, 3);
INSERT INTO 'dancesstepsmap' VALUES (22749, 9558, 1);
INSERT INTO 'dancesstepsmap' VALUES (22750, 17785, 2);
INSERT INTO 'dancesstepsmap' VALUES (22751, 17785, 1);
INSERT INTO 'dancesstepsmap' VALUES (22752, 3766, 5);
INSERT INTO 'dancesstepsmap' VALUES (22753, 18044, 1);
INSERT INTO 'dancesstepsmap' VALUES (22754, 18044, 2);
INSERT INTO 'dancesstepsmap' VALUES (22755, 18046, 5);
INSERT INTO 'dancesstepsmap' VALUES (22756, 18046, 4);
INSERT INTO 'dancesstepsmap' VALUES (22757, 18053, 1);
INSERT INTO 'dancesstepsmap' VALUES (22758, 18053, 2);
INSERT INTO 'dancesstepsmap' VALUES (22759, 18053, 3);
INSERT INTO 'dancesstepsmap' VALUES (22760, 3448, 5);
INSERT INTO 'dancesstepsmap' VALUES (22761, 6539, 5);
INSERT INTO 'dancesstepsmap' VALUES (22762, 18054, 4);
INSERT INTO 'dancesstepsmap' VALUES (22763, 18054, 5);
INSERT INTO 'dancesstepsmap' VALUES (22764, 18055, 4);
INSERT INTO 'dancesstepsmap' VALUES (22765, 18055, 5);
INSERT INTO 'dancesstepsmap' VALUES (22766, 18056, 1);
INSERT INTO 'dancesstepsmap' VALUES (22767, 18056, 2);
INSERT INTO 'dancesstepsmap' VALUES (22768, 18057, 1);
INSERT INTO 'dancesstepsmap' VALUES (22769, 18059, 2);
INSERT INTO 'dancesstepsmap' VALUES (22770, 18059, 1);
INSERT INTO 'dancesstepsmap' VALUES (22771, 18060, 1);
INSERT INTO 'dancesstepsmap' VALUES (22772, 18060, 2);
INSERT INTO 'dancesstepsmap' VALUES (22773, 18061, 1);
INSERT INTO 'dancesstepsmap' VALUES (22774, 18062, 1);
INSERT INTO 'dancesstepsmap' VALUES (22775, 18062, 99);
INSERT INTO 'dancesstepsmap' VALUES (22776, 18062, 2);
INSERT INTO 'dancesstepsmap' VALUES (22777, 18063, 1);
INSERT INTO 'dancesstepsmap' VALUES (22778, 18063, 3);
INSERT INTO 'dancesstepsmap' VALUES (22779, 18064, 1);
INSERT INTO 'dancesstepsmap' VALUES (22780, 18064, 2);
INSERT INTO 'dancesstepsmap' VALUES (22781, 18065, 1);
INSERT INTO 'dancesstepsmap' VALUES (22782, 18065, 2);
INSERT INTO 'dancesstepsmap' VALUES (22784, 18067, 1);
INSERT INTO 'dancesstepsmap' VALUES (22785, 18068, 1);
INSERT INTO 'dancesstepsmap' VALUES (22786, 18068, 2);
INSERT INTO 'dancesstepsmap' VALUES (22601, 17951, 2);
INSERT INTO 'dancesstepsmap' VALUES (22602, 17951, 1);
INSERT INTO 'dancesstepsmap' VALUES (22789, 18070, 4);
INSERT INTO 'dancesstepsmap' VALUES (22790, 18072, 5);
INSERT INTO 'dancesstepsmap' VALUES (22791, 18072, 4);
INSERT INTO 'dancesstepsmap' VALUES (22792, 18073, 1);
INSERT INTO 'dancesstepsmap' VALUES (22793, 18073, 2);
INSERT INTO 'dancesstepsmap' VALUES (22794, 2499, 5);
INSERT INTO 'dancesstepsmap' VALUES (22795, 18074, 1);
INSERT INTO 'dancesstepsmap' VALUES (22796, 18074, 2);
INSERT INTO 'dancesstepsmap' VALUES (22797, 17905, 5);
INSERT INTO 'dancesstepsmap' VALUES (22798, 18075, 2);
INSERT INTO 'dancesstepsmap' VALUES (22799, 18075, 1);
INSERT INTO 'dancesstepsmap' VALUES (22800, 18079, 2);
INSERT INTO 'dancesstepsmap' VALUES (22801, 18079, 1);
INSERT INTO 'dancesstepsmap' VALUES (22802, 18081, 4);
INSERT INTO 'dancesstepsmap' VALUES (22803, 18081, 5);
INSERT INTO 'dancesstepsmap' VALUES (22804, 3017, 2);
INSERT INTO 'dancesstepsmap' VALUES (22805, 18078, 1);
INSERT INTO 'dancesstepsmap' VALUES (22806, 18078, 2);
INSERT INTO 'dancesstepsmap' VALUES (22807, 18078, 3);
INSERT INTO 'dancesstepsmap' VALUES (22808, 18077, 4);
INSERT INTO 'dancesstepsmap' VALUES (22809, 18077, 5);
INSERT INTO 'dancesstepsmap' VALUES (22810, 18082, 1);
INSERT INTO 'dancesstepsmap' VALUES (22811, 18082, 2);
INSERT INTO 'dancesstepsmap' VALUES (22814, 18084, 2);
INSERT INTO 'dancesstepsmap' VALUES (22815, 18084, 1);
INSERT INTO 'dancesstepsmap' VALUES (22816, 18085, 4);
INSERT INTO 'dancesstepsmap' VALUES (22817, 18085, 5);
INSERT INTO 'dancesstepsmap' VALUES (22818, 18086, 5);
INSERT INTO 'dancesstepsmap' VALUES (22819, 18086, 4);
INSERT INTO 'dancesstepsmap' VALUES (22820, 18087, 5);
INSERT INTO 'dancesstepsmap' VALUES (22821, 18087, 4);
INSERT INTO 'dancesstepsmap' VALUES (22822, 18088, 5);
INSERT INTO 'dancesstepsmap' VALUES (22823, 18088, 4);
INSERT INTO 'dancesstepsmap' VALUES (22824, 18088, 6);
INSERT INTO 'dancesstepsmap' VALUES (22825, 18089, 4);
INSERT INTO 'dancesstepsmap' VALUES (22826, 18089, 5);
INSERT INTO 'dancesstepsmap' VALUES (22827, 9126, 2);
INSERT INTO 'dancesstepsmap' VALUES (22828, 6382, 5);
INSERT INTO 'dancesstepsmap' VALUES (22829, 3690, 5);
INSERT INTO 'dancesstepsmap' VALUES (22830, 18091, 2);
INSERT INTO 'dancesstepsmap' VALUES (22831, 18091, 1);
INSERT INTO 'dancesstepsmap' VALUES (22832, 18091, 3);
INSERT INTO 'dancesstepsmap' VALUES (22833, 18092, 4);
INSERT INTO 'dancesstepsmap' VALUES (22834, 18092, 5);
INSERT INTO 'dancesstepsmap' VALUES (22835, 18093, 2);
INSERT INTO 'dancesstepsmap' VALUES (22836, 18093, 1);
INSERT INTO 'dancesstepsmap' VALUES (22837, 18094, 2);
INSERT INTO 'dancesstepsmap' VALUES (22838, 18094, 1);
INSERT INTO 'dancesstepsmap' VALUES (22839, 18094, 8);
INSERT INTO 'dancesstepsmap' VALUES (22840, 18095, 5);
INSERT INTO 'dancesstepsmap' VALUES (22841, 18095, 4);
INSERT INTO 'dancesstepsmap' VALUES (22842, 15587, 1);
INSERT INTO 'dancesstepsmap' VALUES (22843, 15587, 2);
INSERT INTO 'dancesstepsmap' VALUES (22844, 18096, 1);
INSERT INTO 'dancesstepsmap' VALUES (22845, 18096, 2);
INSERT INTO 'dancesstepsmap' VALUES (22846, 18097, 4);
INSERT INTO 'dancesstepsmap' VALUES (22847, 18097, 5);
INSERT INTO 'dancesstepsmap' VALUES (22848, 18098, 5);
INSERT INTO 'dancesstepsmap' VALUES (22849, 18098, 4);
INSERT INTO 'dancesstepsmap' VALUES (22850, 18099, 1);
INSERT INTO 'dancesstepsmap' VALUES (22851, 18099, 2);
INSERT INTO 'dancesstepsmap' VALUES (22852, 18100, 4);
INSERT INTO 'dancesstepsmap' VALUES (22853, 18100, 5);
INSERT INTO 'dancesstepsmap' VALUES (22854, 18101, 2);
INSERT INTO 'dancesstepsmap' VALUES (22855, 18101, 1);
INSERT INTO 'dancesstepsmap' VALUES (22856, 15122, 1);
INSERT INTO 'dancesstepsmap' VALUES (22857, 15122, 2);
INSERT INTO 'dancesstepsmap' VALUES (22858, 15122, 3);
INSERT INTO 'dancesstepsmap' VALUES (22859, 15121, 1);
INSERT INTO 'dancesstepsmap' VALUES (22860, 15118, 1);
INSERT INTO 'dancesstepsmap' VALUES (22861, 15118, 2);
INSERT INTO 'dancesstepsmap' VALUES (22862, 15116, 2);
INSERT INTO 'dancesstepsmap' VALUES (22863, 15116, 1);
INSERT INTO 'dancesstepsmap' VALUES (22864, 15114, 1);
INSERT INTO 'dancesstepsmap' VALUES (22865, 15114, 2);
INSERT INTO 'dancesstepsmap' VALUES (22866, 15114, 3);
INSERT INTO 'dancesstepsmap' VALUES (22867, 15110, 2);
INSERT INTO 'dancesstepsmap' VALUES (22868, 15110, 1);
INSERT INTO 'dancesstepsmap' VALUES (22869, 15113, 4);
INSERT INTO 'dancesstepsmap' VALUES (22870, 15113, 5);
INSERT INTO 'dancesstepsmap' VALUES (22871, 15109, 1);
INSERT INTO 'dancesstepsmap' VALUES (22872, 15109, 2);
INSERT INTO 'dancesstepsmap' VALUES (22873, 15104, 5);
INSERT INTO 'dancesstepsmap' VALUES (22874, 15104, 4);
INSERT INTO 'dancesstepsmap' VALUES (22875, 2506, 2);
INSERT INTO 'dancesstepsmap' VALUES (22876, 17747, 1);
INSERT INTO 'dancesstepsmap' VALUES (22877, 17746, 5);
INSERT INTO 'dancesstepsmap' VALUES (22878, 17746, 4);
INSERT INTO 'dancesstepsmap' VALUES (22879, 17745, 4);
INSERT INTO 'dancesstepsmap' VALUES (22880, 17745, 5);
INSERT INTO 'dancesstepsmap' VALUES (22881, 17748, 2);
INSERT INTO 'dancesstepsmap' VALUES (22882, 17748, 1);
INSERT INTO 'dancesstepsmap' VALUES (22883, 15108, 4);
INSERT INTO 'dancesstepsmap' VALUES (22884, 11037, 5);
INSERT INTO 'dancesstepsmap' VALUES (22885, 11031, 4);
INSERT INTO 'dancesstepsmap' VALUES (22886, 11031, 1);
INSERT INTO 'dancesstepsmap' VALUES (22887, 18102, 1);
INSERT INTO 'dancesstepsmap' VALUES (22888, 18102, 2);
INSERT INTO 'dancesstepsmap' VALUES (22889, 17465, 2);
INSERT INTO 'dancesstepsmap' VALUES (22890, 17465, 1);
INSERT INTO 'dancesstepsmap' VALUES (22891, 17465, 3);
INSERT INTO 'dancesstepsmap' VALUES (22892, 11050, 5);
INSERT INTO 'dancesstepsmap' VALUES (22893, 18103, 5);
INSERT INTO 'dancesstepsmap' VALUES (22894, 18103, 4);
INSERT INTO 'dancesstepsmap' VALUES (22895, 18104, 2);
INSERT INTO 'dancesstepsmap' VALUES (22896, 18104, 1);
INSERT INTO 'dancesstepsmap' VALUES (22897, 18105, 3);
INSERT INTO 'dancesstepsmap' VALUES (22898, 18105, 1);
INSERT INTO 'dancesstepsmap' VALUES (22899, 18106, 2);
INSERT INTO 'dancesstepsmap' VALUES (22900, 18106, 1);
INSERT INTO 'dancesstepsmap' VALUES (22901, 18106, 3);
INSERT INTO 'dancesstepsmap' VALUES (22902, 18107, 1);
INSERT INTO 'dancesstepsmap' VALUES (22903, 18107, 3);
INSERT INTO 'dancesstepsmap' VALUES (22904, 18108, 3);
INSERT INTO 'dancesstepsmap' VALUES (22905, 18108, 1);
INSERT INTO 'dancesstepsmap' VALUES (22906, 11042, 2);
INSERT INTO 'dancesstepsmap' VALUES (22907, 18109, 1);
INSERT INTO 'dancesstepsmap' VALUES (22908, 18109, 2);
INSERT INTO 'dancesstepsmap' VALUES (22909, 18110, 1);
INSERT INTO 'dancesstepsmap' VALUES (22910, 18111, 2);
INSERT INTO 'dancesstepsmap' VALUES (22911, 18111, 1);
INSERT INTO 'dancesstepsmap' VALUES (22912, 18112, 1);
INSERT INTO 'dancesstepsmap' VALUES (22913, 18112, 2);
INSERT INTO 'dancesstepsmap' VALUES (22914, 18114, 5);
INSERT INTO 'dancesstepsmap' VALUES (22915, 18114, 4);
INSERT INTO 'dancesstepsmap' VALUES (22916, 18115, 1);
INSERT INTO 'dancesstepsmap' VALUES (22917, 18115, 3);
INSERT INTO 'dancesstepsmap' VALUES (22918, 18116, 1);
INSERT INTO 'dancesstepsmap' VALUES (22919, 18116, 2);
INSERT INTO 'dancesstepsmap' VALUES (22920, 18117, 5);
INSERT INTO 'dancesstepsmap' VALUES (22921, 18117, 4);
INSERT INTO 'dancesstepsmap' VALUES (22922, 13573, 3);
INSERT INTO 'dancesstepsmap' VALUES (22923, 13573, 1);
INSERT INTO 'dancesstepsmap' VALUES (22924, 18118, 5);
INSERT INTO 'dancesstepsmap' VALUES (22925, 18118, 4);
INSERT INTO 'dancesstepsmap' VALUES (22926, 18119, 1);
INSERT INTO 'dancesstepsmap' VALUES (22927, 18119, 3);
INSERT INTO 'dancesstepsmap' VALUES (22928, 18119, 2);
INSERT INTO 'dancesstepsmap' VALUES (22929, 18120, 5);
INSERT INTO 'dancesstepsmap' VALUES (22930, 18120, 4);
INSERT INTO 'dancesstepsmap' VALUES (22931, 18047, 1);
INSERT INTO 'dancesstepsmap' VALUES (22932, 18049, 1);
INSERT INTO 'dancesstepsmap' VALUES (22933, 18049, 3);
INSERT INTO 'dancesstepsmap' VALUES (22934, 17768, 1);
INSERT INTO 'dancesstepsmap' VALUES (22935, 18121, 5);
INSERT INTO 'dancesstepsmap' VALUES (22936, 18121, 4);
INSERT INTO 'dancesstepsmap' VALUES (22937, 17885, 1);
INSERT INTO 'dancesstepsmap' VALUES (22938, 17885, 3);
INSERT INTO 'dancesstepsmap' VALUES (22939, 18122, 2);
INSERT INTO 'dancesstepsmap' VALUES (22940, 18122, 1);
INSERT INTO 'dancesstepsmap' VALUES (22941, 18122, 3);
INSERT INTO 'dancesstepsmap' VALUES (22942, 18123, 5);
INSERT INTO 'dancesstepsmap' VALUES (22943, 18123, 4);
INSERT INTO 'dancesstepsmap' VALUES (22944, 11030, 1);
INSERT INTO 'dancesstepsmap' VALUES (22945, 11036, 5);
INSERT INTO 'dancesstepsmap' VALUES (22946, 17789, 2);
INSERT INTO 'dancesstepsmap' VALUES (22947, 17789, 3);
INSERT INTO 'dancesstepsmap' VALUES (22948, 17789, 8);
INSERT INTO 'dancesstepsmap' VALUES (22949, 11039, 5);
INSERT INTO 'dancesstepsmap' VALUES (22950, 18129, 5);
INSERT INTO 'dancesstepsmap' VALUES (22951, 18129, 4);
INSERT INTO 'dancesstepsmap' VALUES (22952, 18130, 2);
INSERT INTO 'dancesstepsmap' VALUES (22953, 18130, 1);
INSERT INTO 'dancesstepsmap' VALUES (22954, 18131, 1);
INSERT INTO 'dancesstepsmap' VALUES (22955, 18132, 3);
INSERT INTO 'dancesstepsmap' VALUES (22956, 18132, 1);
INSERT INTO 'dancesstepsmap' VALUES (22957, 18132, 2);
INSERT INTO 'dancesstepsmap' VALUES (22958, 18137, 1);
INSERT INTO 'dancesstepsmap' VALUES (22959, 18139, 4);
INSERT INTO 'dancesstepsmap' VALUES (22960, 18140, 1);
INSERT INTO 'dancesstepsmap' VALUES (22961, 18140, 2);
INSERT INTO 'dancesstepsmap' VALUES (22962, 18141, 5);
INSERT INTO 'dancesstepsmap' VALUES (22963, 18141, 4);
INSERT INTO 'dancesstepsmap' VALUES (22964, 18143, 1);
INSERT INTO 'dancesstepsmap' VALUES (22965, 18143, 2);
INSERT INTO 'dancesstepsmap' VALUES (22966, 18142, 2);
INSERT INTO 'dancesstepsmap' VALUES (22967, 18142, 1);
INSERT INTO 'dancesstepsmap' VALUES (22968, 18142, 3);
INSERT INTO 'dancesstepsmap' VALUES (22969, 18144, 2);
INSERT INTO 'dancesstepsmap' VALUES (22970, 18144, 1);
INSERT INTO 'dancesstepsmap' VALUES (22971, 18144, 3);
INSERT INTO 'dancesstepsmap' VALUES (22972, 18145, 1);
INSERT INTO 'dancesstepsmap' VALUES (22973, 7145, 5);
INSERT INTO 'dancesstepsmap' VALUES (22974, 18183, 2);
INSERT INTO 'dancesstepsmap' VALUES (22975, 18183, 1);
INSERT INTO 'dancesstepsmap' VALUES (22976, 18184, 1);
INSERT INTO 'dancesstepsmap' VALUES (22977, 17405, 4);
INSERT INTO 'dancesstepsmap' VALUES (22978, 17405, 5);
INSERT INTO 'dancesstepsmap' VALUES (22979, 824, 5);
INSERT INTO 'dancesstepsmap' VALUES (22980, 14894, 2);
INSERT INTO 'dancesstepsmap' VALUES (22981, 14894, 1);
INSERT INTO 'dancesstepsmap' VALUES (22982, 2894, 2);
INSERT INTO 'dancesstepsmap' VALUES (22983, 14895, 5);
INSERT INTO 'dancesstepsmap' VALUES (22984, 14895, 4);
INSERT INTO 'dancesstepsmap' VALUES (22985, 14897, 4);
INSERT INTO 'dancesstepsmap' VALUES (22986, 14898, 2);
INSERT INTO 'dancesstepsmap' VALUES (22987, 14898, 1);
INSERT INTO 'dancesstepsmap' VALUES (22988, 14908, 5);
INSERT INTO 'dancesstepsmap' VALUES (22989, 14908, 4);
INSERT INTO 'dancesstepsmap' VALUES (22990, 14907, 2);
INSERT INTO 'dancesstepsmap' VALUES (22991, 14907, 1);
INSERT INTO 'dancesstepsmap' VALUES (22992, 14906, 5);
INSERT INTO 'dancesstepsmap' VALUES (22993, 14906, 4);
INSERT INTO 'dancesstepsmap' VALUES (22994, 14900, 4);
INSERT INTO 'dancesstepsmap' VALUES (22995, 17757, 5);
INSERT INTO 'dancesstepsmap' VALUES (22996, 17757, 4);
INSERT INTO 'dancesstepsmap' VALUES (22997, 18203, 4);
INSERT INTO 'dancesstepsmap' VALUES (22998, 12186, 2);
INSERT INTO 'dancesstepsmap' VALUES (22999, 12186, 1);
INSERT INTO 'dancesstepsmap' VALUES (23000, 12186, 3);
INSERT INTO 'dancesstepsmap' VALUES (23001, 15453, 5);
INSERT INTO 'dancesstepsmap' VALUES (23002, 15453, 4);
INSERT INTO 'dancesstepsmap' VALUES (23003, 15454, 1);
INSERT INTO 'dancesstepsmap' VALUES (23004, 15454, 2);
INSERT INTO 'dancesstepsmap' VALUES (23005, 15454, 3);
INSERT INTO 'dancesstepsmap' VALUES (23006, 1404, 5);
INSERT INTO 'dancesstepsmap' VALUES (23007, 15445, 4);
INSERT INTO 'dancesstepsmap' VALUES (23008, 15445, 5);
INSERT INTO 'dancesstepsmap' VALUES (23009, 15445, 1);
INSERT INTO 'dancesstepsmap' VALUES (23010, 15445, 2);
INSERT INTO 'dancesstepsmap' VALUES (23011, 17569, 1);
INSERT INTO 'dancesstepsmap' VALUES (23012, 17569, 2);
INSERT INTO 'dancesstepsmap' VALUES (23013, 15446, 1);
INSERT INTO 'dancesstepsmap' VALUES (23014, 15446, 2);
INSERT INTO 'dancesstepsmap' VALUES (23015, 18204, 1);
INSERT INTO 'dancesstepsmap' VALUES (23016, 18204, 2);
INSERT INTO 'dancesstepsmap' VALUES (23017, 18206, 1);
INSERT INTO 'dancesstepsmap' VALUES (23018, 18206, 2);
INSERT INTO 'dancesstepsmap' VALUES (23019, 18207, 5);
INSERT INTO 'dancesstepsmap' VALUES (23020, 18207, 4);
INSERT INTO 'dancesstepsmap' VALUES (23021, 18208, 1);
INSERT INTO 'dancesstepsmap' VALUES (23022, 1229, 2);
INSERT INTO 'dancesstepsmap' VALUES (23023, 17100, 2);
INSERT INTO 'dancesstepsmap' VALUES (23025, 17100, 3);
INSERT INTO 'dancesstepsmap' VALUES (23026, 18225, 4);
INSERT INTO 'dancesstepsmap' VALUES (23027, 18225, 5);
INSERT INTO 'dancesstepsmap' VALUES (23028, 18226, 5);
INSERT INTO 'dancesstepsmap' VALUES (23029, 18226, 4);
INSERT INTO 'dancesstepsmap' VALUES (23030, 18226, 2);
INSERT INTO 'dancesstepsmap' VALUES (23031, 18226, 1);
INSERT INTO 'dancesstepsmap' VALUES (23032, 18226, 3);
INSERT INTO 'dancesstepsmap' VALUES (23035, 18227, 1);
INSERT INTO 'dancesstepsmap' VALUES (23036, 18227, 2);
INSERT INTO 'dancesstepsmap' VALUES (23037, 1015, 2);
INSERT INTO 'dancesstepsmap' VALUES (23038, 18228, 1);
INSERT INTO 'dancesstepsmap' VALUES (23039, 18228, 3);
INSERT INTO 'dancesstepsmap' VALUES (23040, 18228, 2);
INSERT INTO 'dancesstepsmap' VALUES (23041, 18229, 3);
INSERT INTO 'dancesstepsmap' VALUES (23042, 18229, 2);
INSERT INTO 'dancesstepsmap' VALUES (23043, 7055, 2);
INSERT INTO 'dancesstepsmap' VALUES (23044, 6817, 2);
INSERT INTO 'dancesstepsmap' VALUES (23045, 6720, 2);
INSERT INTO 'dancesstepsmap' VALUES (23046, 18230, 1);
INSERT INTO 'dancesstepsmap' VALUES (23047, 18230, 2);
INSERT INTO 'dancesstepsmap' VALUES (23048, 18231, 2);
INSERT INTO 'dancesstepsmap' VALUES (23049, 18231, 1);
INSERT INTO 'dancesstepsmap' VALUES (23050, 18231, 3);
INSERT INTO 'dancesstepsmap' VALUES (23051, 18232, 5);
INSERT INTO 'dancesstepsmap' VALUES (23052, 18232, 4);
INSERT INTO 'dancesstepsmap' VALUES (23053, 18233, 1);
INSERT INTO 'dancesstepsmap' VALUES (23054, 18234, 2);
INSERT INTO 'dancesstepsmap' VALUES (23055, 18234, 1);
INSERT INTO 'dancesstepsmap' VALUES (23056, 18235, 1);
INSERT INTO 'dancesstepsmap' VALUES (23057, 18235, 2);
INSERT INTO 'dancesstepsmap' VALUES (23058, 18219, 3);
INSERT INTO 'dancesstepsmap' VALUES (23059, 18219, 1);
INSERT INTO 'dancesstepsmap' VALUES (23060, 18219, 2);
INSERT INTO 'dancesstepsmap' VALUES (23061, 16898, 3);
INSERT INTO 'dancesstepsmap' VALUES (23062, 18236, 1);
INSERT INTO 'dancesstepsmap' VALUES (23063, 18236, 2);
INSERT INTO 'dancesstepsmap' VALUES (23064, 14446, 2);
INSERT INTO 'dancesstepsmap' VALUES (23065, 14446, 1);
INSERT INTO 'dancesstepsmap' VALUES (23066, 16680, 2);
INSERT INTO 'dancesstepsmap' VALUES (23067, 18238, 1);
INSERT INTO 'dancesstepsmap' VALUES (23068, 18238, 3);
INSERT INTO 'dancesstepsmap' VALUES (23069, 18238, 2);
INSERT INTO 'dancesstepsmap' VALUES (23070, 18239, 5);
INSERT INTO 'dancesstepsmap' VALUES (23071, 18239, 4);
INSERT INTO 'dancesstepsmap' VALUES (23072, 18240, 1);
INSERT INTO 'dancesstepsmap' VALUES (23073, 18240, 2);
INSERT INTO 'dancesstepsmap' VALUES (23074, 18241, 2);
INSERT INTO 'dancesstepsmap' VALUES (23075, 18241, 1);
INSERT INTO 'dancesstepsmap' VALUES (23076, 17467, 2);
INSERT INTO 'dancesstepsmap' VALUES (23077, 17467, 1);
INSERT INTO 'dancesstepsmap' VALUES (23078, 3894, 5);
INSERT INTO 'dancesstepsmap' VALUES (23079, 2826, 2);
INSERT INTO 'dancesstepsmap' VALUES (23080, 3101, 2);
INSERT INTO 'dancesstepsmap' VALUES (23081, 6017, 2);
INSERT INTO 'dancesstepsmap' VALUES (23082, 5674, 2);
INSERT INTO 'dancesstepsmap' VALUES (23083, 2305, 2);
INSERT INTO 'dancesstepsmap' VALUES (23084, 1447, 5);
INSERT INTO 'dancesstepsmap' VALUES (23085, 2232, 2);
INSERT INTO 'dancesstepsmap' VALUES (23086, 2671, 5);
INSERT INTO 'dancesstepsmap' VALUES (23087, 2552, 2);
INSERT INTO 'dancesstepsmap' VALUES (23088, 2300, 5);
INSERT INTO 'dancesstepsmap' VALUES (23089, 2300, 6);
INSERT INTO 'dancesstepsmap' VALUES (23092, 17470, 2);
INSERT INTO 'dancesstepsmap' VALUES (23093, 17470, 1);
INSERT INTO 'dancesstepsmap' VALUES (23095, 17473, 2);
INSERT INTO 'dancesstepsmap' VALUES (23096, 17473, 1);
INSERT INTO 'dancesstepsmap' VALUES (23097, 453, 2);
INSERT INTO 'dancesstepsmap' VALUES (23098, 2849, 2);
INSERT INTO 'dancesstepsmap' VALUES (23099, 1195, 2);
INSERT INTO 'dancesstepsmap' VALUES (23100, 6030, 2);
INSERT INTO 'dancesstepsmap' VALUES (23101, 784, 2);
INSERT INTO 'dancesstepsmap' VALUES (23103, 3196, 3);
INSERT INTO 'dancesstepsmap' VALUES (23104, 4033, 5);
INSERT INTO 'dancesstepsmap' VALUES (23105, 3465, 2);
INSERT INTO 'dancesstepsmap' VALUES (23106, 4475, 2);
INSERT INTO 'dancesstepsmap' VALUES (23107, 6360, 2);
INSERT INTO 'dancesstepsmap' VALUES (23108, 371, 2);
INSERT INTO 'dancesstepsmap' VALUES (23109, 3968, 2);
INSERT INTO 'dancesstepsmap' VALUES (23110, 3521, 5);
INSERT INTO 'dancesstepsmap' VALUES (23111, 2544, 5);
INSERT INTO 'dancesstepsmap' VALUES (23112, 2485, 2);
INSERT INTO 'dancesstepsmap' VALUES (23113, 3653, 5);
INSERT INTO 'dancesstepsmap' VALUES (23114, 17468, 2);
INSERT INTO 'dancesstepsmap' VALUES (23115, 17468, 1);
INSERT INTO 'dancesstepsmap' VALUES (23116, 18242, 2);
INSERT INTO 'dancesstepsmap' VALUES (23117, 18242, 1);
INSERT INTO 'dancesstepsmap' VALUES (23118, 18242, 3);
INSERT INTO 'dancesstepsmap' VALUES (23119, 18243, 4);
INSERT INTO 'dancesstepsmap' VALUES (23120, 18243, 3);
INSERT INTO 'dancesstepsmap' VALUES (23122, 18243, 1);
INSERT INTO 'dancesstepsmap' VALUES (23123, 18243, 2);
INSERT INTO 'dancesstepsmap' VALUES (23124, 2171, 2);
INSERT INTO 'dancesstepsmap' VALUES (23125, 3857, 5);
INSERT INTO 'dancesstepsmap' VALUES (23128, 17436, 2);
INSERT INTO 'dancesstepsmap' VALUES (23129, 17436, 1);
INSERT INTO 'dancesstepsmap' VALUES (23091, 17469, 4);
INSERT INTO 'dancesstepsmap' VALUES (23218, 18265, 1);
INSERT INTO 'dancesstepsmap' VALUES (23241, 13897, 4);
INSERT INTO 'dancesstepsmap' VALUES (23242, 13897, 5);
INSERT INTO 'dancesstepsmap' VALUES (23250, 13898, 1);
INSERT INTO 'dancesstepsmap' VALUES (23252, 13899, 1);
INSERT INTO 'dancesstepsmap' VALUES (23253, 13900, 1);
INSERT INTO 'dancesstepsmap' VALUES (23254, 13900, 2);
INSERT INTO 'dancesstepsmap' VALUES (23255, 13901, 1);
INSERT INTO 'dancesstepsmap' VALUES (23256, 13901, 2);
INSERT INTO 'dancesstepsmap' VALUES (23257, 4042, 2);
INSERT INTO 'dancesstepsmap' VALUES (23258, 13902, 1);
INSERT INTO 'dancesstepsmap' VALUES (23259, 13902, 2);
INSERT INTO 'dancesstepsmap' VALUES (23260, 13903, 4);
INSERT INTO 'dancesstepsmap' VALUES (23261, 13903, 5);
INSERT INTO 'dancesstepsmap' VALUES (23262, 13904, 4);
INSERT INTO 'dancesstepsmap' VALUES (23263, 13904, 5);
INSERT INTO 'dancesstepsmap' VALUES (23264, 13904, 1);
INSERT INTO 'dancesstepsmap' VALUES (23265, 13904, 2);
INSERT INTO 'dancesstepsmap' VALUES (23266, 13905, 4);
INSERT INTO 'dancesstepsmap' VALUES (23267, 13905, 5);
INSERT INTO 'dancesstepsmap' VALUES (23268, 18274, 2);
INSERT INTO 'dancesstepsmap' VALUES (23269, 18274, 1);
INSERT INTO 'dancesstepsmap' VALUES (23270, 18275, 1);
INSERT INTO 'dancesstepsmap' VALUES (23271, 18276, 4);
INSERT INTO 'dancesstepsmap' VALUES (23272, 18277, 1);
INSERT INTO 'dancesstepsmap' VALUES (23273, 18277, 2);
INSERT INTO 'dancesstepsmap' VALUES (23274, 12717, 1);
INSERT INTO 'dancesstepsmap' VALUES (23275, 12717, 2);
INSERT INTO 'dancesstepsmap' VALUES (23276, 18278, 1);
INSERT INTO 'dancesstepsmap' VALUES (23277, 18278, 2);
INSERT INTO 'dancesstepsmap' VALUES (23278, 12715, 4);
INSERT INTO 'dancesstepsmap' VALUES (23279, 16794, 6);
INSERT INTO 'dancesstepsmap' VALUES (23280, 16794, 5);
INSERT INTO 'dancesstepsmap' VALUES (23281, 16794, 4);
INSERT INTO 'dancesstepsmap' VALUES (23282, 13907, 1);
INSERT INTO 'dancesstepsmap' VALUES (23126, 17439, 5);
INSERT INTO 'dancesstepsmap' VALUES (23283, 13907, 3);
INSERT INTO 'dancesstepsmap' VALUES (23284, 18244, 4);
INSERT INTO 'dancesstepsmap' VALUES (23285, 18244, 5);
INSERT INTO 'dancesstepsmap' VALUES (23288, 13868, 1);
INSERT INTO 'dancesstepsmap' VALUES (23289, 15105, 4);
INSERT INTO 'dancesstepsmap' VALUES (23290, 15105, 5);
INSERT INTO 'dancesstepsmap' VALUES (23291, 18279, 1);
INSERT INTO 'dancesstepsmap' VALUES (23292, 18279, 2);
INSERT INTO 'dancesstepsmap' VALUES (23293, 18279, 3);
INSERT INTO 'dancesstepsmap' VALUES (23294, 18280, 5);
INSERT INTO 'dancesstepsmap' VALUES (23295, 18280, 4);
INSERT INTO 'dancesstepsmap' VALUES (23296, 18281, 1);
INSERT INTO 'dancesstepsmap' VALUES (23297, 17524, 4);
INSERT INTO 'dancesstepsmap' VALUES (23298, 17524, 5);
INSERT INTO 'dancesstepsmap' VALUES (23299, 13919, 4);
INSERT INTO 'dancesstepsmap' VALUES (23300, 13919, 5);
INSERT INTO 'dancesstepsmap' VALUES (23301, 13929, 1);
INSERT INTO 'dancesstepsmap' VALUES (23302, 13929, 2);
INSERT INTO 'dancesstepsmap' VALUES (23303, 13928, 1);
INSERT INTO 'dancesstepsmap' VALUES (23304, 13927, 1);
INSERT INTO 'dancesstepsmap' VALUES (23305, 12093, 4);
INSERT INTO 'dancesstepsmap' VALUES (23306, 12093, 5);
INSERT INTO 'dancesstepsmap' VALUES (23307, 12099, 4);
INSERT INTO 'dancesstepsmap' VALUES (23308, 12099, 5);
INSERT INTO 'dancesstepsmap' VALUES (23309, 18282, 4);
INSERT INTO 'dancesstepsmap' VALUES (23312, 8083, 5);
INSERT INTO 'dancesstepsmap' VALUES (23313, 15680, 1);
INSERT INTO 'dancesstepsmap' VALUES (23314, 15680, 2);
INSERT INTO 'dancesstepsmap' VALUES (23315, 15683, 1);
INSERT INTO 'dancesstepsmap' VALUES (23316, 15683, 2);
INSERT INTO 'dancesstepsmap' VALUES (23317, 15683, 3);
INSERT INTO 'dancesstepsmap' VALUES (23318, 13754, 1);
INSERT INTO 'dancesstepsmap' VALUES (23319, 13925, 4);
INSERT INTO 'dancesstepsmap' VALUES (23320, 13923, 3);
INSERT INTO 'dancesstepsmap' VALUES (23321, 13923, 1);
INSERT INTO 'dancesstepsmap' VALUES (23322, 13923, 2);
INSERT INTO 'dancesstepsmap' VALUES (23323, 13922, 1);
INSERT INTO 'dancesstepsmap' VALUES (23324, 13922, 2);
INSERT INTO 'dancesstepsmap' VALUES (23325, 13921, 1);
INSERT INTO 'dancesstepsmap' VALUES (23326, 13921, 2);
INSERT INTO 'dancesstepsmap' VALUES (23327, 13920, 1);
INSERT INTO 'dancesstepsmap' VALUES (23328, 13918, 1);
INSERT INTO 'dancesstepsmap' VALUES (23329, 13918, 2);
INSERT INTO 'dancesstepsmap' VALUES (23330, 13917, 1);
INSERT INTO 'dancesstepsmap' VALUES (23331, 13917, 2);
INSERT INTO 'dancesstepsmap' VALUES (23332, 13916, 1);
INSERT INTO 'dancesstepsmap' VALUES (23333, 13916, 2);
INSERT INTO 'dancesstepsmap' VALUES (23334, 13916, 3);
INSERT INTO 'dancesstepsmap' VALUES (23335, 13915, 1);
INSERT INTO 'dancesstepsmap' VALUES (23336, 13914, 1);
INSERT INTO 'dancesstepsmap' VALUES (23337, 13913, 1);
INSERT INTO 'dancesstepsmap' VALUES (23338, 13913, 2);
INSERT INTO 'dancesstepsmap' VALUES (23339, 18284, 4);
INSERT INTO 'dancesstepsmap' VALUES (23340, 18284, 5);
INSERT INTO 'dancesstepsmap' VALUES (23341, 13912, 4);
INSERT INTO 'dancesstepsmap' VALUES (23342, 13912, 5);
INSERT INTO 'dancesstepsmap' VALUES (23343, 13909, 1);
INSERT INTO 'dancesstepsmap' VALUES (23344, 13909, 2);
INSERT INTO 'dancesstepsmap' VALUES (23345, 12392, 1);
INSERT INTO 'dancesstepsmap' VALUES (23346, 12392, 2);
INSERT INTO 'dancesstepsmap' VALUES (23347, 13906, 1);
INSERT INTO 'dancesstepsmap' VALUES (23348, 13906, 2);
INSERT INTO 'dancesstepsmap' VALUES (23349, 13906, 3);
INSERT INTO 'dancesstepsmap' VALUES (23350, 4834, 5);
INSERT INTO 'dancesstepsmap' VALUES (23351, 1264, 2);
INSERT INTO 'dancesstepsmap' VALUES (23352, 2534, 5);
INSERT INTO 'dancesstepsmap' VALUES (23353, 13908, 4);
INSERT INTO 'dancesstepsmap' VALUES (23354, 6482, 2);
INSERT INTO 'dancesstepsmap' VALUES (23355, 4741, 5);
INSERT INTO 'dancesstepsmap' VALUES (23356, 5438, 2);
INSERT INTO 'dancesstepsmap' VALUES (23357, 3403, 5);
INSERT INTO 'dancesstepsmap' VALUES (23358, 3566, 2);
INSERT INTO 'dancesstepsmap' VALUES (23359, 3566, 3);
INSERT INTO 'dancesstepsmap' VALUES (23360, 9418, 5);
INSERT INTO 'dancesstepsmap' VALUES (23361, 9423, 4);
INSERT INTO 'dancesstepsmap' VALUES (23362, 9423, 5);
INSERT INTO 'dancesstepsmap' VALUES (23363, 9423, 1);
INSERT INTO 'dancesstepsmap' VALUES (23364, 9423, 2);
INSERT INTO 'dancesstepsmap' VALUES (23365, 9423, 3);
INSERT INTO 'dancesstepsmap' VALUES (23366, 18286, 1);
INSERT INTO 'dancesstepsmap' VALUES (23367, 18286, 2);
INSERT INTO 'dancesstepsmap' VALUES (23368, 18286, 3);
INSERT INTO 'dancesstepsmap' VALUES (23369, 4432, 5);
INSERT INTO 'dancesstepsmap' VALUES (23370, 4489, 5);
INSERT INTO 'dancesstepsmap' VALUES (23371, 1751, 2);
INSERT INTO 'dancesstepsmap' VALUES (23372, 13824, 1);
INSERT INTO 'dancesstepsmap' VALUES (23373, 13824, 2);
INSERT INTO 'dancesstepsmap' VALUES (23374, 18287, 1);
INSERT INTO 'dancesstepsmap' VALUES (23375, 18287, 2);
INSERT INTO 'dancesstepsmap' VALUES (23376, 18287, 3);
INSERT INTO 'dancesstepsmap' VALUES (23377, 18288, 4);
INSERT INTO 'dancesstepsmap' VALUES (23378, 18288, 5);
INSERT INTO 'dancesstepsmap' VALUES (23379, 13825, 1);
INSERT INTO 'dancesstepsmap' VALUES (23380, 13826, 1);
INSERT INTO 'dancesstepsmap' VALUES (23381, 13826, 3);
INSERT INTO 'dancesstepsmap' VALUES (23382, 13829, 3);
INSERT INTO 'dancesstepsmap' VALUES (23383, 6028, 2);
INSERT INTO 'dancesstepsmap' VALUES (23384, 4445, 2);
INSERT INTO 'dancesstepsmap' VALUES (23385, 4445, 3);
INSERT INTO 'dancesstepsmap' VALUES (23386, 18289, 4);
INSERT INTO 'dancesstepsmap' VALUES (23387, 18289, 5);
INSERT INTO 'dancesstepsmap' VALUES (23388, 18285, 1);
INSERT INTO 'dancesstepsmap' VALUES (23389, 18285, 2);
INSERT INTO 'dancesstepsmap' VALUES (23390, 18301, 5);
INSERT INTO 'dancesstepsmap' VALUES (23391, 18301, 4);
INSERT INTO 'dancesstepsmap' VALUES (23392, 18302, 4);
INSERT INTO 'dancesstepsmap' VALUES (23393, 18303, 5);
INSERT INTO 'dancesstepsmap' VALUES (23394, 18303, 4);
INSERT INTO 'dancesstepsmap' VALUES (23395, 18304, 4);
INSERT INTO 'dancesstepsmap' VALUES (23396, 18305, 5);
INSERT INTO 'dancesstepsmap' VALUES (23397, 18305, 4);
INSERT INTO 'dancesstepsmap' VALUES (23400, 18307, 5);
INSERT INTO 'dancesstepsmap' VALUES (23401, 18307, 4);
INSERT INTO 'dancesstepsmap' VALUES (23402, 18308, 5);
INSERT INTO 'dancesstepsmap' VALUES (23403, 18308, 4);
INSERT INTO 'dancesstepsmap' VALUES (23404, 4217, 5);
INSERT INTO 'dancesstepsmap' VALUES (23405, 6725, 2);
INSERT INTO 'dancesstepsmap' VALUES (23406, 6725, 3);
INSERT INTO 'dancesstepsmap' VALUES (23407, 18309, 1);
INSERT INTO 'dancesstepsmap' VALUES (23408, 18310, 5);
INSERT INTO 'dancesstepsmap' VALUES (23409, 18310, 4);
INSERT INTO 'dancesstepsmap' VALUES (23410, 18310, 6);
INSERT INTO 'dancesstepsmap' VALUES (23411, 12245, 5);
INSERT INTO 'dancesstepsmap' VALUES (23412, 15825, 3);
INSERT INTO 'dancesstepsmap' VALUES (23413, 14422, 1);
INSERT INTO 'dancesstepsmap' VALUES (23414, 14422, 3);
INSERT INTO 'dancesstepsmap' VALUES (23415, 14422, 4);
INSERT INTO 'dancesstepsmap' VALUES (23416, 18311, 4);
INSERT INTO 'dancesstepsmap' VALUES (23417, 18311, 5);
INSERT INTO 'dancesstepsmap' VALUES (23418, 6242, 5);
INSERT INTO 'dancesstepsmap' VALUES (23419, 18330, 5);
INSERT INTO 'dancesstepsmap' VALUES (23420, 18330, 4);
INSERT INTO 'dancesstepsmap' VALUES (23421, 18331, 2);
INSERT INTO 'dancesstepsmap' VALUES (23422, 18331, 1);
INSERT INTO 'dancesstepsmap' VALUES (23423, 18332, 2);
INSERT INTO 'dancesstepsmap' VALUES (23424, 18332, 1);
INSERT INTO 'dancesstepsmap' VALUES (23425, 18332, 3);
INSERT INTO 'dancesstepsmap' VALUES (23426, 18333, 5);
INSERT INTO 'dancesstepsmap' VALUES (23427, 18333, 4);
INSERT INTO 'dancesstepsmap' VALUES (23428, 18316, 1);
INSERT INTO 'dancesstepsmap' VALUES (23429, 18316, 2);
INSERT INTO 'dancesstepsmap' VALUES (23430, 18317, 1);
INSERT INTO 'dancesstepsmap' VALUES (23431, 18317, 3);
INSERT INTO 'dancesstepsmap' VALUES (23432, 18222, 1);
INSERT INTO 'dancesstepsmap' VALUES (23433, 18212, 1);
INSERT INTO 'dancesstepsmap' VALUES (23434, 18212, 3);
INSERT INTO 'dancesstepsmap' VALUES (23435, 18210, 4);
INSERT INTO 'dancesstepsmap' VALUES (23436, 18210, 5);
INSERT INTO 'dancesstepsmap' VALUES (23437, 18215, 1);
INSERT INTO 'dancesstepsmap' VALUES (23438, 18334, 1);
INSERT INTO 'dancesstepsmap' VALUES (23439, 18334, 2);
INSERT INTO 'dancesstepsmap' VALUES (23440, 18335, 4);
INSERT INTO 'dancesstepsmap' VALUES (23441, 18335, 5);
INSERT INTO 'dancesstepsmap' VALUES (23442, 18335, 1);
INSERT INTO 'dancesstepsmap' VALUES (23443, 18335, 2);
INSERT INTO 'dancesstepsmap' VALUES (23444, 18224, 1);
INSERT INTO 'dancesstepsmap' VALUES (23445, 18224, 2);
INSERT INTO 'dancesstepsmap' VALUES (23446, 18224, 3);
INSERT INTO 'dancesstepsmap' VALUES (23447, 18221, 5);
INSERT INTO 'dancesstepsmap' VALUES (23448, 18221, 4);
INSERT INTO 'dancesstepsmap' VALUES (23449, 18221, 1);
INSERT INTO 'dancesstepsmap' VALUES (23450, 18221, 2);
INSERT INTO 'dancesstepsmap' VALUES (23451, 18214, 1);
INSERT INTO 'dancesstepsmap' VALUES (23452, 18214, 2);
INSERT INTO 'dancesstepsmap' VALUES (23453, 18218, 1);
INSERT INTO 'dancesstepsmap' VALUES (23454, 18218, 2);
INSERT INTO 'dancesstepsmap' VALUES (23455, 3186, 2);
INSERT INTO 'dancesstepsmap' VALUES (23456, 2379, 3);
INSERT INTO 'dancesstepsmap' VALUES (23457, 17348, 1);
INSERT INTO 'dancesstepsmap' VALUES (23458, 18336, 1);
INSERT INTO 'dancesstepsmap' VALUES (23459, 18336, 2);
INSERT INTO 'dancesstepsmap' VALUES (23460, 18325, 1);
INSERT INTO 'dancesstepsmap' VALUES (23461, 18325, 2);
INSERT INTO 'dancesstepsmap' VALUES (23462, 18325, 3);
INSERT INTO 'dancesstepsmap' VALUES (23463, 18324, 1);
INSERT INTO 'dancesstepsmap' VALUES (23464, 2233, 2);
INSERT INTO 'dancesstepsmap' VALUES (23465, 11825, 1);
INSERT INTO 'dancesstepsmap' VALUES (23466, 11825, 2);
INSERT INTO 'dancesstepsmap' VALUES (23467, 18318, 1);
INSERT INTO 'dancesstepsmap' VALUES (23468, 18318, 2);
INSERT INTO 'dancesstepsmap' VALUES (23469, 18318, 3);
INSERT INTO 'dancesstepsmap' VALUES (23286, 13932, 4);
INSERT INTO 'dancesstepsmap' VALUES (23287, 13932, 5);
INSERT INTO 'dancesstepsmap' VALUES (23470, 18329, 1);
INSERT INTO 'dancesstepsmap' VALUES (23471, 18329, 2);
INSERT INTO 'dancesstepsmap' VALUES (23472, 18329, 3);
INSERT INTO 'dancesstepsmap' VALUES (23473, 18337, 1);
INSERT INTO 'dancesstepsmap' VALUES (23474, 18337, 3);
INSERT INTO 'dancesstepsmap' VALUES (23475, 18337, 2);
INSERT INTO 'dancesstepsmap' VALUES (23478, 18341, 1);
INSERT INTO 'dancesstepsmap' VALUES (23479, 18341, 2);
INSERT INTO 'dancesstepsmap' VALUES (23480, 18346, 1);
INSERT INTO 'dancesstepsmap' VALUES (23481, 18346, 2);
INSERT INTO 'dancesstepsmap' VALUES (23482, 18348, 1);
INSERT INTO 'dancesstepsmap' VALUES (23486, 16961, 1);
INSERT INTO 'dancesstepsmap' VALUES (23487, 16791, 2);
INSERT INTO 'dancesstepsmap' VALUES (23488, 16791, 1);
INSERT INTO 'dancesstepsmap' VALUES (23489, 18349, 1);
INSERT INTO 'dancesstepsmap' VALUES (23490, 18349, 2);
INSERT INTO 'dancesstepsmap' VALUES (23491, 18349, 3);
INSERT INTO 'dancesstepsmap' VALUES (23492, 18350, 1);
INSERT INTO 'dancesstepsmap' VALUES (23493, 18351, 1);
INSERT INTO 'dancesstepsmap' VALUES (23494, 18351, 2);
INSERT INTO 'dancesstepsmap' VALUES (23495, 18352, 1);
INSERT INTO 'dancesstepsmap' VALUES (23496, 18353, 1);
INSERT INTO 'dancesstepsmap' VALUES (23497, 17877, 1);
INSERT INTO 'dancesstepsmap' VALUES (23498, 17877, 2);
INSERT INTO 'dancesstepsmap' VALUES (23499, 17877, 3);
INSERT INTO 'dancesstepsmap' VALUES (23500, 17876, 1);
INSERT INTO 'dancesstepsmap' VALUES (23501, 17876, 2);
INSERT INTO 'dancesstepsmap' VALUES (23502, 17875, 4);
INSERT INTO 'dancesstepsmap' VALUES (23503, 17875, 5);
INSERT INTO 'dancesstepsmap' VALUES (23504, 17874, 1);
INSERT INTO 'dancesstepsmap' VALUES (23505, 17874, 2);
INSERT INTO 'dancesstepsmap' VALUES (23506, 17873, 4);
INSERT INTO 'dancesstepsmap' VALUES (23507, 17873, 5);
INSERT INTO 'dancesstepsmap' VALUES (23508, 18354, 2);
INSERT INTO 'dancesstepsmap' VALUES (23509, 18354, 1);
INSERT INTO 'dancesstepsmap' VALUES (23510, 18355, 5);
INSERT INTO 'dancesstepsmap' VALUES (23511, 18355, 4);
INSERT INTO 'dancesstepsmap' VALUES (23512, 17870, 1);
INSERT INTO 'dancesstepsmap' VALUES (23513, 17870, 2);
INSERT INTO 'dancesstepsmap' VALUES (23514, 15237, 4);
INSERT INTO 'dancesstepsmap' VALUES (23515, 15237, 5);
INSERT INTO 'dancesstepsmap' VALUES (23516, 18356, 3);
INSERT INTO 'dancesstepsmap' VALUES (23517, 18356, 2);
INSERT INTO 'dancesstepsmap' VALUES (23518, 18356, 1);
INSERT INTO 'dancesstepsmap' VALUES (23519, 15342, 1);
INSERT INTO 'dancesstepsmap' VALUES (23520, 15342, 2);
INSERT INTO 'dancesstepsmap' VALUES (23521, 15342, 3);
INSERT INTO 'dancesstepsmap' VALUES (23522, 15343, 1);
INSERT INTO 'dancesstepsmap' VALUES (23523, 15343, 2);
INSERT INTO 'dancesstepsmap' VALUES (23524, 18369, 1);
INSERT INTO 'dancesstepsmap' VALUES (23525, 18369, 2);
INSERT INTO 'dancesstepsmap' VALUES (23526, 18369, 3);
INSERT INTO 'dancesstepsmap' VALUES (23527, 18372, 1);
INSERT INTO 'dancesstepsmap' VALUES (23528, 18372, 2);
INSERT INTO 'dancesstepsmap' VALUES (23529, 18365, 4);
INSERT INTO 'dancesstepsmap' VALUES (23530, 18365, 5);
INSERT INTO 'dancesstepsmap' VALUES (23531, 5509, 2);
INSERT INTO 'dancesstepsmap' VALUES (23532, 18373, 5);
INSERT INTO 'dancesstepsmap' VALUES (23533, 18373, 4);
INSERT INTO 'dancesstepsmap' VALUES (23534, 18373, 1);
INSERT INTO 'dancesstepsmap' VALUES (23535, 18373, 2);
INSERT INTO 'dancesstepsmap' VALUES (23536, 18374, 1);
INSERT INTO 'dancesstepsmap' VALUES (23537, 18374, 3);
INSERT INTO 'dancesstepsmap' VALUES (23538, 18378, 1);
INSERT INTO 'dancesstepsmap' VALUES (23539, 18378, 2);
INSERT INTO 'dancesstepsmap' VALUES (23540, 18378, 3);
INSERT INTO 'dancesstepsmap' VALUES (23541, 18379, 4);
INSERT INTO 'dancesstepsmap' VALUES (23542, 18379, 5);
INSERT INTO 'dancesstepsmap' VALUES (23543, 18380, 1);
INSERT INTO 'dancesstepsmap' VALUES (23544, 18380, 2);
INSERT INTO 'dancesstepsmap' VALUES (23545, 18380, 3);
INSERT INTO 'dancesstepsmap' VALUES (23547, 18381, 1);
INSERT INTO 'dancesstepsmap' VALUES (23548, 18381, 2);
INSERT INTO 'dancesstepsmap' VALUES (23549, 18382, 4);
INSERT INTO 'dancesstepsmap' VALUES (23550, 18382, 5);
INSERT INTO 'dancesstepsmap' VALUES (23551, 18384, 1);
INSERT INTO 'dancesstepsmap' VALUES (23552, 18384, 2);
INSERT INTO 'dancesstepsmap' VALUES (23553, 18384, 3);
INSERT INTO 'dancesstepsmap' VALUES (23554, 18383, 2);
INSERT INTO 'dancesstepsmap' VALUES (23555, 18383, 1);
INSERT INTO 'dancesstepsmap' VALUES (23556, 17430, 1);
INSERT INTO 'dancesstepsmap' VALUES (23557, 863, 3);
INSERT INTO 'dancesstepsmap' VALUES (23558, 13052, 2);
INSERT INTO 'dancesstepsmap' VALUES (23559, 13052, 1);
INSERT INTO 'dancesstepsmap' VALUES (23560, 18385, 2);
INSERT INTO 'dancesstepsmap' VALUES (23561, 18385, 1);
INSERT INTO 'dancesstepsmap' VALUES (23562, 18385, 3);
INSERT INTO 'dancesstepsmap' VALUES (23563, 18386, 1);
INSERT INTO 'dancesstepsmap' VALUES (23564, 18386, 2);
INSERT INTO 'dancesstepsmap' VALUES (23565, 18387, 4);
INSERT INTO 'dancesstepsmap' VALUES (23566, 18387, 5);
INSERT INTO 'dancesstepsmap' VALUES (23567, 15662, 1);
INSERT INTO 'dancesstepsmap' VALUES (23568, 15662, 2);
INSERT INTO 'dancesstepsmap' VALUES (23569, 15676, 1);
INSERT INTO 'dancesstepsmap' VALUES (23570, 10532, 4);
INSERT INTO 'dancesstepsmap' VALUES (23571, 303, 5);
INSERT INTO 'dancesstepsmap' VALUES (23572, 18389, 1);
INSERT INTO 'dancesstepsmap' VALUES (23573, 18389, 3);
INSERT INTO 'dancesstepsmap' VALUES (23574, 18389, 2);
INSERT INTO 'dancesstepsmap' VALUES (23575, 18390, 1);
INSERT INTO 'dancesstepsmap' VALUES (23576, 18390, 2);
INSERT INTO 'dancesstepsmap' VALUES (23577, 18391, 5);
INSERT INTO 'dancesstepsmap' VALUES (23578, 18391, 4);
INSERT INTO 'dancesstepsmap' VALUES (23579, 18392, 4);
INSERT INTO 'dancesstepsmap' VALUES (23580, 18392, 6);
INSERT INTO 'dancesstepsmap' VALUES (23581, 13838, 1);
INSERT INTO 'dancesstepsmap' VALUES (23582, 13838, 2);
INSERT INTO 'dancesstepsmap' VALUES (23583, 13838, 3);
INSERT INTO 'dancesstepsmap' VALUES (23546, 18380, 103);
INSERT INTO 'dancesstepsmap' VALUES (23483, 16787, 1);
INSERT INTO 'dancesstepsmap' VALUES (23584, 13840, 1);
INSERT INTO 'dancesstepsmap' VALUES (23585, 13840, 2);
INSERT INTO 'dancesstepsmap' VALUES (23586, 13841, 4);
INSERT INTO 'dancesstepsmap' VALUES (23587, 13841, 5);
INSERT INTO 'dancesstepsmap' VALUES (23588, 13843, 4);
INSERT INTO 'dancesstepsmap' VALUES (23589, 13843, 5);
INSERT INTO 'dancesstepsmap' VALUES (23590, 13845, 1);
INSERT INTO 'dancesstepsmap' VALUES (23591, 13845, 3);
INSERT INTO 'dancesstepsmap' VALUES (12604, 11298, 1);
INSERT INTO 'dancesstepsmap' VALUES (12605, 11298, 2);
INSERT INTO 'dancesstepsmap' VALUES (23592, 18366, 4);
INSERT INTO 'dancesstepsmap' VALUES (23593, 18366, 5);
INSERT INTO 'dancesstepsmap' VALUES (23594, 13837, 4);
INSERT INTO 'dancesstepsmap' VALUES (23595, 13837, 5);
INSERT INTO 'dancesstepsmap' VALUES (23596, 18393, 1);
INSERT INTO 'dancesstepsmap' VALUES (23597, 18393, 2);
INSERT INTO 'dancesstepsmap' VALUES (23598, 18394, 1);
INSERT INTO 'dancesstepsmap' VALUES (23599, 18395, 4);
INSERT INTO 'dancesstepsmap' VALUES (23600, 18395, 5);
INSERT INTO 'dancesstepsmap' VALUES (23601, 1953, 2);
INSERT INTO 'dancesstepsmap' VALUES (23602, 1953, 3);
INSERT INTO 'dancesstepsmap' VALUES (23603, 733, 5);
INSERT INTO 'dancesstepsmap' VALUES (23604, 2062, 2);
INSERT INTO 'dancesstepsmap' VALUES (23605, 6893, 2);
INSERT INTO 'dancesstepsmap' VALUES (23606, 18376, 1);
INSERT INTO 'dancesstepsmap' VALUES (23607, 10264, 2);
INSERT INTO 'dancesstepsmap' VALUES (23608, 12369, 1);
INSERT INTO 'dancesstepsmap' VALUES (23609, 12369, 2);
INSERT INTO 'dancesstepsmap' VALUES (23610, 18408, 1);
INSERT INTO 'dancesstepsmap' VALUES (23611, 18409, 1);
INSERT INTO 'dancesstepsmap' VALUES (23612, 18409, 2);
INSERT INTO 'dancesstepsmap' VALUES (23613, 16566, 5);
INSERT INTO 'dancesstepsmap' VALUES (23614, 16566, 4);
INSERT INTO 'dancesstepsmap' VALUES (23615, 18410, 4);
INSERT INTO 'dancesstepsmap' VALUES (23616, 18410, 5);
INSERT INTO 'dancesstepsmap' VALUES (23617, 14903, 1);
INSERT INTO 'dancesstepsmap' VALUES (23618, 14903, 2);
INSERT INTO 'dancesstepsmap' VALUES (23619, 14903, 3);
INSERT INTO 'dancesstepsmap' VALUES (23620, 9939, 1);
INSERT INTO 'dancesstepsmap' VALUES (23621, 16661, 2);
INSERT INTO 'dancesstepsmap' VALUES (23622, 16661, 1);
INSERT INTO 'dancesstepsmap' VALUES (23623, 14224, 2);
INSERT INTO 'dancesstepsmap' VALUES (23624, 14224, 1);
INSERT INTO 'dancesstepsmap' VALUES (23625, 17599, 5);
INSERT INTO 'dancesstepsmap' VALUES (23626, 17599, 4);
INSERT INTO 'dancesstepsmap' VALUES (23627, 14456, 5);
INSERT INTO 'dancesstepsmap' VALUES (23628, 14456, 4);
INSERT INTO 'dancesstepsmap' VALUES (23629, 3375, 2);
INSERT INTO 'dancesstepsmap' VALUES (23630, 3375, 3);
INSERT INTO 'dancesstepsmap' VALUES (23631, 8760, 1);
INSERT INTO 'dancesstepsmap' VALUES (23632, 8760, 2);
INSERT INTO 'dancesstepsmap' VALUES (23633, 14959, 2);
INSERT INTO 'dancesstepsmap' VALUES (23634, 14959, 1);
INSERT INTO 'dancesstepsmap' VALUES (23635, 18466, 5);
INSERT INTO 'dancesstepsmap' VALUES (23636, 18466, 4);
INSERT INTO 'dancesstepsmap' VALUES (23637, 18467, 1);
INSERT INTO 'dancesstepsmap' VALUES (23638, 18467, 2);
INSERT INTO 'dancesstepsmap' VALUES (23639, 18468, 4);
INSERT INTO 'dancesstepsmap' VALUES (23640, 18468, 5);
INSERT INTO 'dancesstepsmap' VALUES (23641, 18469, 1);
INSERT INTO 'dancesstepsmap' VALUES (23642, 18469, 2);
INSERT INTO 'dancesstepsmap' VALUES (23643, 18470, 1);
INSERT INTO 'dancesstepsmap' VALUES (23644, 18470, 2);
INSERT INTO 'dancesstepsmap' VALUES (23645, 18470, 3);
INSERT INTO 'dancesstepsmap' VALUES (23646, 18471, 4);
INSERT INTO 'dancesstepsmap' VALUES (23647, 18471, 5);
INSERT INTO 'dancesstepsmap' VALUES (23648, 2503, 3);
INSERT INTO 'dancesstepsmap' VALUES (23649, 5682, 5);
INSERT INTO 'dancesstepsmap' VALUES (23650, 18472, 1);
INSERT INTO 'dancesstepsmap' VALUES (23651, 18472, 2);
INSERT INTO 'dancesstepsmap' VALUES (23652, 18473, 1);
INSERT INTO 'dancesstepsmap' VALUES (23653, 18473, 2);
INSERT INTO 'dancesstepsmap' VALUES (23654, 18474, 1);
INSERT INTO 'dancesstepsmap' VALUES (23655, 18474, 2);
INSERT INTO 'dancesstepsmap' VALUES (23656, 18474, 3);
INSERT INTO 'dancesstepsmap' VALUES (23657, 18475, 1);
INSERT INTO 'dancesstepsmap' VALUES (23658, 18476, 1);
INSERT INTO 'dancesstepsmap' VALUES (23659, 18476, 2);
INSERT INTO 'dancesstepsmap' VALUES (23660, 18476, 3);
INSERT INTO 'dancesstepsmap' VALUES (23661, 18477, 4);
INSERT INTO 'dancesstepsmap' VALUES (23662, 18477, 5);
INSERT INTO 'dancesstepsmap' VALUES (23663, 18478, 4);
INSERT INTO 'dancesstepsmap' VALUES (23664, 18478, 5);
INSERT INTO 'dancesstepsmap' VALUES (23665, 18479, 1);
INSERT INTO 'dancesstepsmap' VALUES (23666, 18479, 2);
INSERT INTO 'dancesstepsmap' VALUES (23667, 18479, 3);
INSERT INTO 'dancesstepsmap' VALUES (23668, 18480, 1);
INSERT INTO 'dancesstepsmap' VALUES (23669, 18480, 2);
INSERT INTO 'dancesstepsmap' VALUES (23670, 18481, 1);
INSERT INTO 'dancesstepsmap' VALUES (23671, 18481, 2);
INSERT INTO 'dancesstepsmap' VALUES (23672, 18481, 3);
INSERT INTO 'dancesstepsmap' VALUES (23673, 18482, 1);
INSERT INTO 'dancesstepsmap' VALUES (23674, 18482, 2);
INSERT INTO 'dancesstepsmap' VALUES (23675, 18483, 1);
INSERT INTO 'dancesstepsmap' VALUES (23676, 18483, 2);
INSERT INTO 'dancesstepsmap' VALUES (23677, 18483, 3);
INSERT INTO 'dancesstepsmap' VALUES (23678, 18484, 1);
INSERT INTO 'dancesstepsmap' VALUES (23679, 18484, 2);
INSERT INTO 'dancesstepsmap' VALUES (23680, 18484, 3);
INSERT INTO 'dancesstepsmap' VALUES (16487, 7080, 5);
INSERT INTO 'dancesstepsmap' VALUES (23684, 9679, 2);
INSERT INTO 'dancesstepsmap' VALUES (23685, 14122, 4);
INSERT INTO 'dancesstepsmap' VALUES (23686, 14122, 5);
INSERT INTO 'dancesstepsmap' VALUES (23687, 14765, 1);
INSERT INTO 'dancesstepsmap' VALUES (23688, 14765, 2);
INSERT INTO 'dancesstepsmap' VALUES (23689, 14765, 3);
INSERT INTO 'dancesstepsmap' VALUES (23690, 14118, 1);
INSERT INTO 'dancesstepsmap' VALUES (23691, 14118, 2);
INSERT INTO 'dancesstepsmap' VALUES (23692, 14118, 3);
INSERT INTO 'dancesstepsmap' VALUES (23693, 1621, 5);
INSERT INTO 'dancesstepsmap' VALUES (23694, 18487, 4);
INSERT INTO 'dancesstepsmap' VALUES (23695, 18487, 5);
INSERT INTO 'dancesstepsmap' VALUES (23696, 18488, 1);
INSERT INTO 'dancesstepsmap' VALUES (23697, 18488, 2);
INSERT INTO 'dancesstepsmap' VALUES (23698, 18488, 3);
INSERT INTO 'dancesstepsmap' VALUES (23701, 18486, 1);
INSERT INTO 'dancesstepsmap' VALUES (23702, 18486, 2);
INSERT INTO 'dancesstepsmap' VALUES (23703, 18486, 10);
INSERT INTO 'dancesstepsmap' VALUES (23704, 18490, 4);
INSERT INTO 'dancesstepsmap' VALUES (23705, 18490, 5);
INSERT INTO 'dancesstepsmap' VALUES (23706, 18491, 1);
INSERT INTO 'dancesstepsmap' VALUES (23707, 18491, 2);
INSERT INTO 'dancesstepsmap' VALUES (23708, 18492, 4);
INSERT INTO 'dancesstepsmap' VALUES (23709, 18492, 5);
INSERT INTO 'dancesstepsmap' VALUES (23710, 18493, 1);
INSERT INTO 'dancesstepsmap' VALUES (23711, 18494, 1);
INSERT INTO 'dancesstepsmap' VALUES (23712, 18494, 2);
INSERT INTO 'dancesstepsmap' VALUES (23713, 18494, 3);
INSERT INTO 'dancesstepsmap' VALUES (23714, 7972, 1);
INSERT INTO 'dancesstepsmap' VALUES (23715, 7972, 2);
INSERT INTO 'dancesstepsmap' VALUES (16679, 14326, 4);
INSERT INTO 'dancesstepsmap' VALUES (16680, 14326, 5);
INSERT INTO 'dancesstepsmap' VALUES (23716, 6854, 2);
INSERT INTO 'dancesstepsmap' VALUES (23717, 6854, 3);
INSERT INTO 'dancesstepsmap' VALUES (23718, 10641, 1);
INSERT INTO 'dancesstepsmap' VALUES (23719, 18495, 4);
INSERT INTO 'dancesstepsmap' VALUES (23720, 18495, 5);
INSERT INTO 'dancesstepsmap' VALUES (23721, 18497, 1);
INSERT INTO 'dancesstepsmap' VALUES (23722, 18497, 3);
INSERT INTO 'dancesstepsmap' VALUES (23723, 1384, 5);
INSERT INTO 'dancesstepsmap' VALUES (23724, 567, 5);
INSERT INTO 'dancesstepsmap' VALUES (23727, 5983, 2);
INSERT INTO 'dancesstepsmap' VALUES (23728, 5983, 3);
INSERT INTO 'dancesstepsmap' VALUES (23729, 16923, 3);
INSERT INTO 'dancesstepsmap' VALUES (21351, 16924, 5);
INSERT INTO 'dancesstepsmap' VALUES (21352, 16924, 4);
INSERT INTO 'dancesstepsmap' VALUES (23730, 10852, 5);
INSERT INTO 'dancesstepsmap' VALUES (23731, 10852, 4);
INSERT INTO 'dancesstepsmap' VALUES (23732, 10852, 2);
INSERT INTO 'dancesstepsmap' VALUES (23733, 10852, 1);
INSERT INTO 'dancesstepsmap' VALUES (23734, 15301, 1);
INSERT INTO 'dancesstepsmap' VALUES (23735, 15301, 2);
INSERT INTO 'dancesstepsmap' VALUES (23736, 15301, 3);
INSERT INTO 'dancesstepsmap' VALUES (23737, 2930, 2);
INSERT INTO 'dancesstepsmap' VALUES (23738, 9938, 1);
INSERT INTO 'dancesstepsmap' VALUES (23739, 9938, 2);
INSERT INTO 'dancesstepsmap' VALUES (23740, 15295, 4);
INSERT INTO 'dancesstepsmap' VALUES (23741, 15295, 5);
INSERT INTO 'dancesstepsmap' VALUES (23742, 15288, 4);
INSERT INTO 'dancesstepsmap' VALUES (23743, 15288, 5);
INSERT INTO 'dancesstepsmap' VALUES (23744, 11827, 5);
INSERT INTO 'dancesstepsmap' VALUES (23745, 15287, 1);
INSERT INTO 'dancesstepsmap' VALUES (23746, 15287, 2);
INSERT INTO 'dancesstepsmap' VALUES (23747, 15289, 1);
INSERT INTO 'dancesstepsmap' VALUES (23748, 15289, 2);
INSERT INTO 'dancesstepsmap' VALUES (23749, 15289, 3);
INSERT INTO 'dancesstepsmap' VALUES (23750, 15290, 4);
INSERT INTO 'dancesstepsmap' VALUES (23751, 15290, 5);
INSERT INTO 'dancesstepsmap' VALUES (23752, 17321, 1);
INSERT INTO 'dancesstepsmap' VALUES (23753, 17321, 2);
INSERT INTO 'dancesstepsmap' VALUES (23754, 17321, 3);
INSERT INTO 'dancesstepsmap' VALUES (23755, 15291, 1);
INSERT INTO 'dancesstepsmap' VALUES (23756, 15291, 2);
INSERT INTO 'dancesstepsmap' VALUES (23757, 15293, 1);
INSERT INTO 'dancesstepsmap' VALUES (23758, 3510, 2);
INSERT INTO 'dancesstepsmap' VALUES (23759, 15292, 4);
INSERT INTO 'dancesstepsmap' VALUES (23760, 15292, 5);
INSERT INTO 'dancesstepsmap' VALUES (23761, 15292, 1);
INSERT INTO 'dancesstepsmap' VALUES (23762, 15292, 2);
INSERT INTO 'dancesstepsmap' VALUES (23763, 15292, 3);
INSERT INTO 'dancesstepsmap' VALUES (23764, 15298, 4);
INSERT INTO 'dancesstepsmap' VALUES (23765, 15298, 5);
INSERT INTO 'dancesstepsmap' VALUES (23766, 18193, 1);
INSERT INTO 'dancesstepsmap' VALUES (23767, 18193, 2);
INSERT INTO 'dancesstepsmap' VALUES (23771, 18508, 1);
INSERT INTO 'dancesstepsmap' VALUES (23772, 18508, 2);
INSERT INTO 'dancesstepsmap' VALUES (23773, 18508, 3);
INSERT INTO 'dancesstepsmap' VALUES (23774, 18509, 1);
INSERT INTO 'dancesstepsmap' VALUES (23775, 18509, 2);
INSERT INTO 'dancesstepsmap' VALUES (23776, 18509, 3);
INSERT INTO 'dancesstepsmap' VALUES (23777, 104, 2);
INSERT INTO 'dancesstepsmap' VALUES (23778, 878, 5);
INSERT INTO 'dancesstepsmap' VALUES (23779, 1637, 5);
INSERT INTO 'dancesstepsmap' VALUES (23780, 17516, 1);
INSERT INTO 'dancesstepsmap' VALUES (23781, 17516, 2);
INSERT INTO 'dancesstepsmap' VALUES (23782, 18510, 1);
INSERT INTO 'dancesstepsmap' VALUES (23783, 18510, 2);
INSERT INTO 'dancesstepsmap' VALUES (23784, 6607, 1);
INSERT INTO 'dancesstepsmap' VALUES (23785, 12759, 5);
INSERT INTO 'dancesstepsmap' VALUES (23786, 3481, 2);
INSERT INTO 'dancesstepsmap' VALUES (23787, 3481, 3);
INSERT INTO 'dancesstepsmap' VALUES (23788, 17339, 3);
INSERT INTO 'dancesstepsmap' VALUES (23789, 17339, 1);
INSERT INTO 'dancesstepsmap' VALUES (23790, 17339, 2);
INSERT INTO 'dancesstepsmap' VALUES (23791, 12766, 3);
INSERT INTO 'dancesstepsmap' VALUES (23792, 18507, 4);
INSERT INTO 'dancesstepsmap' VALUES (23793, 18507, 5);
INSERT INTO 'dancesstepsmap' VALUES (23794, 18511, 2);
INSERT INTO 'dancesstepsmap' VALUES (23795, 18511, 1);
INSERT INTO 'dancesstepsmap' VALUES (23796, 18512, 4);
INSERT INTO 'dancesstepsmap' VALUES (23797, 18512, 5);
INSERT INTO 'dancesstepsmap' VALUES (23800, 18515, 2);
INSERT INTO 'dancesstepsmap' VALUES (23801, 18515, 1);
INSERT INTO 'dancesstepsmap' VALUES (23804, 18517, 1);
INSERT INTO 'dancesstepsmap' VALUES (23805, 18518, 1);
INSERT INTO 'dancesstepsmap' VALUES (23807, 18520, 1);
INSERT INTO 'dancesstepsmap' VALUES (23808, 18520, 3);
INSERT INTO 'dancesstepsmap' VALUES (23809, 12765, 5);
INSERT INTO 'dancesstepsmap' VALUES (23810, 13505, 1);
INSERT INTO 'dancesstepsmap' VALUES (23811, 13505, 2);
INSERT INTO 'dancesstepsmap' VALUES (23812, 12764, 3);
INSERT INTO 'dancesstepsmap' VALUES (23813, 12763, 2);
INSERT INTO 'dancesstepsmap' VALUES (23814, 15242, 4);
INSERT INTO 'dancesstepsmap' VALUES (23815, 15242, 5);
INSERT INTO 'dancesstepsmap' VALUES (23816, 1503, 5);
INSERT INTO 'dancesstepsmap' VALUES (23817, 18521, 5);
INSERT INTO 'dancesstepsmap' VALUES (23818, 18521, 4);
INSERT INTO 'dancesstepsmap' VALUES (23819, 6659, 2);
INSERT INTO 'dancesstepsmap' VALUES (23820, 6659, 3);
INSERT INTO 'dancesstepsmap' VALUES (23821, 17437, 4);
INSERT INTO 'dancesstepsmap' VALUES (23822, 17437, 5);
INSERT INTO 'dancesstepsmap' VALUES (23823, 18522, 4);
INSERT INTO 'dancesstepsmap' VALUES (23824, 18523, 4);
INSERT INTO 'dancesstepsmap' VALUES (23825, 17438, 1);
INSERT INTO 'dancesstepsmap' VALUES (23826, 18533, 1);
INSERT INTO 'dancesstepsmap' VALUES (23827, 18533, 2);
INSERT INTO 'dancesstepsmap' VALUES (23828, 18534, 4);
INSERT INTO 'dancesstepsmap' VALUES (23829, 18534, 5);
INSERT INTO 'dancesstepsmap' VALUES (23830, 1656, 5);
INSERT INTO 'dancesstepsmap' VALUES (23831, 2370, 2);
INSERT INTO 'dancesstepsmap' VALUES (23832, 18535, 4);
INSERT INTO 'dancesstepsmap' VALUES (23833, 18535, 5);
INSERT INTO 'dancesstepsmap' VALUES (23834, 17370, 1);
INSERT INTO 'dancesstepsmap' VALUES (23835, 17370, 3);
INSERT INTO 'dancesstepsmap' VALUES (23836, 18536, 1);
INSERT INTO 'dancesstepsmap' VALUES (23837, 18536, 2);
INSERT INTO 'dancesstepsmap' VALUES (23838, 18537, 5);
INSERT INTO 'dancesstepsmap' VALUES (23839, 18537, 4);
INSERT INTO 'dancesstepsmap' VALUES (23840, 18537, 1);
INSERT INTO 'dancesstepsmap' VALUES (23841, 18537, 2);
INSERT INTO 'dancesstepsmap' VALUES (23842, 18538, 5);
INSERT INTO 'dancesstepsmap' VALUES (23843, 18538, 4);
INSERT INTO 'dancesstepsmap' VALUES (23844, 18539, 5);
INSERT INTO 'dancesstepsmap' VALUES (23845, 18539, 4);
INSERT INTO 'dancesstepsmap' VALUES (23846, 18540, 4);
INSERT INTO 'dancesstepsmap' VALUES (23847, 18540, 5);
INSERT INTO 'dancesstepsmap' VALUES (23848, 18540, 1);
INSERT INTO 'dancesstepsmap' VALUES (23849, 18540, 2);
INSERT INTO 'dancesstepsmap' VALUES (23850, 18540, 3);
INSERT INTO 'dancesstepsmap' VALUES (23851, 18541, 1);
INSERT INTO 'dancesstepsmap' VALUES (23852, 18541, 2);
INSERT INTO 'dancesstepsmap' VALUES (23853, 18541, 3);
INSERT INTO 'dancesstepsmap' VALUES (23854, 18542, 1);
INSERT INTO 'dancesstepsmap' VALUES (23855, 18542, 2);
INSERT INTO 'dancesstepsmap' VALUES (23856, 18543, 4);
INSERT INTO 'dancesstepsmap' VALUES (23857, 18543, 5);
INSERT INTO 'dancesstepsmap' VALUES (23858, 18544, 1);
INSERT INTO 'dancesstepsmap' VALUES (23859, 18544, 2);
INSERT INTO 'dancesstepsmap' VALUES (23860, 18545, 1);
INSERT INTO 'dancesstepsmap' VALUES (23861, 18545, 2);
INSERT INTO 'dancesstepsmap' VALUES (23862, 18546, 4);
INSERT INTO 'dancesstepsmap' VALUES (23863, 18546, 5);
INSERT INTO 'dancesstepsmap' VALUES (23864, 18547, 1);
INSERT INTO 'dancesstepsmap' VALUES (23865, 18547, 3);
INSERT INTO 'dancesstepsmap' VALUES (23866, 18548, 4);
INSERT INTO 'dancesstepsmap' VALUES (23867, 18548, 5);
INSERT INTO 'dancesstepsmap' VALUES (23868, 18549, 1);
INSERT INTO 'dancesstepsmap' VALUES (23869, 18549, 2);
INSERT INTO 'dancesstepsmap' VALUES (23870, 18549, 3);
INSERT INTO 'dancesstepsmap' VALUES (23871, 18550, 2);
INSERT INTO 'dancesstepsmap' VALUES (23872, 18550, 1);
INSERT INTO 'dancesstepsmap' VALUES (23873, 18550, 3);
INSERT INTO 'dancesstepsmap' VALUES (23874, 18551, 1);
INSERT INTO 'dancesstepsmap' VALUES (23875, 18551, 2);
INSERT INTO 'dancesstepsmap' VALUES (23876, 18552, 1);
INSERT INTO 'dancesstepsmap' VALUES (23877, 18552, 3);
INSERT INTO 'dancesstepsmap' VALUES (23878, 18553, 1);
INSERT INTO 'dancesstepsmap' VALUES (23879, 18553, 2);
INSERT INTO 'dancesstepsmap' VALUES (23880, 14115, 1);
INSERT INTO 'dancesstepsmap' VALUES (23881, 14115, 3);
INSERT INTO 'dancesstepsmap' VALUES (23882, 14119, 4);
INSERT INTO 'dancesstepsmap' VALUES (23883, 14119, 5);
INSERT INTO 'dancesstepsmap' VALUES (23884, 14120, 1);
INSERT INTO 'dancesstepsmap' VALUES (23885, 14120, 2);
INSERT INTO 'dancesstepsmap' VALUES (23886, 14120, 3);
INSERT INTO 'dancesstepsmap' VALUES (23887, 14121, 1);
INSERT INTO 'dancesstepsmap' VALUES (23888, 14121, 2);
INSERT INTO 'dancesstepsmap' VALUES (23889, 14121, 3);
INSERT INTO 'dancesstepsmap' VALUES (23890, 17279, 4);
INSERT INTO 'dancesstepsmap' VALUES (23891, 17279, 5);
INSERT INTO 'dancesstepsmap' VALUES (23892, 14132, 1);
INSERT INTO 'dancesstepsmap' VALUES (23893, 14131, 1);
INSERT INTO 'dancesstepsmap' VALUES (23894, 14131, 2);
INSERT INTO 'dancesstepsmap' VALUES (23896, 14130, 6);
INSERT INTO 'dancesstepsmap' VALUES (23897, 18554, 1);
INSERT INTO 'dancesstepsmap' VALUES (23898, 18554, 2);
INSERT INTO 'dancesstepsmap' VALUES (23798, 18513, 1);
INSERT INTO 'dancesstepsmap' VALUES (23799, 18513, 2);
INSERT INTO 'dancesstepsmap' VALUES (23900, 18555, 2);
INSERT INTO 'dancesstepsmap' VALUES (23901, 18555, 3);
INSERT INTO 'dancesstepsmap' VALUES (23902, 17457, 1);
INSERT INTO 'dancesstepsmap' VALUES (23903, 17457, 3);
INSERT INTO 'dancesstepsmap' VALUES (23904, 17456, 4);
INSERT INTO 'dancesstepsmap' VALUES (23905, 17456, 5);
INSERT INTO 'dancesstepsmap' VALUES (23906, 17455, 1);
INSERT INTO 'dancesstepsmap' VALUES (23907, 17455, 2);
INSERT INTO 'dancesstepsmap' VALUES (23908, 17455, 3);
INSERT INTO 'dancesstepsmap' VALUES (23802, 18516, 1);
INSERT INTO 'dancesstepsmap' VALUES (23803, 18516, 2);
INSERT INTO 'dancesstepsmap' VALUES (23909, 16610, 5);
INSERT INTO 'dancesstepsmap' VALUES (23910, 16610, 4);
INSERT INTO 'dancesstepsmap' VALUES (23911, 14123, 1);
INSERT INTO 'dancesstepsmap' VALUES (23912, 14123, 2);
INSERT INTO 'dancesstepsmap' VALUES (23913, 14129, 1);
INSERT INTO 'dancesstepsmap' VALUES (23914, 14129, 2);
INSERT INTO 'dancesstepsmap' VALUES (23915, 15401, 3);
INSERT INTO 'dancesstepsmap' VALUES (23916, 3400, 5);
INSERT INTO 'dancesstepsmap' VALUES (23917, 4023, 5);
INSERT INTO 'dancesstepsmap' VALUES (23918, 18560, 1);
INSERT INTO 'dancesstepsmap' VALUES (23919, 18560, 2);
INSERT INTO 'dancesstepsmap' VALUES (23920, 14252, 1);
INSERT INTO 'dancesstepsmap' VALUES (23921, 14252, 2);
INSERT INTO 'dancesstepsmap' VALUES (23922, 14252, 3);
INSERT INTO 'dancesstepsmap' VALUES (23923, 13592, 4);
INSERT INTO 'dancesstepsmap' VALUES (23924, 4396, 2);
INSERT INTO 'dancesstepsmap' VALUES (23925, 18561, 1);
INSERT INTO 'dancesstepsmap' VALUES (23926, 18562, 1);
INSERT INTO 'dancesstepsmap' VALUES (23927, 18562, 2);
INSERT INTO 'dancesstepsmap' VALUES (23928, 18563, 1);
INSERT INTO 'dancesstepsmap' VALUES (23929, 18563, 2);
INSERT INTO 'dancesstepsmap' VALUES (23930, 18567, 1);
INSERT INTO 'dancesstepsmap' VALUES (23931, 18567, 3);
INSERT INTO 'dancesstepsmap' VALUES (23932, 18568, 1);
INSERT INTO 'dancesstepsmap' VALUES (23933, 18568, 2);
INSERT INTO 'dancesstepsmap' VALUES (23934, 18569, 4);
INSERT INTO 'dancesstepsmap' VALUES (23935, 18569, 5);
INSERT INTO 'dancesstepsmap' VALUES (12791, 11464, 1);
INSERT INTO 'dancesstepsmap' VALUES (23936, 11464, 2);
INSERT INTO 'dancesstepsmap' VALUES (23937, 18570, 1);
INSERT INTO 'dancesstepsmap' VALUES (23938, 4607, 5);
INSERT INTO 'dancesstepsmap' VALUES (23939, 4667, 2);
INSERT INTO 'dancesstepsmap' VALUES (23940, 1584, 2);
INSERT INTO 'dancesstepsmap' VALUES (23941, 2701, 2);
INSERT INTO 'dancesstepsmap' VALUES (23942, 18576, 1);
INSERT INTO 'dancesstepsmap' VALUES (23946, 18580, 1);
INSERT INTO 'dancesstepsmap' VALUES (23947, 18580, 2);
INSERT INTO 'dancesstepsmap' VALUES (23948, 18579, 4);
INSERT INTO 'dancesstepsmap' VALUES (23949, 18579, 5);
INSERT INTO 'dancesstepsmap' VALUES (23950, 18581, 4);
INSERT INTO 'dancesstepsmap' VALUES (23951, 18581, 5);
INSERT INTO 'dancesstepsmap' VALUES (23952, 12096, 5);
INSERT INTO 'dancesstepsmap' VALUES (23953, 12096, 4);
INSERT INTO 'dancesstepsmap' VALUES (23954, 15681, 5);
INSERT INTO 'dancesstepsmap' VALUES (23955, 15681, 4);
INSERT INTO 'dancesstepsmap' VALUES (23956, 18571, 1);
INSERT INTO 'dancesstepsmap' VALUES (23957, 18571, 2);
INSERT INTO 'dancesstepsmap' VALUES (23958, 17249, 4);
INSERT INTO 'dancesstepsmap' VALUES (23959, 17249, 5);
INSERT INTO 'dancesstepsmap' VALUES (23960, 17254, 1);
INSERT INTO 'dancesstepsmap' VALUES (23961, 17254, 2);
INSERT INTO 'dancesstepsmap' VALUES (23962, 17247, 2);
INSERT INTO 'dancesstepsmap' VALUES (23963, 17247, 1);
INSERT INTO 'dancesstepsmap' VALUES (23964, 11243, 4);
INSERT INTO 'dancesstepsmap' VALUES (23965, 11243, 5);
INSERT INTO 'dancesstepsmap' VALUES (23966, 11243, 2);
INSERT INTO 'dancesstepsmap' VALUES (23967, 11243, 1);
INSERT INTO 'dancesstepsmap' VALUES (23968, 11243, 3);
INSERT INTO 'dancesstepsmap' VALUES (23969, 12169, 1);
INSERT INTO 'dancesstepsmap' VALUES (23970, 12169, 2);
INSERT INTO 'dancesstepsmap' VALUES (23971, 17252, 1);
INSERT INTO 'dancesstepsmap' VALUES (23972, 17252, 2);
INSERT INTO 'dancesstepsmap' VALUES (23973, 12817, 1);
INSERT INTO 'dancesstepsmap' VALUES (23974, 12817, 2);
INSERT INTO 'dancesstepsmap' VALUES (23975, 12817, 3);
INSERT INTO 'dancesstepsmap' VALUES (23976, 18033, 3);
INSERT INTO 'dancesstepsmap' VALUES (23977, 18033, 1);
INSERT INTO 'dancesstepsmap' VALUES (23978, 7888, 2);
INSERT INTO 'dancesstepsmap' VALUES (23979, 7888, 3);
INSERT INTO 'dancesstepsmap' VALUES (23980, 16479, 1);
INSERT INTO 'dancesstepsmap' VALUES (23981, 16612, 4);
INSERT INTO 'dancesstepsmap' VALUES (9234, 3413, 2);
INSERT INTO 'dancesstepsmap' VALUES (23982, 3413, 3);
INSERT INTO 'dancesstepsmap' VALUES (23983, 5413, 5);
INSERT INTO 'dancesstepsmap' VALUES (23984, 18587, 4);
INSERT INTO 'dancesstepsmap' VALUES (23985, 6890, 5);
INSERT INTO 'dancesstepsmap' VALUES (23986, 18588, 1);
INSERT INTO 'dancesstepsmap' VALUES (23987, 18588, 2);
INSERT INTO 'dancesstepsmap' VALUES (23988, 18594, 5);
INSERT INTO 'dancesstepsmap' VALUES (23989, 18594, 4);
INSERT INTO 'dancesstepsmap' VALUES (23990, 18595, 1);
INSERT INTO 'dancesstepsmap' VALUES (23991, 18595, 3);
INSERT INTO 'dancesstepsmap' VALUES (23992, 18595, 2);
INSERT INTO 'dancesstepsmap' VALUES (23995, 18597, 2);
INSERT INTO 'dancesstepsmap' VALUES (23996, 18597, 1);
INSERT INTO 'dancesstepsmap' VALUES (23997, 18597, 3);
INSERT INTO 'dancesstepsmap' VALUES (24001, 18600, 5);
INSERT INTO 'dancesstepsmap' VALUES (24002, 18600, 4);
INSERT INTO 'dancesstepsmap' VALUES (24003, 18601, 4);
INSERT INTO 'dancesstepsmap' VALUES (24004, 18601, 5);
INSERT INTO 'dancesstepsmap' VALUES (24005, 18602, 2);
INSERT INTO 'dancesstepsmap' VALUES (24006, 18602, 1);
INSERT INTO 'dancesstepsmap' VALUES (24007, 18602, 3);
INSERT INTO 'dancesstepsmap' VALUES (24008, 18603, 1);
INSERT INTO 'dancesstepsmap' VALUES (24009, 18603, 2);
INSERT INTO 'dancesstepsmap' VALUES (24010, 18604, 5);
INSERT INTO 'dancesstepsmap' VALUES (24012, 18604, 1);
INSERT INTO 'dancesstepsmap' VALUES (24013, 18604, 2);
INSERT INTO 'dancesstepsmap' VALUES (24014, 18604, 3);
INSERT INTO 'dancesstepsmap' VALUES (24015, 18605, 1);
INSERT INTO 'dancesstepsmap' VALUES (24016, 18605, 2);
INSERT INTO 'dancesstepsmap' VALUES (24017, 18606, 5);
INSERT INTO 'dancesstepsmap' VALUES (24018, 18606, 4);
INSERT INTO 'dancesstepsmap' VALUES (24019, 18607, 5);
INSERT INTO 'dancesstepsmap' VALUES (24020, 18607, 4);
INSERT INTO 'dancesstepsmap' VALUES (24021, 14952, 5);
INSERT INTO 'dancesstepsmap' VALUES (24022, 14952, 4);
INSERT INTO 'dancesstepsmap' VALUES (24023, 18610, 4);
INSERT INTO 'dancesstepsmap' VALUES (24024, 18610, 5);
INSERT INTO 'dancesstepsmap' VALUES (24025, 6963, 2);
INSERT INTO 'dancesstepsmap' VALUES (7723, 4252, 2);
INSERT INTO 'dancesstepsmap' VALUES (24026, 4252, 3);
INSERT INTO 'dancesstepsmap' VALUES (24027, 18612, 4);
INSERT INTO 'dancesstepsmap' VALUES (24028, 18623, 4);
INSERT INTO 'dancesstepsmap' VALUES (24029, 18624, 4);
INSERT INTO 'dancesstepsmap' VALUES (24030, 18626, 1);
INSERT INTO 'dancesstepsmap' VALUES (24031, 18626, 2);
INSERT INTO 'dancesstepsmap' VALUES (24032, 18630, 4);
INSERT INTO 'dancesstepsmap' VALUES (23998, 18599, 5);
INSERT INTO 'dancesstepsmap' VALUES (24033, 18630, 5);
INSERT INTO 'dancesstepsmap' VALUES (24034, 18631, 1);
INSERT INTO 'dancesstepsmap' VALUES (24035, 18631, 2);
INSERT INTO 'dancesstepsmap' VALUES (24036, 18632, 5);
INSERT INTO 'dancesstepsmap' VALUES (24037, 18632, 4);
INSERT INTO 'dancesstepsmap' VALUES (24038, 18633, 4);
INSERT INTO 'dancesstepsmap' VALUES (24039, 18633, 5);
INSERT INTO 'dancesstepsmap' VALUES (24040, 18634, 1);
INSERT INTO 'dancesstepsmap' VALUES (24041, 18634, 2);
INSERT INTO 'dancesstepsmap' VALUES (24042, 18634, 3);
INSERT INTO 'dancesstepsmap' VALUES (24043, 18635, 1);
INSERT INTO 'dancesstepsmap' VALUES (24044, 18635, 2);
INSERT INTO 'dancesstepsmap' VALUES (24045, 18637, 1);
INSERT INTO 'dancesstepsmap' VALUES (24046, 18637, 3);
INSERT INTO 'dancesstepsmap' VALUES (24047, 18638, 1);
INSERT INTO 'dancesstepsmap' VALUES (24048, 18638, 2);
INSERT INTO 'dancesstepsmap' VALUES (24049, 18639, 1);
INSERT INTO 'dancesstepsmap' VALUES (24050, 18640, 4);
INSERT INTO 'dancesstepsmap' VALUES (24051, 18640, 5);
INSERT INTO 'dancesstepsmap' VALUES (24052, 18641, 1);
INSERT INTO 'dancesstepsmap' VALUES (24053, 18641, 2);
INSERT INTO 'dancesstepsmap' VALUES (24054, 18642, 1);
INSERT INTO 'dancesstepsmap' VALUES (24055, 18642, 2);
INSERT INTO 'dancesstepsmap' VALUES (24056, 18642, 3);
INSERT INTO 'dancesstepsmap' VALUES (24057, 18643, 1);
INSERT INTO 'dancesstepsmap' VALUES (24058, 18644, 4);
INSERT INTO 'dancesstepsmap' VALUES (24059, 18644, 5);
INSERT INTO 'dancesstepsmap' VALUES (24060, 18645, 1);
INSERT INTO 'dancesstepsmap' VALUES (24061, 18645, 2);
INSERT INTO 'dancesstepsmap' VALUES (24062, 18646, 1);
INSERT INTO 'dancesstepsmap' VALUES (24063, 18646, 2);
INSERT INTO 'dancesstepsmap' VALUES (24064, 18648, 1);
INSERT INTO 'dancesstepsmap' VALUES (24065, 18648, 2);
INSERT INTO 'dancesstepsmap' VALUES (24066, 12924, 1);
INSERT INTO 'dancesstepsmap' VALUES (24067, 18650, 4);
INSERT INTO 'dancesstepsmap' VALUES (24068, 18651, 1);
INSERT INTO 'dancesstepsmap' VALUES (24069, 18651, 3);
INSERT INTO 'dancesstepsmap' VALUES (24070, 18653, 5);
INSERT INTO 'dancesstepsmap' VALUES (24071, 18653, 4);
INSERT INTO 'dancesstepsmap' VALUES (24072, 18625, 1);
INSERT INTO 'dancesstepsmap' VALUES (24073, 18625, 2);
INSERT INTO 'dancesstepsmap' VALUES (24074, 18625, 3);
INSERT INTO 'dancesstepsmap' VALUES (24075, 14400, 3);
INSERT INTO 'dancesstepsmap' VALUES (24076, 18647, 1);
INSERT INTO 'dancesstepsmap' VALUES (24077, 18647, 2);
INSERT INTO 'dancesstepsmap' VALUES (24078, 18649, 4);
INSERT INTO 'dancesstepsmap' VALUES (24079, 18649, 5);
INSERT INTO 'dancesstepsmap' VALUES (24080, 18652, 4);
INSERT INTO 'dancesstepsmap' VALUES (24081, 18652, 5);
INSERT INTO 'dancesstepsmap' VALUES (24082, 18627, 1);
INSERT INTO 'dancesstepsmap' VALUES (24083, 18627, 2);
INSERT INTO 'dancesstepsmap' VALUES (24084, 14080, 1);
INSERT INTO 'dancesstepsmap' VALUES (24085, 14080, 2);
INSERT INTO 'dancesstepsmap' VALUES (24086, 14078, 4);
INSERT INTO 'dancesstepsmap' VALUES (24087, 14078, 5);
INSERT INTO 'dancesstepsmap' VALUES (24088, 18656, 1);
INSERT INTO 'dancesstepsmap' VALUES (24089, 18656, 2);
INSERT INTO 'dancesstepsmap' VALUES (24090, 396, 2);
INSERT INTO 'dancesstepsmap' VALUES (24091, 396, 3);
INSERT INTO 'dancesstepsmap' VALUES (24092, 18657, 1);
INSERT INTO 'dancesstepsmap' VALUES (24093, 18657, 2);
INSERT INTO 'dancesstepsmap' VALUES (24094, 18657, 3);
INSERT INTO 'dancesstepsmap' VALUES (24095, 18659, 1);
INSERT INTO 'dancesstepsmap' VALUES (24096, 18660, 4);
INSERT INTO 'dancesstepsmap' VALUES (24097, 18660, 5);
INSERT INTO 'dancesstepsmap' VALUES (24098, 18658, 4);
INSERT INTO 'dancesstepsmap' VALUES (24099, 18658, 5);
INSERT INTO 'dancesstepsmap' VALUES (24100, 18661, 1);
INSERT INTO 'dancesstepsmap' VALUES (24101, 18661, 3);
INSERT INTO 'dancesstepsmap' VALUES (24102, 18662, 4);
INSERT INTO 'dancesstepsmap' VALUES (24103, 18662, 5);
INSERT INTO 'dancesstepsmap' VALUES (24104, 18664, 5);
INSERT INTO 'dancesstepsmap' VALUES (24105, 18664, 4);
INSERT INTO 'dancesstepsmap' VALUES (24106, 10692, 5);
INSERT INTO 'dancesstepsmap' VALUES (24107, 10692, 4);
INSERT INTO 'dancesstepsmap' VALUES (24108, 10448, 1);
INSERT INTO 'dancesstepsmap' VALUES (24109, 10448, 3);
INSERT INTO 'dancesstepsmap' VALUES (24110, 18666, 1);
INSERT INTO 'dancesstepsmap' VALUES (24111, 18666, 2);
INSERT INTO 'dancesstepsmap' VALUES (24112, 18666, 3);
INSERT INTO 'dancesstepsmap' VALUES (24113, 3281, 5);
INSERT INTO 'dancesstepsmap' VALUES (24114, 3611, 5);
INSERT INTO 'dancesstepsmap' VALUES (24115, 18665, 1);
INSERT INTO 'dancesstepsmap' VALUES (24116, 18636, 5);
INSERT INTO 'dancesstepsmap' VALUES (24117, 18636, 4);
INSERT INTO 'dancesstepsmap' VALUES (24118, 18636, 1);
INSERT INTO 'dancesstepsmap' VALUES (24119, 18636, 2);
INSERT INTO 'dancesstepsmap' VALUES (24122, 8692, 2);
INSERT INTO 'dancesstepsmap' VALUES (24123, 9443, 5);
INSERT INTO 'dancesstepsmap' VALUES (24124, 18674, 1);
INSERT INTO 'dancesstepsmap' VALUES (24125, 18674, 2);
INSERT INTO 'dancesstepsmap' VALUES (24126, 18675, 4);
INSERT INTO 'dancesstepsmap' VALUES (24127, 18675, 5);
INSERT INTO 'dancesstepsmap' VALUES (24128, 18676, 1);
INSERT INTO 'dancesstepsmap' VALUES (24129, 18676, 2);
INSERT INTO 'dancesstepsmap' VALUES (24130, 18677, 1);
INSERT INTO 'dancesstepsmap' VALUES (24131, 18677, 2);
INSERT INTO 'dancesstepsmap' VALUES (24132, 18678, 1);
INSERT INTO 'dancesstepsmap' VALUES (24133, 18678, 2);
INSERT INTO 'dancesstepsmap' VALUES (24134, 18679, 1);
INSERT INTO 'dancesstepsmap' VALUES (24135, 15609, 4);
INSERT INTO 'dancesstepsmap' VALUES (24136, 15609, 5);
INSERT INTO 'dancesstepsmap' VALUES (24137, 463, 2);
INSERT INTO 'dancesstepsmap' VALUES (24138, 463, 3);
INSERT INTO 'dancesstepsmap' VALUES (24139, 11450, 4);
INSERT INTO 'dancesstepsmap' VALUES (24140, 11450, 5);
INSERT INTO 'dancesstepsmap' VALUES (24141, 18682, 1);
INSERT INTO 'dancesstepsmap' VALUES (24142, 18683, 4);
INSERT INTO 'dancesstepsmap' VALUES (24143, 18683, 5);
INSERT INTO 'dancesstepsmap' VALUES (24144, 18690, 4);
INSERT INTO 'dancesstepsmap' VALUES (24145, 18696, 1);
INSERT INTO 'dancesstepsmap' VALUES (24146, 18696, 2);
INSERT INTO 'dancesstepsmap' VALUES (24147, 18697, 1);
INSERT INTO 'dancesstepsmap' VALUES (24148, 18697, 2);
INSERT INTO 'dancesstepsmap' VALUES (24149, 18721, 5);
INSERT INTO 'dancesstepsmap' VALUES (24150, 18721, 4);
INSERT INTO 'dancesstepsmap' VALUES (24151, 18722, 4);
INSERT INTO 'dancesstepsmap' VALUES (24152, 18722, 5);
INSERT INTO 'dancesstepsmap' VALUES (24153, 18724, 1);
INSERT INTO 'dancesstepsmap' VALUES (24154, 18724, 2);
INSERT INTO 'dancesstepsmap' VALUES (24155, 18726, 1);
INSERT INTO 'dancesstepsmap' VALUES (24156, 18726, 2);
INSERT INTO 'dancesstepsmap' VALUES (24157, 9493, 1);
INSERT INTO 'dancesstepsmap' VALUES (24158, 18741, 4);
INSERT INTO 'dancesstepsmap' VALUES (24159, 3133, 5);
INSERT INTO 'dancesstepsmap' VALUES (24160, 18755, 4);
INSERT INTO 'dancesstepsmap' VALUES (24161, 18755, 5);
INSERT INTO 'dancesstepsmap' VALUES (24162, 18791, 1);
INSERT INTO 'dancesstepsmap' VALUES (24163, 18791, 2);
INSERT INTO 'dancesstepsmap' VALUES (24164, 18801, 1);
INSERT INTO 'dancesstepsmap' VALUES (24165, 18801, 2);
INSERT INTO 'dancesstepsmap' VALUES (24166, 18806, 4);
INSERT INTO 'dancesstepsmap' VALUES (24167, 18806, 5);
INSERT INTO 'dancesstepsmap' VALUES (24168, 18815, 1);
INSERT INTO 'dancesstepsmap' VALUES (24169, 18815, 2);
INSERT INTO 'dancesstepsmap' VALUES (24170, 18818, 4);
INSERT INTO 'dancesstepsmap' VALUES (24171, 18818, 5);
INSERT INTO 'dancesstepsmap' VALUES (24173, 9983, 5);
INSERT INTO 'dancesstepsmap' VALUES (24174, 7033, 2);
INSERT INTO 'dancesstepsmap' VALUES (24175, 9542, 5);
INSERT INTO 'dancesstepsmap' VALUES (24176, 18926, 4);
INSERT INTO 'dancesstepsmap' VALUES (24177, 18926, 5);
INSERT INTO 'dancesstepsmap' VALUES (24178, 11779, 2);
INSERT INTO 'dancesstepsmap' VALUES (24179, 18956, 1);
INSERT INTO 'dancesstepsmap' VALUES (24180, 18956, 2);
INSERT INTO 'dancesstepsmap' VALUES (24181, 18957, 5);
INSERT INTO 'dancesstepsmap' VALUES (24182, 18957, 4);
INSERT INTO 'dancesstepsmap' VALUES (24183, 18958, 5);
INSERT INTO 'dancesstepsmap' VALUES (24184, 18958, 4);
INSERT INTO 'dancesstepsmap' VALUES (24185, 18966, 5);
INSERT INTO 'dancesstepsmap' VALUES (24186, 18966, 4);
INSERT INTO 'dancesstepsmap' VALUES (24187, 16533, 1);
INSERT INTO 'dancesstepsmap' VALUES (24188, 16533, 2);
INSERT INTO 'dancesstepsmap' VALUES (24189, 16534, 5);
INSERT INTO 'dancesstepsmap' VALUES (24190, 16534, 4);
INSERT INTO 'dancesstepsmap' VALUES (24191, 3832, 2);
INSERT INTO 'dancesstepsmap' VALUES (24192, 3832, 1);
INSERT INTO 'dancesstepsmap' VALUES (24193, 3832, 3);
INSERT INTO 'dancesstepsmap' VALUES (24194, 3832, 5);
INSERT INTO 'dancesstepsmap' VALUES (24195, 3832, 4);
INSERT INTO 'dancesstepsmap' VALUES (24196, 17140, 2);
INSERT INTO 'dancesstepsmap' VALUES (24197, 17140, 1);
INSERT INTO 'dancesstepsmap' VALUES (24198, 18967, 1);
INSERT INTO 'dancesstepsmap' VALUES (24199, 18967, 2);
INSERT INTO 'dancesstepsmap' VALUES (24200, 18967, 3);
INSERT INTO 'dancesstepsmap' VALUES (24201, 18968, 1);
INSERT INTO 'dancesstepsmap' VALUES (24202, 18968, 3);
INSERT INTO 'dancesstepsmap' VALUES (24203, 18969, 1);
INSERT INTO 'dancesstepsmap' VALUES (24204, 18969, 2);
INSERT INTO 'dancesstepsmap' VALUES (24205, 18971, 1);
INSERT INTO 'dancesstepsmap' VALUES (24206, 18971, 3);
INSERT INTO 'dancesstepsmap' VALUES (24207, 18972, 1);
INSERT INTO 'dancesstepsmap' VALUES (24208, 18972, 2);
INSERT INTO 'dancesstepsmap' VALUES (24209, 18973, 1);
INSERT INTO 'dancesstepsmap' VALUES (24210, 18974, 5);
INSERT INTO 'dancesstepsmap' VALUES (24211, 18974, 4);
INSERT INTO 'dancesstepsmap' VALUES (24212, 18975, 5);
INSERT INTO 'dancesstepsmap' VALUES (24213, 18975, 4);
INSERT INTO 'dancesstepsmap' VALUES (24214, 18954, 4);
INSERT INTO 'dancesstepsmap' VALUES (24216, 18953, 4);
INSERT INTO 'dancesstepsmap' VALUES (24217, 18953, 5);
INSERT INTO 'dancesstepsmap' VALUES (24218, 18951, 1);
INSERT INTO 'dancesstepsmap' VALUES (24219, 18951, 2);
INSERT INTO 'dancesstepsmap' VALUES (24220, 10245, 2);
INSERT INTO 'dancesstepsmap' VALUES (24221, 10239, 5);
INSERT INTO 'dancesstepsmap' VALUES (24222, 18976, 1);
INSERT INTO 'dancesstepsmap' VALUES (24223, 18976, 2);
INSERT INTO 'dancesstepsmap' VALUES (24224, 18977, 4);
INSERT INTO 'dancesstepsmap' VALUES (24225, 18977, 5);
INSERT INTO 'dancesstepsmap' VALUES (24229, 19010, 1);
INSERT INTO 'dancesstepsmap' VALUES (24230, 19010, 2);
INSERT INTO 'dancesstepsmap' VALUES (24231, 19010, 3);
INSERT INTO 'dancesstepsmap' VALUES (24232, 18080, 5);
INSERT INTO 'dancesstepsmap' VALUES (24233, 18080, 4);
INSERT INTO 'dancesstepsmap' VALUES (24234, 18080, 9);
INSERT INTO 'dancesstepsmap' VALUES (24235, 9064, 1);
INSERT INTO 'dancesstepsmap' VALUES (24236, 9064, 2);
INSERT INTO 'dancesstepsmap' VALUES (24237, 10605, 4);
INSERT INTO 'dancesstepsmap' VALUES (24238, 10605, 5);
INSERT INTO 'dancesstepsmap' VALUES (24239, 12594, 5);
INSERT INTO 'dancesstepsmap' VALUES (24240, 18514, 4);
INSERT INTO 'dancesstepsmap' VALUES (24241, 18514, 5);
INSERT INTO 'dancesstepsmap' VALUES (24242, 19013, 1);
INSERT INTO 'dancesstepsmap' VALUES (24243, 19013, 2);
INSERT INTO 'dancesstepsmap' VALUES (24244, 19014, 1);
INSERT INTO 'dancesstepsmap' VALUES (24245, 19014, 3);
INSERT INTO 'dancesstepsmap' VALUES (24246, 19015, 1);
INSERT INTO 'dancesstepsmap' VALUES (24247, 19016, 1);
INSERT INTO 'dancesstepsmap' VALUES (24248, 19019, 1);
INSERT INTO 'dancesstepsmap' VALUES (24249, 19019, 4);
INSERT INTO 'dancesstepsmap' VALUES (24250, 19017, 1);
INSERT INTO 'dancesstepsmap' VALUES (24251, 19017, 2);
INSERT INTO 'dancesstepsmap' VALUES (24252, 19017, 4);
INSERT INTO 'dancesstepsmap' VALUES (24253, 19017, 5);
INSERT INTO 'dancesstepsmap' VALUES (24254, 19030, 1);
INSERT INTO 'dancesstepsmap' VALUES (24255, 19025, 4);
INSERT INTO 'dancesstepsmap' VALUES (24256, 19025, 5);
INSERT INTO 'dancesstepsmap' VALUES (24257, 19022, 1);
INSERT INTO 'dancesstepsmap' VALUES (24258, 19022, 3);
INSERT INTO 'dancesstepsmap' VALUES (24259, 19028, 1);
INSERT INTO 'dancesstepsmap' VALUES (24260, 19028, 3);
INSERT INTO 'dancesstepsmap' VALUES (24261, 19026, 4);
INSERT INTO 'dancesstepsmap' VALUES (24262, 19026, 5);
INSERT INTO 'dancesstepsmap' VALUES (24263, 19024, 1);
INSERT INTO 'dancesstepsmap' VALUES (24264, 19024, 2);
INSERT INTO 'dancesstepsmap' VALUES (24265, 19018, 4);
INSERT INTO 'dancesstepsmap' VALUES (24266, 19018, 5);
INSERT INTO 'dancesstepsmap' VALUES (24267, 7940, 5);
INSERT INTO 'dancesstepsmap' VALUES (23944, 18578, 4);
INSERT INTO 'dancesstepsmap' VALUES (23945, 18578, 5);
INSERT INTO 'dancesstepsmap' VALUES (24268, 19031, 1);
INSERT INTO 'dancesstepsmap' VALUES (24269, 19031, 2);
INSERT INTO 'dancesstepsmap' VALUES (24270, 2794, 3);
INSERT INTO 'dancesstepsmap' VALUES (24271, 6187, 5);
INSERT INTO 'dancesstepsmap' VALUES (24272, 19034, 1);
INSERT INTO 'dancesstepsmap' VALUES (24273, 19034, 2);
INSERT INTO 'dancesstepsmap' VALUES (24274, 19038, 1);
INSERT INTO 'dancesstepsmap' VALUES (24275, 19038, 2);
INSERT INTO 'dancesstepsmap' VALUES (24276, 17264, 1);
INSERT INTO 'dancesstepsmap' VALUES (24277, 17264, 2);
INSERT INTO 'dancesstepsmap' VALUES (21617, 17047, 4);
INSERT INTO 'dancesstepsmap' VALUES (21618, 17047, 5);
INSERT INTO 'dancesstepsmap' VALUES (24278, 15608, 1);
INSERT INTO 'dancesstepsmap' VALUES (21603, 17042, 5);
INSERT INTO 'dancesstepsmap' VALUES (21604, 17042, 1);
INSERT INTO 'dancesstepsmap' VALUES (21605, 17042, 2);
INSERT INTO 'dancesstepsmap' VALUES (24279, 6047, 5);
INSERT INTO 'dancesstepsmap' VALUES (24280, 9878, 5);
INSERT INTO 'dancesstepsmap' VALUES (24281, 5451, 5);
INSERT INTO 'dancesstepsmap' VALUES (24282, 5451, 4);
INSERT INTO 'dancesstepsmap' VALUES (24283, 5451, 1);
INSERT INTO 'dancesstepsmap' VALUES (24284, 5451, 2);
INSERT INTO 'dancesstepsmap' VALUES (24285, 12054, 2);
INSERT INTO 'dancesstepsmap' VALUES (24286, 19040, 1);
INSERT INTO 'dancesstepsmap' VALUES (24287, 19040, 3);
INSERT INTO 'dancesstepsmap' VALUES (24288, 19041, 1);
INSERT INTO 'dancesstepsmap' VALUES (24289, 19041, 2);
INSERT INTO 'dancesstepsmap' VALUES (24290, 19011, 2);
INSERT INTO 'dancesstepsmap' VALUES (24291, 19011, 3);
INSERT INTO 'dancesstepsmap' VALUES (24292, 19011, 1);
INSERT INTO 'dancesstepsmap' VALUES (24293, 8389, 2);
INSERT INTO 'dancesstepsmap' VALUES (23485, 16788, 4);
INSERT INTO 'dancesstepsmap' VALUES (24294, 16788, 5);
INSERT INTO 'dancesstepsmap' VALUES (24295, 6520, 2);
INSERT INTO 'dancesstepsmap' VALUES (24296, 6520, 3);
INSERT INTO 'dancesstepsmap' VALUES (24297, 19042, 4);
INSERT INTO 'dancesstepsmap' VALUES (24298, 12014, 2);
INSERT INTO 'dancesstepsmap' VALUES (24299, 18772, 2);
INSERT INTO 'dancesstepsmap' VALUES (24300, 18772, 1);
INSERT INTO 'dancesstepsmap' VALUES (24301, 19043, 1);
INSERT INTO 'dancesstepsmap' VALUES (24302, 19043, 2);
INSERT INTO 'dancesstepsmap' VALUES (24303, 1069, 5);
INSERT INTO 'dancesstepsmap' VALUES (24304, 2739, 3);
INSERT INTO 'dancesstepsmap' VALUES (24305, 2739, 2);
INSERT INTO 'dancesstepsmap' VALUES (24306, 13192, 2);
INSERT INTO 'dancesstepsmap' VALUES (24307, 17104, 1);
INSERT INTO 'dancesstepsmap' VALUES (24308, 17104, 2);
INSERT INTO 'dancesstepsmap' VALUES (24309, 18695, 1);
INSERT INTO 'dancesstepsmap' VALUES (24226, 18978, 4);
INSERT INTO 'dancesstepsmap' VALUES (24310, 18695, 2);
INSERT INTO 'dancesstepsmap' VALUES (24311, 18357, 1);
INSERT INTO 'dancesstepsmap' VALUES (24312, 18357, 2);
INSERT INTO 'dancesstepsmap' VALUES (24313, 18911, 1);
INSERT INTO 'dancesstepsmap' VALUES (24314, 18911, 2);
INSERT INTO 'dancesstepsmap' VALUES (24315, 18668, 1);
INSERT INTO 'dancesstepsmap' VALUES (24316, 917, 5);
INSERT INTO 'dancesstepsmap' VALUES (24317, 19049, 5);
INSERT INTO 'dancesstepsmap' VALUES (24318, 19049, 4);
INSERT INTO 'dancesstepsmap' VALUES (24319, 19050, 5);
INSERT INTO 'dancesstepsmap' VALUES (24320, 19050, 4);
INSERT INTO 'dancesstepsmap' VALUES (24321, 19051, 5);
INSERT INTO 'dancesstepsmap' VALUES (24322, 19051, 4);
INSERT INTO 'dancesstepsmap' VALUES (24323, 19052, 1);
INSERT INTO 'dancesstepsmap' VALUES (24324, 19032, 1);
INSERT INTO 'dancesstepsmap' VALUES (24325, 19032, 2);
INSERT INTO 'dancesstepsmap' VALUES (24326, 19032, 3);
INSERT INTO 'dancesstepsmap' VALUES (24327, 9478, 2);
INSERT INTO 'dancesstepsmap' VALUES (24328, 17107, 1);
INSERT INTO 'dancesstepsmap' VALUES (24329, 17107, 2);
INSERT INTO 'dancesstepsmap' VALUES (24330, 17107, 3);
INSERT INTO 'dancesstepsmap' VALUES (24331, 17108, 4);
INSERT INTO 'dancesstepsmap' VALUES (24332, 17108, 5);
INSERT INTO 'dancesstepsmap' VALUES (24333, 19053, 5);
INSERT INTO 'dancesstepsmap' VALUES (24334, 19053, 4);
INSERT INTO 'dancesstepsmap' VALUES (24335, 19053, 6);
INSERT INTO 'dancesstepsmap' VALUES (24336, 17116, 4);
INSERT INTO 'dancesstepsmap' VALUES (24338, 17116, 1);
INSERT INTO 'dancesstepsmap' VALUES (24339, 17116, 2);
INSERT INTO 'dancesstepsmap' VALUES (24340, 17116, 3);
INSERT INTO 'dancesstepsmap' VALUES (24341, 7387, 2);
INSERT INTO 'dancesstepsmap' VALUES (24342, 19054, 5);
INSERT INTO 'dancesstepsmap' VALUES (24343, 19054, 4);
INSERT INTO 'dancesstepsmap' VALUES (24344, 19055, 1);
INSERT INTO 'dancesstepsmap' VALUES (24345, 19055, 2);
INSERT INTO 'dancesstepsmap' VALUES (24346, 19057, 5);
INSERT INTO 'dancesstepsmap' VALUES (24347, 19057, 4);
INSERT INTO 'dancesstepsmap' VALUES (24348, 12928, 1);
INSERT INTO 'dancesstepsmap' VALUES (24349, 12928, 2);
INSERT INTO 'dancesstepsmap' VALUES (24350, 308, 2);
INSERT INTO 'dancesstepsmap' VALUES (24351, 14471, 5);
INSERT INTO 'dancesstepsmap' VALUES (24352, 14471, 4);
INSERT INTO 'dancesstepsmap' VALUES (22028, 17536, 1);
INSERT INTO 'dancesstepsmap' VALUES (22029, 17536, 2);
INSERT INTO 'dancesstepsmap' VALUES (24353, 18398, 1);
INSERT INTO 'dancesstepsmap' VALUES (24354, 9380, 2);
INSERT INTO 'dancesstepsmap' VALUES (24355, 2432, 2);
INSERT INTO 'dancesstepsmap' VALUES (24356, 14971, 5);
INSERT INTO 'dancesstepsmap' VALUES (24357, 14971, 4);
INSERT INTO 'dancesstepsmap' VALUES (24358, 17314, 2);
INSERT INTO 'dancesstepsmap' VALUES (24359, 17314, 1);
INSERT INTO 'dancesstepsmap' VALUES (24360, 19058, 1);
INSERT INTO 'dancesstepsmap' VALUES (24361, 19058, 3);
INSERT INTO 'dancesstepsmap' VALUES (24362, 17434, 1);
INSERT INTO 'dancesstepsmap' VALUES (24363, 17434, 2);
INSERT INTO 'dancesstepsmap' VALUES (24364, 17434, 3);
INSERT INTO 'dancesstepsmap' VALUES (24365, 17441, 4);
INSERT INTO 'dancesstepsmap' VALUES (24366, 17441, 5);
INSERT INTO 'dancesstepsmap' VALUES (24367, 17454, 4);
INSERT INTO 'dancesstepsmap' VALUES (24368, 17454, 5);
INSERT INTO 'dancesstepsmap' VALUES (24369, 17452, 1);
INSERT INTO 'dancesstepsmap' VALUES (24370, 17452, 2);
INSERT INTO 'dancesstepsmap' VALUES (24371, 17452, 3);
INSERT INTO 'dancesstepsmap' VALUES (24372, 7503, 5);
INSERT INTO 'dancesstepsmap' VALUES (24373, 17450, 1);
INSERT INTO 'dancesstepsmap' VALUES (24374, 17450, 3);
INSERT INTO 'dancesstepsmap' VALUES (24375, 13296, 5);
INSERT INTO 'dancesstepsmap' VALUES (24376, 13296, 4);
INSERT INTO 'dancesstepsmap' VALUES (24377, 17449, 1);
INSERT INTO 'dancesstepsmap' VALUES (24378, 17449, 2);
INSERT INTO 'dancesstepsmap' VALUES (24379, 17449, 3);
INSERT INTO 'dancesstepsmap' VALUES (24380, 17448, 4);
INSERT INTO 'dancesstepsmap' VALUES (24381, 17448, 5);
INSERT INTO 'dancesstepsmap' VALUES (24382, 17447, 1);
INSERT INTO 'dancesstepsmap' VALUES (24383, 17447, 2);
INSERT INTO 'dancesstepsmap' VALUES (24384, 17447, 3);
INSERT INTO 'dancesstepsmap' VALUES (24385, 17446, 4);
INSERT INTO 'dancesstepsmap' VALUES (24386, 17446, 5);
INSERT INTO 'dancesstepsmap' VALUES (24392, 19067, 5);
INSERT INTO 'dancesstepsmap' VALUES (24393, 19067, 4);
INSERT INTO 'dancesstepsmap' VALUES (24394, 19067, 10);
INSERT INTO 'dancesstepsmap' VALUES (24395, 19067, 2);
INSERT INTO 'dancesstepsmap' VALUES (24396, 19067, 1);
INSERT INTO 'dancesstepsmap' VALUES (24397, 19068, 1);
INSERT INTO 'dancesstepsmap' VALUES (24398, 19068, 3);
INSERT INTO 'dancesstepsmap' VALUES (24399, 19069, 2);
INSERT INTO 'dancesstepsmap' VALUES (24400, 19069, 1);
INSERT INTO 'dancesstepsmap' VALUES (24401, 19070, 4);
INSERT INTO 'dancesstepsmap' VALUES (24402, 19071, 2);
INSERT INTO 'dancesstepsmap' VALUES (24403, 19071, 1);
INSERT INTO 'dancesstepsmap' VALUES (24404, 19072, 2);
INSERT INTO 'dancesstepsmap' VALUES (24405, 19072, 1);
INSERT INTO 'dancesstepsmap' VALUES (24408, 19074, 5);
INSERT INTO 'dancesstepsmap' VALUES (24409, 19074, 4);
INSERT INTO 'dancesstepsmap' VALUES (24410, 19086, 3);
INSERT INTO 'dancesstepsmap' VALUES (24411, 19086, 1);
INSERT INTO 'dancesstepsmap' VALUES (24412, 19087, 2);
INSERT INTO 'dancesstepsmap' VALUES (24413, 19087, 1);
INSERT INTO 'dancesstepsmap' VALUES (24414, 19087, 3);
INSERT INTO 'dancesstepsmap' VALUES (24415, 19088, 4);
INSERT INTO 'dancesstepsmap' VALUES (24416, 19089, 5);
INSERT INTO 'dancesstepsmap' VALUES (24417, 19089, 4);
INSERT INTO 'dancesstepsmap' VALUES (24418, 19090, 2);
INSERT INTO 'dancesstepsmap' VALUES (24419, 19090, 1);
INSERT INTO 'dancesstepsmap' VALUES (24420, 19091, 5);
INSERT INTO 'dancesstepsmap' VALUES (24421, 19091, 4);
INSERT INTO 'dancesstepsmap' VALUES (24422, 19092, 5);
INSERT INTO 'dancesstepsmap' VALUES (24423, 19092, 4);
INSERT INTO 'dancesstepsmap' VALUES (24424, 19093, 2);
INSERT INTO 'dancesstepsmap' VALUES (24425, 19093, 1);
INSERT INTO 'dancesstepsmap' VALUES (24426, 19096, 5);
INSERT INTO 'dancesstepsmap' VALUES (24427, 19096, 4);
INSERT INTO 'dancesstepsmap' VALUES (24428, 19097, 2);
INSERT INTO 'dancesstepsmap' VALUES (24429, 19097, 1);
INSERT INTO 'dancesstepsmap' VALUES (24430, 19098, 2);
INSERT INTO 'dancesstepsmap' VALUES (24431, 19098, 1);
INSERT INTO 'dancesstepsmap' VALUES (24432, 19099, 1);
INSERT INTO 'dancesstepsmap' VALUES (24433, 19099, 3);
INSERT INTO 'dancesstepsmap' VALUES (24434, 19100, 5);
INSERT INTO 'dancesstepsmap' VALUES (24435, 19100, 4);
INSERT INTO 'dancesstepsmap' VALUES (24436, 19101, 1);
INSERT INTO 'dancesstepsmap' VALUES (24437, 19102, 5);
INSERT INTO 'dancesstepsmap' VALUES (24438, 19102, 4);
INSERT INTO 'dancesstepsmap' VALUES (24439, 19102, 2);
INSERT INTO 'dancesstepsmap' VALUES (24440, 19102, 1);
INSERT INTO 'dancesstepsmap' VALUES (24441, 19102, 3);
INSERT INTO 'dancesstepsmap' VALUES (24444, 19033, 1);
INSERT INTO 'dancesstepsmap' VALUES (24445, 19033, 2);
INSERT INTO 'dancesstepsmap' VALUES (24446, 19033, 3);
INSERT INTO 'dancesstepsmap' VALUES (24451, 19105, 5);
INSERT INTO 'dancesstepsmap' VALUES (24452, 19105, 4);
INSERT INTO 'dancesstepsmap' VALUES (24453, 19114, 4);
INSERT INTO 'dancesstepsmap' VALUES (24454, 19114, 5);
INSERT INTO 'dancesstepsmap' VALUES (24455, 19115, 1);
INSERT INTO 'dancesstepsmap' VALUES (24456, 19115, 3);
INSERT INTO 'dancesstepsmap' VALUES (24457, 19116, 4);
INSERT INTO 'dancesstepsmap' VALUES (24458, 19116, 5);
INSERT INTO 'dancesstepsmap' VALUES (13848, 264, 2);
INSERT INTO 'dancesstepsmap' VALUES (24461, 264, 3);
INSERT INTO 'dancesstepsmap' VALUES (24462, 2657, 3);
INSERT INTO 'dancesstepsmap' VALUES (24459, 19117, 4);
INSERT INTO 'dancesstepsmap' VALUES (24460, 19117, 5);
INSERT INTO 'dancesstepsmap' VALUES (24449, 19104, 1);
INSERT INTO 'dancesstepsmap' VALUES (24450, 19104, 2);
INSERT INTO 'dancesstepsmap' VALUES (24447, 19103, 1);
INSERT INTO 'dancesstepsmap' VALUES (24448, 19103, 2);
INSERT INTO 'dancesstepsmap' VALUES (24463, 17979, 4);
INSERT INTO 'dancesstepsmap' VALUES (24464, 17979, 5);
INSERT INTO 'dancesstepsmap' VALUES (24465, 19118, 1);
INSERT INTO 'dancesstepsmap' VALUES (24466, 19118, 2);
INSERT INTO 'dancesstepsmap' VALUES (24467, 19112, 4);
INSERT INTO 'dancesstepsmap' VALUES (24468, 19112, 5);
INSERT INTO 'dancesstepsmap' VALUES (24469, 19111, 1);
INSERT INTO 'dancesstepsmap' VALUES (24470, 19111, 2);
INSERT INTO 'dancesstepsmap' VALUES (24471, 19111, 3);
INSERT INTO 'dancesstepsmap' VALUES (24472, 19109, 1);
INSERT INTO 'dancesstepsmap' VALUES (24473, 19109, 2);
INSERT INTO 'dancesstepsmap' VALUES (24474, 19113, 1);
INSERT INTO 'dancesstepsmap' VALUES (24475, 19113, 2);
INSERT INTO 'dancesstepsmap' VALUES (24476, 19113, 3);
INSERT INTO 'dancesstepsmap' VALUES (24477, 13812, 3);
INSERT INTO 'dancesstepsmap' VALUES (24478, 19119, 4);
INSERT INTO 'dancesstepsmap' VALUES (24479, 19119, 5);
INSERT INTO 'dancesstepsmap' VALUES (24480, 19120, 1);
INSERT INTO 'dancesstepsmap' VALUES (24481, 19120, 2);
INSERT INTO 'dancesstepsmap' VALUES (24485, 19122, 1);
INSERT INTO 'dancesstepsmap' VALUES (24486, 19122, 2);
INSERT INTO 'dancesstepsmap' VALUES (24487, 19122, 3);
INSERT INTO 'dancesstepsmap' VALUES (24488, 19123, 4);
INSERT INTO 'dancesstepsmap' VALUES (24489, 19123, 5);
INSERT INTO 'dancesstepsmap' VALUES (24490, 16169, 2);
INSERT INTO 'dancesstepsmap' VALUES (24491, 16169, 1);
INSERT INTO 'dancesstepsmap' VALUES (24492, 16169, 3);
INSERT INTO 'dancesstepsmap' VALUES (24493, 19106, 1);
INSERT INTO 'dancesstepsmap' VALUES (24494, 19106, 2);
INSERT INTO 'dancesstepsmap' VALUES (24495, 19124, 2);
INSERT INTO 'dancesstepsmap' VALUES (24496, 19124, 1);
INSERT INTO 'dancesstepsmap' VALUES (24497, 12866, 2);
INSERT INTO 'dancesstepsmap' VALUES (24498, 76, 2);
INSERT INTO 'dancesstepsmap' VALUES (24499, 171, 2);
INSERT INTO 'dancesstepsmap' VALUES (24500, 192, 2);
INSERT INTO 'dancesstepsmap' VALUES (24390, 19066, 1);
INSERT INTO 'dancesstepsmap' VALUES (24391, 19066, 2);
INSERT INTO 'dancesstepsmap' VALUES (24406, 19073, 4);
INSERT INTO 'dancesstepsmap' VALUES (24407, 19073, 5);
INSERT INTO 'dancesstepsmap' VALUES (24442, 15499, 4);
INSERT INTO 'dancesstepsmap' VALUES (24443, 15499, 5);
INSERT INTO 'dancesstepsmap' VALUES (24501, 7343, 2);
INSERT INTO 'dancesstepsmap' VALUES (24502, 9769, 2);
INSERT INTO 'dancesstepsmap' VALUES (24503, 557, 2);
INSERT INTO 'dancesstepsmap' VALUES (24504, 9562, 2);
INSERT INTO 'dancesstepsmap' VALUES (24505, 8529, 2);
INSERT INTO 'dancesstepsmap' VALUES (24506, 585, 2);
INSERT INTO 'dancesstepsmap' VALUES (24507, 685, 2);
INSERT INTO 'dancesstepsmap' VALUES (24508, 715, 2);
INSERT INTO 'dancesstepsmap' VALUES (24509, 739, 2);
INSERT INTO 'dancesstepsmap' VALUES (24510, 774, 2);
INSERT INTO 'dancesstepsmap' VALUES (24511, 15492, 4);
INSERT INTO 'dancesstepsmap' VALUES (24512, 15492, 5);
INSERT INTO 'dancesstepsmap' VALUES (24513, 15493, 4);
INSERT INTO 'dancesstepsmap' VALUES (24514, 15493, 5);
INSERT INTO 'dancesstepsmap' VALUES (24515, 15495, 4);
INSERT INTO 'dancesstepsmap' VALUES (24516, 15495, 5);
INSERT INTO 'dancesstepsmap' VALUES (24517, 19125, 3);
INSERT INTO 'dancesstepsmap' VALUES (24518, 19125, 2);
INSERT INTO 'dancesstepsmap' VALUES (24519, 19125, 1);
INSERT INTO 'dancesstepsmap' VALUES (24520, 19126, 4);
INSERT INTO 'dancesstepsmap' VALUES (24521, 19127, 4);
INSERT INTO 'dancesstepsmap' VALUES (24522, 19127, 5);
INSERT INTO 'dancesstepsmap' VALUES (24523, 19128, 1);
INSERT INTO 'dancesstepsmap' VALUES (24524, 19128, 2);
INSERT INTO 'dancesstepsmap' VALUES (24525, 18711, 5);
INSERT INTO 'dancesstepsmap' VALUES (24526, 18711, 4);
INSERT INTO 'dancesstepsmap' VALUES (24527, 18841, 1);
INSERT INTO 'dancesstepsmap' VALUES (24528, 18841, 3);
INSERT INTO 'dancesstepsmap' VALUES (24530, 18910, 1);
INSERT INTO 'dancesstepsmap' VALUES (24531, 18910, 2);
INSERT INTO 'dancesstepsmap' VALUES (24532, 7326, 5);
INSERT INTO 'dancesstepsmap' VALUES (24533, 19107, 2);
INSERT INTO 'dancesstepsmap' VALUES (24534, 19107, 1);
INSERT INTO 'dancesstepsmap' VALUES (24535, 11015, 1);
INSERT INTO 'dancesstepsmap' VALUES (24538, 11019, 1);
INSERT INTO 'dancesstepsmap' VALUES (24539, 11019, 2);
INSERT INTO 'dancesstepsmap' VALUES (24540, 11021, 1);
INSERT INTO 'dancesstepsmap' VALUES (24541, 11021, 2);
INSERT INTO 'dancesstepsmap' VALUES (24542, 11022, 1);
INSERT INTO 'dancesstepsmap' VALUES (24543, 11022, 2);
INSERT INTO 'dancesstepsmap' VALUES (24544, 19129, 4);
INSERT INTO 'dancesstepsmap' VALUES (24545, 19129, 5);
INSERT INTO 'dancesstepsmap' VALUES (24546, 11023, 4);
INSERT INTO 'dancesstepsmap' VALUES (24547, 11024, 4);
INSERT INTO 'dancesstepsmap' VALUES (24548, 11024, 5);
INSERT INTO 'dancesstepsmap' VALUES (24549, 11025, 1);
INSERT INTO 'dancesstepsmap' VALUES (24550, 11025, 2);
INSERT INTO 'dancesstepsmap' VALUES (24551, 11026, 4);
INSERT INTO 'dancesstepsmap' VALUES (24552, 11028, 1);
INSERT INTO 'dancesstepsmap' VALUES (24553, 11028, 2);
INSERT INTO 'dancesstepsmap' VALUES (24554, 10040, 1);
INSERT INTO 'dancesstepsmap' VALUES (24555, 10040, 2);
INSERT INTO 'dancesstepsmap' VALUES (24556, 11929, 2);
INSERT INTO 'dancesstepsmap' VALUES (24557, 17937, 1);
INSERT INTO 'dancesstepsmap' VALUES (24558, 17937, 3);
INSERT INTO 'dancesstepsmap' VALUES (24559, 7892, 2);
INSERT INTO 'dancesstepsmap' VALUES (24560, 7892, 10);
INSERT INTO 'dancesstepsmap' VALUES (24561, 7421, 2);
INSERT INTO 'dancesstepsmap' VALUES (24562, 7421, 3);
INSERT INTO 'dancesstepsmap' VALUES (24563, 11020, 5);
INSERT INTO 'dancesstepsmap' VALUES (24564, 11020, 4);
INSERT INTO 'dancesstepsmap' VALUES (24565, 11020, 1);
INSERT INTO 'dancesstepsmap' VALUES (24566, 11020, 2);
INSERT INTO 'dancesstepsmap' VALUES (24567, 15482, 1);
INSERT INTO 'dancesstepsmap' VALUES (24568, 15482, 2);
INSERT INTO 'dancesstepsmap' VALUES (24387, 19065, 1);
INSERT INTO 'dancesstepsmap' VALUES (24388, 19065, 2);
INSERT INTO 'dancesstepsmap' VALUES (24389, 19065, 3);
INSERT INTO 'dancesstepsmap' VALUES (24569, 13790, 3);
INSERT INTO 'dancesstepsmap' VALUES (24570, 18734, 4);
INSERT INTO 'dancesstepsmap' VALUES (24571, 18734, 5);
INSERT INTO 'dancesstepsmap' VALUES (24572, 19108, 1);
INSERT INTO 'dancesstepsmap' VALUES (24573, 19108, 3);
INSERT INTO 'dancesstepsmap' VALUES (24574, 19130, 4);
INSERT INTO 'dancesstepsmap' VALUES (24575, 19130, 5);
INSERT INTO 'dancesstepsmap' VALUES (24576, 19131, 99);
INSERT INTO 'dancesstepsmap' VALUES (24577, 18211, 2);
INSERT INTO 'dancesstepsmap' VALUES (24578, 18211, 1);
INSERT INTO 'dancesstepsmap' VALUES (24579, 18213, 5);
INSERT INTO 'dancesstepsmap' VALUES (24580, 18213, 4);
INSERT INTO 'dancesstepsmap' VALUES (24581, 18217, 2);
INSERT INTO 'dancesstepsmap' VALUES (24529, 18841, 2);
INSERT INTO 'dancesstepsmap' VALUES (24582, 18217, 1);
INSERT INTO 'dancesstepsmap' VALUES (24583, 9476, 2);
INSERT INTO 'dancesstepsmap' VALUES (24584, 1613, 2);
INSERT INTO 'dancesstepsmap' VALUES (24585, 14020, 4);
INSERT INTO 'dancesstepsmap' VALUES (24586, 14020, 1);
INSERT INTO 'dancesstepsmap' VALUES (24587, 19110, 5);
INSERT INTO 'dancesstepsmap' VALUES (24588, 19110, 4);
INSERT INTO 'dancesstepsmap' VALUES (24589, 1470, 2);
INSERT INTO 'dancesstepsmap' VALUES (24590, 19037, 5);
INSERT INTO 'dancesstepsmap' VALUES (24591, 19037, 4);
INSERT INTO 'dancesstepsmap' VALUES (24592, 19133, 1);
INSERT INTO 'dancesstepsmap' VALUES (24593, 19133, 2);
INSERT INTO 'dancesstepsmap' VALUES (24594, 12344, 1);
INSERT INTO 'dancesstepsmap' VALUES (24595, 12344, 2);
INSERT INTO 'dancesstepsmap' VALUES (24596, 12343, 1);
INSERT INTO 'dancesstepsmap' VALUES (24597, 14443, 4);
INSERT INTO 'dancesstepsmap' VALUES (24598, 14443, 5);
INSERT INTO 'dancesstepsmap' VALUES (24599, 14449, 1);
INSERT INTO 'dancesstepsmap' VALUES (24600, 14449, 2);
INSERT INTO 'dancesstepsmap' VALUES (24601, 14450, 4);
INSERT INTO 'dancesstepsmap' VALUES (24602, 14450, 5);
INSERT INTO 'dancesstepsmap' VALUES (24603, 14451, 1);
INSERT INTO 'dancesstepsmap' VALUES (24604, 14451, 2);
INSERT INTO 'dancesstepsmap' VALUES (24605, 14451, 3);
INSERT INTO 'dancesstepsmap' VALUES (24606, 2484, 2);
INSERT INTO 'dancesstepsmap' VALUES (24607, 13865, 2);
INSERT INTO 'dancesstepsmap' VALUES (24608, 13865, 1);
INSERT INTO 'dancesstepsmap' VALUES (24609, 14452, 1);
INSERT INTO 'dancesstepsmap' VALUES (24610, 14452, 2);
INSERT INTO 'dancesstepsmap' VALUES (24611, 14441, 1);
INSERT INTO 'dancesstepsmap' VALUES (24612, 14441, 2);
INSERT INTO 'dancesstepsmap' VALUES (24613, 14441, 3);
INSERT INTO 'dancesstepsmap' VALUES (24614, 13637, 4);
INSERT INTO 'dancesstepsmap' VALUES (24615, 14459, 1);
INSERT INTO 'dancesstepsmap' VALUES (24616, 14459, 2);
INSERT INTO 'dancesstepsmap' VALUES (24617, 14459, 3);
INSERT INTO 'dancesstepsmap' VALUES (24618, 14445, 1);
INSERT INTO 'dancesstepsmap' VALUES (24619, 14445, 3);
INSERT INTO 'dancesstepsmap' VALUES (24620, 2284, 2);
INSERT INTO 'dancesstepsmap' VALUES (24621, 18946, 1);
INSERT INTO 'dancesstepsmap' VALUES (24622, 19134, 2);
INSERT INTO 'dancesstepsmap' VALUES (24623, 19134, 1);
INSERT INTO 'dancesstepsmap' VALUES (24624, 19135, 5);
INSERT INTO 'dancesstepsmap' VALUES (24625, 19135, 4);
INSERT INTO 'dancesstepsmap' VALUES (24626, 18941, 2);
INSERT INTO 'dancesstepsmap' VALUES (24627, 18941, 1);
INSERT INTO 'dancesstepsmap' VALUES (24628, 18655, 5);
INSERT INTO 'dancesstepsmap' VALUES (24629, 18655, 4);
INSERT INTO 'dancesstepsmap' VALUES (24630, 19142, 1);
INSERT INTO 'dancesstepsmap' VALUES (24631, 7261, 5);
INSERT INTO 'dancesstepsmap' VALUES (24632, 6326, 2);
INSERT INTO 'dancesstepsmap' VALUES (24633, 4586, 5);
INSERT INTO 'dancesstepsmap' VALUES (24634, 4586, 6);
INSERT INTO 'dancesstepsmap' VALUES (24635, 14448, 1);
INSERT INTO 'dancesstepsmap' VALUES (24636, 14448, 2);
INSERT INTO 'dancesstepsmap' VALUES (24637, 14442, 1);
INSERT INTO 'dancesstepsmap' VALUES (24638, 14442, 2);
INSERT INTO 'dancesstepsmap' VALUES (24639, 14442, 3);
INSERT INTO 'dancesstepsmap' VALUES (24640, 4286, 6);
INSERT INTO 'dancesstepsmap' VALUES (24641, 19143, 1);
INSERT INTO 'dancesstepsmap' VALUES (24642, 19143, 2);
INSERT INTO 'dancesstepsmap' VALUES (24643, 19144, 1);
INSERT INTO 'dancesstepsmap' VALUES (24647, 14187, 1);
INSERT INTO 'dancesstepsmap' VALUES (24648, 14187, 2);
INSERT INTO 'dancesstepsmap' VALUES (24649, 3583, 2);
INSERT INTO 'dancesstepsmap' VALUES (24650, 4924, 2);
INSERT INTO 'dancesstepsmap' VALUES (24651, 2805, 2);
INSERT INTO 'dancesstepsmap' VALUES (24652, 17324, 3);
INSERT INTO 'dancesstepsmap' VALUES (24653, 17324, 1);
INSERT INTO 'dancesstepsmap' VALUES (24654, 19145, 1);
INSERT INTO 'dancesstepsmap' VALUES (24655, 19146, 5);
INSERT INTO 'dancesstepsmap' VALUES (24656, 19146, 4);
INSERT INTO 'dancesstepsmap' VALUES (24657, 19147, 5);
INSERT INTO 'dancesstepsmap' VALUES (24658, 19147, 4);
INSERT INTO 'dancesstepsmap' VALUES (24659, 19148, 1);
INSERT INTO 'dancesstepsmap' VALUES (24660, 19148, 3);
INSERT INTO 'dancesstepsmap' VALUES (24661, 19149, 2);
INSERT INTO 'dancesstepsmap' VALUES (24662, 19149, 3);
INSERT INTO 'dancesstepsmap' VALUES (24663, 19149, 1);
INSERT INTO 'dancesstepsmap' VALUES (24664, 19150, 4);
INSERT INTO 'dancesstepsmap' VALUES (24665, 19151, 5);
INSERT INTO 'dancesstepsmap' VALUES (24666, 19151, 4);
INSERT INTO 'dancesstepsmap' VALUES (24667, 19152, 5);
INSERT INTO 'dancesstepsmap' VALUES (24668, 19152, 4);
INSERT INTO 'dancesstepsmap' VALUES (24669, 19153, 5);
INSERT INTO 'dancesstepsmap' VALUES (24670, 19153, 4);
INSERT INTO 'dancesstepsmap' VALUES (24671, 19154, 1);
INSERT INTO 'dancesstepsmap' VALUES (24672, 19155, 4);
INSERT INTO 'dancesstepsmap' VALUES (24673, 19156, 2);
INSERT INTO 'dancesstepsmap' VALUES (24674, 19156, 3);
INSERT INTO 'dancesstepsmap' VALUES (24675, 19156, 1);
INSERT INTO 'dancesstepsmap' VALUES (24676, 19157, 4);
INSERT INTO 'dancesstepsmap' VALUES (24677, 19158, 5);
INSERT INTO 'dancesstepsmap' VALUES (24678, 19158, 4);
INSERT INTO 'dancesstepsmap' VALUES (24679, 19159, 2);
INSERT INTO 'dancesstepsmap' VALUES (24680, 19159, 1);
INSERT INTO 'dancesstepsmap' VALUES (24681, 19159, 3);
INSERT INTO 'dancesstepsmap' VALUES (24682, 19160, 4);
INSERT INTO 'dancesstepsmap' VALUES (24683, 19161, 4);
INSERT INTO 'dancesstepsmap' VALUES (24684, 19162, 4);
INSERT INTO 'dancesstepsmap' VALUES (24685, 19163, 5);
INSERT INTO 'dancesstepsmap' VALUES (24686, 19163, 4);
INSERT INTO 'dancesstepsmap' VALUES (24687, 19164, 5);
INSERT INTO 'dancesstepsmap' VALUES (24688, 19164, 4);
INSERT INTO 'dancesstepsmap' VALUES (24689, 19165, 1);
INSERT INTO 'dancesstepsmap' VALUES (24690, 19166, 4);
INSERT INTO 'dancesstepsmap' VALUES (24691, 19166, 5);
INSERT INTO 'dancesstepsmap' VALUES (24692, 19167, 1);
INSERT INTO 'dancesstepsmap' VALUES (24693, 19167, 2);
INSERT INTO 'dancesstepsmap' VALUES (24694, 19168, 4);
INSERT INTO 'dancesstepsmap' VALUES (24695, 19168, 5);
INSERT INTO 'dancesstepsmap' VALUES (24696, 19169, 4);
INSERT INTO 'dancesstepsmap' VALUES (24697, 19169, 5);
INSERT INTO 'dancesstepsmap' VALUES (24698, 14620, 4);
INSERT INTO 'dancesstepsmap' VALUES (24699, 14620, 5);
INSERT INTO 'dancesstepsmap' VALUES (24700, 19094, 1);
INSERT INTO 'dancesstepsmap' VALUES (24701, 19094, 2);
INSERT INTO 'dancesstepsmap' VALUES (24702, 19094, 3);
INSERT INTO 'dancesstepsmap' VALUES (24703, 16615, 2);
INSERT INTO 'dancesstepsmap' VALUES (24704, 16615, 1);
INSERT INTO 'dancesstepsmap' VALUES (24705, 16835, 1);
INSERT INTO 'dancesstepsmap' VALUES (24706, 2656, 5);
INSERT INTO 'dancesstepsmap' VALUES (24707, 9284, 1);
INSERT INTO 'dancesstepsmap' VALUES (24708, 9284, 2);
INSERT INTO 'dancesstepsmap' VALUES (24709, 9284, 3);
INSERT INTO 'dancesstepsmap' VALUES (24710, 9282, 4);
INSERT INTO 'dancesstepsmap' VALUES (24711, 9282, 5);
INSERT INTO 'dancesstepsmap' VALUES (24712, 10170, 2);
INSERT INTO 'dancesstepsmap' VALUES (24713, 18164, 4);
INSERT INTO 'dancesstepsmap' VALUES (24714, 18164, 5);
INSERT INTO 'dancesstepsmap' VALUES (24715, 424, 2);
INSERT INTO 'dancesstepsmap' VALUES (24716, 15484, 1);
INSERT INTO 'dancesstepsmap' VALUES (24717, 15484, 2);
INSERT INTO 'dancesstepsmap' VALUES (24718, 15485, 1);
INSERT INTO 'dancesstepsmap' VALUES (24719, 15485, 2);
INSERT INTO 'dancesstepsmap' VALUES (24720, 15485, 3);
INSERT INTO 'dancesstepsmap' VALUES (24721, 15486, 1);
INSERT INTO 'dancesstepsmap' VALUES (24722, 15486, 2);
INSERT INTO 'dancesstepsmap' VALUES (24723, 15487, 1);
INSERT INTO 'dancesstepsmap' VALUES (24724, 15487, 2);
INSERT INTO 'dancesstepsmap' VALUES (24725, 15488, 1);
INSERT INTO 'dancesstepsmap' VALUES (24726, 15488, 2);
INSERT INTO 'dancesstepsmap' VALUES (24727, 15489, 1);
INSERT INTO 'dancesstepsmap' VALUES (24728, 15489, 2);
INSERT INTO 'dancesstepsmap' VALUES (24729, 15490, 1);
INSERT INTO 'dancesstepsmap' VALUES (24730, 15490, 2);
INSERT INTO 'dancesstepsmap' VALUES (24731, 15491, 1);
INSERT INTO 'dancesstepsmap' VALUES (24732, 15491, 2);
INSERT INTO 'dancesstepsmap' VALUES (24733, 15496, 4);
INSERT INTO 'dancesstepsmap' VALUES (24734, 15496, 5);
INSERT INTO 'dancesstepsmap' VALUES (24735, 15497, 4);
INSERT INTO 'dancesstepsmap' VALUES (24736, 15497, 5);
INSERT INTO 'dancesstepsmap' VALUES (24737, 15498, 4);
INSERT INTO 'dancesstepsmap' VALUES (24738, 15498, 5);
INSERT INTO 'dancesstepsmap' VALUES (24739, 15500, 4);
INSERT INTO 'dancesstepsmap' VALUES (24740, 15500, 5);
INSERT INTO 'dancesstepsmap' VALUES (24741, 15501, 4);
INSERT INTO 'dancesstepsmap' VALUES (24742, 15501, 5);
INSERT INTO 'dancesstepsmap' VALUES (24743, 15502, 4);
INSERT INTO 'dancesstepsmap' VALUES (24744, 15502, 5);
INSERT INTO 'dancesstepsmap' VALUES (24745, 15503, 4);
INSERT INTO 'dancesstepsmap' VALUES (24746, 15503, 5);
INSERT INTO 'dancesstepsmap' VALUES (24747, 15504, 4);
INSERT INTO 'dancesstepsmap' VALUES (24748, 15504, 5);
INSERT INTO 'dancesstepsmap' VALUES (24749, 15505, 4);
INSERT INTO 'dancesstepsmap' VALUES (24750, 15505, 5);
INSERT INTO 'dancesstepsmap' VALUES (24751, 15506, 4);
INSERT INTO 'dancesstepsmap' VALUES (24752, 15506, 5);
INSERT INTO 'dancesstepsmap' VALUES (24753, 15507, 4);
INSERT INTO 'dancesstepsmap' VALUES (24754, 15507, 5);
INSERT INTO 'dancesstepsmap' VALUES (24755, 15508, 1);
INSERT INTO 'dancesstepsmap' VALUES (24756, 15508, 2);
INSERT INTO 'dancesstepsmap' VALUES (24757, 15508, 3);
INSERT INTO 'dancesstepsmap' VALUES (24758, 15509, 1);
INSERT INTO 'dancesstepsmap' VALUES (24759, 15509, 2);
INSERT INTO 'dancesstepsmap' VALUES (24760, 15510, 1);
INSERT INTO 'dancesstepsmap' VALUES (24761, 15510, 2);
INSERT INTO 'dancesstepsmap' VALUES (24762, 15511, 1);
INSERT INTO 'dancesstepsmap' VALUES (24763, 15512, 1);
INSERT INTO 'dancesstepsmap' VALUES (24764, 15512, 2);
INSERT INTO 'dancesstepsmap' VALUES (24765, 15513, 1);
INSERT INTO 'dancesstepsmap' VALUES (24766, 15513, 2);
INSERT INTO 'dancesstepsmap' VALUES (24767, 15514, 1);
INSERT INTO 'dancesstepsmap' VALUES (24768, 15514, 2);
INSERT INTO 'dancesstepsmap' VALUES (24769, 15515, 1);
INSERT INTO 'dancesstepsmap' VALUES (24770, 15515, 2);
INSERT INTO 'dancesstepsmap' VALUES (24771, 15515, 3);
INSERT INTO 'dancesstepsmap' VALUES (24772, 15516, 1);
INSERT INTO 'dancesstepsmap' VALUES (24773, 15516, 2);
INSERT INTO 'dancesstepsmap' VALUES (24774, 15516, 3);
INSERT INTO 'dancesstepsmap' VALUES (24775, 15517, 1);
INSERT INTO 'dancesstepsmap' VALUES (24776, 15517, 2);
INSERT INTO 'dancesstepsmap' VALUES (24777, 15518, 1);
INSERT INTO 'dancesstepsmap' VALUES (24778, 15518, 3);
INSERT INTO 'dancesstepsmap' VALUES (24779, 15519, 1);
INSERT INTO 'dancesstepsmap' VALUES (24780, 15519, 2);
INSERT INTO 'dancesstepsmap' VALUES (24781, 15519, 3);
INSERT INTO 'dancesstepsmap' VALUES (24782, 15520, 1);
INSERT INTO 'dancesstepsmap' VALUES (24783, 15520, 2);
INSERT INTO 'dancesstepsmap' VALUES (24784, 15521, 1);
INSERT INTO 'dancesstepsmap' VALUES (24785, 15521, 2);
INSERT INTO 'dancesstepsmap' VALUES (24786, 15521, 3);
INSERT INTO 'dancesstepsmap' VALUES (24787, 15522, 1);
INSERT INTO 'dancesstepsmap' VALUES (24788, 15522, 2);
INSERT INTO 'dancesstepsmap' VALUES (24789, 15522, 3);
INSERT INTO 'dancesstepsmap' VALUES (24790, 15523, 1);
INSERT INTO 'dancesstepsmap' VALUES (24791, 15523, 2);
INSERT INTO 'dancesstepsmap' VALUES (24792, 15524, 1);
INSERT INTO 'dancesstepsmap' VALUES (24793, 15524, 2);
INSERT INTO 'dancesstepsmap' VALUES (24794, 15525, 4);
INSERT INTO 'dancesstepsmap' VALUES (24795, 15525, 5);
INSERT INTO 'dancesstepsmap' VALUES (24796, 15525, 1);
INSERT INTO 'dancesstepsmap' VALUES (24797, 15525, 2);
INSERT INTO 'dancesstepsmap' VALUES (24798, 15525, 3);
INSERT INTO 'dancesstepsmap' VALUES (24799, 12414, 1);
INSERT INTO 'dancesstepsmap' VALUES (24800, 12414, 2);
INSERT INTO 'dancesstepsmap' VALUES (24801, 10953, 1);
INSERT INTO 'dancesstepsmap' VALUES (24802, 10953, 3);
INSERT INTO 'dancesstepsmap' VALUES (24803, 18719, 5);
INSERT INTO 'dancesstepsmap' VALUES (24804, 18719, 4);
INSERT INTO 'dancesstepsmap' VALUES (24805, 18708, 1);
INSERT INTO 'dancesstepsmap' VALUES (24806, 18718, 2);
INSERT INTO 'dancesstepsmap' VALUES (24807, 18718, 1);
INSERT INTO 'dancesstepsmap' VALUES (24808, 10576, 3);
INSERT INTO 'dancesstepsmap' VALUES (24809, 12316, 1);
INSERT INTO 'dancesstepsmap' VALUES (24810, 12316, 2);
INSERT INTO 'dancesstepsmap' VALUES (24811, 12316, 3);
INSERT INTO 'dancesstepsmap' VALUES (24812, 10157, 1);
INSERT INTO 'dancesstepsmap' VALUES (24813, 10157, 2);
INSERT INTO 'dancesstepsmap' VALUES (24814, 10157, 3);
INSERT INTO 'dancesstepsmap' VALUES (24815, 14200, 1);
INSERT INTO 'dancesstepsmap' VALUES (24816, 12190, 1);
INSERT INTO 'dancesstepsmap' VALUES (24817, 19170, 2);
INSERT INTO 'dancesstepsmap' VALUES (24818, 19170, 1);
INSERT INTO 'dancesstepsmap' VALUES (24819, 18591, 1);
INSERT INTO 'dancesstepsmap' VALUES (24820, 18591, 2);
INSERT INTO 'dancesstepsmap' VALUES (24821, 18591, 3);
INSERT INTO 'dancesstepsmap' VALUES (24822, 14817, 4);
INSERT INTO 'dancesstepsmap' VALUES (24823, 14817, 5);
INSERT INTO 'dancesstepsmap' VALUES (24824, 19171, 4);
INSERT INTO 'dancesstepsmap' VALUES (24825, 19171, 5);
INSERT INTO 'dancesstepsmap' VALUES (24826, 19171, 1);
INSERT INTO 'dancesstepsmap' VALUES (24827, 19171, 2);
INSERT INTO 'dancesstepsmap' VALUES (24828, 19171, 3);
INSERT INTO 'dancesstepsmap' VALUES (24829, 17500, 1);
INSERT INTO 'dancesstepsmap' VALUES (24830, 19173, 1);
INSERT INTO 'dancesstepsmap' VALUES (24831, 19173, 2);
INSERT INTO 'dancesstepsmap' VALUES (24833, 19174, 5);
INSERT INTO 'dancesstepsmap' VALUES (24834, 19174, 6);
INSERT INTO 'dancesstepsmap' VALUES (24835, 19175, 4);
INSERT INTO 'dancesstepsmap' VALUES (24836, 19175, 5);
INSERT INTO 'dancesstepsmap' VALUES (24837, 19176, 1);
INSERT INTO 'dancesstepsmap' VALUES (24838, 19176, 2);
INSERT INTO 'dancesstepsmap' VALUES (24839, 19176, 10);
INSERT INTO 'dancesstepsmap' VALUES (24840, 19176, 3);
INSERT INTO 'dancesstepsmap' VALUES (24841, 12771, 1);
INSERT INTO 'dancesstepsmap' VALUES (24842, 12771, 2);
INSERT INTO 'dancesstepsmap' VALUES (24843, 12772, 2);
INSERT INTO 'dancesstepsmap' VALUES (24844, 14161, 1);
INSERT INTO 'dancesstepsmap' VALUES (24845, 14161, 2);
INSERT INTO 'dancesstepsmap' VALUES (24846, 18747, 2);
INSERT INTO 'dancesstepsmap' VALUES (24847, 18747, 1);
INSERT INTO 'dancesstepsmap' VALUES (24848, 19177, 1);
INSERT INTO 'dancesstepsmap' VALUES (24850, 14816, 1);
INSERT INTO 'dancesstepsmap' VALUES (24851, 14816, 2);
INSERT INTO 'dancesstepsmap' VALUES (24852, 14816, 3);
INSERT INTO 'dancesstepsmap' VALUES (24853, 14815, 4);
INSERT INTO 'dancesstepsmap' VALUES (24854, 19179, 4);
INSERT INTO 'dancesstepsmap' VALUES (24855, 18760, 2);
INSERT INTO 'dancesstepsmap' VALUES (24856, 18760, 1);
INSERT INTO 'dancesstepsmap' VALUES (24857, 14155, 1);
INSERT INTO 'dancesstepsmap' VALUES (24858, 14155, 2);
INSERT INTO 'dancesstepsmap' VALUES (24859, 19180, 4);
INSERT INTO 'dancesstepsmap' VALUES (24860, 19181, 3);
INSERT INTO 'dancesstepsmap' VALUES (24861, 19181, 1);
INSERT INTO 'dancesstepsmap' VALUES (24862, 3241, 5);
INSERT INTO 'dancesstepsmap' VALUES (24863, 2797, 2);
INSERT INTO 'dancesstepsmap' VALUES (24864, 3851, 2);
INSERT INTO 'dancesstepsmap' VALUES (24865, 18010, 2);
INSERT INTO 'dancesstepsmap' VALUES (24120, 18670, 5);
INSERT INTO 'dancesstepsmap' VALUES (24121, 18670, 4);
INSERT INTO 'dancesstepsmap' VALUES (24866, 19182, 2);
INSERT INTO 'dancesstepsmap' VALUES (24867, 19182, 3);
INSERT INTO 'dancesstepsmap' VALUES (24849, 19177, 2);
INSERT INTO 'dancesstepsmap' VALUES (24868, 19182, 1);
INSERT INTO 'dancesstepsmap' VALUES (24869, 6845, 2);
INSERT INTO 'dancesstepsmap' VALUES (24870, 15287, 3);
INSERT INTO 'dancesstepsmap' VALUES (24871, 707, 2);
INSERT INTO 'dancesstepsmap' VALUES (24872, 2718, 2);
INSERT INTO 'dancesstepsmap' VALUES (24873, 12302, 1);
INSERT INTO 'dancesstepsmap' VALUES (24874, 12302, 2);
INSERT INTO 'dancesstepsmap' VALUES (24875, 12302, 3);
INSERT INTO 'dancesstepsmap' VALUES (24876, 14963, 1);
INSERT INTO 'dancesstepsmap' VALUES (24877, 14963, 2);
INSERT INTO 'dancesstepsmap' VALUES (24878, 14963, 3);
INSERT INTO 'dancesstepsmap' VALUES (24879, 5788, 2);
INSERT INTO 'dancesstepsmap' VALUES (24880, 12027, 1);
INSERT INTO 'dancesstepsmap' VALUES (24881, 7578, 2);
INSERT INTO 'dancesstepsmap' VALUES (24882, 11178, 4);
INSERT INTO 'dancesstepsmap' VALUES (24883, 11178, 5);
INSERT INTO 'dancesstepsmap' VALUES (24884, 19059, 1);
INSERT INTO 'dancesstepsmap' VALUES (24885, 19059, 3);
INSERT INTO 'dancesstepsmap' VALUES (11526, 10417, 1);
INSERT INTO 'dancesstepsmap' VALUES (11527, 10417, 2);
INSERT INTO 'dancesstepsmap' VALUES (24886, 18565, 1);
INSERT INTO 'dancesstepsmap' VALUES (24887, 6966, 2);
INSERT INTO 'dancesstepsmap' VALUES (24888, 6966, 3);
INSERT INTO 'dancesstepsmap' VALUES (24889, 163, 2);
INSERT INTO 'dancesstepsmap' VALUES (24890, 857, 5);
INSERT INTO 'dancesstepsmap' VALUES (24891, 1008, 2);
INSERT INTO 'dancesstepsmap' VALUES (24892, 1804, 5);
INSERT INTO 'dancesstepsmap' VALUES (24893, 19183, 1);
INSERT INTO 'dancesstepsmap' VALUES (24894, 7356, 2);
INSERT INTO 'dancesstepsmap' VALUES (24895, 6549, 2);
INSERT INTO 'dancesstepsmap' VALUES (24896, 6549, 3);
INSERT INTO 'dancesstepsmap' VALUES (24897, 5289, 2);
INSERT INTO 'dancesstepsmap' VALUES (24898, 9226, 1);
INSERT INTO 'dancesstepsmap' VALUES (24899, 7591, 5);
INSERT INTO 'dancesstepsmap' VALUES (24900, 6729, 2);
INSERT INTO 'dancesstepsmap' VALUES (24901, 9945, 5);
INSERT INTO 'dancesstepsmap' VALUES (24902, 10764, 1);
INSERT INTO 'dancesstepsmap' VALUES (24903, 10764, 2);
INSERT INTO 'dancesstepsmap' VALUES (24904, 10159, 1);
INSERT INTO 'dancesstepsmap' VALUES (24905, 10159, 2);
INSERT INTO 'dancesstepsmap' VALUES (24906, 10160, 1);
INSERT INTO 'dancesstepsmap' VALUES (24907, 10160, 2);
INSERT INTO 'dancesstepsmap' VALUES (24908, 10160, 3);
INSERT INTO 'dancesstepsmap' VALUES (24909, 7783, 5);
INSERT INTO 'dancesstepsmap' VALUES (24910, 15978, 2);
INSERT INTO 'dancesstepsmap' VALUES (24911, 15978, 1);
INSERT INTO 'dancesstepsmap' VALUES (24912, 18566, 1);
INSERT INTO 'dancesstepsmap' VALUES (24913, 18566, 2);
INSERT INTO 'dancesstepsmap' VALUES (24914, 12345, 4);
INSERT INTO 'dancesstepsmap' VALUES (24915, 12345, 5);
INSERT INTO 'dancesstepsmap' VALUES (24916, 19012, 4);
INSERT INTO 'dancesstepsmap' VALUES (24917, 19012, 5);
INSERT INTO 'dancesstepsmap' VALUES (24918, 14583, 1);
INSERT INTO 'dancesstepsmap' VALUES (24919, 14583, 2);
INSERT INTO 'dancesstepsmap' VALUES (24920, 14583, 3);
INSERT INTO 'dancesstepsmap' VALUES (24921, 14961, 4);
INSERT INTO 'dancesstepsmap' VALUES (24922, 14961, 5);
INSERT INTO 'dancesstepsmap' VALUES (24923, 17098, 4);
INSERT INTO 'dancesstepsmap' VALUES (24924, 17098, 5);
INSERT INTO 'dancesstepsmap' VALUES (24925, 18031, 1);
INSERT INTO 'dancesstepsmap' VALUES (24926, 18031, 2);
INSERT INTO 'dancesstepsmap' VALUES (24927, 18029, 1);
INSERT INTO 'dancesstepsmap' VALUES (24928, 18029, 2);
INSERT INTO 'dancesstepsmap' VALUES (24929, 18029, 3);
INSERT INTO 'dancesstepsmap' VALUES (24930, 15585, 4);
INSERT INTO 'dancesstepsmap' VALUES (24931, 15585, 5);
INSERT INTO 'dancesstepsmap' VALUES (24932, 14766, 4);
INSERT INTO 'dancesstepsmap' VALUES (24933, 14766, 5);
INSERT INTO 'dancesstepsmap' VALUES (24934, 10435, 5);
INSERT INTO 'dancesstepsmap' VALUES (24935, 19184, 4);
INSERT INTO 'dancesstepsmap' VALUES (24936, 19184, 1);
INSERT INTO 'dancesstepsmap' VALUES (24937, 19184, 3);
INSERT INTO 'dancesstepsmap' VALUES (24938, 19185, 4);
INSERT INTO 'dancesstepsmap' VALUES (24939, 19185, 5);
INSERT INTO 'dancesstepsmap' VALUES (24940, 4984, 5);
INSERT INTO 'dancesstepsmap' VALUES (24943, 10500, 5);
INSERT INTO 'dancesstepsmap' VALUES (24941, 19186, 4);
INSERT INTO 'dancesstepsmap' VALUES (24942, 19186, 5);
INSERT INTO 'dancesstepsmap' VALUES (24944, 19187, 5);
INSERT INTO 'dancesstepsmap' VALUES (24945, 19187, 4);
INSERT INTO 'dancesstepsmap' VALUES (24946, 19188, 4);
INSERT INTO 'dancesstepsmap' VALUES (24947, 19188, 5);
INSERT INTO 'dancesstepsmap' VALUES (24948, 17811, 4);
INSERT INTO 'dancesstepsmap' VALUES (24949, 17811, 5);
INSERT INTO 'dancesstepsmap' VALUES (24950, 14396, 5);
INSERT INTO 'dancesstepsmap' VALUES (24951, 12348, 1);
INSERT INTO 'dancesstepsmap' VALUES (24952, 12348, 3);
INSERT INTO 'dancesstepsmap' VALUES (24953, 19189, 2);
INSERT INTO 'dancesstepsmap' VALUES (24954, 19189, 1);
INSERT INTO 'dancesstepsmap' VALUES (24955, 13419, 1);
INSERT INTO 'dancesstepsmap' VALUES (24956, 10445, 1);
INSERT INTO 'dancesstepsmap' VALUES (24957, 10445, 2);
INSERT INTO 'dancesstepsmap' VALUES (24958, 10445, 3);
INSERT INTO 'dancesstepsmap' VALUES (24959, 8548, 5);
INSERT INTO 'dancesstepsmap' VALUES (24960, 7120, 5);
INSERT INTO 'dancesstepsmap' VALUES (24961, 19192, 1);
INSERT INTO 'dancesstepsmap' VALUES (24962, 19192, 2);
INSERT INTO 'dancesstepsmap' VALUES (24963, 19195, 1);
INSERT INTO 'dancesstepsmap' VALUES (24964, 19195, 2);
INSERT INTO 'dancesstepsmap' VALUES (24965, 19194, 1);
INSERT INTO 'dancesstepsmap' VALUES (24966, 19194, 2);
INSERT INTO 'dancesstepsmap' VALUES (24967, 8549, 2);
INSERT INTO 'dancesstepsmap' VALUES (24968, 8552, 3);
INSERT INTO 'dancesstepsmap' VALUES (24969, 19199, 1);
INSERT INTO 'dancesstepsmap' VALUES (24970, 19199, 2);
INSERT INTO 'dancesstepsmap' VALUES (24971, 3482, 5);
INSERT INTO 'dancesstepsmap' VALUES (24972, 3893, 2);
INSERT INTO 'dancesstepsmap' VALUES (24973, 3899, 2);
INSERT INTO 'dancesstepsmap' VALUES (24974, 3959, 5);
INSERT INTO 'dancesstepsmap' VALUES (24975, 11229, 1);
INSERT INTO 'dancesstepsmap' VALUES (24976, 11229, 2);
INSERT INTO 'dancesstepsmap' VALUES (24977, 7153, 5);
INSERT INTO 'dancesstepsmap' VALUES (24978, 7193, 2);
INSERT INTO 'dancesstepsmap' VALUES (24979, 7193, 3);
INSERT INTO 'dancesstepsmap' VALUES (24980, 9006, 5);
INSERT INTO 'dancesstepsmap' VALUES (24981, 9006, 4);
INSERT INTO 'dancesstepsmap' VALUES (24982, 9020, 4);
INSERT INTO 'dancesstepsmap' VALUES (24983, 9020, 5);
INSERT INTO 'dancesstepsmap' VALUES (24984, 9096, 1);
INSERT INTO 'dancesstepsmap' VALUES (24985, 9100, 1);
INSERT INTO 'dancesstepsmap' VALUES (24986, 9683, 5);
INSERT INTO 'dancesstepsmap' VALUES (24987, 9818, 1);
INSERT INTO 'dancesstepsmap' VALUES (24988, 9818, 2);
INSERT INTO 'dancesstepsmap' VALUES (24989, 9818, 3);
INSERT INTO 'dancesstepsmap' VALUES (24990, 10141, 1);
INSERT INTO 'dancesstepsmap' VALUES (24991, 10141, 2);
INSERT INTO 'dancesstepsmap' VALUES (24992, 10141, 3);
INSERT INTO 'dancesstepsmap' VALUES (24993, 10158, 1);
INSERT INTO 'dancesstepsmap' VALUES (24994, 10158, 2);
INSERT INTO 'dancesstepsmap' VALUES (24995, 10164, 4);
INSERT INTO 'dancesstepsmap' VALUES (24996, 10164, 5);
INSERT INTO 'dancesstepsmap' VALUES (24997, 10168, 1);
INSERT INTO 'dancesstepsmap' VALUES (24998, 10168, 2);
INSERT INTO 'dancesstepsmap' VALUES (24999, 10181, 1);
INSERT INTO 'dancesstepsmap' VALUES (25000, 10182, 4);
INSERT INTO 'dancesstepsmap' VALUES (25001, 10571, 1);
INSERT INTO 'dancesstepsmap' VALUES (25002, 11514, 1);
INSERT INTO 'dancesstepsmap' VALUES (25003, 14948, 1);
INSERT INTO 'dancesstepsmap' VALUES (25004, 14948, 2);
INSERT INTO 'dancesstepsmap' VALUES (25005, 14951, 1);
INSERT INTO 'dancesstepsmap' VALUES (25006, 14951, 2);
INSERT INTO 'dancesstepsmap' VALUES (25007, 14953, 4);
INSERT INTO 'dancesstepsmap' VALUES (25008, 14953, 5);
INSERT INTO 'dancesstepsmap' VALUES (25009, 15042, 4);
INSERT INTO 'dancesstepsmap' VALUES (25010, 15042, 5);
INSERT INTO 'dancesstepsmap' VALUES (25011, 15067, 1);
INSERT INTO 'dancesstepsmap' VALUES (25012, 15067, 2);
INSERT INTO 'dancesstepsmap' VALUES (25013, 9635, 5);
INSERT INTO 'dancesstepsmap' VALUES (25014, 9633, 5);
INSERT INTO 'dancesstepsmap' VALUES (25015, 9609, 4);
INSERT INTO 'dancesstepsmap' VALUES (25016, 9577, 2);
INSERT INTO 'dancesstepsmap' VALUES (25017, 9577, 3);
INSERT INTO 'dancesstepsmap' VALUES (25018, 9572, 2);
INSERT INTO 'dancesstepsmap' VALUES (25019, 9405, 1);
INSERT INTO 'dancesstepsmap' VALUES (25020, 9405, 3);
INSERT INTO 'dancesstepsmap' VALUES (25021, 9389, 5);
INSERT INTO 'dancesstepsmap' VALUES (25022, 9386, 2);
INSERT INTO 'dancesstepsmap' VALUES (25023, 9296, 4);
INSERT INTO 'dancesstepsmap' VALUES (25024, 9296, 5);
INSERT INTO 'dancesstepsmap' VALUES (25025, 2416, 2);
INSERT INTO 'dancesstepsmap' VALUES (25026, 2208, 3);
INSERT INTO 'dancesstepsmap' VALUES (25027, 2352, 5);
INSERT INTO 'dancesstepsmap' VALUES (25028, 2301, 2);
INSERT INTO 'dancesstepsmap' VALUES (25029, 282, 2);
INSERT INTO 'dancesstepsmap' VALUES (25030, 721, 5);
INSERT INTO 'dancesstepsmap' VALUES (25031, 726, 5);
INSERT INTO 'dancesstepsmap' VALUES (25032, 18622, 5);
INSERT INTO 'dancesstepsmap' VALUES (25033, 18622, 4);
INSERT INTO 'dancesstepsmap' VALUES (25034, 18617, 1);
INSERT INTO 'dancesstepsmap' VALUES (25035, 18617, 2);
INSERT INTO 'dancesstepsmap' VALUES (25036, 18617, 3);
INSERT INTO 'dancesstepsmap' VALUES (25037, 18528, 4);
INSERT INTO 'dancesstepsmap' VALUES (25038, 18528, 5);
INSERT INTO 'dancesstepsmap' VALUES (25039, 17778, 3);
INSERT INTO 'dancesstepsmap' VALUES (25040, 16836, 4);
INSERT INTO 'dancesstepsmap' VALUES (25041, 16836, 5);
INSERT INTO 'dancesstepsmap' VALUES (25042, 16834, 4);
INSERT INTO 'dancesstepsmap' VALUES (25043, 16834, 5);
INSERT INTO 'dancesstepsmap' VALUES (25044, 5686, 4);
INSERT INTO 'dancesstepsmap' VALUES (25045, 5686, 5);
INSERT INTO 'dancesstepsmap' VALUES (25046, 5686, 1);
INSERT INTO 'dancesstepsmap' VALUES (25047, 8211, 3);
INSERT INTO 'dancesstepsmap' VALUES (25048, 19201, 1);
INSERT INTO 'dancesstepsmap' VALUES (25049, 19201, 2);
INSERT INTO 'dancesstepsmap' VALUES (25050, 17323, 1);
INSERT INTO 'dancesstepsmap' VALUES (25051, 17323, 3);
INSERT INTO 'dancesstepsmap' VALUES (25052, 12297, 1);
INSERT INTO 'dancesstepsmap' VALUES (25053, 19202, 2);
INSERT INTO 'dancesstepsmap' VALUES (25054, 19202, 1);
INSERT INTO 'dancesstepsmap' VALUES (25055, 19202, 3);
INSERT INTO 'dancesstepsmap' VALUES (25056, 13572, 1);
INSERT INTO 'dancesstepsmap' VALUES (25057, 13572, 2);
INSERT INTO 'dancesstepsmap' VALUES (25058, 13572, 3);
INSERT INTO 'dancesstepsmap' VALUES (25059, 19203, 5);
INSERT INTO 'dancesstepsmap' VALUES (25060, 19203, 4);
INSERT INTO 'dancesstepsmap' VALUES (25061, 8243, 5);
INSERT INTO 'dancesstepsmap' VALUES (25062, 16576, 4);
INSERT INTO 'dancesstepsmap' VALUES (25063, 16576, 5);
INSERT INTO 'dancesstepsmap' VALUES (25064, 15664, 4);
INSERT INTO 'dancesstepsmap' VALUES (25065, 15664, 5);
INSERT INTO 'dancesstepsmap' VALUES (25066, 15597, 4);
INSERT INTO 'dancesstepsmap' VALUES (25067, 17162, 1);
INSERT INTO 'dancesstepsmap' VALUES (25068, 17162, 2);
INSERT INTO 'dancesstepsmap' VALUES (25069, 17156, 4);
INSERT INTO 'dancesstepsmap' VALUES (25070, 17156, 5);
INSERT INTO 'dancesstepsmap' VALUES (25071, 18503, 4);
INSERT INTO 'dancesstepsmap' VALUES (25072, 18503, 5);
INSERT INTO 'dancesstepsmap' VALUES (25073, 19200, 3);
INSERT INTO 'dancesstepsmap' VALUES (25074, 19200, 1);
INSERT INTO 'dancesstepsmap' VALUES (25075, 15066, 4);
INSERT INTO 'dancesstepsmap' VALUES (25076, 15066, 5);
INSERT INTO 'dancesstepsmap' VALUES (25077, 14236, 4);
INSERT INTO 'dancesstepsmap' VALUES (25078, 14236, 5);
INSERT INTO 'dancesstepsmap' VALUES (25079, 14819, 1);
INSERT INTO 'dancesstepsmap' VALUES (25080, 14819, 2);
INSERT INTO 'dancesstepsmap' VALUES (25081, 14819, 3);
INSERT INTO 'dancesstepsmap' VALUES (25085, 15037, 4);
INSERT INTO 'dancesstepsmap' VALUES (25086, 15037, 5);
INSERT INTO 'dancesstepsmap' VALUES (25087, 14233, 4);
INSERT INTO 'dancesstepsmap' VALUES (25088, 14233, 5);
INSERT INTO 'dancesstepsmap' VALUES (25092, 3708, 5);
INSERT INTO 'dancesstepsmap' VALUES (7623, 278, 2);
INSERT INTO 'dancesstepsmap' VALUES (10576, 278, 3);
INSERT INTO 'dancesstepsmap' VALUES (25093, 2920, 2);
INSERT INTO 'dancesstepsmap' VALUES (25094, 15062, 1);
INSERT INTO 'dancesstepsmap' VALUES (25095, 15062, 2);
INSERT INTO 'dancesstepsmap' VALUES (25096, 8523, 2);
INSERT INTO 'dancesstepsmap' VALUES (25097, 4120, 2);
INSERT INTO 'dancesstepsmap' VALUES (25098, 14943, 4);
INSERT INTO 'dancesstepsmap' VALUES (25099, 14943, 5);
INSERT INTO 'dancesstepsmap' VALUES (25100, 15072, 1);
INSERT INTO 'dancesstepsmap' VALUES (25101, 15072, 2);
INSERT INTO 'dancesstepsmap' VALUES (25102, 19205, 4);
INSERT INTO 'dancesstepsmap' VALUES (25103, 19205, 5);
INSERT INTO 'dancesstepsmap' VALUES (25104, 13126, 1);
INSERT INTO 'dancesstepsmap' VALUES (25105, 13126, 2);
INSERT INTO 'dancesstepsmap' VALUES (25106, 12760, 2);
INSERT INTO 'dancesstepsmap' VALUES (25107, 12534, 2);
INSERT INTO 'dancesstepsmap' VALUES (25108, 12528, 2);
INSERT INTO 'dancesstepsmap' VALUES (25109, 12453, 5);
INSERT INTO 'dancesstepsmap' VALUES (25110, 18264, 1);
INSERT INTO 'dancesstepsmap' VALUES (25111, 18264, 2);
INSERT INTO 'dancesstepsmap' VALUES (25112, 10759, 1);
INSERT INTO 'dancesstepsmap' VALUES (25113, 10777, 1);
INSERT INTO 'dancesstepsmap' VALUES (25114, 11016, 4);
INSERT INTO 'dancesstepsmap' VALUES (25115, 11224, 1);
INSERT INTO 'dancesstepsmap' VALUES (25116, 11224, 2);
INSERT INTO 'dancesstepsmap' VALUES (25117, 11224, 3);
INSERT INTO 'dancesstepsmap' VALUES (25118, 12301, 4);
INSERT INTO 'dancesstepsmap' VALUES (25119, 12381, 4);
INSERT INTO 'dancesstepsmap' VALUES (25120, 12381, 5);
INSERT INTO 'dancesstepsmap' VALUES (25121, 10702, 1);
INSERT INTO 'dancesstepsmap' VALUES (25122, 10702, 3);
INSERT INTO 'dancesstepsmap' VALUES (25123, 10701, 1);
INSERT INTO 'dancesstepsmap' VALUES (25124, 10701, 3);
INSERT INTO 'dancesstepsmap' VALUES (25125, 10651, 1);
INSERT INTO 'dancesstepsmap' VALUES (25126, 10651, 2);
INSERT INTO 'dancesstepsmap' VALUES (25127, 10510, 1);
INSERT INTO 'dancesstepsmap' VALUES (25128, 12170, 1);
INSERT INTO 'dancesstepsmap' VALUES (25129, 12170, 3);
INSERT INTO 'dancesstepsmap' VALUES (25130, 18948, 1);
INSERT INTO 'dancesstepsmap' VALUES (25082, 15035, 4);
INSERT INTO 'dancesstepsmap' VALUES (25083, 15035, 5);
INSERT INTO 'dancesstepsmap' VALUES (25131, 18948, 2);
INSERT INTO 'dancesstepsmap' VALUES (25132, 18663, 4);
INSERT INTO 'dancesstepsmap' VALUES (25133, 10161, 1);
INSERT INTO 'dancesstepsmap' VALUES (25134, 10156, 1);
INSERT INTO 'dancesstepsmap' VALUES (25135, 10156, 3);
INSERT INTO 'dancesstepsmap' VALUES (25136, 10147, 2);
INSERT INTO 'dancesstepsmap' VALUES (25137, 10017, 2);
INSERT INTO 'dancesstepsmap' VALUES (25139, 19222, 1);
INSERT INTO 'dancesstepsmap' VALUES (25140, 19222, 2);
INSERT INTO 'dancesstepsmap' VALUES (25141, 19222, 3);
INSERT INTO 'dancesstepsmap' VALUES (25142, 9907, 2);
INSERT INTO 'dancesstepsmap' VALUES (25143, 9879, 4);
INSERT INTO 'dancesstepsmap' VALUES (25144, 9876, 5);
INSERT INTO 'dancesstepsmap' VALUES (25145, 9874, 5);
INSERT INTO 'dancesstepsmap' VALUES (25146, 19223, 1);
INSERT INTO 'dancesstepsmap' VALUES (25147, 19223, 2);
INSERT INTO 'dancesstepsmap' VALUES (25148, 19223, 3);
INSERT INTO 'dancesstepsmap' VALUES (25149, 1318, 5);
INSERT INTO 'dancesstepsmap' VALUES (25150, 4070, 5);
INSERT INTO 'dancesstepsmap' VALUES (25151, 12622, 5);
INSERT INTO 'dancesstepsmap' VALUES (25152, 9867, 2);
INSERT INTO 'dancesstepsmap' VALUES (25153, 9849, 5);
INSERT INTO 'dancesstepsmap' VALUES (25154, 9829, 2);
INSERT INTO 'dancesstepsmap' VALUES (25155, 9735, 1);
INSERT INTO 'dancesstepsmap' VALUES (25156, 9735, 2);
INSERT INTO 'dancesstepsmap' VALUES (25157, 9658, 4);
INSERT INTO 'dancesstepsmap' VALUES (25160, 9468, 4);
INSERT INTO 'dancesstepsmap' VALUES (25161, 9468, 5);
INSERT INTO 'dancesstepsmap' VALUES (25162, 9280, 4);
INSERT INTO 'dancesstepsmap' VALUES (25163, 9280, 5);
INSERT INTO 'dancesstepsmap' VALUES (25164, 9280, 1);
INSERT INTO 'dancesstepsmap' VALUES (25165, 9280, 2);
INSERT INTO 'dancesstepsmap' VALUES (25166, 9207, 1);
INSERT INTO 'dancesstepsmap' VALUES (25167, 9207, 2);
INSERT INTO 'dancesstepsmap' VALUES (25168, 9207, 3);
INSERT INTO 'dancesstepsmap' VALUES (25169, 9187, 4);
INSERT INTO 'dancesstepsmap' VALUES (25170, 9187, 5);
INSERT INTO 'dancesstepsmap' VALUES (25171, 9159, 5);
INSERT INTO 'dancesstepsmap' VALUES (25172, 9004, 4);
INSERT INTO 'dancesstepsmap' VALUES (25173, 9004, 5);
INSERT INTO 'dancesstepsmap' VALUES (25174, 19224, 4);
INSERT INTO 'dancesstepsmap' VALUES (25175, 19224, 5);
INSERT INTO 'dancesstepsmap' VALUES (25176, 8934, 2);
INSERT INTO 'dancesstepsmap' VALUES (25177, 8912, 1);
INSERT INTO 'dancesstepsmap' VALUES (25178, 8863, 1);
INSERT INTO 'dancesstepsmap' VALUES (25179, 8658, 2);
INSERT INTO 'dancesstepsmap' VALUES (25180, 8658, 3);
INSERT INTO 'dancesstepsmap' VALUES (25181, 8575, 2);
INSERT INTO 'dancesstepsmap' VALUES (25182, 8575, 3);
INSERT INTO 'dancesstepsmap' VALUES (25183, 8539, 2);
INSERT INTO 'dancesstepsmap' VALUES (25184, 8528, 2);
INSERT INTO 'dancesstepsmap' VALUES (25185, 8493, 5);
INSERT INTO 'dancesstepsmap' VALUES (25186, 8250, 3);
INSERT INTO 'dancesstepsmap' VALUES (25187, 8246, 2);
INSERT INTO 'dancesstepsmap' VALUES (25188, 8246, 3);
INSERT INTO 'dancesstepsmap' VALUES (25189, 19225, 1);
INSERT INTO 'dancesstepsmap' VALUES (25190, 19225, 3);
INSERT INTO 'dancesstepsmap' VALUES (25191, 8106, 2);
INSERT INTO 'dancesstepsmap' VALUES (25192, 19226, 2);
INSERT INTO 'dancesstepsmap' VALUES (25193, 19226, 1);
INSERT INTO 'dancesstepsmap' VALUES (25194, 19227, 1);
INSERT INTO 'dancesstepsmap' VALUES (25195, 14478, 1);
INSERT INTO 'dancesstepsmap' VALUES (25196, 14478, 2);
INSERT INTO 'dancesstepsmap' VALUES (25197, 8023, 5);
INSERT INTO 'dancesstepsmap' VALUES (25198, 7975, 5);
INSERT INTO 'dancesstepsmap' VALUES (25199, 7946, 2);
INSERT INTO 'dancesstepsmap' VALUES (25200, 14966, 3);
INSERT INTO 'dancesstepsmap' VALUES (25201, 14966, 1);
INSERT INTO 'dancesstepsmap' VALUES (25202, 7855, 5);
INSERT INTO 'dancesstepsmap' VALUES (25203, 7849, 5);
INSERT INTO 'dancesstepsmap' VALUES (25204, 7518, 5);
INSERT INTO 'dancesstepsmap' VALUES (25205, 7513, 5);
INSERT INTO 'dancesstepsmap' VALUES (25206, 7488, 4);
INSERT INTO 'dancesstepsmap' VALUES (25207, 7488, 5);
INSERT INTO 'dancesstepsmap' VALUES (25208, 7488, 1);
INSERT INTO 'dancesstepsmap' VALUES (25209, 7488, 2);
INSERT INTO 'dancesstepsmap' VALUES (25210, 7488, 3);
INSERT INTO 'dancesstepsmap' VALUES (25211, 7486, 2);
INSERT INTO 'dancesstepsmap' VALUES (25212, 7486, 3);
INSERT INTO 'dancesstepsmap' VALUES (25213, 7460, 4);
INSERT INTO 'dancesstepsmap' VALUES (25214, 7460, 5);
INSERT INTO 'dancesstepsmap' VALUES (25215, 7460, 1);
INSERT INTO 'dancesstepsmap' VALUES (25216, 7460, 2);
INSERT INTO 'dancesstepsmap' VALUES (25217, 7460, 3);
INSERT INTO 'dancesstepsmap' VALUES (25218, 17253, 4);
INSERT INTO 'dancesstepsmap' VALUES (25219, 17253, 5);
INSERT INTO 'dancesstepsmap' VALUES (25220, 7443, 4);
INSERT INTO 'dancesstepsmap' VALUES (25221, 7443, 5);
INSERT INTO 'dancesstepsmap' VALUES (25222, 7443, 1);
INSERT INTO 'dancesstepsmap' VALUES (25223, 7443, 2);
INSERT INTO 'dancesstepsmap' VALUES (25224, 7443, 3);
INSERT INTO 'dancesstepsmap' VALUES (25225, 7442, 5);
INSERT INTO 'dancesstepsmap' VALUES (25226, 7414, 4);
INSERT INTO 'dancesstepsmap' VALUES (25227, 7414, 5);
INSERT INTO 'dancesstepsmap' VALUES (25228, 7414, 1);
INSERT INTO 'dancesstepsmap' VALUES (25229, 7414, 3);
INSERT INTO 'dancesstepsmap' VALUES (25230, 7358, 5);
INSERT INTO 'dancesstepsmap' VALUES (25231, 7352, 2);
INSERT INTO 'dancesstepsmap' VALUES (25232, 7229, 2);
INSERT INTO 'dancesstepsmap' VALUES (25233, 19230, 5);
INSERT INTO 'dancesstepsmap' VALUES (25234, 19230, 4);
INSERT INTO 'dancesstepsmap' VALUES (25235, 7112, 5);
INSERT INTO 'dancesstepsmap' VALUES (25236, 7079, 4);
INSERT INTO 'dancesstepsmap' VALUES (25237, 7079, 5);
INSERT INTO 'dancesstepsmap' VALUES (25238, 7079, 6);
INSERT INTO 'dancesstepsmap' VALUES (25239, 7079, 1);
INSERT INTO 'dancesstepsmap' VALUES (25240, 7079, 2);
INSERT INTO 'dancesstepsmap' VALUES (25241, 7060, 2);
INSERT INTO 'dancesstepsmap' VALUES (25242, 7060, 3);
INSERT INTO 'dancesstepsmap' VALUES (25243, 19231, 2);
INSERT INTO 'dancesstepsmap' VALUES (25244, 19231, 3);
INSERT INTO 'dancesstepsmap' VALUES (25245, 19231, 1);
INSERT INTO 'dancesstepsmap' VALUES (25246, 19232, 1);
INSERT INTO 'dancesstepsmap' VALUES (25247, 19233, 2);
INSERT INTO 'dancesstepsmap' VALUES (25248, 19233, 1);
INSERT INTO 'dancesstepsmap' VALUES (25249, 19233, 3);
INSERT INTO 'dancesstepsmap' VALUES (25250, 19234, 1);
INSERT INTO 'dancesstepsmap' VALUES (25251, 19235, 5);
INSERT INTO 'dancesstepsmap' VALUES (25252, 19235, 6);
INSERT INTO 'dancesstepsmap' VALUES (25253, 19235, 4);
INSERT INTO 'dancesstepsmap' VALUES (25254, 19236, 5);
INSERT INTO 'dancesstepsmap' VALUES (25255, 19236, 4);
INSERT INTO 'dancesstepsmap' VALUES (25256, 19237, 5);
INSERT INTO 'dancesstepsmap' VALUES (25257, 19237, 4);
INSERT INTO 'dancesstepsmap' VALUES (25258, 6902, 2);
INSERT INTO 'dancesstepsmap' VALUES (25259, 6873, 2);
INSERT INTO 'dancesstepsmap' VALUES (25260, 6829, 6);
INSERT INTO 'dancesstepsmap' VALUES (25261, 6801, 5);
INSERT INTO 'dancesstepsmap' VALUES (25262, 6775, 2);
INSERT INTO 'dancesstepsmap' VALUES (25263, 6655, 5);
INSERT INTO 'dancesstepsmap' VALUES (25264, 6569, 5);
INSERT INTO 'dancesstepsmap' VALUES (25265, 6506, 4);
INSERT INTO 'dancesstepsmap' VALUES (25266, 6506, 5);
INSERT INTO 'dancesstepsmap' VALUES (25267, 6506, 1);
INSERT INTO 'dancesstepsmap' VALUES (25268, 6506, 2);
INSERT INTO 'dancesstepsmap' VALUES (25269, 6506, 3);
INSERT INTO 'dancesstepsmap' VALUES (25270, 6436, 2);
INSERT INTO 'dancesstepsmap' VALUES (25271, 6432, 5);
INSERT INTO 'dancesstepsmap' VALUES (25272, 6431, 2);
INSERT INTO 'dancesstepsmap' VALUES (25273, 6420, 3);
INSERT INTO 'dancesstepsmap' VALUES (25274, 6375, 5);
INSERT INTO 'dancesstepsmap' VALUES (25275, 6341, 3);
INSERT INTO 'dancesstepsmap' VALUES (25276, 6309, 2);
INSERT INTO 'dancesstepsmap' VALUES (25277, 6309, 3);
INSERT INTO 'dancesstepsmap' VALUES (25278, 6234, 5);
INSERT INTO 'dancesstepsmap' VALUES (25279, 6229, 2);
INSERT INTO 'dancesstepsmap' VALUES (25280, 6209, 2);
INSERT INTO 'dancesstepsmap' VALUES (25281, 6185, 2);
INSERT INTO 'dancesstepsmap' VALUES (25282, 6153, 5);
INSERT INTO 'dancesstepsmap' VALUES (25283, 6149, 2);
INSERT INTO 'dancesstepsmap' VALUES (25284, 6149, 3);
INSERT INTO 'dancesstepsmap' VALUES (25285, 6116, 5);
INSERT INTO 'dancesstepsmap' VALUES (25286, 6094, 2);
INSERT INTO 'dancesstepsmap' VALUES (25287, 6094, 3);
INSERT INTO 'dancesstepsmap' VALUES (25288, 6081, 5);
INSERT INTO 'dancesstepsmap' VALUES (25289, 6044, 2);
INSERT INTO 'dancesstepsmap' VALUES (25290, 5928, 2);
INSERT INTO 'dancesstepsmap' VALUES (25291, 5862, 4);
INSERT INTO 'dancesstepsmap' VALUES (25292, 5862, 1);
INSERT INTO 'dancesstepsmap' VALUES (25293, 5862, 2);
INSERT INTO 'dancesstepsmap' VALUES (25294, 5857, 5);
INSERT INTO 'dancesstepsmap' VALUES (25295, 5835, 2);
INSERT INTO 'dancesstepsmap' VALUES (25296, 5775, 6);
INSERT INTO 'dancesstepsmap' VALUES (25297, 5764, 5);
INSERT INTO 'dancesstepsmap' VALUES (25298, 5713, 2);
INSERT INTO 'dancesstepsmap' VALUES (25299, 5703, 2);
INSERT INTO 'dancesstepsmap' VALUES (25300, 5636, 2);
INSERT INTO 'dancesstepsmap' VALUES (25301, 5619, 2);
INSERT INTO 'dancesstepsmap' VALUES (25302, 5618, 5);
INSERT INTO 'dancesstepsmap' VALUES (25303, 5618, 6);
INSERT INTO 'dancesstepsmap' VALUES (25304, 5519, 4);
INSERT INTO 'dancesstepsmap' VALUES (25305, 5519, 5);
INSERT INTO 'dancesstepsmap' VALUES (25306, 5519, 1);
INSERT INTO 'dancesstepsmap' VALUES (25307, 5519, 2);
INSERT INTO 'dancesstepsmap' VALUES (25308, 5518, 2);
INSERT INTO 'dancesstepsmap' VALUES (25309, 5502, 2);
INSERT INTO 'dancesstepsmap' VALUES (25310, 5446, 2);
INSERT INTO 'dancesstepsmap' VALUES (25311, 5414, 5);
INSERT INTO 'dancesstepsmap' VALUES (25312, 5404, 2);
INSERT INTO 'dancesstepsmap' VALUES (25313, 5387, 5);
INSERT INTO 'dancesstepsmap' VALUES (25314, 5377, 2);
INSERT INTO 'dancesstepsmap' VALUES (25315, 5371, 5);
INSERT INTO 'dancesstepsmap' VALUES (25316, 5345, 5);
INSERT INTO 'dancesstepsmap' VALUES (25317, 5345, 6);
INSERT INTO 'dancesstepsmap' VALUES (25318, 5271, 5);
INSERT INTO 'dancesstepsmap' VALUES (25319, 5200, 2);
INSERT INTO 'dancesstepsmap' VALUES (25320, 5178, 2);
INSERT INTO 'dancesstepsmap' VALUES (25321, 5137, 5);
INSERT INTO 'dancesstepsmap' VALUES (25322, 5090, 2);
INSERT INTO 'dancesstepsmap' VALUES (25323, 19240, 5);
INSERT INTO 'dancesstepsmap' VALUES (25324, 19240, 4);
INSERT INTO 'dancesstepsmap' VALUES (25325, 11687, 2);
INSERT INTO 'dancesstepsmap' VALUES (25326, 4930, 3);
INSERT INTO 'dancesstepsmap' VALUES (25327, 705, 2);
INSERT INTO 'dancesstepsmap' VALUES (25328, 4884, 2);
INSERT INTO 'dancesstepsmap' VALUES (25329, 4816, 5);
INSERT INTO 'dancesstepsmap' VALUES (25330, 4789, 5);
INSERT INTO 'dancesstepsmap' VALUES (25331, 19241, 1);
INSERT INTO 'dancesstepsmap' VALUES (25332, 19241, 2);
INSERT INTO 'dancesstepsmap' VALUES (25333, 4672, 5);
INSERT INTO 'dancesstepsmap' VALUES (25334, 4661, 2);
INSERT INTO 'dancesstepsmap' VALUES (25335, 4654, 5);
INSERT INTO 'dancesstepsmap' VALUES (25336, 4652, 5);
INSERT INTO 'dancesstepsmap' VALUES (25337, 4552, 5);
INSERT INTO 'dancesstepsmap' VALUES (25338, 4494, 5);
INSERT INTO 'dancesstepsmap' VALUES (25339, 4479, 2);
INSERT INTO 'dancesstepsmap' VALUES (25340, 4283, 2);
INSERT INTO 'dancesstepsmap' VALUES (25341, 18322, 1);
INSERT INTO 'dancesstepsmap' VALUES (25342, 18322, 2);
INSERT INTO 'dancesstepsmap' VALUES (25343, 18322, 3);
INSERT INTO 'dancesstepsmap' VALUES (25344, 6805, 2);
INSERT INTO 'dancesstepsmap' VALUES (25345, 4191, 5);
INSERT INTO 'dancesstepsmap' VALUES (25346, 17498, 1);
INSERT INTO 'dancesstepsmap' VALUES (25347, 17498, 2);
INSERT INTO 'dancesstepsmap' VALUES (25348, 17498, 3);
INSERT INTO 'dancesstepsmap' VALUES (25349, 4147, 2);
INSERT INTO 'dancesstepsmap' VALUES (25350, 4145, 3);
INSERT INTO 'dancesstepsmap' VALUES (25351, 3987, 5);
INSERT INTO 'dancesstepsmap' VALUES (25352, 3978, 5);
INSERT INTO 'dancesstepsmap' VALUES (25353, 3901, 5);
INSERT INTO 'dancesstepsmap' VALUES (25354, 3869, 5);
INSERT INTO 'dancesstepsmap' VALUES (25355, 3869, 6);
INSERT INTO 'dancesstepsmap' VALUES (25356, 3864, 5);
INSERT INTO 'dancesstepsmap' VALUES (25357, 3799, 2);
INSERT INTO 'dancesstepsmap' VALUES (25358, 3806, 3);
INSERT INTO 'dancesstepsmap' VALUES (25359, 19239, 5);
INSERT INTO 'dancesstepsmap' VALUES (25360, 19239, 4);
INSERT INTO 'dancesstepsmap' VALUES (25361, 17494, 4);
INSERT INTO 'dancesstepsmap' VALUES (25362, 17494, 5);
INSERT INTO 'dancesstepsmap' VALUES (25363, 3789, 5);
INSERT INTO 'dancesstepsmap' VALUES (25364, 3786, 2);
INSERT INTO 'dancesstepsmap' VALUES (25365, 3762, 2);
INSERT INTO 'dancesstepsmap' VALUES (25366, 3755, 5);
INSERT INTO 'dancesstepsmap' VALUES (25367, 3745, 2);
INSERT INTO 'dancesstepsmap' VALUES (25368, 3732, 4);
INSERT INTO 'dancesstepsmap' VALUES (25369, 3732, 1);
INSERT INTO 'dancesstepsmap' VALUES (25370, 3732, 3);
INSERT INTO 'dancesstepsmap' VALUES (25371, 3504, 3);
INSERT INTO 'dancesstepsmap' VALUES (25372, 3407, 5);
INSERT INTO 'dancesstepsmap' VALUES (25373, 3396, 4);
INSERT INTO 'dancesstepsmap' VALUES (25374, 3396, 5);
INSERT INTO 'dancesstepsmap' VALUES (25375, 3396, 1);
INSERT INTO 'dancesstepsmap' VALUES (25376, 3396, 2);
INSERT INTO 'dancesstepsmap' VALUES (25377, 3389, 5);
INSERT INTO 'dancesstepsmap' VALUES (25378, 3378, 2);
INSERT INTO 'dancesstepsmap' VALUES (25379, 3368, 2);
INSERT INTO 'dancesstepsmap' VALUES (25380, 3368, 3);
INSERT INTO 'dancesstepsmap' VALUES (25381, 3352, 2);
INSERT INTO 'dancesstepsmap' VALUES (25382, 3219, 2);
INSERT INTO 'dancesstepsmap' VALUES (25383, 3147, 5);
INSERT INTO 'dancesstepsmap' VALUES (25384, 2974, 5);
INSERT INTO 'dancesstepsmap' VALUES (25385, 2944, 5);
INSERT INTO 'dancesstepsmap' VALUES (25386, 2943, 5);
INSERT INTO 'dancesstepsmap' VALUES (25387, 19060, 1);
INSERT INTO 'dancesstepsmap' VALUES (25388, 19060, 3);
INSERT INTO 'dancesstepsmap' VALUES (25389, 19060, 2);
INSERT INTO 'dancesstepsmap' VALUES (25390, 15052, 3);
INSERT INTO 'dancesstepsmap' VALUES (25391, 2911, 6);
INSERT INTO 'dancesstepsmap' VALUES (25392, 2905, 2);
INSERT INTO 'dancesstepsmap' VALUES (25393, 2896, 5);
INSERT INTO 'dancesstepsmap' VALUES (25394, 2868, 4);
INSERT INTO 'dancesstepsmap' VALUES (25395, 2868, 1);
INSERT INTO 'dancesstepsmap' VALUES (25396, 2868, 2);
INSERT INTO 'dancesstepsmap' VALUES (25397, 2825, 2);
INSERT INTO 'dancesstepsmap' VALUES (25398, 2811, 2);
INSERT INTO 'dancesstepsmap' VALUES (25399, 8146, 99);
INSERT INTO 'dancesstepsmap' VALUES (25400, 15244, 1);
INSERT INTO 'dancesstepsmap' VALUES (25401, 15244, 2);
INSERT INTO 'dancesstepsmap' VALUES (25402, 2760, 5);
INSERT INTO 'dancesstepsmap' VALUES (25403, 2743, 4);
INSERT INTO 'dancesstepsmap' VALUES (25404, 2743, 5);
INSERT INTO 'dancesstepsmap' VALUES (25405, 2743, 1);
INSERT INTO 'dancesstepsmap' VALUES (25406, 2743, 2);
INSERT INTO 'dancesstepsmap' VALUES (25407, 1513, 2);
INSERT INTO 'dancesstepsmap' VALUES (25408, 2702, 5);
INSERT INTO 'dancesstepsmap' VALUES (25409, 2611, 5);
INSERT INTO 'dancesstepsmap' VALUES (25410, 2583, 5);
INSERT INTO 'dancesstepsmap' VALUES (25411, 2540, 4);
INSERT INTO 'dancesstepsmap' VALUES (25412, 2540, 5);
INSERT INTO 'dancesstepsmap' VALUES (25413, 2540, 2);
INSERT INTO 'dancesstepsmap' VALUES (25414, 2540, 1);
INSERT INTO 'dancesstepsmap' VALUES (25415, 2507, 5);
INSERT INTO 'dancesstepsmap' VALUES (25416, 2492, 4);
INSERT INTO 'dancesstepsmap' VALUES (25417, 2492, 5);
INSERT INTO 'dancesstepsmap' VALUES (25418, 2492, 1);
INSERT INTO 'dancesstepsmap' VALUES (25419, 2492, 2);
INSERT INTO 'dancesstepsmap' VALUES (25420, 2376, 5);
INSERT INTO 'dancesstepsmap' VALUES (25421, 19242, 1);
INSERT INTO 'dancesstepsmap' VALUES (25422, 19242, 2);
INSERT INTO 'dancesstepsmap' VALUES (25423, 2329, 5);
INSERT INTO 'dancesstepsmap' VALUES (25424, 2089, 5);
INSERT INTO 'dancesstepsmap' VALUES (25425, 2052, 2);
INSERT INTO 'dancesstepsmap' VALUES (25426, 2050, 5);
INSERT INTO 'dancesstepsmap' VALUES (25427, 2014, 5);
INSERT INTO 'dancesstepsmap' VALUES (25428, 1996, 2);
INSERT INTO 'dancesstepsmap' VALUES (25429, 1951, 5);
INSERT INTO 'dancesstepsmap' VALUES (25430, 1913, 4);
INSERT INTO 'dancesstepsmap' VALUES (25431, 1913, 2);
INSERT INTO 'dancesstepsmap' VALUES (25432, 1913, 1);
INSERT INTO 'dancesstepsmap' VALUES (25433, 13078, 5);
INSERT INTO 'dancesstepsmap' VALUES (25434, 1731, 2);
INSERT INTO 'dancesstepsmap' VALUES (25435, 1720, 2);
INSERT INTO 'dancesstepsmap' VALUES (25436, 1716, 5);
INSERT INTO 'dancesstepsmap' VALUES (25437, 1679, 5);
INSERT INTO 'dancesstepsmap' VALUES (25438, 1549, 2);
INSERT INTO 'dancesstepsmap' VALUES (25439, 1539, 5);
INSERT INTO 'dancesstepsmap' VALUES (25440, 1507, 5);
INSERT INTO 'dancesstepsmap' VALUES (25441, 17320, 3);
INSERT INTO 'dancesstepsmap' VALUES (25442, 17320, 1);
INSERT INTO 'dancesstepsmap' VALUES (25443, 1424, 2);
INSERT INTO 'dancesstepsmap' VALUES (25444, 1385, 2);
INSERT INTO 'dancesstepsmap' VALUES (25445, 1378, 2);
INSERT INTO 'dancesstepsmap' VALUES (25446, 1338, 5);
INSERT INTO 'dancesstepsmap' VALUES (25447, 1319, 5);
INSERT INTO 'dancesstepsmap' VALUES (25448, 1282, 5);
INSERT INTO 'dancesstepsmap' VALUES (25449, 1251, 5);
INSERT INTO 'dancesstepsmap' VALUES (25450, 19243, 1);
INSERT INTO 'dancesstepsmap' VALUES (25451, 1202, 4);
INSERT INTO 'dancesstepsmap' VALUES (25452, 1202, 5);
INSERT INTO 'dancesstepsmap' VALUES (25453, 1202, 1);
INSERT INTO 'dancesstepsmap' VALUES (25454, 1202, 2);
INSERT INTO 'dancesstepsmap' VALUES (25455, 1161, 5);
INSERT INTO 'dancesstepsmap' VALUES (25456, 1147, 5);
INSERT INTO 'dancesstepsmap' VALUES (25457, 1124, 2);
INSERT INTO 'dancesstepsmap' VALUES (25458, 1058, 2);
INSERT INTO 'dancesstepsmap' VALUES (25459, 1045, 2);
INSERT INTO 'dancesstepsmap' VALUES (25460, 1045, 3);
INSERT INTO 'dancesstepsmap' VALUES (25461, 1013, 3);
INSERT INTO 'dancesstepsmap' VALUES (25462, 964, 5);
INSERT INTO 'dancesstepsmap' VALUES (25463, 946, 5);
INSERT INTO 'dancesstepsmap' VALUES (25464, 898, 5);
INSERT INTO 'dancesstepsmap' VALUES (25465, 820, 2);
INSERT INTO 'dancesstepsmap' VALUES (25466, 810, 5);
INSERT INTO 'dancesstepsmap' VALUES (25467, 751, 4);
INSERT INTO 'dancesstepsmap' VALUES (25468, 751, 6);
INSERT INTO 'dancesstepsmap' VALUES (25469, 751, 1);
INSERT INTO 'dancesstepsmap' VALUES (25471, 710, 2);
INSERT INTO 'dancesstepsmap' VALUES (25472, 691, 3);
INSERT INTO 'dancesstepsmap' VALUES (25473, 691, 2);
INSERT INTO 'dancesstepsmap' VALUES (25474, 684, 2);
INSERT INTO 'dancesstepsmap' VALUES (25475, 665, 3);
INSERT INTO 'dancesstepsmap' VALUES (25476, 665, 2);
INSERT INTO 'dancesstepsmap' VALUES (25477, 658, 5);
INSERT INTO 'dancesstepsmap' VALUES (25478, 642, 4);
INSERT INTO 'dancesstepsmap' VALUES (25479, 642, 6);
INSERT INTO 'dancesstepsmap' VALUES (25480, 642, 5);
INSERT INTO 'dancesstepsmap' VALUES (25481, 642, 1);
INSERT INTO 'dancesstepsmap' VALUES (25482, 642, 2);
INSERT INTO 'dancesstepsmap' VALUES (25483, 642, 3);
INSERT INTO 'dancesstepsmap' VALUES (25484, 483, 5);
INSERT INTO 'dancesstepsmap' VALUES (25485, 447, 2);
INSERT INTO 'dancesstepsmap' VALUES (25486, 441, 4);
INSERT INTO 'dancesstepsmap' VALUES (25487, 441, 5);
INSERT INTO 'dancesstepsmap' VALUES (25488, 441, 1);
INSERT INTO 'dancesstepsmap' VALUES (25489, 441, 2);
INSERT INTO 'dancesstepsmap' VALUES (25490, 441, 10);
INSERT INTO 'dancesstepsmap' VALUES (25491, 394, 5);
INSERT INTO 'dancesstepsmap' VALUES (25492, 354, 5);
INSERT INTO 'dancesstepsmap' VALUES (25493, 307, 5);
INSERT INTO 'dancesstepsmap' VALUES (25494, 188, 2);
INSERT INTO 'dancesstepsmap' VALUES (25495, 154, 2);
INSERT INTO 'dancesstepsmap' VALUES (25496, 67, 5);
INSERT INTO 'dancesstepsmap' VALUES (25497, 46, 5);
INSERT INTO 'dancesstepsmap' VALUES (25498, 18, 2);
INSERT INTO 'dancesstepsmap' VALUES (25499, 19246, 1);
INSERT INTO 'dancesstepsmap' VALUES (25500, 4127, 5);
INSERT INTO 'dancesstepsmap' VALUES (25501, 8574, 2);
INSERT INTO 'dancesstepsmap' VALUES (25502, 16514, 3);
INSERT INTO 'dancesstepsmap' VALUES (25503, 19247, 4);
INSERT INTO 'dancesstepsmap' VALUES (25504, 19247, 5);
INSERT INTO 'dancesstepsmap' VALUES (25505, 17777, 4);
INSERT INTO 'dancesstepsmap' VALUES (25506, 17777, 5);
INSERT INTO 'dancesstepsmap' VALUES (25507, 17777, 1);
INSERT INTO 'dancesstepsmap' VALUES (25508, 17777, 2);
INSERT INTO 'dancesstepsmap' VALUES (25509, 17777, 3);
INSERT INTO 'dancesstepsmap' VALUES (25510, 17779, 3);
INSERT INTO 'dancesstepsmap' VALUES (25511, 17779, 1);
INSERT INTO 'dancesstepsmap' VALUES (25512, 17772, 4);
INSERT INTO 'dancesstepsmap' VALUES (25513, 17772, 1);
INSERT INTO 'dancesstepsmap' VALUES (25514, 17772, 2);
INSERT INTO 'dancesstepsmap' VALUES (25515, 17772, 3);
INSERT INTO 'dancesstepsmap' VALUES (25516, 17782, 3);
INSERT INTO 'dancesstepsmap' VALUES (25517, 19248, 2);
INSERT INTO 'dancesstepsmap' VALUES (25518, 19248, 1);
INSERT INTO 'dancesstepsmap' VALUES (25519, 19249, 3);
INSERT INTO 'dancesstepsmap' VALUES (25520, 19249, 1);
INSERT INTO 'dancesstepsmap' VALUES (25521, 14502, 1);
INSERT INTO 'dancesstepsmap' VALUES (25522, 14502, 3);
INSERT INTO 'dancesstepsmap' VALUES (25523, 14502, 2);
INSERT INTO 'dancesstepsmap' VALUES (25524, 12166, 2);
INSERT INTO 'dancesstepsmap' VALUES (25525, 13292, 2);
INSERT INTO 'dancesstepsmap' VALUES (25526, 13292, 1);
INSERT INTO 'dancesstepsmap' VALUES (25527, 19207, 1);
INSERT INTO 'dancesstepsmap' VALUES (25528, 19207, 2);
INSERT INTO 'dancesstepsmap' VALUES (25529, 19207, 3);
INSERT INTO 'dancesstepsmap' VALUES (25530, 19063, 4);
INSERT INTO 'dancesstepsmap' VALUES (25531, 19063, 5);
INSERT INTO 'dancesstepsmap' VALUES (25532, 19082, 1);
INSERT INTO 'dancesstepsmap' VALUES (25533, 19082, 3);
INSERT INTO 'dancesstepsmap' VALUES (25534, 4758, 5);
INSERT INTO 'dancesstepsmap' VALUES (25535, 19250, 3);
INSERT INTO 'dancesstepsmap' VALUES (25536, 19250, 1);
INSERT INTO 'dancesstepsmap' VALUES (25537, 19250, 2);
INSERT INTO 'dancesstepsmap' VALUES (25538, 19251, 4);
INSERT INTO 'dancesstepsmap' VALUES (25539, 19251, 5);
INSERT INTO 'dancesstepsmap' VALUES (25540, 214, 2);
INSERT INTO 'dancesstepsmap' VALUES (25541, 14474, 4);
INSERT INTO 'dancesstepsmap' VALUES (25542, 14474, 5);
INSERT INTO 'dancesstepsmap' VALUES (25543, 19252, 5);
INSERT INTO 'dancesstepsmap' VALUES (25544, 19252, 4);
INSERT INTO 'dancesstepsmap' VALUES (25545, 12324, 4);
INSERT INTO 'dancesstepsmap' VALUES (25546, 12324, 5);
INSERT INTO 'dancesstepsmap' VALUES (25547, 19255, 1);
INSERT INTO 'dancesstepsmap' VALUES (25548, 19255, 2);
INSERT INTO 'dancesstepsmap' VALUES (25549, 19255, 3);
INSERT INTO 'dancesstepsmap' VALUES (25550, 19256, 1);
INSERT INTO 'dancesstepsmap' VALUES (25551, 19256, 2);
INSERT INTO 'dancesstepsmap' VALUES (25552, 19257, 4);
INSERT INTO 'dancesstepsmap' VALUES (25553, 14017, 4);
INSERT INTO 'dancesstepsmap' VALUES (25554, 14017, 5);
INSERT INTO 'dancesstepsmap' VALUES (25555, 13163, 1);
INSERT INTO 'dancesstepsmap' VALUES (25556, 13163, 2);
INSERT INTO 'dancesstepsmap' VALUES (25557, 732, 4);
INSERT INTO 'dancesstepsmap' VALUES (25558, 732, 5);
INSERT INTO 'dancesstepsmap' VALUES (25559, 732, 1);
INSERT INTO 'dancesstepsmap' VALUES (25560, 732, 2);
INSERT INTO 'dancesstepsmap' VALUES (25561, 19258, 4);
INSERT INTO 'dancesstepsmap' VALUES (25562, 19258, 5);
INSERT INTO 'dancesstepsmap' VALUES (25563, 19259, 1);
INSERT INTO 'dancesstepsmap' VALUES (25564, 19260, 4);
INSERT INTO 'dancesstepsmap' VALUES (25565, 19260, 5);
INSERT INTO 'dancesstepsmap' VALUES (25566, 19261, 1);
INSERT INTO 'dancesstepsmap' VALUES (25567, 19261, 2);
INSERT INTO 'dancesstepsmap' VALUES (25568, 19262, 2);
INSERT INTO 'dancesstepsmap' VALUES (25569, 19262, 1);
INSERT INTO 'dancesstepsmap' VALUES (25570, 19262, 3);
INSERT INTO 'dancesstepsmap' VALUES (25571, 19263, 4);
INSERT INTO 'dancesstepsmap' VALUES (25572, 19263, 5);
INSERT INTO 'dancesstepsmap' VALUES (25573, 19264, 1);
INSERT INTO 'dancesstepsmap' VALUES (25574, 19264, 2);
INSERT INTO 'dancesstepsmap' VALUES (25575, 19265, 1);
INSERT INTO 'dancesstepsmap' VALUES (25576, 19265, 2);
INSERT INTO 'dancesstepsmap' VALUES (25577, 19266, 5);
INSERT INTO 'dancesstepsmap' VALUES (25578, 19266, 4);
INSERT INTO 'dancesstepsmap' VALUES (25579, 19267, 1);
INSERT INTO 'dancesstepsmap' VALUES (25580, 19267, 2);
INSERT INTO 'dancesstepsmap' VALUES (25581, 19269, 4);
INSERT INTO 'dancesstepsmap' VALUES (25582, 5359, 9);
INSERT INTO 'dancesstepsmap' VALUES (25583, 5359, 6);
INSERT INTO 'dancesstepsmap' VALUES (25584, 13889, 1);
INSERT INTO 'dancesstepsmap' VALUES (25585, 13637, 5);
INSERT INTO 'dancesstepsmap' VALUES (25586, 11645, 1);
INSERT INTO 'dancesstepsmap' VALUES (25587, 11645, 2);
INSERT INTO 'dancesstepsmap' VALUES (25588, 11645, 3);
INSERT INTO 'dancesstepsmap' VALUES (25589, 19270, 99);
INSERT INTO 'dancesstepsmap' VALUES (25590, 19271, 3);
INSERT INTO 'dancesstepsmap' VALUES (25591, 19271, 1);
INSERT INTO 'dancesstepsmap' VALUES (25592, 19271, 2);
INSERT INTO 'dancesstepsmap' VALUES (25593, 19272, 1);
INSERT INTO 'dancesstepsmap' VALUES (25594, 19272, 2);
INSERT INTO 'dancesstepsmap' VALUES (25595, 18851, 1);
INSERT INTO 'dancesstepsmap' VALUES (25596, 18851, 2);
INSERT INTO 'dancesstepsmap' VALUES (25597, 18851, 3);
INSERT INTO 'dancesstepsmap' VALUES (25598, 19273, 1);
INSERT INTO 'dancesstepsmap' VALUES (25599, 19273, 3);
INSERT INTO 'dancesstepsmap' VALUES (25600, 19273, 2);
INSERT INTO 'dancesstepsmap' VALUES (25601, 10268, 2);
INSERT INTO 'dancesstepsmap' VALUES (25602, 19274, 5);
INSERT INTO 'dancesstepsmap' VALUES (25603, 19274, 4);
INSERT INTO 'dancesstepsmap' VALUES (25604, 232, 5);
INSERT INTO 'dancesstepsmap' VALUES (25605, 19083, 1);
INSERT INTO 'dancesstepsmap' VALUES (25606, 19083, 2);
INSERT INTO 'dancesstepsmap' VALUES (25607, 19083, 3);
INSERT INTO 'dancesstepsmap' VALUES (25608, 19081, 5);
INSERT INTO 'dancesstepsmap' VALUES (25609, 19081, 4);
INSERT INTO 'dancesstepsmap' VALUES (25610, 15837, 2);
INSERT INTO 'dancesstepsmap' VALUES (25611, 8149, 2);
INSERT INTO 'dancesstepsmap' VALUES (25612, 8149, 99);
INSERT INTO 'dancesstepsmap' VALUES (25613, 2101, 1);
INSERT INTO 'dancesstepsmap' VALUES (25614, 2101, 2);
INSERT INTO 'dancesstepsmap' VALUES (25615, 2101, 3);
INSERT INTO 'dancesstepsmap' VALUES (25616, 2101, 4);
INSERT INTO 'dancesstepsmap' VALUES (25617, 2101, 5);
INSERT INTO 'dancesstepsmap' VALUES (25618, 2313, 2);
INSERT INTO 'dancesstepsmap' VALUES (25619, 2313, 102);
INSERT INTO 'dancesstepsmap' VALUES (25620, 8091, 102);
INSERT INTO 'dancesstepsmap' VALUES (25470, 751, 102);
INSERT INTO 'dancesstepsmap' VALUES (25621, 751, 2);
INSERT INTO 'dancesstepsmap' VALUES (25622, 11196, 4);
INSERT INTO 'dancesstepsmap' VALUES (25623, 11196, 5);
INSERT INTO 'dancesstepsmap' VALUES (25624, 11196, 1);
INSERT INTO 'dancesstepsmap' VALUES (25625, 11196, 2);
INSERT INTO 'dancesstepsmap' VALUES (25626, 11196, 3);
INSERT INTO 'dancesstepsmap' VALUES (25627, 11196, 6);
INSERT INTO 'dancesstepsmap' VALUES (25628, 11196, 102);
INSERT INTO 'dancesstepsmap' VALUES (25629, 195, 102);
INSERT INTO 'dancesstepsmap' VALUES (25630, 458, 102);
INSERT INTO 'dancesstepsmap' VALUES (25631, 12166, 102);
INSERT INTO 'dancesstepsmap' VALUES (25632, 16690, 102);
INSERT INTO 'dancesstepsmap' VALUES (25633, 1897, 102);
INSERT INTO 'dancesstepsmap' VALUES (25634, 2269, 2);
INSERT INTO 'dancesstepsmap' VALUES (25635, 2269, 102);
INSERT INTO 'dancesstepsmap' VALUES (25636, 2536, 102);
INSERT INTO 'dancesstepsmap' VALUES (25637, 2536, 2);
INSERT INTO 'dancesstepsmap' VALUES (25638, 3202, 102);
INSERT INTO 'dancesstepsmap' VALUES (14663, 3941, 102);
INSERT INTO 'dancesstepsmap' VALUES (25639, 3973, 102);
INSERT INTO 'dancesstepsmap' VALUES (25640, 19275, 1);
INSERT INTO 'dancesstepsmap' VALUES (25641, 19275, 2);
INSERT INTO 'dancesstepsmap' VALUES (25643, 11972, 102);
INSERT INTO 'dancesstepsmap' VALUES (25644, 4317, 4);
INSERT INTO 'dancesstepsmap' VALUES (25645, 4317, 5);
INSERT INTO 'dancesstepsmap' VALUES (25646, 4317, 1);
INSERT INTO 'dancesstepsmap' VALUES (25647, 4317, 2);
INSERT INTO 'dancesstepsmap' VALUES (25648, 4317, 102);
INSERT INTO 'dancesstepsmap' VALUES (25649, 4317, 10);
INSERT INTO 'dancesstepsmap' VALUES (25650, 5306, 102);
INSERT INTO 'dancesstepsmap' VALUES (25652, 5642, 2);
INSERT INTO 'dancesstepsmap' VALUES (25653, 5642, 102);
INSERT INTO 'dancesstepsmap' VALUES (25654, 7079, 102);
INSERT INTO 'dancesstepsmap' VALUES (13716, 11915, 2);
INSERT INTO 'dancesstepsmap' VALUES (25655, 11915, 102);
INSERT INTO 'dancesstepsmap' VALUES (11080, 7544, 102);
INSERT INTO 'dancesstepsmap' VALUES (25656, 6299, 102);
INSERT INTO 'dancesstepsmap' VALUES (25657, 9539, 102);
INSERT INTO 'dancesstepsmap' VALUES (25658, 9539, 2);
INSERT INTO 'dancesstepsmap' VALUES (21159, 4832, 102);
INSERT INTO 'dancesstepsmap' VALUES (11999, 9742, 102);
INSERT INTO 'dancesstepsmap' VALUES (12628, 4165, 102);
INSERT INTO 'dancesstepsmap' VALUES (25659, 17206, 4);
INSERT INTO 'dancesstepsmap' VALUES (25660, 17206, 5);
INSERT INTO 'dancesstepsmap' VALUES (25661, 17206, 1);
INSERT INTO 'dancesstepsmap' VALUES (25662, 17206, 2);
INSERT INTO 'dancesstepsmap' VALUES (25663, 17206, 102);
INSERT INTO 'dancesstepsmap' VALUES (11975, 10797, 102);
INSERT INTO 'dancesstepsmap' VALUES (25664, 2101, 102);
INSERT INTO 'dancesstepsmap' VALUES (25665, 10580, 102);
INSERT INTO 'dancesstepsmap' VALUES (17288, 153, 103);
INSERT INTO 'dancesstepsmap' VALUES (11837, 10580, 103);
INSERT INTO 'dancesstepsmap' VALUES (25666, 15056, 8);
INSERT INTO 'dancesstepsmap' VALUES (17157, 14561, 103);
INSERT INTO 'dancesstepsmap' VALUES (17154, 14560, 103);
INSERT INTO 'dancesstepsmap' VALUES (25667, 15526, 8);
INSERT INTO 'dancesstepsmap' VALUES (25668, 3180, 103);
INSERT INTO 'dancesstepsmap' VALUES (25669, 3715, 103);
INSERT INTO 'dancesstepsmap' VALUES (25670, 9539, 103);
INSERT INTO 'dancesstepsmap' VALUES (20963, 16736, 103);
INSERT INTO 'dancesstepsmap' VALUES (25671, 6513, 103);
INSERT INTO 'dancesstepsmap' VALUES (25672, 6568, 103);
INSERT INTO 'dancesstepsmap' VALUES (25673, 9824, 103);
INSERT INTO 'dancesstepsmap' VALUES (25674, 11972, 103);
INSERT INTO 'dancesstepsmap' VALUES (25675, 19067, 9);
INSERT INTO 'dancesstepsmap' VALUES (25676, 19067, 6);
INSERT INTO 'dancesstepsmap' VALUES (25677, 6805, 10);
INSERT INTO 'dancesstepsmap' VALUES (25678, 6805, 103);
INSERT INTO 'dancesstepsmap' VALUES (25679, 544, 5);
INSERT INTO 'dancesstepsmap' VALUES (25680, 544, 4);
INSERT INTO 'dancesstepsmap' VALUES (25681, 544, 1);
INSERT INTO 'dancesstepsmap' VALUES (25682, 544, 2);
INSERT INTO 'dancesstepsmap' VALUES (25683, 544, 103);
INSERT INTO 'dancesstepsmap' VALUES (25684, 544, 3);
INSERT INTO 'dancesstepsmap' VALUES (25685, 3854, 2);
INSERT INTO 'dancesstepsmap' VALUES (25686, 3854, 103);
INSERT INTO 'dancesstepsmap' VALUES (25687, 5458, 4);
INSERT INTO 'dancesstepsmap' VALUES (25688, 5458, 5);
INSERT INTO 'dancesstepsmap' VALUES (25689, 5458, 9);
INSERT INTO 'dancesstepsmap' VALUES (25690, 5458, 10);
INSERT INTO 'dancesstepsmap' VALUES (25691, 5458, 1);
INSERT INTO 'dancesstepsmap' VALUES (25692, 5458, 2);
INSERT INTO 'dancesstepsmap' VALUES (25693, 5458, 103);
INSERT INTO 'dancesstepsmap' VALUES (25694, 19276, 1);
INSERT INTO 'dancesstepsmap' VALUES (25695, 19078, 1);
INSERT INTO 'dancesstepsmap' VALUES (25696, 19078, 2);
INSERT INTO 'dancesstepsmap' VALUES (25697, 18589, 1);
INSERT INTO 'dancesstepsmap' VALUES (25698, 18589, 2);
INSERT INTO 'dancesstepsmap' VALUES (25699, 18589, 3);
INSERT INTO 'dancesstepsmap' VALUES (25700, 18407, 1);
INSERT INTO 'dancesstepsmap' VALUES (25701, 18407, 2);
INSERT INTO 'dancesstepsmap' VALUES (25702, 14945, 4);
INSERT INTO 'dancesstepsmap' VALUES (25703, 5305, 2);
INSERT INTO 'dancesstepsmap' VALUES (25704, 10515, 3);
INSERT INTO 'dancesstepsmap' VALUES (25705, 8193, 5);
INSERT INTO 'dancesstepsmap' VALUES (25706, 3134, 5);
INSERT INTO 'dancesstepsmap' VALUES (25707, 19277, 4);
INSERT INTO 'dancesstepsmap' VALUES (25708, 19277, 5);
INSERT INTO 'dancesstepsmap' VALUES (25709, 19278, 5);
INSERT INTO 'dancesstepsmap' VALUES (25710, 19278, 4);
INSERT INTO 'dancesstepsmap' VALUES (25711, 2616, 2);
INSERT INTO 'dancesstepsmap' VALUES (25712, 19281, 1);
INSERT INTO 'dancesstepsmap' VALUES (25713, 19281, 2);
INSERT INTO 'dancesstepsmap' VALUES (25714, 19281, 3);
INSERT INTO 'dancesstepsmap' VALUES (25715, 19212, 1);
INSERT INTO 'dancesstepsmap' VALUES (25716, 19212, 2);
INSERT INTO 'dancesstepsmap' VALUES (25717, 18618, 1);
INSERT INTO 'dancesstepsmap' VALUES (25718, 18618, 3);
INSERT INTO 'dancesstepsmap' VALUES (25719, 18613, 4);
INSERT INTO 'dancesstepsmap' VALUES (25720, 18613, 5);
INSERT INTO 'dancesstepsmap' VALUES (25721, 18398, 2);
INSERT INTO 'dancesstepsmap' VALUES (25722, 15602, 1);
INSERT INTO 'dancesstepsmap' VALUES (25723, 15602, 2);
INSERT INTO 'dancesstepsmap' VALUES (25724, 1834, 2);
INSERT INTO 'dancesstepsmap' VALUES (25725, 19282, 2);
INSERT INTO 'dancesstepsmap' VALUES (25726, 19282, 1);
INSERT INTO 'dancesstepsmap' VALUES (25727, 8346, 5);
INSERT INTO 'dancesstepsmap' VALUES (25728, 6672, 3);
INSERT INTO 'dancesstepsmap' VALUES (25729, 19079, 4);
INSERT INTO 'dancesstepsmap' VALUES (25730, 19079, 5);
INSERT INTO 'dancesstepsmap' VALUES (25731, 19283, 1);
INSERT INTO 'dancesstepsmap' VALUES (25732, 19283, 2);
INSERT INTO 'dancesstepsmap' VALUES (25733, 19284, 1);
INSERT INTO 'dancesstepsmap' VALUES (25734, 19284, 2);
INSERT INTO 'dancesstepsmap' VALUES (25735, 19284, 3);
INSERT INTO 'dancesstepsmap' VALUES (25736, 19285, 1);
INSERT INTO 'dancesstepsmap' VALUES (25737, 19285, 2);
INSERT INTO 'dancesstepsmap' VALUES (25738, 19286, 1);
INSERT INTO 'dancesstepsmap' VALUES (25739, 19286, 2);
INSERT INTO 'dancesstepsmap' VALUES (25742, 19279, 1);
INSERT INTO 'dancesstepsmap' VALUES (25743, 19279, 2);
INSERT INTO 'dancesstepsmap' VALUES (25744, 8770, 2);
INSERT INTO 'dancesstepsmap' VALUES (25745, 8770, 1);
INSERT INTO 'dancesstepsmap' VALUES (25746, 19288, 1);
INSERT INTO 'dancesstepsmap' VALUES (25747, 19288, 2);
INSERT INTO 'dancesstepsmap' VALUES (25748, 19288, 3);
INSERT INTO 'dancesstepsmap' VALUES (25749, 19290, 1);
INSERT INTO 'dancesstepsmap' VALUES (25750, 19290, 2);
INSERT INTO 'dancesstepsmap' VALUES (25751, 19290, 8);
INSERT INTO 'dancesstepsmap' VALUES (25752, 19291, 5);
INSERT INTO 'dancesstepsmap' VALUES (25753, 19291, 4);
INSERT INTO 'dancesstepsmap' VALUES (25754, 17803, 1);
INSERT INTO 'dancesstepsmap' VALUES (25755, 17803, 2);
INSERT INTO 'dancesstepsmap' VALUES (25756, 19292, 1);
INSERT INTO 'dancesstepsmap' VALUES (25757, 19292, 2);
INSERT INTO 'dancesstepsmap' VALUES (25758, 19293, 2);
INSERT INTO 'dancesstepsmap' VALUES (25759, 19293, 1);
INSERT INTO 'dancesstepsmap' VALUES (25760, 19293, 3);
INSERT INTO 'dancesstepsmap' VALUES (25761, 19294, 5);
INSERT INTO 'dancesstepsmap' VALUES (25762, 19294, 4);
INSERT INTO 'dancesstepsmap' VALUES (25763, 19295, 3);
INSERT INTO 'dancesstepsmap' VALUES (25764, 19295, 2);
INSERT INTO 'dancesstepsmap' VALUES (25765, 19295, 1);
INSERT INTO 'dancesstepsmap' VALUES (25766, 19296, 1);
INSERT INTO 'dancesstepsmap' VALUES (25767, 19296, 2);
INSERT INTO 'dancesstepsmap' VALUES (25768, 19296, 3);
INSERT INTO 'dancesstepsmap' VALUES (25769, 19297, 1);
INSERT INTO 'dancesstepsmap' VALUES (25770, 19297, 2);
INSERT INTO 'dancesstepsmap' VALUES (25771, 19298, 4);
INSERT INTO 'dancesstepsmap' VALUES (25772, 19298, 5);
INSERT INTO 'dancesstepsmap' VALUES (25773, 19299, 1);
INSERT INTO 'dancesstepsmap' VALUES (25774, 19299, 2);
INSERT INTO 'dancesstepsmap' VALUES (25775, 19300, 4);
INSERT INTO 'dancesstepsmap' VALUES (25776, 19300, 5);
INSERT INTO 'dancesstepsmap' VALUES (25777, 19301, 1);
INSERT INTO 'dancesstepsmap' VALUES (25781, 19303, 5);
INSERT INTO 'dancesstepsmap' VALUES (25782, 19303, 4);
INSERT INTO 'dancesstepsmap' VALUES (25783, 19304, 5);
INSERT INTO 'dancesstepsmap' VALUES (25784, 19304, 4);
INSERT INTO 'dancesstepsmap' VALUES (25785, 19304, 2);
INSERT INTO 'dancesstepsmap' VALUES (25786, 19304, 1);
INSERT INTO 'dancesstepsmap' VALUES (25787, 19305, 1);
INSERT INTO 'dancesstepsmap' VALUES (25788, 19305, 2);
INSERT INTO 'dancesstepsmap' VALUES (25789, 19306, 4);
INSERT INTO 'dancesstepsmap' VALUES (25790, 19306, 5);
INSERT INTO 'dancesstepsmap' VALUES (25791, 19307, 1);
INSERT INTO 'dancesstepsmap' VALUES (25792, 19307, 2);
INSERT INTO 'dancesstepsmap' VALUES (25793, 19308, 5);
INSERT INTO 'dancesstepsmap' VALUES (25794, 19308, 4);
INSERT INTO 'dancesstepsmap' VALUES (25795, 19309, 1);
INSERT INTO 'dancesstepsmap' VALUES (25796, 19309, 2);
INSERT INTO 'dancesstepsmap' VALUES (25797, 19309, 3);
INSERT INTO 'dancesstepsmap' VALUES (25798, 18531, 5);
INSERT INTO 'dancesstepsmap' VALUES (25799, 18531, 4);
INSERT INTO 'dancesstepsmap' VALUES (25800, 19310, 4);
INSERT INTO 'dancesstepsmap' VALUES (25801, 19310, 5);
INSERT INTO 'dancesstepsmap' VALUES (25802, 4612, 5);
INSERT INTO 'dancesstepsmap' VALUES (25803, 2574, 2);
INSERT INTO 'dancesstepsmap' VALUES (25804, 4386, 2);
INSERT INTO 'dancesstepsmap' VALUES (25805, 1425, 2);
INSERT INTO 'dancesstepsmap' VALUES (25806, 1425, 3);
INSERT INTO 'dancesstepsmap' VALUES (25807, 19354, 5);
INSERT INTO 'dancesstepsmap' VALUES (25808, 19354, 4);
INSERT INTO 'dancesstepsmap' VALUES (25809, 19355, 1);
INSERT INTO 'dancesstepsmap' VALUES (25810, 19355, 2);
INSERT INTO 'dancesstepsmap' VALUES (25811, 19356, 4);
INSERT INTO 'dancesstepsmap' VALUES (25812, 19356, 5);
INSERT INTO 'dancesstepsmap' VALUES (25813, 19357, 4);
INSERT INTO 'dancesstepsmap' VALUES (25814, 19357, 5);
INSERT INTO 'dancesstepsmap' VALUES (25815, 19358, 1);
INSERT INTO 'dancesstepsmap' VALUES (25816, 19359, 4);
INSERT INTO 'dancesstepsmap' VALUES (25817, 19360, 1);
INSERT INTO 'dancesstepsmap' VALUES (25818, 19360, 2);
INSERT INTO 'dancesstepsmap' VALUES (25819, 19360, 3);
INSERT INTO 'dancesstepsmap' VALUES (25820, 9425, 4);
INSERT INTO 'dancesstepsmap' VALUES (25821, 9425, 1);
INSERT INTO 'dancesstepsmap' VALUES (25822, 9425, 2);
INSERT INTO 'dancesstepsmap' VALUES (25823, 19361, 1);
INSERT INTO 'dancesstepsmap' VALUES (25824, 19361, 2);
INSERT INTO 'dancesstepsmap' VALUES (25825, 19361, 3);
INSERT INTO 'dancesstepsmap' VALUES (25826, 19362, 5);
INSERT INTO 'dancesstepsmap' VALUES (25827, 19362, 4);
INSERT INTO 'dancesstepsmap' VALUES (25828, 566, 2);
INSERT INTO 'dancesstepsmap' VALUES (25829, 13297, 5);
INSERT INTO 'dancesstepsmap' VALUES (25830, 13297, 4);
INSERT INTO 'dancesstepsmap' VALUES (25831, 6909, 5);
INSERT INTO 'dancesstepsmap' VALUES (25832, 10142, 1);
INSERT INTO 'dancesstepsmap' VALUES (25833, 10142, 2);
INSERT INTO 'dancesstepsmap' VALUES (25834, 10143, 5);
INSERT INTO 'dancesstepsmap' VALUES (25835, 10143, 4);
INSERT INTO 'dancesstepsmap' VALUES (25836, 10144, 1);
INSERT INTO 'dancesstepsmap' VALUES (25837, 10145, 4);
INSERT INTO 'dancesstepsmap' VALUES (25838, 10145, 5);
INSERT INTO 'dancesstepsmap' VALUES (25839, 10149, 5);
INSERT INTO 'dancesstepsmap' VALUES (15833, 13348, 1);
INSERT INTO 'dancesstepsmap' VALUES (25840, 13348, 2);
INSERT INTO 'dancesstepsmap' VALUES (25841, 13348, 3);
INSERT INTO 'dancesstepsmap' VALUES (25842, 19363, 4);
INSERT INTO 'dancesstepsmap' VALUES (25843, 19363, 5);
INSERT INTO 'dancesstepsmap' VALUES (25844, 19364, 2);
INSERT INTO 'dancesstepsmap' VALUES (25845, 19364, 1);
INSERT INTO 'dancesstepsmap' VALUES (25846, 17309, 1);
INSERT INTO 'dancesstepsmap' VALUES (25847, 17309, 2);
INSERT INTO 'dancesstepsmap' VALUES (25848, 19365, 2);
INSERT INTO 'dancesstepsmap' VALUES (25849, 19365, 1);
INSERT INTO 'dancesstepsmap' VALUES (25850, 19366, 4);
INSERT INTO 'dancesstepsmap' VALUES (25851, 19366, 5);
INSERT INTO 'dancesstepsmap' VALUES (25852, 19367, 5);
INSERT INTO 'dancesstepsmap' VALUES (25853, 19367, 4);
INSERT INTO 'dancesstepsmap' VALUES (25854, 19368, 2);
INSERT INTO 'dancesstepsmap' VALUES (25855, 19368, 1);
INSERT INTO 'dancesstepsmap' VALUES (25856, 19368, 3);
INSERT INTO 'dancesstepsmap' VALUES (25857, 19369, 3);
INSERT INTO 'dancesstepsmap' VALUES (25858, 19369, 2);
INSERT INTO 'dancesstepsmap' VALUES (25859, 19369, 1);
INSERT INTO 'dancesstepsmap' VALUES (25860, 19370, 1);
INSERT INTO 'dancesstepsmap' VALUES (25861, 19370, 3);
INSERT INTO 'dancesstepsmap' VALUES (25862, 19370, 2);
INSERT INTO 'dancesstepsmap' VALUES (25863, 19371, 5);
INSERT INTO 'dancesstepsmap' VALUES (25864, 19371, 4);
INSERT INTO 'dancesstepsmap' VALUES (25865, 19372, 2);
INSERT INTO 'dancesstepsmap' VALUES (25866, 19372, 1);
INSERT INTO 'dancesstepsmap' VALUES (25867, 19373, 2);
INSERT INTO 'dancesstepsmap' VALUES (25868, 19373, 1);
INSERT INTO 'dancesstepsmap' VALUES (25869, 19373, 3);
INSERT INTO 'dancesstepsmap' VALUES (25870, 6443, 2);
INSERT INTO 'dancesstepsmap' VALUES (25871, 19374, 5);
INSERT INTO 'dancesstepsmap' VALUES (25872, 19374, 4);
INSERT INTO 'dancesstepsmap' VALUES (25873, 19375, 2);
INSERT INTO 'dancesstepsmap' VALUES (25874, 19375, 1);
INSERT INTO 'dancesstepsmap' VALUES (25875, 19376, 2);
INSERT INTO 'dancesstepsmap' VALUES (25876, 19376, 1);
INSERT INTO 'dancesstepsmap' VALUES (25877, 19377, 1);
INSERT INTO 'dancesstepsmap' VALUES (25878, 19378, 2);
INSERT INTO 'dancesstepsmap' VALUES (25879, 19378, 1);
INSERT INTO 'dancesstepsmap' VALUES (25880, 19378, 3);
INSERT INTO 'dancesstepsmap' VALUES (25881, 19379, 5);
INSERT INTO 'dancesstepsmap' VALUES (25882, 19379, 4);
INSERT INTO 'dancesstepsmap' VALUES (25883, 19382, 1);
INSERT INTO 'dancesstepsmap' VALUES (25884, 19382, 2);
INSERT INTO 'dancesstepsmap' VALUES (25885, 19384, 5);
INSERT INTO 'dancesstepsmap' VALUES (25886, 19384, 4);
INSERT INTO 'dancesstepsmap' VALUES (25887, 19380, 1);
INSERT INTO 'dancesstepsmap' VALUES (25888, 19380, 2);
INSERT INTO 'dancesstepsmap' VALUES (25889, 19381, 4);
INSERT INTO 'dancesstepsmap' VALUES (25890, 19381, 5);
INSERT INTO 'dancesstepsmap' VALUES (25891, 19385, 1);
INSERT INTO 'dancesstepsmap' VALUES (25892, 19386, 2);
INSERT INTO 'dancesstepsmap' VALUES (25893, 19386, 1);
INSERT INTO 'dancesstepsmap' VALUES (25894, 2236, 2);
INSERT INTO 'dancesstepsmap' VALUES (25895, 17502, 1);
INSERT INTO 'dancesstepsmap' VALUES (25896, 19387, 5);
INSERT INTO 'dancesstepsmap' VALUES (25897, 19387, 4);
INSERT INTO 'dancesstepsmap' VALUES (25898, 19388, 3);
INSERT INTO 'dancesstepsmap' VALUES (25899, 19388, 1);
INSERT INTO 'dancesstepsmap' VALUES (25900, 19388, 2);
INSERT INTO 'dancesstepsmap' VALUES (25901, 19389, 1);
INSERT INTO 'dancesstepsmap' VALUES (25902, 19390, 3);
INSERT INTO 'dancesstepsmap' VALUES (25903, 19390, 1);
INSERT INTO 'dancesstepsmap' VALUES (25904, 19391, 2);
INSERT INTO 'dancesstepsmap' VALUES (25905, 19391, 1);
INSERT INTO 'dancesstepsmap' VALUES (25906, 19392, 1);
INSERT INTO 'dancesstepsmap' VALUES (25907, 19392, 3);
INSERT INTO 'dancesstepsmap' VALUES (25908, 19228, 1);
INSERT INTO 'dancesstepsmap' VALUES (25909, 13214, 2);
INSERT INTO 'dancesstepsmap' VALUES (25910, 13214, 3);
INSERT INTO 'dancesstepsmap' VALUES (25911, 19393, 4);
INSERT INTO 'dancesstepsmap' VALUES (25912, 19393, 5);
INSERT INTO 'dancesstepsmap' VALUES (25913, 17462, 3);
INSERT INTO 'dancesstepsmap' VALUES (25914, 17462, 1);
INSERT INTO 'dancesstepsmap' VALUES (25915, 7419, 2);
INSERT INTO 'dancesstepsmap' VALUES (25916, 10638, 2);
INSERT INTO 'dancesstepsmap' VALUES (25917, 10638, 1);
INSERT INTO 'dancesstepsmap' VALUES (25918, 19394, 1);
INSERT INTO 'dancesstepsmap' VALUES (25919, 19394, 2);
INSERT INTO 'dancesstepsmap' VALUES (25920, 11804, 1);
INSERT INTO 'dancesstepsmap' VALUES (25921, 11804, 3);
INSERT INTO 'dancesstepsmap' VALUES (25922, 5882, 5);
INSERT INTO 'dancesstepsmap' VALUES (25923, 19395, 1);
INSERT INTO 'dancesstepsmap' VALUES (25924, 19395, 2);
INSERT INTO 'dancesstepsmap' VALUES (25925, 19396, 5);
INSERT INTO 'dancesstepsmap' VALUES (25926, 19396, 4);
INSERT INTO 'dancesstepsmap' VALUES (25927, 2068, 2);
INSERT INTO 'dancesstepsmap' VALUES (25928, 1569, 2);
INSERT INTO 'dancesstepsmap' VALUES (25929, 12807, 5);
INSERT INTO 'dancesstepsmap' VALUES (25930, 12807, 4);
INSERT INTO 'dancesstepsmap' VALUES (25931, 3284, 6);
INSERT INTO 'dancesstepsmap' VALUES (25932, 9236, 2);
INSERT INTO 'dancesstepsmap' VALUES (25933, 9236, 1);
INSERT INTO 'dancesstepsmap' VALUES (25934, 782, 5);
INSERT INTO 'dancesstepsmap' VALUES (25935, 16832, 5);
INSERT INTO 'dancesstepsmap' VALUES (25936, 16832, 4);
INSERT INTO 'dancesstepsmap' VALUES (25937, 19397, 5);
INSERT INTO 'dancesstepsmap' VALUES (25938, 19397, 4);
INSERT INTO 'dancesstepsmap' VALUES (25939, 19398, 4);
INSERT INTO 'dancesstepsmap' VALUES (25940, 19398, 5);
INSERT INTO 'dancesstepsmap' VALUES (25941, 19399, 4);
INSERT INTO 'dancesstepsmap' VALUES (25942, 19399, 5);
INSERT INTO 'dancesstepsmap' VALUES (25943, 19400, 1);
INSERT INTO 'dancesstepsmap' VALUES (25944, 19400, 2);
INSERT INTO 'dancesstepsmap' VALUES (25945, 19401, 1);
INSERT INTO 'dancesstepsmap' VALUES (25946, 19401, 2);
INSERT INTO 'dancesstepsmap' VALUES (25947, 19402, 1);
INSERT INTO 'dancesstepsmap' VALUES (25948, 19402, 2);
INSERT INTO 'dancesstepsmap' VALUES (25949, 19403, 1);
INSERT INTO 'dancesstepsmap' VALUES (25950, 19403, 2);
INSERT INTO 'dancesstepsmap' VALUES (25951, 19405, 1);
INSERT INTO 'dancesstepsmap' VALUES (25952, 15315, 5);
INSERT INTO 'dancesstepsmap' VALUES (25953, 15315, 4);
INSERT INTO 'dancesstepsmap' VALUES (25954, 19404, 4);
INSERT INTO 'dancesstepsmap' VALUES (25955, 19404, 5);
INSERT INTO 'dancesstepsmap' VALUES (25956, 19407, 1);
INSERT INTO 'dancesstepsmap' VALUES (25957, 1654, 5);
INSERT INTO 'dancesstepsmap' VALUES (25958, 15312, 5);
INSERT INTO 'dancesstepsmap' VALUES (25959, 15312, 4);
INSERT INTO 'dancesstepsmap' VALUES (25960, 15312, 9);
INSERT INTO 'dancesstepsmap' VALUES (25961, 14237, 3);
INSERT INTO 'dancesstepsmap' VALUES (25962, 14237, 2);
INSERT INTO 'dancesstepsmap' VALUES (25963, 14237, 1);
INSERT INTO 'dancesstepsmap' VALUES (25964, 19409, 4);
INSERT INTO 'dancesstepsmap' VALUES (25965, 19409, 5);
INSERT INTO 'dancesstepsmap' VALUES (25966, 14944, 5);
INSERT INTO 'dancesstepsmap' VALUES (25967, 14944, 4);
INSERT INTO 'dancesstepsmap' VALUES (25968, 19410, 1);
INSERT INTO 'dancesstepsmap' VALUES (25969, 8865, 2);
INSERT INTO 'dancesstepsmap' VALUES (25970, 8865, 1);
INSERT INTO 'dancesstepsmap' VALUES (25971, 8865, 3);
INSERT INTO 'dancesstepsmap' VALUES (15229, 12913, 4);
INSERT INTO 'dancesstepsmap' VALUES (15230, 12913, 5);
INSERT INTO 'dancesstepsmap' VALUES (25972, 19411, 1);
INSERT INTO 'dancesstepsmap' VALUES (25973, 529, 2);
INSERT INTO 'dancesstepsmap' VALUES (25974, 529, 3);
INSERT INTO 'dancesstepsmap' VALUES (25977, 19413, 1);
INSERT INTO 'dancesstepsmap' VALUES (25980, 19414, 3);
INSERT INTO 'dancesstepsmap' VALUES (25981, 19415, 1);
INSERT INTO 'dancesstepsmap' VALUES (25982, 19415, 2);
INSERT INTO 'dancesstepsmap' VALUES (25983, 19416, 4);
INSERT INTO 'dancesstepsmap' VALUES (25984, 19416, 5);
INSERT INTO 'dancesstepsmap' VALUES (25985, 19417, 5);
INSERT INTO 'dancesstepsmap' VALUES (25986, 19417, 4);
INSERT INTO 'dancesstepsmap' VALUES (25987, 19418, 2);
INSERT INTO 'dancesstepsmap' VALUES (25988, 19418, 1);
INSERT INTO 'dancesstepsmap' VALUES (25989, 19419, 1);
INSERT INTO 'dancesstepsmap' VALUES (25990, 19419, 2);
INSERT INTO 'dancesstepsmap' VALUES (25991, 19420, 1);
INSERT INTO 'dancesstepsmap' VALUES (25992, 19420, 2);
INSERT INTO 'dancesstepsmap' VALUES (25993, 19421, 4);
INSERT INTO 'dancesstepsmap' VALUES (25994, 19421, 5);
INSERT INTO 'dancesstepsmap' VALUES (25995, 19422, 1);
INSERT INTO 'dancesstepsmap' VALUES (25996, 19422, 2);
INSERT INTO 'dancesstepsmap' VALUES (25975, 19412, 4);
INSERT INTO 'dancesstepsmap' VALUES (25976, 19412, 5);
INSERT INTO 'dancesstepsmap' VALUES (25978, 19414, 1);
INSERT INTO 'dancesstepsmap' VALUES (25979, 19414, 2);
INSERT INTO 'dancesstepsmap' VALUES (25997, 3955, 102);
INSERT INTO 'dancesstepsmap' VALUES (25998, 3955, 103);
INSERT INTO 'dancesstepsmap' VALUES (25999, 3955, 2);
INSERT INTO 'dancesstepsmap' VALUES (26000, 19428, 1);
INSERT INTO 'dancesstepsmap' VALUES (26001, 19427, 4);
INSERT INTO 'dancesstepsmap' VALUES (26002, 19427, 5);
INSERT INTO 'dancesstepsmap' VALUES (26003, 17510, 1);
INSERT INTO 'dancesstepsmap' VALUES (26004, 17510, 2);
INSERT INTO 'dancesstepsmap' VALUES (26005, 17510, 3);
INSERT INTO 'dancesstepsmap' VALUES (26006, 17511, 10);
INSERT INTO 'dancesstepsmap' VALUES (26007, 17511, 4);
INSERT INTO 'dancesstepsmap' VALUES (26008, 17511, 5);
INSERT INTO 'dancesstepsmap' VALUES (26009, 17511, 9);
INSERT INTO 'dancesstepsmap' VALUES (26010, 17511, 102);
INSERT INTO 'dancesstepsmap' VALUES (26011, 17511, 1);
INSERT INTO 'dancesstepsmap' VALUES (26012, 17511, 2);
INSERT INTO 'dancesstepsmap' VALUES (26013, 17511, 103);
INSERT INTO 'dancesstepsmap' VALUES (26014, 17513, 1);
INSERT INTO 'dancesstepsmap' VALUES (26015, 17513, 2);
INSERT INTO 'dancesstepsmap' VALUES (26016, 17514, 2);
INSERT INTO 'dancesstepsmap' VALUES (26017, 17514, 1);
INSERT INTO 'dancesstepsmap' VALUES (26018, 17514, 3);
INSERT INTO 'dancesstepsmap' VALUES (26019, 17515, 1);
INSERT INTO 'dancesstepsmap' VALUES (26020, 17515, 2);
INSERT INTO 'dancesstepsmap' VALUES (26021, 17517, 4);
INSERT INTO 'dancesstepsmap' VALUES (26022, 17517, 5);
INSERT INTO 'dancesstepsmap' VALUES (26023, 17518, 4);
INSERT INTO 'dancesstepsmap' VALUES (26024, 17518, 5);
INSERT INTO 'dancesstepsmap' VALUES (26025, 17518, 6);
INSERT INTO 'dancesstepsmap' VALUES (26026, 17519, 4);
INSERT INTO 'dancesstepsmap' VALUES (26027, 17519, 5);
INSERT INTO 'dancesstepsmap' VALUES (26028, 17520, 1);
INSERT INTO 'dancesstepsmap' VALUES (26029, 17520, 3);
INSERT INTO 'dancesstepsmap' VALUES (26030, 17521, 4);
INSERT INTO 'dancesstepsmap' VALUES (26031, 17521, 5);
INSERT INTO 'dancesstepsmap' VALUES (26032, 17521, 6);
INSERT INTO 'dancesstepsmap' VALUES (26033, 17522, 3);
INSERT INTO 'dancesstepsmap' VALUES (26034, 17522, 1);
INSERT INTO 'dancesstepsmap' VALUES (26035, 17522, 2);
INSERT INTO 'dancesstepsmap' VALUES (26036, 19429, 4);
INSERT INTO 'dancesstepsmap' VALUES (26037, 19429, 5);
INSERT INTO 'dancesstepsmap' VALUES (26038, 19430, 1);
INSERT INTO 'dancesstepsmap' VALUES (26039, 19430, 3);
INSERT INTO 'dancesstepsmap' VALUES (26040, 19430, 2);
INSERT INTO 'dancesstepsmap' VALUES (26041, 19431, 4);
INSERT INTO 'dancesstepsmap' VALUES (26042, 19431, 5);
INSERT INTO 'dancesstepsmap' VALUES (26043, 19440, 1);
INSERT INTO 'dancesstepsmap' VALUES (26044, 19440, 3);
INSERT INTO 'dancesstepsmap' VALUES (26045, 19463, 1);
INSERT INTO 'dancesstepsmap' VALUES (26046, 19463, 2);
INSERT INTO 'dancesstepsmap' VALUES (26047, 19442, 4);
INSERT INTO 'dancesstepsmap' VALUES (26048, 19442, 5);
INSERT INTO 'dancesstepsmap' VALUES (26049, 9496, 1);
INSERT INTO 'dancesstepsmap' VALUES (26050, 9496, 2);
INSERT INTO 'dancesstepsmap' VALUES (26051, 9496, 3);
INSERT INTO 'dancesstepsmap' VALUES (26052, 9496, 5);
INSERT INTO 'dancesstepsmap' VALUES (26053, 9496, 4);
INSERT INTO 'dancesstepsmap' VALUES (26054, 19461, 1);
INSERT INTO 'dancesstepsmap' VALUES (26055, 19460, 1);
INSERT INTO 'dancesstepsmap' VALUES (26056, 10241, 5);
INSERT INTO 'dancesstepsmap' VALUES (26057, 13574, 1);
INSERT INTO 'dancesstepsmap' VALUES (26058, 13574, 3);
INSERT INTO 'dancesstepsmap' VALUES (26059, 2582, 2);
INSERT INTO 'dancesstepsmap' VALUES (26060, 15601, 1);
INSERT INTO 'dancesstepsmap' VALUES (26061, 19464, 2);
INSERT INTO 'dancesstepsmap' VALUES (26062, 19464, 1);
INSERT INTO 'dancesstepsmap' VALUES (26063, 19465, 4);
INSERT INTO 'dancesstepsmap' VALUES (26064, 19465, 5);
INSERT INTO 'dancesstepsmap' VALUES (26065, 19466, 1);
INSERT INTO 'dancesstepsmap' VALUES (26066, 19466, 2);
INSERT INTO 'dancesstepsmap' VALUES (26067, 19466, 3);
INSERT INTO 'dancesstepsmap' VALUES (26068, 19467, 2);
INSERT INTO 'dancesstepsmap' VALUES (26069, 19467, 1);
INSERT INTO 'dancesstepsmap' VALUES (26070, 19467, 3);
INSERT INTO 'dancesstepsmap' VALUES (26071, 19468, 1);
INSERT INTO 'dancesstepsmap' VALUES (26072, 19468, 2);
INSERT INTO 'dancesstepsmap' VALUES (26073, 19468, 102);
INSERT INTO 'dancesstepsmap' VALUES (26074, 19469, 4);
INSERT INTO 'dancesstepsmap' VALUES (26075, 19469, 5);
INSERT INTO 'dancesstepsmap' VALUES (26076, 19470, 1);
INSERT INTO 'dancesstepsmap' VALUES (26077, 19470, 2);
INSERT INTO 'dancesstepsmap' VALUES (26078, 19470, 3);
INSERT INTO 'dancesstepsmap' VALUES (26079, 647, 2);
INSERT INTO 'dancesstepsmap' VALUES (26080, 14567, 4);
INSERT INTO 'dancesstepsmap' VALUES (26081, 14567, 5);
INSERT INTO 'dancesstepsmap' VALUES (26082, 18669, 2);
INSERT INTO 'dancesstepsmap' VALUES (26083, 18669, 1);
INSERT INTO 'dancesstepsmap' VALUES (26084, 19471, 4);
INSERT INTO 'dancesstepsmap' VALUES (26085, 1742, 5);
INSERT INTO 'dancesstepsmap' VALUES (26086, 19472, 1);
INSERT INTO 'dancesstepsmap' VALUES (26087, 19472, 3);
INSERT INTO 'dancesstepsmap' VALUES (26088, 19472, 2);
INSERT INTO 'dancesstepsmap' VALUES (26089, 14565, 4);
INSERT INTO 'dancesstepsmap' VALUES (26091, 19473, 5);
INSERT INTO 'dancesstepsmap' VALUES (26092, 19473, 4);
INSERT INTO 'dancesstepsmap' VALUES (26094, 427, 2);
INSERT INTO 'dancesstepsmap' VALUES (26095, 47, 3);
INSERT INTO 'dancesstepsmap' VALUES (26096, 47, 2);
INSERT INTO 'dancesstepsmap' VALUES (26097, 52, 3);
INSERT INTO 'dancesstepsmap' VALUES (26098, 8489, 2);
INSERT INTO 'dancesstepsmap' VALUES (26099, 2793, 2);
INSERT INTO 'dancesstepsmap' VALUES (26100, 18437, 4);
INSERT INTO 'dancesstepsmap' VALUES (26101, 18437, 5);
INSERT INTO 'dancesstepsmap' VALUES (26102, 15309, 1);
INSERT INTO 'dancesstepsmap' VALUES (26103, 15309, 2);
INSERT INTO 'dancesstepsmap' VALUES (26104, 15309, 3);
INSERT INTO 'dancesstepsmap' VALUES (26105, 2832, 2);
INSERT INTO 'dancesstepsmap' VALUES (26106, 18438, 1);
INSERT INTO 'dancesstepsmap' VALUES (26107, 18438, 2);
INSERT INTO 'dancesstepsmap' VALUES (26108, 18438, 3);
INSERT INTO 'dancesstepsmap' VALUES (26109, 4243, 2);
INSERT INTO 'dancesstepsmap' VALUES (26110, 19475, 1);
INSERT INTO 'dancesstepsmap' VALUES (26111, 19475, 3);
INSERT INTO 'dancesstepsmap' VALUES (26112, 16878, 1);
INSERT INTO 'dancesstepsmap' VALUES (26113, 16878, 2);
INSERT INTO 'dancesstepsmap' VALUES (26114, 19476, 1);
INSERT INTO 'dancesstepsmap' VALUES (26115, 19476, 2);
INSERT INTO 'dancesstepsmap' VALUES (26116, 19476, 3);
INSERT INTO 'dancesstepsmap' VALUES (26120, 19062, 1);
INSERT INTO 'dancesstepsmap' VALUES (26121, 19062, 2);
INSERT INTO 'dancesstepsmap' VALUES (26122, 19084, 4);
INSERT INTO 'dancesstepsmap' VALUES (26123, 19084, 5);
INSERT INTO 'dancesstepsmap' VALUES (26124, 19076, 1);
INSERT INTO 'dancesstepsmap' VALUES (26125, 19076, 2);
INSERT INTO 'dancesstepsmap' VALUES (26126, 19477, 4);
INSERT INTO 'dancesstepsmap' VALUES (26127, 19477, 5);
INSERT INTO 'dancesstepsmap' VALUES (26128, 19477, 9);
INSERT INTO 'dancesstepsmap' VALUES (26129, 19478, 1);
INSERT INTO 'dancesstepsmap' VALUES (26130, 19478, 2);
INSERT INTO 'dancesstepsmap' VALUES (26131, 19479, 2);
INSERT INTO 'dancesstepsmap' VALUES (26132, 19479, 1);
INSERT INTO 'dancesstepsmap' VALUES (26133, 19480, 4);
INSERT INTO 'dancesstepsmap' VALUES (26134, 19480, 5);
INSERT INTO 'dancesstepsmap' VALUES (26135, 19481, 1);
INSERT INTO 'dancesstepsmap' VALUES (26136, 19482, 5);
INSERT INTO 'dancesstepsmap' VALUES (26137, 19482, 4);
INSERT INTO 'dancesstepsmap' VALUES (26138, 19483, 4);
INSERT INTO 'dancesstepsmap' VALUES (26139, 19483, 5);
INSERT INTO 'dancesstepsmap' VALUES (26140, 19484, 1);
INSERT INTO 'dancesstepsmap' VALUES (26141, 19484, 2);
INSERT INTO 'dancesstepsmap' VALUES (26142, 19485, 2);
INSERT INTO 'dancesstepsmap' VALUES (26143, 19485, 1);
INSERT INTO 'dancesstepsmap' VALUES (26144, 19486, 2);
INSERT INTO 'dancesstepsmap' VALUES (26145, 19486, 1);
INSERT INTO 'dancesstepsmap' VALUES (26146, 19487, 1);
INSERT INTO 'dancesstepsmap' VALUES (26147, 19488, 2);
INSERT INTO 'dancesstepsmap' VALUES (26148, 19488, 1);
INSERT INTO 'dancesstepsmap' VALUES (26149, 19488, 3);
INSERT INTO 'dancesstepsmap' VALUES (26150, 19489, 2);
INSERT INTO 'dancesstepsmap' VALUES (26151, 19489, 1);
INSERT INTO 'dancesstepsmap' VALUES (26152, 19490, 1);
INSERT INTO 'dancesstepsmap' VALUES (26153, 19490, 2);
INSERT INTO 'dancesstepsmap' VALUES (26154, 19491, 4);
INSERT INTO 'dancesstepsmap' VALUES (26155, 19491, 5);
INSERT INTO 'dancesstepsmap' VALUES (26156, 19492, 4);
INSERT INTO 'dancesstepsmap' VALUES (26157, 19492, 5);
INSERT INTO 'dancesstepsmap' VALUES (26158, 19493, 4);
INSERT INTO 'dancesstepsmap' VALUES (26159, 19493, 5);
INSERT INTO 'dancesstepsmap' VALUES (26160, 19494, 1);
INSERT INTO 'dancesstepsmap' VALUES (26161, 19494, 2);
INSERT INTO 'dancesstepsmap' VALUES (26162, 19495, 5);
INSERT INTO 'dancesstepsmap' VALUES (26163, 19495, 4);
INSERT INTO 'dancesstepsmap' VALUES (26164, 19496, 4);
INSERT INTO 'dancesstepsmap' VALUES (26165, 19497, 2);
INSERT INTO 'dancesstepsmap' VALUES (26166, 19497, 1);
INSERT INTO 'dancesstepsmap' VALUES (26167, 12252, 2);
INSERT INTO 'dancesstepsmap' VALUES (26168, 12252, 1);
INSERT INTO 'dancesstepsmap' VALUES (26169, 12274, 4);
INSERT INTO 'dancesstepsmap' VALUES (26170, 12274, 5);
INSERT INTO 'dancesstepsmap' VALUES (26171, 19498, 2);
INSERT INTO 'dancesstepsmap' VALUES (26172, 19498, 1);
INSERT INTO 'dancesstepsmap' VALUES (26173, 19499, 1);
INSERT INTO 'dancesstepsmap' VALUES (26174, 12375, 2);
INSERT INTO 'dancesstepsmap' VALUES (26175, 12375, 1);
INSERT INTO 'dancesstepsmap' VALUES (26176, 19500, 2);
INSERT INTO 'dancesstepsmap' VALUES (26177, 19500, 1);
INSERT INTO 'dancesstepsmap' VALUES (26178, 19501, 2);
INSERT INTO 'dancesstepsmap' VALUES (26179, 19501, 1);
INSERT INTO 'dancesstepsmap' VALUES (26180, 15139, 1);
INSERT INTO 'dancesstepsmap' VALUES (26181, 12606, 5);
INSERT INTO 'dancesstepsmap' VALUES (26182, 19502, 4);
INSERT INTO 'dancesstepsmap' VALUES (26183, 4005, 2);
INSERT INTO 'dancesstepsmap' VALUES (26184, 4085, 2);
INSERT INTO 'dancesstepsmap' VALUES (26185, 19503, 1);
INSERT INTO 'dancesstepsmap' VALUES (26186, 19503, 2);
INSERT INTO 'dancesstepsmap' VALUES (26187, 19503, 3);
INSERT INTO 'dancesstepsmap' VALUES (26188, 19504, 4);
INSERT INTO 'dancesstepsmap' VALUES (26189, 18855, 1);
INSERT INTO 'dancesstepsmap' VALUES (26190, 18855, 2);
INSERT INTO 'dancesstepsmap' VALUES (26191, 18855, 3);
INSERT INTO 'dancesstepsmap' VALUES (26192, 19505, 5);
INSERT INTO 'dancesstepsmap' VALUES (26193, 19505, 4);
INSERT INTO 'dancesstepsmap' VALUES (26194, 19505, 1);
INSERT INTO 'dancesstepsmap' VALUES (26195, 19505, 2);
INSERT INTO 'dancesstepsmap' VALUES (26196, 19505, 3);
INSERT INTO 'dancesstepsmap' VALUES (26197, 19506, 1);
INSERT INTO 'dancesstepsmap' VALUES (26198, 19506, 2);
INSERT INTO 'dancesstepsmap' VALUES (26199, 19507, 1);
INSERT INTO 'dancesstepsmap' VALUES (26200, 19508, 4);
INSERT INTO 'dancesstepsmap' VALUES (26201, 14173, 1);
INSERT INTO 'dancesstepsmap' VALUES (26202, 14173, 2);
INSERT INTO 'dancesstepsmap' VALUES (26203, 14173, 3);
INSERT INTO 'dancesstepsmap' VALUES (26204, 3677, 2);
INSERT INTO 'dancesstepsmap' VALUES (26205, 19509, 1);
INSERT INTO 'dancesstepsmap' VALUES (26206, 19509, 2);
INSERT INTO 'dancesstepsmap' VALUES (26209, 1065, 5);
INSERT INTO 'dancesstepsmap' VALUES (26210, 3999, 6);
INSERT INTO 'dancesstepsmap' VALUES (26211, 19511, 1);
INSERT INTO 'dancesstepsmap' VALUES (26212, 19512, 1);
INSERT INTO 'dancesstepsmap' VALUES (26213, 19512, 3);
INSERT INTO 'dancesstepsmap' VALUES (26214, 19511, 3);
INSERT INTO 'dancesstepsmap' VALUES (26215, 19513, 5);
INSERT INTO 'dancesstepsmap' VALUES (26216, 19513, 4);
INSERT INTO 'dancesstepsmap' VALUES (26220, 19515, 1);
INSERT INTO 'dancesstepsmap' VALUES (26221, 19515, 3);
INSERT INTO 'dancesstepsmap' VALUES (26222, 1816, 2);
INSERT INTO 'dancesstepsmap' VALUES (26223, 19516, 1);
INSERT INTO 'dancesstepsmap' VALUES (26224, 19516, 2);
INSERT INTO 'dancesstepsmap' VALUES (26225, 19516, 3);
INSERT INTO 'dancesstepsmap' VALUES (26226, 12703, 4);
INSERT INTO 'dancesstepsmap' VALUES (26227, 12703, 5);
INSERT INTO 'dancesstepsmap' VALUES (26228, 14678, 1);
INSERT INTO 'dancesstepsmap' VALUES (26229, 14678, 2);
INSERT INTO 'dancesstepsmap' VALUES (26230, 14677, 1);
INSERT INTO 'dancesstepsmap' VALUES (26231, 19518, 4);
INSERT INTO 'dancesstepsmap' VALUES (26217, 19514, 4);
INSERT INTO 'dancesstepsmap' VALUES (26218, 19514, 5);
INSERT INTO 'dancesstepsmap' VALUES (26232, 19519, 1);
INSERT INTO 'dancesstepsmap' VALUES (26233, 19520, 4);
INSERT INTO 'dancesstepsmap' VALUES (26234, 19520, 5);
INSERT INTO 'dancesstepsmap' VALUES (26235, 19521, 1);
INSERT INTO 'dancesstepsmap' VALUES (26236, 19522, 1);
INSERT INTO 'dancesstepsmap' VALUES (26237, 19522, 3);
INSERT INTO 'dancesstepsmap' VALUES (26238, 19523, 2);
INSERT INTO 'dancesstepsmap' VALUES (26239, 19523, 1);
INSERT INTO 'dancesstepsmap' VALUES (26240, 19524, 4);
INSERT INTO 'dancesstepsmap' VALUES (26241, 19525, 1);
INSERT INTO 'dancesstepsmap' VALUES (26242, 19526, 1);
INSERT INTO 'dancesstepsmap' VALUES (26243, 19526, 2);
INSERT INTO 'dancesstepsmap' VALUES (26244, 19527, 5);
INSERT INTO 'dancesstepsmap' VALUES (26245, 19527, 4);
INSERT INTO 'dancesstepsmap' VALUES (26246, 19528, 1);
INSERT INTO 'dancesstepsmap' VALUES (26247, 19528, 3);
INSERT INTO 'dancesstepsmap' VALUES (26248, 19529, 1);
INSERT INTO 'dancesstepsmap' VALUES (26249, 19529, 2);
INSERT INTO 'dancesstepsmap' VALUES (26250, 19529, 3);
INSERT INTO 'dancesstepsmap' VALUES (26251, 19530, 1);
INSERT INTO 'dancesstepsmap' VALUES (26252, 19531, 2);
INSERT INTO 'dancesstepsmap' VALUES (26253, 19532, 4);
INSERT INTO 'dancesstepsmap' VALUES (26254, 19532, 5);
INSERT INTO 'dancesstepsmap' VALUES (26255, 19533, 2);
INSERT INTO 'dancesstepsmap' VALUES (26256, 19533, 1);
INSERT INTO 'dancesstepsmap' VALUES (26257, 19534, 2);
INSERT INTO 'dancesstepsmap' VALUES (26258, 19534, 1);
INSERT INTO 'dancesstepsmap' VALUES (26259, 19535, 1);
INSERT INTO 'dancesstepsmap' VALUES (26260, 19536, 2);
INSERT INTO 'dancesstepsmap' VALUES (26261, 19536, 1);
INSERT INTO 'dancesstepsmap' VALUES (26262, 19536, 3);
INSERT INTO 'dancesstepsmap' VALUES (26263, 19537, 1);
INSERT INTO 'dancesstepsmap' VALUES (26264, 19542, 1);
INSERT INTO 'dancesstepsmap' VALUES (26265, 19543, 5);
INSERT INTO 'dancesstepsmap' VALUES (26266, 19543, 4);
INSERT INTO 'dancesstepsmap' VALUES (26267, 19544, 1);
INSERT INTO 'dancesstepsmap' VALUES (26268, 19544, 2);
INSERT INTO 'dancesstepsmap' VALUES (26269, 19545, 1);
INSERT INTO 'dancesstepsmap' VALUES (26270, 19545, 2);
INSERT INTO 'dancesstepsmap' VALUES (26271, 19546, 1);
INSERT INTO 'dancesstepsmap' VALUES (26272, 19546, 2);
INSERT INTO 'dancesstepsmap' VALUES (26273, 19546, 3);
INSERT INTO 'dancesstepsmap' VALUES (26274, 19547, 4);
INSERT INTO 'dancesstepsmap' VALUES (26275, 19547, 5);
INSERT INTO 'dancesstepsmap' VALUES (26276, 19517, 1);
INSERT INTO 'dancesstepsmap' VALUES (26277, 19517, 2);
INSERT INTO 'dancesstepsmap' VALUES (26278, 19517, 3);
INSERT INTO 'dancesstepsmap' VALUES (26279, 19548, 2);
INSERT INTO 'dancesstepsmap' VALUES (26280, 19548, 1);
INSERT INTO 'dancesstepsmap' VALUES (26281, 19549, 2);
INSERT INTO 'dancesstepsmap' VALUES (26282, 19549, 1);
INSERT INTO 'dancesstepsmap' VALUES (26283, 19549, 3);
INSERT INTO 'dancesstepsmap' VALUES (26284, 19550, 5);
INSERT INTO 'dancesstepsmap' VALUES (26285, 19550, 4);
INSERT INTO 'dancesstepsmap' VALUES (26286, 14512, 1);
INSERT INTO 'dancesstepsmap' VALUES (26287, 14512, 2);
INSERT INTO 'dancesstepsmap' VALUES (26288, 14516, 1);
INSERT INTO 'dancesstepsmap' VALUES (26289, 19551, 4);
INSERT INTO 'dancesstepsmap' VALUES (26290, 19551, 5);
INSERT INTO 'dancesstepsmap' VALUES (26291, 14506, 4);
INSERT INTO 'dancesstepsmap' VALUES (26292, 14506, 5);
INSERT INTO 'dancesstepsmap' VALUES (26293, 19552, 2);
INSERT INTO 'dancesstepsmap' VALUES (26294, 19552, 1);
INSERT INTO 'dancesstepsmap' VALUES (26295, 19553, 4);
INSERT INTO 'dancesstepsmap' VALUES (26296, 19553, 5);
INSERT INTO 'dancesstepsmap' VALUES (26297, 6087, 5);
INSERT INTO 'dancesstepsmap' VALUES (26298, 14513, 4);
INSERT INTO 'dancesstepsmap' VALUES (26299, 14513, 5);
INSERT INTO 'dancesstepsmap' VALUES (26300, 19554, 1);
INSERT INTO 'dancesstepsmap' VALUES (26301, 19554, 2);
INSERT INTO 'dancesstepsmap' VALUES (26302, 606, 6);
INSERT INTO 'dancesstepsmap' VALUES (26303, 17250, 1);
INSERT INTO 'dancesstepsmap' VALUES (26304, 16926, 1);
INSERT INTO 'dancesstepsmap' VALUES (26305, 16926, 3);
INSERT INTO 'dancesstepsmap' VALUES (26093, 5225, 3);
INSERT INTO 'dancesstepsmap' VALUES (26306, 4421, 5);
INSERT INTO 'dancesstepsmap' VALUES (26307, 7218, 2);
INSERT INTO 'dancesstepsmap' VALUES (26308, 257, 2);
INSERT INTO 'dancesstepsmap' VALUES (26309, 257, 3);
INSERT INTO 'dancesstepsmap' VALUES (26310, 6181, 2);
INSERT INTO 'dancesstepsmap' VALUES (26311, 6181, 3);
INSERT INTO 'dancesstepsmap' VALUES (26312, 19560, 4);
INSERT INTO 'dancesstepsmap' VALUES (26313, 19560, 5);
INSERT INTO 'dancesstepsmap' VALUES (26314, 19561, 1);
INSERT INTO 'dancesstepsmap' VALUES (26315, 19562, 1);
INSERT INTO 'dancesstepsmap' VALUES (26316, 19563, 5);
INSERT INTO 'dancesstepsmap' VALUES (26317, 19563, 4);
INSERT INTO 'dancesstepsmap' VALUES (26318, 3965, 5);
INSERT INTO 'dancesstepsmap' VALUES (7801, 489, 3);
INSERT INTO 'dancesstepsmap' VALUES (26319, 560, 2);
INSERT INTO 'dancesstepsmap' VALUES (26320, 560, 3);
INSERT INTO 'dancesstepsmap' VALUES (26321, 17464, 1);
INSERT INTO 'dancesstepsmap' VALUES (26322, 15439, 2);
INSERT INTO 'dancesstepsmap' VALUES (26323, 3493, 5);
INSERT INTO 'dancesstepsmap' VALUES (26324, 3516, 2);
INSERT INTO 'dancesstepsmap' VALUES (26325, 13588, 2);
INSERT INTO 'dancesstepsmap' VALUES (26326, 13588, 1);
INSERT INTO 'dancesstepsmap' VALUES (26327, 1387, 2);
INSERT INTO 'dancesstepsmap' VALUES (26328, 6243, 2);
INSERT INTO 'dancesstepsmap' VALUES (26329, 6243, 3);
INSERT INTO 'dancesstepsmap' VALUES (26330, 261, 2);
INSERT INTO 'dancesstepsmap' VALUES (26331, 4992, 5);
INSERT INTO 'dancesstepsmap' VALUES (26332, 4818, 2);
INSERT INTO 'dancesstepsmap' VALUES (26333, 2709, 5);
INSERT INTO 'dancesstepsmap' VALUES (26334, 4954, 2);
INSERT INTO 'dancesstepsmap' VALUES (26335, 213, 5);
INSERT INTO 'dancesstepsmap' VALUES (26336, 2762, 2);
INSERT INTO 'dancesstepsmap' VALUES (26337, 2762, 3);
INSERT INTO 'dancesstepsmap' VALUES (26338, 3753, 2);
INSERT INTO 'dancesstepsmap' VALUES (26339, 3753, 3);
INSERT INTO 'dancesstepsmap' VALUES (26340, 1590, 2);
INSERT INTO 'dancesstepsmap' VALUES (26341, 19567, 1);
INSERT INTO 'dancesstepsmap' VALUES (26342, 19567, 2);
INSERT INTO 'dancesstepsmap' VALUES (26343, 19568, 5);
INSERT INTO 'dancesstepsmap' VALUES (26344, 19568, 4);
INSERT INTO 'dancesstepsmap' VALUES (26345, 19569, 1);
INSERT INTO 'dancesstepsmap' VALUES (26346, 19570, 1);
INSERT INTO 'dancesstepsmap' VALUES (26347, 19570, 2);
INSERT INTO 'dancesstepsmap' VALUES (26348, 19570, 3);
INSERT INTO 'dancesstepsmap' VALUES (26349, 19571, 2);
INSERT INTO 'dancesstepsmap' VALUES (26350, 19571, 1);
INSERT INTO 'dancesstepsmap' VALUES (26351, 19571, 3);
INSERT INTO 'dancesstepsmap' VALUES (26352, 19572, 4);
INSERT INTO 'dancesstepsmap' VALUES (26353, 19573, 1);
INSERT INTO 'dancesstepsmap' VALUES (26354, 19573, 2);
INSERT INTO 'dancesstepsmap' VALUES (26355, 19574, 1);
INSERT INTO 'dancesstepsmap' VALUES (26356, 19574, 3);
INSERT INTO 'dancesstepsmap' VALUES (26357, 19574, 2);
INSERT INTO 'dancesstepsmap' VALUES (26358, 19575, 4);
INSERT INTO 'dancesstepsmap' VALUES (26359, 19575, 5);
INSERT INTO 'dancesstepsmap' VALUES (26360, 19576, 1);
INSERT INTO 'dancesstepsmap' VALUES (26361, 19577, 4);
INSERT INTO 'dancesstepsmap' VALUES (26362, 19577, 5);
INSERT INTO 'dancesstepsmap' VALUES (26363, 19578, 4);
INSERT INTO 'dancesstepsmap' VALUES (26364, 19578, 5);
INSERT INTO 'dancesstepsmap' VALUES (26365, 14584, 4);
INSERT INTO 'dancesstepsmap' VALUES (26366, 14584, 5);
INSERT INTO 'dancesstepsmap' VALUES (26367, 19581, 4);
INSERT INTO 'dancesstepsmap' VALUES (26368, 19581, 5);
INSERT INTO 'dancesstepsmap' VALUES (26369, 19582, 5);
INSERT INTO 'dancesstepsmap' VALUES (26370, 19582, 4);
INSERT INTO 'dancesstepsmap' VALUES (26371, 19585, 1);
INSERT INTO 'dancesstepsmap' VALUES (26372, 19585, 2);
INSERT INTO 'dancesstepsmap' VALUES (26373, 19588, 5);
INSERT INTO 'dancesstepsmap' VALUES (26374, 19588, 4);
INSERT INTO 'dancesstepsmap' VALUES (26375, 19592, 1);
INSERT INTO 'dancesstepsmap' VALUES (26376, 19592, 2);
INSERT INTO 'dancesstepsmap' VALUES (26377, 19590, 4);
INSERT INTO 'dancesstepsmap' VALUES (26378, 19590, 5);
INSERT INTO 'dancesstepsmap' VALUES (26379, 19593, 1);
INSERT INTO 'dancesstepsmap' VALUES (26380, 19594, 1);
INSERT INTO 'dancesstepsmap' VALUES (26381, 19595, 1);
INSERT INTO 'dancesstepsmap' VALUES (26382, 18564, 1);
INSERT INTO 'dancesstepsmap' VALUES (26383, 18564, 2);
INSERT INTO 'dancesstepsmap' VALUES (26384, 16769, 4);
INSERT INTO 'dancesstepsmap' VALUES (26385, 16769, 5);
INSERT INTO 'dancesstepsmap' VALUES (26386, 19596, 1);
INSERT INTO 'dancesstepsmap' VALUES (26387, 19596, 2);
INSERT INTO 'dancesstepsmap' VALUES (26392, 19604, 3);
INSERT INTO 'dancesstepsmap' VALUES (26393, 19610, 1);
INSERT INTO 'dancesstepsmap' VALUES (26394, 19610, 2);
INSERT INTO 'dancesstepsmap' VALUES (26395, 19615, 4);
INSERT INTO 'dancesstepsmap' VALUES (26396, 19615, 5);
INSERT INTO 'dancesstepsmap' VALUES (26397, 15233, 2);
INSERT INTO 'dancesstepsmap' VALUES (26398, 15233, 1);
INSERT INTO 'dancesstepsmap' VALUES (26399, 15236, 1);
INSERT INTO 'dancesstepsmap' VALUES (26400, 15236, 2);
INSERT INTO 'dancesstepsmap' VALUES (26401, 15239, 2);
INSERT INTO 'dancesstepsmap' VALUES (26402, 15239, 1);
INSERT INTO 'dancesstepsmap' VALUES (26403, 15247, 5);
INSERT INTO 'dancesstepsmap' VALUES (26404, 15247, 4);
INSERT INTO 'dancesstepsmap' VALUES (26405, 4904, 1);
INSERT INTO 'dancesstepsmap' VALUES (26406, 4904, 2);
INSERT INTO 'dancesstepsmap' VALUES (26407, 4904, 5);
INSERT INTO 'dancesstepsmap' VALUES (26408, 19629, 4);
INSERT INTO 'dancesstepsmap' VALUES (26409, 19629, 5);
INSERT INTO 'dancesstepsmap' VALUES (26410, 19630, 1);
INSERT INTO 'dancesstepsmap' VALUES (26411, 19630, 2);
INSERT INTO 'dancesstepsmap' VALUES (26412, 19631, 4);
INSERT INTO 'dancesstepsmap' VALUES (26413, 15235, 1);
INSERT INTO 'dancesstepsmap' VALUES (26414, 15235, 2);
INSERT INTO 'dancesstepsmap' VALUES (26390, 19604, 1);
INSERT INTO 'dancesstepsmap' VALUES (26391, 19604, 2);
INSERT INTO 'dancesstepsmap' VALUES (26415, 13985, 1);
INSERT INTO 'dancesstepsmap' VALUES (26416, 13985, 3);
INSERT INTO 'dancesstepsmap' VALUES (26417, 13985, 2);
INSERT INTO 'dancesstepsmap' VALUES (26418, 19633, 5);
INSERT INTO 'dancesstepsmap' VALUES (26419, 19633, 4);
INSERT INTO 'dancesstepsmap' VALUES (26422, 17988, 4);
INSERT INTO 'dancesstepsmap' VALUES (26423, 17988, 5);
INSERT INTO 'dancesstepsmap' VALUES (26424, 13961, 1);
INSERT INTO 'dancesstepsmap' VALUES (26425, 13961, 2);
INSERT INTO 'dancesstepsmap' VALUES (26426, 13961, 3);
INSERT INTO 'dancesstepsmap' VALUES (26427, 19635, 5);
INSERT INTO 'dancesstepsmap' VALUES (26428, 19635, 4);
INSERT INTO 'dancesstepsmap' VALUES (9250, 3838, 2);
INSERT INTO 'dancesstepsmap' VALUES (26429, 3838, 3);
INSERT INTO 'dancesstepsmap' VALUES (26430, 19636, 1);
INSERT INTO 'dancesstepsmap' VALUES (26431, 19636, 2);
INSERT INTO 'dancesstepsmap' VALUES (26432, 19637, 1);
INSERT INTO 'dancesstepsmap' VALUES (26433, 19637, 2);
INSERT INTO 'dancesstepsmap' VALUES (26434, 19638, 4);
INSERT INTO 'dancesstepsmap' VALUES (26435, 19638, 5);
INSERT INTO 'dancesstepsmap' VALUES (26436, 19639, 4);
INSERT INTO 'dancesstepsmap' VALUES (26437, 19640, 5);
INSERT INTO 'dancesstepsmap' VALUES (26438, 19640, 4);
INSERT INTO 'dancesstepsmap' VALUES (26439, 13327, 2);
INSERT INTO 'dancesstepsmap' VALUES (26440, 3590, 2);
INSERT INTO 'dancesstepsmap' VALUES (12832, 11491, 2);
INSERT INTO 'dancesstepsmap' VALUES (26441, 14469, 1);
INSERT INTO 'dancesstepsmap' VALUES (26442, 14469, 2);
INSERT INTO 'dancesstepsmap' VALUES (26443, 7598, 2);
INSERT INTO 'dancesstepsmap' VALUES (26444, 19641, 1);
INSERT INTO 'dancesstepsmap' VALUES (26445, 19642, 4);
INSERT INTO 'dancesstepsmap' VALUES (26446, 19642, 5);
INSERT INTO 'dancesstepsmap' VALUES (26447, 19643, 1);
INSERT INTO 'dancesstepsmap' VALUES (26448, 19643, 2);
INSERT INTO 'dancesstepsmap' VALUES (26451, 19474, 3);
INSERT INTO 'dancesstepsmap' VALUES (26452, 1875, 3);
INSERT INTO 'dancesstepsmap' VALUES (26453, 1875, 2);
INSERT INTO 'dancesstepsmap' VALUES (26454, 328, 5);
INSERT INTO 'dancesstepsmap' VALUES (26455, 19023, 1);
INSERT INTO 'dancesstepsmap' VALUES (26456, 1571, 2);
INSERT INTO 'dancesstepsmap' VALUES (26449, 19474, 1);
INSERT INTO 'dancesstepsmap' VALUES (26450, 19474, 2);
INSERT INTO 'dancesstepsmap' VALUES (26457, 19611, 5);
INSERT INTO 'dancesstepsmap' VALUES (26458, 19611, 6);
INSERT INTO 'dancesstepsmap' VALUES (26459, 19611, 4);
INSERT INTO 'dancesstepsmap' VALUES (26460, 14461, 4);
INSERT INTO 'dancesstepsmap' VALUES (26461, 14461, 5);
INSERT INTO 'dancesstepsmap' VALUES (26462, 750, 5);
INSERT INTO 'dancesstepsmap' VALUES (26463, 8532, 2);
INSERT INTO 'dancesstepsmap' VALUES (26464, 19555, 1);
INSERT INTO 'dancesstepsmap' VALUES (26465, 19555, 2);
INSERT INTO 'dancesstepsmap' VALUES (26466, 19644, 1);
INSERT INTO 'dancesstepsmap' VALUES (26467, 19644, 2);
INSERT INTO 'dancesstepsmap' VALUES (26468, 19649, 4);
INSERT INTO 'dancesstepsmap' VALUES (26469, 19649, 5);
INSERT INTO 'dancesstepsmap' VALUES (26470, 19651, 1);
INSERT INTO 'dancesstepsmap' VALUES (26471, 19651, 2);
INSERT INTO 'dancesstepsmap' VALUES (26472, 19559, 4);
INSERT INTO 'dancesstepsmap' VALUES (26473, 19559, 5);
INSERT INTO 'dancesstepsmap' VALUES (26474, 19645, 1);
INSERT INTO 'dancesstepsmap' VALUES (26475, 19645, 2);
INSERT INTO 'dancesstepsmap' VALUES (26476, 19645, 3);
INSERT INTO 'dancesstepsmap' VALUES (26477, 19646, 4);
INSERT INTO 'dancesstepsmap' VALUES (26478, 19647, 1);
INSERT INTO 'dancesstepsmap' VALUES (26479, 19647, 2);
INSERT INTO 'dancesstepsmap' VALUES (26480, 956, 4);
INSERT INTO 'dancesstepsmap' VALUES (26481, 956, 5);
INSERT INTO 'dancesstepsmap' VALUES (26482, 956, 2);
INSERT INTO 'dancesstepsmap' VALUES (26483, 956, 1);
INSERT INTO 'dancesstepsmap' VALUES (26484, 19656, 1);
INSERT INTO 'dancesstepsmap' VALUES (26485, 19656, 2);
INSERT INTO 'dancesstepsmap' VALUES (26486, 19653, 4);
INSERT INTO 'dancesstepsmap' VALUES (26487, 19658, 1);
INSERT INTO 'dancesstepsmap' VALUES (26488, 19657, 4);
INSERT INTO 'dancesstepsmap' VALUES (26489, 19657, 5);
INSERT INTO 'dancesstepsmap' VALUES (26490, 19650, 1);
INSERT INTO 'dancesstepsmap' VALUES (26491, 19557, 2);
INSERT INTO 'dancesstepsmap' VALUES (26492, 19557, 1);
INSERT INTO 'dancesstepsmap' VALUES (26493, 19648, 1);
INSERT INTO 'dancesstepsmap' VALUES (26494, 19648, 2);
INSERT INTO 'dancesstepsmap' VALUES (26495, 19648, 3);
INSERT INTO 'dancesstepsmap' VALUES (26496, 19655, 1);
INSERT INTO 'dancesstepsmap' VALUES (26497, 19655, 2);
INSERT INTO 'dancesstepsmap' VALUES (26498, 19655, 3);
INSERT INTO 'dancesstepsmap' VALUES (26499, 19659, 4);
INSERT INTO 'dancesstepsmap' VALUES (26500, 11220, 5);
INSERT INTO 'dancesstepsmap' VALUES (26501, 19652, 1);
INSERT INTO 'dancesstepsmap' VALUES (26502, 19652, 2);
INSERT INTO 'dancesstepsmap' VALUES (26503, 19652, 3);
INSERT INTO 'dancesstepsmap' VALUES (26504, 16601, 4);
INSERT INTO 'dancesstepsmap' VALUES (26505, 16601, 5);
INSERT INTO 'dancesstepsmap' VALUES (26506, 16601, 1);
INSERT INTO 'dancesstepsmap' VALUES (26507, 16601, 2);
INSERT INTO 'dancesstepsmap' VALUES (26508, 16601, 3);
INSERT INTO 'dancesstepsmap' VALUES (26509, 19660, 4);
INSERT INTO 'dancesstepsmap' VALUES (26510, 19660, 5);
INSERT INTO 'dancesstepsmap' VALUES (26511, 19660, 1);
INSERT INTO 'dancesstepsmap' VALUES (26512, 19660, 2);
INSERT INTO 'dancesstepsmap' VALUES (26513, 168, 3);
INSERT INTO 'dancesstepsmap' VALUES (26514, 2949, 1);
INSERT INTO 'dancesstepsmap' VALUES (26515, 2949, 2);
INSERT INTO 'dancesstepsmap' VALUES (26388, 19597, 5);
INSERT INTO 'dancesstepsmap' VALUES (26389, 19597, 4);
INSERT INTO 'dancesstepsmap' VALUES (26516, 19661, 2);
INSERT INTO 'dancesstepsmap' VALUES (26517, 19661, 1);
INSERT INTO 'dancesstepsmap' VALUES (26518, 19661, 3);
INSERT INTO 'dancesstepsmap' VALUES (26519, 15344, 1);
INSERT INTO 'dancesstepsmap' VALUES (26520, 15344, 3);
INSERT INTO 'dancesstepsmap' VALUES (26521, 15344, 2);
INSERT INTO 'dancesstepsmap' VALUES (26522, 15352, 3);
INSERT INTO 'dancesstepsmap' VALUES (26523, 15352, 1);
INSERT INTO 'dancesstepsmap' VALUES (26524, 15352, 2);
INSERT INTO 'dancesstepsmap' VALUES (26525, 19662, 5);
INSERT INTO 'dancesstepsmap' VALUES (26526, 19662, 4);
INSERT INTO 'dancesstepsmap' VALUES (26527, 14185, 1);
INSERT INTO 'dancesstepsmap' VALUES (26528, 14185, 2);
INSERT INTO 'dancesstepsmap' VALUES (26529, 19663, 2);
INSERT INTO 'dancesstepsmap' VALUES (26530, 19663, 1);
INSERT INTO 'dancesstepsmap' VALUES (26531, 19663, 3);
INSERT INTO 'dancesstepsmap' VALUES (26532, 19664, 5);
INSERT INTO 'dancesstepsmap' VALUES (26533, 19664, 4);
INSERT INTO 'dancesstepsmap' VALUES (26534, 19558, 4);
INSERT INTO 'dancesstepsmap' VALUES (26535, 19558, 5);
INSERT INTO 'dancesstepsmap' VALUES (26536, 19665, 2);
INSERT INTO 'dancesstepsmap' VALUES (26537, 19665, 1);
INSERT INTO 'dancesstepsmap' VALUES (26538, 19665, 3);
INSERT INTO 'dancesstepsmap' VALUES (20668, 11716, 3);
INSERT INTO 'dancesstepsmap' VALUES (26539, 19666, 5);
INSERT INTO 'dancesstepsmap' VALUES (26540, 19666, 4);
INSERT INTO 'dancesstepsmap' VALUES (26541, 19666, 2);
INSERT INTO 'dancesstepsmap' VALUES (26542, 19666, 1);
INSERT INTO 'dancesstepsmap' VALUES (26543, 19666, 3);
INSERT INTO 'dancesstepsmap' VALUES (26544, 19667, 2);
INSERT INTO 'dancesstepsmap' VALUES (26545, 19667, 1);
INSERT INTO 'dancesstepsmap' VALUES (26546, 18881, 4);
INSERT INTO 'dancesstepsmap' VALUES (26547, 18881, 5);
INSERT INTO 'dancesstepsmap' VALUES (26548, 19668, 5);
INSERT INTO 'dancesstepsmap' VALUES (26549, 19668, 4);
INSERT INTO 'dancesstepsmap' VALUES (26550, 19669, 1);
INSERT INTO 'dancesstepsmap' VALUES (26551, 19670, 2);
INSERT INTO 'dancesstepsmap' VALUES (26552, 19670, 3);
INSERT INTO 'dancesstepsmap' VALUES (26553, 19670, 1);
INSERT INTO 'dancesstepsmap' VALUES (26554, 19671, 5);
INSERT INTO 'dancesstepsmap' VALUES (26555, 19671, 4);
INSERT INTO 'dancesstepsmap' VALUES (26556, 19672, 1);
INSERT INTO 'dancesstepsmap' VALUES (26557, 19672, 2);
INSERT INTO 'dancesstepsmap' VALUES (26558, 19672, 3);
INSERT INTO 'dancesstepsmap' VALUES (26559, 19673, 1);
INSERT INTO 'dancesstepsmap' VALUES (26560, 19673, 2);
INSERT INTO 'dancesstepsmap' VALUES (26561, 19673, 3);
INSERT INTO 'dancesstepsmap' VALUES (26562, 19674, 2);
INSERT INTO 'dancesstepsmap' VALUES (26563, 19674, 1);
INSERT INTO 'dancesstepsmap' VALUES (26564, 19675, 5);
INSERT INTO 'dancesstepsmap' VALUES (26565, 19675, 4);
INSERT INTO 'dancesstepsmap' VALUES (26566, 19676, 4);
INSERT INTO 'dancesstepsmap' VALUES (26567, 19677, 2);
INSERT INTO 'dancesstepsmap' VALUES (26568, 19677, 1);
INSERT INTO 'dancesstepsmap' VALUES (26569, 19678, 2);
INSERT INTO 'dancesstepsmap' VALUES (26570, 19678, 1);
INSERT INTO 'dancesstepsmap' VALUES (26571, 19679, 3);
INSERT INTO 'dancesstepsmap' VALUES (26572, 19679, 2);
INSERT INTO 'dancesstepsmap' VALUES (26573, 19679, 1);
INSERT INTO 'dancesstepsmap' VALUES (26574, 19680, 2);
INSERT INTO 'dancesstepsmap' VALUES (26575, 19680, 3);
INSERT INTO 'dancesstepsmap' VALUES (26576, 19680, 1);
INSERT INTO 'dancesstepsmap' VALUES (26577, 19681, 4);
INSERT INTO 'dancesstepsmap' VALUES (26578, 19681, 5);
INSERT INTO 'dancesstepsmap' VALUES (26579, 18858, 1);
INSERT INTO 'dancesstepsmap' VALUES (26580, 18865, 4);
INSERT INTO 'dancesstepsmap' VALUES (26581, 18865, 5);
INSERT INTO 'dancesstepsmap' VALUES (26582, 19682, 1);
INSERT INTO 'dancesstepsmap' VALUES (26583, 19682, 2);
INSERT INTO 'dancesstepsmap' VALUES (26584, 19684, 2);
INSERT INTO 'dancesstepsmap' VALUES (26585, 19684, 1);
INSERT INTO 'dancesstepsmap' VALUES (26586, 19684, 3);
INSERT INTO 'dancesstepsmap' VALUES (26587, 19685, 1);
INSERT INTO 'dancesstepsmap' VALUES (26588, 19685, 2);
INSERT INTO 'dancesstepsmap' VALUES (26589, 19686, 1);
INSERT INTO 'dancesstepsmap' VALUES (26590, 4024, 5);
INSERT INTO 'dancesstepsmap' VALUES (26591, 19687, 1);
INSERT INTO 'dancesstepsmap' VALUES (26592, 19687, 2);
INSERT INTO 'dancesstepsmap' VALUES (26593, 19687, 3);
INSERT INTO 'dancesstepsmap' VALUES (26594, 19688, 1);
INSERT INTO 'dancesstepsmap' VALUES (26595, 19688, 2);
INSERT INTO 'dancesstepsmap' VALUES (26596, 19688, 3);
INSERT INTO 'dancesstepsmap' VALUES (26597, 17848, 1);
INSERT INTO 'dancesstepsmap' VALUES (26598, 17848, 2);
INSERT INTO 'dancesstepsmap' VALUES (26599, 19446, 1);
INSERT INTO 'dancesstepsmap' VALUES (26600, 19446, 2);
INSERT INTO 'dancesstepsmap' VALUES (26601, 15234, 5);
INSERT INTO 'dancesstepsmap' VALUES (26602, 15234, 4);
INSERT INTO 'dancesstepsmap' VALUES (26603, 19689, 5);
INSERT INTO 'dancesstepsmap' VALUES (26604, 19689, 4);
INSERT INTO 'dancesstepsmap' VALUES (26605, 17164, 1);
INSERT INTO 'dancesstepsmap' VALUES (26606, 18343, 1);
INSERT INTO 'dancesstepsmap' VALUES (26207, 19510, 4);
INSERT INTO 'dancesstepsmap' VALUES (26208, 19510, 5);
INSERT INTO 'dancesstepsmap' VALUES (26607, 13938, 1);
INSERT INTO 'dancesstepsmap' VALUES (26608, 13938, 2);
INSERT INTO 'dancesstepsmap' VALUES (26609, 14053, 4);
INSERT INTO 'dancesstepsmap' VALUES (26610, 14053, 5);
INSERT INTO 'dancesstepsmap' VALUES (26611, 1454, 5);
INSERT INTO 'dancesstepsmap' VALUES (26612, 19690, 1);
INSERT INTO 'dancesstepsmap' VALUES (26613, 15241, 2);
INSERT INTO 'dancesstepsmap' VALUES (26614, 15241, 1);
INSERT INTO 'dancesstepsmap' VALUES (26615, 813, 5);
INSERT INTO 'dancesstepsmap' VALUES (26616, 19691, 1);
INSERT INTO 'dancesstepsmap' VALUES (26617, 19692, 1);
INSERT INTO 'dancesstepsmap' VALUES (26618, 897, 2);
INSERT INTO 'dancesstepsmap' VALUES (26619, 19693, 1);
INSERT INTO 'dancesstepsmap' VALUES (26620, 19694, 1);
INSERT INTO 'dancesstepsmap' VALUES (26621, 19694, 3);
INSERT INTO 'dancesstepsmap' VALUES (26622, 13817, 5);
INSERT INTO 'dancesstepsmap' VALUES (26623, 19695, 4);
INSERT INTO 'dancesstepsmap' VALUES (26624, 19695, 5);
INSERT INTO 'dancesstepsmap' VALUES (26625, 19696, 5);
INSERT INTO 'dancesstepsmap' VALUES (26626, 19696, 4);
INSERT INTO 'dancesstepsmap' VALUES (26627, 19697, 1);
INSERT INTO 'dancesstepsmap' VALUES (26628, 19697, 2);
INSERT INTO 'dancesstepsmap' VALUES (26629, 19698, 1);
INSERT INTO 'dancesstepsmap' VALUES (26630, 19698, 2);
INSERT INTO 'dancesstepsmap' VALUES (26631, 19698, 3);
INSERT INTO 'dancesstepsmap' VALUES (26632, 19699, 1);
INSERT INTO 'dancesstepsmap' VALUES (26633, 19699, 2);
INSERT INTO 'dancesstepsmap' VALUES (26634, 19699, 3);
INSERT INTO 'dancesstepsmap' VALUES (26635, 2235, 6);
INSERT INTO 'dancesstepsmap' VALUES (26636, 2235, 5);
INSERT INTO 'dancesstepsmap' VALUES (26637, 19700, 1);
INSERT INTO 'dancesstepsmap' VALUES (26638, 19700, 3);
INSERT INTO 'dancesstepsmap' VALUES (26639, 205, 5);
INSERT INTO 'dancesstepsmap' VALUES (26640, 18124, 1);
INSERT INTO 'dancesstepsmap' VALUES (26641, 18124, 2);
INSERT INTO 'dancesstepsmap' VALUES (26642, 210, 2);
INSERT INTO 'dancesstepsmap' VALUES (26643, 16792, 1);
INSERT INTO 'dancesstepsmap' VALUES (26644, 7999, 5);
INSERT INTO 'dancesstepsmap' VALUES (26645, 7378, 5);
INSERT INTO 'dancesstepsmap' VALUES (26646, 534, 102);
INSERT INTO 'dancesstepsmap' VALUES (26647, 1235, 2);
INSERT INTO 'dancesstepsmap' VALUES (26648, 18127, 1);
INSERT INTO 'dancesstepsmap' VALUES (26649, 18133, 1);
INSERT INTO 'dancesstepsmap' VALUES (26650, 18133, 2);
INSERT INTO 'dancesstepsmap' VALUES (23484, 16787, 2);
INSERT INTO 'dancesstepsmap' VALUES (26651, 16787, 3);
INSERT INTO 'dancesstepsmap' VALUES (26652, 15240, 2);
INSERT INTO 'dancesstepsmap' VALUES (26653, 15240, 1);
INSERT INTO 'dancesstepsmap' VALUES (26654, 19701, 2);
INSERT INTO 'dancesstepsmap' VALUES (26655, 19701, 1);
INSERT INTO 'dancesstepsmap' VALUES (26656, 19701, 3);
INSERT INTO 'dancesstepsmap' VALUES (26657, 18135, 1);
INSERT INTO 'dancesstepsmap' VALUES (26658, 18135, 2);
INSERT INTO 'dancesstepsmap' VALUES (26661, 16873, 1);
INSERT INTO 'dancesstepsmap' VALUES (26662, 16873, 2);
INSERT INTO 'dancesstepsmap' VALUES (26663, 19702, 5);
INSERT INTO 'dancesstepsmap' VALUES (26664, 19702, 4);
INSERT INTO 'dancesstepsmap' VALUES (26665, 19703, 1);
INSERT INTO 'dancesstepsmap' VALUES (26666, 19703, 3);
INSERT INTO 'dancesstepsmap' VALUES (26667, 19704, 5);
INSERT INTO 'dancesstepsmap' VALUES (26668, 19704, 4);
INSERT INTO 'dancesstepsmap' VALUES (26669, 19712, 4);
INSERT INTO 'dancesstepsmap' VALUES (26670, 19712, 5);
INSERT INTO 'dancesstepsmap' VALUES (26671, 19717, 1);
INSERT INTO 'dancesstepsmap' VALUES (26672, 19717, 2);
INSERT INTO 'dancesstepsmap' VALUES (26673, 17628, 1);
INSERT INTO 'dancesstepsmap' VALUES (26674, 17628, 2);
INSERT INTO 'dancesstepsmap' VALUES (26675, 19705, 1);
INSERT INTO 'dancesstepsmap' VALUES (26676, 19706, 1);
INSERT INTO 'dancesstepsmap' VALUES (26677, 19707, 4);
INSERT INTO 'dancesstepsmap' VALUES (26678, 19708, 4);
INSERT INTO 'dancesstepsmap' VALUES (26679, 19708, 6);
INSERT INTO 'dancesstepsmap' VALUES (26680, 19708, 1);
INSERT INTO 'dancesstepsmap' VALUES (26681, 19709, 2);
INSERT INTO 'dancesstepsmap' VALUES (26682, 19709, 1);
INSERT INTO 'dancesstepsmap' VALUES (26683, 19710, 1);
INSERT INTO 'dancesstepsmap' VALUES (26684, 19711, 1);
INSERT INTO 'dancesstepsmap' VALUES (26685, 19711, 2);
INSERT INTO 'dancesstepsmap' VALUES (26686, 19713, 4);
INSERT INTO 'dancesstepsmap' VALUES (26687, 19713, 5);
INSERT INTO 'dancesstepsmap' VALUES (26688, 19714, 1);
INSERT INTO 'dancesstepsmap' VALUES (26689, 19714, 2);
INSERT INTO 'dancesstepsmap' VALUES (26690, 19715, 4);
INSERT INTO 'dancesstepsmap' VALUES (26691, 19715, 5);
INSERT INTO 'dancesstepsmap' VALUES (26692, 19716, 1);
INSERT INTO 'dancesstepsmap' VALUES (26693, 19719, 4);
INSERT INTO 'dancesstepsmap' VALUES (26694, 19718, 4);
INSERT INTO 'dancesstepsmap' VALUES (26698, 19721, 3);
INSERT INTO 'dancesstepsmap' VALUES (26699, 19721, 2);
INSERT INTO 'dancesstepsmap' VALUES (26700, 19721, 1);
INSERT INTO 'dancesstepsmap' VALUES (26701, 19722, 1);
INSERT INTO 'dancesstepsmap' VALUES (26702, 19723, 1);
INSERT INTO 'dancesstepsmap' VALUES (26703, 19723, 2);
INSERT INTO 'dancesstepsmap' VALUES (26704, 19724, 5);
INSERT INTO 'dancesstepsmap' VALUES (26705, 19724, 4);
INSERT INTO 'dancesstepsmap' VALUES (26706, 19718, 5);
INSERT INTO 'dancesstepsmap' VALUES (26707, 18176, 1);
INSERT INTO 'dancesstepsmap' VALUES (26708, 18176, 2);
INSERT INTO 'dancesstepsmap' VALUES (26709, 18156, 4);
INSERT INTO 'dancesstepsmap' VALUES (26710, 18156, 5);
INSERT INTO 'dancesstepsmap' VALUES (26711, 15243, 1);
INSERT INTO 'dancesstepsmap' VALUES (26712, 15243, 2);
INSERT INTO 'dancesstepsmap' VALUES (26713, 19725, 2);
INSERT INTO 'dancesstepsmap' VALUES (26714, 19725, 1);
INSERT INTO 'dancesstepsmap' VALUES (26715, 19726, 1);
INSERT INTO 'dancesstepsmap' VALUES (26716, 19727, 1);
INSERT INTO 'dancesstepsmap' VALUES (26717, 19727, 2);
INSERT INTO 'dancesstepsmap' VALUES (26718, 19727, 3);
INSERT INTO 'dancesstepsmap' VALUES (26719, 4639, 2);
INSERT INTO 'dancesstepsmap' VALUES (26720, 11386, 1);
INSERT INTO 'dancesstepsmap' VALUES (26721, 11386, 2);
INSERT INTO 'dancesstepsmap' VALUES (26722, 18182, 4);
INSERT INTO 'dancesstepsmap' VALUES (26723, 18182, 5);
INSERT INTO 'dancesstepsmap' VALUES (26724, 18182, 1);
INSERT INTO 'dancesstepsmap' VALUES (26725, 18182, 2);
INSERT INTO 'dancesstepsmap' VALUES (26726, 18182, 3);
INSERT INTO 'dancesstepsmap' VALUES (26727, 19564, 1);
INSERT INTO 'dancesstepsmap' VALUES (26728, 19738, 4);
INSERT INTO 'dancesstepsmap' VALUES (26733, 7679, 5);
INSERT INTO 'dancesstepsmap' VALUES (26734, 19728, 1);
INSERT INTO 'dancesstepsmap' VALUES (26735, 19728, 2);
INSERT INTO 'dancesstepsmap' VALUES (26736, 19736, 1);
INSERT INTO 'dancesstepsmap' VALUES (26737, 19736, 3);
INSERT INTO 'dancesstepsmap' VALUES (26738, 19759, 2);
INSERT INTO 'dancesstepsmap' VALUES (26739, 19759, 1);
INSERT INTO 'dancesstepsmap' VALUES (26740, 18785, 1);
INSERT INTO 'dancesstepsmap' VALUES (26741, 19737, 1);
INSERT INTO 'dancesstepsmap' VALUES (26742, 19741, 2);
INSERT INTO 'dancesstepsmap' VALUES (26743, 19741, 1);
INSERT INTO 'dancesstepsmap' VALUES (26744, 7096, 2);
INSERT INTO 'dancesstepsmap' VALUES (26745, 18364, 1);
INSERT INTO 'dancesstepsmap' VALUES (26746, 18364, 2);
INSERT INTO 'dancesstepsmap' VALUES (26747, 19760, 2);
INSERT INTO 'dancesstepsmap' VALUES (26748, 19760, 1);
INSERT INTO 'dancesstepsmap' VALUES (26749, 19761, 1);
INSERT INTO 'dancesstepsmap' VALUES (26750, 19761, 2);
INSERT INTO 'dancesstepsmap' VALUES (26751, 19762, 4);
INSERT INTO 'dancesstepsmap' VALUES (26752, 19762, 5);
INSERT INTO 'dancesstepsmap' VALUES (26753, 19763, 1);
INSERT INTO 'dancesstepsmap' VALUES (26754, 19763, 3);
INSERT INTO 'dancesstepsmap' VALUES (26755, 19764, 1);
INSERT INTO 'dancesstepsmap' VALUES (26756, 19764, 2);
INSERT INTO 'dancesstepsmap' VALUES (26759, 19766, 1);
INSERT INTO 'dancesstepsmap' VALUES (26760, 19766, 2);
INSERT INTO 'dancesstepsmap' VALUES (26761, 19766, 3);
INSERT INTO 'dancesstepsmap' VALUES (26762, 19767, 1);
INSERT INTO 'dancesstepsmap' VALUES (26763, 19767, 2);
INSERT INTO 'dancesstepsmap' VALUES (26764, 19767, 3);
INSERT INTO 'dancesstepsmap' VALUES (26765, 19768, 2);
INSERT INTO 'dancesstepsmap' VALUES (26766, 19768, 1);
INSERT INTO 'dancesstepsmap' VALUES (26767, 19768, 102);
INSERT INTO 'dancesstepsmap' VALUES (26768, 19768, 3);
INSERT INTO 'dancesstepsmap' VALUES (26769, 18358, 5);
INSERT INTO 'dancesstepsmap' VALUES (26770, 18358, 4);
INSERT INTO 'dancesstepsmap' VALUES (26771, 6780, 2);
INSERT INTO 'dancesstepsmap' VALUES (26772, 17816, 1);
INSERT INTO 'dancesstepsmap' VALUES (26773, 17816, 2);
INSERT INTO 'dancesstepsmap' VALUES (26776, 17824, 4);
INSERT INTO 'dancesstepsmap' VALUES (26777, 17824, 5);
INSERT INTO 'dancesstepsmap' VALUES (26778, 10093, 5);
INSERT INTO 'dancesstepsmap' VALUES (26779, 18149, 4);
INSERT INTO 'dancesstepsmap' VALUES (26780, 4491, 2);
INSERT INTO 'dancesstepsmap' VALUES (26781, 18179, 1);
INSERT INTO 'dancesstepsmap' VALUES (26782, 18179, 2);
INSERT INTO 'dancesstepsmap' VALUES (26783, 18178, 1);
INSERT INTO 'dancesstepsmap' VALUES (26784, 18178, 2);
INSERT INTO 'dancesstepsmap' VALUES (26785, 18178, 3);
INSERT INTO 'dancesstepsmap' VALUES (26731, 19729, 4);
INSERT INTO 'dancesstepsmap' VALUES (26732, 19729, 5);
INSERT INTO 'dancesstepsmap' VALUES (26774, 16940, 5);
INSERT INTO 'dancesstepsmap' VALUES (26775, 16940, 4);
INSERT INTO 'dancesstepsmap' VALUES (26659, 18151, 4);
INSERT INTO 'dancesstepsmap' VALUES (26786, 17255, 4);
INSERT INTO 'dancesstepsmap' VALUES (26787, 17255, 5);
INSERT INTO 'dancesstepsmap' VALUES (26788, 1661, 2);
INSERT INTO 'dancesstepsmap' VALUES (26789, 19769, 4);
INSERT INTO 'dancesstepsmap' VALUES (26790, 19769, 5);
INSERT INTO 'dancesstepsmap' VALUES (26791, 19769, 1);
INSERT INTO 'dancesstepsmap' VALUES (26792, 19770, 4);
INSERT INTO 'dancesstepsmap' VALUES (26793, 19770, 2);
INSERT INTO 'dancesstepsmap' VALUES (26794, 19770, 1);
INSERT INTO 'dancesstepsmap' VALUES (26795, 19770, 5);
INSERT INTO 'dancesstepsmap' VALUES (26796, 19770, 10);
INSERT INTO 'dancesstepsmap' VALUES (26797, 3031, 5);
INSERT INTO 'dancesstepsmap' VALUES (26798, 12143, 1);
INSERT INTO 'dancesstepsmap' VALUES (26799, 12143, 2);
INSERT INTO 'dancesstepsmap' VALUES (21076, 16800, 1);
INSERT INTO 'dancesstepsmap' VALUES (26800, 19771, 4);
INSERT INTO 'dancesstepsmap' VALUES (26801, 999, 3);
INSERT INTO 'dancesstepsmap' VALUES (26802, 999, 2);
INSERT INTO 'dancesstepsmap' VALUES (26803, 10694, 1);
INSERT INTO 'dancesstepsmap' VALUES (26804, 10694, 2);
INSERT INTO 'dancesstepsmap' VALUES (26805, 19772, 1);
INSERT INTO 'dancesstepsmap' VALUES (26806, 19772, 2);
INSERT INTO 'dancesstepsmap' VALUES (26807, 19773, 4);
INSERT INTO 'dancesstepsmap' VALUES (26808, 19773, 5);
INSERT INTO 'dancesstepsmap' VALUES (26809, 16962, 5);
INSERT INTO 'dancesstepsmap' VALUES (26810, 16962, 4);
INSERT INTO 'dancesstepsmap' VALUES (26811, 9942, 3);
INSERT INTO 'dancesstepsmap' VALUES (26812, 1719, 2);
INSERT INTO 'dancesstepsmap' VALUES (26813, 1719, 3);
INSERT INTO 'dancesstepsmap' VALUES (26814, 19774, 5);
INSERT INTO 'dancesstepsmap' VALUES (26815, 19774, 4);
INSERT INTO 'dancesstepsmap' VALUES (26816, 4251, 102);
INSERT INTO 'dancesstepsmap' VALUES (26817, 4251, 5);
INSERT INTO 'dancesstepsmap' VALUES (26818, 19626, 4);
INSERT INTO 'dancesstepsmap' VALUES (26819, 19607, 1);
INSERT INTO 'dancesstepsmap' VALUES (26820, 19607, 3);
INSERT INTO 'dancesstepsmap' VALUES (26821, 19589, 1);
INSERT INTO 'dancesstepsmap' VALUES (26822, 19589, 2);
INSERT INTO 'dancesstepsmap' VALUES (26823, 19589, 3);
INSERT INTO 'dancesstepsmap' VALUES (26824, 19085, 3);
INSERT INTO 'dancesstepsmap' VALUES (26825, 19085, 1);
INSERT INTO 'dancesstepsmap' VALUES (26826, 19085, 2);
INSERT INTO 'dancesstepsmap' VALUES (26827, 19080, 2);
INSERT INTO 'dancesstepsmap' VALUES (26828, 19080, 1);
INSERT INTO 'dancesstepsmap' VALUES (26829, 19080, 3);
INSERT INTO 'dancesstepsmap' VALUES (26830, 19064, 2);
INSERT INTO 'dancesstepsmap' VALUES (26831, 19064, 1);
INSERT INTO 'dancesstepsmap' VALUES (26832, 19064, 3);
INSERT INTO 'dancesstepsmap' VALUES (26833, 16628, 5);
INSERT INTO 'dancesstepsmap' VALUES (26834, 16628, 4);
INSERT INTO 'dancesstepsmap' VALUES (26835, 5464, 5);
INSERT INTO 'dancesstepsmap' VALUES (26836, 19776, 1);
INSERT INTO 'dancesstepsmap' VALUES (26838, 19777, 4);
INSERT INTO 'dancesstepsmap' VALUES (26839, 19778, 5);
INSERT INTO 'dancesstepsmap' VALUES (26840, 19778, 4);
INSERT INTO 'dancesstepsmap' VALUES (26841, 4679, 2);
INSERT INTO 'dancesstepsmap' VALUES (26842, 15063, 5);
INSERT INTO 'dancesstepsmap' VALUES (26843, 15063, 4);
INSERT INTO 'dancesstepsmap' VALUES (26844, 15059, 1);
INSERT INTO 'dancesstepsmap' VALUES (26845, 15059, 2);
INSERT INTO 'dancesstepsmap' VALUES (26846, 15059, 3);
INSERT INTO 'dancesstepsmap' VALUES (26847, 19779, 1);
INSERT INTO 'dancesstepsmap' VALUES (26848, 19780, 4);
INSERT INTO 'dancesstepsmap' VALUES (26849, 19780, 5);
INSERT INTO 'dancesstepsmap' VALUES (26852, 15070, 5);
INSERT INTO 'dancesstepsmap' VALUES (26853, 15070, 4);
INSERT INTO 'dancesstepsmap' VALUES (26854, 15073, 2);
INSERT INTO 'dancesstepsmap' VALUES (26855, 15073, 1);
INSERT INTO 'dancesstepsmap' VALUES (26856, 15065, 1);
INSERT INTO 'dancesstepsmap' VALUES (26857, 15061, 1);
INSERT INTO 'dancesstepsmap' VALUES (26858, 15069, 2);
INSERT INTO 'dancesstepsmap' VALUES (26859, 15069, 1);
INSERT INTO 'dancesstepsmap' VALUES (26860, 15071, 1);
INSERT INTO 'dancesstepsmap' VALUES (26861, 15071, 2);
INSERT INTO 'dancesstepsmap' VALUES (26862, 19781, 4);
INSERT INTO 'dancesstepsmap' VALUES (26863, 19781, 5);
INSERT INTO 'dancesstepsmap' VALUES (26864, 6571, 2);
INSERT INTO 'dancesstepsmap' VALUES (26865, 6571, 3);
INSERT INTO 'dancesstepsmap' VALUES (26866, 19782, 5);
INSERT INTO 'dancesstepsmap' VALUES (26867, 19782, 4);
INSERT INTO 'dancesstepsmap' VALUES (26868, 19783, 2);
INSERT INTO 'dancesstepsmap' VALUES (26869, 19783, 1);
INSERT INTO 'dancesstepsmap' VALUES (26870, 19784, 2);
INSERT INTO 'dancesstepsmap' VALUES (26871, 19784, 1);
INSERT INTO 'dancesstepsmap' VALUES (26872, 19204, 1);
INSERT INTO 'dancesstepsmap' VALUES (26873, 19204, 2);
INSERT INTO 'dancesstepsmap' VALUES (26874, 19786, 1);
INSERT INTO 'dancesstepsmap' VALUES (26875, 19787, 4);
INSERT INTO 'dancesstepsmap' VALUES (26876, 19787, 5);
INSERT INTO 'dancesstepsmap' VALUES (26877, 19788, 1);
INSERT INTO 'dancesstepsmap' VALUES (26878, 19788, 2);
INSERT INTO 'dancesstepsmap' VALUES (26879, 189, 1);
INSERT INTO 'dancesstepsmap' VALUES (26880, 189, 2);
INSERT INTO 'dancesstepsmap' VALUES (26881, 1127, 5);
INSERT INTO 'dancesstepsmap' VALUES (26882, 1142, 5);
INSERT INTO 'dancesstepsmap' VALUES (26883, 1142, 6);
INSERT INTO 'dancesstepsmap' VALUES (26884, 1231, 2);
INSERT INTO 'dancesstepsmap' VALUES (26885, 1234, 3);
INSERT INTO 'dancesstepsmap' VALUES (26886, 1696, 5);
INSERT INTO 'dancesstepsmap' VALUES (26887, 2163, 2);
INSERT INTO 'dancesstepsmap' VALUES (26888, 12651, 4);
INSERT INTO 'dancesstepsmap' VALUES (26889, 12651, 5);
INSERT INTO 'dancesstepsmap' VALUES (26890, 12896, 3);
INSERT INTO 'dancesstepsmap' VALUES (26891, 12900, 5);
INSERT INTO 'dancesstepsmap' VALUES (26892, 19789, 1);
INSERT INTO 'dancesstepsmap' VALUES (26893, 19789, 3);
INSERT INTO 'dancesstepsmap' VALUES (26894, 10747, 1);
INSERT INTO 'dancesstepsmap' VALUES (26897, 12828, 1);
INSERT INTO 'dancesstepsmap' VALUES (26898, 12828, 2);
INSERT INTO 'dancesstepsmap' VALUES (26899, 19792, 4);
INSERT INTO 'dancesstepsmap' VALUES (26900, 19792, 5);
INSERT INTO 'dancesstepsmap' VALUES (26901, 19793, 3);
INSERT INTO 'dancesstepsmap' VALUES (26902, 19793, 2);
INSERT INTO 'dancesstepsmap' VALUES (26903, 19793, 1);
INSERT INTO 'dancesstepsmap' VALUES (26904, 19794, 4);
INSERT INTO 'dancesstepsmap' VALUES (26905, 19794, 5);
INSERT INTO 'dancesstepsmap' VALUES (26906, 19795, 1);
INSERT INTO 'dancesstepsmap' VALUES (26907, 19795, 2);
INSERT INTO 'dancesstepsmap' VALUES (26908, 19796, 1);
INSERT INTO 'dancesstepsmap' VALUES (26909, 19796, 2);
INSERT INTO 'dancesstepsmap' VALUES (26910, 19584, 4);
INSERT INTO 'dancesstepsmap' VALUES (26911, 19584, 5);
INSERT INTO 'dancesstepsmap' VALUES (26912, 19602, 1);
INSERT INTO 'dancesstepsmap' VALUES (26913, 19602, 2);
INSERT INTO 'dancesstepsmap' VALUES (26914, 18611, 1);
INSERT INTO 'dancesstepsmap' VALUES (26915, 11235, 4);
INSERT INTO 'dancesstepsmap' VALUES (26916, 11235, 5);
INSERT INTO 'dancesstepsmap' VALUES (26917, 11236, 1);
INSERT INTO 'dancesstepsmap' VALUES (26918, 11236, 2);
INSERT INTO 'dancesstepsmap' VALUES (26919, 10198, 4);
INSERT INTO 'dancesstepsmap' VALUES (26920, 10198, 5);
INSERT INTO 'dancesstepsmap' VALUES (26921, 19797, 4);
INSERT INTO 'dancesstepsmap' VALUES (26922, 19797, 5);
INSERT INTO 'dancesstepsmap' VALUES (26923, 13643, 3);
INSERT INTO 'dancesstepsmap' VALUES (26924, 11405, 2);
INSERT INTO 'dancesstepsmap' VALUES (26925, 11405, 1);
INSERT INTO 'dancesstepsmap' VALUES (26926, 19798, 1);
INSERT INTO 'dancesstepsmap' VALUES (26927, 19798, 3);
INSERT INTO 'dancesstepsmap' VALUES (26928, 9239, 1);
INSERT INTO 'dancesstepsmap' VALUES (26929, 9239, 2);
INSERT INTO 'dancesstepsmap' VALUES (26930, 19136, 1);
INSERT INTO 'dancesstepsmap' VALUES (26931, 19799, 4);
INSERT INTO 'dancesstepsmap' VALUES (26932, 19799, 5);
INSERT INTO 'dancesstepsmap' VALUES (26933, 12122, 3);
INSERT INTO 'dancesstepsmap' VALUES (26934, 19800, 2);
INSERT INTO 'dancesstepsmap' VALUES (26935, 19800, 1);
INSERT INTO 'dancesstepsmap' VALUES (26936, 11588, 2);
INSERT INTO 'dancesstepsmap' VALUES (26937, 17624, 4);
INSERT INTO 'dancesstepsmap' VALUES (26938, 19802, 5);
INSERT INTO 'dancesstepsmap' VALUES (26939, 19802, 4);
INSERT INTO 'dancesstepsmap' VALUES (26940, 13559, 4);
INSERT INTO 'dancesstepsmap' VALUES (26941, 13559, 5);
INSERT INTO 'dancesstepsmap' VALUES (12655, 11359, 1);
INSERT INTO 'dancesstepsmap' VALUES (12656, 11359, 3);
INSERT INTO 'dancesstepsmap' VALUES (26117, 19061, 5);
INSERT INTO 'dancesstepsmap' VALUES (26118, 19061, 4);
INSERT INTO 'dancesstepsmap' VALUES (26942, 17318, 5);
INSERT INTO 'dancesstepsmap' VALUES (26943, 17318, 4);
INSERT INTO 'dancesstepsmap' VALUES (26944, 1108, 2);
INSERT INTO 'dancesstepsmap' VALUES (26945, 18996, 4);
INSERT INTO 'dancesstepsmap' VALUES (26946, 18996, 5);
INSERT INTO 'dancesstepsmap' VALUES (26947, 1186, 102);
INSERT INTO 'dancesstepsmap' VALUES (26948, 1186, 2);
INSERT INTO 'dancesstepsmap' VALUES (26949, 198, 2);
INSERT INTO 'dancesstepsmap' VALUES (26950, 641, 5);
INSERT INTO 'dancesstepsmap' VALUES (26951, 641, 6);
INSERT INTO 'dancesstepsmap' VALUES (26952, 681, 2);
INSERT INTO 'dancesstepsmap' VALUES (26953, 19803, 1);
INSERT INTO 'dancesstepsmap' VALUES (26954, 19803, 2);
INSERT INTO 'dancesstepsmap' VALUES (26955, 6922, 5);
INSERT INTO 'dancesstepsmap' VALUES (26956, 833, 5);
INSERT INTO 'dancesstepsmap' VALUES (26957, 890, 5);
INSERT INTO 'dancesstepsmap' VALUES (26958, 12799, 3);
INSERT INTO 'dancesstepsmap' VALUES (26959, 12799, 1);
INSERT INTO 'dancesstepsmap' VALUES (26960, 12799, 2);
INSERT INTO 'dancesstepsmap' VALUES (26961, 12832, 1);
INSERT INTO 'dancesstepsmap' VALUES (26962, 12832, 2);
INSERT INTO 'dancesstepsmap' VALUES (26963, 19804, 3);
INSERT INTO 'dancesstepsmap' VALUES (26964, 19804, 1);
INSERT INTO 'dancesstepsmap' VALUES (26965, 19804, 8);
INSERT INTO 'dancesstepsmap' VALUES (26966, 19806, 1);
INSERT INTO 'dancesstepsmap' VALUES (26967, 19806, 2);
INSERT INTO 'dancesstepsmap' VALUES (26968, 19805, 4);
INSERT INTO 'dancesstepsmap' VALUES (26969, 19809, 5);
INSERT INTO 'dancesstepsmap' VALUES (26970, 19809, 4);
INSERT INTO 'dancesstepsmap' VALUES (26971, 14504, 1);
INSERT INTO 'dancesstepsmap' VALUES (26972, 14504, 2);
INSERT INTO 'dancesstepsmap' VALUES (26973, 14504, 3);
INSERT INTO 'dancesstepsmap' VALUES (26974, 14517, 1);
INSERT INTO 'dancesstepsmap' VALUES (26975, 14517, 2);
INSERT INTO 'dancesstepsmap' VALUES (26976, 14515, 1);
INSERT INTO 'dancesstepsmap' VALUES (26977, 19808, 1);
INSERT INTO 'dancesstepsmap' VALUES (26978, 19808, 2);
INSERT INTO 'dancesstepsmap' VALUES (26979, 19810, 1);
INSERT INTO 'dancesstepsmap' VALUES (26980, 19810, 2);
INSERT INTO 'dancesstepsmap' VALUES (26981, 19810, 3);
INSERT INTO 'dancesstepsmap' VALUES (26982, 1461, 2);
INSERT INTO 'dancesstepsmap' VALUES (26983, 19811, 4);
INSERT INTO 'dancesstepsmap' VALUES (26984, 19811, 5);
INSERT INTO 'dancesstepsmap' VALUES (26985, 19812, 2);
INSERT INTO 'dancesstepsmap' VALUES (26986, 19812, 1);
INSERT INTO 'dancesstepsmap' VALUES (26987, 19812, 3);
INSERT INTO 'dancesstepsmap' VALUES (26988, 19813, 4);
INSERT INTO 'dancesstepsmap' VALUES (26989, 19813, 5);
INSERT INTO 'dancesstepsmap' VALUES (26990, 19814, 4);
INSERT INTO 'dancesstepsmap' VALUES (26991, 19814, 5);
INSERT INTO 'dancesstepsmap' VALUES (26992, 19815, 2);
INSERT INTO 'dancesstepsmap' VALUES (26993, 19815, 1);
INSERT INTO 'dancesstepsmap' VALUES (26994, 19815, 3);
INSERT INTO 'dancesstepsmap' VALUES (26995, 2035, 5);
INSERT INTO 'dancesstepsmap' VALUES (26996, 1278, 2);
INSERT INTO 'dancesstepsmap' VALUES (26997, 1449, 2);
INSERT INTO 'dancesstepsmap' VALUES (26998, 6880, 5);
INSERT INTO 'dancesstepsmap' VALUES (26999, 19818, 1);
INSERT INTO 'dancesstepsmap' VALUES (27000, 19818, 2);
INSERT INTO 'dancesstepsmap' VALUES (26729, 19730, 2);
INSERT INTO 'dancesstepsmap' VALUES (26730, 19730, 1);
INSERT INTO 'dancesstepsmap' VALUES (27001, 16876, 1);
INSERT INTO 'dancesstepsmap' VALUES (27002, 19731, 4);
INSERT INTO 'dancesstepsmap' VALUES (27003, 19731, 5);
INSERT INTO 'dancesstepsmap' VALUES (27004, 4301, 2);
INSERT INTO 'dancesstepsmap' VALUES (27005, 19819, 2);
INSERT INTO 'dancesstepsmap' VALUES (27006, 19819, 1);
INSERT INTO 'dancesstepsmap' VALUES (27007, 8388, 2);
INSERT INTO 'dancesstepsmap' VALUES (27008, 7582, 3);
INSERT INTO 'dancesstepsmap' VALUES (27009, 19747, 1);
INSERT INTO 'dancesstepsmap' VALUES (27010, 19747, 2);
INSERT INTO 'dancesstepsmap' VALUES (27011, 19820, 1);
INSERT INTO 'dancesstepsmap' VALUES (27012, 19820, 2);
INSERT INTO 'dancesstepsmap' VALUES (27013, 19820, 3);
INSERT INTO 'dancesstepsmap' VALUES (27014, 4044, 2);
INSERT INTO 'dancesstepsmap' VALUES (27015, 4737, 5);
INSERT INTO 'dancesstepsmap' VALUES (27016, 15040, 1);
INSERT INTO 'dancesstepsmap' VALUES (27017, 15040, 2);
INSERT INTO 'dancesstepsmap' VALUES (27018, 15040, 3);
INSERT INTO 'dancesstepsmap' VALUES (27019, 19617, 1);
INSERT INTO 'dancesstepsmap' VALUES (27020, 19617, 2);
INSERT INTO 'dancesstepsmap' VALUES (27021, 15530, 2);
INSERT INTO 'dancesstepsmap' VALUES (27022, 15530, 1);
INSERT INTO 'dancesstepsmap' VALUES (27023, 6473, 2);
INSERT INTO 'dancesstepsmap' VALUES (27024, 17983, 1);
INSERT INTO 'dancesstepsmap' VALUES (27025, 18854, 5);
INSERT INTO 'dancesstepsmap' VALUES (27026, 18854, 4);
INSERT INTO 'dancesstepsmap' VALUES (27027, 19831, 4);
INSERT INTO 'dancesstepsmap' VALUES (27028, 19831, 5);
INSERT INTO 'dancesstepsmap' VALUES (27029, 19831, 1);
INSERT INTO 'dancesstepsmap' VALUES (27030, 19831, 2);
INSERT INTO 'dancesstepsmap' VALUES (27031, 19832, 5);
INSERT INTO 'dancesstepsmap' VALUES (27032, 19832, 4);
INSERT INTO 'dancesstepsmap' VALUES (27033, 17471, 2);
INSERT INTO 'dancesstepsmap' VALUES (27034, 17471, 1);
INSERT INTO 'dancesstepsmap' VALUES (27035, 15536, 5);
INSERT INTO 'dancesstepsmap' VALUES (27036, 15536, 4);
INSERT INTO 'dancesstepsmap' VALUES (27037, 5301, 5);
INSERT INTO 'dancesstepsmap' VALUES (27038, 8360, 2);
INSERT INTO 'dancesstepsmap' VALUES (27039, 19833, 5);
INSERT INTO 'dancesstepsmap' VALUES (27040, 19833, 4);
INSERT INTO 'dancesstepsmap' VALUES (27041, 10928, 2);
INSERT INTO 'dancesstepsmap' VALUES (27042, 6012, 2);
INSERT INTO 'dancesstepsmap' VALUES (27043, 14713, 1);
INSERT INTO 'dancesstepsmap' VALUES (27044, 14713, 8);
INSERT INTO 'dancesstepsmap' VALUES (27045, 14231, 2);
INSERT INTO 'dancesstepsmap' VALUES (27046, 14231, 1);
INSERT INTO 'dancesstepsmap' VALUES (27047, 14231, 3);
INSERT INTO 'dancesstepsmap' VALUES (27048, 14140, 4);
INSERT INTO 'dancesstepsmap' VALUES (27049, 14140, 5);
INSERT INTO 'dancesstepsmap' VALUES (27050, 12827, 1);
INSERT INTO 'dancesstepsmap' VALUES (27051, 12827, 2);
INSERT INTO 'dancesstepsmap' VALUES (27052, 10884, 3);
INSERT INTO 'dancesstepsmap' VALUES (27053, 19834, 1);
INSERT INTO 'dancesstepsmap' VALUES (27054, 19835, 5);
INSERT INTO 'dancesstepsmap' VALUES (27055, 19835, 4);
INSERT INTO 'dancesstepsmap' VALUES (27056, 365, 5);
INSERT INTO 'dancesstepsmap' VALUES (27057, 19423, 1);
INSERT INTO 'dancesstepsmap' VALUES (27058, 19423, 2);
INSERT INTO 'dancesstepsmap' VALUES (27059, 6206, 5);
INSERT INTO 'dancesstepsmap' VALUES (27062, 1392, 2);
INSERT INTO 'dancesstepsmap' VALUES (27063, 17177, 1);
INSERT INTO 'dancesstepsmap' VALUES (27064, 17177, 2);
INSERT INTO 'dancesstepsmap' VALUES (27065, 7397, 5);
INSERT INTO 'dancesstepsmap' VALUES (27066, 11821, 2);
INSERT INTO 'dancesstepsmap' VALUES (27067, 19837, 1);
INSERT INTO 'dancesstepsmap' VALUES (27068, 19837, 2);
INSERT INTO 'dancesstepsmap' VALUES (27069, 19838, 5);
INSERT INTO 'dancesstepsmap' VALUES (27070, 19838, 4);
INSERT INTO 'dancesstepsmap' VALUES (27071, 6363, 5);
INSERT INTO 'dancesstepsmap' VALUES (27072, 14182, 1);
INSERT INTO 'dancesstepsmap' VALUES (27073, 14182, 2);
INSERT INTO 'dancesstepsmap' VALUES (27074, 19839, 4);
INSERT INTO 'dancesstepsmap' VALUES (27075, 19839, 5);
INSERT INTO 'dancesstepsmap' VALUES (27076, 19840, 1);
INSERT INTO 'dancesstepsmap' VALUES (27077, 19840, 3);
INSERT INTO 'dancesstepsmap' VALUES (27078, 10384, 5);
INSERT INTO 'dancesstepsmap' VALUES (27079, 2247, 5);
INSERT INTO 'dancesstepsmap' VALUES (27080, 8312, 5);
INSERT INTO 'dancesstepsmap' VALUES (27081, 624, 2);
INSERT INTO 'dancesstepsmap' VALUES (27082, 19841, 1);
INSERT INTO 'dancesstepsmap' VALUES (27083, 19841, 2);
INSERT INTO 'dancesstepsmap' VALUES (27085, 3169, 5);
INSERT INTO 'dancesstepsmap' VALUES (2927, 3168, 2);
INSERT INTO 'dancesstepsmap' VALUES (27084, 3168, 1);
INSERT INTO 'dancesstepsmap' VALUES (27086, 19842, 1);
INSERT INTO 'dancesstepsmap' VALUES (27087, 19842, 2);
INSERT INTO 'dancesstepsmap' VALUES (27088, 19843, 2);
INSERT INTO 'dancesstepsmap' VALUES (27089, 19843, 1);
INSERT INTO 'dancesstepsmap' VALUES (27090, 212, 5);
INSERT INTO 'dancesstepsmap' VALUES (27091, 9860, 2);
INSERT INTO 'dancesstepsmap' VALUES (27092, 8505, 2);
INSERT INTO 'dancesstepsmap' VALUES (27093, 7577, 5);
INSERT INTO 'dancesstepsmap' VALUES (27094, 7215, 2);
INSERT INTO 'dancesstepsmap' VALUES (27095, 5359, 5);
INSERT INTO 'dancesstepsmap' VALUES (27096, 1001, 2);
INSERT INTO 'dancesstepsmap' VALUES (27097, 551, 5);
INSERT INTO 'dancesstepsmap' VALUES (27098, 5063, 2);
INSERT INTO 'dancesstepsmap' VALUES (27099, 5063, 3);
INSERT INTO 'dancesstepsmap' VALUES (27100, 11171, 5);
INSERT INTO 'dancesstepsmap' VALUES (27101, 11171, 4);
INSERT INTO 'dancesstepsmap' VALUES (27102, 19822, 4);
INSERT INTO 'dancesstepsmap' VALUES (27103, 19822, 5);
INSERT INTO 'dancesstepsmap' VALUES (27104, 5062, 2);
INSERT INTO 'dancesstepsmap' VALUES (27105, 5889, 5);
INSERT INTO 'dancesstepsmap' VALUES (27106, 15649, 4);
INSERT INTO 'dancesstepsmap' VALUES (27107, 15649, 5);
INSERT INTO 'dancesstepsmap' VALUES (27108, 10960, 2);
INSERT INTO 'dancesstepsmap' VALUES (27109, 5471, 3);
INSERT INTO 'dancesstepsmap' VALUES (27110, 8644, 1);
INSERT INTO 'dancesstepsmap' VALUES (27111, 15632, 1);
INSERT INTO 'dancesstepsmap' VALUES (27112, 15632, 2);
INSERT INTO 'dancesstepsmap' VALUES (27113, 15632, 3);
INSERT INTO 'dancesstepsmap' VALUES (27114, 3225, 2);
INSERT INTO 'dancesstepsmap' VALUES (27115, 15633, 1);
INSERT INTO 'dancesstepsmap' VALUES (27116, 15633, 2);
INSERT INTO 'dancesstepsmap' VALUES (27117, 11181, 4);
INSERT INTO 'dancesstepsmap' VALUES (27118, 11181, 5);
INSERT INTO 'dancesstepsmap' VALUES (27119, 13507, 1);
INSERT INTO 'dancesstepsmap' VALUES (27120, 13507, 2);
INSERT INTO 'dancesstepsmap' VALUES (27121, 6464, 2);
INSERT INTO 'dancesstepsmap' VALUES (27122, 6464, 3);
INSERT INTO 'dancesstepsmap' VALUES (27126, 19599, 1);
INSERT INTO 'dancesstepsmap' VALUES (27127, 19599, 2);
INSERT INTO 'dancesstepsmap' VALUES (27128, 2172, 2);
INSERT INTO 'dancesstepsmap' VALUES (27129, 534, 3);
INSERT INTO 'dancesstepsmap' VALUES (27130, 533, 2);
INSERT INTO 'dancesstepsmap' VALUES (27131, 15233, 3);
INSERT INTO 'dancesstepsmap' VALUES (27132, 19845, 1);
INSERT INTO 'dancesstepsmap' VALUES (27133, 19845, 3);
INSERT INTO 'dancesstepsmap' VALUES (27134, 16892, 3);
INSERT INTO 'dancesstepsmap' VALUES (27135, 19846, 4);
INSERT INTO 'dancesstepsmap' VALUES (27136, 19847, 2);
INSERT INTO 'dancesstepsmap' VALUES (27137, 19847, 1);
INSERT INTO 'dancesstepsmap' VALUES (27139, 19848, 1);
INSERT INTO 'dancesstepsmap' VALUES (27140, 16338, 7);
INSERT INTO 'dancesstepsmap' VALUES (27141, 16338, 99);
INSERT INTO 'dancesstepsmap' VALUES (27143, 14540, 1);
INSERT INTO 'dancesstepsmap' VALUES (27144, 14540, 2);
INSERT INTO 'dancesstepsmap' VALUES (27145, 19850, 4);
INSERT INTO 'dancesstepsmap' VALUES (27146, 19850, 5);
INSERT INTO 'dancesstepsmap' VALUES (27147, 3615, 5);
INSERT INTO 'dancesstepsmap' VALUES (27148, 3139, 2);
INSERT INTO 'dancesstepsmap' VALUES (27150, 2229, 2);
INSERT INTO 'dancesstepsmap' VALUES (27151, 3140, 2);
INSERT INTO 'dancesstepsmap' VALUES (27149, 11939, 3);
INSERT INTO 'dancesstepsmap' VALUES (27154, 14851, 1);
INSERT INTO 'dancesstepsmap' VALUES (27155, 14851, 2);
INSERT INTO 'dancesstepsmap' VALUES (27156, 17805, 4);
INSERT INTO 'dancesstepsmap' VALUES (27157, 17805, 5);
INSERT INTO 'dancesstepsmap' VALUES (27158, 19851, 1);
INSERT INTO 'dancesstepsmap' VALUES (27159, 19851, 2);
INSERT INTO 'dancesstepsmap' VALUES (27160, 9291, 5);
INSERT INTO 'dancesstepsmap' VALUES (27161, 9291, 4);
INSERT INTO 'dancesstepsmap' VALUES (27162, 9291, 6);
INSERT INTO 'dancesstepsmap' VALUES (27163, 19852, 1);
INSERT INTO 'dancesstepsmap' VALUES (27164, 12894, 2);
INSERT INTO 'dancesstepsmap' VALUES (27165, 19828, 1);
INSERT INTO 'dancesstepsmap' VALUES (27166, 19828, 2);
INSERT INTO 'dancesstepsmap' VALUES (27167, 19828, 3);
INSERT INTO 'dancesstepsmap' VALUES (27171, 5804, 2);
INSERT INTO 'dancesstepsmap' VALUES (27172, 5804, 3);
INSERT INTO 'dancesstepsmap' VALUES (27173, 8525, 2);
INSERT INTO 'dancesstepsmap' VALUES (27174, 7731, 2);
INSERT INTO 'dancesstepsmap' VALUES (27175, 7731, 3);
INSERT INTO 'dancesstepsmap' VALUES (27176, 2371, 5);
INSERT INTO 'dancesstepsmap' VALUES (27177, 19856, 4);
INSERT INTO 'dancesstepsmap' VALUES (27178, 19856, 5);
INSERT INTO 'dancesstepsmap' VALUES (27179, 15246, 1);
INSERT INTO 'dancesstepsmap' VALUES (27180, 15246, 2);
INSERT INTO 'dancesstepsmap' VALUES (27181, 15246, 3);
INSERT INTO 'dancesstepsmap' VALUES (27182, 1894, 2);
INSERT INTO 'dancesstepsmap' VALUES (27183, 1894, 3);
INSERT INTO 'dancesstepsmap' VALUES (27184, 15307, 4);
INSERT INTO 'dancesstepsmap' VALUES (27185, 15307, 5);
INSERT INTO 'dancesstepsmap' VALUES (27186, 19849, 4);
INSERT INTO 'dancesstepsmap' VALUES (27187, 19849, 5);
INSERT INTO 'dancesstepsmap' VALUES (27188, 19857, 1);
INSERT INTO 'dancesstepsmap' VALUES (27189, 19857, 2);
INSERT INTO 'dancesstepsmap' VALUES (27190, 17371, 5);
INSERT INTO 'dancesstepsmap' VALUES (27191, 17371, 4);
INSERT INTO 'dancesstepsmap' VALUES (27192, 20, 5);
INSERT INTO 'dancesstepsmap' VALUES (27193, 9219, 6);
INSERT INTO 'dancesstepsmap' VALUES (27194, 8578, 3);
INSERT INTO 'dancesstepsmap' VALUES (27195, 12960, 2);
INSERT INTO 'dancesstepsmap' VALUES (27196, 4185, 3);
INSERT INTO 'dancesstepsmap' VALUES (27197, 19858, 1);
INSERT INTO 'dancesstepsmap' VALUES (27198, 19858, 2);
INSERT INTO 'dancesstepsmap' VALUES (27199, 19859, 1);
INSERT INTO 'dancesstepsmap' VALUES (27200, 19859, 2);
INSERT INTO 'dancesstepsmap' VALUES (27201, 572, 2);
INSERT INTO 'dancesstepsmap' VALUES (27202, 1504, 2);
INSERT INTO 'dancesstepsmap' VALUES (27203, 19878, 4);
INSERT INTO 'dancesstepsmap' VALUES (27204, 19878, 5);
INSERT INTO 'dancesstepsmap' VALUES (27206, 19887, 1);
INSERT INTO 'dancesstepsmap' VALUES (27207, 19860, 5);
INSERT INTO 'dancesstepsmap' VALUES (27208, 19860, 4);
INSERT INTO 'dancesstepsmap' VALUES (27209, 10619, 2);
INSERT INTO 'dancesstepsmap' VALUES (27210, 10619, 1);
INSERT INTO 'dancesstepsmap' VALUES (27211, 10619, 3);
INSERT INTO 'dancesstepsmap' VALUES (27212, 10726, 4);
INSERT INTO 'dancesstepsmap' VALUES (27213, 10726, 5);
INSERT INTO 'dancesstepsmap' VALUES (27214, 19889, 1);
INSERT INTO 'dancesstepsmap' VALUES (27215, 19889, 2);
INSERT INTO 'dancesstepsmap' VALUES (27216, 19889, 3);
INSERT INTO 'dancesstepsmap' VALUES (27217, 19890, 1);
INSERT INTO 'dancesstepsmap' VALUES (27218, 19891, 1);
INSERT INTO 'dancesstepsmap' VALUES (27219, 19890, 2);
INSERT INTO 'dancesstepsmap' VALUES (27220, 1806, 5);
INSERT INTO 'dancesstepsmap' VALUES (13211, 11613, 2);
INSERT INTO 'dancesstepsmap' VALUES (27221, 11613, 3);
INSERT INTO 'dancesstepsmap' VALUES (27222, 9222, 2);
INSERT INTO 'dancesstepsmap' VALUES (27223, 19892, 1);
INSERT INTO 'dancesstepsmap' VALUES (27224, 19892, 2);
INSERT INTO 'dancesstepsmap' VALUES (27225, 19893, 1);
INSERT INTO 'dancesstepsmap' VALUES (27226, 19893, 2);
INSERT INTO 'dancesstepsmap' VALUES (27227, 19894, 2);
INSERT INTO 'dancesstepsmap' VALUES (27228, 19894, 1);
INSERT INTO 'dancesstepsmap' VALUES (27229, 19895, 2);
INSERT INTO 'dancesstepsmap' VALUES (27230, 19895, 1);
INSERT INTO 'dancesstepsmap' VALUES (27231, 3037, 5);
INSERT INTO 'dancesstepsmap' VALUES (27232, 2396, 3);
INSERT INTO 'dancesstepsmap' VALUES (27233, 19864, 1);
INSERT INTO 'dancesstepsmap' VALUES (27234, 19864, 3);
INSERT INTO 'dancesstepsmap' VALUES (27235, 19861, 1);
INSERT INTO 'dancesstepsmap' VALUES (27236, 19861, 2);
INSERT INTO 'dancesstepsmap' VALUES (27237, 19877, 4);
INSERT INTO 'dancesstepsmap' VALUES (27238, 19877, 5);
INSERT INTO 'dancesstepsmap' VALUES (27239, 19871, 1);
INSERT INTO 'dancesstepsmap' VALUES (27240, 19871, 2);
INSERT INTO 'dancesstepsmap' VALUES (27241, 19871, 3);
INSERT INTO 'dancesstepsmap' VALUES (27242, 19876, 1);
INSERT INTO 'dancesstepsmap' VALUES (27243, 19876, 2);
INSERT INTO 'dancesstepsmap' VALUES (27244, 19876, 3);
INSERT INTO 'dancesstepsmap' VALUES (27245, 19896, 4);
INSERT INTO 'dancesstepsmap' VALUES (27246, 19896, 5);
INSERT INTO 'dancesstepsmap' VALUES (27247, 19874, 1);
INSERT INTO 'dancesstepsmap' VALUES (27248, 3522, 3);
INSERT INTO 'dancesstepsmap' VALUES (27249, 19883, 1);
INSERT INTO 'dancesstepsmap' VALUES (27250, 19904, 1);
INSERT INTO 'dancesstepsmap' VALUES (27251, 19904, 3);
INSERT INTO 'dancesstepsmap' VALUES (27252, 19906, 1);
INSERT INTO 'dancesstepsmap' VALUES (27253, 19906, 2);
INSERT INTO 'dancesstepsmap' VALUES (27254, 19906, 3);
INSERT INTO 'dancesstepsmap' VALUES (27255, 8624, 5);
INSERT INTO 'dancesstepsmap' VALUES (27256, 19905, 4);
INSERT INTO 'dancesstepsmap' VALUES (27257, 19905, 5);
INSERT INTO 'dancesstepsmap' VALUES (27258, 18939, 1);
INSERT INTO 'dancesstepsmap' VALUES (6969, 327, 10);
INSERT INTO 'dancesstepsmap' VALUES (27259, 19908, 1);
INSERT INTO 'dancesstepsmap' VALUES (27260, 19908, 2);
INSERT INTO 'dancesstepsmap' VALUES (27261, 19908, 3);
INSERT INTO 'dancesstepsmap' VALUES (27262, 19926, 2);
INSERT INTO 'dancesstepsmap' VALUES (27263, 19926, 1);
INSERT INTO 'dancesstepsmap' VALUES (27264, 19927, 2);
INSERT INTO 'dancesstepsmap' VALUES (27265, 19927, 1);
INSERT INTO 'dancesstepsmap' VALUES (27266, 19929, 2);
INSERT INTO 'dancesstepsmap' VALUES (27267, 19929, 1);
INSERT INTO 'dancesstepsmap' VALUES (27268, 19930, 2);
INSERT INTO 'dancesstepsmap' VALUES (27269, 19930, 1);
INSERT INTO 'dancesstepsmap' VALUES (27270, 19930, 3);
INSERT INTO 'dancesstepsmap' VALUES (27271, 19931, 2);
INSERT INTO 'dancesstepsmap' VALUES (27272, 19931, 1);
INSERT INTO 'dancesstepsmap' VALUES (27273, 19932, 5);
INSERT INTO 'dancesstepsmap' VALUES (27274, 19932, 4);
INSERT INTO 'dancesstepsmap' VALUES (27275, 4026, 6);
INSERT INTO 'dancesstepsmap' VALUES (27276, 19933, 2);
INSERT INTO 'dancesstepsmap' VALUES (27277, 19933, 1);
INSERT INTO 'dancesstepsmap' VALUES (27278, 19933, 3);
INSERT INTO 'dancesstepsmap' VALUES (27279, 17251, 5);
INSERT INTO 'dancesstepsmap' VALUES (27280, 17251, 4);
INSERT INTO 'dancesstepsmap' VALUES (27281, 14860, 1);
INSERT INTO 'dancesstepsmap' VALUES (27282, 14860, 2);
INSERT INTO 'dancesstepsmap' VALUES (27283, 14860, 3);
INSERT INTO 'dancesstepsmap' VALUES (27284, 14832, 1);
INSERT INTO 'dancesstepsmap' VALUES (27285, 19941, 1);
INSERT INTO 'dancesstepsmap' VALUES (27286, 19941, 2);
INSERT INTO 'dancesstepsmap' VALUES (27287, 9143, 1);
INSERT INTO 'dancesstepsmap' VALUES (27288, 9143, 2);
INSERT INTO 'dancesstepsmap' VALUES (27289, 9143, 3);
INSERT INTO 'dancesstepsmap' VALUES (27290, 19942, 2);
INSERT INTO 'dancesstepsmap' VALUES (27291, 19942, 1);
INSERT INTO 'dancesstepsmap' VALUES (27292, 5543, 2);
INSERT INTO 'dancesstepsmap' VALUES (27293, 5543, 3);
INSERT INTO 'dancesstepsmap' VALUES (27294, 11422, 1);
INSERT INTO 'dancesstepsmap' VALUES (27295, 11422, 2);
INSERT INTO 'dancesstepsmap' VALUES (27296, 11422, 3);
INSERT INTO 'dancesstepsmap' VALUES (7381, 8141, 1);
INSERT INTO 'dancesstepsmap' VALUES (7382, 8141, 2);
INSERT INTO 'dancesstepsmap' VALUES (27297, 19943, 1);
INSERT INTO 'dancesstepsmap' VALUES (27298, 19943, 2);
INSERT INTO 'dancesstepsmap' VALUES (27299, 5934, 2);
INSERT INTO 'dancesstepsmap' VALUES (27300, 19935, 1);
INSERT INTO 'dancesstepsmap' VALUES (27301, 19935, 2);
INSERT INTO 'dancesstepsmap' VALUES (27302, 19936, 4);
INSERT INTO 'dancesstepsmap' VALUES (27303, 19936, 5);
INSERT INTO 'dancesstepsmap' VALUES (27304, 19940, 1);
INSERT INTO 'dancesstepsmap' VALUES (27305, 19944, 1);
INSERT INTO 'dancesstepsmap' VALUES (27306, 19944, 2);
INSERT INTO 'dancesstepsmap' VALUES (27307, 19944, 3);
INSERT INTO 'dancesstepsmap' VALUES (27308, 9048, 5);
INSERT INTO 'dancesstepsmap' VALUES (27309, 19945, 1);
INSERT INTO 'dancesstepsmap' VALUES (27310, 19945, 3);
INSERT INTO 'dancesstepsmap' VALUES (27311, 19946, 1);
INSERT INTO 'dancesstepsmap' VALUES (27312, 19946, 2);
INSERT INTO 'dancesstepsmap' VALUES (27313, 19947, 1);
INSERT INTO 'dancesstepsmap' VALUES (27314, 19947, 2);
INSERT INTO 'dancesstepsmap' VALUES (27315, 19947, 3);
INSERT INTO 'dancesstepsmap' VALUES (27316, 19948, 2);
INSERT INTO 'dancesstepsmap' VALUES (27317, 19948, 1);
INSERT INTO 'dancesstepsmap' VALUES (27318, 19948, 3);
INSERT INTO 'dancesstepsmap' VALUES (27319, 19949, 1);
INSERT INTO 'dancesstepsmap' VALUES (27320, 19950, 1);
INSERT INTO 'dancesstepsmap' VALUES (27321, 19950, 2);
INSERT INTO 'dancesstepsmap' VALUES (27322, 4959, 2);
INSERT INTO 'dancesstepsmap' VALUES (27323, 19944, 8);
INSERT INTO 'dancesstepsmap' VALUES (27324, 19934, 1);
INSERT INTO 'dancesstepsmap' VALUES (27325, 19934, 2);
INSERT INTO 'dancesstepsmap' VALUES (27326, 19951, 2);
INSERT INTO 'dancesstepsmap' VALUES (27327, 19951, 1);
INSERT INTO 'dancesstepsmap' VALUES (27328, 19951, 3);
INSERT INTO 'dancesstepsmap' VALUES (27332, 19924, 4);
INSERT INTO 'dancesstepsmap' VALUES (27333, 19924, 5);
INSERT INTO 'dancesstepsmap' VALUES (27334, 3788, 5);
INSERT INTO 'dancesstepsmap' VALUES (27335, 12519, 2);
INSERT INTO 'dancesstepsmap' VALUES (27336, 19953, 1);
INSERT INTO 'dancesstepsmap' VALUES (27337, 19953, 3);
INSERT INTO 'dancesstepsmap' VALUES (27338, 19939, 1);
INSERT INTO 'dancesstepsmap' VALUES (27339, 19939, 2);
INSERT INTO 'dancesstepsmap' VALUES (27340, 17769, 1);
INSERT INTO 'dancesstepsmap' VALUES (27341, 17769, 2);
INSERT INTO 'dancesstepsmap' VALUES (27342, 17769, 3);
INSERT INTO 'dancesstepsmap' VALUES (27343, 1773, 5);
INSERT INTO 'dancesstepsmap' VALUES (27344, 479, 2);
INSERT INTO 'dancesstepsmap' VALUES (27345, 13914, 2);
INSERT INTO 'dancesstepsmap' VALUES (27346, 19954, 5);
INSERT INTO 'dancesstepsmap' VALUES (27347, 19954, 4);
INSERT INTO 'dancesstepsmap' VALUES (27348, 19955, 1);
INSERT INTO 'dancesstepsmap' VALUES (27349, 19955, 2);
INSERT INTO 'dancesstepsmap' VALUES (27350, 19925, 1);
INSERT INTO 'dancesstepsmap' VALUES (27351, 19938, 1);
INSERT INTO 'dancesstepsmap' VALUES (27352, 19938, 2);
INSERT INTO 'dancesstepsmap' VALUES (27353, 19938, 3);
INSERT INTO 'dancesstepsmap' VALUES (27354, 19956, 5);
INSERT INTO 'dancesstepsmap' VALUES (27355, 19956, 4);
INSERT INTO 'dancesstepsmap' VALUES (27356, 19869, 1);
INSERT INTO 'dancesstepsmap' VALUES (27357, 19869, 2);
INSERT INTO 'dancesstepsmap' VALUES (27358, 19869, 3);
INSERT INTO 'dancesstepsmap' VALUES (27359, 19886, 4);
INSERT INTO 'dancesstepsmap' VALUES (27360, 14010, 2);
INSERT INTO 'dancesstepsmap' VALUES (27361, 14010, 1);
INSERT INTO 'dancesstepsmap' VALUES (27362, 19885, 1);
INSERT INTO 'dancesstepsmap' VALUES (27363, 19957, 4);
INSERT INTO 'dancesstepsmap' VALUES (27364, 19884, 1);
INSERT INTO 'dancesstepsmap' VALUES (27365, 19866, 1);
INSERT INTO 'dancesstepsmap' VALUES (27366, 19866, 2);
INSERT INTO 'dancesstepsmap' VALUES (27367, 19959, 4);
INSERT INTO 'dancesstepsmap' VALUES (27368, 19959, 5);
INSERT INTO 'dancesstepsmap' VALUES (27369, 19959, 1);
INSERT INTO 'dancesstepsmap' VALUES (27370, 19959, 2);
INSERT INTO 'dancesstepsmap' VALUES (27371, 19960, 5);
INSERT INTO 'dancesstepsmap' VALUES (27372, 19960, 4);
INSERT INTO 'dancesstepsmap' VALUES (27373, 19901, 4);
INSERT INTO 'dancesstepsmap' VALUES (27374, 19901, 5);
INSERT INTO 'dancesstepsmap' VALUES (27375, 19958, 1);
INSERT INTO 'dancesstepsmap' VALUES (27376, 19958, 2);
INSERT INTO 'dancesstepsmap' VALUES (27379, 19962, 2);
INSERT INTO 'dancesstepsmap' VALUES (27380, 19962, 1);
INSERT INTO 'dancesstepsmap' VALUES (27381, 19963, 3);
INSERT INTO 'dancesstepsmap' VALUES (27382, 19963, 1);
INSERT INTO 'dancesstepsmap' VALUES (27385, 19964, 3);
INSERT INTO 'dancesstepsmap' VALUES (27388, 19966, 3);
INSERT INTO 'dancesstepsmap' VALUES (27389, 19966, 1);
INSERT INTO 'dancesstepsmap' VALUES (27390, 8918, 1);
INSERT INTO 'dancesstepsmap' VALUES (27391, 8918, 2);
INSERT INTO 'dancesstepsmap' VALUES (27392, 19448, 1);
INSERT INTO 'dancesstepsmap' VALUES (27393, 19448, 2);
INSERT INTO 'dancesstepsmap' VALUES (27394, 19438, 4);
INSERT INTO 'dancesstepsmap' VALUES (27395, 19438, 5);
INSERT INTO 'dancesstepsmap' VALUES (27396, 175, 2);
INSERT INTO 'dancesstepsmap' VALUES (27397, 7137, 2);
INSERT INTO 'dancesstepsmap' VALUES (27398, 11760, 5);
INSERT INTO 'dancesstepsmap' VALUES (27399, 17623, 1);
INSERT INTO 'dancesstepsmap' VALUES (27400, 18710, 1);
INSERT INTO 'dancesstepsmap' VALUES (27401, 18710, 2);
INSERT INTO 'dancesstepsmap' VALUES (27402, 8917, 5);
INSERT INTO 'dancesstepsmap' VALUES (27403, 8917, 4);
INSERT INTO 'dancesstepsmap' VALUES (27404, 18905, 1);
INSERT INTO 'dancesstepsmap' VALUES (27405, 19967, 2);
INSERT INTO 'dancesstepsmap' VALUES (27406, 19967, 3);
INSERT INTO 'dancesstepsmap' VALUES (27407, 19967, 1);
INSERT INTO 'dancesstepsmap' VALUES (27408, 19968, 5);
INSERT INTO 'dancesstepsmap' VALUES (27409, 19968, 4);
INSERT INTO 'dancesstepsmap' VALUES (27410, 4471, 2);
INSERT INTO 'dancesstepsmap' VALUES (27411, 19910, 1);
INSERT INTO 'dancesstepsmap' VALUES (27412, 19910, 2);
INSERT INTO 'dancesstepsmap' VALUES (27413, 18729, 1);
INSERT INTO 'dancesstepsmap' VALUES (27414, 18729, 2);
INSERT INTO 'dancesstepsmap' VALUES (27415, 18930, 4);
INSERT INTO 'dancesstepsmap' VALUES (27416, 18930, 5);
INSERT INTO 'dancesstepsmap' VALUES (27417, 17693, 1);
INSERT INTO 'dancesstepsmap' VALUES (27418, 17581, 2);
INSERT INTO 'dancesstepsmap' VALUES (27419, 17581, 1);
INSERT INTO 'dancesstepsmap' VALUES (27420, 19197, 1);
INSERT INTO 'dancesstepsmap' VALUES (27421, 19197, 2);
INSERT INTO 'dancesstepsmap' VALUES (27422, 19198, 1);
INSERT INTO 'dancesstepsmap' VALUES (27423, 19198, 2);
INSERT INTO 'dancesstepsmap' VALUES (27424, 19969, 2);
INSERT INTO 'dancesstepsmap' VALUES (27425, 19969, 1);
INSERT INTO 'dancesstepsmap' VALUES (27426, 19969, 3);
INSERT INTO 'dancesstepsmap' VALUES (27427, 19970, 4);
INSERT INTO 'dancesstepsmap' VALUES (27428, 19970, 5);
INSERT INTO 'dancesstepsmap' VALUES (27429, 19923, 1);
INSERT INTO 'dancesstepsmap' VALUES (27430, 19923, 2);
INSERT INTO 'dancesstepsmap' VALUES (27431, 19971, 2);
INSERT INTO 'dancesstepsmap' VALUES (27432, 19971, 1);
INSERT INTO 'dancesstepsmap' VALUES (27433, 10270, 1);
INSERT INTO 'dancesstepsmap' VALUES (27434, 10270, 2);
INSERT INTO 'dancesstepsmap' VALUES (27435, 10270, 4);
INSERT INTO 'dancesstepsmap' VALUES (27436, 10270, 5);
INSERT INTO 'dancesstepsmap' VALUES (27437, 4474, 5);
INSERT INTO 'dancesstepsmap' VALUES (27438, 5799, 2);
INSERT INTO 'dancesstepsmap' VALUES (27439, 5799, 3);
INSERT INTO 'dancesstepsmap' VALUES (27440, 5799, 8);
INSERT INTO 'dancesstepsmap' VALUES (27441, 7302, 2);
INSERT INTO 'dancesstepsmap' VALUES (27442, 18808, 1);
INSERT INTO 'dancesstepsmap' VALUES (27443, 18808, 2);
INSERT INTO 'dancesstepsmap' VALUES (27444, 19972, 4);
INSERT INTO 'dancesstepsmap' VALUES (27445, 17695, 5);
INSERT INTO 'dancesstepsmap' VALUES (27446, 17695, 4);
INSERT INTO 'dancesstepsmap' VALUES (27447, 17695, 2);
INSERT INTO 'dancesstepsmap' VALUES (27448, 17695, 1);
INSERT INTO 'dancesstepsmap' VALUES (27449, 7302, 8);
INSERT INTO 'dancesstepsmap' VALUES (27450, 19974, 1);
INSERT INTO 'dancesstepsmap' VALUES (27451, 19974, 3);
INSERT INTO 'dancesstepsmap' VALUES (27452, 19974, 2);
INSERT INTO 'dancesstepsmap' VALUES (27453, 19975, 1);
INSERT INTO 'dancesstepsmap' VALUES (27454, 19975, 2);
INSERT INTO 'dancesstepsmap' VALUES (27455, 17577, 1);
INSERT INTO 'dancesstepsmap' VALUES (27456, 17577, 2);
INSERT INTO 'dancesstepsmap' VALUES (27457, 19973, 1);
INSERT INTO 'dancesstepsmap' VALUES (27458, 19973, 2);
INSERT INTO 'dancesstepsmap' VALUES (27459, 19903, 1);
INSERT INTO 'dancesstepsmap' VALUES (27460, 19903, 2);
INSERT INTO 'dancesstepsmap' VALUES (27461, 6928, 2);
INSERT INTO 'dancesstepsmap' VALUES (27462, 19976, 4);
INSERT INTO 'dancesstepsmap' VALUES (27463, 19976, 5);
INSERT INTO 'dancesstepsmap' VALUES (27464, 4103, 2);
INSERT INTO 'dancesstepsmap' VALUES (27465, 19979, 1);
INSERT INTO 'dancesstepsmap' VALUES (27466, 19979, 2);
INSERT INTO 'dancesstepsmap' VALUES (27467, 19980, 5);
INSERT INTO 'dancesstepsmap' VALUES (27468, 19980, 4);
INSERT INTO 'dancesstepsmap' VALUES (9261, 4442, 2);
INSERT INTO 'dancesstepsmap' VALUES (27469, 4442, 3);
INSERT INTO 'dancesstepsmap' VALUES (27470, 19054, 6);
INSERT INTO 'dancesstepsmap' VALUES (27471, 19981, 4);
INSERT INTO 'dancesstepsmap' VALUES (27472, 4806, 5);
INSERT INTO 'dancesstepsmap' VALUES (27473, 794, 5);
INSERT INTO 'dancesstepsmap' VALUES (27474, 4907, 5);
INSERT INTO 'dancesstepsmap' VALUES (27475, 19437, 1);
INSERT INTO 'dancesstepsmap' VALUES (27476, 19437, 2);
INSERT INTO 'dancesstepsmap' VALUES (27477, 18714, 1);
INSERT INTO 'dancesstepsmap' VALUES (27478, 18714, 2);
INSERT INTO 'dancesstepsmap' VALUES (27479, 2257, 3);
INSERT INTO 'dancesstepsmap' VALUES (27480, 2780, 2);
INSERT INTO 'dancesstepsmap' VALUES (27481, 1400, 2);
INSERT INTO 'dancesstepsmap' VALUES (27482, 1400, 3);
INSERT INTO 'dancesstepsmap' VALUES (27484, 19862, 1);
INSERT INTO 'dancesstepsmap' VALUES (27485, 2593, 3);
INSERT INTO 'dancesstepsmap' VALUES (27486, 936, 5);
INSERT INTO 'dancesstepsmap' VALUES (27487, 1591, 5);
INSERT INTO 'dancesstepsmap' VALUES (27488, 19982, 5);
INSERT INTO 'dancesstepsmap' VALUES (27489, 19982, 4);
INSERT INTO 'dancesstepsmap' VALUES (27490, 19982, 2);
INSERT INTO 'dancesstepsmap' VALUES (27491, 19982, 1);
INSERT INTO 'dancesstepsmap' VALUES (27493, 6739, 5);
INSERT INTO 'dancesstepsmap' VALUES (27494, 19983, 5);
INSERT INTO 'dancesstepsmap' VALUES (27495, 19983, 4);
INSERT INTO 'dancesstepsmap' VALUES (27496, 19983, 2);
INSERT INTO 'dancesstepsmap' VALUES (27497, 19983, 1);
INSERT INTO 'dancesstepsmap' VALUES (27498, 18875, 4);
INSERT INTO 'dancesstepsmap' VALUES (27499, 18940, 1);
INSERT INTO 'dancesstepsmap' VALUES (27500, 18940, 2);
INSERT INTO 'dancesstepsmap' VALUES (27501, 16291, 3);
INSERT INTO 'dancesstepsmap' VALUES (27502, 14572, 4);
INSERT INTO 'dancesstepsmap' VALUES (27503, 14572, 5);
INSERT INTO 'dancesstepsmap' VALUES (27504, 19900, 4);
INSERT INTO 'dancesstepsmap' VALUES (27505, 19900, 5);
INSERT INTO 'dancesstepsmap' VALUES (27506, 19984, 1);
INSERT INTO 'dancesstepsmap' VALUES (27507, 19984, 3);
INSERT INTO 'dancesstepsmap' VALUES (27508, 12919, 2);
INSERT INTO 'dancesstepsmap' VALUES (27509, 19985, 1);
INSERT INTO 'dancesstepsmap' VALUES (27510, 19985, 2);
INSERT INTO 'dancesstepsmap' VALUES (27512, 19994, 1);
INSERT INTO 'dancesstepsmap' VALUES (27513, 19994, 2);
INSERT INTO 'dancesstepsmap' VALUES (27514, 19994, 3);
INSERT INTO 'dancesstepsmap' VALUES (27515, 19995, 1);
INSERT INTO 'dancesstepsmap' VALUES (27516, 19995, 2);
INSERT INTO 'dancesstepsmap' VALUES (27517, 19995, 3);
INSERT INTO 'dancesstepsmap' VALUES (27518, 19996, 4);
INSERT INTO 'dancesstepsmap' VALUES (27519, 19997, 4);
INSERT INTO 'dancesstepsmap' VALUES (27520, 19997, 5);
INSERT INTO 'dancesstepsmap' VALUES (27521, 19998, 1);
INSERT INTO 'dancesstepsmap' VALUES (27522, 19998, 2);
INSERT INTO 'dancesstepsmap' VALUES (27523, 19999, 4);
INSERT INTO 'dancesstepsmap' VALUES (27524, 19999, 5);
INSERT INTO 'dancesstepsmap' VALUES (27483, 5997, 4);
INSERT INTO 'dancesstepsmap' VALUES (27386, 19965, 4);
INSERT INTO 'dancesstepsmap' VALUES (27383, 19964, 1);
INSERT INTO 'dancesstepsmap' VALUES (27384, 19964, 2);
INSERT INTO 'dancesstepsmap' VALUES (27377, 19961, 1);
INSERT INTO 'dancesstepsmap' VALUES (27378, 19961, 2);
INSERT INTO 'dancesstepsmap' VALUES (27525, 20002, 2);
INSERT INTO 'dancesstepsmap' VALUES (27526, 20002, 3);
INSERT INTO 'dancesstepsmap' VALUES (27527, 20002, 1);
INSERT INTO 'dancesstepsmap' VALUES (27528, 20001, 1);
INSERT INTO 'dancesstepsmap' VALUES (27529, 20001, 2);
INSERT INTO 'dancesstepsmap' VALUES (27530, 20000, 4);
INSERT INTO 'dancesstepsmap' VALUES (27531, 20000, 5);
INSERT INTO 'dancesstepsmap' VALUES (27511, 19986, 1);
INSERT INTO 'dancesstepsmap' VALUES (27532, 19733, 1);
INSERT INTO 'dancesstepsmap' VALUES (27533, 19733, 2);
INSERT INTO 'dancesstepsmap' VALUES (27534, 19987, 1);
INSERT INTO 'dancesstepsmap' VALUES (27535, 19987, 3);
INSERT INTO 'dancesstepsmap' VALUES (27536, 19988, 1);
INSERT INTO 'dancesstepsmap' VALUES (27537, 19989, 1);
INSERT INTO 'dancesstepsmap' VALUES (27538, 19989, 2);
INSERT INTO 'dancesstepsmap' VALUES (27539, 19990, 1);
INSERT INTO 'dancesstepsmap' VALUES (27540, 19990, 2);
INSERT INTO 'dancesstepsmap' VALUES (27541, 18446, 1);
INSERT INTO 'dancesstepsmap' VALUES (27542, 18446, 2);
INSERT INTO 'dancesstepsmap' VALUES (27543, 19991, 5);
INSERT INTO 'dancesstepsmap' VALUES (27544, 19991, 4);
INSERT INTO 'dancesstepsmap' VALUES (27545, 19992, 5);
INSERT INTO 'dancesstepsmap' VALUES (27546, 19992, 4);
INSERT INTO 'dancesstepsmap' VALUES (27547, 18451, 1);
INSERT INTO 'dancesstepsmap' VALUES (27548, 18451, 3);
INSERT INTO 'dancesstepsmap' VALUES (27549, 19993, 1);
INSERT INTO 'dancesstepsmap' VALUES (27550, 19993, 2);
INSERT INTO 'dancesstepsmap' VALUES (27551, 6460, 2);
INSERT INTO 'dancesstepsmap' VALUES (27552, 1438, 5);
INSERT INTO 'dancesstepsmap' VALUES (27553, 1581, 2);
INSERT INTO 'dancesstepsmap' VALUES (27554, 2002, 2);
INSERT INTO 'dancesstepsmap' VALUES (27555, 20009, 2);
INSERT INTO 'dancesstepsmap' VALUES (27556, 20009, 1);
INSERT INTO 'dancesstepsmap' VALUES (27557, 20010, 4);
INSERT INTO 'dancesstepsmap' VALUES (27559, 10255, 1);
INSERT INTO 'dancesstepsmap' VALUES (27560, 10656, 2);
INSERT INTO 'dancesstepsmap' VALUES (27561, 10656, 1);
INSERT INTO 'dancesstepsmap' VALUES (27562, 20011, 4);
INSERT INTO 'dancesstepsmap' VALUES (27563, 20011, 5);
INSERT INTO 'dancesstepsmap' VALUES (27564, 13782, 2);
INSERT INTO 'dancesstepsmap' VALUES (27565, 20012, 2);
INSERT INTO 'dancesstepsmap' VALUES (27566, 20012, 1);
INSERT INTO 'dancesstepsmap' VALUES (27567, 20013, 2);
INSERT INTO 'dancesstepsmap' VALUES (27568, 20013, 1);
INSERT INTO 'dancesstepsmap' VALUES (27569, 20014, 5);
INSERT INTO 'dancesstepsmap' VALUES (27570, 20014, 4);
INSERT INTO 'dancesstepsmap' VALUES (27571, 20015, 1);
INSERT INTO 'dancesstepsmap' VALUES (27572, 20016, 2);
INSERT INTO 'dancesstepsmap' VALUES (27573, 20016, 1);
INSERT INTO 'dancesstepsmap' VALUES (27574, 20017, 1);
INSERT INTO 'dancesstepsmap' VALUES (27575, 20018, 5);
INSERT INTO 'dancesstepsmap' VALUES (27576, 20018, 4);
INSERT INTO 'dancesstepsmap' VALUES (27577, 20019, 5);
INSERT INTO 'dancesstepsmap' VALUES (27578, 20019, 4);
INSERT INTO 'dancesstepsmap' VALUES (27579, 20020, 5);
INSERT INTO 'dancesstepsmap' VALUES (27580, 20020, 4);
INSERT INTO 'dancesstepsmap' VALUES (27581, 20021, 2);
INSERT INTO 'dancesstepsmap' VALUES (27582, 20021, 1);
INSERT INTO 'dancesstepsmap' VALUES (27583, 20021, 3);
INSERT INTO 'dancesstepsmap' VALUES (27584, 20022, 2);
INSERT INTO 'dancesstepsmap' VALUES (27585, 20022, 1);
INSERT INTO 'dancesstepsmap' VALUES (27586, 20022, 3);
INSERT INTO 'dancesstepsmap' VALUES (27587, 20023, 2);
INSERT INTO 'dancesstepsmap' VALUES (27588, 20023, 1);
INSERT INTO 'dancesstepsmap' VALUES (27589, 20024, 2);
INSERT INTO 'dancesstepsmap' VALUES (27590, 20024, 1);
INSERT INTO 'dancesstepsmap' VALUES (27591, 20025, 2);
INSERT INTO 'dancesstepsmap' VALUES (27592, 20025, 1);
INSERT INTO 'dancesstepsmap' VALUES (27593, 20026, 5);
INSERT INTO 'dancesstepsmap' VALUES (27594, 20026, 4);
INSERT INTO 'dancesstepsmap' VALUES (27595, 1958, 2);
INSERT INTO 'dancesstepsmap' VALUES (27596, 1958, 10);
INSERT INTO 'dancesstepsmap' VALUES (27597, 20027, 1);
INSERT INTO 'dancesstepsmap' VALUES (27598, 20027, 3);
INSERT INTO 'dancesstepsmap' VALUES (27599, 3543, 2);
INSERT INTO 'dancesstepsmap' VALUES (27600, 20028, 4);
INSERT INTO 'dancesstepsmap' VALUES (27601, 20028, 5);
INSERT INTO 'dancesstepsmap' VALUES (27602, 20028, 1);
INSERT INTO 'dancesstepsmap' VALUES (27603, 20028, 2);
INSERT INTO 'dancesstepsmap' VALUES (27604, 20029, 1);
INSERT INTO 'dancesstepsmap' VALUES (27605, 20029, 2);
INSERT INTO 'dancesstepsmap' VALUES (27606, 20030, 4);
INSERT INTO 'dancesstepsmap' VALUES (27607, 20030, 10);
INSERT INTO 'dancesstepsmap' VALUES (27608, 20030, 1);
INSERT INTO 'dancesstepsmap' VALUES (27609, 9753, 2);
INSERT INTO 'dancesstepsmap' VALUES (27610, 2836, 5);
INSERT INTO 'dancesstepsmap' VALUES (27611, 20006, 5);
INSERT INTO 'dancesstepsmap' VALUES (27612, 20006, 4);
INSERT INTO 'dancesstepsmap' VALUES (27613, 6510, 5);
INSERT INTO 'dancesstepsmap' VALUES (27614, 6029, 5);
INSERT INTO 'dancesstepsmap' VALUES (27615, 20031, 1);
INSERT INTO 'dancesstepsmap' VALUES (27616, 20031, 2);
INSERT INTO 'dancesstepsmap' VALUES (27617, 20031, 3);
INSERT INTO 'dancesstepsmap' VALUES (27618, 15668, 1);
INSERT INTO 'dancesstepsmap' VALUES (27619, 15668, 2);
INSERT INTO 'dancesstepsmap' VALUES (27620, 20032, 4);
INSERT INTO 'dancesstepsmap' VALUES (27621, 20032, 5);
INSERT INTO 'dancesstepsmap' VALUES (27622, 20032, 1);
INSERT INTO 'dancesstepsmap' VALUES (27623, 20032, 2);
INSERT INTO 'dancesstepsmap' VALUES (27624, 20033, 4);
INSERT INTO 'dancesstepsmap' VALUES (27625, 20033, 5);
INSERT INTO 'dancesstepsmap' VALUES (27626, 20034, 1);
INSERT INTO 'dancesstepsmap' VALUES (27627, 20034, 3);
INSERT INTO 'dancesstepsmap' VALUES (27628, 13281, 2);
INSERT INTO 'dancesstepsmap' VALUES (27629, 13281, 3);
INSERT INTO 'dancesstepsmap' VALUES (27630, 12792, 2);
INSERT INTO 'dancesstepsmap' VALUES (27631, 19254, 1);
INSERT INTO 'dancesstepsmap' VALUES (27632, 19254, 2);
INSERT INTO 'dancesstepsmap' VALUES (27633, 17105, 1);
INSERT INTO 'dancesstepsmap' VALUES (27634, 12831, 1);
INSERT INTO 'dancesstepsmap' VALUES (27635, 12831, 2);
INSERT INTO 'dancesstepsmap' VALUES (27636, 19826, 1);
INSERT INTO 'dancesstepsmap' VALUES (27637, 19826, 2);
INSERT INTO 'dancesstepsmap' VALUES (27638, 17501, 1);
INSERT INTO 'dancesstepsmap' VALUES (27639, 17307, 1);
INSERT INTO 'dancesstepsmap' VALUES (27640, 17307, 2);
INSERT INTO 'dancesstepsmap' VALUES (27641, 17360, 1);
INSERT INTO 'dancesstepsmap' VALUES (27642, 17360, 2);
INSERT INTO 'dancesstepsmap' VALUES (27643, 17596, 4);
INSERT INTO 'dancesstepsmap' VALUES (27644, 17596, 1);
INSERT INTO 'dancesstepsmap' VALUES (27645, 17596, 2);
INSERT INTO 'dancesstepsmap' VALUES (27646, 17610, 4);
INSERT INTO 'dancesstepsmap' VALUES (27647, 17610, 5);
INSERT INTO 'dancesstepsmap' VALUES (27648, 17609, 1);
INSERT INTO 'dancesstepsmap' VALUES (27649, 17609, 2);
INSERT INTO 'dancesstepsmap' VALUES (27650, 17593, 2);
INSERT INTO 'dancesstepsmap' VALUES (27651, 17593, 1);
INSERT INTO 'dancesstepsmap' VALUES (27652, 17593, 3);
INSERT INTO 'dancesstepsmap' VALUES (27653, 17594, 2);
INSERT INTO 'dancesstepsmap' VALUES (27654, 17594, 1);
INSERT INTO 'dancesstepsmap' VALUES (27655, 20035, 2);
INSERT INTO 'dancesstepsmap' VALUES (27656, 20035, 1);
INSERT INTO 'dancesstepsmap' VALUES (27657, 15646, 4);
INSERT INTO 'dancesstepsmap' VALUES (27658, 15646, 5);
INSERT INTO 'dancesstepsmap' VALUES (27659, 20036, 1);
INSERT INTO 'dancesstepsmap' VALUES (27660, 20036, 2);
INSERT INTO 'dancesstepsmap' VALUES (27661, 20036, 3);
INSERT INTO 'dancesstepsmap' VALUES (27662, 20037, 4);
INSERT INTO 'dancesstepsmap' VALUES (27663, 20037, 5);
INSERT INTO 'dancesstepsmap' VALUES (27664, 20038, 1);
INSERT INTO 'dancesstepsmap' VALUES (27665, 20038, 2);
INSERT INTO 'dancesstepsmap' VALUES (27666, 20039, 4);
INSERT INTO 'dancesstepsmap' VALUES (27667, 20039, 5);
INSERT INTO 'dancesstepsmap' VALUES (27668, 20039, 1);
INSERT INTO 'dancesstepsmap' VALUES (27669, 20039, 2);
INSERT INTO 'dancesstepsmap' VALUES (27670, 20040, 1);
INSERT INTO 'dancesstepsmap' VALUES (27671, 20040, 2);
INSERT INTO 'dancesstepsmap' VALUES (27672, 20040, 3);
INSERT INTO 'dancesstepsmap' VALUES (27673, 3251, 2);
INSERT INTO 'dancesstepsmap' VALUES (27674, 3251, 3);
INSERT INTO 'dancesstepsmap' VALUES (27675, 14640, 2);
INSERT INTO 'dancesstepsmap' VALUES (27676, 20041, 1);
INSERT INTO 'dancesstepsmap' VALUES (27677, 20041, 2);
INSERT INTO 'dancesstepsmap' VALUES (27678, 20042, 1);
INSERT INTO 'dancesstepsmap' VALUES (27679, 20043, 4);
INSERT INTO 'dancesstepsmap' VALUES (27680, 20043, 5);
INSERT INTO 'dancesstepsmap' VALUES (27681, 12522, 2);
INSERT INTO 'dancesstepsmap' VALUES (27682, 20044, 4);
INSERT INTO 'dancesstepsmap' VALUES (27683, 20044, 5);
INSERT INTO 'dancesstepsmap' VALUES (27684, 12630, 5);
INSERT INTO 'dancesstepsmap' VALUES (27685, 12694, 5);
INSERT INTO 'dancesstepsmap' VALUES (27686, 20045, 2);
INSERT INTO 'dancesstepsmap' VALUES (27687, 20045, 1);
INSERT INTO 'dancesstepsmap' VALUES (27690, 20047, 5);
INSERT INTO 'dancesstepsmap' VALUES (27691, 20047, 4);
INSERT INTO 'dancesstepsmap' VALUES (27692, 15675, 4);
INSERT INTO 'dancesstepsmap' VALUES (27693, 15675, 5);
INSERT INTO 'dancesstepsmap' VALUES (27694, 16847, 1);
INSERT INTO 'dancesstepsmap' VALUES (27696, 6523, 5);
INSERT INTO 'dancesstepsmap' VALUES (27697, 5843, 2);
INSERT INTO 'dancesstepsmap' VALUES (27698, 20048, 5);
INSERT INTO 'dancesstepsmap' VALUES (27699, 20048, 4);
INSERT INTO 'dancesstepsmap' VALUES (27700, 12253, 1);
INSERT INTO 'dancesstepsmap' VALUES (27701, 20049, 2);
INSERT INTO 'dancesstepsmap' VALUES (27702, 20049, 1);
INSERT INTO 'dancesstepsmap' VALUES (27703, 17700, 1);
INSERT INTO 'dancesstepsmap' VALUES (27704, 17700, 2);
INSERT INTO 'dancesstepsmap' VALUES (27705, 17700, 3);
INSERT INTO 'dancesstepsmap' VALUES (27706, 14336, 1);
INSERT INTO 'dancesstepsmap' VALUES (27707, 14336, 2);
INSERT INTO 'dancesstepsmap' VALUES (27708, 14336, 3);
INSERT INTO 'dancesstepsmap' VALUES (27709, 20050, 2);
INSERT INTO 'dancesstepsmap' VALUES (27710, 20050, 1);
INSERT INTO 'dancesstepsmap' VALUES (27711, 20051, 1);
INSERT INTO 'dancesstepsmap' VALUES (27712, 20052, 1);
INSERT INTO 'dancesstepsmap' VALUES (27713, 17340, 4);
INSERT INTO 'dancesstepsmap' VALUES (27714, 17340, 5);
INSERT INTO 'dancesstepsmap' VALUES (27715, 20053, 4);
INSERT INTO 'dancesstepsmap' VALUES (27716, 20053, 5);
INSERT INTO 'dancesstepsmap' VALUES (12201, 10924, 1);
INSERT INTO 'dancesstepsmap' VALUES (27717, 20054, 4);
INSERT INTO 'dancesstepsmap' VALUES (27718, 20054, 5);
INSERT INTO 'dancesstepsmap' VALUES (27719, 13122, 4);
INSERT INTO 'dancesstepsmap' VALUES (27720, 13122, 5);
INSERT INTO 'dancesstepsmap' VALUES (27721, 10922, 1);
INSERT INTO 'dancesstepsmap' VALUES (27722, 10922, 2);
INSERT INTO 'dancesstepsmap' VALUES (27723, 11661, 1);
INSERT INTO 'dancesstepsmap' VALUES (27724, 11661, 2);
INSERT INTO 'dancesstepsmap' VALUES (27725, 12545, 1);
INSERT INTO 'dancesstepsmap' VALUES (27726, 12545, 3);
INSERT INTO 'dancesstepsmap' VALUES (27727, 2140, 5);
INSERT INTO 'dancesstepsmap' VALUES (27728, 4767, 2);
INSERT INTO 'dancesstepsmap' VALUES (27729, 20055, 1);
INSERT INTO 'dancesstepsmap' VALUES (27730, 20055, 3);
INSERT INTO 'dancesstepsmap' VALUES (27731, 5279, 5);
INSERT INTO 'dancesstepsmap' VALUES (27732, 5174, 3);
INSERT INTO 'dancesstepsmap' VALUES (27733, 20056, 5);
INSERT INTO 'dancesstepsmap' VALUES (27734, 20056, 4);
INSERT INTO 'dancesstepsmap' VALUES (27735, 4632, 3);
INSERT INTO 'dancesstepsmap' VALUES (27736, 20057, 4);
INSERT INTO 'dancesstepsmap' VALUES (27737, 20057, 5);
INSERT INTO 'dancesstepsmap' VALUES (27738, 20057, 1);
INSERT INTO 'dancesstepsmap' VALUES (27739, 20057, 2);
INSERT INTO 'dancesstepsmap' VALUES (27740, 20057, 3);
INSERT INTO 'dancesstepsmap' VALUES (27741, 19898, 1);
INSERT INTO 'dancesstepsmap' VALUES (27742, 19898, 3);
INSERT INTO 'dancesstepsmap' VALUES (27743, 20058, 1);
INSERT INTO 'dancesstepsmap' VALUES (27744, 20058, 2);
INSERT INTO 'dancesstepsmap' VALUES (27745, 7360, 2);
INSERT INTO 'dancesstepsmap' VALUES (27746, 20059, 1);
INSERT INTO 'dancesstepsmap' VALUES (27747, 20059, 2);
INSERT INTO 'dancesstepsmap' VALUES (27748, 20060, 4);
INSERT INTO 'dancesstepsmap' VALUES (27749, 20060, 5);
INSERT INTO 'dancesstepsmap' VALUES (27750, 20061, 5);
INSERT INTO 'dancesstepsmap' VALUES (27751, 20061, 4);
INSERT INTO 'dancesstepsmap' VALUES (27752, 20062, 2);
INSERT INTO 'dancesstepsmap' VALUES (27753, 20062, 1);
INSERT INTO 'dancesstepsmap' VALUES (27754, 625, 2);
INSERT INTO 'dancesstepsmap' VALUES (27755, 2150, 2);
INSERT INTO 'dancesstepsmap' VALUES (27756, 6826, 3);
INSERT INTO 'dancesstepsmap' VALUES (27757, 7223, 2);
INSERT INTO 'dancesstepsmap' VALUES (27758, 3025, 2);
INSERT INTO 'dancesstepsmap' VALUES (27759, 3025, 3);
INSERT INTO 'dancesstepsmap' VALUES (27760, 1033, 6);
INSERT INTO 'dancesstepsmap' VALUES (27761, 1033, 99);
INSERT INTO 'dancesstepsmap' VALUES (27762, 12823, 1);
INSERT INTO 'dancesstepsmap' VALUES (27763, 12823, 2);
INSERT INTO 'dancesstepsmap' VALUES (27764, 12823, 3);
INSERT INTO 'dancesstepsmap' VALUES (27765, 2069, 5);
INSERT INTO 'dancesstepsmap' VALUES (27766, 18573, 1);
INSERT INTO 'dancesstepsmap' VALUES (27767, 18573, 2);
INSERT INTO 'dancesstepsmap' VALUES (27768, 467, 3);
INSERT INTO 'dancesstepsmap' VALUES (27769, 6367, 3);
INSERT INTO 'dancesstepsmap' VALUES (27770, 4835, 3);
INSERT INTO 'dancesstepsmap' VALUES (27771, 20065, 1);
INSERT INTO 'dancesstepsmap' VALUES (27772, 5310, 2);
INSERT INTO 'dancesstepsmap' VALUES (27773, 19897, 1);
INSERT INTO 'dancesstepsmap' VALUES (27774, 19897, 2);
INSERT INTO 'dancesstepsmap' VALUES (27775, 19897, 103);
INSERT INTO 'dancesstepsmap' VALUES (27776, 114, 3);
INSERT INTO 'dancesstepsmap' VALUES (27777, 484, 2);
INSERT INTO 'dancesstepsmap' VALUES (27778, 1892, 2);
INSERT INTO 'dancesstepsmap' VALUES (27779, 2227, 5);
INSERT INTO 'dancesstepsmap' VALUES (27780, 2345, 5);
INSERT INTO 'dancesstepsmap' VALUES (27781, 17586, 4);
INSERT INTO 'dancesstepsmap' VALUES (27782, 17602, 1);
INSERT INTO 'dancesstepsmap' VALUES (27783, 17602, 3);
INSERT INTO 'dancesstepsmap' VALUES (27784, 19977, 4);
INSERT INTO 'dancesstepsmap' VALUES (27785, 18416, 1);
INSERT INTO 'dancesstepsmap' VALUES (27786, 18416, 2);
INSERT INTO 'dancesstepsmap' VALUES (27787, 18416, 3);
INSERT INTO 'dancesstepsmap' VALUES (27788, 17608, 1);
INSERT INTO 'dancesstepsmap' VALUES (27789, 17605, 1);
INSERT INTO 'dancesstepsmap' VALUES (27790, 17605, 3);
INSERT INTO 'dancesstepsmap' VALUES (27791, 17605, 2);
INSERT INTO 'dancesstepsmap' VALUES (27792, 17604, 4);
INSERT INTO 'dancesstepsmap' VALUES (27793, 17604, 5);
INSERT INTO 'dancesstepsmap' VALUES (27794, 17597, 4);
INSERT INTO 'dancesstepsmap' VALUES (27795, 17597, 5);
INSERT INTO 'dancesstepsmap' VALUES (27796, 17592, 5);
INSERT INTO 'dancesstepsmap' VALUES (27797, 17592, 4);
INSERT INTO 'dancesstepsmap' VALUES (27798, 17591, 1);
INSERT INTO 'dancesstepsmap' VALUES (27799, 17591, 3);
INSERT INTO 'dancesstepsmap' VALUES (27800, 17591, 2);
INSERT INTO 'dancesstepsmap' VALUES (27801, 17589, 1);
INSERT INTO 'dancesstepsmap' VALUES (27802, 17589, 102);
INSERT INTO 'dancesstepsmap' VALUES (27803, 17589, 3);
INSERT INTO 'dancesstepsmap' VALUES (27804, 17588, 4);
INSERT INTO 'dancesstepsmap' VALUES (27805, 17588, 5);
INSERT INTO 'dancesstepsmap' VALUES (27806, 17588, 1);
INSERT INTO 'dancesstepsmap' VALUES (27807, 17588, 2);
INSERT INTO 'dancesstepsmap' VALUES (27808, 17585, 5);
INSERT INTO 'dancesstepsmap' VALUES (27809, 17585, 4);
INSERT INTO 'dancesstepsmap' VALUES (27810, 17584, 2);
INSERT INTO 'dancesstepsmap' VALUES (27811, 17584, 1);
INSERT INTO 'dancesstepsmap' VALUES (27812, 17584, 3);
INSERT INTO 'dancesstepsmap' VALUES (27813, 2463, 5);
INSERT INTO 'dancesstepsmap' VALUES (27814, 2463, 4);
INSERT INTO 'dancesstepsmap' VALUES (27815, 2463, 2);
INSERT INTO 'dancesstepsmap' VALUES (27816, 2463, 1);
INSERT INTO 'dancesstepsmap' VALUES (27817, 4696, 2);
INSERT INTO 'dancesstepsmap' VALUES (27818, 3794, 2);
INSERT INTO 'dancesstepsmap' VALUES (27819, 1080, 2);
INSERT INTO 'dancesstepsmap' VALUES (27820, 4241, 5);
INSERT INTO 'dancesstepsmap' VALUES (27821, 20069, 5);
INSERT INTO 'dancesstepsmap' VALUES (27822, 20069, 4);
INSERT INTO 'dancesstepsmap' VALUES (27823, 2901, 2);
INSERT INTO 'dancesstepsmap' VALUES (27824, 352, 2);
INSERT INTO 'dancesstepsmap' VALUES (27825, 2901, 3);
INSERT INTO 'dancesstepsmap' VALUES (27826, 6373, 5);
INSERT INTO 'dancesstepsmap' VALUES (27827, 20070, 2);
INSERT INTO 'dancesstepsmap' VALUES (27828, 20070, 1);
INSERT INTO 'dancesstepsmap' VALUES (27829, 20070, 3);
INSERT INTO 'dancesstepsmap' VALUES (27830, 20071, 4);
INSERT INTO 'dancesstepsmap' VALUES (27831, 17310, 2);
INSERT INTO 'dancesstepsmap' VALUES (27832, 17310, 1);
INSERT INTO 'dancesstepsmap' VALUES (27833, 17327, 2);
INSERT INTO 'dancesstepsmap' VALUES (27834, 17327, 1);
INSERT INTO 'dancesstepsmap' VALUES (27835, 17327, 3);
INSERT INTO 'dancesstepsmap' VALUES (27836, 14510, 1);
INSERT INTO 'dancesstepsmap' VALUES (27837, 9462, 5);
INSERT INTO 'dancesstepsmap' VALUES (27838, 9462, 4);
INSERT INTO 'dancesstepsmap' VALUES (27839, 14820, 5);
INSERT INTO 'dancesstepsmap' VALUES (27840, 14820, 4);
INSERT INTO 'dancesstepsmap' VALUES (27841, 17230, 5);
INSERT INTO 'dancesstepsmap' VALUES (27842, 17230, 4);
INSERT INTO 'dancesstepsmap' VALUES (27843, 17141, 2);
INSERT INTO 'dancesstepsmap' VALUES (27844, 17141, 1);
INSERT INTO 'dancesstepsmap' VALUES (27845, 16837, 1);
INSERT INTO 'dancesstepsmap' VALUES (27846, 16837, 2);
INSERT INTO 'dancesstepsmap' VALUES (27847, 16837, 3);
INSERT INTO 'dancesstepsmap' VALUES (27848, 15645, 1);
INSERT INTO 'dancesstepsmap' VALUES (27849, 15645, 2);
INSERT INTO 'dancesstepsmap' VALUES (27850, 15603, 2);
INSERT INTO 'dancesstepsmap' VALUES (27851, 15603, 1);
INSERT INTO 'dancesstepsmap' VALUES (27852, 14413, 1);
INSERT INTO 'dancesstepsmap' VALUES (27853, 14413, 2);
INSERT INTO 'dancesstepsmap' VALUES (27854, 18963, 5);
INSERT INTO 'dancesstepsmap' VALUES (27855, 18963, 4);
INSERT INTO 'dancesstepsmap' VALUES (27856, 8498, 2);
INSERT INTO 'dancesstepsmap' VALUES (27857, 8498, 3);
INSERT INTO 'dancesstepsmap' VALUES (27858, 294, 2);
INSERT INTO 'dancesstepsmap' VALUES (27859, 20072, 2);
INSERT INTO 'dancesstepsmap' VALUES (27860, 20072, 1);
INSERT INTO 'dancesstepsmap' VALUES (27861, 20073, 5);
INSERT INTO 'dancesstepsmap' VALUES (27862, 20073, 4);
INSERT INTO 'dancesstepsmap' VALUES (27865, 20075, 1);
INSERT INTO 'dancesstepsmap' VALUES (27866, 20075, 2);
INSERT INTO 'dancesstepsmap' VALUES (27867, 20075, 3);
INSERT INTO 'dancesstepsmap' VALUES (27868, 18965, 1);
INSERT INTO 'dancesstepsmap' VALUES (27869, 19426, 5);
INSERT INTO 'dancesstepsmap' VALUES (27870, 19426, 4);
INSERT INTO 'dancesstepsmap' VALUES (27871, 19426, 2);
INSERT INTO 'dancesstepsmap' VALUES (27872, 19426, 1);
INSERT INTO 'dancesstepsmap' VALUES (27873, 19426, 3);
INSERT INTO 'dancesstepsmap' VALUES (27874, 19612, 2);
INSERT INTO 'dancesstepsmap' VALUES (27875, 19612, 1);
INSERT INTO 'dancesstepsmap' VALUES (27876, 19141, 2);
INSERT INTO 'dancesstepsmap' VALUES (27877, 19141, 1);
INSERT INTO 'dancesstepsmap' VALUES (27878, 19244, 4);
INSERT INTO 'dancesstepsmap' VALUES (27879, 13500, 2);
INSERT INTO 'dancesstepsmap' VALUES (27880, 13500, 1);
INSERT INTO 'dancesstepsmap' VALUES (27881, 20076, 1);
INSERT INTO 'dancesstepsmap' VALUES (27882, 20076, 3);
INSERT INTO 'dancesstepsmap' VALUES (27883, 20077, 1);
INSERT INTO 'dancesstepsmap' VALUES (27884, 20077, 2);
INSERT INTO 'dancesstepsmap' VALUES (27885, 20078, 5);
INSERT INTO 'dancesstepsmap' VALUES (27886, 20078, 4);
INSERT INTO 'dancesstepsmap' VALUES (27887, 177, 2);
INSERT INTO 'dancesstepsmap' VALUES (27888, 186, 5);
INSERT INTO 'dancesstepsmap' VALUES (27889, 249, 3);
INSERT INTO 'dancesstepsmap' VALUES (27890, 249, 2);
INSERT INTO 'dancesstepsmap' VALUES (27891, 366, 5);
INSERT INTO 'dancesstepsmap' VALUES (27892, 452, 2);
INSERT INTO 'dancesstepsmap' VALUES (27893, 510, 2);
INSERT INTO 'dancesstepsmap' VALUES (27894, 510, 3);
INSERT INTO 'dancesstepsmap' VALUES (27895, 875, 2);
INSERT INTO 'dancesstepsmap' VALUES (27897, 1032, 2);
INSERT INTO 'dancesstepsmap' VALUES (27898, 1143, 3);
INSERT INTO 'dancesstepsmap' VALUES (27899, 1160, 5);
INSERT INTO 'dancesstepsmap' VALUES (27900, 1183, 3);
INSERT INTO 'dancesstepsmap' VALUES (27901, 1193, 5);
INSERT INTO 'dancesstepsmap' VALUES (27902, 9216, 2);
INSERT INTO 'dancesstepsmap' VALUES (27903, 9216, 1);
INSERT INTO 'dancesstepsmap' VALUES (27904, 9216, 3);
INSERT INTO 'dancesstepsmap' VALUES (27905, 1245, 2);
INSERT INTO 'dancesstepsmap' VALUES (27906, 1245, 3);
INSERT INTO 'dancesstepsmap' VALUES (27907, 1352, 2);
INSERT INTO 'dancesstepsmap' VALUES (27908, 1356, 2);
INSERT INTO 'dancesstepsmap' VALUES (27909, 1676, 2);
INSERT INTO 'dancesstepsmap' VALUES (27910, 1853, 2);
INSERT INTO 'dancesstepsmap' VALUES (27911, 1853, 3);
INSERT INTO 'dancesstepsmap' VALUES (27912, 1963, 5);
INSERT INTO 'dancesstepsmap' VALUES (27913, 1972, 2);
INSERT INTO 'dancesstepsmap' VALUES (27914, 1972, 3);
INSERT INTO 'dancesstepsmap' VALUES (27915, 1977, 2);
INSERT INTO 'dancesstepsmap' VALUES (27916, 1977, 3);
INSERT INTO 'dancesstepsmap' VALUES (27917, 2100, 5);
INSERT INTO 'dancesstepsmap' VALUES (27918, 2170, 1);
INSERT INTO 'dancesstepsmap' VALUES (27919, 2170, 2);
INSERT INTO 'dancesstepsmap' VALUES (27920, 2170, 3);
INSERT INTO 'dancesstepsmap' VALUES (27921, 2170, 5);
INSERT INTO 'dancesstepsmap' VALUES (27922, 2170, 4);
INSERT INTO 'dancesstepsmap' VALUES (27923, 2348, 2);
INSERT INTO 'dancesstepsmap' VALUES (27924, 2450, 2);
INSERT INTO 'dancesstepsmap' VALUES (27925, 2450, 3);
INSERT INTO 'dancesstepsmap' VALUES (27926, 2660, 5);
INSERT INTO 'dancesstepsmap' VALUES (27927, 20079, 1);
INSERT INTO 'dancesstepsmap' VALUES (27928, 20079, 2);
INSERT INTO 'dancesstepsmap' VALUES (27929, 20079, 3);
INSERT INTO 'dancesstepsmap' VALUES (27930, 20079, 10);
INSERT INTO 'dancesstepsmap' VALUES (27931, 2965, 2);
INSERT INTO 'dancesstepsmap' VALUES (27932, 2965, 3);
INSERT INTO 'dancesstepsmap' VALUES (27933, 3115, 2);
INSERT INTO 'dancesstepsmap' VALUES (27934, 3253, 2);
INSERT INTO 'dancesstepsmap' VALUES (27935, 3253, 3);
INSERT INTO 'dancesstepsmap' VALUES (27936, 13367, 2);
INSERT INTO 'dancesstepsmap' VALUES (27937, 13367, 1);
INSERT INTO 'dancesstepsmap' VALUES (27938, 13383, 1);
INSERT INTO 'dancesstepsmap' VALUES (27939, 13383, 3);
INSERT INTO 'dancesstepsmap' VALUES (27940, 3667, 2);
INSERT INTO 'dancesstepsmap' VALUES (27941, 3785, 2);
INSERT INTO 'dancesstepsmap' VALUES (27942, 3785, 3);
INSERT INTO 'dancesstepsmap' VALUES (27943, 3797, 5);
INSERT INTO 'dancesstepsmap' VALUES (27944, 3812, 5);
INSERT INTO 'dancesstepsmap' VALUES (27945, 3898, 1);
INSERT INTO 'dancesstepsmap' VALUES (27946, 3898, 2);
INSERT INTO 'dancesstepsmap' VALUES (27947, 3925, 2);
INSERT INTO 'dancesstepsmap' VALUES (27948, 3937, 3);
INSERT INTO 'dancesstepsmap' VALUES (27949, 3997, 5);
INSERT INTO 'dancesstepsmap' VALUES (27950, 13863, 4);
INSERT INTO 'dancesstepsmap' VALUES (27951, 13863, 5);
INSERT INTO 'dancesstepsmap' VALUES (27952, 14675, 1);
INSERT INTO 'dancesstepsmap' VALUES (27953, 14675, 3);
INSERT INTO 'dancesstepsmap' VALUES (27954, 15310, 1);
INSERT INTO 'dancesstepsmap' VALUES (27955, 15310, 2);
INSERT INTO 'dancesstepsmap' VALUES (27956, 15310, 3);
INSERT INTO 'dancesstepsmap' VALUES (27957, 15311, 1);
INSERT INTO 'dancesstepsmap' VALUES (27958, 15311, 3);
INSERT INTO 'dancesstepsmap' VALUES (27959, 9699, 1);
INSERT INTO 'dancesstepsmap' VALUES (27960, 9699, 2);
INSERT INTO 'dancesstepsmap' VALUES (27961, 9699, 3);
INSERT INTO 'dancesstepsmap' VALUES (27962, 9699, 10);
INSERT INTO 'dancesstepsmap' VALUES (27963, 3510, 3);
INSERT INTO 'dancesstepsmap' VALUES (27964, 20080, 4);
INSERT INTO 'dancesstepsmap' VALUES (27965, 14578, 1);
INSERT INTO 'dancesstepsmap' VALUES (27966, 14578, 2);
INSERT INTO 'dancesstepsmap' VALUES (27967, 4017, 2);
INSERT INTO 'dancesstepsmap' VALUES (27968, 4082, 5);
INSERT INTO 'dancesstepsmap' VALUES (27969, 4193, 5);
INSERT INTO 'dancesstepsmap' VALUES (27970, 4204, 2);
INSERT INTO 'dancesstepsmap' VALUES (27971, 4417, 2);
INSERT INTO 'dancesstepsmap' VALUES (27972, 4417, 3);
INSERT INTO 'dancesstepsmap' VALUES (27973, 4473, 3);
INSERT INTO 'dancesstepsmap' VALUES (27974, 4559, 10);
INSERT INTO 'dancesstepsmap' VALUES (27975, 4571, 3);
INSERT INTO 'dancesstepsmap' VALUES (27976, 4840, 3);
INSERT INTO 'dancesstepsmap' VALUES (27977, 4878, 2);
INSERT INTO 'dancesstepsmap' VALUES (27978, 4947, 2);
INSERT INTO 'dancesstepsmap' VALUES (27979, 4983, 5);
INSERT INTO 'dancesstepsmap' VALUES (27980, 7637, 6);
INSERT INTO 'dancesstepsmap' VALUES (27981, 19137, 1);
INSERT INTO 'dancesstepsmap' VALUES (27982, 19137, 2);
INSERT INTO 'dancesstepsmap' VALUES (27983, 19137, 3);
INSERT INTO 'dancesstepsmap' VALUES (27984, 18574, 1);
INSERT INTO 'dancesstepsmap' VALUES (27985, 17732, 2);
INSERT INTO 'dancesstepsmap' VALUES (27986, 17732, 1);
INSERT INTO 'dancesstepsmap' VALUES (27987, 17732, 3);
INSERT INTO 'dancesstepsmap' VALUES (27988, 17223, 1);
INSERT INTO 'dancesstepsmap' VALUES (27989, 17223, 2);
INSERT INTO 'dancesstepsmap' VALUES (27990, 5098, 2);
INSERT INTO 'dancesstepsmap' VALUES (27991, 5098, 3);
INSERT INTO 'dancesstepsmap' VALUES (27992, 5181, 2);
INSERT INTO 'dancesstepsmap' VALUES (27993, 5191, 2);
INSERT INTO 'dancesstepsmap' VALUES (27994, 5224, 5);
INSERT INTO 'dancesstepsmap' VALUES (27995, 5264, 2);
INSERT INTO 'dancesstepsmap' VALUES (27996, 5302, 2);
INSERT INTO 'dancesstepsmap' VALUES (27997, 5390, 2);
INSERT INTO 'dancesstepsmap' VALUES (27998, 5448, 2);
INSERT INTO 'dancesstepsmap' VALUES (27999, 5516, 2);
INSERT INTO 'dancesstepsmap' VALUES (28000, 5516, 3);
INSERT INTO 'dancesstepsmap' VALUES (28001, 5818, 5);
INSERT INTO 'dancesstepsmap' VALUES (28002, 5902, 2);
INSERT INTO 'dancesstepsmap' VALUES (28003, 6066, 5);
INSERT INTO 'dancesstepsmap' VALUES (28004, 6085, 5);
INSERT INTO 'dancesstepsmap' VALUES (28005, 6085, 6);
INSERT INTO 'dancesstepsmap' VALUES (28006, 6101, 2);
INSERT INTO 'dancesstepsmap' VALUES (28007, 6217, 2);
INSERT INTO 'dancesstepsmap' VALUES (28008, 6249, 2);
INSERT INTO 'dancesstepsmap' VALUES (28009, 6306, 5);
INSERT INTO 'dancesstepsmap' VALUES (28010, 6318, 2);
INSERT INTO 'dancesstepsmap' VALUES (28011, 6354, 5);
INSERT INTO 'dancesstepsmap' VALUES (28012, 6540, 2);
INSERT INTO 'dancesstepsmap' VALUES (28013, 6656, 5);
INSERT INTO 'dancesstepsmap' VALUES (28014, 6713, 3);
INSERT INTO 'dancesstepsmap' VALUES (28015, 6713, 2);
INSERT INTO 'dancesstepsmap' VALUES (28016, 6785, 5);
INSERT INTO 'dancesstepsmap' VALUES (28017, 6785, 6);
INSERT INTO 'dancesstepsmap' VALUES (28018, 6933, 5);
INSERT INTO 'dancesstepsmap' VALUES (28019, 6939, 2);
INSERT INTO 'dancesstepsmap' VALUES (28020, 6991, 2);
INSERT INTO 'dancesstepsmap' VALUES (28021, 6991, 3);
INSERT INTO 'dancesstepsmap' VALUES (28022, 7036, 2);
INSERT INTO 'dancesstepsmap' VALUES (28023, 20081, 2);
INSERT INTO 'dancesstepsmap' VALUES (28024, 20081, 1);
INSERT INTO 'dancesstepsmap' VALUES (28025, 7273, 2);
INSERT INTO 'dancesstepsmap' VALUES (28026, 7474, 5);
INSERT INTO 'dancesstepsmap' VALUES (28027, 7487, 2);
INSERT INTO 'dancesstepsmap' VALUES (28028, 7656, 3);
INSERT INTO 'dancesstepsmap' VALUES (28029, 7656, 2);
INSERT INTO 'dancesstepsmap' VALUES (28030, 7687, 2);
INSERT INTO 'dancesstepsmap' VALUES (28031, 7714, 2);
INSERT INTO 'dancesstepsmap' VALUES (28032, 7873, 2);
INSERT INTO 'dancesstepsmap' VALUES (28033, 7928, 2);
INSERT INTO 'dancesstepsmap' VALUES (28034, 7950, 4);
INSERT INTO 'dancesstepsmap' VALUES (28035, 7950, 5);
INSERT INTO 'dancesstepsmap' VALUES (28036, 7950, 1);
INSERT INTO 'dancesstepsmap' VALUES (28037, 7994, 2);
INSERT INTO 'dancesstepsmap' VALUES (28038, 7994, 3);
INSERT INTO 'dancesstepsmap' VALUES (28039, 8037, 2);
INSERT INTO 'dancesstepsmap' VALUES (28040, 8118, 5);
INSERT INTO 'dancesstepsmap' VALUES (28041, 8123, 2);
INSERT INTO 'dancesstepsmap' VALUES (28042, 8127, 2);
INSERT INTO 'dancesstepsmap' VALUES (28043, 8129, 2);
INSERT INTO 'dancesstepsmap' VALUES (28044, 8131, 5);
INSERT INTO 'dancesstepsmap' VALUES (28045, 8247, 2);
INSERT INTO 'dancesstepsmap' VALUES (28046, 8247, 3);
INSERT INTO 'dancesstepsmap' VALUES (28047, 8330, 5);
INSERT INTO 'dancesstepsmap' VALUES (28048, 8339, 2);
INSERT INTO 'dancesstepsmap' VALUES (28049, 8363, 2);
INSERT INTO 'dancesstepsmap' VALUES (28050, 8363, 3);
INSERT INTO 'dancesstepsmap' VALUES (28051, 8494, 2);
INSERT INTO 'dancesstepsmap' VALUES (28052, 8496, 2);
INSERT INTO 'dancesstepsmap' VALUES (28053, 8573, 2);
INSERT INTO 'dancesstepsmap' VALUES (28054, 8573, 3);
INSERT INTO 'dancesstepsmap' VALUES (28055, 8688, 4);
INSERT INTO 'dancesstepsmap' VALUES (28056, 8688, 1);
INSERT INTO 'dancesstepsmap' VALUES (28057, 8688, 3);
INSERT INTO 'dancesstepsmap' VALUES (28058, 8688, 2);
INSERT INTO 'dancesstepsmap' VALUES (28059, 8850, 1);
INSERT INTO 'dancesstepsmap' VALUES (28060, 8850, 2);
INSERT INTO 'dancesstepsmap' VALUES (28061, 8924, 2);
INSERT INTO 'dancesstepsmap' VALUES (28062, 8924, 1);
INSERT INTO 'dancesstepsmap' VALUES (28063, 8924, 3);
INSERT INTO 'dancesstepsmap' VALUES (28064, 8926, 5);
INSERT INTO 'dancesstepsmap' VALUES (28065, 8926, 4);
INSERT INTO 'dancesstepsmap' VALUES (28066, 8931, 2);
INSERT INTO 'dancesstepsmap' VALUES (28067, 8931, 1);
INSERT INTO 'dancesstepsmap' VALUES (28068, 8936, 2);
INSERT INTO 'dancesstepsmap' VALUES (28069, 8936, 1);
INSERT INTO 'dancesstepsmap' VALUES (28070, 8938, 2);
INSERT INTO 'dancesstepsmap' VALUES (28071, 8938, 1);
INSERT INTO 'dancesstepsmap' VALUES (28072, 8940, 2);
INSERT INTO 'dancesstepsmap' VALUES (28073, 8940, 1);
INSERT INTO 'dancesstepsmap' VALUES (28074, 8955, 2);
INSERT INTO 'dancesstepsmap' VALUES (28075, 8955, 1);
INSERT INTO 'dancesstepsmap' VALUES (28076, 12839, 5);
INSERT INTO 'dancesstepsmap' VALUES (28077, 9, 2);
INSERT INTO 'dancesstepsmap' VALUES (28078, 9, 3);
INSERT INTO 'dancesstepsmap' VALUES (28079, 89, 5);
INSERT INTO 'dancesstepsmap' VALUES (28080, 92, 2);
INSERT INTO 'dancesstepsmap' VALUES (28081, 9012, 1);
INSERT INTO 'dancesstepsmap' VALUES (28082, 9012, 2);
INSERT INTO 'dancesstepsmap' VALUES (28083, 9016, 2);
INSERT INTO 'dancesstepsmap' VALUES (28084, 9016, 1);
INSERT INTO 'dancesstepsmap' VALUES (28085, 9023, 1);
INSERT INTO 'dancesstepsmap' VALUES (28086, 9023, 2);
INSERT INTO 'dancesstepsmap' VALUES (28087, 9024, 2);
INSERT INTO 'dancesstepsmap' VALUES (28088, 9024, 1);
INSERT INTO 'dancesstepsmap' VALUES (28089, 9069, 4);
INSERT INTO 'dancesstepsmap' VALUES (28090, 9069, 5);
INSERT INTO 'dancesstepsmap' VALUES (28091, 9071, 2);
INSERT INTO 'dancesstepsmap' VALUES (28092, 9071, 1);
INSERT INTO 'dancesstepsmap' VALUES (28093, 9141, 1);
INSERT INTO 'dancesstepsmap' VALUES (28094, 9141, 3);
INSERT INTO 'dancesstepsmap' VALUES (28095, 9141, 2);
INSERT INTO 'dancesstepsmap' VALUES (28096, 9190, 5);
INSERT INTO 'dancesstepsmap' VALUES (28097, 9190, 4);
INSERT INTO 'dancesstepsmap' VALUES (28098, 9203, 2);
INSERT INTO 'dancesstepsmap' VALUES (28099, 9203, 1);
INSERT INTO 'dancesstepsmap' VALUES (28100, 9217, 2);
INSERT INTO 'dancesstepsmap' VALUES (28101, 9217, 1);
INSERT INTO 'dancesstepsmap' VALUES (28102, 9221, 4);
INSERT INTO 'dancesstepsmap' VALUES (28103, 9221, 5);
INSERT INTO 'dancesstepsmap' VALUES (28104, 9229, 2);
INSERT INTO 'dancesstepsmap' VALUES (28105, 9229, 1);
INSERT INTO 'dancesstepsmap' VALUES (28106, 9229, 3);
INSERT INTO 'dancesstepsmap' VALUES (28107, 9240, 5);
INSERT INTO 'dancesstepsmap' VALUES (28108, 9240, 4);
INSERT INTO 'dancesstepsmap' VALUES (28109, 9290, 5);
INSERT INTO 'dancesstepsmap' VALUES (28110, 9290, 4);
INSERT INTO 'dancesstepsmap' VALUES (28111, 9294, 2);
INSERT INTO 'dancesstepsmap' VALUES (28112, 9294, 1);
INSERT INTO 'dancesstepsmap' VALUES (28113, 9294, 3);
INSERT INTO 'dancesstepsmap' VALUES (28114, 9297, 5);
INSERT INTO 'dancesstepsmap' VALUES (28115, 9297, 4);
INSERT INTO 'dancesstepsmap' VALUES (28116, 9458, 1);
INSERT INTO 'dancesstepsmap' VALUES (28117, 9458, 2);
INSERT INTO 'dancesstepsmap' VALUES (28118, 9460, 5);
INSERT INTO 'dancesstepsmap' VALUES (28119, 9460, 4);
INSERT INTO 'dancesstepsmap' VALUES (28120, 9461, 2);
INSERT INTO 'dancesstepsmap' VALUES (28121, 9461, 1);
INSERT INTO 'dancesstepsmap' VALUES (28122, 9472, 5);
INSERT INTO 'dancesstepsmap' VALUES (28123, 9472, 4);
INSERT INTO 'dancesstepsmap' VALUES (28124, 9515, 2);
INSERT INTO 'dancesstepsmap' VALUES (28125, 9515, 1);
INSERT INTO 'dancesstepsmap' VALUES (28126, 9535, 2);
INSERT INTO 'dancesstepsmap' VALUES (28127, 9535, 1);
INSERT INTO 'dancesstepsmap' VALUES (28128, 9637, 5);
INSERT INTO 'dancesstepsmap' VALUES (28129, 9637, 4);
INSERT INTO 'dancesstepsmap' VALUES (28130, 9639, 1);
INSERT INTO 'dancesstepsmap' VALUES (28131, 9639, 2);
INSERT INTO 'dancesstepsmap' VALUES (28132, 9642, 1);
INSERT INTO 'dancesstepsmap' VALUES (28133, 9642, 2);
INSERT INTO 'dancesstepsmap' VALUES (28134, 9642, 3);
INSERT INTO 'dancesstepsmap' VALUES (28135, 9643, 5);
INSERT INTO 'dancesstepsmap' VALUES (28136, 9643, 4);
INSERT INTO 'dancesstepsmap' VALUES (28137, 9649, 1);
INSERT INTO 'dancesstepsmap' VALUES (28138, 9649, 2);
INSERT INTO 'dancesstepsmap' VALUES (28139, 9650, 2);
INSERT INTO 'dancesstepsmap' VALUES (28140, 9650, 3);
INSERT INTO 'dancesstepsmap' VALUES (28141, 9650, 1);
INSERT INTO 'dancesstepsmap' VALUES (28142, 9651, 4);
INSERT INTO 'dancesstepsmap' VALUES (28143, 9651, 5);
INSERT INTO 'dancesstepsmap' VALUES (28144, 9652, 3);
INSERT INTO 'dancesstepsmap' VALUES (28145, 9652, 2);
INSERT INTO 'dancesstepsmap' VALUES (28146, 9652, 1);
INSERT INTO 'dancesstepsmap' VALUES (28147, 9657, 2);
INSERT INTO 'dancesstepsmap' VALUES (28148, 9657, 1);
INSERT INTO 'dancesstepsmap' VALUES (28149, 9657, 3);
INSERT INTO 'dancesstepsmap' VALUES (28150, 9659, 4);
INSERT INTO 'dancesstepsmap' VALUES (28151, 9659, 5);
INSERT INTO 'dancesstepsmap' VALUES (28152, 9659, 6);
INSERT INTO 'dancesstepsmap' VALUES (28153, 9659, 2);
INSERT INTO 'dancesstepsmap' VALUES (28154, 9659, 1);
INSERT INTO 'dancesstepsmap' VALUES (28155, 9659, 102);
INSERT INTO 'dancesstepsmap' VALUES (28156, 9659, 3);
INSERT INTO 'dancesstepsmap' VALUES (28157, 9660, 1);
INSERT INTO 'dancesstepsmap' VALUES (28158, 9660, 2);
INSERT INTO 'dancesstepsmap' VALUES (28159, 9680, 2);
INSERT INTO 'dancesstepsmap' VALUES (28160, 9680, 3);
INSERT INTO 'dancesstepsmap' VALUES (28161, 9653, 4);
INSERT INTO 'dancesstepsmap' VALUES (28162, 9654, 1);
INSERT INTO 'dancesstepsmap' VALUES (28163, 9655, 4);
INSERT INTO 'dancesstepsmap' VALUES (28164, 9655, 5);
INSERT INTO 'dancesstepsmap' VALUES (28165, 9656, 1);
INSERT INTO 'dancesstepsmap' VALUES (28166, 9656, 2);
INSERT INTO 'dancesstepsmap' VALUES (28167, 9936, 1);
INSERT INTO 'dancesstepsmap' VALUES (28168, 9936, 2);
INSERT INTO 'dancesstepsmap' VALUES (28169, 9943, 5);
INSERT INTO 'dancesstepsmap' VALUES (28170, 9943, 4);
INSERT INTO 'dancesstepsmap' VALUES (28171, 3649, 5);
INSERT INTO 'dancesstepsmap' VALUES (28172, 3649, 4);
INSERT INTO 'dancesstepsmap' VALUES (28173, 3649, 2);
INSERT INTO 'dancesstepsmap' VALUES (28174, 3649, 1);
INSERT INTO 'dancesstepsmap' VALUES (28175, 5812, 2);
INSERT INTO 'dancesstepsmap' VALUES (28176, 5812, 1);
INSERT INTO 'dancesstepsmap' VALUES (28177, 5812, 3);
INSERT INTO 'dancesstepsmap' VALUES (28178, 5812, 5);
INSERT INTO 'dancesstepsmap' VALUES (28179, 5812, 4);
INSERT INTO 'dancesstepsmap' VALUES (28180, 7542, 8);
INSERT INTO 'dancesstepsmap' VALUES (28181, 7542, 1);
INSERT INTO 'dancesstepsmap' VALUES (28182, 7542, 2);
INSERT INTO 'dancesstepsmap' VALUES (28183, 7542, 4);
INSERT INTO 'dancesstepsmap' VALUES (28184, 7542, 5);
INSERT INTO 'dancesstepsmap' VALUES (28185, 10150, 1);
INSERT INTO 'dancesstepsmap' VALUES (28186, 10150, 2);
INSERT INTO 'dancesstepsmap' VALUES (28187, 10155, 1);
INSERT INTO 'dancesstepsmap' VALUES (28188, 10155, 3);
INSERT INTO 'dancesstepsmap' VALUES (28189, 10162, 4);
INSERT INTO 'dancesstepsmap' VALUES (28190, 10162, 5);
INSERT INTO 'dancesstepsmap' VALUES (28191, 10162, 1);
INSERT INTO 'dancesstepsmap' VALUES (28192, 10162, 3);
INSERT INTO 'dancesstepsmap' VALUES (28193, 10165, 2);
INSERT INTO 'dancesstepsmap' VALUES (28194, 10165, 1);
INSERT INTO 'dancesstepsmap' VALUES (28195, 10165, 3);
INSERT INTO 'dancesstepsmap' VALUES (28196, 10169, 2);
INSERT INTO 'dancesstepsmap' VALUES (28197, 10169, 1);
INSERT INTO 'dancesstepsmap' VALUES (28198, 10171, 2);
INSERT INTO 'dancesstepsmap' VALUES (28199, 10171, 1);
INSERT INTO 'dancesstepsmap' VALUES (28200, 10172, 2);
INSERT INTO 'dancesstepsmap' VALUES (28201, 10172, 1);
INSERT INTO 'dancesstepsmap' VALUES (28202, 10172, 3);
INSERT INTO 'dancesstepsmap' VALUES (28203, 10174, 4);
INSERT INTO 'dancesstepsmap' VALUES (28204, 10174, 5);
INSERT INTO 'dancesstepsmap' VALUES (28205, 10174, 1);
INSERT INTO 'dancesstepsmap' VALUES (28206, 10174, 2);
INSERT INTO 'dancesstepsmap' VALUES (28207, 10174, 3);
INSERT INTO 'dancesstepsmap' VALUES (28208, 10175, 3);
INSERT INTO 'dancesstepsmap' VALUES (28209, 10175, 1);
INSERT INTO 'dancesstepsmap' VALUES (28210, 10178, 5);
INSERT INTO 'dancesstepsmap' VALUES (28211, 10178, 4);
INSERT INTO 'dancesstepsmap' VALUES (28212, 10179, 1);
INSERT INTO 'dancesstepsmap' VALUES (28213, 10179, 3);
INSERT INTO 'dancesstepsmap' VALUES (28214, 10183, 4);
INSERT INTO 'dancesstepsmap' VALUES (28215, 10183, 1);
INSERT INTO 'dancesstepsmap' VALUES (28216, 10183, 2);
INSERT INTO 'dancesstepsmap' VALUES (28217, 10183, 3);
INSERT INTO 'dancesstepsmap' VALUES (28218, 10184, 4);
INSERT INTO 'dancesstepsmap' VALUES (28219, 10184, 5);
INSERT INTO 'dancesstepsmap' VALUES (28220, 10185, 2);
INSERT INTO 'dancesstepsmap' VALUES (28221, 10185, 1);
INSERT INTO 'dancesstepsmap' VALUES (28222, 10194, 5);
INSERT INTO 'dancesstepsmap' VALUES (28223, 10194, 4);
INSERT INTO 'dancesstepsmap' VALUES (28224, 10434, 2);
INSERT INTO 'dancesstepsmap' VALUES (28225, 10434, 1);
INSERT INTO 'dancesstepsmap' VALUES (28226, 10577, 1);
INSERT INTO 'dancesstepsmap' VALUES (28227, 10689, 1);
INSERT INTO 'dancesstepsmap' VALUES (28228, 10689, 2);
INSERT INTO 'dancesstepsmap' VALUES (28229, 10699, 1);
INSERT INTO 'dancesstepsmap' VALUES (28230, 10699, 2);
INSERT INTO 'dancesstepsmap' VALUES (28231, 10699, 3);
INSERT INTO 'dancesstepsmap' VALUES (28232, 10802, 2);
INSERT INTO 'dancesstepsmap' VALUES (28233, 1765, 2);
INSERT INTO 'dancesstepsmap' VALUES (28234, 3154, 2);
INSERT INTO 'dancesstepsmap' VALUES (28235, 10707, 1);
INSERT INTO 'dancesstepsmap' VALUES (28236, 10708, 1);
INSERT INTO 'dancesstepsmap' VALUES (28237, 10708, 2);
INSERT INTO 'dancesstepsmap' VALUES (28238, 10740, 1);
INSERT INTO 'dancesstepsmap' VALUES (28239, 10754, 1);
INSERT INTO 'dancesstepsmap' VALUES (28240, 10754, 2);
INSERT INTO 'dancesstepsmap' VALUES (28241, 10756, 2);
INSERT INTO 'dancesstepsmap' VALUES (28242, 10756, 1);
INSERT INTO 'dancesstepsmap' VALUES (28243, 10756, 3);
INSERT INTO 'dancesstepsmap' VALUES (28244, 10757, 4);
INSERT INTO 'dancesstepsmap' VALUES (28245, 10757, 5);
INSERT INTO 'dancesstepsmap' VALUES (28246, 10758, 2);
INSERT INTO 'dancesstepsmap' VALUES (28247, 10758, 1);
INSERT INTO 'dancesstepsmap' VALUES (28248, 10762, 1);
INSERT INTO 'dancesstepsmap' VALUES (28249, 10762, 2);
INSERT INTO 'dancesstepsmap' VALUES (28250, 10762, 3);
INSERT INTO 'dancesstepsmap' VALUES (28251, 10763, 4);
INSERT INTO 'dancesstepsmap' VALUES (28252, 10765, 1);
INSERT INTO 'dancesstepsmap' VALUES (28253, 10765, 3);
INSERT INTO 'dancesstepsmap' VALUES (28254, 10767, 5);
INSERT INTO 'dancesstepsmap' VALUES (28255, 10767, 4);
INSERT INTO 'dancesstepsmap' VALUES (28256, 19978, 1);
INSERT INTO 'dancesstepsmap' VALUES (28257, 19978, 2);
INSERT INTO 'dancesstepsmap' VALUES (28258, 10269, 4);
INSERT INTO 'dancesstepsmap' VALUES (28259, 10269, 5);
INSERT INTO 'dancesstepsmap' VALUES (28260, 10832, 2);
INSERT INTO 'dancesstepsmap' VALUES (28261, 10832, 1);
INSERT INTO 'dancesstepsmap' VALUES (28262, 10834, 4);
INSERT INTO 'dancesstepsmap' VALUES (28263, 10834, 5);
INSERT INTO 'dancesstepsmap' VALUES (28264, 10865, 5);
INSERT INTO 'dancesstepsmap' VALUES (28265, 10865, 4);
INSERT INTO 'dancesstepsmap' VALUES (28266, 10865, 2);
INSERT INTO 'dancesstepsmap' VALUES (28267, 10865, 1);
INSERT INTO 'dancesstepsmap' VALUES (28268, 10865, 3);
INSERT INTO 'dancesstepsmap' VALUES (28269, 10994, 1);
INSERT INTO 'dancesstepsmap' VALUES (28270, 10994, 3);
INSERT INTO 'dancesstepsmap' VALUES (28271, 10994, 2);
INSERT INTO 'dancesstepsmap' VALUES (28272, 11001, 1);
INSERT INTO 'dancesstepsmap' VALUES (28273, 11001, 2);
INSERT INTO 'dancesstepsmap' VALUES (28274, 11001, 3);
INSERT INTO 'dancesstepsmap' VALUES (28275, 11014, 2);
INSERT INTO 'dancesstepsmap' VALUES (28276, 11014, 1);
INSERT INTO 'dancesstepsmap' VALUES (28277, 11017, 1);
INSERT INTO 'dancesstepsmap' VALUES (28278, 11017, 2);
INSERT INTO 'dancesstepsmap' VALUES (28279, 11025, 3);
INSERT INTO 'dancesstepsmap' VALUES (28280, 11091, 1);
INSERT INTO 'dancesstepsmap' VALUES (28281, 11197, 5);
INSERT INTO 'dancesstepsmap' VALUES (28282, 11197, 4);
INSERT INTO 'dancesstepsmap' VALUES (28283, 11198, 2);
INSERT INTO 'dancesstepsmap' VALUES (28284, 11198, 1);
INSERT INTO 'dancesstepsmap' VALUES (28285, 11200, 1);
INSERT INTO 'dancesstepsmap' VALUES (28286, 11200, 2);
INSERT INTO 'dancesstepsmap' VALUES (28287, 11201, 2);
INSERT INTO 'dancesstepsmap' VALUES (28288, 11201, 3);
INSERT INTO 'dancesstepsmap' VALUES (28289, 11201, 1);
INSERT INTO 'dancesstepsmap' VALUES (28290, 11202, 2);
INSERT INTO 'dancesstepsmap' VALUES (28291, 11202, 1);
INSERT INTO 'dancesstepsmap' VALUES (28292, 11204, 1);
INSERT INTO 'dancesstepsmap' VALUES (28293, 11204, 3);
INSERT INTO 'dancesstepsmap' VALUES (28294, 11227, 1);
INSERT INTO 'dancesstepsmap' VALUES (28295, 11227, 2);
INSERT INTO 'dancesstepsmap' VALUES (28296, 11300, 5);
INSERT INTO 'dancesstepsmap' VALUES (28297, 11300, 4);
INSERT INTO 'dancesstepsmap' VALUES (28298, 11316, 5);
INSERT INTO 'dancesstepsmap' VALUES (28299, 11316, 4);
INSERT INTO 'dancesstepsmap' VALUES (28300, 11316, 3);
INSERT INTO 'dancesstepsmap' VALUES (28301, 11316, 1);
INSERT INTO 'dancesstepsmap' VALUES (28302, 11316, 2);
INSERT INTO 'dancesstepsmap' VALUES (28303, 11419, 1);
INSERT INTO 'dancesstepsmap' VALUES (28304, 11419, 2);
INSERT INTO 'dancesstepsmap' VALUES (28305, 12086, 1);
INSERT INTO 'dancesstepsmap' VALUES (28306, 12086, 2);
INSERT INTO 'dancesstepsmap' VALUES (28307, 12086, 3);
INSERT INTO 'dancesstepsmap' VALUES (28308, 12090, 1);
INSERT INTO 'dancesstepsmap' VALUES (28309, 12281, 1);
INSERT INTO 'dancesstepsmap' VALUES (28310, 12296, 4);
INSERT INTO 'dancesstepsmap' VALUES (28311, 12323, 4);
INSERT INTO 'dancesstepsmap' VALUES (28312, 12323, 5);
INSERT INTO 'dancesstepsmap' VALUES (28313, 12396, 4);
INSERT INTO 'dancesstepsmap' VALUES (28314, 12396, 5);
INSERT INTO 'dancesstepsmap' VALUES (28315, 12718, 2);
INSERT INTO 'dancesstepsmap' VALUES (28316, 12718, 1);
INSERT INTO 'dancesstepsmap' VALUES (28317, 12718, 3);
INSERT INTO 'dancesstepsmap' VALUES (28318, 12805, 1);
INSERT INTO 'dancesstepsmap' VALUES (28319, 12829, 1);
INSERT INTO 'dancesstepsmap' VALUES (28320, 12829, 2);
INSERT INTO 'dancesstepsmap' VALUES (28321, 12853, 2);
INSERT INTO 'dancesstepsmap' VALUES (28322, 13123, 1);
INSERT INTO 'dancesstepsmap' VALUES (28323, 13123, 2);
INSERT INTO 'dancesstepsmap' VALUES (28324, 13123, 3);
INSERT INTO 'dancesstepsmap' VALUES (28325, 13124, 1);
INSERT INTO 'dancesstepsmap' VALUES (28326, 13124, 2);
INSERT INTO 'dancesstepsmap' VALUES (28327, 13125, 2);
INSERT INTO 'dancesstepsmap' VALUES (28328, 13125, 1);
INSERT INTO 'dancesstepsmap' VALUES (28329, 12196, 6);
INSERT INTO 'dancesstepsmap' VALUES (28330, 12196, 5);
INSERT INTO 'dancesstepsmap' VALUES (28331, 12196, 4);
INSERT INTO 'dancesstepsmap' VALUES (28332, 7890, 2);
INSERT INTO 'dancesstepsmap' VALUES (28333, 7890, 3);
INSERT INTO 'dancesstepsmap' VALUES (28334, 13130, 2);
INSERT INTO 'dancesstepsmap' VALUES (28335, 13130, 1);
INSERT INTO 'dancesstepsmap' VALUES (28336, 13136, 1);
INSERT INTO 'dancesstepsmap' VALUES (28337, 13136, 2);
INSERT INTO 'dancesstepsmap' VALUES (28338, 13137, 2);
INSERT INTO 'dancesstepsmap' VALUES (28339, 13137, 1);
INSERT INTO 'dancesstepsmap' VALUES (28340, 13139, 1);
INSERT INTO 'dancesstepsmap' VALUES (28341, 13139, 2);
INSERT INTO 'dancesstepsmap' VALUES (28342, 13139, 3);
INSERT INTO 'dancesstepsmap' VALUES (28343, 13212, 5);
INSERT INTO 'dancesstepsmap' VALUES (28344, 13212, 4);
INSERT INTO 'dancesstepsmap' VALUES (28345, 13215, 5);
INSERT INTO 'dancesstepsmap' VALUES (28346, 13215, 4);
INSERT INTO 'dancesstepsmap' VALUES (28347, 13216, 9);
INSERT INTO 'dancesstepsmap' VALUES (28348, 13216, 1);
INSERT INTO 'dancesstepsmap' VALUES (28349, 13216, 2);
INSERT INTO 'dancesstepsmap' VALUES (28350, 13216, 10);
INSERT INTO 'dancesstepsmap' VALUES (28351, 13152, 2);
INSERT INTO 'dancesstepsmap' VALUES (28352, 13317, 2);
INSERT INTO 'dancesstepsmap' VALUES (28353, 13453, 1);
INSERT INTO 'dancesstepsmap' VALUES (28354, 13455, 1);
INSERT INTO 'dancesstepsmap' VALUES (28355, 13456, 4);
INSERT INTO 'dancesstepsmap' VALUES (28356, 13456, 5);
INSERT INTO 'dancesstepsmap' VALUES (28357, 13497, 1);
INSERT INTO 'dancesstepsmap' VALUES (28358, 13497, 2);
INSERT INTO 'dancesstepsmap' VALUES (28359, 13502, 5);
INSERT INTO 'dancesstepsmap' VALUES (28360, 13502, 4);
INSERT INTO 'dancesstepsmap' VALUES (28361, 13508, 4);
INSERT INTO 'dancesstepsmap' VALUES (28362, 13517, 1);
INSERT INTO 'dancesstepsmap' VALUES (28363, 13517, 3);
INSERT INTO 'dancesstepsmap' VALUES (28364, 13523, 4);
INSERT INTO 'dancesstepsmap' VALUES (28365, 13528, 1);
INSERT INTO 'dancesstepsmap' VALUES (28366, 13528, 3);
INSERT INTO 'dancesstepsmap' VALUES (28367, 13538, 3);
INSERT INTO 'dancesstepsmap' VALUES (28368, 13538, 2);
INSERT INTO 'dancesstepsmap' VALUES (28369, 13538, 1);
INSERT INTO 'dancesstepsmap' VALUES (28370, 13553, 1);
INSERT INTO 'dancesstepsmap' VALUES (28371, 13553, 2);
INSERT INTO 'dancesstepsmap' VALUES (28372, 13556, 4);
INSERT INTO 'dancesstepsmap' VALUES (28373, 13556, 5);
INSERT INTO 'dancesstepsmap' VALUES (28374, 20082, 2);
INSERT INTO 'dancesstepsmap' VALUES (28375, 20082, 1);
INSERT INTO 'dancesstepsmap' VALUES (28376, 10410, 4);
INSERT INTO 'dancesstepsmap' VALUES (28377, 10409, 4);
INSERT INTO 'dancesstepsmap' VALUES (28378, 3912, 2);
INSERT INTO 'dancesstepsmap' VALUES (28379, 13560, 1);
INSERT INTO 'dancesstepsmap' VALUES (28380, 13560, 3);
INSERT INTO 'dancesstepsmap' VALUES (28381, 13584, 2);
INSERT INTO 'dancesstepsmap' VALUES (28382, 13584, 1);
INSERT INTO 'dancesstepsmap' VALUES (28383, 13625, 4);
INSERT INTO 'dancesstepsmap' VALUES (28384, 13625, 5);
INSERT INTO 'dancesstepsmap' VALUES (28385, 13743, 2);
INSERT INTO 'dancesstepsmap' VALUES (28386, 13743, 1);
INSERT INTO 'dancesstepsmap' VALUES (28387, 13744, 1);
INSERT INTO 'dancesstepsmap' VALUES (28388, 13751, 5);
INSERT INTO 'dancesstepsmap' VALUES (28389, 13752, 1);
INSERT INTO 'dancesstepsmap' VALUES (28390, 13752, 3);
INSERT INTO 'dancesstepsmap' VALUES (28391, 13761, 3);
INSERT INTO 'dancesstepsmap' VALUES (28392, 13761, 1);
INSERT INTO 'dancesstepsmap' VALUES (28393, 13761, 2);
INSERT INTO 'dancesstepsmap' VALUES (28394, 13763, 4);
INSERT INTO 'dancesstepsmap' VALUES (28395, 13765, 1);
INSERT INTO 'dancesstepsmap' VALUES (28396, 13765, 2);
INSERT INTO 'dancesstepsmap' VALUES (28397, 13767, 5);
INSERT INTO 'dancesstepsmap' VALUES (16335, 13772, 3);
INSERT INTO 'dancesstepsmap' VALUES (28398, 13823, 1);
INSERT INTO 'dancesstepsmap' VALUES (28399, 13823, 2);
INSERT INTO 'dancesstepsmap' VALUES (28400, 13835, 1);
INSERT INTO 'dancesstepsmap' VALUES (28401, 13835, 2);
INSERT INTO 'dancesstepsmap' VALUES (28402, 13849, 5);
INSERT INTO 'dancesstepsmap' VALUES (28403, 13849, 4);
INSERT INTO 'dancesstepsmap' VALUES (28404, 13852, 1);
INSERT INTO 'dancesstepsmap' VALUES (28405, 13852, 2);
INSERT INTO 'dancesstepsmap' VALUES (28406, 13852, 3);
INSERT INTO 'dancesstepsmap' VALUES (28407, 13859, 1);
INSERT INTO 'dancesstepsmap' VALUES (28408, 13859, 2);
INSERT INTO 'dancesstepsmap' VALUES (28409, 20083, 5);
INSERT INTO 'dancesstepsmap' VALUES (28410, 20083, 4);
INSERT INTO 'dancesstepsmap' VALUES (28411, 13860, 2);
INSERT INTO 'dancesstepsmap' VALUES (28412, 13860, 1);
INSERT INTO 'dancesstepsmap' VALUES (28413, 20084, 4);
INSERT INTO 'dancesstepsmap' VALUES (28414, 20084, 5);
INSERT INTO 'dancesstepsmap' VALUES (28415, 20084, 1);
INSERT INTO 'dancesstepsmap' VALUES (28416, 20084, 3);
INSERT INTO 'dancesstepsmap' VALUES (28417, 20084, 2);
INSERT INTO 'dancesstepsmap' VALUES (28418, 13861, 1);
INSERT INTO 'dancesstepsmap' VALUES (28419, 13861, 2);
INSERT INTO 'dancesstepsmap' VALUES (28420, 13864, 5);
INSERT INTO 'dancesstepsmap' VALUES (28421, 13864, 4);
INSERT INTO 'dancesstepsmap' VALUES (28422, 13866, 2);
INSERT INTO 'dancesstepsmap' VALUES (28423, 13866, 1);
INSERT INTO 'dancesstepsmap' VALUES (28424, 13867, 5);
INSERT INTO 'dancesstepsmap' VALUES (28425, 13867, 4);
INSERT INTO 'dancesstepsmap' VALUES (28426, 13886, 5);
INSERT INTO 'dancesstepsmap' VALUES (28427, 13886, 4);
INSERT INTO 'dancesstepsmap' VALUES (28428, 13887, 2);
INSERT INTO 'dancesstepsmap' VALUES (28429, 13887, 1);
INSERT INTO 'dancesstepsmap' VALUES (28430, 13892, 5);
INSERT INTO 'dancesstepsmap' VALUES (28431, 13892, 4);
INSERT INTO 'dancesstepsmap' VALUES (28432, 13924, 1);
INSERT INTO 'dancesstepsmap' VALUES (28433, 13924, 2);
INSERT INTO 'dancesstepsmap' VALUES (28434, 13930, 5);
INSERT INTO 'dancesstepsmap' VALUES (28435, 13930, 4);
INSERT INTO 'dancesstepsmap' VALUES (28436, 13933, 2);
INSERT INTO 'dancesstepsmap' VALUES (28437, 13933, 1);
INSERT INTO 'dancesstepsmap' VALUES (28438, 13942, 1);
INSERT INTO 'dancesstepsmap' VALUES (28439, 13942, 2);
INSERT INTO 'dancesstepsmap' VALUES (28440, 13942, 3);
INSERT INTO 'dancesstepsmap' VALUES (28441, 14001, 1);
INSERT INTO 'dancesstepsmap' VALUES (28442, 14001, 2);
INSERT INTO 'dancesstepsmap' VALUES (28443, 14001, 3);
INSERT INTO 'dancesstepsmap' VALUES (28444, 14009, 1);
INSERT INTO 'dancesstepsmap' VALUES (28445, 14009, 2);
INSERT INTO 'dancesstepsmap' VALUES (28446, 14021, 2);
INSERT INTO 'dancesstepsmap' VALUES (28447, 14021, 1);
INSERT INTO 'dancesstepsmap' VALUES (28448, 14023, 5);
INSERT INTO 'dancesstepsmap' VALUES (28449, 14023, 4);
INSERT INTO 'dancesstepsmap' VALUES (28450, 14024, 2);
INSERT INTO 'dancesstepsmap' VALUES (28451, 14024, 1);
INSERT INTO 'dancesstepsmap' VALUES (28452, 14024, 3);
INSERT INTO 'dancesstepsmap' VALUES (28453, 14038, 2);
INSERT INTO 'dancesstepsmap' VALUES (28454, 14038, 1);
INSERT INTO 'dancesstepsmap' VALUES (28455, 14038, 3);
INSERT INTO 'dancesstepsmap' VALUES (28456, 14043, 1);
INSERT INTO 'dancesstepsmap' VALUES (28457, 14075, 2);
INSERT INTO 'dancesstepsmap' VALUES (28458, 14075, 1);
INSERT INTO 'dancesstepsmap' VALUES (28459, 14086, 1);
INSERT INTO 'dancesstepsmap' VALUES (28460, 14102, 1);
INSERT INTO 'dancesstepsmap' VALUES (28461, 14102, 2);
INSERT INTO 'dancesstepsmap' VALUES (28462, 14103, 2);
INSERT INTO 'dancesstepsmap' VALUES (28463, 14103, 1);
INSERT INTO 'dancesstepsmap' VALUES (28464, 14117, 1);
INSERT INTO 'dancesstepsmap' VALUES (28465, 14117, 2);
INSERT INTO 'dancesstepsmap' VALUES (28466, 14136, 2);
INSERT INTO 'dancesstepsmap' VALUES (28467, 14136, 1);
INSERT INTO 'dancesstepsmap' VALUES (28468, 14137, 5);
INSERT INTO 'dancesstepsmap' VALUES (28469, 14137, 4);
INSERT INTO 'dancesstepsmap' VALUES (28470, 14137, 2);
INSERT INTO 'dancesstepsmap' VALUES (28471, 14137, 1);
INSERT INTO 'dancesstepsmap' VALUES (28472, 14137, 3);
INSERT INTO 'dancesstepsmap' VALUES (28473, 14138, 5);
INSERT INTO 'dancesstepsmap' VALUES (28474, 14138, 4);
INSERT INTO 'dancesstepsmap' VALUES (28475, 14139, 1);
INSERT INTO 'dancesstepsmap' VALUES (28476, 14139, 3);
INSERT INTO 'dancesstepsmap' VALUES (28477, 14141, 5);
INSERT INTO 'dancesstepsmap' VALUES (28478, 14141, 4);
INSERT INTO 'dancesstepsmap' VALUES (28479, 14232, 1);
INSERT INTO 'dancesstepsmap' VALUES (28480, 14232, 2);
INSERT INTO 'dancesstepsmap' VALUES (28481, 14234, 4);
INSERT INTO 'dancesstepsmap' VALUES (28482, 14234, 1);
INSERT INTO 'dancesstepsmap' VALUES (28483, 14234, 3);
INSERT INTO 'dancesstepsmap' VALUES (28484, 14235, 1);
INSERT INTO 'dancesstepsmap' VALUES (28485, 14235, 2);
INSERT INTO 'dancesstepsmap' VALUES (28486, 14238, 1);
INSERT INTO 'dancesstepsmap' VALUES (28487, 14238, 3);
INSERT INTO 'dancesstepsmap' VALUES (28488, 14238, 2);
INSERT INTO 'dancesstepsmap' VALUES (28489, 14072, 1);
INSERT INTO 'dancesstepsmap' VALUES (28490, 14072, 2);
INSERT INTO 'dancesstepsmap' VALUES (28491, 14242, 2);
INSERT INTO 'dancesstepsmap' VALUES (28492, 14242, 1);
INSERT INTO 'dancesstepsmap' VALUES (28493, 14242, 8);
INSERT INTO 'dancesstepsmap' VALUES (28494, 11437, 2);
INSERT INTO 'dancesstepsmap' VALUES (28495, 1256, 5);
INSERT INTO 'dancesstepsmap' VALUES (28496, 1256, 4);
INSERT INTO 'dancesstepsmap' VALUES (28497, 1256, 2);
INSERT INTO 'dancesstepsmap' VALUES (28498, 1256, 1);
INSERT INTO 'dancesstepsmap' VALUES (28499, 1256, 3);
INSERT INTO 'dancesstepsmap' VALUES (28500, 14293, 2);
INSERT INTO 'dancesstepsmap' VALUES (28501, 14293, 1);
INSERT INTO 'dancesstepsmap' VALUES (28502, 14293, 3);
INSERT INTO 'dancesstepsmap' VALUES (28503, 14294, 2);
INSERT INTO 'dancesstepsmap' VALUES (28504, 14294, 1);
INSERT INTO 'dancesstepsmap' VALUES (28505, 14318, 1);
INSERT INTO 'dancesstepsmap' VALUES (28506, 14318, 3);
INSERT INTO 'dancesstepsmap' VALUES (28507, 14371, 1);
INSERT INTO 'dancesstepsmap' VALUES (28508, 14371, 2);
INSERT INTO 'dancesstepsmap' VALUES (28509, 1354, 3);
INSERT INTO 'dancesstepsmap' VALUES (28510, 14376, 5);
INSERT INTO 'dancesstepsmap' VALUES (28511, 14414, 2);
INSERT INTO 'dancesstepsmap' VALUES (28512, 14414, 1);
INSERT INTO 'dancesstepsmap' VALUES (28516, 3013, 3);
INSERT INTO 'dancesstepsmap' VALUES (28517, 19867, 1);
INSERT INTO 'dancesstepsmap' VALUES (28518, 19867, 2);
INSERT INTO 'dancesstepsmap' VALUES (28521, 14460, 1);
INSERT INTO 'dancesstepsmap' VALUES (28522, 14460, 2);
INSERT INTO 'dancesstepsmap' VALUES (28523, 14466, 1);
INSERT INTO 'dancesstepsmap' VALUES (28524, 14476, 4);
INSERT INTO 'dancesstepsmap' VALUES (28525, 14476, 5);
INSERT INTO 'dancesstepsmap' VALUES (28526, 20086, 1);
INSERT INTO 'dancesstepsmap' VALUES (28527, 20086, 2);
INSERT INTO 'dancesstepsmap' VALUES (28528, 14479, 2);
INSERT INTO 'dancesstepsmap' VALUES (28529, 14479, 1);
INSERT INTO 'dancesstepsmap' VALUES (28530, 14480, 1);
INSERT INTO 'dancesstepsmap' VALUES (28531, 14480, 2);
INSERT INTO 'dancesstepsmap' VALUES (28532, 14480, 3);
INSERT INTO 'dancesstepsmap' VALUES (28533, 13289, 1);
INSERT INTO 'dancesstepsmap' VALUES (28534, 13289, 2);
INSERT INTO 'dancesstepsmap' VALUES (28535, 20088, 2);
INSERT INTO 'dancesstepsmap' VALUES (28536, 20088, 1);
INSERT INTO 'dancesstepsmap' VALUES (28537, 20089, 4);
INSERT INTO 'dancesstepsmap' VALUES (28538, 20089, 5);
INSERT INTO 'dancesstepsmap' VALUES (28539, 20090, 1);
INSERT INTO 'dancesstepsmap' VALUES (28540, 20090, 2);
INSERT INTO 'dancesstepsmap' VALUES (28541, 20091, 4);
INSERT INTO 'dancesstepsmap' VALUES (28542, 20091, 5);
INSERT INTO 'dancesstepsmap' VALUES (28543, 20092, 2);
INSERT INTO 'dancesstepsmap' VALUES (28544, 20092, 1);
INSERT INTO 'dancesstepsmap' VALUES (28545, 20093, 2);
INSERT INTO 'dancesstepsmap' VALUES (28546, 20093, 1);
INSERT INTO 'dancesstepsmap' VALUES (28547, 20094, 1);
INSERT INTO 'dancesstepsmap' VALUES (28548, 20095, 4);
INSERT INTO 'dancesstepsmap' VALUES (28549, 20095, 5);
INSERT INTO 'dancesstepsmap' VALUES (28550, 20096, 2);
INSERT INTO 'dancesstepsmap' VALUES (28551, 20096, 1);
INSERT INTO 'dancesstepsmap' VALUES (28552, 20097, 5);
INSERT INTO 'dancesstepsmap' VALUES (28553, 20097, 4);
INSERT INTO 'dancesstepsmap' VALUES (28554, 20098, 1);
INSERT INTO 'dancesstepsmap' VALUES (28555, 20098, 2);
INSERT INTO 'dancesstepsmap' VALUES (28556, 20099, 5);
INSERT INTO 'dancesstepsmap' VALUES (28557, 20099, 4);
INSERT INTO 'dancesstepsmap' VALUES (28558, 14496, 4);
INSERT INTO 'dancesstepsmap' VALUES (28559, 14496, 5);
INSERT INTO 'dancesstepsmap' VALUES (28560, 14497, 1);
INSERT INTO 'dancesstepsmap' VALUES (28561, 14545, 4);
INSERT INTO 'dancesstepsmap' VALUES (28562, 14545, 5);
INSERT INTO 'dancesstepsmap' VALUES (28563, 14545, 1);
INSERT INTO 'dancesstepsmap' VALUES (28564, 14547, 5);
INSERT INTO 'dancesstepsmap' VALUES (28565, 14547, 4);
INSERT INTO 'dancesstepsmap' VALUES (28566, 14556, 4);
INSERT INTO 'dancesstepsmap' VALUES (28567, 14556, 5);
INSERT INTO 'dancesstepsmap' VALUES (28568, 14563, 1);
INSERT INTO 'dancesstepsmap' VALUES (28569, 14563, 2);
INSERT INTO 'dancesstepsmap' VALUES (28570, 14589, 4);
INSERT INTO 'dancesstepsmap' VALUES (28571, 14590, 1);
INSERT INTO 'dancesstepsmap' VALUES (28572, 14785, 1);
INSERT INTO 'dancesstepsmap' VALUES (28573, 5500, 5);
INSERT INTO 'dancesstepsmap' VALUES (28574, 280, 2);
INSERT INTO 'dancesstepsmap' VALUES (28575, 14665, 1);
INSERT INTO 'dancesstepsmap' VALUES (28576, 14665, 2);
INSERT INTO 'dancesstepsmap' VALUES (28577, 14666, 1);
INSERT INTO 'dancesstepsmap' VALUES (28578, 14668, 1);
INSERT INTO 'dancesstepsmap' VALUES (28579, 14668, 2);
INSERT INTO 'dancesstepsmap' VALUES (28580, 14669, 4);
INSERT INTO 'dancesstepsmap' VALUES (28581, 14669, 5);
INSERT INTO 'dancesstepsmap' VALUES (28582, 14669, 1);
INSERT INTO 'dancesstepsmap' VALUES (28583, 14669, 2);
INSERT INTO 'dancesstepsmap' VALUES (28584, 14670, 1);
INSERT INTO 'dancesstepsmap' VALUES (28585, 14670, 2);
INSERT INTO 'dancesstepsmap' VALUES (28586, 14670, 3);
INSERT INTO 'dancesstepsmap' VALUES (28587, 14671, 4);
INSERT INTO 'dancesstepsmap' VALUES (28588, 14671, 5);
INSERT INTO 'dancesstepsmap' VALUES (28589, 14676, 4);
INSERT INTO 'dancesstepsmap' VALUES (28590, 14676, 5);
INSERT INTO 'dancesstepsmap' VALUES (28591, 14748, 4);
INSERT INTO 'dancesstepsmap' VALUES (28592, 14814, 2);
INSERT INTO 'dancesstepsmap' VALUES (28593, 14814, 1);
INSERT INTO 'dancesstepsmap' VALUES (28594, 14828, 2);
INSERT INTO 'dancesstepsmap' VALUES (28595, 14828, 1);
INSERT INTO 'dancesstepsmap' VALUES (28596, 14904, 4);
INSERT INTO 'dancesstepsmap' VALUES (28597, 14904, 5);
INSERT INTO 'dancesstepsmap' VALUES (28598, 14946, 4);
INSERT INTO 'dancesstepsmap' VALUES (28599, 14947, 1);
INSERT INTO 'dancesstepsmap' VALUES (28600, 14947, 3);
INSERT INTO 'dancesstepsmap' VALUES (28601, 597, 5);
INSERT INTO 'dancesstepsmap' VALUES (28602, 2550, 2);
INSERT INTO 'dancesstepsmap' VALUES (28603, 14949, 4);
INSERT INTO 'dancesstepsmap' VALUES (28604, 4828, 5);
INSERT INTO 'dancesstepsmap' VALUES (28605, 14952, 6);
INSERT INTO 'dancesstepsmap' VALUES (28606, 14954, 5);
INSERT INTO 'dancesstepsmap' VALUES (28607, 14954, 4);
INSERT INTO 'dancesstepsmap' VALUES (28608, 14965, 4);
INSERT INTO 'dancesstepsmap' VALUES (28609, 14965, 5);
INSERT INTO 'dancesstepsmap' VALUES (28610, 14967, 1);
INSERT INTO 'dancesstepsmap' VALUES (28611, 14968, 1);
INSERT INTO 'dancesstepsmap' VALUES (28612, 14969, 1);
INSERT INTO 'dancesstepsmap' VALUES (28613, 14972, 1);
INSERT INTO 'dancesstepsmap' VALUES (28614, 14972, 2);
INSERT INTO 'dancesstepsmap' VALUES (28615, 18807, 1);
INSERT INTO 'dancesstepsmap' VALUES (28616, 18807, 2);
INSERT INTO 'dancesstepsmap' VALUES (28617, 20100, 2);
INSERT INTO 'dancesstepsmap' VALUES (28618, 20100, 1);
INSERT INTO 'dancesstepsmap' VALUES (28619, 20101, 2);
INSERT INTO 'dancesstepsmap' VALUES (28620, 20101, 1);
INSERT INTO 'dancesstepsmap' VALUES (28621, 20101, 3);
INSERT INTO 'dancesstepsmap' VALUES (28622, 20102, 4);
INSERT INTO 'dancesstepsmap' VALUES (28623, 20102, 5);
INSERT INTO 'dancesstepsmap' VALUES (28624, 20103, 2);
INSERT INTO 'dancesstepsmap' VALUES (28625, 20103, 1);
INSERT INTO 'dancesstepsmap' VALUES (28626, 20104, 1);
INSERT INTO 'dancesstepsmap' VALUES (28627, 20104, 2);
INSERT INTO 'dancesstepsmap' VALUES (28628, 20105, 1);
INSERT INTO 'dancesstepsmap' VALUES (28629, 20105, 2);
INSERT INTO 'dancesstepsmap' VALUES (28630, 20106, 4);
INSERT INTO 'dancesstepsmap' VALUES (28631, 20106, 5);
INSERT INTO 'dancesstepsmap' VALUES (28632, 20107, 2);
INSERT INTO 'dancesstepsmap' VALUES (28633, 20107, 1);
INSERT INTO 'dancesstepsmap' VALUES (28634, 2992, 2);
INSERT INTO 'dancesstepsmap' VALUES (28635, 19077, 5);
INSERT INTO 'dancesstepsmap' VALUES (28636, 19077, 4);
INSERT INTO 'dancesstepsmap' VALUES (28637, 20108, 2);
INSERT INTO 'dancesstepsmap' VALUES (28638, 20108, 8);
INSERT INTO 'dancesstepsmap' VALUES (28639, 20108, 10);
INSERT INTO 'dancesstepsmap' VALUES (28640, 20108, 1);
INSERT INTO 'dancesstepsmap' VALUES (28641, 20108, 3);
INSERT INTO 'dancesstepsmap' VALUES (28642, 20108, 102);
INSERT INTO 'dancesstepsmap' VALUES (28643, 20109, 1);
INSERT INTO 'dancesstepsmap' VALUES (28644, 20109, 2);
INSERT INTO 'dancesstepsmap' VALUES (28645, 20112, 4);
INSERT INTO 'dancesstepsmap' VALUES (28646, 20112, 5);
INSERT INTO 'dancesstepsmap' VALUES (28647, 20112, 6);
INSERT INTO 'dancesstepsmap' VALUES (28648, 20114, 3);
INSERT INTO 'dancesstepsmap' VALUES (28649, 20114, 1);
INSERT INTO 'dancesstepsmap' VALUES (28650, 20114, 2);
INSERT INTO 'dancesstepsmap' VALUES (28651, 20117, 5);
INSERT INTO 'dancesstepsmap' VALUES (28652, 20117, 4);
INSERT INTO 'dancesstepsmap' VALUES (28653, 20117, 6);
INSERT INTO 'dancesstepsmap' VALUES (28654, 20118, 2);
INSERT INTO 'dancesstepsmap' VALUES (28655, 20118, 1);
INSERT INTO 'dancesstepsmap' VALUES (28656, 14950, 2);
INSERT INTO 'dancesstepsmap' VALUES (28657, 14950, 1);
INSERT INTO 'dancesstepsmap' VALUES (28658, 20119, 2);
INSERT INTO 'dancesstepsmap' VALUES (28659, 20119, 1);
INSERT INTO 'dancesstepsmap' VALUES (28660, 20119, 102);
INSERT INTO 'dancesstepsmap' VALUES (28661, 15025, 1);
INSERT INTO 'dancesstepsmap' VALUES (28662, 15025, 2);
INSERT INTO 'dancesstepsmap' VALUES (28663, 15030, 4);
INSERT INTO 'dancesstepsmap' VALUES (28664, 15030, 5);
INSERT INTO 'dancesstepsmap' VALUES (28665, 15033, 1);
INSERT INTO 'dancesstepsmap' VALUES (28666, 15033, 2);
INSERT INTO 'dancesstepsmap' VALUES (28667, 15034, 1);
INSERT INTO 'dancesstepsmap' VALUES (28668, 15036, 1);
INSERT INTO 'dancesstepsmap' VALUES (28669, 15036, 2);
INSERT INTO 'dancesstepsmap' VALUES (28670, 15043, 1);
INSERT INTO 'dancesstepsmap' VALUES (28671, 15043, 2);
INSERT INTO 'dancesstepsmap' VALUES (28672, 15043, 3);
INSERT INTO 'dancesstepsmap' VALUES (28673, 15058, 1);
INSERT INTO 'dancesstepsmap' VALUES (28674, 15058, 2);
INSERT INTO 'dancesstepsmap' VALUES (28675, 15064, 4);
INSERT INTO 'dancesstepsmap' VALUES (28676, 15064, 5);
INSERT INTO 'dancesstepsmap' VALUES (28677, 15068, 1);
INSERT INTO 'dancesstepsmap' VALUES (28678, 15101, 4);
INSERT INTO 'dancesstepsmap' VALUES (28679, 15101, 1);
INSERT INTO 'dancesstepsmap' VALUES (28680, 15101, 2);
INSERT INTO 'dancesstepsmap' VALUES (28681, 15103, 2);
INSERT INTO 'dancesstepsmap' VALUES (28682, 15103, 1);
INSERT INTO 'dancesstepsmap' VALUES (28683, 15111, 2);
INSERT INTO 'dancesstepsmap' VALUES (28684, 15111, 1);
INSERT INTO 'dancesstepsmap' VALUES (28685, 15124, 1);
INSERT INTO 'dancesstepsmap' VALUES (28686, 15124, 2);
INSERT INTO 'dancesstepsmap' VALUES (28687, 15304, 3);
INSERT INTO 'dancesstepsmap' VALUES (28688, 15304, 1);
INSERT INTO 'dancesstepsmap' VALUES (28689, 15306, 2);
INSERT INTO 'dancesstepsmap' VALUES (28690, 15306, 1);
INSERT INTO 'dancesstepsmap' VALUES (28691, 15316, 1);
INSERT INTO 'dancesstepsmap' VALUES (28692, 15316, 2);
INSERT INTO 'dancesstepsmap' VALUES (28693, 15317, 1);
INSERT INTO 'dancesstepsmap' VALUES (28694, 15317, 2);
INSERT INTO 'dancesstepsmap' VALUES (28695, 15320, 1);
INSERT INTO 'dancesstepsmap' VALUES (28696, 15320, 2);
INSERT INTO 'dancesstepsmap' VALUES (28697, 15327, 4);
INSERT INTO 'dancesstepsmap' VALUES (28698, 15334, 4);
INSERT INTO 'dancesstepsmap' VALUES (28699, 15339, 1);
INSERT INTO 'dancesstepsmap' VALUES (28700, 15339, 2);
INSERT INTO 'dancesstepsmap' VALUES (28701, 2606, 2);
INSERT INTO 'dancesstepsmap' VALUES (28702, 15369, 3);
INSERT INTO 'dancesstepsmap' VALUES (28703, 15369, 1);
INSERT INTO 'dancesstepsmap' VALUES (28704, 15369, 2);
INSERT INTO 'dancesstepsmap' VALUES (28705, 15408, 1);
INSERT INTO 'dancesstepsmap' VALUES (28706, 15408, 2);
INSERT INTO 'dancesstepsmap' VALUES (28707, 15409, 1);
INSERT INTO 'dancesstepsmap' VALUES (28708, 15409, 2);
INSERT INTO 'dancesstepsmap' VALUES (28709, 2907, 4);
INSERT INTO 'dancesstepsmap' VALUES (28710, 2907, 5);
INSERT INTO 'dancesstepsmap' VALUES (28711, 2907, 2);
INSERT INTO 'dancesstepsmap' VALUES (28712, 2907, 1);
INSERT INTO 'dancesstepsmap' VALUES (28713, 15582, 2);
INSERT INTO 'dancesstepsmap' VALUES (28714, 15588, 4);
INSERT INTO 'dancesstepsmap' VALUES (28715, 15588, 5);
INSERT INTO 'dancesstepsmap' VALUES (28716, 15588, 1);
INSERT INTO 'dancesstepsmap' VALUES (28717, 15588, 2);
INSERT INTO 'dancesstepsmap' VALUES (28718, 2932, 5);
INSERT INTO 'dancesstepsmap' VALUES (28719, 2932, 6);
INSERT INTO 'dancesstepsmap' VALUES (28720, 5136, 2);
INSERT INTO 'dancesstepsmap' VALUES (28721, 20121, 4);
INSERT INTO 'dancesstepsmap' VALUES (28722, 15429, 1);
INSERT INTO 'dancesstepsmap' VALUES (28723, 15429, 3);
INSERT INTO 'dancesstepsmap' VALUES (28724, 15591, 1);
INSERT INTO 'dancesstepsmap' VALUES (28725, 15591, 2);
INSERT INTO 'dancesstepsmap' VALUES (28726, 15591, 3);
INSERT INTO 'dancesstepsmap' VALUES (28727, 15592, 2);
INSERT INTO 'dancesstepsmap' VALUES (28728, 15592, 3);
INSERT INTO 'dancesstepsmap' VALUES (28729, 15593, 2);
INSERT INTO 'dancesstepsmap' VALUES (28730, 15593, 1);
INSERT INTO 'dancesstepsmap' VALUES (28731, 3041, 5);
INSERT INTO 'dancesstepsmap' VALUES (28732, 15594, 4);
INSERT INTO 'dancesstepsmap' VALUES (28733, 15594, 5);
INSERT INTO 'dancesstepsmap' VALUES (28734, 15595, 1);
INSERT INTO 'dancesstepsmap' VALUES (28735, 15595, 3);
INSERT INTO 'dancesstepsmap' VALUES (28736, 15596, 1);
INSERT INTO 'dancesstepsmap' VALUES (28737, 15596, 2);
INSERT INTO 'dancesstepsmap' VALUES (28738, 20131, 4);
INSERT INTO 'dancesstepsmap' VALUES (28739, 3146, 3);
INSERT INTO 'dancesstepsmap' VALUES (28740, 15604, 1);
INSERT INTO 'dancesstepsmap' VALUES (28741, 15610, 4);
INSERT INTO 'dancesstepsmap' VALUES (28742, 3183, 3);
INSERT INTO 'dancesstepsmap' VALUES (28743, 15611, 1);
INSERT INTO 'dancesstepsmap' VALUES (28744, 15612, 4);
INSERT INTO 'dancesstepsmap' VALUES (28745, 15612, 5);
INSERT INTO 'dancesstepsmap' VALUES (28746, 15614, 2);
INSERT INTO 'dancesstepsmap' VALUES (28747, 15614, 1);
INSERT INTO 'dancesstepsmap' VALUES (28748, 15615, 4);
INSERT INTO 'dancesstepsmap' VALUES (28749, 15615, 5);
INSERT INTO 'dancesstepsmap' VALUES (28750, 15616, 1);
INSERT INTO 'dancesstepsmap' VALUES (28751, 15617, 3);
INSERT INTO 'dancesstepsmap' VALUES (28752, 15617, 1);
INSERT INTO 'dancesstepsmap' VALUES (28753, 15626, 4);
INSERT INTO 'dancesstepsmap' VALUES (28754, 15627, 5);
INSERT INTO 'dancesstepsmap' VALUES (28755, 15627, 4);
INSERT INTO 'dancesstepsmap' VALUES (28756, 15636, 5);
INSERT INTO 'dancesstepsmap' VALUES (28757, 15636, 4);
INSERT INTO 'dancesstepsmap' VALUES (28758, 15636, 2);
INSERT INTO 'dancesstepsmap' VALUES (28759, 15636, 1);
INSERT INTO 'dancesstepsmap' VALUES (28760, 15636, 3);
INSERT INTO 'dancesstepsmap' VALUES (28761, 15639, 1);
INSERT INTO 'dancesstepsmap' VALUES (28762, 15639, 2);
INSERT INTO 'dancesstepsmap' VALUES (28763, 15640, 1);
INSERT INTO 'dancesstepsmap' VALUES (28764, 15640, 2);
INSERT INTO 'dancesstepsmap' VALUES (28765, 15641, 4);
INSERT INTO 'dancesstepsmap' VALUES (28766, 15641, 5);
INSERT INTO 'dancesstepsmap' VALUES (28767, 15642, 1);
INSERT INTO 'dancesstepsmap' VALUES (28768, 15642, 2);
INSERT INTO 'dancesstepsmap' VALUES (28769, 15642, 3);
INSERT INTO 'dancesstepsmap' VALUES (28770, 15643, 4);
INSERT INTO 'dancesstepsmap' VALUES (28771, 15644, 2);
INSERT INTO 'dancesstepsmap' VALUES (28772, 15644, 1);
INSERT INTO 'dancesstepsmap' VALUES (28773, 15644, 3);
INSERT INTO 'dancesstepsmap' VALUES (28774, 15647, 2);
INSERT INTO 'dancesstepsmap' VALUES (28775, 15647, 1);
INSERT INTO 'dancesstepsmap' VALUES (28776, 15647, 3);
INSERT INTO 'dancesstepsmap' VALUES (28777, 15648, 1);
INSERT INTO 'dancesstepsmap' VALUES (28778, 15648, 2);
INSERT INTO 'dancesstepsmap' VALUES (28779, 15648, 3);
INSERT INTO 'dancesstepsmap' VALUES (28780, 4384, 2);
INSERT INTO 'dancesstepsmap' VALUES (28781, 15650, 2);
INSERT INTO 'dancesstepsmap' VALUES (28782, 15650, 1);
INSERT INTO 'dancesstepsmap' VALUES (28783, 15661, 2);
INSERT INTO 'dancesstepsmap' VALUES (28784, 15661, 1);
INSERT INTO 'dancesstepsmap' VALUES (28785, 15663, 1);
INSERT INTO 'dancesstepsmap' VALUES (28786, 15663, 2);
INSERT INTO 'dancesstepsmap' VALUES (28787, 15666, 3);
INSERT INTO 'dancesstepsmap' VALUES (28788, 15666, 1);
INSERT INTO 'dancesstepsmap' VALUES (28789, 15666, 2);
INSERT INTO 'dancesstepsmap' VALUES (28790, 15667, 5);
INSERT INTO 'dancesstepsmap' VALUES (28791, 15667, 4);
INSERT INTO 'dancesstepsmap' VALUES (28792, 12397, 2);
INSERT INTO 'dancesstepsmap' VALUES (28793, 12397, 1);
INSERT INTO 'dancesstepsmap' VALUES (28794, 2510, 2);
INSERT INTO 'dancesstepsmap' VALUES (28795, 583, 5);
INSERT INTO 'dancesstepsmap' VALUES (28796, 5243, 2);
INSERT INTO 'dancesstepsmap' VALUES (28797, 11746, 2);
INSERT INTO 'dancesstepsmap' VALUES (28798, 11746, 1);
INSERT INTO 'dancesstepsmap' VALUES (28799, 15690, 1);
INSERT INTO 'dancesstepsmap' VALUES (28800, 15690, 2);
INSERT INTO 'dancesstepsmap' VALUES (28801, 15695, 4);
INSERT INTO 'dancesstepsmap' VALUES (28802, 15695, 5);
INSERT INTO 'dancesstepsmap' VALUES (28803, 15699, 1);
INSERT INTO 'dancesstepsmap' VALUES (28804, 15699, 2);
INSERT INTO 'dancesstepsmap' VALUES (28805, 15700, 5);
INSERT INTO 'dancesstepsmap' VALUES (28806, 15700, 4);
INSERT INTO 'dancesstepsmap' VALUES (28807, 16070, 3);
INSERT INTO 'dancesstepsmap' VALUES (28808, 16218, 2);
INSERT INTO 'dancesstepsmap' VALUES (28809, 16218, 1);
INSERT INTO 'dancesstepsmap' VALUES (28810, 16219, 5);
INSERT INTO 'dancesstepsmap' VALUES (28811, 16219, 4);
INSERT INTO 'dancesstepsmap' VALUES (28812, 16219, 2);
INSERT INTO 'dancesstepsmap' VALUES (28813, 16219, 1);
INSERT INTO 'dancesstepsmap' VALUES (28814, 16219, 3);
INSERT INTO 'dancesstepsmap' VALUES (28815, 16220, 3);
INSERT INTO 'dancesstepsmap' VALUES (28816, 16558, 2);
INSERT INTO 'dancesstepsmap' VALUES (28817, 16558, 1);
INSERT INTO 'dancesstepsmap' VALUES (28818, 16625, 1);
INSERT INTO 'dancesstepsmap' VALUES (28819, 16626, 2);
INSERT INTO 'dancesstepsmap' VALUES (28820, 16626, 1);
INSERT INTO 'dancesstepsmap' VALUES (28821, 16626, 3);
INSERT INTO 'dancesstepsmap' VALUES (28822, 16663, 1);
INSERT INTO 'dancesstepsmap' VALUES (28823, 16663, 2);
INSERT INTO 'dancesstepsmap' VALUES (28824, 16663, 3);
INSERT INTO 'dancesstepsmap' VALUES (28825, 16700, 3);
INSERT INTO 'dancesstepsmap' VALUES (28826, 20120, 1);
INSERT INTO 'dancesstepsmap' VALUES (28827, 20120, 2);
INSERT INTO 'dancesstepsmap' VALUES (28828, 20120, 3);
INSERT INTO 'dancesstepsmap' VALUES (28829, 16762, 2);
INSERT INTO 'dancesstepsmap' VALUES (28830, 16768, 1);
INSERT INTO 'dancesstepsmap' VALUES (28831, 16768, 8);
INSERT INTO 'dancesstepsmap' VALUES (28832, 16770, 4);
INSERT INTO 'dancesstepsmap' VALUES (28833, 16777, 1);
INSERT INTO 'dancesstepsmap' VALUES (28834, 16777, 2);
INSERT INTO 'dancesstepsmap' VALUES (28835, 16779, 1);
INSERT INTO 'dancesstepsmap' VALUES (28836, 16779, 2);
INSERT INTO 'dancesstepsmap' VALUES (28837, 16782, 4);
INSERT INTO 'dancesstepsmap' VALUES (28838, 16782, 5);
INSERT INTO 'dancesstepsmap' VALUES (28839, 16784, 1);
INSERT INTO 'dancesstepsmap' VALUES (28840, 16784, 2);
INSERT INTO 'dancesstepsmap' VALUES (28841, 16784, 3);
INSERT INTO 'dancesstepsmap' VALUES (28842, 16830, 1);
INSERT INTO 'dancesstepsmap' VALUES (28843, 16830, 2);
INSERT INTO 'dancesstepsmap' VALUES (28844, 16831, 1);
INSERT INTO 'dancesstepsmap' VALUES (28845, 16831, 2);
INSERT INTO 'dancesstepsmap' VALUES (28846, 18353, 3);
INSERT INTO 'dancesstepsmap' VALUES (28847, 16833, 1);
INSERT INTO 'dancesstepsmap' VALUES (28848, 16833, 3);
INSERT INTO 'dancesstepsmap' VALUES (28849, 16865, 4);
INSERT INTO 'dancesstepsmap' VALUES (28850, 16867, 1);
INSERT INTO 'dancesstepsmap' VALUES (28851, 16877, 5);
INSERT INTO 'dancesstepsmap' VALUES (28852, 16877, 4);
INSERT INTO 'dancesstepsmap' VALUES (28853, 16881, 2);
INSERT INTO 'dancesstepsmap' VALUES (28854, 16881, 1);
INSERT INTO 'dancesstepsmap' VALUES (28855, 16883, 2);
INSERT INTO 'dancesstepsmap' VALUES (28856, 16883, 1);
INSERT INTO 'dancesstepsmap' VALUES (28857, 16883, 3);
INSERT INTO 'dancesstepsmap' VALUES (28858, 16953, 1);
INSERT INTO 'dancesstepsmap' VALUES (28859, 16953, 2);
INSERT INTO 'dancesstepsmap' VALUES (28860, 16953, 3);
INSERT INTO 'dancesstepsmap' VALUES (28861, 5772, 2);
INSERT INTO 'dancesstepsmap' VALUES (28862, 17027, 1);
INSERT INTO 'dancesstepsmap' VALUES (21625, 17049, 4);
INSERT INTO 'dancesstepsmap' VALUES (28863, 1768, 5);
INSERT INTO 'dancesstepsmap' VALUES (28864, 17072, 2);
INSERT INTO 'dancesstepsmap' VALUES (28865, 17072, 1);
INSERT INTO 'dancesstepsmap' VALUES (28866, 17073, 2);
INSERT INTO 'dancesstepsmap' VALUES (28867, 17073, 1);
INSERT INTO 'dancesstepsmap' VALUES (28868, 17073, 3);
INSERT INTO 'dancesstepsmap' VALUES (28869, 17074, 1);
INSERT INTO 'dancesstepsmap' VALUES (28870, 17074, 3);
INSERT INTO 'dancesstepsmap' VALUES (28871, 17076, 2);
INSERT INTO 'dancesstepsmap' VALUES (28872, 17076, 1);
INSERT INTO 'dancesstepsmap' VALUES (28873, 17076, 3);
INSERT INTO 'dancesstepsmap' VALUES (28874, 17091, 1);
INSERT INTO 'dancesstepsmap' VALUES (28875, 17091, 2);
INSERT INTO 'dancesstepsmap' VALUES (28876, 17131, 5);
INSERT INTO 'dancesstepsmap' VALUES (28877, 3596, 2);
INSERT INTO 'dancesstepsmap' VALUES (28878, 3596, 3);
INSERT INTO 'dancesstepsmap' VALUES (28879, 3507, 3);
INSERT INTO 'dancesstepsmap' VALUES (28880, 3371, 2);
INSERT INTO 'dancesstepsmap' VALUES (28881, 2108, 2);
INSERT INTO 'dancesstepsmap' VALUES (28882, 2945, 2);
INSERT INTO 'dancesstepsmap' VALUES (28883, 2945, 3);
INSERT INTO 'dancesstepsmap' VALUES (28884, 9293, 4);
INSERT INTO 'dancesstepsmap' VALUES (28885, 9293, 5);
INSERT INTO 'dancesstepsmap' VALUES (28886, 3012, 2);
INSERT INTO 'dancesstepsmap' VALUES (28887, 17084, 1);
INSERT INTO 'dancesstepsmap' VALUES (28888, 17084, 3);
INSERT INTO 'dancesstepsmap' VALUES (28889, 17084, 2);
INSERT INTO 'dancesstepsmap' VALUES (28890, 20133, 4);
INSERT INTO 'dancesstepsmap' VALUES (28891, 20133, 2);
INSERT INTO 'dancesstepsmap' VALUES (28892, 20133, 1);
INSERT INTO 'dancesstepsmap' VALUES (28893, 17134, 4);
INSERT INTO 'dancesstepsmap' VALUES (28894, 17136, 2);
INSERT INTO 'dancesstepsmap' VALUES (28895, 17140, 3);
INSERT INTO 'dancesstepsmap' VALUES (28896, 17145, 2);
INSERT INTO 'dancesstepsmap' VALUES (28897, 17145, 3);
INSERT INTO 'dancesstepsmap' VALUES (28898, 17146, 1);
INSERT INTO 'dancesstepsmap' VALUES (28899, 17146, 2);
INSERT INTO 'dancesstepsmap' VALUES (28902, 17148, 2);
INSERT INTO 'dancesstepsmap' VALUES (28903, 17148, 1);
INSERT INTO 'dancesstepsmap' VALUES (28904, 17149, 5);
INSERT INTO 'dancesstepsmap' VALUES (28905, 17149, 4);
INSERT INTO 'dancesstepsmap' VALUES (28906, 5391, 2);
INSERT INTO 'dancesstepsmap' VALUES (28907, 9369, 1);
INSERT INTO 'dancesstepsmap' VALUES (28909, 17175, 2);
INSERT INTO 'dancesstepsmap' VALUES (28910, 17175, 1);
INSERT INTO 'dancesstepsmap' VALUES (28911, 17180, 5);
INSERT INTO 'dancesstepsmap' VALUES (28912, 17180, 4);
INSERT INTO 'dancesstepsmap' VALUES (28913, 17181, 1);
INSERT INTO 'dancesstepsmap' VALUES (28914, 17181, 3);
INSERT INTO 'dancesstepsmap' VALUES (28915, 17185, 1);
INSERT INTO 'dancesstepsmap' VALUES (28916, 17185, 2);
INSERT INTO 'dancesstepsmap' VALUES (28917, 17185, 3);
INSERT INTO 'dancesstepsmap' VALUES (28918, 17187, 1);
INSERT INTO 'dancesstepsmap' VALUES (28919, 17187, 3);
INSERT INTO 'dancesstepsmap' VALUES (28920, 20134, 2);
INSERT INTO 'dancesstepsmap' VALUES (28921, 20134, 1);
INSERT INTO 'dancesstepsmap' VALUES (28922, 17208, 2);
INSERT INTO 'dancesstepsmap' VALUES (28923, 17208, 1);
INSERT INTO 'dancesstepsmap' VALUES (28924, 17211, 2);
INSERT INTO 'dancesstepsmap' VALUES (28925, 17211, 1);
INSERT INTO 'dancesstepsmap' VALUES (28926, 20135, 2);
INSERT INTO 'dancesstepsmap' VALUES (28927, 20135, 1);
INSERT INTO 'dancesstepsmap' VALUES (28928, 20136, 1);
INSERT INTO 'dancesstepsmap' VALUES (28929, 20136, 2);
INSERT INTO 'dancesstepsmap' VALUES (28930, 17218, 2);
INSERT INTO 'dancesstepsmap' VALUES (28931, 17218, 1);
INSERT INTO 'dancesstepsmap' VALUES (28932, 17221, 1);
INSERT INTO 'dancesstepsmap' VALUES (28933, 17221, 2);
INSERT INTO 'dancesstepsmap' VALUES (28934, 17228, 2);
INSERT INTO 'dancesstepsmap' VALUES (28935, 17228, 1);
INSERT INTO 'dancesstepsmap' VALUES (28936, 17229, 1);
INSERT INTO 'dancesstepsmap' VALUES (28937, 17229, 2);
INSERT INTO 'dancesstepsmap' VALUES (28938, 17231, 1);
INSERT INTO 'dancesstepsmap' VALUES (28939, 17231, 3);
INSERT INTO 'dancesstepsmap' VALUES (28940, 17232, 1);
INSERT INTO 'dancesstepsmap' VALUES (28941, 17234, 4);
INSERT INTO 'dancesstepsmap' VALUES (28942, 17234, 5);
INSERT INTO 'dancesstepsmap' VALUES (28943, 17235, 4);
INSERT INTO 'dancesstepsmap' VALUES (28944, 17235, 5);
INSERT INTO 'dancesstepsmap' VALUES (28945, 17237, 1);
INSERT INTO 'dancesstepsmap' VALUES (28946, 17238, 4);
INSERT INTO 'dancesstepsmap' VALUES (28947, 17238, 5);
INSERT INTO 'dancesstepsmap' VALUES (28948, 17239, 2);
INSERT INTO 'dancesstepsmap' VALUES (28949, 17239, 1);
INSERT INTO 'dancesstepsmap' VALUES (28950, 17260, 4);
INSERT INTO 'dancesstepsmap' VALUES (28951, 17260, 5);
INSERT INTO 'dancesstepsmap' VALUES (28952, 17261, 2);
INSERT INTO 'dancesstepsmap' VALUES (28953, 17261, 1);
INSERT INTO 'dancesstepsmap' VALUES (28954, 17261, 3);
INSERT INTO 'dancesstepsmap' VALUES (28955, 17266, 2);
INSERT INTO 'dancesstepsmap' VALUES (28956, 17266, 1);
INSERT INTO 'dancesstepsmap' VALUES (28957, 17267, 4);
INSERT INTO 'dancesstepsmap' VALUES (28958, 17268, 1);
INSERT INTO 'dancesstepsmap' VALUES (28959, 17269, 4);
INSERT INTO 'dancesstepsmap' VALUES (28960, 17269, 5);
INSERT INTO 'dancesstepsmap' VALUES (28961, 17270, 2);
INSERT INTO 'dancesstepsmap' VALUES (28962, 17270, 1);
INSERT INTO 'dancesstepsmap' VALUES (28963, 17271, 1);
INSERT INTO 'dancesstepsmap' VALUES (28964, 17272, 1);
INSERT INTO 'dancesstepsmap' VALUES (28965, 17273, 1);
INSERT INTO 'dancesstepsmap' VALUES (28966, 17274, 4);
INSERT INTO 'dancesstepsmap' VALUES (28967, 17275, 4);
INSERT INTO 'dancesstepsmap' VALUES (28968, 17276, 1);
INSERT INTO 'dancesstepsmap' VALUES (28969, 17305, 5);
INSERT INTO 'dancesstepsmap' VALUES (28970, 17305, 4);
INSERT INTO 'dancesstepsmap' VALUES (28971, 17306, 3);
INSERT INTO 'dancesstepsmap' VALUES (28972, 17306, 1);
INSERT INTO 'dancesstepsmap' VALUES (28973, 17306, 2);
INSERT INTO 'dancesstepsmap' VALUES (28974, 17308, 4);
INSERT INTO 'dancesstepsmap' VALUES (28975, 17308, 5);
INSERT INTO 'dancesstepsmap' VALUES (28976, 17312, 1);
INSERT INTO 'dancesstepsmap' VALUES (28977, 17312, 2);
INSERT INTO 'dancesstepsmap' VALUES (28978, 17313, 4);
INSERT INTO 'dancesstepsmap' VALUES (28979, 17313, 5);
INSERT INTO 'dancesstepsmap' VALUES (28980, 17313, 1);
INSERT INTO 'dancesstepsmap' VALUES (28981, 17313, 2);
INSERT INTO 'dancesstepsmap' VALUES (28982, 17315, 4);
INSERT INTO 'dancesstepsmap' VALUES (28983, 17315, 5);
INSERT INTO 'dancesstepsmap' VALUES (28984, 17326, 4);
INSERT INTO 'dancesstepsmap' VALUES (28985, 17326, 5);
INSERT INTO 'dancesstepsmap' VALUES (28986, 17372, 2);
INSERT INTO 'dancesstepsmap' VALUES (28987, 17372, 1);
INSERT INTO 'dancesstepsmap' VALUES (28988, 3333, 5);
INSERT INTO 'dancesstepsmap' VALUES (28989, 17403, 4);
INSERT INTO 'dancesstepsmap' VALUES (28990, 17403, 5);
INSERT INTO 'dancesstepsmap' VALUES (28991, 17407, 1);
INSERT INTO 'dancesstepsmap' VALUES (28992, 17407, 2);
INSERT INTO 'dancesstepsmap' VALUES (28993, 17407, 3);
INSERT INTO 'dancesstepsmap' VALUES (28994, 17408, 2);
INSERT INTO 'dancesstepsmap' VALUES (28995, 17408, 1);
INSERT INTO 'dancesstepsmap' VALUES (28996, 17408, 3);
INSERT INTO 'dancesstepsmap' VALUES (28997, 17428, 2);
INSERT INTO 'dancesstepsmap' VALUES (28998, 17428, 1);
INSERT INTO 'dancesstepsmap' VALUES (28999, 17428, 3);
INSERT INTO 'dancesstepsmap' VALUES (29000, 17435, 4);
INSERT INTO 'dancesstepsmap' VALUES (29001, 17435, 5);
INSERT INTO 'dancesstepsmap' VALUES (29002, 17442, 3);
INSERT INTO 'dancesstepsmap' VALUES (29003, 17442, 1);
INSERT INTO 'dancesstepsmap' VALUES (29004, 17443, 4);
INSERT INTO 'dancesstepsmap' VALUES (29005, 17443, 5);
INSERT INTO 'dancesstepsmap' VALUES (29006, 17444, 5);
INSERT INTO 'dancesstepsmap' VALUES (29007, 17444, 4);
INSERT INTO 'dancesstepsmap' VALUES (29008, 17445, 1);
INSERT INTO 'dancesstepsmap' VALUES (29009, 17445, 3);
INSERT INTO 'dancesstepsmap' VALUES (29010, 17453, 1);
INSERT INTO 'dancesstepsmap' VALUES (29011, 17453, 2);
INSERT INTO 'dancesstepsmap' VALUES (29012, 17466, 5);
INSERT INTO 'dancesstepsmap' VALUES (29013, 17466, 4);
INSERT INTO 'dancesstepsmap' VALUES (29014, 6186, 2);
INSERT INTO 'dancesstepsmap' VALUES (29015, 14218, 4);
INSERT INTO 'dancesstepsmap' VALUES (29016, 17474, 2);
INSERT INTO 'dancesstepsmap' VALUES (29017, 17474, 1);
INSERT INTO 'dancesstepsmap' VALUES (29018, 17475, 4);
INSERT INTO 'dancesstepsmap' VALUES (29019, 17475, 5);
INSERT INTO 'dancesstepsmap' VALUES (29020, 17476, 1);
INSERT INTO 'dancesstepsmap' VALUES (29021, 17477, 1);
INSERT INTO 'dancesstepsmap' VALUES (29022, 17477, 2);
INSERT INTO 'dancesstepsmap' VALUES (29023, 17478, 4);
INSERT INTO 'dancesstepsmap' VALUES (29024, 17478, 5);
INSERT INTO 'dancesstepsmap' VALUES (29025, 17487, 1);
INSERT INTO 'dancesstepsmap' VALUES (29026, 17487, 2);
INSERT INTO 'dancesstepsmap' VALUES (29027, 17499, 1);
INSERT INTO 'dancesstepsmap' VALUES (29028, 17499, 2);
INSERT INTO 'dancesstepsmap' VALUES (29029, 4083, 5);
INSERT INTO 'dancesstepsmap' VALUES (29030, 17505, 2);
INSERT INTO 'dancesstepsmap' VALUES (29031, 17505, 1);
INSERT INTO 'dancesstepsmap' VALUES (29032, 17505, 3);
INSERT INTO 'dancesstepsmap' VALUES (29033, 17506, 5);
INSERT INTO 'dancesstepsmap' VALUES (29034, 17506, 4);
INSERT INTO 'dancesstepsmap' VALUES (29035, 17563, 2);
INSERT INTO 'dancesstepsmap' VALUES (29036, 17563, 1);
INSERT INTO 'dancesstepsmap' VALUES (29037, 20137, 4);
INSERT INTO 'dancesstepsmap' VALUES (29038, 20138, 4);
INSERT INTO 'dancesstepsmap' VALUES (29039, 20138, 5);
INSERT INTO 'dancesstepsmap' VALUES (29040, 7067, 5);
INSERT INTO 'dancesstepsmap' VALUES (29041, 1190, 2);
INSERT INTO 'dancesstepsmap' VALUES (29044, 17595, 2);
INSERT INTO 'dancesstepsmap' VALUES (29045, 17595, 1);
INSERT INTO 'dancesstepsmap' VALUES (29046, 17595, 3);
INSERT INTO 'dancesstepsmap' VALUES (29047, 17598, 2);
INSERT INTO 'dancesstepsmap' VALUES (29048, 17598, 1);
INSERT INTO 'dancesstepsmap' VALUES (29049, 17598, 3);
INSERT INTO 'dancesstepsmap' VALUES (29050, 3321, 2);
INSERT INTO 'dancesstepsmap' VALUES (29051, 3321, 3);
INSERT INTO 'dancesstepsmap' VALUES (29052, 6784, 102);
INSERT INTO 'dancesstepsmap' VALUES (29053, 6784, 2);
INSERT INTO 'dancesstepsmap' VALUES (29054, 4240, 5);
INSERT INTO 'dancesstepsmap' VALUES (29055, 1420, 2);
INSERT INTO 'dancesstepsmap' VALUES (29056, 1420, 3);
INSERT INTO 'dancesstepsmap' VALUES (29057, 17600, 1);
INSERT INTO 'dancesstepsmap' VALUES (29058, 17600, 3);
INSERT INTO 'dancesstepsmap' VALUES (29059, 17601, 1);
INSERT INTO 'dancesstepsmap' VALUES (29060, 17601, 2);
INSERT INTO 'dancesstepsmap' VALUES (29061, 17603, 1);
INSERT INTO 'dancesstepsmap' VALUES (29062, 17603, 3);
INSERT INTO 'dancesstepsmap' VALUES (29063, 17606, 1);
INSERT INTO 'dancesstepsmap' VALUES (29064, 17606, 2);
INSERT INTO 'dancesstepsmap' VALUES (29065, 17606, 3);
INSERT INTO 'dancesstepsmap' VALUES (29066, 17607, 5);
INSERT INTO 'dancesstepsmap' VALUES (29067, 17607, 4);
INSERT INTO 'dancesstepsmap' VALUES (29068, 17612, 2);
INSERT INTO 'dancesstepsmap' VALUES (29069, 17612, 1);
INSERT INTO 'dancesstepsmap' VALUES (29070, 17612, 3);
INSERT INTO 'dancesstepsmap' VALUES (29071, 17625, 4);
INSERT INTO 'dancesstepsmap' VALUES (29072, 3619, 5);
INSERT INTO 'dancesstepsmap' VALUES (29073, 3619, 10);
INSERT INTO 'dancesstepsmap' VALUES (29074, 17656, 1);
INSERT INTO 'dancesstepsmap' VALUES (29075, 3793, 2);
INSERT INTO 'dancesstepsmap' VALUES (29076, 3793, 3);
INSERT INTO 'dancesstepsmap' VALUES (29077, 17730, 1);
INSERT INTO 'dancesstepsmap' VALUES (29078, 17730, 2);
INSERT INTO 'dancesstepsmap' VALUES (29079, 17731, 4);
INSERT INTO 'dancesstepsmap' VALUES (29080, 17731, 5);
INSERT INTO 'dancesstepsmap' VALUES (29081, 17733, 2);
INSERT INTO 'dancesstepsmap' VALUES (29082, 17733, 1);
INSERT INTO 'dancesstepsmap' VALUES (29083, 17734, 5);
INSERT INTO 'dancesstepsmap' VALUES (29084, 17734, 4);
INSERT INTO 'dancesstepsmap' VALUES (29085, 17735, 2);
INSERT INTO 'dancesstepsmap' VALUES (29086, 17735, 1);
INSERT INTO 'dancesstepsmap' VALUES (29087, 17774, 1);
INSERT INTO 'dancesstepsmap' VALUES (29088, 17790, 4);
INSERT INTO 'dancesstepsmap' VALUES (29089, 17790, 1);
INSERT INTO 'dancesstepsmap' VALUES (29090, 17790, 3);
INSERT INTO 'dancesstepsmap' VALUES (29091, 10325, 4);
INSERT INTO 'dancesstepsmap' VALUES (29092, 10325, 5);
INSERT INTO 'dancesstepsmap' VALUES (29093, 3721, 2);
INSERT INTO 'dancesstepsmap' VALUES (29094, 3721, 3);
INSERT INTO 'dancesstepsmap' VALUES (29095, 3956, 3);
INSERT INTO 'dancesstepsmap' VALUES (29096, 3966, 6);
INSERT INTO 'dancesstepsmap' VALUES (29097, 4129, 5);
INSERT INTO 'dancesstepsmap' VALUES (29098, 4153, 2);
INSERT INTO 'dancesstepsmap' VALUES (29099, 4153, 3);
INSERT INTO 'dancesstepsmap' VALUES (29100, 4153, 10);
INSERT INTO 'dancesstepsmap' VALUES (29101, 17964, 4);
INSERT INTO 'dancesstepsmap' VALUES (29102, 17964, 5);
INSERT INTO 'dancesstepsmap' VALUES (29103, 17965, 1);
INSERT INTO 'dancesstepsmap' VALUES (29104, 17965, 3);
INSERT INTO 'dancesstepsmap' VALUES (29105, 17968, 4);
INSERT INTO 'dancesstepsmap' VALUES (29106, 17968, 5);
INSERT INTO 'dancesstepsmap' VALUES (29107, 17971, 1);
INSERT INTO 'dancesstepsmap' VALUES (29108, 17971, 2);
INSERT INTO 'dancesstepsmap' VALUES (29109, 17973, 3);
INSERT INTO 'dancesstepsmap' VALUES (29110, 17973, 1);
INSERT INTO 'dancesstepsmap' VALUES (29111, 17973, 2);
INSERT INTO 'dancesstepsmap' VALUES (29112, 17981, 5);
INSERT INTO 'dancesstepsmap' VALUES (29113, 17981, 4);
INSERT INTO 'dancesstepsmap' VALUES (29114, 17986, 1);
INSERT INTO 'dancesstepsmap' VALUES (29115, 4448, 3);
INSERT INTO 'dancesstepsmap' VALUES (29116, 18024, 4);
INSERT INTO 'dancesstepsmap' VALUES (29117, 18024, 6);
INSERT INTO 'dancesstepsmap' VALUES (29118, 18024, 5);
INSERT INTO 'dancesstepsmap' VALUES (29119, 18063, 2);
INSERT INTO 'dancesstepsmap' VALUES (29120, 18136, 5);
INSERT INTO 'dancesstepsmap' VALUES (29121, 18136, 4);
INSERT INTO 'dancesstepsmap' VALUES (29122, 18138, 2);
INSERT INTO 'dancesstepsmap' VALUES (29123, 18138, 1);
INSERT INTO 'dancesstepsmap' VALUES (29124, 18181, 1);
INSERT INTO 'dancesstepsmap' VALUES (29125, 18181, 2);
INSERT INTO 'dancesstepsmap' VALUES (29126, 18181, 4);
INSERT INTO 'dancesstepsmap' VALUES (29127, 18181, 5);
INSERT INTO 'dancesstepsmap' VALUES (29128, 18209, 1);
INSERT INTO 'dancesstepsmap' VALUES (29129, 18209, 2);
INSERT INTO 'dancesstepsmap' VALUES (29130, 18209, 3);
INSERT INTO 'dancesstepsmap' VALUES (29131, 18216, 4);
INSERT INTO 'dancesstepsmap' VALUES (29132, 18216, 5);
INSERT INTO 'dancesstepsmap' VALUES (29133, 18237, 1);
INSERT INTO 'dancesstepsmap' VALUES (29134, 18237, 3);
INSERT INTO 'dancesstepsmap' VALUES (29135, 20141, 3);
INSERT INTO 'dancesstepsmap' VALUES (29136, 20141, 1);
INSERT INTO 'dancesstepsmap' VALUES (29137, 20142, 1);
INSERT INTO 'dancesstepsmap' VALUES (29138, 20143, 1);
INSERT INTO 'dancesstepsmap' VALUES (29139, 20144, 1);
INSERT INTO 'dancesstepsmap' VALUES (29140, 20145, 2);
INSERT INTO 'dancesstepsmap' VALUES (29141, 20145, 1);
INSERT INTO 'dancesstepsmap' VALUES (29142, 20146, 5);
INSERT INTO 'dancesstepsmap' VALUES (29143, 20146, 4);
INSERT INTO 'dancesstepsmap' VALUES (29144, 20147, 4);
INSERT INTO 'dancesstepsmap' VALUES (29145, 20147, 5);
INSERT INTO 'dancesstepsmap' VALUES (29146, 18342, 1);
INSERT INTO 'dancesstepsmap' VALUES (29147, 18342, 3);
INSERT INTO 'dancesstepsmap' VALUES (29148, 18342, 2);
INSERT INTO 'dancesstepsmap' VALUES (29149, 18445, 5);
INSERT INTO 'dancesstepsmap' VALUES (29150, 18445, 4);
INSERT INTO 'dancesstepsmap' VALUES (29151, 18498, 5);
INSERT INTO 'dancesstepsmap' VALUES (29152, 18498, 4);
INSERT INTO 'dancesstepsmap' VALUES (29153, 18499, 1);
INSERT INTO 'dancesstepsmap' VALUES (29154, 18499, 2);
INSERT INTO 'dancesstepsmap' VALUES (29155, 18402, 4);
INSERT INTO 'dancesstepsmap' VALUES (29156, 18402, 5);
INSERT INTO 'dancesstepsmap' VALUES (29157, 20148, 1);
INSERT INTO 'dancesstepsmap' VALUES (29158, 20148, 2);
INSERT INTO 'dancesstepsmap' VALUES (29159, 20148, 3);
INSERT INTO 'dancesstepsmap' VALUES (29160, 18500, 1);
INSERT INTO 'dancesstepsmap' VALUES (29161, 18500, 3);
INSERT INTO 'dancesstepsmap' VALUES (29162, 18500, 2);
INSERT INTO 'dancesstepsmap' VALUES (29163, 18501, 1);
INSERT INTO 'dancesstepsmap' VALUES (29164, 18502, 1);
INSERT INTO 'dancesstepsmap' VALUES (29165, 18502, 2);
INSERT INTO 'dancesstepsmap' VALUES (29166, 18504, 1);
INSERT INTO 'dancesstepsmap' VALUES (29167, 18504, 3);
INSERT INTO 'dancesstepsmap' VALUES (29168, 18505, 4);
INSERT INTO 'dancesstepsmap' VALUES (29169, 18505, 9);
INSERT INTO 'dancesstepsmap' VALUES (29170, 18506, 1);
INSERT INTO 'dancesstepsmap' VALUES (29171, 18506, 2);
INSERT INTO 'dancesstepsmap' VALUES (29172, 18506, 3);
INSERT INTO 'dancesstepsmap' VALUES (29173, 18572, 2);
INSERT INTO 'dancesstepsmap' VALUES (29174, 18572, 1);
INSERT INTO 'dancesstepsmap' VALUES (29175, 18575, 3);
INSERT INTO 'dancesstepsmap' VALUES (29176, 18575, 1);
INSERT INTO 'dancesstepsmap' VALUES (29177, 18586, 1);
INSERT INTO 'dancesstepsmap' VALUES (29178, 18586, 3);
INSERT INTO 'dancesstepsmap' VALUES (29179, 18590, 1);
INSERT INTO 'dancesstepsmap' VALUES (29180, 18590, 2);
INSERT INTO 'dancesstepsmap' VALUES (29181, 18592, 2);
INSERT INTO 'dancesstepsmap' VALUES (29182, 18592, 1);
INSERT INTO 'dancesstepsmap' VALUES (29183, 18593, 1);
INSERT INTO 'dancesstepsmap' VALUES (29184, 18593, 2);
INSERT INTO 'dancesstepsmap' VALUES (29185, 18614, 1);
INSERT INTO 'dancesstepsmap' VALUES (29186, 18614, 3);
INSERT INTO 'dancesstepsmap' VALUES (29187, 18614, 2);
INSERT INTO 'dancesstepsmap' VALUES (29188, 18616, 1);
INSERT INTO 'dancesstepsmap' VALUES (29189, 18616, 2);
INSERT INTO 'dancesstepsmap' VALUES (29190, 18615, 2);
INSERT INTO 'dancesstepsmap' VALUES (29191, 18615, 1);
INSERT INTO 'dancesstepsmap' VALUES (29192, 18615, 3);
INSERT INTO 'dancesstepsmap' VALUES (29193, 18619, 1);
INSERT INTO 'dancesstepsmap' VALUES (29194, 18619, 2);
INSERT INTO 'dancesstepsmap' VALUES (29195, 18621, 2);
INSERT INTO 'dancesstepsmap' VALUES (29196, 18621, 1);
INSERT INTO 'dancesstepsmap' VALUES (29197, 18654, 2);
INSERT INTO 'dancesstepsmap' VALUES (29198, 18654, 1);
INSERT INTO 'dancesstepsmap' VALUES (29199, 18667, 4);
INSERT INTO 'dancesstepsmap' VALUES (29200, 18667, 5);
INSERT INTO 'dancesstepsmap' VALUES (29201, 18667, 1);
INSERT INTO 'dancesstepsmap' VALUES (29202, 18667, 2);
INSERT INTO 'dancesstepsmap' VALUES (29203, 18667, 3);
INSERT INTO 'dancesstepsmap' VALUES (29204, 18943, 2);
INSERT INTO 'dancesstepsmap' VALUES (29205, 18943, 1);
INSERT INTO 'dancesstepsmap' VALUES (29206, 18944, 4);
INSERT INTO 'dancesstepsmap' VALUES (29207, 18945, 1);
INSERT INTO 'dancesstepsmap' VALUES (29208, 18945, 2);
INSERT INTO 'dancesstepsmap' VALUES (29209, 18947, 4);
INSERT INTO 'dancesstepsmap' VALUES (29210, 18947, 5);
INSERT INTO 'dancesstepsmap' VALUES (29211, 18949, 1);
INSERT INTO 'dancesstepsmap' VALUES (29212, 18949, 2);
INSERT INTO 'dancesstepsmap' VALUES (29213, 18949, 3);
INSERT INTO 'dancesstepsmap' VALUES (29214, 18950, 1);
INSERT INTO 'dancesstepsmap' VALUES (29215, 18955, 5);
INSERT INTO 'dancesstepsmap' VALUES (29216, 18955, 4);
INSERT INTO 'dancesstepsmap' VALUES (29217, 18959, 4);
INSERT INTO 'dancesstepsmap' VALUES (29218, 18959, 5);
INSERT INTO 'dancesstepsmap' VALUES (29219, 18961, 4);
INSERT INTO 'dancesstepsmap' VALUES (29220, 18961, 5);
INSERT INTO 'dancesstepsmap' VALUES (29221, 18962, 1);
INSERT INTO 'dancesstepsmap' VALUES (29222, 18964, 1);
INSERT INTO 'dancesstepsmap' VALUES (29223, 18964, 2);
INSERT INTO 'dancesstepsmap' VALUES (29224, 4457, 2);
INSERT INTO 'dancesstepsmap' VALUES (29225, 4457, 3);
INSERT INTO 'dancesstepsmap' VALUES (29226, 19138, 5);
INSERT INTO 'dancesstepsmap' VALUES (29227, 19138, 4);
INSERT INTO 'dancesstepsmap' VALUES (29228, 19139, 1);
INSERT INTO 'dancesstepsmap' VALUES (29229, 19139, 2);
INSERT INTO 'dancesstepsmap' VALUES (29230, 19140, 4);
INSERT INTO 'dancesstepsmap' VALUES (29231, 19220, 3);
INSERT INTO 'dancesstepsmap' VALUES (29232, 19220, 1);
INSERT INTO 'dancesstepsmap' VALUES (29233, 19220, 2);
INSERT INTO 'dancesstepsmap' VALUES (29234, 4530, 2);
INSERT INTO 'dancesstepsmap' VALUES (29235, 4160, 5);
INSERT INTO 'dancesstepsmap' VALUES (29236, 4545, 2);
INSERT INTO 'dancesstepsmap' VALUES (29237, 19238, 5);
INSERT INTO 'dancesstepsmap' VALUES (29238, 19238, 4);
INSERT INTO 'dancesstepsmap' VALUES (29239, 19328, 1);
INSERT INTO 'dancesstepsmap' VALUES (29240, 19328, 2);
INSERT INTO 'dancesstepsmap' VALUES (29241, 19424, 2);
INSERT INTO 'dancesstepsmap' VALUES (29242, 19424, 1);
INSERT INTO 'dancesstepsmap' VALUES (29243, 19425, 3);
INSERT INTO 'dancesstepsmap' VALUES (29244, 19425, 1);
INSERT INTO 'dancesstepsmap' VALUES (29245, 19425, 2);
INSERT INTO 'dancesstepsmap' VALUES (29246, 19579, 1);
INSERT INTO 'dancesstepsmap' VALUES (29247, 19579, 3);
INSERT INTO 'dancesstepsmap' VALUES (29248, 19580, 3);
INSERT INTO 'dancesstepsmap' VALUES (29249, 19580, 1);
INSERT INTO 'dancesstepsmap' VALUES (29250, 19583, 3);
INSERT INTO 'dancesstepsmap' VALUES (29251, 19583, 1);
INSERT INTO 'dancesstepsmap' VALUES (29252, 19583, 2);
INSERT INTO 'dancesstepsmap' VALUES (29253, 19586, 2);
INSERT INTO 'dancesstepsmap' VALUES (29254, 19586, 1);
INSERT INTO 'dancesstepsmap' VALUES (29255, 19591, 1);
INSERT INTO 'dancesstepsmap' VALUES (29258, 19605, 2);
INSERT INTO 'dancesstepsmap' VALUES (29259, 19605, 1);
INSERT INTO 'dancesstepsmap' VALUES (29260, 19608, 2);
INSERT INTO 'dancesstepsmap' VALUES (29261, 19608, 1);
INSERT INTO 'dancesstepsmap' VALUES (29262, 19616, 1);
INSERT INTO 'dancesstepsmap' VALUES (29263, 19616, 2);
INSERT INTO 'dancesstepsmap' VALUES (29264, 19616, 3);
INSERT INTO 'dancesstepsmap' VALUES (29265, 19619, 4);
INSERT INTO 'dancesstepsmap' VALUES (29266, 19619, 5);
INSERT INTO 'dancesstepsmap' VALUES (29267, 19625, 2);
INSERT INTO 'dancesstepsmap' VALUES (29268, 19625, 1);
INSERT INTO 'dancesstepsmap' VALUES (29269, 19628, 1);
INSERT INTO 'dancesstepsmap' VALUES (29270, 17872, 4);
INSERT INTO 'dancesstepsmap' VALUES (29271, 17872, 5);
INSERT INTO 'dancesstepsmap' VALUES (29272, 17872, 1);
INSERT INTO 'dancesstepsmap' VALUES (29273, 17872, 2);
INSERT INTO 'dancesstepsmap' VALUES (29274, 19816, 1);
INSERT INTO 'dancesstepsmap' VALUES (29275, 19816, 3);
INSERT INTO 'dancesstepsmap' VALUES (29276, 19872, 5);
INSERT INTO 'dancesstepsmap' VALUES (29277, 19872, 4);
INSERT INTO 'dancesstepsmap' VALUES (29278, 19879, 4);
INSERT INTO 'dancesstepsmap' VALUES (29279, 19899, 2);
INSERT INTO 'dancesstepsmap' VALUES (29280, 19899, 1);
INSERT INTO 'dancesstepsmap' VALUES (29281, 19899, 3);
INSERT INTO 'dancesstepsmap' VALUES (29282, 17205, 1);
INSERT INTO 'dancesstepsmap' VALUES (29283, 17205, 2);
INSERT INTO 'dancesstepsmap' VALUES (29284, 15123, 4);
INSERT INTO 'dancesstepsmap' VALUES (29285, 15123, 5);
INSERT INTO 'dancesstepsmap' VALUES (29286, 15123, 1);
INSERT INTO 'dancesstepsmap' VALUES (29287, 15123, 2);
INSERT INTO 'dancesstepsmap' VALUES (29288, 11721, 1);
INSERT INTO 'dancesstepsmap' VALUES (29289, 11721, 2);
INSERT INTO 'dancesstepsmap' VALUES (29290, 11721, 3);
INSERT INTO 'dancesstepsmap' VALUES (29291, 2524, 5);
INSERT INTO 'dancesstepsmap' VALUES (29292, 1071, 2);
INSERT INTO 'dancesstepsmap' VALUES (29293, 1869, 2);
INSERT INTO 'dancesstepsmap' VALUES (29294, 7044, 5);
INSERT INTO 'dancesstepsmap' VALUES (29295, 1767, 5);
INSERT INTO 'dancesstepsmap' VALUES (29296, 1764, 2);
INSERT INTO 'dancesstepsmap' VALUES (29297, 20139, 2);
INSERT INTO 'dancesstepsmap' VALUES (29298, 20139, 3);
INSERT INTO 'dancesstepsmap' VALUES (29299, 20139, 1);
INSERT INTO 'dancesstepsmap' VALUES (29300, 6173, 2);
INSERT INTO 'dancesstepsmap' VALUES (29301, 6173, 3);
INSERT INTO 'dancesstepsmap' VALUES (29302, 20150, 2);
INSERT INTO 'dancesstepsmap' VALUES (29303, 20150, 1);
INSERT INTO 'dancesstepsmap' VALUES (29304, 19705, 2);
INSERT INTO 'dancesstepsmap' VALUES (29305, 3572, 5);
INSERT INTO 'dancesstepsmap' VALUES (29306, 2854, 5);
INSERT INTO 'dancesstepsmap' VALUES (29307, 10690, 1);
INSERT INTO 'dancesstepsmap' VALUES (29308, 9353, 5);
INSERT INTO 'dancesstepsmap' VALUES (29309, 11689, 5);
INSERT INTO 'dancesstepsmap' VALUES (29310, 1937, 2);
INSERT INTO 'dancesstepsmap' VALUES (29311, 2259, 2);
INSERT INTO 'dancesstepsmap' VALUES (29312, 2323, 4);
INSERT INTO 'dancesstepsmap' VALUES (29313, 2323, 5);
INSERT INTO 'dancesstepsmap' VALUES (29314, 2323, 2);
INSERT INTO 'dancesstepsmap' VALUES (29315, 2323, 1);
INSERT INTO 'dancesstepsmap' VALUES (29316, 2387, 5);
INSERT INTO 'dancesstepsmap' VALUES (29317, 2387, 4);
INSERT INTO 'dancesstepsmap' VALUES (29318, 2387, 1);
INSERT INTO 'dancesstepsmap' VALUES (29319, 2589, 5);
INSERT INTO 'dancesstepsmap' VALUES (29320, 17509, 1);
INSERT INTO 'dancesstepsmap' VALUES (29321, 17509, 3);
INSERT INTO 'dancesstepsmap' VALUES (29322, 17509, 2);
INSERT INTO 'dancesstepsmap' VALUES (29323, 20151, 1);
INSERT INTO 'dancesstepsmap' VALUES (29324, 20151, 2);
INSERT INTO 'dancesstepsmap' VALUES (29325, 20151, 3);
INSERT INTO 'dancesstepsmap' VALUES (29326, 20180, 1);
INSERT INTO 'dancesstepsmap' VALUES (29327, 20180, 2);
INSERT INTO 'dancesstepsmap' VALUES (29328, 3244, 5);
INSERT INTO 'dancesstepsmap' VALUES (29329, 3390, 2);
INSERT INTO 'dancesstepsmap' VALUES (29330, 20181, 1);
INSERT INTO 'dancesstepsmap' VALUES (29331, 20182, 1);
INSERT INTO 'dancesstepsmap' VALUES (29332, 20182, 2);
INSERT INTO 'dancesstepsmap' VALUES (29333, 3444, 5);
INSERT INTO 'dancesstepsmap' VALUES (29334, 3570, 2);
INSERT INTO 'dancesstepsmap' VALUES (29335, 3625, 4);
INSERT INTO 'dancesstepsmap' VALUES (29336, 3625, 3);
INSERT INTO 'dancesstepsmap' VALUES (29337, 3625, 1);
INSERT INTO 'dancesstepsmap' VALUES (29338, 20153, 1);
INSERT INTO 'dancesstepsmap' VALUES (29339, 20153, 2);
INSERT INTO 'dancesstepsmap' VALUES (29340, 20196, 1);
INSERT INTO 'dancesstepsmap' VALUES (29341, 20196, 2);
INSERT INTO 'dancesstepsmap' VALUES (29342, 4100, 5);
INSERT INTO 'dancesstepsmap' VALUES (29343, 1271, 5);
INSERT INTO 'dancesstepsmap' VALUES (29344, 1407, 2);
INSERT INTO 'dancesstepsmap' VALUES (29345, 4312, 5);
INSERT INTO 'dancesstepsmap' VALUES (29346, 4394, 5);
INSERT INTO 'dancesstepsmap' VALUES (29347, 4444, 5);
INSERT INTO 'dancesstepsmap' VALUES (29348, 4476, 2);
INSERT INTO 'dancesstepsmap' VALUES (29349, 4477, 5);
INSERT INTO 'dancesstepsmap' VALUES (29350, 2850, 2);
INSERT INTO 'dancesstepsmap' VALUES (29351, 4518, 2);
INSERT INTO 'dancesstepsmap' VALUES (29352, 4521, 2);
INSERT INTO 'dancesstepsmap' VALUES (29353, 4544, 5);
INSERT INTO 'dancesstepsmap' VALUES (29354, 4610, 5);
INSERT INTO 'dancesstepsmap' VALUES (29355, 4620, 2);
INSERT INTO 'dancesstepsmap' VALUES (29356, 2919, 2);
INSERT INTO 'dancesstepsmap' VALUES (29357, 5237, 2);
INSERT INTO 'dancesstepsmap' VALUES (29358, 3664, 2);
INSERT INTO 'dancesstepsmap' VALUES (29359, 5316, 5);
INSERT INTO 'dancesstepsmap' VALUES (29360, 5320, 5);
INSERT INTO 'dancesstepsmap' VALUES (29361, 4527, 5);
INSERT INTO 'dancesstepsmap' VALUES (14414, 12479, 2);
INSERT INTO 'dancesstepsmap' VALUES (14415, 12479, 1);
INSERT INTO 'dancesstepsmap' VALUES (29362, 5495, 5);
INSERT INTO 'dancesstepsmap' VALUES (29363, 5609, 5);
INSERT INTO 'dancesstepsmap' VALUES (29364, 5578, 2);
INSERT INTO 'dancesstepsmap' VALUES (29365, 6379, 2);
INSERT INTO 'dancesstepsmap' VALUES (29366, 6628, 5);
INSERT INTO 'dancesstepsmap' VALUES (29367, 5726, 5);
INSERT INTO 'dancesstepsmap' VALUES (29368, 5853, 5);
INSERT INTO 'dancesstepsmap' VALUES (29369, 6197, 5);
INSERT INTO 'dancesstepsmap' VALUES (29370, 6450, 2);
INSERT INTO 'dancesstepsmap' VALUES (29371, 10691, 1);
INSERT INTO 'dancesstepsmap' VALUES (29372, 10691, 2);
INSERT INTO 'dancesstepsmap' VALUES (29373, 6835, 3);
INSERT INTO 'dancesstepsmap' VALUES (29374, 7310, 2);
INSERT INTO 'dancesstepsmap' VALUES (29375, 7310, 3);
INSERT INTO 'dancesstepsmap' VALUES (29376, 8132, 2);
INSERT INTO 'dancesstepsmap' VALUES (29377, 8238, 5);
INSERT INTO 'dancesstepsmap' VALUES (29378, 8511, 2);
INSERT INTO 'dancesstepsmap' VALUES (29379, 2668, 2);
INSERT INTO 'dancesstepsmap' VALUES (29380, 2668, 3);
INSERT INTO 'dancesstepsmap' VALUES (29381, 20197, 4);
INSERT INTO 'dancesstepsmap' VALUES (29382, 20197, 5);
INSERT INTO 'dancesstepsmap' VALUES (29383, 9372, 5);
INSERT INTO 'dancesstepsmap' VALUES (29384, 9484, 2);
INSERT INTO 'dancesstepsmap' VALUES (29385, 9484, 1);
INSERT INTO 'dancesstepsmap' VALUES (29386, 9563, 2);
INSERT INTO 'dancesstepsmap' VALUES (29387, 9648, 1);
INSERT INTO 'dancesstepsmap' VALUES (29388, 9803, 1);
INSERT INTO 'dancesstepsmap' VALUES (29389, 9804, 2);
INSERT INTO 'dancesstepsmap' VALUES (29390, 9869, 2);
INSERT INTO 'dancesstepsmap' VALUES (29391, 9989, 5);
INSERT INTO 'dancesstepsmap' VALUES (29392, 9387, 4);
INSERT INTO 'dancesstepsmap' VALUES (29393, 9387, 2);
INSERT INTO 'dancesstepsmap' VALUES (29394, 9387, 1);
INSERT INTO 'dancesstepsmap' VALUES (29395, 10075, 1);
INSERT INTO 'dancesstepsmap' VALUES (29396, 10696, 1);
INSERT INTO 'dancesstepsmap' VALUES (29397, 10696, 2);
INSERT INTO 'dancesstepsmap' VALUES (29398, 10697, 1);
INSERT INTO 'dancesstepsmap' VALUES (29399, 10697, 2);
INSERT INTO 'dancesstepsmap' VALUES (29400, 2775, 2);
INSERT INTO 'dancesstepsmap' VALUES (29401, 2775, 3);
INSERT INTO 'dancesstepsmap' VALUES (29402, 4258, 2);
INSERT INTO 'dancesstepsmap' VALUES (29403, 10675, 1);
INSERT INTO 'dancesstepsmap' VALUES (29404, 10695, 2);
INSERT INTO 'dancesstepsmap' VALUES (29405, 5484, 2);
INSERT INTO 'dancesstepsmap' VALUES (29406, 5484, 1);
INSERT INTO 'dancesstepsmap' VALUES (29407, 5484, 3);
INSERT INTO 'dancesstepsmap' VALUES (29408, 5484, 5);
INSERT INTO 'dancesstepsmap' VALUES (29409, 5484, 4);
INSERT INTO 'dancesstepsmap' VALUES (29410, 10704, 4);
INSERT INTO 'dancesstepsmap' VALUES (29411, 10704, 5);
INSERT INTO 'dancesstepsmap' VALUES (29412, 10711, 4);
INSERT INTO 'dancesstepsmap' VALUES (29413, 10711, 5);
INSERT INTO 'dancesstepsmap' VALUES (29414, 10715, 1);
INSERT INTO 'dancesstepsmap' VALUES (29415, 11885, 5);
INSERT INTO 'dancesstepsmap' VALUES (29416, 11885, 4);
INSERT INTO 'dancesstepsmap' VALUES (29417, 11885, 2);
INSERT INTO 'dancesstepsmap' VALUES (29418, 11885, 1);
INSERT INTO 'dancesstepsmap' VALUES (29419, 11934, 2);
INSERT INTO 'dancesstepsmap' VALUES (29420, 12953, 5);
INSERT INTO 'dancesstepsmap' VALUES (29421, 13227, 5);
INSERT INTO 'dancesstepsmap' VALUES (29422, 1599, 5);
INSERT INTO 'dancesstepsmap' VALUES (29423, 3696, 2);
INSERT INTO 'dancesstepsmap' VALUES (29424, 10714, 1);
INSERT INTO 'dancesstepsmap' VALUES (29425, 4690, 5);
INSERT INTO 'dancesstepsmap' VALUES (29426, 6090, 5);
INSERT INTO 'dancesstepsmap' VALUES (29427, 4329, 2);
INSERT INTO 'dancesstepsmap' VALUES (29428, 697, 2);
INSERT INTO 'dancesstepsmap' VALUES (29429, 2873, 2);
INSERT INTO 'dancesstepsmap' VALUES (29430, 1339, 5);
INSERT INTO 'dancesstepsmap' VALUES (29431, 9227, 5);
INSERT INTO 'dancesstepsmap' VALUES (29432, 9227, 4);
INSERT INTO 'dancesstepsmap' VALUES (29433, 9227, 6);
INSERT INTO 'dancesstepsmap' VALUES (29434, 17798, 3);
INSERT INTO 'dancesstepsmap' VALUES (29435, 2848, 2);
INSERT INTO 'dancesstepsmap' VALUES (29436, 14, 2);
INSERT INTO 'dancesstepsmap' VALUES (29437, 60, 2);
INSERT INTO 'dancesstepsmap' VALUES (29438, 73, 5);
INSERT INTO 'dancesstepsmap' VALUES (29439, 73, 4);
INSERT INTO 'dancesstepsmap' VALUES (29440, 73, 2);
INSERT INTO 'dancesstepsmap' VALUES (29441, 73, 1);
INSERT INTO 'dancesstepsmap' VALUES (29442, 98, 2);
INSERT INTO 'dancesstepsmap' VALUES (29443, 100, 2);
INSERT INTO 'dancesstepsmap' VALUES (29444, 128, 5);
INSERT INTO 'dancesstepsmap' VALUES (29445, 129, 2);
INSERT INTO 'dancesstepsmap' VALUES (29446, 3155, 5);
INSERT INTO 'dancesstepsmap' VALUES (29447, 155, 5);
INSERT INTO 'dancesstepsmap' VALUES (29448, 162, 2);
INSERT INTO 'dancesstepsmap' VALUES (29449, 197, 2);
INSERT INTO 'dancesstepsmap' VALUES (29450, 3224, 2);
INSERT INTO 'dancesstepsmap' VALUES (29451, 3946, 5);
INSERT INTO 'dancesstepsmap' VALUES (29452, 12735, 3);
INSERT INTO 'dancesstepsmap' VALUES (29453, 20198, 2);
INSERT INTO 'dancesstepsmap' VALUES (29454, 20198, 1);
INSERT INTO 'dancesstepsmap' VALUES (29455, 20199, 1);
INSERT INTO 'dancesstepsmap' VALUES (29456, 20199, 2);
INSERT INTO 'dancesstepsmap' VALUES (29457, 11819, 2);
INSERT INTO 'dancesstepsmap' VALUES (29458, 12719, 5);
INSERT INTO 'dancesstepsmap' VALUES (29459, 16801, 8);
INSERT INTO 'dancesstepsmap' VALUES (29460, 11823, 1);
INSERT INTO 'dancesstepsmap' VALUES (29461, 15436, 2);
INSERT INTO 'dancesstepsmap' VALUES (29462, 6965, 2);
INSERT INTO 'dancesstepsmap' VALUES (29463, 11822, 5);
INSERT INTO 'dancesstepsmap' VALUES (29464, 11824, 5);
INSERT INTO 'dancesstepsmap' VALUES (29465, 11824, 4);
INSERT INTO 'dancesstepsmap' VALUES (29466, 5602, 2);
INSERT INTO 'dancesstepsmap' VALUES (29467, 1363, 5);
INSERT INTO 'dancesstepsmap' VALUES (29468, 1464, 2);
INSERT INTO 'dancesstepsmap' VALUES (29469, 4382, 2);
INSERT INTO 'dancesstepsmap' VALUES (29470, 1818, 5);
INSERT INTO 'dancesstepsmap' VALUES (18483, 15406, 5);
INSERT INTO 'dancesstepsmap' VALUES (18484, 15406, 4);
INSERT INTO 'dancesstepsmap' VALUES (29471, 609, 2);
INSERT INTO 'dancesstepsmap' VALUES (29472, 10666, 1);
INSERT INTO 'dancesstepsmap' VALUES (29473, 10666, 2);
INSERT INTO 'dancesstepsmap' VALUES (29475, 7009, 2);
INSERT INTO 'dancesstepsmap' VALUES (29476, 13229, 2);
INSERT INTO 'dancesstepsmap' VALUES (29477, 13229, 1);
INSERT INTO 'dancesstepsmap' VALUES (29478, 8500, 2);
INSERT INTO 'dancesstepsmap' VALUES (29479, 12576, 5);
INSERT INTO 'dancesstepsmap' VALUES (29480, 5530, 2);
INSERT INTO 'dancesstepsmap' VALUES (29481, 13620, 3);
INSERT INTO 'dancesstepsmap' VALUES (29482, 13610, 3);
INSERT INTO 'dancesstepsmap' VALUES (29483, 13603, 3);
INSERT INTO 'dancesstepsmap' VALUES (25089, 13129, 4);
INSERT INTO 'dancesstepsmap' VALUES (25090, 13129, 5);
INSERT INTO 'dancesstepsmap' VALUES (23310, 13926, 2);
INSERT INTO 'dancesstepsmap' VALUES (23311, 13926, 1);
INSERT INTO 'dancesstepsmap' VALUES (19762, 14076, 4);
INSERT INTO 'dancesstepsmap' VALUES (23094, 17472, 4);
INSERT INTO 'dancesstepsmap' VALUES (23127, 17439, 4);
INSERT INTO 'dancesstepsmap' VALUES (29484, 4684, 5);
INSERT INTO 'dancesstepsmap' VALUES (29485, 4684, 4);
INSERT INTO 'dancesstepsmap' VALUES (29486, 4684, 1);
INSERT INTO 'dancesstepsmap' VALUES (29487, 13443, 2);
INSERT INTO 'dancesstepsmap' VALUES (29488, 2013, 2);
INSERT INTO 'dancesstepsmap' VALUES (29489, 13439, 3);
INSERT INTO 'dancesstepsmap' VALUES (29490, 20200, 5);
INSERT INTO 'dancesstepsmap' VALUES (29491, 20200, 4);
INSERT INTO 'dancesstepsmap' VALUES (29492, 20200, 2);
INSERT INTO 'dancesstepsmap' VALUES (29493, 20200, 1);
INSERT INTO 'dancesstepsmap' VALUES (29494, 20200, 3);
INSERT INTO 'dancesstepsmap' VALUES (29495, 20201, 2);
INSERT INTO 'dancesstepsmap' VALUES (29496, 20201, 1);
INSERT INTO 'dancesstepsmap' VALUES (29497, 13318, 2);
INSERT INTO 'dancesstepsmap' VALUES (29498, 13301, 5);
INSERT INTO 'dancesstepsmap' VALUES (26850, 15060, 5);
INSERT INTO 'dancesstepsmap' VALUES (26851, 15060, 4);
INSERT INTO 'dancesstepsmap' VALUES (28900, 17147, 4);
INSERT INTO 'dancesstepsmap' VALUES (28901, 17147, 5);
INSERT INTO 'dancesstepsmap' VALUES (29499, 14787, 4);
INSERT INTO 'dancesstepsmap' VALUES (29500, 14787, 5);
INSERT INTO 'dancesstepsmap' VALUES (29501, 14788, 1);
INSERT INTO 'dancesstepsmap' VALUES (29502, 14788, 2);
INSERT INTO 'dancesstepsmap' VALUES (29503, 14788, 3);
INSERT INTO 'dancesstepsmap' VALUES (29504, 13233, 2);
INSERT INTO 'dancesstepsmap' VALUES (29505, 16518, 2);
INSERT INTO 'dancesstepsmap' VALUES (29506, 16518, 1);
INSERT INTO 'dancesstepsmap' VALUES (29507, 9214, 5);
INSERT INTO 'dancesstepsmap' VALUES (29508, 14791, 1);
INSERT INTO 'dancesstepsmap' VALUES (29509, 14791, 2);
INSERT INTO 'dancesstepsmap' VALUES (29510, 14791, 3);
INSERT INTO 'dancesstepsmap' VALUES (29511, 20203, 1);
INSERT INTO 'dancesstepsmap' VALUES (22090, 17311, 5);
INSERT INTO 'dancesstepsmap' VALUES (22091, 17311, 4);
INSERT INTO 'dancesstepsmap' VALUES (22473, 9483, 4);
INSERT INTO 'dancesstepsmap' VALUES (22474, 9483, 5);
INSERT INTO 'dancesstepsmap' VALUES (25158, 9772, 2);
INSERT INTO 'dancesstepsmap' VALUES (25159, 9772, 1);
INSERT INTO 'dancesstepsmap' VALUES (24536, 11018, 4);
INSERT INTO 'dancesstepsmap' VALUES (24537, 11018, 5);
INSERT INTO 'dancesstepsmap' VALUES (23895, 14130, 4);
INSERT INTO 'dancesstepsmap' VALUES (24644, 14194, 4);
INSERT INTO 'dancesstepsmap' VALUES (24645, 14194, 5);
INSERT INTO 'dancesstepsmap' VALUES (23725, 15303, 4);
INSERT INTO 'dancesstepsmap' VALUES (21338, 16915, 5);
INSERT INTO 'dancesstepsmap' VALUES (21339, 16915, 4);
INSERT INTO 'dancesstepsmap' VALUES (22744, 17694, 4);
INSERT INTO 'dancesstepsmap' VALUES (22745, 17694, 5);
INSERT INTO 'dancesstepsmap' VALUES (26660, 18151, 5);
INSERT INTO 'dancesstepsmap' VALUES (24172, 18837, 4);
INSERT INTO 'dancesstepsmap' VALUES (29512, 18837, 5);
INSERT INTO 'dancesstepsmap' VALUES (2822, 3058, 4);
INSERT INTO 'dancesstepsmap' VALUES (7696, 3058, 6);
INSERT INTO 'dancesstepsmap' VALUES (10340, 9566, 5);
INSERT INTO 'dancesstepsmap' VALUES (23999, 18599, 4);
INSERT INTO 'dancesstepsmap' VALUES (19132, 15786, 4);
INSERT INTO 'dancesstepsmap' VALUES (12990, 8892, 5);
INSERT INTO 'dancesstepsmap' VALUES (29513, 13080, 5);
INSERT INTO 'dancesstepsmap' VALUES (29514, 13068, 2);
INSERT INTO 'dancesstepsmap' VALUES (25778, 19302, 5);
INSERT INTO 'dancesstepsmap' VALUES (25779, 19302, 4);
INSERT INTO 'dancesstepsmap' VALUES (19170, 15805, 5);
INSERT INTO 'dancesstepsmap' VALUES (29515, 11642, 1);
INSERT INTO 'dancesstepsmap' VALUES (20145, 10441, 4);
INSERT INTO 'dancesstepsmap' VALUES (20146, 10441, 5);
INSERT INTO 'dancesstepsmap' VALUES (15384, 12963, 4);
INSERT INTO 'dancesstepsmap' VALUES (29516, 12963, 5);
INSERT INTO 'dancesstepsmap' VALUES (5532, 5997, 5);
INSERT INTO 'dancesstepsmap' VALUES (16468, 13830, 4);
INSERT INTO 'dancesstepsmap' VALUES (16469, 13830, 5);
INSERT INTO 'dancesstepsmap' VALUES (29517, 12959, 5);
INSERT INTO 'dancesstepsmap' VALUES (29518, 12955, 2);
INSERT INTO 'dancesstepsmap' VALUES (29519, 12954, 2);
INSERT INTO 'dancesstepsmap' VALUES (29520, 12952, 2);
INSERT INTO 'dancesstepsmap' VALUES (29521, 12949, 5);
INSERT INTO 'dancesstepsmap' VALUES (29522, 9446, 2);
INSERT INTO 'dancesstepsmap' VALUES (29523, 15419, 3);
INSERT INTO 'dancesstepsmap' VALUES (19856, 16106, 4);
INSERT INTO 'dancesstepsmap' VALUES (19857, 16106, 5);
INSERT INTO 'dancesstepsmap' VALUES (4188, 4531, 4);
INSERT INTO 'dancesstepsmap' VALUES (29524, 4531, 5);
INSERT INTO 'dancesstepsmap' VALUES (6107, 6624, 5);
INSERT INTO 'dancesstepsmap' VALUES (29525, 11585, 4);
INSERT INTO 'dancesstepsmap' VALUES (29526, 12905, 2);
INSERT INTO 'dancesstepsmap' VALUES (29527, 12681, 5);
INSERT INTO 'dancesstepsmap' VALUES (19014, 15726, 4);
INSERT INTO 'dancesstepsmap' VALUES (19015, 15726, 5);
INSERT INTO 'dancesstepsmap' VALUES (29528, 2978, 2);
INSERT INTO 'dancesstepsmap' VALUES (29529, 11643, 1);
INSERT INTO 'dancesstepsmap' VALUES (29530, 976, 2);
INSERT INTO 'dancesstepsmap' VALUES (29531, 976, 5);
INSERT INTO 'dancesstepsmap' VALUES (29532, 976, 4);
INSERT INTO 'dancesstepsmap' VALUES (29533, 7210, 5);
INSERT INTO 'dancesstepsmap' VALUES (29534, 4174, 2);
INSERT INTO 'dancesstepsmap' VALUES (29535, 11644, 1);
INSERT INTO 'dancesstepsmap' VALUES (29536, 12898, 2);
INSERT INTO 'dancesstepsmap' VALUES (29537, 12897, 1);
INSERT INTO 'dancesstepsmap' VALUES (29538, 12897, 2);
INSERT INTO 'dancesstepsmap' VALUES (29539, 12897, 3);
INSERT INTO 'dancesstepsmap' VALUES (29540, 12888, 2);
INSERT INTO 'dancesstepsmap' VALUES (29541, 12881, 1);
INSERT INTO 'dancesstepsmap' VALUES (29542, 12880, 2);
INSERT INTO 'dancesstepsmap' VALUES (29543, 11656, 4);
INSERT INTO 'dancesstepsmap' VALUES (29544, 11656, 5);
INSERT INTO 'dancesstepsmap' VALUES (29545, 12879, 4);
INSERT INTO 'dancesstepsmap' VALUES (29546, 12879, 1);
INSERT INTO 'dancesstepsmap' VALUES (29547, 12876, 99);
INSERT INTO 'dancesstepsmap' VALUES (29548, 12871, 3);
INSERT INTO 'dancesstepsmap' VALUES (29549, 2644, 2);
INSERT INTO 'dancesstepsmap' VALUES (29550, 19165, 101);
INSERT INTO 'dancesstepsmap' VALUES (29551, 12869, 2);
INSERT INTO 'dancesstepsmap' VALUES (29552, 12862, 2);
INSERT INTO 'dancesstepsmap' VALUES (29553, 12850, 2);
INSERT INTO 'dancesstepsmap' VALUES (29554, 12825, 5);
INSERT INTO 'dancesstepsmap' VALUES (29555, 12820, 4);
INSERT INTO 'dancesstepsmap' VALUES (29556, 12820, 5);
INSERT INTO 'dancesstepsmap' VALUES (29557, 1747, 2);
INSERT INTO 'dancesstepsmap' VALUES (29558, 1747, 99);
INSERT INTO 'dancesstepsmap' VALUES (29559, 12811, 2);
INSERT INTO 'dancesstepsmap' VALUES (29560, 12811, 3);
INSERT INTO 'dancesstepsmap' VALUES (29561, 12795, 2);
INSERT INTO 'dancesstepsmap' VALUES (29562, 12747, 2);
INSERT INTO 'dancesstepsmap' VALUES (29563, 12745, 5);
INSERT INTO 'dancesstepsmap' VALUES (29564, 7527, 3);
INSERT INTO 'dancesstepsmap' VALUES (29565, 12742, 2);
INSERT INTO 'dancesstepsmap' VALUES (29566, 13252, 2);
INSERT INTO 'dancesstepsmap' VALUES (29567, 4320, 3);
INSERT INTO 'dancesstepsmap' VALUES (29568, 4320, 2);
INSERT INTO 'dancesstepsmap' VALUES (29569, 2430, 3);
INSERT INTO 'dancesstepsmap' VALUES (29570, 1155, 2);
INSERT INTO 'dancesstepsmap' VALUES (29571, 9236, 3);
INSERT INTO 'dancesstepsmap' VALUES (29572, 9021, 1);
INSERT INTO 'dancesstepsmap' VALUES (29573, 9021, 2);
INSERT INTO 'dancesstepsmap' VALUES (29574, 12686, 2);
INSERT INTO 'dancesstepsmap' VALUES (29575, 12683, 5);
INSERT INTO 'dancesstepsmap' VALUES (29576, 12662, 5);
INSERT INTO 'dancesstepsmap' VALUES (29577, 12642, 2);
INSERT INTO 'dancesstepsmap' VALUES (29578, 17699, 1);
INSERT INTO 'dancesstepsmap' VALUES (29579, 17699, 2);
INSERT INTO 'dancesstepsmap' VALUES (29580, 17701, 4);
INSERT INTO 'dancesstepsmap' VALUES (29581, 17701, 5);
INSERT INTO 'dancesstepsmap' VALUES (29582, 4871, 2);
INSERT INTO 'dancesstepsmap' VALUES (29583, 12636, 5);
INSERT INTO 'dancesstepsmap' VALUES (29584, 12625, 5);
INSERT INTO 'dancesstepsmap' VALUES (29585, 12623, 2);
INSERT INTO 'dancesstepsmap' VALUES (29586, 12621, 2);
INSERT INTO 'dancesstepsmap' VALUES (29587, 12617, 1);
INSERT INTO 'dancesstepsmap' VALUES (29588, 9017, 1);
INSERT INTO 'dancesstepsmap' VALUES (29589, 9017, 2);
INSERT INTO 'dancesstepsmap' VALUES (29590, 9017, 3);
INSERT INTO 'dancesstepsmap' VALUES (29591, 12614, 2);
INSERT INTO 'dancesstepsmap' VALUES (29592, 12610, 2);
INSERT INTO 'dancesstepsmap' VALUES (29593, 12587, 5);
INSERT INTO 'dancesstepsmap' VALUES (29594, 12529, 5);
INSERT INTO 'dancesstepsmap' VALUES (29595, 12524, 2);
INSERT INTO 'dancesstepsmap' VALUES (29596, 12429, 5);
INSERT INTO 'dancesstepsmap' VALUES (29597, 12428, 2);
INSERT INTO 'dancesstepsmap' VALUES (29598, 1162, 2);
INSERT INTO 'dancesstepsmap' VALUES (29599, 1763, 2);
INSERT INTO 'dancesstepsmap' VALUES (29600, 12401, 2);
INSERT INTO 'dancesstepsmap' VALUES (29601, 12246, 5);
INSERT INTO 'dancesstepsmap' VALUES (29602, 12242, 2);
INSERT INTO 'dancesstepsmap' VALUES (29603, 12228, 3);
INSERT INTO 'dancesstepsmap' VALUES (29604, 12149, 2);
INSERT INTO 'dancesstepsmap' VALUES (29605, 12121, 5);
INSERT INTO 'dancesstepsmap' VALUES (29606, 12121, 4);
INSERT INTO 'dancesstepsmap' VALUES (29607, 12120, 1);
INSERT INTO 'dancesstepsmap' VALUES (29608, 12108, 2);
INSERT INTO 'dancesstepsmap' VALUES (29609, 12105, 1);
INSERT INTO 'dancesstepsmap' VALUES (29610, 12105, 2);
INSERT INTO 'dancesstepsmap' VALUES (29611, 2968, 5);
INSERT INTO 'dancesstepsmap' VALUES (29612, 12094, 1);
INSERT INTO 'dancesstepsmap' VALUES (29613, 20205, 1);
INSERT INTO 'dancesstepsmap' VALUES (29614, 20205, 2);
INSERT INTO 'dancesstepsmap' VALUES (29615, 20205, 3);
INSERT INTO 'dancesstepsmap' VALUES (29616, 12092, 1);
INSERT INTO 'dancesstepsmap' VALUES (29617, 12092, 2);
INSERT INTO 'dancesstepsmap' VALUES (29618, 12083, 5);
INSERT INTO 'dancesstepsmap' VALUES (29619, 12091, 4);
INSERT INTO 'dancesstepsmap' VALUES (29620, 12091, 5);
INSERT INTO 'dancesstepsmap' VALUES (29621, 1398, 5);
INSERT INTO 'dancesstepsmap' VALUES (29622, 12007, 1);
INSERT INTO 'dancesstepsmap' VALUES (29623, 11978, 5);
INSERT INTO 'dancesstepsmap' VALUES (29624, 11978, 4);
INSERT INTO 'dancesstepsmap' VALUES (29625, 11976, 1);
INSERT INTO 'dancesstepsmap' VALUES (29626, 11976, 2);
INSERT INTO 'dancesstepsmap' VALUES (29627, 11908, 5);
INSERT INTO 'dancesstepsmap' VALUES (29628, 11866, 2);
INSERT INTO 'dancesstepsmap' VALUES (29629, 11835, 2);
INSERT INTO 'dancesstepsmap' VALUES (29630, 11832, 5);
INSERT INTO 'dancesstepsmap' VALUES (29631, 13315, 2);
INSERT INTO 'dancesstepsmap' VALUES (29632, 10438, 1);
INSERT INTO 'dancesstepsmap' VALUES (29633, 9487, 2);
INSERT INTO 'dancesstepsmap' VALUES (29634, 11812, 5);
INSERT INTO 'dancesstepsmap' VALUES (29635, 11802, 2);
INSERT INTO 'dancesstepsmap' VALUES (29636, 17691, 4);
INSERT INTO 'dancesstepsmap' VALUES (29637, 17691, 5);
INSERT INTO 'dancesstepsmap' VALUES (29638, 17696, 1);
INSERT INTO 'dancesstepsmap' VALUES (29639, 17698, 5);
INSERT INTO 'dancesstepsmap' VALUES (29640, 17698, 4);
INSERT INTO 'dancesstepsmap' VALUES (29641, 17698, 1);
INSERT INTO 'dancesstepsmap' VALUES (29642, 17702, 1);
INSERT INTO 'dancesstepsmap' VALUES (29643, 17703, 1);
INSERT INTO 'dancesstepsmap' VALUES (29644, 17703, 2);
INSERT INTO 'dancesstepsmap' VALUES (29645, 18799, 1);
INSERT INTO 'dancesstepsmap' VALUES (29646, 18799, 3);
INSERT INTO 'dancesstepsmap' VALUES (29647, 11772, 5);
INSERT INTO 'dancesstepsmap' VALUES (29648, 11750, 2);
INSERT INTO 'dancesstepsmap' VALUES (29649, 11749, 2);
INSERT INTO 'dancesstepsmap' VALUES (29650, 11727, 2);
INSERT INTO 'dancesstepsmap' VALUES (29651, 18938, 1);
INSERT INTO 'dancesstepsmap' VALUES (29652, 18938, 2);
INSERT INTO 'dancesstepsmap' VALUES (29653, 11640, 5);
INSERT INTO 'dancesstepsmap' VALUES (29654, 18937, 1);
INSERT INTO 'dancesstepsmap' VALUES (29655, 18937, 2);
INSERT INTO 'dancesstepsmap' VALUES (29656, 20206, 4);
INSERT INTO 'dancesstepsmap' VALUES (29657, 11618, 1);
INSERT INTO 'dancesstepsmap' VALUES (29658, 20207, 1);
INSERT INTO 'dancesstepsmap' VALUES (29659, 20207, 2);
INSERT INTO 'dancesstepsmap' VALUES (29660, 12357, 1);
INSERT INTO 'dancesstepsmap' VALUES (29661, 12357, 2);
INSERT INTO 'dancesstepsmap' VALUES (29662, 11604, 1);
INSERT INTO 'dancesstepsmap' VALUES (29663, 11600, 2);
INSERT INTO 'dancesstepsmap' VALUES (29664, 12293, 1);
INSERT INTO 'dancesstepsmap' VALUES (29665, 12265, 1);
INSERT INTO 'dancesstepsmap' VALUES (29666, 12265, 2);
INSERT INTO 'dancesstepsmap' VALUES (29667, 12159, 1);
INSERT INTO 'dancesstepsmap' VALUES (29668, 11569, 5);
INSERT INTO 'dancesstepsmap' VALUES (29669, 11526, 3);
INSERT INTO 'dancesstepsmap' VALUES (29670, 11526, 4);
INSERT INTO 'dancesstepsmap' VALUES (29671, 12131, 4);
INSERT INTO 'dancesstepsmap' VALUES (29672, 12131, 5);
INSERT INTO 'dancesstepsmap' VALUES (29673, 11486, 2);
INSERT INTO 'dancesstepsmap' VALUES (29674, 11485, 2);
INSERT INTO 'dancesstepsmap' VALUES (29675, 11475, 5);
INSERT INTO 'dancesstepsmap' VALUES (29676, 11399, 2);
INSERT INTO 'dancesstepsmap' VALUES (29677, 12153, 1);
INSERT INTO 'dancesstepsmap' VALUES (29678, 12153, 2);
INSERT INTO 'dancesstepsmap' VALUES (29679, 12153, 3);
INSERT INTO 'dancesstepsmap' VALUES (29680, 12358, 1);
INSERT INTO 'dancesstepsmap' VALUES (29681, 12358, 3);
INSERT INTO 'dancesstepsmap' VALUES (29682, 12187, 1);
INSERT INTO 'dancesstepsmap' VALUES (29683, 12187, 2);
INSERT INTO 'dancesstepsmap' VALUES (29684, 12205, 2);
INSERT INTO 'dancesstepsmap' VALUES (29685, 12205, 1);
INSERT INTO 'dancesstepsmap' VALUES (29686, 20209, 10);
INSERT INTO 'dancesstepsmap' VALUES (29687, 11395, 5);
INSERT INTO 'dancesstepsmap' VALUES (29688, 11390, 2);
INSERT INTO 'dancesstepsmap' VALUES (29689, 11368, 5);
INSERT INTO 'dancesstepsmap' VALUES (29690, 2529, 2);
INSERT INTO 'dancesstepsmap' VALUES (29691, 2529, 3);
INSERT INTO 'dancesstepsmap' VALUES (29692, 4655, 5);
INSERT INTO 'dancesstepsmap' VALUES (29693, 11267, 5);
INSERT INTO 'dancesstepsmap' VALUES (29694, 11264, 5);
INSERT INTO 'dancesstepsmap' VALUES (13313, 11696, 1);
INSERT INTO 'dancesstepsmap' VALUES (13314, 11696, 2);
INSERT INTO 'dancesstepsmap' VALUES (29695, 11697, 2);
INSERT INTO 'dancesstepsmap' VALUES (29696, 20210, 1);
INSERT INTO 'dancesstepsmap' VALUES (29697, 20210, 2);
INSERT INTO 'dancesstepsmap' VALUES (29698, 20211, 1);
INSERT INTO 'dancesstepsmap' VALUES (29699, 20211, 3);
INSERT INTO 'dancesstepsmap' VALUES (29700, 20212, 1);
INSERT INTO 'dancesstepsmap' VALUES (29701, 20212, 2);
INSERT INTO 'dancesstepsmap' VALUES (29702, 20212, 3);
INSERT INTO 'dancesstepsmap' VALUES (13325, 11702, 2);
INSERT INTO 'dancesstepsmap' VALUES (13326, 11702, 1);
INSERT INTO 'dancesstepsmap' VALUES (29703, 11032, 1);
INSERT INTO 'dancesstepsmap' VALUES (29704, 10961, 2);
INSERT INTO 'dancesstepsmap' VALUES (29705, 10959, 2);
INSERT INTO 'dancesstepsmap' VALUES (29706, 14370, 4);
INSERT INTO 'dancesstepsmap' VALUES (29707, 10949, 2);
INSERT INTO 'dancesstepsmap' VALUES (29708, 10947, 2);
INSERT INTO 'dancesstepsmap' VALUES (29709, 10945, 2);
INSERT INTO 'dancesstepsmap' VALUES (29710, 10943, 2);
INSERT INTO 'dancesstepsmap' VALUES (29711, 10942, 2);
INSERT INTO 'dancesstepsmap' VALUES (29712, 10941, 2);
INSERT INTO 'dancesstepsmap' VALUES (29713, 10934, 2);
INSERT INTO 'dancesstepsmap' VALUES (29714, 10929, 2);
INSERT INTO 'dancesstepsmap' VALUES (29715, 10927, 2);
INSERT INTO 'dancesstepsmap' VALUES (29716, 10915, 2);
INSERT INTO 'dancesstepsmap' VALUES (29717, 20214, 1);
INSERT INTO 'dancesstepsmap' VALUES (29718, 20214, 3);
INSERT INTO 'dancesstepsmap' VALUES (29719, 10896, 1);
INSERT INTO 'dancesstepsmap' VALUES (29720, 10862, 1);
INSERT INTO 'dancesstepsmap' VALUES (29721, 14184, 1);
INSERT INTO 'dancesstepsmap' VALUES (29722, 14184, 2);
INSERT INTO 'dancesstepsmap' VALUES (29723, 20215, 1);
INSERT INTO 'dancesstepsmap' VALUES (29724, 20215, 2);
INSERT INTO 'dancesstepsmap' VALUES (29725, 5560, 5);
INSERT INTO 'dancesstepsmap' VALUES (29726, 10778, 5);
INSERT INTO 'dancesstepsmap' VALUES (29727, 20216, 1);
INSERT INTO 'dancesstepsmap' VALUES (29728, 20216, 2);
INSERT INTO 'dancesstepsmap' VALUES (29729, 20217, 1);
INSERT INTO 'dancesstepsmap' VALUES (29730, 20217, 2);
INSERT INTO 'dancesstepsmap' VALUES (29731, 20217, 3);
INSERT INTO 'dancesstepsmap' VALUES (29732, 10672, 1);
INSERT INTO 'dancesstepsmap' VALUES (29733, 10572, 2);
INSERT INTO 'dancesstepsmap' VALUES (29734, 219, 5);
INSERT INTO 'dancesstepsmap' VALUES (29735, 10546, 5);
INSERT INTO 'dancesstepsmap' VALUES (29736, 10546, 2);
INSERT INTO 'dancesstepsmap' VALUES (29737, 10545, 5);
INSERT INTO 'dancesstepsmap' VALUES (29738, 10543, 5);
INSERT INTO 'dancesstepsmap' VALUES (29739, 10523, 5);
INSERT INTO 'dancesstepsmap' VALUES (29740, 10522, 5);
INSERT INTO 'dancesstepsmap' VALUES (29741, 17974, 1);
INSERT INTO 'dancesstepsmap' VALUES (29742, 17974, 2);
INSERT INTO 'dancesstepsmap' VALUES (29743, 17972, 4);
INSERT INTO 'dancesstepsmap' VALUES (29744, 17970, 1);
INSERT INTO 'dancesstepsmap' VALUES (29745, 17970, 2);
INSERT INTO 'dancesstepsmap' VALUES (29746, 17970, 3);
INSERT INTO 'dancesstepsmap' VALUES (29747, 10519, 2);
INSERT INTO 'dancesstepsmap' VALUES (29748, 10518, 5);
INSERT INTO 'dancesstepsmap' VALUES (29749, 10516, 2);
INSERT INTO 'dancesstepsmap' VALUES (29750, 17969, 4);
INSERT INTO 'dancesstepsmap' VALUES (29751, 17967, 1);
INSERT INTO 'dancesstepsmap' VALUES (29752, 10495, 1);
INSERT INTO 'dancesstepsmap' VALUES (29753, 10473, 1);
INSERT INTO 'dancesstepsmap' VALUES (29754, 10462, 5);
INSERT INTO 'dancesstepsmap' VALUES (29755, 17966, 1);
INSERT INTO 'dancesstepsmap' VALUES (29756, 17966, 2);
INSERT INTO 'dancesstepsmap' VALUES (29757, 17966, 3);
INSERT INTO 'dancesstepsmap' VALUES (29758, 17963, 1);
INSERT INTO 'dancesstepsmap' VALUES (29759, 17963, 2);
INSERT INTO 'dancesstepsmap' VALUES (29760, 17963, 3);
INSERT INTO 'dancesstepsmap' VALUES (29761, 10406, 5);
INSERT INTO 'dancesstepsmap' VALUES (29762, 10364, 5);
INSERT INTO 'dancesstepsmap' VALUES (29763, 10356, 5);
INSERT INTO 'dancesstepsmap' VALUES (29764, 10324, 5);
INSERT INTO 'dancesstepsmap' VALUES (29765, 10307, 2);
INSERT INTO 'dancesstepsmap' VALUES (29766, 10303, 1);
INSERT INTO 'dancesstepsmap' VALUES (29767, 10302, 2);
INSERT INTO 'dancesstepsmap' VALUES (29768, 10173, 6);
INSERT INTO 'dancesstepsmap' VALUES (29769, 10163, 2);
INSERT INTO 'dancesstepsmap' VALUES (29770, 10154, 2);
INSERT INTO 'dancesstepsmap' VALUES (29771, 10154, 1);
INSERT INTO 'dancesstepsmap' VALUES (29772, 10153, 5);
INSERT INTO 'dancesstepsmap' VALUES (29773, 10114, 3);
INSERT INTO 'dancesstepsmap' VALUES (29774, 10111, 5);
INSERT INTO 'dancesstepsmap' VALUES (29775, 10109, 5);
INSERT INTO 'dancesstepsmap' VALUES (29776, 10108, 5);
INSERT INTO 'dancesstepsmap' VALUES (29777, 10107, 4);
INSERT INTO 'dancesstepsmap' VALUES (29778, 10107, 5);
INSERT INTO 'dancesstepsmap' VALUES (29779, 10097, 2);
INSERT INTO 'dancesstepsmap' VALUES (29780, 10096, 2);
INSERT INTO 'dancesstepsmap' VALUES (29781, 10086, 5);
INSERT INTO 'dancesstepsmap' VALUES (29782, 10084, 2);
INSERT INTO 'dancesstepsmap' VALUES (29783, 10083, 5);
INSERT INTO 'dancesstepsmap' VALUES (29784, 10071, 2);
INSERT INTO 'dancesstepsmap' VALUES (29785, 10068, 2);
INSERT INTO 'dancesstepsmap' VALUES (29786, 10067, 2);
INSERT INTO 'dancesstepsmap' VALUES (29787, 10066, 5);
INSERT INTO 'dancesstepsmap' VALUES (29788, 10065, 2);
INSERT INTO 'dancesstepsmap' VALUES (29789, 10063, 4);
INSERT INTO 'dancesstepsmap' VALUES (29790, 10063, 5);
INSERT INTO 'dancesstepsmap' VALUES (29791, 10063, 1);
INSERT INTO 'dancesstepsmap' VALUES (29792, 10063, 2);
INSERT INTO 'dancesstepsmap' VALUES (29793, 10060, 1);
INSERT INTO 'dancesstepsmap' VALUES (29794, 10060, 2);
INSERT INTO 'dancesstepsmap' VALUES (29795, 10060, 4);
INSERT INTO 'dancesstepsmap' VALUES (29796, 10060, 5);
INSERT INTO 'dancesstepsmap' VALUES (29797, 10059, 2);
INSERT INTO 'dancesstepsmap' VALUES (29798, 10015, 5);
INSERT INTO 'dancesstepsmap' VALUES (29799, 10012, 5);
INSERT INTO 'dancesstepsmap' VALUES (29800, 10007, 2);
INSERT INTO 'dancesstepsmap' VALUES (29801, 9984, 5);
INSERT INTO 'dancesstepsmap' VALUES (29802, 9941, 5);
INSERT INTO 'dancesstepsmap' VALUES (29803, 9908, 2);
INSERT INTO 'dancesstepsmap' VALUES (29804, 9908, 1);
INSERT INTO 'dancesstepsmap' VALUES (29805, 9902, 2);
INSERT INTO 'dancesstepsmap' VALUES (29806, 9895, 5);
INSERT INTO 'dancesstepsmap' VALUES (29807, 9890, 3);
INSERT INTO 'dancesstepsmap' VALUES (29808, 9890, 2);
INSERT INTO 'dancesstepsmap' VALUES (29809, 9885, 2);
INSERT INTO 'dancesstepsmap' VALUES (29810, 9882, 5);
INSERT INTO 'dancesstepsmap' VALUES (29811, 9877, 5);
INSERT INTO 'dancesstepsmap' VALUES (29812, 9880, 2);
INSERT INTO 'dancesstepsmap' VALUES (29813, 9873, 5);
INSERT INTO 'dancesstepsmap' VALUES (29814, 9872, 5);
INSERT INTO 'dancesstepsmap' VALUES (29815, 9871, 2);
INSERT INTO 'dancesstepsmap' VALUES (29816, 3382, 2);
INSERT INTO 'dancesstepsmap' VALUES (29817, 9868, 2);
INSERT INTO 'dancesstepsmap' VALUES (29819, 9859, 2);
INSERT INTO 'dancesstepsmap' VALUES (29820, 9856, 2);
INSERT INTO 'dancesstepsmap' VALUES (29821, 9847, 3);
INSERT INTO 'dancesstepsmap' VALUES (29822, 20218, 2);
INSERT INTO 'dancesstepsmap' VALUES (29823, 20218, 1);
INSERT INTO 'dancesstepsmap' VALUES (29824, 10668, 1);
INSERT INTO 'dancesstepsmap' VALUES (29825, 10668, 2);
INSERT INTO 'dancesstepsmap' VALUES (29826, 9830, 5);
INSERT INTO 'dancesstepsmap' VALUES (29827, 9819, 2);
INSERT INTO 'dancesstepsmap' VALUES (29828, 20219, 3);
INSERT INTO 'dancesstepsmap' VALUES (29829, 20219, 1);
INSERT INTO 'dancesstepsmap' VALUES (29830, 1990, 5);
INSERT INTO 'dancesstepsmap' VALUES (29831, 20220, 4);
INSERT INTO 'dancesstepsmap' VALUES (29832, 20220, 5);
INSERT INTO 'dancesstepsmap' VALUES (29833, 17720, 3);
INSERT INTO 'dancesstepsmap' VALUES (29834, 9809, 1);
INSERT INTO 'dancesstepsmap' VALUES (29835, 9809, 2);
INSERT INTO 'dancesstepsmap' VALUES (29836, 17724, 1);
INSERT INTO 'dancesstepsmap' VALUES (29837, 17724, 3);
INSERT INTO 'dancesstepsmap' VALUES (29838, 20221, 3);
INSERT INTO 'dancesstepsmap' VALUES (29839, 20221, 7);
INSERT INTO 'dancesstepsmap' VALUES (29840, 17723, 1);
INSERT INTO 'dancesstepsmap' VALUES (29841, 17723, 2);
INSERT INTO 'dancesstepsmap' VALUES (29842, 17723, 3);
INSERT INTO 'dancesstepsmap' VALUES (29843, 9710, 2);
INSERT INTO 'dancesstepsmap' VALUES (29844, 9687, 2);
INSERT INTO 'dancesstepsmap' VALUES (29845, 9667, 1);
INSERT INTO 'dancesstepsmap' VALUES (29846, 11203, 1);
INSERT INTO 'dancesstepsmap' VALUES (29847, 11203, 2);
INSERT INTO 'dancesstepsmap' VALUES (29848, 3568, 6);
INSERT INTO 'dancesstepsmap' VALUES (29849, 20223, 1);
INSERT INTO 'dancesstepsmap' VALUES (29850, 20223, 2);
INSERT INTO 'dancesstepsmap' VALUES (29851, 20223, 3);
INSERT INTO 'dancesstepsmap' VALUES (29852, 20224, 4);
INSERT INTO 'dancesstepsmap' VALUES (29853, 20224, 5);
INSERT INTO 'dancesstepsmap' VALUES (29854, 20225, 1);
INSERT INTO 'dancesstepsmap' VALUES (29855, 20225, 2);
INSERT INTO 'dancesstepsmap' VALUES (29856, 9584, 2);
INSERT INTO 'dancesstepsmap' VALUES (29857, 9582, 2);
INSERT INTO 'dancesstepsmap' VALUES (29858, 9578, 3);
INSERT INTO 'dancesstepsmap' VALUES (29859, 9574, 2);
INSERT INTO 'dancesstepsmap' VALUES (29860, 8911, 1);
INSERT INTO 'dancesstepsmap' VALUES (29861, 8913, 1);
INSERT INTO 'dancesstepsmap' VALUES (29862, 8913, 2);
INSERT INTO 'dancesstepsmap' VALUES (29863, 20226, 4);
INSERT INTO 'dancesstepsmap' VALUES (29864, 20226, 5);
INSERT INTO 'dancesstepsmap' VALUES (29865, 20226, 1);
INSERT INTO 'dancesstepsmap' VALUES (29866, 20226, 2);
INSERT INTO 'dancesstepsmap' VALUES (29867, 20226, 3);
INSERT INTO 'dancesstepsmap' VALUES (29868, 9570, 2);
INSERT INTO 'dancesstepsmap' VALUES (29869, 9547, 2);
INSERT INTO 'dancesstepsmap' VALUES (29870, 9536, 1);
INSERT INTO 'dancesstepsmap' VALUES (29871, 9532, 5);
INSERT INTO 'dancesstepsmap' VALUES (29872, 9523, 2);
INSERT INTO 'dancesstepsmap' VALUES (29873, 8919, 1);
INSERT INTO 'dancesstepsmap' VALUES (29877, 18076, 2);
INSERT INTO 'dancesstepsmap' VALUES (29878, 18076, 1);
INSERT INTO 'dancesstepsmap' VALUES (29879, 9469, 2);
INSERT INTO 'dancesstepsmap' VALUES (29880, 9469, 3);
INSERT INTO 'dancesstepsmap' VALUES (29881, 8916, 1);
INSERT INTO 'dancesstepsmap' VALUES (29882, 8915, 1);
INSERT INTO 'dancesstepsmap' VALUES (29883, 8915, 2);
INSERT INTO 'dancesstepsmap' VALUES (29884, 9459, 2);
INSERT INTO 'dancesstepsmap' VALUES (29874, 20229, 4);
INSERT INTO 'dancesstepsmap' VALUES (29875, 20229, 5);
INSERT INTO 'dancesstepsmap' VALUES (29887, 9384, 2);
INSERT INTO 'dancesstepsmap' VALUES (29888, 9365, 2);
INSERT INTO 'dancesstepsmap' VALUES (29889, 9343, 5);
INSERT INTO 'dancesstepsmap' VALUES (29890, 9334, 5);
INSERT INTO 'dancesstepsmap' VALUES (29891, 8910, 4);
INSERT INTO 'dancesstepsmap' VALUES (10154, 9388, 2);
INSERT INTO 'dancesstepsmap' VALUES (29892, 9388, 3);
INSERT INTO 'dancesstepsmap' VALUES (29893, 2617, 2);
INSERT INTO 'dancesstepsmap' VALUES (29894, 2617, 3);
INSERT INTO 'dancesstepsmap' VALUES (29895, 9289, 3);
INSERT INTO 'dancesstepsmap' VALUES (29896, 9286, 3);
INSERT INTO 'dancesstepsmap' VALUES (29897, 9234, 2);
INSERT INTO 'dancesstepsmap' VALUES (29898, 9220, 2);
INSERT INTO 'dancesstepsmap' VALUES (29899, 4738, 2);
INSERT INTO 'dancesstepsmap' VALUES (29900, 9204, 2);
INSERT INTO 'dancesstepsmap' VALUES (29901, 9192, 2);
INSERT INTO 'dancesstepsmap' VALUES (29902, 16627, 4);
INSERT INTO 'dancesstepsmap' VALUES (29903, 16627, 5);
INSERT INTO 'dancesstepsmap' VALUES (29904, 16632, 1);
INSERT INTO 'dancesstepsmap' VALUES (29905, 9181, 2);
INSERT INTO 'dancesstepsmap' VALUES (29906, 16629, 4);
INSERT INTO 'dancesstepsmap' VALUES (29907, 16629, 5);
INSERT INTO 'dancesstepsmap' VALUES (29908, 20230, 3);
INSERT INTO 'dancesstepsmap' VALUES (29909, 20230, 1);
INSERT INTO 'dancesstepsmap' VALUES (29912, 16630, 1);
INSERT INTO 'dancesstepsmap' VALUES (29913, 16630, 2);
INSERT INTO 'dancesstepsmap' VALUES (29914, 4151, 2);
INSERT INTO 'dancesstepsmap' VALUES (29915, 9167, 2);
INSERT INTO 'dancesstepsmap' VALUES (29916, 9162, 5);
INSERT INTO 'dancesstepsmap' VALUES (29917, 9162, 4);
INSERT INTO 'dancesstepsmap' VALUES (29918, 9162, 1);
INSERT INTO 'dancesstepsmap' VALUES (29919, 2877, 2);
INSERT INTO 'dancesstepsmap' VALUES (29920, 2877, 3);
INSERT INTO 'dancesstepsmap' VALUES (29921, 10278, 2);
INSERT INTO 'dancesstepsmap' VALUES (29922, 10278, 3);
INSERT INTO 'dancesstepsmap' VALUES (29923, 20232, 2);
INSERT INTO 'dancesstepsmap' VALUES (29924, 20232, 1);
INSERT INTO 'dancesstepsmap' VALUES (29925, 20233, 4);
INSERT INTO 'dancesstepsmap' VALUES (29927, 20233, 5);
INSERT INTO 'dancesstepsmap' VALUES (29928, 9127, 5);
INSERT INTO 'dancesstepsmap' VALUES (29929, 20234, 1);
INSERT INTO 'dancesstepsmap' VALUES (29930, 20234, 2);
INSERT INTO 'dancesstepsmap' VALUES (29931, 9123, 1);
INSERT INTO 'dancesstepsmap' VALUES (29932, 9122, 5);
INSERT INTO 'dancesstepsmap' VALUES (29933, 20235, 5);
INSERT INTO 'dancesstepsmap' VALUES (29934, 20235, 4);
INSERT INTO 'dancesstepsmap' VALUES (29935, 10282, 2);
INSERT INTO 'dancesstepsmap' VALUES (29936, 20236, 4);
INSERT INTO 'dancesstepsmap' VALUES (29937, 20236, 5);
INSERT INTO 'dancesstepsmap' VALUES (29938, 20236, 1);
INSERT INTO 'dancesstepsmap' VALUES (29939, 20236, 2);
INSERT INTO 'dancesstepsmap' VALUES (29940, 20237, 4);
INSERT INTO 'dancesstepsmap' VALUES (29941, 20237, 5);
INSERT INTO 'dancesstepsmap' VALUES (29942, 18909, 1);
INSERT INTO 'dancesstepsmap' VALUES (29943, 18909, 2);
INSERT INTO 'dancesstepsmap' VALUES (29944, 9091, 2);
INSERT INTO 'dancesstepsmap' VALUES (29945, 9089, 2);
INSERT INTO 'dancesstepsmap' VALUES (29946, 20238, 1);
INSERT INTO 'dancesstepsmap' VALUES (29947, 20238, 2);
INSERT INTO 'dancesstepsmap' VALUES (29948, 4337, 2);
INSERT INTO 'dancesstepsmap' VALUES (29949, 4337, 3);
INSERT INTO 'dancesstepsmap' VALUES (29950, 20239, 1);
INSERT INTO 'dancesstepsmap' VALUES (29951, 9085, 1);
INSERT INTO 'dancesstepsmap' VALUES (29952, 9080, 3);
INSERT INTO 'dancesstepsmap' VALUES (29953, 20240, 4);
INSERT INTO 'dancesstepsmap' VALUES (29954, 13377, 10);
INSERT INTO 'dancesstepsmap' VALUES (29955, 20241, 4);
INSERT INTO 'dancesstepsmap' VALUES (29956, 20241, 5);
INSERT INTO 'dancesstepsmap' VALUES (29957, 19600, 1);
INSERT INTO 'dancesstepsmap' VALUES (29958, 19600, 3);
INSERT INTO 'dancesstepsmap' VALUES (29959, 17322, 4);
INSERT INTO 'dancesstepsmap' VALUES (29960, 17322, 5);
INSERT INTO 'dancesstepsmap' VALUES (29961, 17322, 1);
INSERT INTO 'dancesstepsmap' VALUES (29962, 17322, 2);
INSERT INTO 'dancesstepsmap' VALUES (29963, 20242, 1);
INSERT INTO 'dancesstepsmap' VALUES (29964, 20242, 2);
INSERT INTO 'dancesstepsmap' VALUES (29965, 20243, 1);
INSERT INTO 'dancesstepsmap' VALUES (29966, 20243, 2);
INSERT INTO 'dancesstepsmap' VALUES (29968, 9046, 2);
INSERT INTO 'dancesstepsmap' VALUES (29969, 20244, 4);
INSERT INTO 'dancesstepsmap' VALUES (29970, 20244, 5);
INSERT INTO 'dancesstepsmap' VALUES (29971, 9025, 5);
INSERT INTO 'dancesstepsmap' VALUES (29972, 9002, 2);
INSERT INTO 'dancesstepsmap' VALUES (29973, 20250, 1);
INSERT INTO 'dancesstepsmap' VALUES (29974, 20250, 2);
INSERT INTO 'dancesstepsmap' VALUES (29975, 20252, 1);
INSERT INTO 'dancesstepsmap' VALUES (29976, 20252, 2);
INSERT INTO 'dancesstepsmap' VALUES (29977, 8977, 2);
INSERT INTO 'dancesstepsmap' VALUES (29978, 8975, 2);
INSERT INTO 'dancesstepsmap' VALUES (29979, 8954, 5);
INSERT INTO 'dancesstepsmap' VALUES (29980, 8951, 2);
INSERT INTO 'dancesstepsmap' VALUES (29981, 20253, 1);
INSERT INTO 'dancesstepsmap' VALUES (29982, 20253, 3);
INSERT INTO 'dancesstepsmap' VALUES (29983, 12388, 2);
INSERT INTO 'dancesstepsmap' VALUES (29984, 2681, 2);
INSERT INTO 'dancesstepsmap' VALUES (29985, 20254, 1);
INSERT INTO 'dancesstepsmap' VALUES (29986, 20254, 3);
INSERT INTO 'dancesstepsmap' VALUES (29987, 14499, 4);
INSERT INTO 'dancesstepsmap' VALUES (29988, 14499, 5);
INSERT INTO 'dancesstepsmap' VALUES (29989, 16654, 1);
INSERT INTO 'dancesstepsmap' VALUES (29990, 16654, 2);
INSERT INTO 'dancesstepsmap' VALUES (29991, 16654, 3);
INSERT INTO 'dancesstepsmap' VALUES (29992, 20255, 1);
INSERT INTO 'dancesstepsmap' VALUES (29993, 20255, 2);
INSERT INTO 'dancesstepsmap' VALUES (29994, 20259, 4);
INSERT INTO 'dancesstepsmap' VALUES (29995, 20259, 5);
INSERT INTO 'dancesstepsmap' VALUES (29996, 2491, 2);
INSERT INTO 'dancesstepsmap' VALUES (30000, 20260, 1);
INSERT INTO 'dancesstepsmap' VALUES (30001, 20260, 2);
INSERT INTO 'dancesstepsmap' VALUES (30002, 20260, 3);
INSERT INTO 'dancesstepsmap' VALUES (30003, 20261, 1);
INSERT INTO 'dancesstepsmap' VALUES (30004, 20261, 2);
INSERT INTO 'dancesstepsmap' VALUES (30005, 20261, 3);
INSERT INTO 'dancesstepsmap' VALUES (30006, 20266, 4);
INSERT INTO 'dancesstepsmap' VALUES (30007, 20266, 5);
INSERT INTO 'dancesstepsmap' VALUES (30008, 9019, 1);
INSERT INTO 'dancesstepsmap' VALUES (30009, 9019, 2);
INSERT INTO 'dancesstepsmap' VALUES (30010, 8866, 5);
INSERT INTO 'dancesstepsmap' VALUES (30011, 8853, 5);
INSERT INTO 'dancesstepsmap' VALUES (12124, 9197, 1);
INSERT INTO 'dancesstepsmap' VALUES (12125, 9197, 2);
INSERT INTO 'dancesstepsmap' VALUES (30012, 2367, 2);
INSERT INTO 'dancesstepsmap' VALUES (30013, 20274, 5);
INSERT INTO 'dancesstepsmap' VALUES (30014, 20274, 4);
INSERT INTO 'dancesstepsmap' VALUES (30015, 20275, 4);
INSERT INTO 'dancesstepsmap' VALUES (30016, 20275, 5);
INSERT INTO 'dancesstepsmap' VALUES (29997, 9018, 4);
INSERT INTO 'dancesstepsmap' VALUES (29998, 9018, 5);
INSERT INTO 'dancesstepsmap' VALUES (29967, 9058, 5);
INSERT INTO 'dancesstepsmap' VALUES (30018, 20276, 2);
INSERT INTO 'dancesstepsmap' VALUES (30019, 20276, 1);
INSERT INTO 'dancesstepsmap' VALUES (30020, 20277, 4);
INSERT INTO 'dancesstepsmap' VALUES (30021, 20278, 2);
INSERT INTO 'dancesstepsmap' VALUES (30022, 20278, 1);
INSERT INTO 'dancesstepsmap' VALUES (30023, 20279, 4);
INSERT INTO 'dancesstepsmap' VALUES (30024, 20279, 5);
INSERT INTO 'dancesstepsmap' VALUES (30025, 20280, 2);
INSERT INTO 'dancesstepsmap' VALUES (30026, 20280, 1);
INSERT INTO 'dancesstepsmap' VALUES (30027, 20280, 3);
INSERT INTO 'dancesstepsmap' VALUES (30028, 9052, 5);
INSERT INTO 'dancesstepsmap' VALUES (30029, 8836, 2);
INSERT INTO 'dancesstepsmap' VALUES (30030, 8833, 5);
INSERT INTO 'dancesstepsmap' VALUES (30031, 8725, 2);
INSERT INTO 'dancesstepsmap' VALUES (30032, 8725, 1);
INSERT INTO 'dancesstepsmap' VALUES (30033, 8708, 2);
INSERT INTO 'dancesstepsmap' VALUES (30034, 8708, 1);
INSERT INTO 'dancesstepsmap' VALUES (30035, 8708, 5);
INSERT INTO 'dancesstepsmap' VALUES (30036, 8708, 4);
INSERT INTO 'dancesstepsmap' VALUES (30037, 8703, 2);
INSERT INTO 'dancesstepsmap' VALUES (30038, 8700, 2);
INSERT INTO 'dancesstepsmap' VALUES (30039, 8700, 3);
INSERT INTO 'dancesstepsmap' VALUES (30040, 8670, 2);
INSERT INTO 'dancesstepsmap' VALUES (30041, 8670, 3);
INSERT INTO 'dancesstepsmap' VALUES (30042, 8670, 4);
INSERT INTO 'dancesstepsmap' VALUES (30043, 8668, 2);
INSERT INTO 'dancesstepsmap' VALUES (30044, 8665, 2);
INSERT INTO 'dancesstepsmap' VALUES (30045, 20258, 4);
INSERT INTO 'dancesstepsmap' VALUES (30046, 20258, 5);
INSERT INTO 'dancesstepsmap' VALUES (30047, 20258, 6);
INSERT INTO 'dancesstepsmap' VALUES (30048, 3254, 2);
INSERT INTO 'dancesstepsmap' VALUES (30049, 8566, 5);
INSERT INTO 'dancesstepsmap' VALUES (30050, 3883, 2);
INSERT INTO 'dancesstepsmap' VALUES (30051, 6766, 3);
INSERT INTO 'dancesstepsmap' VALUES (30052, 3777, 10);
INSERT INTO 'dancesstepsmap' VALUES (30053, 3777, 6);
INSERT INTO 'dancesstepsmap' VALUES (30054, 8522, 2);
INSERT INTO 'dancesstepsmap' VALUES (30055, 8520, 2);
INSERT INTO 'dancesstepsmap' VALUES (30056, 8519, 2);
INSERT INTO 'dancesstepsmap' VALUES (30057, 8513, 2);
INSERT INTO 'dancesstepsmap' VALUES (30058, 8512, 2);
INSERT INTO 'dancesstepsmap' VALUES (30059, 8507, 2);
INSERT INTO 'dancesstepsmap' VALUES (30060, 8506, 2);
INSERT INTO 'dancesstepsmap' VALUES (30061, 8503, 2);
INSERT INTO 'dancesstepsmap' VALUES (30062, 8502, 2);
INSERT INTO 'dancesstepsmap' VALUES (30063, 8499, 2);
INSERT INTO 'dancesstepsmap' VALUES (30064, 7455, 3);
INSERT INTO 'dancesstepsmap' VALUES (30065, 20281, 1);
INSERT INTO 'dancesstepsmap' VALUES (30066, 20281, 2);
INSERT INTO 'dancesstepsmap' VALUES (30067, 8375, 2);
INSERT INTO 'dancesstepsmap' VALUES (30068, 8367, 5);
INSERT INTO 'dancesstepsmap' VALUES (30069, 8271, 5);
INSERT INTO 'dancesstepsmap' VALUES (30070, 7461, 2);
INSERT INTO 'dancesstepsmap' VALUES (30071, 8175, 5);
INSERT INTO 'dancesstepsmap' VALUES (30072, 7523, 3);
INSERT INTO 'dancesstepsmap' VALUES (30073, 7382, 2);
INSERT INTO 'dancesstepsmap' VALUES (14084, 12117, 1);
INSERT INTO 'dancesstepsmap' VALUES (14085, 12117, 3);
INSERT INTO 'dancesstepsmap' VALUES (30074, 8073, 2);
INSERT INTO 'dancesstepsmap' VALUES (30075, 8049, 2);
INSERT INTO 'dancesstepsmap' VALUES (30076, 8024, 2);
INSERT INTO 'dancesstepsmap' VALUES (30077, 20282, 1);
INSERT INTO 'dancesstepsmap' VALUES (30078, 20282, 2);
INSERT INTO 'dancesstepsmap' VALUES (30079, 20256, 1);
INSERT INTO 'dancesstepsmap' VALUES (30080, 20256, 2);
INSERT INTO 'dancesstepsmap' VALUES (30081, 7412, 2);
INSERT INTO 'dancesstepsmap' VALUES (30082, 7842, 5);
INSERT INTO 'dancesstepsmap' VALUES (30083, 7835, 5);
INSERT INTO 'dancesstepsmap' VALUES (30084, 7814, 2);
INSERT INTO 'dancesstepsmap' VALUES (30085, 7723, 5);
INSERT INTO 'dancesstepsmap' VALUES (30086, 7723, 4);
INSERT INTO 'dancesstepsmap' VALUES (30087, 7723, 1);
INSERT INTO 'dancesstepsmap' VALUES (30088, 7723, 2);
INSERT INTO 'dancesstepsmap' VALUES (30089, 7654, 3);
INSERT INTO 'dancesstepsmap' VALUES (30090, 7647, 5);
INSERT INTO 'dancesstepsmap' VALUES (30091, 20283, 4);
INSERT INTO 'dancesstepsmap' VALUES (30092, 7468, 2);
INSERT INTO 'dancesstepsmap' VALUES (30093, 7631, 2);
INSERT INTO 'dancesstepsmap' VALUES (30094, 7566, 2);
INSERT INTO 'dancesstepsmap' VALUES (30095, 7565, 2);
INSERT INTO 'dancesstepsmap' VALUES (30096, 7547, 4);
INSERT INTO 'dancesstepsmap' VALUES (30097, 7547, 5);
INSERT INTO 'dancesstepsmap' VALUES (30098, 7547, 2);
INSERT INTO 'dancesstepsmap' VALUES (30099, 7547, 1);
INSERT INTO 'dancesstepsmap' VALUES (30100, 7547, 3);
INSERT INTO 'dancesstepsmap' VALUES (30101, 7529, 2);
INSERT INTO 'dancesstepsmap' VALUES (30102, 7528, 5);
INSERT INTO 'dancesstepsmap' VALUES (30103, 7524, 2);
INSERT INTO 'dancesstepsmap' VALUES (30104, 7506, 5);
INSERT INTO 'dancesstepsmap' VALUES (30105, 7499, 2);
INSERT INTO 'dancesstepsmap' VALUES (30106, 7494, 5);
INSERT INTO 'dancesstepsmap' VALUES (30107, 7490, 3);
INSERT INTO 'dancesstepsmap' VALUES (30108, 7450, 2);
INSERT INTO 'dancesstepsmap' VALUES (30109, 7409, 2);
INSERT INTO 'dancesstepsmap' VALUES (30110, 7348, 5);
INSERT INTO 'dancesstepsmap' VALUES (30111, 13776, 2);
INSERT INTO 'dancesstepsmap' VALUES (30112, 13776, 1);
INSERT INTO 'dancesstepsmap' VALUES (30113, 13776, 3);
INSERT INTO 'dancesstepsmap' VALUES (30114, 7340, 5);
INSERT INTO 'dancesstepsmap' VALUES (30115, 20257, 4);
INSERT INTO 'dancesstepsmap' VALUES (30116, 20257, 5);
INSERT INTO 'dancesstepsmap' VALUES (30117, 20257, 1);
INSERT INTO 'dancesstepsmap' VALUES (30118, 20257, 2);
INSERT INTO 'dancesstepsmap' VALUES (30119, 7333, 2);
INSERT INTO 'dancesstepsmap' VALUES (30120, 7355, 2);
INSERT INTO 'dancesstepsmap' VALUES (30121, 4765, 2);
INSERT INTO 'dancesstepsmap' VALUES (30122, 3473, 2);
INSERT INTO 'dancesstepsmap' VALUES (30123, 20285, 1);
INSERT INTO 'dancesstepsmap' VALUES (30124, 20285, 2);
INSERT INTO 'dancesstepsmap' VALUES (30125, 7260, 2);
INSERT INTO 'dancesstepsmap' VALUES (30126, 7257, 5);
INSERT INTO 'dancesstepsmap' VALUES (30127, 7256, 5);
INSERT INTO 'dancesstepsmap' VALUES (30128, 7220, 2);
INSERT INTO 'dancesstepsmap' VALUES (30129, 20286, 1);
INSERT INTO 'dancesstepsmap' VALUES (30130, 20286, 2);
INSERT INTO 'dancesstepsmap' VALUES (30131, 7195, 3);
INSERT INTO 'dancesstepsmap' VALUES (30132, 7195, 2);
INSERT INTO 'dancesstepsmap' VALUES (30133, 7188, 5);
INSERT INTO 'dancesstepsmap' VALUES (30134, 7188, 9);
INSERT INTO 'dancesstepsmap' VALUES (30135, 7188, 10);
INSERT INTO 'dancesstepsmap' VALUES (30136, 7164, 5);
INSERT INTO 'dancesstepsmap' VALUES (17774, 15093, 1);
INSERT INTO 'dancesstepsmap' VALUES (17775, 15093, 2);
INSERT INTO 'dancesstepsmap' VALUES (30137, 20287, 5);
INSERT INTO 'dancesstepsmap' VALUES (30138, 20287, 4);
INSERT INTO 'dancesstepsmap' VALUES (30139, 20287, 2);
INSERT INTO 'dancesstepsmap' VALUES (30140, 20287, 1);
INSERT INTO 'dancesstepsmap' VALUES (30141, 20287, 3);
INSERT INTO 'dancesstepsmap' VALUES (30142, 20289, 1);
INSERT INTO 'dancesstepsmap' VALUES (30143, 20289, 2);
INSERT INTO 'dancesstepsmap' VALUES (30144, 7157, 5);
INSERT INTO 'dancesstepsmap' VALUES (30145, 7143, 5);
INSERT INTO 'dancesstepsmap' VALUES (30146, 7142, 2);
INSERT INTO 'dancesstepsmap' VALUES (30147, 7110, 5);
INSERT INTO 'dancesstepsmap' VALUES (30148, 20290, 4);
INSERT INTO 'dancesstepsmap' VALUES (30149, 20290, 5);
INSERT INTO 'dancesstepsmap' VALUES (30150, 7093, 2);
INSERT INTO 'dancesstepsmap' VALUES (30151, 7081, 2);
INSERT INTO 'dancesstepsmap' VALUES (30152, 7073, 2);
INSERT INTO 'dancesstepsmap' VALUES (30153, 7071, 2);
INSERT INTO 'dancesstepsmap' VALUES (30154, 20240, 5);
INSERT INTO 'dancesstepsmap' VALUES (30155, 12737, 2);
INSERT INTO 'dancesstepsmap' VALUES (30156, 7027, 5);
INSERT INTO 'dancesstepsmap' VALUES (30157, 7016, 5);
INSERT INTO 'dancesstepsmap' VALUES (30158, 7013, 5);
INSERT INTO 'dancesstepsmap' VALUES (30159, 20292, 1);
INSERT INTO 'dancesstepsmap' VALUES (30160, 15238, 3);
INSERT INTO 'dancesstepsmap' VALUES (30161, 15238, 1);
INSERT INTO 'dancesstepsmap' VALUES (30162, 12354, 2);
INSERT INTO 'dancesstepsmap' VALUES (30163, 12354, 1);
INSERT INTO 'dancesstepsmap' VALUES (30164, 11758, 5);
INSERT INTO 'dancesstepsmap' VALUES (30165, 1573, 5);
INSERT INTO 'dancesstepsmap' VALUES (30166, 4896, 5);
INSERT INTO 'dancesstepsmap' VALUES (30167, 4896, 9);
INSERT INTO 'dancesstepsmap' VALUES (30168, 4896, 10);
INSERT INTO 'dancesstepsmap' VALUES (30169, 5142, 2);
INSERT INTO 'dancesstepsmap' VALUES (30170, 20293, 4);
INSERT INTO 'dancesstepsmap' VALUES (30171, 5984, 2);
INSERT INTO 'dancesstepsmap' VALUES (30172, 5984, 3);
INSERT INTO 'dancesstepsmap' VALUES (30173, 20294, 1);
INSERT INTO 'dancesstepsmap' VALUES (30174, 20294, 2);
INSERT INTO 'dancesstepsmap' VALUES (30175, 20294, 3);
INSERT INTO 'dancesstepsmap' VALUES (30176, 6606, 2);
INSERT INTO 'dancesstepsmap' VALUES (30177, 11323, 1);
INSERT INTO 'dancesstepsmap' VALUES (30178, 11323, 2);
INSERT INTO 'dancesstepsmap' VALUES (30179, 10842, 5);
INSERT INTO 'dancesstepsmap' VALUES (30180, 6941, 5);
INSERT INTO 'dancesstepsmap' VALUES (30181, 6913, 5);
INSERT INTO 'dancesstepsmap' VALUES (30182, 6879, 5);
INSERT INTO 'dancesstepsmap' VALUES (30183, 6876, 2);
INSERT INTO 'dancesstepsmap' VALUES (30184, 6870, 2);
INSERT INTO 'dancesstepsmap' VALUES (30185, 6853, 2);
INSERT INTO 'dancesstepsmap' VALUES (30186, 6849, 2);
INSERT INTO 'dancesstepsmap' VALUES (30187, 6847, 2);
INSERT INTO 'dancesstepsmap' VALUES (30188, 6833, 2);
INSERT INTO 'dancesstepsmap' VALUES (30189, 2639, 2);
INSERT INTO 'dancesstepsmap' VALUES (30190, 20295, 4);
INSERT INTO 'dancesstepsmap' VALUES (30191, 20295, 5);
INSERT INTO 'dancesstepsmap' VALUES (30193, 20300, 1);
INSERT INTO 'dancesstepsmap' VALUES (30194, 20300, 2);
INSERT INTO 'dancesstepsmap' VALUES (30195, 10199, 1);
INSERT INTO 'dancesstepsmap' VALUES (30196, 6783, 2);
INSERT INTO 'dancesstepsmap' VALUES (30197, 6767, 5);
INSERT INTO 'dancesstepsmap' VALUES (30198, 20296, 1);
INSERT INTO 'dancesstepsmap' VALUES (30199, 6758, 2);
INSERT INTO 'dancesstepsmap' VALUES (30200, 6758, 3);
INSERT INTO 'dancesstepsmap' VALUES (30201, 6705, 2);
INSERT INTO 'dancesstepsmap' VALUES (30202, 20298, 1);
INSERT INTO 'dancesstepsmap' VALUES (30203, 20298, 2);
INSERT INTO 'dancesstepsmap' VALUES (30204, 6675, 5);
INSERT INTO 'dancesstepsmap' VALUES (30205, 20299, 4);
INSERT INTO 'dancesstepsmap' VALUES (30206, 20299, 5);
INSERT INTO 'dancesstepsmap' VALUES (30207, 6899, 3);
INSERT INTO 'dancesstepsmap' VALUES (30208, 20302, 4);
INSERT INTO 'dancesstepsmap' VALUES (30209, 20302, 5);
INSERT INTO 'dancesstepsmap' VALUES (30210, 20302, 1);
INSERT INTO 'dancesstepsmap' VALUES (30211, 20302, 2);
INSERT INTO 'dancesstepsmap' VALUES (30212, 20305, 1);
INSERT INTO 'dancesstepsmap' VALUES (30213, 20305, 2);
INSERT INTO 'dancesstepsmap' VALUES (30214, 20305, 3);
INSERT INTO 'dancesstepsmap' VALUES (30215, 20306, 1);
INSERT INTO 'dancesstepsmap' VALUES (30216, 20304, 1);
INSERT INTO 'dancesstepsmap' VALUES (30217, 20303, 1);
INSERT INTO 'dancesstepsmap' VALUES (30218, 5534, 3);
INSERT INTO 'dancesstepsmap' VALUES (30219, 5332, 4);
INSERT INTO 'dancesstepsmap' VALUES (30220, 5332, 3);
INSERT INTO 'dancesstepsmap' VALUES (30221, 5332, 1);
INSERT INTO 'dancesstepsmap' VALUES (30222, 5324, 5);
INSERT INTO 'dancesstepsmap' VALUES (30223, 5001, 5);
INSERT INTO 'dancesstepsmap' VALUES (30224, 6618, 2);
INSERT INTO 'dancesstepsmap' VALUES (30225, 6616, 5);
INSERT INTO 'dancesstepsmap' VALUES (30226, 6616, 4);
INSERT INTO 'dancesstepsmap' VALUES (30227, 6616, 2);
INSERT INTO 'dancesstepsmap' VALUES (30228, 6616, 1);
INSERT INTO 'dancesstepsmap' VALUES (30229, 6600, 2);
INSERT INTO 'dancesstepsmap' VALUES (30230, 3238, 5);
INSERT INTO 'dancesstepsmap' VALUES (30231, 3053, 2);
INSERT INTO 'dancesstepsmap' VALUES (30232, 3051, 2);
INSERT INTO 'dancesstepsmap' VALUES (30233, 2914, 5);
INSERT INTO 'dancesstepsmap' VALUES (30234, 2914, 4);
INSERT INTO 'dancesstepsmap' VALUES (30235, 2914, 10);
INSERT INTO 'dancesstepsmap' VALUES (30236, 2914, 2);
INSERT INTO 'dancesstepsmap' VALUES (30237, 2914, 1);
INSERT INTO 'dancesstepsmap' VALUES (30238, 2914, 102);
INSERT INTO 'dancesstepsmap' VALUES (30239, 2914, 3);
INSERT INTO 'dancesstepsmap' VALUES (30240, 20307, 2);
INSERT INTO 'dancesstepsmap' VALUES (30241, 20307, 1);
INSERT INTO 'dancesstepsmap' VALUES (30242, 20297, 4);
INSERT INTO 'dancesstepsmap' VALUES (30243, 20297, 5);
INSERT INTO 'dancesstepsmap' VALUES (30244, 1862, 4);
INSERT INTO 'dancesstepsmap' VALUES (30245, 1862, 5);
INSERT INTO 'dancesstepsmap' VALUES (30246, 1862, 2);
INSERT INTO 'dancesstepsmap' VALUES (30247, 1862, 1);
INSERT INTO 'dancesstepsmap' VALUES (30248, 1862, 3);
INSERT INTO 'dancesstepsmap' VALUES (30249, 1577, 5);
INSERT INTO 'dancesstepsmap' VALUES (30250, 2813, 5);
INSERT INTO 'dancesstepsmap' VALUES (30251, 20284, 4);
INSERT INTO 'dancesstepsmap' VALUES (30252, 20284, 5);
INSERT INTO 'dancesstepsmap' VALUES (30253, 3067, 5);
INSERT INTO 'dancesstepsmap' VALUES (30254, 6093, 5);
INSERT INTO 'dancesstepsmap' VALUES (30255, 5109, 4);
INSERT INTO 'dancesstepsmap' VALUES (30256, 5109, 6);
INSERT INTO 'dancesstepsmap' VALUES (30257, 5109, 5);
INSERT INTO 'dancesstepsmap' VALUES (30258, 5109, 1);
INSERT INTO 'dancesstepsmap' VALUES (30259, 5109, 3);
INSERT INTO 'dancesstepsmap' VALUES (30260, 6456, 4);
INSERT INTO 'dancesstepsmap' VALUES (30261, 6456, 5);
INSERT INTO 'dancesstepsmap' VALUES (30262, 6456, 1);
INSERT INTO 'dancesstepsmap' VALUES (30263, 6456, 2);
INSERT INTO 'dancesstepsmap' VALUES (30264, 7270, 1);
INSERT INTO 'dancesstepsmap' VALUES (30265, 7270, 2);
INSERT INTO 'dancesstepsmap' VALUES (30266, 7270, 4);
INSERT INTO 'dancesstepsmap' VALUES (30267, 7270, 6);
INSERT INTO 'dancesstepsmap' VALUES (30268, 7270, 10);
INSERT INTO 'dancesstepsmap' VALUES (30269, 7270, 9);
INSERT INTO 'dancesstepsmap' VALUES (30270, 6586, 5);
INSERT INTO 'dancesstepsmap' VALUES (30271, 15673, 4);
INSERT INTO 'dancesstepsmap' VALUES (30272, 15672, 1);
INSERT INTO 'dancesstepsmap' VALUES (30273, 15672, 2);
INSERT INTO 'dancesstepsmap' VALUES (30274, 6550, 2);
INSERT INTO 'dancesstepsmap' VALUES (30275, 3470, 5);
INSERT INTO 'dancesstepsmap' VALUES (30276, 15669, 4);
INSERT INTO 'dancesstepsmap' VALUES (30277, 15669, 5);
INSERT INTO 'dancesstepsmap' VALUES (30278, 6526, 5);
INSERT INTO 'dancesstepsmap' VALUES (30279, 6518, 5);
INSERT INTO 'dancesstepsmap' VALUES (30280, 6484, 2);
INSERT INTO 'dancesstepsmap' VALUES (30281, 6485, 2);
INSERT INTO 'dancesstepsmap' VALUES (30282, 20308, 1);
INSERT INTO 'dancesstepsmap' VALUES (30283, 20308, 2);
INSERT INTO 'dancesstepsmap' VALUES (30284, 6478, 2);
INSERT INTO 'dancesstepsmap' VALUES (30285, 19566, 1);
INSERT INTO 'dancesstepsmap' VALUES (30286, 19566, 2);
INSERT INTO 'dancesstepsmap' VALUES (30287, 19566, 3);
INSERT INTO 'dancesstepsmap' VALUES (30288, 6397, 5);
INSERT INTO 'dancesstepsmap' VALUES (30289, 2706, 2);
INSERT INTO 'dancesstepsmap' VALUES (30290, 6380, 2);
INSERT INTO 'dancesstepsmap' VALUES (30291, 6358, 5);
INSERT INTO 'dancesstepsmap' VALUES (30292, 6319, 5);
INSERT INTO 'dancesstepsmap' VALUES (30293, 6289, 2);
INSERT INTO 'dancesstepsmap' VALUES (30294, 20310, 1);
INSERT INTO 'dancesstepsmap' VALUES (30295, 20310, 2);
INSERT INTO 'dancesstepsmap' VALUES (30296, 6135, 2);
INSERT INTO 'dancesstepsmap' VALUES (30297, 6098, 5);
INSERT INTO 'dancesstepsmap' VALUES (30298, 6055, 2);
INSERT INTO 'dancesstepsmap' VALUES (30299, 6053, 2);
INSERT INTO 'dancesstepsmap' VALUES (30300, 6025, 2);
INSERT INTO 'dancesstepsmap' VALUES (30301, 4261, 5);
INSERT INTO 'dancesstepsmap' VALUES (30302, 20323, 4);
INSERT INTO 'dancesstepsmap' VALUES (30303, 20323, 5);
INSERT INTO 'dancesstepsmap' VALUES (30304, 20311, 1);
INSERT INTO 'dancesstepsmap' VALUES (30305, 20311, 2);
INSERT INTO 'dancesstepsmap' VALUES (30306, 20311, 3);
INSERT INTO 'dancesstepsmap' VALUES (30307, 20324, 1);
INSERT INTO 'dancesstepsmap' VALUES (30308, 20319, 4);
INSERT INTO 'dancesstepsmap' VALUES (30309, 20319, 5);
INSERT INTO 'dancesstepsmap' VALUES (30310, 20319, 1);
INSERT INTO 'dancesstepsmap' VALUES (30311, 20319, 2);
INSERT INTO 'dancesstepsmap' VALUES (30312, 5981, 3);
INSERT INTO 'dancesstepsmap' VALUES (30313, 5961, 3);
INSERT INTO 'dancesstepsmap' VALUES (30314, 5945, 5);
INSERT INTO 'dancesstepsmap' VALUES (30315, 20326, 1);
INSERT INTO 'dancesstepsmap' VALUES (30316, 20326, 2);
INSERT INTO 'dancesstepsmap' VALUES (30317, 4895, 5);
INSERT INTO 'dancesstepsmap' VALUES (30318, 5897, 5);
INSERT INTO 'dancesstepsmap' VALUES (30319, 5868, 2);
INSERT INTO 'dancesstepsmap' VALUES (30320, 5763, 2);
INSERT INTO 'dancesstepsmap' VALUES (30321, 1119, 3);
INSERT INTO 'dancesstepsmap' VALUES (30322, 1119, 2);
INSERT INTO 'dancesstepsmap' VALUES (30323, 7144, 2);
INSERT INTO 'dancesstepsmap' VALUES (30324, 795, 5);
INSERT INTO 'dancesstepsmap' VALUES (30325, 550, 5);
INSERT INTO 'dancesstepsmap' VALUES (30326, 5385, 2);
INSERT INTO 'dancesstepsmap' VALUES (30327, 2223, 2);
INSERT INTO 'dancesstepsmap' VALUES (30328, 3551, 5);
INSERT INTO 'dancesstepsmap' VALUES (30329, 3551, 6);
INSERT INTO 'dancesstepsmap' VALUES (30330, 4373, 5);
INSERT INTO 'dancesstepsmap' VALUES (30331, 3662, 4);
INSERT INTO 'dancesstepsmap' VALUES (30332, 3662, 1);
INSERT INTO 'dancesstepsmap' VALUES (30333, 2535, 5);
INSERT INTO 'dancesstepsmap' VALUES (30334, 20327, 1);
INSERT INTO 'dancesstepsmap' VALUES (30335, 20327, 3);
INSERT INTO 'dancesstepsmap' VALUES (30336, 893, 5);
INSERT INTO 'dancesstepsmap' VALUES (30337, 4211, 5);
INSERT INTO 'dancesstepsmap' VALUES (30338, 1300, 2);
INSERT INTO 'dancesstepsmap' VALUES (30339, 4047, 2);
INSERT INTO 'dancesstepsmap' VALUES (30340, 4047, 3);
INSERT INTO 'dancesstepsmap' VALUES (30341, 3106, 5);
INSERT INTO 'dancesstepsmap' VALUES (30342, 5307, 5);
INSERT INTO 'dancesstepsmap' VALUES (30343, 5661, 2);
INSERT INTO 'dancesstepsmap' VALUES (30344, 5303, 5);
INSERT INTO 'dancesstepsmap' VALUES (30345, 491, 6);
INSERT INTO 'dancesstepsmap' VALUES (30346, 491, 10);
INSERT INTO 'dancesstepsmap' VALUES (30347, 6207, 5);
INSERT INTO 'dancesstepsmap' VALUES (30348, 6691, 4);
INSERT INTO 'dancesstepsmap' VALUES (30349, 6691, 5);
INSERT INTO 'dancesstepsmap' VALUES (30350, 6691, 1);
INSERT INTO 'dancesstepsmap' VALUES (30351, 6691, 2);
INSERT INTO 'dancesstepsmap' VALUES (30352, 4999, 2);
INSERT INTO 'dancesstepsmap' VALUES (30353, 4999, 3);
INSERT INTO 'dancesstepsmap' VALUES (30354, 20328, 1);
INSERT INTO 'dancesstepsmap' VALUES (30355, 20328, 2);
INSERT INTO 'dancesstepsmap' VALUES (30356, 20328, 3);
INSERT INTO 'dancesstepsmap' VALUES (30357, 20331, 4);
INSERT INTO 'dancesstepsmap' VALUES (30358, 20331, 5);
INSERT INTO 'dancesstepsmap' VALUES (30359, 20333, 1);
INSERT INTO 'dancesstepsmap' VALUES (30360, 20333, 2);
INSERT INTO 'dancesstepsmap' VALUES (30361, 5893, 2);
INSERT INTO 'dancesstepsmap' VALUES (30362, 5840, 2);
INSERT INTO 'dancesstepsmap' VALUES (30363, 5839, 5);
INSERT INTO 'dancesstepsmap' VALUES (30364, 5798, 3);
INSERT INTO 'dancesstepsmap' VALUES (30365, 5798, 2);
INSERT INTO 'dancesstepsmap' VALUES (30366, 20330, 4);
INSERT INTO 'dancesstepsmap' VALUES (30367, 20330, 5);
INSERT INTO 'dancesstepsmap' VALUES (30368, 20330, 1);
INSERT INTO 'dancesstepsmap' VALUES (30369, 20330, 2);
INSERT INTO 'dancesstepsmap' VALUES (30370, 5710, 2);
INSERT INTO 'dancesstepsmap' VALUES (30371, 20334, 4);
INSERT INTO 'dancesstepsmap' VALUES (30372, 5687, 2);
INSERT INTO 'dancesstepsmap' VALUES (30373, 20335, 4);
INSERT INTO 'dancesstepsmap' VALUES (30374, 20335, 5);
INSERT INTO 'dancesstepsmap' VALUES (30375, 5671, 5);
INSERT INTO 'dancesstepsmap' VALUES (30376, 5669, 5);
INSERT INTO 'dancesstepsmap' VALUES (30377, 5669, 10);
INSERT INTO 'dancesstepsmap' VALUES (30378, 5648, 2);
INSERT INTO 'dancesstepsmap' VALUES (30379, 5643, 2);
INSERT INTO 'dancesstepsmap' VALUES (30380, 20332, 1);
INSERT INTO 'dancesstepsmap' VALUES (30381, 20332, 2);
INSERT INTO 'dancesstepsmap' VALUES (30382, 20336, 5);
INSERT INTO 'dancesstepsmap' VALUES (30383, 20336, 4);
INSERT INTO 'dancesstepsmap' VALUES (30384, 5571, 6);
INSERT INTO 'dancesstepsmap' VALUES (30385, 5571, 5);
INSERT INTO 'dancesstepsmap' VALUES (30386, 5568, 2);
INSERT INTO 'dancesstepsmap' VALUES (30387, 5493, 2);
INSERT INTO 'dancesstepsmap' VALUES (30388, 5487, 2);
INSERT INTO 'dancesstepsmap' VALUES (30389, 5434, 2);
INSERT INTO 'dancesstepsmap' VALUES (30391, 5410, 6);
INSERT INTO 'dancesstepsmap' VALUES (30392, 5398, 2);
INSERT INTO 'dancesstepsmap' VALUES (30393, 5378, 5);
INSERT INTO 'dancesstepsmap' VALUES (30394, 5364, 5);
INSERT INTO 'dancesstepsmap' VALUES (30395, 5358, 2);
INSERT INTO 'dancesstepsmap' VALUES (30396, 5350, 2);
INSERT INTO 'dancesstepsmap' VALUES (30397, 5282, 2);
INSERT INTO 'dancesstepsmap' VALUES (30398, 5282, 3);
INSERT INTO 'dancesstepsmap' VALUES (30399, 5281, 2);
INSERT INTO 'dancesstepsmap' VALUES (30400, 5276, 6);
INSERT INTO 'dancesstepsmap' VALUES (30401, 9630, 1);
INSERT INTO 'dancesstepsmap' VALUES (30402, 9630, 2);
INSERT INTO 'dancesstepsmap' VALUES (30403, 5102, 2);
INSERT INTO 'dancesstepsmap' VALUES (30404, 5088, 2);
INSERT INTO 'dancesstepsmap' VALUES (30405, 5027, 5);
INSERT INTO 'dancesstepsmap' VALUES (30406, 4991, 5);
INSERT INTO 'dancesstepsmap' VALUES (30407, 20325, 1);
INSERT INTO 'dancesstepsmap' VALUES (30408, 20325, 3);
INSERT INTO 'dancesstepsmap' VALUES (30409, 9617, 4);
INSERT INTO 'dancesstepsmap' VALUES (30410, 9617, 5);
INSERT INTO 'dancesstepsmap' VALUES (30411, 4271, 2);
INSERT INTO 'dancesstepsmap' VALUES (30412, 4271, 10);
INSERT INTO 'dancesstepsmap' VALUES (30413, 1881, 2);
INSERT INTO 'dancesstepsmap' VALUES (30414, 3651, 2);
INSERT INTO 'dancesstepsmap' VALUES (30415, 3680, 2);
INSERT INTO 'dancesstepsmap' VALUES (30416, 5699, 2);
INSERT INTO 'dancesstepsmap' VALUES (30417, 5699, 99);
INSERT INTO 'dancesstepsmap' VALUES (30418, 4282, 4);
INSERT INTO 'dancesstepsmap' VALUES (30419, 4282, 9);
INSERT INTO 'dancesstepsmap' VALUES (30420, 4282, 2);
INSERT INTO 'dancesstepsmap' VALUES (30421, 4282, 102);
INSERT INTO 'dancesstepsmap' VALUES (30422, 4282, 1);
INSERT INTO 'dancesstepsmap' VALUES (30423, 4045, 5);
INSERT INTO 'dancesstepsmap' VALUES (30424, 4045, 4);
INSERT INTO 'dancesstepsmap' VALUES (30425, 20337, 1);
INSERT INTO 'dancesstepsmap' VALUES (30426, 4988, 5);
INSERT INTO 'dancesstepsmap' VALUES (30427, 4951, 2);
INSERT INTO 'dancesstepsmap' VALUES (30428, 4932, 5);
INSERT INTO 'dancesstepsmap' VALUES (30429, 4888, 2);
INSERT INTO 'dancesstepsmap' VALUES (30430, 4888, 3);
INSERT INTO 'dancesstepsmap' VALUES (30431, 20338, 1);
INSERT INTO 'dancesstepsmap' VALUES (30432, 20339, 1);
INSERT INTO 'dancesstepsmap' VALUES (30433, 20339, 2);
INSERT INTO 'dancesstepsmap' VALUES (30434, 20340, 3);
INSERT INTO 'dancesstepsmap' VALUES (30435, 20340, 2);
INSERT INTO 'dancesstepsmap' VALUES (30436, 20340, 1);
INSERT INTO 'dancesstepsmap' VALUES (30437, 20341, 1);
INSERT INTO 'dancesstepsmap' VALUES (30438, 20341, 2);
INSERT INTO 'dancesstepsmap' VALUES (30439, 20342, 1);
INSERT INTO 'dancesstepsmap' VALUES (30440, 20342, 2);
INSERT INTO 'dancesstepsmap' VALUES (30441, 4752, 5);
INSERT INTO 'dancesstepsmap' VALUES (30442, 5491, 2);
INSERT INTO 'dancesstepsmap' VALUES (30443, 4746, 5);
INSERT INTO 'dancesstepsmap' VALUES (30444, 4727, 5);
INSERT INTO 'dancesstepsmap' VALUES (30445, 4666, 2);
INSERT INTO 'dancesstepsmap' VALUES (30446, 4666, 3);
INSERT INTO 'dancesstepsmap' VALUES (30447, 4642, 4);
INSERT INTO 'dancesstepsmap' VALUES (30448, 4642, 2);
INSERT INTO 'dancesstepsmap' VALUES (30449, 4642, 1);
INSERT INTO 'dancesstepsmap' VALUES (30450, 20343, 4);
INSERT INTO 'dancesstepsmap' VALUES (30451, 20343, 5);
INSERT INTO 'dancesstepsmap' VALUES (30452, 4597, 2);
INSERT INTO 'dancesstepsmap' VALUES (30453, 4595, 2);
INSERT INTO 'dancesstepsmap' VALUES (30454, 4581, 2);
INSERT INTO 'dancesstepsmap' VALUES (30455, 4562, 2);
INSERT INTO 'dancesstepsmap' VALUES (30456, 4561, 5);
INSERT INTO 'dancesstepsmap' VALUES (30457, 4512, 2);
INSERT INTO 'dancesstepsmap' VALUES (30458, 4487, 2);
INSERT INTO 'dancesstepsmap' VALUES (30459, 4484, 5);
INSERT INTO 'dancesstepsmap' VALUES (30460, 3552, 5);
INSERT INTO 'dancesstepsmap' VALUES (30461, 4441, 2);
INSERT INTO 'dancesstepsmap' VALUES (30462, 4439, 5);
INSERT INTO 'dancesstepsmap' VALUES (30463, 4422, 2);
INSERT INTO 'dancesstepsmap' VALUES (30464, 4398, 5);
INSERT INTO 'dancesstepsmap' VALUES (30465, 4397, 4);
INSERT INTO 'dancesstepsmap' VALUES (30466, 4397, 5);
INSERT INTO 'dancesstepsmap' VALUES (30467, 4397, 1);
INSERT INTO 'dancesstepsmap' VALUES (30468, 4397, 2);
INSERT INTO 'dancesstepsmap' VALUES (30469, 4346, 2);
INSERT INTO 'dancesstepsmap' VALUES (30470, 4374, 5);
INSERT INTO 'dancesstepsmap' VALUES (30471, 4318, 2);
INSERT INTO 'dancesstepsmap' VALUES (30472, 4280, 5);
INSERT INTO 'dancesstepsmap' VALUES (30473, 4279, 2);
INSERT INTO 'dancesstepsmap' VALUES (30474, 4268, 3);
INSERT INTO 'dancesstepsmap' VALUES (30475, 4262, 2);
INSERT INTO 'dancesstepsmap' VALUES (30476, 4238, 2);
INSERT INTO 'dancesstepsmap' VALUES (30477, 4227, 2);
INSERT INTO 'dancesstepsmap' VALUES (30478, 4222, 5);
INSERT INTO 'dancesstepsmap' VALUES (30479, 4196, 5);
INSERT INTO 'dancesstepsmap' VALUES (30480, 4183, 2);
INSERT INTO 'dancesstepsmap' VALUES (30481, 4169, 5);
INSERT INTO 'dancesstepsmap' VALUES (30482, 4155, 5);
INSERT INTO 'dancesstepsmap' VALUES (30483, 4142, 2);
INSERT INTO 'dancesstepsmap' VALUES (30484, 4142, 3);
INSERT INTO 'dancesstepsmap' VALUES (30485, 4140, 2);
INSERT INTO 'dancesstepsmap' VALUES (30486, 5979, 3);
INSERT INTO 'dancesstepsmap' VALUES (30487, 6024, 4);
INSERT INTO 'dancesstepsmap' VALUES (30488, 6024, 3);
INSERT INTO 'dancesstepsmap' VALUES (30489, 6024, 2);
INSERT INTO 'dancesstepsmap' VALUES (30490, 4115, 5);
INSERT INTO 'dancesstepsmap' VALUES (30491, 4087, 5);
INSERT INTO 'dancesstepsmap' VALUES (30492, 4064, 5);
INSERT INTO 'dancesstepsmap' VALUES (30493, 6067, 3);
INSERT INTO 'dancesstepsmap' VALUES (30494, 4019, 5);
INSERT INTO 'dancesstepsmap' VALUES (30495, 6290, 2);
INSERT INTO 'dancesstepsmap' VALUES (30496, 5962, 2);
INSERT INTO 'dancesstepsmap' VALUES (30497, 59, 2);
INSERT INTO 'dancesstepsmap' VALUES (30498, 4688, 2);
INSERT INTO 'dancesstepsmap' VALUES (30499, 237, 2);
INSERT INTO 'dancesstepsmap' VALUES (30500, 2980, 2);
INSERT INTO 'dancesstepsmap' VALUES (30501, 3938, 2);
INSERT INTO 'dancesstepsmap' VALUES (30502, 3932, 5);
INSERT INTO 'dancesstepsmap' VALUES (30503, 3931, 2);
INSERT INTO 'dancesstepsmap' VALUES (30504, 3918, 5);
INSERT INTO 'dancesstepsmap' VALUES (30505, 3908, 5);
INSERT INTO 'dancesstepsmap' VALUES (30506, 3876, 2);
INSERT INTO 'dancesstepsmap' VALUES (30507, 6322, 3);
INSERT INTO 'dancesstepsmap' VALUES (30509, 6357, 3);
INSERT INTO 'dancesstepsmap' VALUES (30510, 6357, 2);
INSERT INTO 'dancesstepsmap' VALUES (30511, 3859, 6);
INSERT INTO 'dancesstepsmap' VALUES (30512, 3845, 2);
INSERT INTO 'dancesstepsmap' VALUES (30513, 3833, 4);
INSERT INTO 'dancesstepsmap' VALUES (30514, 3833, 1);
INSERT INTO 'dancesstepsmap' VALUES (30515, 3814, 5);
INSERT INTO 'dancesstepsmap' VALUES (30516, 3792, 2);
INSERT INTO 'dancesstepsmap' VALUES (30517, 3784, 5);
INSERT INTO 'dancesstepsmap' VALUES (30518, 3783, 2);
INSERT INTO 'dancesstepsmap' VALUES (30519, 3781, 5);
INSERT INTO 'dancesstepsmap' VALUES (30520, 3769, 2);
INSERT INTO 'dancesstepsmap' VALUES (30521, 3747, 2);
INSERT INTO 'dancesstepsmap' VALUES (30522, 3728, 5);
INSERT INTO 'dancesstepsmap' VALUES (30523, 3723, 5);
INSERT INTO 'dancesstepsmap' VALUES (30524, 6447, 5);
INSERT INTO 'dancesstepsmap' VALUES (30525, 6429, 2);
INSERT INTO 'dancesstepsmap' VALUES (30526, 6508, 6);
INSERT INTO 'dancesstepsmap' VALUES (30527, 6508, 5);
INSERT INTO 'dancesstepsmap' VALUES (30528, 3706, 5);
INSERT INTO 'dancesstepsmap' VALUES (30529, 3704, 2);
INSERT INTO 'dancesstepsmap' VALUES (30530, 3691, 2);
INSERT INTO 'dancesstepsmap' VALUES (30531, 3660, 2);
INSERT INTO 'dancesstepsmap' VALUES (30532, 3659, 2);
INSERT INTO 'dancesstepsmap' VALUES (30533, 1099, 2);
INSERT INTO 'dancesstepsmap' VALUES (30534, 6579, 2);
INSERT INTO 'dancesstepsmap' VALUES (30535, 6595, 2);
INSERT INTO 'dancesstepsmap' VALUES (30536, 6595, 3);
INSERT INTO 'dancesstepsmap' VALUES (30537, 3638, 5);
INSERT INTO 'dancesstepsmap' VALUES (30538, 3579, 2);
INSERT INTO 'dancesstepsmap' VALUES (30539, 3569, 2);
INSERT INTO 'dancesstepsmap' VALUES (30540, 3559, 5);
INSERT INTO 'dancesstepsmap' VALUES (30541, 3544, 2);
INSERT INTO 'dancesstepsmap' VALUES (30542, 3544, 3);
INSERT INTO 'dancesstepsmap' VALUES (30543, 6649, 2);
INSERT INTO 'dancesstepsmap' VALUES (30544, 6649, 3);
INSERT INTO 'dancesstepsmap' VALUES (30545, 3499, 5);
INSERT INTO 'dancesstepsmap' VALUES (30546, 3475, 3);
INSERT INTO 'dancesstepsmap' VALUES (30547, 3475, 2);
INSERT INTO 'dancesstepsmap' VALUES (30548, 3446, 2);
INSERT INTO 'dancesstepsmap' VALUES (30549, 3416, 2);
INSERT INTO 'dancesstepsmap' VALUES (30550, 3412, 5);
INSERT INTO 'dancesstepsmap' VALUES (30551, 3409, 5);
INSERT INTO 'dancesstepsmap' VALUES (30552, 3391, 5);
INSERT INTO 'dancesstepsmap' VALUES (30553, 3391, 6);
INSERT INTO 'dancesstepsmap' VALUES (30554, 3287, 2);
INSERT INTO 'dancesstepsmap' VALUES (30555, 3377, 2);
INSERT INTO 'dancesstepsmap' VALUES (30556, 3345, 2);
INSERT INTO 'dancesstepsmap' VALUES (30557, 8430, 2);
INSERT INTO 'dancesstepsmap' VALUES (30558, 3340, 3);
INSERT INTO 'dancesstepsmap' VALUES (30559, 3340, 2);
INSERT INTO 'dancesstepsmap' VALUES (30560, 3309, 2);
INSERT INTO 'dancesstepsmap' VALUES (30561, 3280, 2);
INSERT INTO 'dancesstepsmap' VALUES (30562, 1997, 2);
INSERT INTO 'dancesstepsmap' VALUES (30563, 5186, 2);
INSERT INTO 'dancesstepsmap' VALUES (30564, 3256, 2);
INSERT INTO 'dancesstepsmap' VALUES (30565, 3200, 2);
INSERT INTO 'dancesstepsmap' VALUES (30566, 3177, 5);
INSERT INTO 'dancesstepsmap' VALUES (30567, 3105, 5);
INSERT INTO 'dancesstepsmap' VALUES (30568, 3084, 5);
INSERT INTO 'dancesstepsmap' VALUES (30569, 3063, 5);
INSERT INTO 'dancesstepsmap' VALUES (30570, 20347, 4);
INSERT INTO 'dancesstepsmap' VALUES (30571, 20347, 5);
INSERT INTO 'dancesstepsmap' VALUES (30572, 20346, 1);
INSERT INTO 'dancesstepsmap' VALUES (30573, 20346, 2);
INSERT INTO 'dancesstepsmap' VALUES (30574, 20345, 4);
INSERT INTO 'dancesstepsmap' VALUES (30575, 20345, 5);
INSERT INTO 'dancesstepsmap' VALUES (30576, 20344, 1);
INSERT INTO 'dancesstepsmap' VALUES (30577, 20344, 2);
INSERT INTO 'dancesstepsmap' VALUES (30578, 20344, 3);
INSERT INTO 'dancesstepsmap' VALUES (30579, 17285, 1);
INSERT INTO 'dancesstepsmap' VALUES (30580, 17285, 2);
INSERT INTO 'dancesstepsmap' VALUES (30581, 17285, 3);
INSERT INTO 'dancesstepsmap' VALUES (30582, 2990, 2);
INSERT INTO 'dancesstepsmap' VALUES (30583, 2966, 2);
INSERT INTO 'dancesstepsmap' VALUES (30584, 2957, 2);
INSERT INTO 'dancesstepsmap' VALUES (13743, 11939, 1);
INSERT INTO 'dancesstepsmap' VALUES (15507, 11939, 2);
INSERT INTO 'dancesstepsmap' VALUES (30585, 20348, 2);
INSERT INTO 'dancesstepsmap' VALUES (30586, 20348, 1);
INSERT INTO 'dancesstepsmap' VALUES (30587, 2926, 5);
INSERT INTO 'dancesstepsmap' VALUES (30588, 7211, 2);
INSERT INTO 'dancesstepsmap' VALUES (30589, 2878, 2);
INSERT INTO 'dancesstepsmap' VALUES (30590, 2871, 2);
INSERT INTO 'dancesstepsmap' VALUES (30591, 8447, 5);
INSERT INTO 'dancesstepsmap' VALUES (30592, 2859, 2);
INSERT INTO 'dancesstepsmap' VALUES (30593, 2834, 5);
INSERT INTO 'dancesstepsmap' VALUES (30594, 2823, 5);
INSERT INTO 'dancesstepsmap' VALUES (30595, 2821, 2);
INSERT INTO 'dancesstepsmap' VALUES (30596, 2753, 2);
INSERT INTO 'dancesstepsmap' VALUES (30597, 2742, 5);
INSERT INTO 'dancesstepsmap' VALUES (30598, 2734, 3);
INSERT INTO 'dancesstepsmap' VALUES (30599, 2734, 2);
INSERT INTO 'dancesstepsmap' VALUES (30600, 10, 5);
INSERT INTO 'dancesstepsmap' VALUES (30601, 2727, 2);
INSERT INTO 'dancesstepsmap' VALUES (30602, 2717, 2);
INSERT INTO 'dancesstepsmap' VALUES (30603, 2707, 2);
INSERT INTO 'dancesstepsmap' VALUES (30604, 2687, 5);
INSERT INTO 'dancesstepsmap' VALUES (30605, 2578, 2);
INSERT INTO 'dancesstepsmap' VALUES (30606, 8460, 5);
INSERT INTO 'dancesstepsmap' VALUES (30607, 8451, 5);
INSERT INTO 'dancesstepsmap' VALUES (30608, 2568, 5);
INSERT INTO 'dancesstepsmap' VALUES (30609, 2543, 2);
INSERT INTO 'dancesstepsmap' VALUES (30610, 2538, 2);
INSERT INTO 'dancesstepsmap' VALUES (30611, 2497, 5);
INSERT INTO 'dancesstepsmap' VALUES (30612, 6971, 2);
INSERT INTO 'dancesstepsmap' VALUES (30613, 2471, 2);
INSERT INTO 'dancesstepsmap' VALUES (30614, 2469, 2);
INSERT INTO 'dancesstepsmap' VALUES (30615, 2458, 3);
INSERT INTO 'dancesstepsmap' VALUES (30616, 2423, 2);
INSERT INTO 'dancesstepsmap' VALUES (30617, 2419, 2);
INSERT INTO 'dancesstepsmap' VALUES (30618, 2356, 5);
INSERT INTO 'dancesstepsmap' VALUES (30619, 18939, 2);
INSERT INTO 'dancesstepsmap' VALUES (30620, 18376, 2);
INSERT INTO 'dancesstepsmap' VALUES (30621, 17693, 2);
INSERT INTO 'dancesstepsmap' VALUES (30622, 16347, 1);
INSERT INTO 'dancesstepsmap' VALUES (30623, 16347, 2);
INSERT INTO 'dancesstepsmap' VALUES (30624, 16286, 2);
INSERT INTO 'dancesstepsmap' VALUES (30625, 16227, 2);
INSERT INTO 'dancesstepsmap' VALUES (30626, 15119, 2);
INSERT INTO 'dancesstepsmap' VALUES (30627, 14739, 2);
INSERT INTO 'dancesstepsmap' VALUES (30628, 13825, 2);
INSERT INTO 'dancesstepsmap' VALUES (30629, 12819, 1);
INSERT INTO 'dancesstepsmap' VALUES (30630, 12819, 2);
INSERT INTO 'dancesstepsmap' VALUES (30631, 16426, 1);
INSERT INTO 'dancesstepsmap' VALUES (30632, 16426, 2);
INSERT INTO 'dancesstepsmap' VALUES (30633, 10924, 2);
INSERT INTO 'dancesstepsmap' VALUES (30634, 10315, 2);
INSERT INTO 'dancesstepsmap' VALUES (30635, 2333, 3);
INSERT INTO 'dancesstepsmap' VALUES (30636, 2308, 2);
INSERT INTO 'dancesstepsmap' VALUES (30637, 9325, 2);
INSERT INTO 'dancesstepsmap' VALUES (30638, 9180, 2);
INSERT INTO 'dancesstepsmap' VALUES (30639, 9179, 2);
INSERT INTO 'dancesstepsmap' VALUES (30640, 9041, 2);
INSERT INTO 'dancesstepsmap' VALUES (30641, 8794, 1);
INSERT INTO 'dancesstepsmap' VALUES (30642, 8794, 2);
INSERT INTO 'dancesstepsmap' VALUES (30643, 8707, 1);
INSERT INTO 'dancesstepsmap' VALUES (30644, 8707, 2);
INSERT INTO 'dancesstepsmap' VALUES (30645, 8544, 2);
INSERT INTO 'dancesstepsmap' VALUES (30646, 5253, 3);
INSERT INTO 'dancesstepsmap' VALUES (30647, 5253, 2);
INSERT INTO 'dancesstepsmap' VALUES (30648, 15936, 1);
INSERT INTO 'dancesstepsmap' VALUES (30649, 15936, 2);
INSERT INTO 'dancesstepsmap' VALUES (30650, 12637, 2);
INSERT INTO 'dancesstepsmap' VALUES (30651, 2514, 2);
INSERT INTO 'dancesstepsmap' VALUES (30652, 6394, 2);
INSERT INTO 'dancesstepsmap' VALUES (30653, 14596, 2);
INSERT INTO 'dancesstepsmap' VALUES (30654, 16013, 2);
INSERT INTO 'dancesstepsmap' VALUES (30655, 18145, 2);
INSERT INTO 'dancesstepsmap' VALUES (30656, 18145, 3);
INSERT INTO 'dancesstepsmap' VALUES (30657, 18708, 2);
INSERT INTO 'dancesstepsmap' VALUES (30658, 19690, 2);
INSERT INTO 'dancesstepsmap' VALUES (30659, 3263, 2);
INSERT INTO 'dancesstepsmap' VALUES (30660, 3263, 3);
INSERT INTO 'dancesstepsmap' VALUES (30661, 4048, 2);
INSERT INTO 'dancesstepsmap' VALUES (30662, 14335, 2);
INSERT INTO 'dancesstepsmap' VALUES (30663, 2295, 2);
INSERT INTO 'dancesstepsmap' VALUES (30664, 11966, 2);
INSERT INTO 'dancesstepsmap' VALUES (30665, 2288, 5);
INSERT INTO 'dancesstepsmap' VALUES (30666, 2275, 5);
INSERT INTO 'dancesstepsmap' VALUES (30667, 2226, 3);
INSERT INTO 'dancesstepsmap' VALUES (30668, 2196, 2);
INSERT INTO 'dancesstepsmap' VALUES (30669, 20349, 4);
INSERT INTO 'dancesstepsmap' VALUES (30670, 20349, 5);
INSERT INTO 'dancesstepsmap' VALUES (30671, 18905, 2);
INSERT INTO 'dancesstepsmap' VALUES (30672, 17523, 2);
INSERT INTO 'dancesstepsmap' VALUES (30673, 17523, 1);
INSERT INTO 'dancesstepsmap' VALUES (30674, 10328, 2);
INSERT INTO 'dancesstepsmap' VALUES (30675, 10322, 2);
INSERT INTO 'dancesstepsmap' VALUES (30676, 10193, 2);
INSERT INTO 'dancesstepsmap' VALUES (30677, 10193, 1);
INSERT INTO 'dancesstepsmap' VALUES (30678, 9899, 2);
INSERT INTO 'dancesstepsmap' VALUES (30679, 9828, 2);
INSERT INTO 'dancesstepsmap' VALUES (30680, 9591, 2);
INSERT INTO 'dancesstepsmap' VALUES (30681, 2169, 3);
INSERT INTO 'dancesstepsmap' VALUES (30682, 2162, 3);
INSERT INTO 'dancesstepsmap' VALUES (30683, 2157, 2);
INSERT INTO 'dancesstepsmap' VALUES (30684, 9528, 2);
INSERT INTO 'dancesstepsmap' VALUES (30685, 9435, 2);
INSERT INTO 'dancesstepsmap' VALUES (30686, 9363, 2);
INSERT INTO 'dancesstepsmap' VALUES (30687, 2130, 5);
INSERT INTO 'dancesstepsmap' VALUES (30688, 2129, 3);
INSERT INTO 'dancesstepsmap' VALUES (30689, 2076, 2);
INSERT INTO 'dancesstepsmap' VALUES (30690, 2063, 2);
INSERT INTO 'dancesstepsmap' VALUES (30691, 2060, 2);
INSERT INTO 'dancesstepsmap' VALUES (30692, 2045, 2);
INSERT INTO 'dancesstepsmap' VALUES (30693, 2021, 5);
INSERT INTO 'dancesstepsmap' VALUES (30694, 2008, 5);
INSERT INTO 'dancesstepsmap' VALUES (30695, 1974, 2);
INSERT INTO 'dancesstepsmap' VALUES (30696, 1966, 2);
INSERT INTO 'dancesstepsmap' VALUES (30697, 1965, 5);
INSERT INTO 'dancesstepsmap' VALUES (30698, 1965, 6);
INSERT INTO 'dancesstepsmap' VALUES (30699, 1928, 3);
INSERT INTO 'dancesstepsmap' VALUES (30700, 472, 2);
INSERT INTO 'dancesstepsmap' VALUES (30701, 5768, 2);
INSERT INTO 'dancesstepsmap' VALUES (30702, 1884, 2);
INSERT INTO 'dancesstepsmap' VALUES (30703, 1866, 2);
INSERT INTO 'dancesstepsmap' VALUES (30704, 1856, 5);
INSERT INTO 'dancesstepsmap' VALUES (30705, 8996, 1);
INSERT INTO 'dancesstepsmap' VALUES (30706, 8996, 2);
INSERT INTO 'dancesstepsmap' VALUES (30707, 8973, 2);
INSERT INTO 'dancesstepsmap' VALUES (30708, 8697, 2);
INSERT INTO 'dancesstepsmap' VALUES (30709, 8682, 2);
INSERT INTO 'dancesstepsmap' VALUES (30710, 8656, 2);
INSERT INTO 'dancesstepsmap' VALUES (30711, 8394, 2);
INSERT INTO 'dancesstepsmap' VALUES (30712, 7172, 2);
INSERT INTO 'dancesstepsmap' VALUES (30713, 7138, 2);
INSERT INTO 'dancesstepsmap' VALUES (30714, 7116, 2);
INSERT INTO 'dancesstepsmap' VALUES (30715, 135, 5);
INSERT INTO 'dancesstepsmap' VALUES (30716, 2064, 5);
INSERT INTO 'dancesstepsmap' VALUES (30717, 3944, 2);
INSERT INTO 'dancesstepsmap' VALUES (30718, 4792, 5);
INSERT INTO 'dancesstepsmap' VALUES (30719, 861, 2);
INSERT INTO 'dancesstepsmap' VALUES (30720, 6013, 5);
INSERT INTO 'dancesstepsmap' VALUES (30721, 3860, 5);
INSERT INTO 'dancesstepsmap' VALUES (30722, 1793, 2);
INSERT INTO 'dancesstepsmap' VALUES (30723, 1780, 2);
INSERT INTO 'dancesstepsmap' VALUES (30724, 1774, 2);
INSERT INTO 'dancesstepsmap' VALUES (30725, 1762, 2);
INSERT INTO 'dancesstepsmap' VALUES (30726, 6722, 2);
INSERT INTO 'dancesstepsmap' VALUES (30727, 6682, 2);
INSERT INTO 'dancesstepsmap' VALUES (30728, 6682, 3);
INSERT INTO 'dancesstepsmap' VALUES (30729, 6438, 2);
INSERT INTO 'dancesstepsmap' VALUES (30730, 6261, 2);
INSERT INTO 'dancesstepsmap' VALUES (30731, 6038, 2);
INSERT INTO 'dancesstepsmap' VALUES (30732, 5554, 2);
INSERT INTO 'dancesstepsmap' VALUES (30733, 5531, 2);
INSERT INTO 'dancesstepsmap' VALUES (30734, 5513, 2);
INSERT INTO 'dancesstepsmap' VALUES (30735, 4928, 2);
INSERT INTO 'dancesstepsmap' VALUES (30736, 4919, 2);
INSERT INTO 'dancesstepsmap' VALUES (30737, 1757, 5);
INSERT INTO 'dancesstepsmap' VALUES (30738, 1756, 5);
INSERT INTO 'dancesstepsmap' VALUES (30739, 10263, 5);
INSERT INTO 'dancesstepsmap' VALUES (30740, 6292, 2);
INSERT INTO 'dancesstepsmap' VALUES (30741, 1707, 2);
INSERT INTO 'dancesstepsmap' VALUES (30742, 1677, 5);
INSERT INTO 'dancesstepsmap' VALUES (30743, 1653, 2);
INSERT INTO 'dancesstepsmap' VALUES (30744, 4426, 2);
INSERT INTO 'dancesstepsmap' VALUES (30745, 4352, 2);
INSERT INTO 'dancesstepsmap' VALUES (30746, 4324, 2);
INSERT INTO 'dancesstepsmap' VALUES (30747, 4253, 2);
INSERT INTO 'dancesstepsmap' VALUES (30748, 4123, 2);
INSERT INTO 'dancesstepsmap' VALUES (30749, 4097, 2);
INSERT INTO 'dancesstepsmap' VALUES (30750, 1596, 5);
INSERT INTO 'dancesstepsmap' VALUES (30751, 20350, 4);
INSERT INTO 'dancesstepsmap' VALUES (30752, 20350, 5);
INSERT INTO 'dancesstepsmap' VALUES (30753, 1567, 5);
INSERT INTO 'dancesstepsmap' VALUES (30754, 3852, 2);
INSERT INTO 'dancesstepsmap' VALUES (30755, 3584, 2);
INSERT INTO 'dancesstepsmap' VALUES (30756, 3459, 2);
INSERT INTO 'dancesstepsmap' VALUES (30757, 3288, 2);
INSERT INTO 'dancesstepsmap' VALUES (30758, 3135, 2);
INSERT INTO 'dancesstepsmap' VALUES (30759, 3364, 5);
INSERT INTO 'dancesstepsmap' VALUES (30760, 3046, 2);
INSERT INTO 'dancesstepsmap' VALUES (19314, 15880, 2);
INSERT INTO 'dancesstepsmap' VALUES (30761, 1558, 5);
INSERT INTO 'dancesstepsmap' VALUES (30762, 1555, 5);
INSERT INTO 'dancesstepsmap' VALUES (30763, 1547, 2);
INSERT INTO 'dancesstepsmap' VALUES (30764, 2936, 2);
INSERT INTO 'dancesstepsmap' VALUES (30765, 2566, 2);
INSERT INTO 'dancesstepsmap' VALUES (30766, 2513, 2);
INSERT INTO 'dancesstepsmap' VALUES (30767, 1543, 3);
INSERT INTO 'dancesstepsmap' VALUES (30768, 1526, 5);
INSERT INTO 'dancesstepsmap' VALUES (30769, 1475, 5);
INSERT INTO 'dancesstepsmap' VALUES (30770, 1446, 5);
INSERT INTO 'dancesstepsmap' VALUES (30771, 1431, 2);
INSERT INTO 'dancesstepsmap' VALUES (30772, 1427, 2);
INSERT INTO 'dancesstepsmap' VALUES (30773, 1402, 2);
INSERT INTO 'dancesstepsmap' VALUES (30774, 1376, 5);
INSERT INTO 'dancesstepsmap' VALUES (30775, 1366, 5);
INSERT INTO 'dancesstepsmap' VALUES (30776, 1359, 5);
INSERT INTO 'dancesstepsmap' VALUES (30777, 281, 2);
INSERT INTO 'dancesstepsmap' VALUES (30778, 1561, 5);
INSERT INTO 'dancesstepsmap' VALUES (30779, 2032, 2);
INSERT INTO 'dancesstepsmap' VALUES (30780, 1180, 5);
INSERT INTO 'dancesstepsmap' VALUES (30781, 6283, 2);
INSERT INTO 'dancesstepsmap' VALUES (30782, 2467, 2);
INSERT INTO 'dancesstepsmap' VALUES (30783, 1353, 5);
INSERT INTO 'dancesstepsmap' VALUES (30784, 20312, 1);
INSERT INTO 'dancesstepsmap' VALUES (30785, 1252, 2);
INSERT INTO 'dancesstepsmap' VALUES (30786, 20314, 4);
INSERT INTO 'dancesstepsmap' VALUES (30787, 20351, 4);
INSERT INTO 'dancesstepsmap' VALUES (30788, 20351, 5);
INSERT INTO 'dancesstepsmap' VALUES (30789, 1882, 2);
INSERT INTO 'dancesstepsmap' VALUES (30790, 828, 2);
INSERT INTO 'dancesstepsmap' VALUES (30791, 3069, 5);
INSERT INTO 'dancesstepsmap' VALUES (30792, 931, 2);
INSERT INTO 'dancesstepsmap' VALUES (30793, 3877, 2);
INSERT INTO 'dancesstepsmap' VALUES (30794, 1311, 2);
INSERT INTO 'dancesstepsmap' VALUES (30795, 1237, 5);
INSERT INTO 'dancesstepsmap' VALUES (30796, 1215, 2);
INSERT INTO 'dancesstepsmap' VALUES (30797, 1215, 3);
INSERT INTO 'dancesstepsmap' VALUES (30798, 2255, 2);
INSERT INTO 'dancesstepsmap' VALUES (30799, 2044, 2);
INSERT INTO 'dancesstepsmap' VALUES (30800, 2006, 2);
INSERT INTO 'dancesstepsmap' VALUES (30801, 1954, 2);
INSERT INTO 'dancesstepsmap' VALUES (30802, 1861, 2);
INSERT INTO 'dancesstepsmap' VALUES (30803, 1511, 2);
INSERT INTO 'dancesstepsmap' VALUES (30804, 3189, 10);
INSERT INTO 'dancesstepsmap' VALUES (30805, 20352, 1);
INSERT INTO 'dancesstepsmap' VALUES (30806, 20353, 1);
INSERT INTO 'dancesstepsmap' VALUES (30807, 20354, 1);
INSERT INTO 'dancesstepsmap' VALUES (30808, 20354, 3);
INSERT INTO 'dancesstepsmap' VALUES (30809, 20355, 4);
INSERT INTO 'dancesstepsmap' VALUES (30810, 20355, 5);
INSERT INTO 'dancesstepsmap' VALUES (30811, 20356, 5);
INSERT INTO 'dancesstepsmap' VALUES (30812, 20356, 4);
INSERT INTO 'dancesstepsmap' VALUES (30813, 20357, 4);
INSERT INTO 'dancesstepsmap' VALUES (30814, 20357, 5);
INSERT INTO 'dancesstepsmap' VALUES (30815, 20358, 4);
INSERT INTO 'dancesstepsmap' VALUES (30816, 20358, 1);
INSERT INTO 'dancesstepsmap' VALUES (30817, 20358, 3);
INSERT INTO 'dancesstepsmap' VALUES (30818, 1171, 5);
INSERT INTO 'dancesstepsmap' VALUES (30819, 1165, 2);
INSERT INTO 'dancesstepsmap' VALUES (30820, 1368, 2);
INSERT INTO 'dancesstepsmap' VALUES (30821, 1349, 2);
INSERT INTO 'dancesstepsmap' VALUES (30822, 1194, 2);
INSERT INTO 'dancesstepsmap' VALUES (30823, 910, 2);
INSERT INTO 'dancesstepsmap' VALUES (30824, 690, 2);
INSERT INTO 'dancesstepsmap' VALUES (30825, 430, 2);
INSERT INTO 'dancesstepsmap' VALUES (30826, 273, 2);
INSERT INTO 'dancesstepsmap' VALUES (30827, 103, 2);
INSERT INTO 'dancesstepsmap' VALUES (30828, 82, 2);
INSERT INTO 'dancesstepsmap' VALUES (30829, 81, 2);
INSERT INTO 'dancesstepsmap' VALUES (30830, 1093, 2);
INSERT INTO 'dancesstepsmap' VALUES (30831, 1073, 5);
INSERT INTO 'dancesstepsmap' VALUES (30832, 1034, 3);
INSERT INTO 'dancesstepsmap' VALUES (30833, 1029, 2);
INSERT INTO 'dancesstepsmap' VALUES (30834, 992, 5);
INSERT INTO 'dancesstepsmap' VALUES (30835, 992, 10);
INSERT INTO 'dancesstepsmap' VALUES (30836, 20321, 4);
INSERT INTO 'dancesstepsmap' VALUES (30837, 20321, 5);
INSERT INTO 'dancesstepsmap' VALUES (30838, 932, 2);
INSERT INTO 'dancesstepsmap' VALUES (30839, 919, 5);
INSERT INTO 'dancesstepsmap' VALUES (30840, 915, 2);
INSERT INTO 'dancesstepsmap' VALUES (30841, 904, 5);
INSERT INTO 'dancesstepsmap' VALUES (30842, 20359, 4);
INSERT INTO 'dancesstepsmap' VALUES (30843, 20359, 5);
INSERT INTO 'dancesstepsmap' VALUES (30844, 20360, 4);
INSERT INTO 'dancesstepsmap' VALUES (30845, 20360, 5);
INSERT INTO 'dancesstepsmap' VALUES (30846, 20361, 1);
INSERT INTO 'dancesstepsmap' VALUES (30847, 20361, 2);
INSERT INTO 'dancesstepsmap' VALUES (30848, 20361, 3);
INSERT INTO 'dancesstepsmap' VALUES (30849, 889, 5);
INSERT INTO 'dancesstepsmap' VALUES (30850, 852, 3);
INSERT INTO 'dancesstepsmap' VALUES (30851, 848, 2);
INSERT INTO 'dancesstepsmap' VALUES (30852, 765, 2);
INSERT INTO 'dancesstepsmap' VALUES (30853, 729, 5);
INSERT INTO 'dancesstepsmap' VALUES (30854, 722, 2);
INSERT INTO 'dancesstepsmap' VALUES (30855, 717, 2);
INSERT INTO 'dancesstepsmap' VALUES (30856, 687, 2);
INSERT INTO 'dancesstepsmap' VALUES (30857, 20248, 1);
INSERT INTO 'dancesstepsmap' VALUES (30858, 20248, 2);
INSERT INTO 'dancesstepsmap' VALUES (30859, 683, 2);
INSERT INTO 'dancesstepsmap' VALUES (30860, 680, 5);
INSERT INTO 'dancesstepsmap' VALUES (30861, 20245, 4);
INSERT INTO 'dancesstepsmap' VALUES (30862, 20245, 5);
INSERT INTO 'dancesstepsmap' VALUES (30863, 20246, 1);
INSERT INTO 'dancesstepsmap' VALUES (30864, 20246, 2);
INSERT INTO 'dancesstepsmap' VALUES (30865, 20246, 3);
INSERT INTO 'dancesstepsmap' VALUES (30866, 671, 2);
INSERT INTO 'dancesstepsmap' VALUES (30867, 9213, 4);
INSERT INTO 'dancesstepsmap' VALUES (30868, 9213, 6);
INSERT INTO 'dancesstepsmap' VALUES (30869, 20247, 1);
INSERT INTO 'dancesstepsmap' VALUES (30870, 20247, 2);
INSERT INTO 'dancesstepsmap' VALUES (30871, 20247, 3);
INSERT INTO 'dancesstepsmap' VALUES (30872, 598, 5);
INSERT INTO 'dancesstepsmap' VALUES (30873, 596, 2);
INSERT INTO 'dancesstepsmap' VALUES (30874, 578, 5);
INSERT INTO 'dancesstepsmap' VALUES (30875, 547, 3);
INSERT INTO 'dancesstepsmap' VALUES (30876, 1711, 6);
INSERT INTO 'dancesstepsmap' VALUES (30877, 530, 5);
INSERT INTO 'dancesstepsmap' VALUES (30878, 519, 1);
INSERT INTO 'dancesstepsmap' VALUES (30879, 519, 4);
INSERT INTO 'dancesstepsmap' VALUES (30880, 20362, 1);
INSERT INTO 'dancesstepsmap' VALUES (30881, 20362, 2);
INSERT INTO 'dancesstepsmap' VALUES (30882, 20362, 3);
INSERT INTO 'dancesstepsmap' VALUES (30883, 420, 2);
INSERT INTO 'dancesstepsmap' VALUES (30884, 400, 3);
INSERT INTO 'dancesstepsmap' VALUES (30885, 397, 2);
INSERT INTO 'dancesstepsmap' VALUES (30886, 382, 2);
INSERT INTO 'dancesstepsmap' VALUES (30887, 378, 5);
INSERT INTO 'dancesstepsmap' VALUES (30888, 377, 5);
INSERT INTO 'dancesstepsmap' VALUES (30889, 359, 2);
INSERT INTO 'dancesstepsmap' VALUES (30890, 326, 2);
INSERT INTO 'dancesstepsmap' VALUES (30891, 268, 2);
INSERT INTO 'dancesstepsmap' VALUES (30892, 235, 5);
INSERT INTO 'dancesstepsmap' VALUES (30893, 235, 4);
INSERT INTO 'dancesstepsmap' VALUES (30894, 235, 2);
INSERT INTO 'dancesstepsmap' VALUES (30895, 235, 1);
INSERT INTO 'dancesstepsmap' VALUES (30896, 229, 2);
INSERT INTO 'dancesstepsmap' VALUES (30897, 137, 5);
INSERT INTO 'dancesstepsmap' VALUES (30898, 11331, 1);
INSERT INTO 'dancesstepsmap' VALUES (30899, 11331, 2);
INSERT INTO 'dancesstepsmap' VALUES (30900, 4007, 5);
INSERT INTO 'dancesstepsmap' VALUES (30901, 1004, 2);
INSERT INTO 'dancesstepsmap' VALUES (30902, 20368, 1);
INSERT INTO 'dancesstepsmap' VALUES (30903, 20368, 3);
INSERT INTO 'dancesstepsmap' VALUES (30904, 4231, 5);
INSERT INTO 'dancesstepsmap' VALUES (30905, 20367, 1);
INSERT INTO 'dancesstepsmap' VALUES (30906, 20367, 3);
INSERT INTO 'dancesstepsmap' VALUES (30907, 20366, 1);
INSERT INTO 'dancesstepsmap' VALUES (30908, 20366, 2);
INSERT INTO 'dancesstepsmap' VALUES (30909, 20370, 2);
INSERT INTO 'dancesstepsmap' VALUES (30910, 20370, 1);
INSERT INTO 'dancesstepsmap' VALUES (30911, 20370, 3);
INSERT INTO 'dancesstepsmap' VALUES (30912, 20364, 1);
INSERT INTO 'dancesstepsmap' VALUES (30913, 20364, 2);
INSERT INTO 'dancesstepsmap' VALUES (30914, 20313, 1);
INSERT INTO 'dancesstepsmap' VALUES (30915, 20313, 3);
INSERT INTO 'dancesstepsmap' VALUES (30916, 1823, 5);
INSERT INTO 'dancesstepsmap' VALUES (30917, 1823, 4);
INSERT INTO 'dancesstepsmap' VALUES (30918, 1823, 1);
INSERT INTO 'dancesstepsmap' VALUES (30919, 1823, 2);
INSERT INTO 'dancesstepsmap' VALUES (30920, 20390, 1);
INSERT INTO 'dancesstepsmap' VALUES (30921, 20390, 2);
INSERT INTO 'dancesstepsmap' VALUES (30922, 20391, 1);
INSERT INTO 'dancesstepsmap' VALUES (30923, 20391, 2);
INSERT INTO 'dancesstepsmap' VALUES (30924, 20392, 1);
INSERT INTO 'dancesstepsmap' VALUES (30925, 20392, 3);
INSERT INTO 'dancesstepsmap' VALUES (30926, 12629, 1);
INSERT INTO 'dancesstepsmap' VALUES (30927, 12629, 2);
INSERT INTO 'dancesstepsmap' VALUES (30928, 2630, 2);
INSERT INTO 'dancesstepsmap' VALUES (30929, 5978, 2);
INSERT INTO 'dancesstepsmap' VALUES (30930, 20363, 1);
INSERT INTO 'dancesstepsmap' VALUES (30931, 20365, 1);
INSERT INTO 'dancesstepsmap' VALUES (30932, 20365, 4);
INSERT INTO 'dancesstepsmap' VALUES (30933, 20393, 1);
INSERT INTO 'dancesstepsmap' VALUES (30934, 20393, 3);
INSERT INTO 'dancesstepsmap' VALUES (30935, 20394, 5);
INSERT INTO 'dancesstepsmap' VALUES (30936, 20394, 4);
INSERT INTO 'dancesstepsmap' VALUES (30937, 8452, 5);
INSERT INTO 'dancesstepsmap' VALUES (16233, 13739, 3);
INSERT INTO 'dancesstepsmap' VALUES (30938, 6536, 2);
INSERT INTO 'dancesstepsmap' VALUES (30939, 5776, 2);
INSERT INTO 'dancesstepsmap' VALUES (30940, 5776, 3);
INSERT INTO 'dancesstepsmap' VALUES (30941, 2649, 5);
INSERT INTO 'dancesstepsmap' VALUES (30942, 4800, 5);
INSERT INTO 'dancesstepsmap' VALUES (30943, 11563, 2);
INSERT INTO 'dancesstepsmap' VALUES (30944, 17571, 1);
INSERT INTO 'dancesstepsmap' VALUES (30945, 17571, 2);
INSERT INTO 'dancesstepsmap' VALUES (30946, 20421, 4);
INSERT INTO 'dancesstepsmap' VALUES (30947, 17572, 1);
INSERT INTO 'dancesstepsmap' VALUES (30948, 17572, 2);
INSERT INTO 'dancesstepsmap' VALUES (30949, 17572, 3);
INSERT INTO 'dancesstepsmap' VALUES (30950, 9527, 2);
INSERT INTO 'dancesstepsmap' VALUES (30951, 1814, 2);
INSERT INTO 'dancesstepsmap' VALUES (30952, 9529, 5);
INSERT INTO 'dancesstepsmap' VALUES (30953, 13144, 2);
INSERT INTO 'dancesstepsmap' VALUES (30954, 4045, 2);
INSERT INTO 'dancesstepsmap' VALUES (30955, 4045, 1);
INSERT INTO 'dancesstepsmap' VALUES (30958, 20416, 1);
INSERT INTO 'dancesstepsmap' VALUES (30959, 20416, 2);
INSERT INTO 'dancesstepsmap' VALUES (30960, 20416, 3);
INSERT INTO 'dancesstepsmap' VALUES (30961, 20369, 1);
INSERT INTO 'dancesstepsmap' VALUES (30962, 20369, 2);
INSERT INTO 'dancesstepsmap' VALUES (30963, 8567, 5);
INSERT INTO 'dancesstepsmap' VALUES (30964, 10978, 2);
INSERT INTO 'dancesstepsmap' VALUES (30965, 10978, 3);
INSERT INTO 'dancesstepsmap' VALUES (30966, 20425, 5);
INSERT INTO 'dancesstepsmap' VALUES (30967, 20425, 4);
INSERT INTO 'dancesstepsmap' VALUES (30968, 20427, 1);
INSERT INTO 'dancesstepsmap' VALUES (30969, 20427, 2);
INSERT INTO 'dancesstepsmap' VALUES (30970, 8078, 2);
INSERT INTO 'dancesstepsmap' VALUES (30971, 8077, 2);
INSERT INTO 'dancesstepsmap' VALUES (30972, 4658, 6);
INSERT INTO 'dancesstepsmap' VALUES (30973, 3036, 3);
INSERT INTO 'dancesstepsmap' VALUES (30974, 3036, 2);
INSERT INTO 'dancesstepsmap' VALUES (27387, 19965, 5);
INSERT INTO 'dancesstepsmap' VALUES (30975, 12162, 5);
INSERT INTO 'dancesstepsmap' VALUES (30976, 14383, 4);
INSERT INTO 'dancesstepsmap' VALUES (30977, 14383, 5);
INSERT INTO 'dancesstepsmap' VALUES (30978, 12140, 1);
INSERT INTO 'dancesstepsmap' VALUES (30979, 20428, 4);
INSERT INTO 'dancesstepsmap' VALUES (30980, 20428, 5);
INSERT INTO 'dancesstepsmap' VALUES (30981, 20429, 1);
INSERT INTO 'dancesstepsmap' VALUES (30982, 20430, 4);
INSERT INTO 'dancesstepsmap' VALUES (30983, 20430, 5);
INSERT INTO 'dancesstepsmap' VALUES (30984, 20431, 4);
INSERT INTO 'dancesstepsmap' VALUES (30985, 20431, 5);
INSERT INTO 'dancesstepsmap' VALUES (30986, 20432, 1);
INSERT INTO 'dancesstepsmap' VALUES (30987, 20432, 3);
INSERT INTO 'dancesstepsmap' VALUES (30988, 20433, 4);
INSERT INTO 'dancesstepsmap' VALUES (30989, 20433, 5);
INSERT INTO 'dancesstepsmap' VALUES (30990, 20434, 4);
INSERT INTO 'dancesstepsmap' VALUES (30991, 20434, 5);
INSERT INTO 'dancesstepsmap' VALUES (30992, 20435, 1);
INSERT INTO 'dancesstepsmap' VALUES (30993, 20436, 1);
INSERT INTO 'dancesstepsmap' VALUES (30994, 20436, 2);
INSERT INTO 'dancesstepsmap' VALUES (30995, 20437, 5);
INSERT INTO 'dancesstepsmap' VALUES (30996, 20437, 4);
INSERT INTO 'dancesstepsmap' VALUES (30997, 11582, 5);
INSERT INTO 'dancesstepsmap' VALUES (30998, 20439, 4);
INSERT INTO 'dancesstepsmap' VALUES (30999, 20439, 5);
INSERT INTO 'dancesstepsmap' VALUES (31000, 20439, 1);
INSERT INTO 'dancesstepsmap' VALUES (31001, 20439, 3);
INSERT INTO 'dancesstepsmap' VALUES (31002, 20439, 2);
INSERT INTO 'dancesstepsmap' VALUES (31003, 20440, 2);
INSERT INTO 'dancesstepsmap' VALUES (31004, 20440, 1);
INSERT INTO 'dancesstepsmap' VALUES (31005, 20440, 3);
INSERT INTO 'dancesstepsmap' VALUES (31006, 20441, 1);
INSERT INTO 'dancesstepsmap' VALUES (31007, 20441, 3);
INSERT INTO 'dancesstepsmap' VALUES (31008, 20441, 4);
INSERT INTO 'dancesstepsmap' VALUES (31009, 20442, 5);
INSERT INTO 'dancesstepsmap' VALUES (31010, 20442, 4);
INSERT INTO 'dancesstepsmap' VALUES (31011, 20443, 1);
INSERT INTO 'dancesstepsmap' VALUES (31012, 20443, 3);
INSERT INTO 'dancesstepsmap' VALUES (31013, 20443, 2);
INSERT INTO 'dancesstepsmap' VALUES (31014, 20444, 1);
INSERT INTO 'dancesstepsmap' VALUES (31015, 20444, 2);
INSERT INTO 'dancesstepsmap' VALUES (31016, 20445, 5);
INSERT INTO 'dancesstepsmap' VALUES (31017, 20445, 4);
INSERT INTO 'dancesstepsmap' VALUES (31018, 20446, 1);
INSERT INTO 'dancesstepsmap' VALUES (31019, 20447, 5);
INSERT INTO 'dancesstepsmap' VALUES (31020, 20447, 4);
INSERT INTO 'dancesstepsmap' VALUES (31021, 20449, 4);
INSERT INTO 'dancesstepsmap' VALUES (31022, 20449, 5);
INSERT INTO 'dancesstepsmap' VALUES (31023, 20448, 4);
INSERT INTO 'dancesstepsmap' VALUES (31024, 20448, 5);
INSERT INTO 'dancesstepsmap' VALUES (31025, 20398, 1);
INSERT INTO 'dancesstepsmap' VALUES (31026, 20396, 1);
INSERT INTO 'dancesstepsmap' VALUES (31027, 20396, 2);
INSERT INTO 'dancesstepsmap' VALUES (31028, 20399, 1);
INSERT INTO 'dancesstepsmap' VALUES (31029, 20397, 4);
INSERT INTO 'dancesstepsmap' VALUES (31030, 20397, 5);
INSERT INTO 'dancesstepsmap' VALUES (31031, 20402, 1);
INSERT INTO 'dancesstepsmap' VALUES (31032, 20402, 2);
INSERT INTO 'dancesstepsmap' VALUES (31034, 20401, 1);
INSERT INTO 'dancesstepsmap' VALUES (31035, 20401, 2);
INSERT INTO 'dancesstepsmap' VALUES (31036, 20400, 4);
INSERT INTO 'dancesstepsmap' VALUES (31037, 20400, 5);
INSERT INTO 'dancesstepsmap' VALUES (31038, 20403, 4);
INSERT INTO 'dancesstepsmap' VALUES (31039, 20403, 5);
INSERT INTO 'dancesstepsmap' VALUES (31040, 20316, 1);
INSERT INTO 'dancesstepsmap' VALUES (31041, 20316, 2);
INSERT INTO 'dancesstepsmap' VALUES (31042, 20450, 5);
INSERT INTO 'dancesstepsmap' VALUES (31043, 20450, 4);
INSERT INTO 'dancesstepsmap' VALUES (31044, 11095, 4);
INSERT INTO 'dancesstepsmap' VALUES (31045, 20404, 1);
INSERT INTO 'dancesstepsmap' VALUES (31046, 20404, 2);
INSERT INTO 'dancesstepsmap' VALUES (31047, 20404, 3);
INSERT INTO 'dancesstepsmap' VALUES (31048, 20451, 1);
INSERT INTO 'dancesstepsmap' VALUES (31049, 20451, 2);
INSERT INTO 'dancesstepsmap' VALUES (31052, 20453, 4);
INSERT INTO 'dancesstepsmap' VALUES (31053, 20453, 5);
INSERT INTO 'dancesstepsmap' VALUES (31054, 20454, 2);
INSERT INTO 'dancesstepsmap' VALUES (31056, 20455, 5);
INSERT INTO 'dancesstepsmap' VALUES (31057, 20455, 4);
INSERT INTO 'dancesstepsmap' VALUES (31058, 20456, 1);
INSERT INTO 'dancesstepsmap' VALUES (31059, 20456, 2);
INSERT INTO 'dancesstepsmap' VALUES (31060, 20457, 1);
INSERT INTO 'dancesstepsmap' VALUES (31061, 20457, 2);
INSERT INTO 'dancesstepsmap' VALUES (31062, 20458, 1);
INSERT INTO 'dancesstepsmap' VALUES (31063, 20458, 2);
INSERT INTO 'dancesstepsmap' VALUES (31064, 20459, 1);
INSERT INTO 'dancesstepsmap' VALUES (31065, 20459, 2);
INSERT INTO 'dancesstepsmap' VALUES (31066, 20459, 3);
INSERT INTO 'dancesstepsmap' VALUES (31067, 20472, 5);
INSERT INTO 'dancesstepsmap' VALUES (31068, 20472, 4);
INSERT INTO 'dancesstepsmap' VALUES (31069, 20473, 1);
INSERT INTO 'dancesstepsmap' VALUES (31070, 20473, 2);
INSERT INTO 'dancesstepsmap' VALUES (31071, 20474, 4);
INSERT INTO 'dancesstepsmap' VALUES (31072, 20475, 1);
INSERT INTO 'dancesstepsmap' VALUES (31073, 20475, 2);
INSERT INTO 'dancesstepsmap' VALUES (31074, 20476, 5);
INSERT INTO 'dancesstepsmap' VALUES (31075, 20476, 4);
INSERT INTO 'dancesstepsmap' VALUES (31076, 20477, 4);
INSERT INTO 'dancesstepsmap' VALUES (31077, 20477, 5);
INSERT INTO 'dancesstepsmap' VALUES (31078, 20478, 1);
INSERT INTO 'dancesstepsmap' VALUES (31079, 20479, 2);
INSERT INTO 'dancesstepsmap' VALUES (31080, 20479, 1);
INSERT INTO 'dancesstepsmap' VALUES (31081, 20480, 5);
INSERT INTO 'dancesstepsmap' VALUES (31082, 20480, 4);
INSERT INTO 'dancesstepsmap' VALUES (31083, 20480, 2);
INSERT INTO 'dancesstepsmap' VALUES (31084, 20480, 1);
INSERT INTO 'dancesstepsmap' VALUES (31085, 20480, 3);
INSERT INTO 'dancesstepsmap' VALUES (31086, 20481, 2);
INSERT INTO 'dancesstepsmap' VALUES (31087, 20481, 1);
INSERT INTO 'dancesstepsmap' VALUES (31088, 20483, 4);
INSERT INTO 'dancesstepsmap' VALUES (31089, 20483, 5);
INSERT INTO 'dancesstepsmap' VALUES (31090, 20484, 1);
INSERT INTO 'dancesstepsmap' VALUES (31091, 20484, 2);
INSERT INTO 'dancesstepsmap' VALUES (31092, 20484, 3);
INSERT INTO 'dancesstepsmap' VALUES (31093, 20485, 4);
INSERT INTO 'dancesstepsmap' VALUES (31094, 20485, 5);
INSERT INTO 'dancesstepsmap' VALUES (31095, 20486, 1);
INSERT INTO 'dancesstepsmap' VALUES (31096, 20486, 3);
INSERT INTO 'dancesstepsmap' VALUES (31097, 20491, 4);
INSERT INTO 'dancesstepsmap' VALUES (31098, 20491, 5);
INSERT INTO 'dancesstepsmap' VALUES (31099, 20490, 1);
INSERT INTO 'dancesstepsmap' VALUES (31100, 20490, 2);
INSERT INTO 'dancesstepsmap' VALUES (31101, 20490, 3);
INSERT INTO 'dancesstepsmap' VALUES (31102, 20489, 4);
INSERT INTO 'dancesstepsmap' VALUES (31103, 20489, 5);
INSERT INTO 'dancesstepsmap' VALUES (31104, 20487, 4);
INSERT INTO 'dancesstepsmap' VALUES (31105, 20487, 5);
INSERT INTO 'dancesstepsmap' VALUES (31106, 20488, 1);
INSERT INTO 'dancesstepsmap' VALUES (31107, 20488, 2);
INSERT INTO 'dancesstepsmap' VALUES (31108, 20488, 3);
INSERT INTO 'dancesstepsmap' VALUES (31109, 20493, 4);
INSERT INTO 'dancesstepsmap' VALUES (31110, 20493, 5);
INSERT INTO 'dancesstepsmap' VALUES (31111, 20317, 4);
INSERT INTO 'dancesstepsmap' VALUES (31112, 20317, 5);
INSERT INTO 'dancesstepsmap' VALUES (31113, 6587, 5);
INSERT INTO 'dancesstepsmap' VALUES (31114, 6786, 2);
INSERT INTO 'dancesstepsmap' VALUES (31115, 3629, 5);
INSERT INTO 'dancesstepsmap' VALUES (31116, 20492, 1);
INSERT INTO 'dancesstepsmap' VALUES (31117, 20492, 3);
INSERT INTO 'dancesstepsmap' VALUES (31118, 8535, 2);
INSERT INTO 'dancesstepsmap' VALUES (31119, 14481, 5);
INSERT INTO 'dancesstepsmap' VALUES (31120, 14481, 4);
INSERT INTO 'dancesstepsmap' VALUES (31121, 14481, 6);
INSERT INTO 'dancesstepsmap' VALUES (31122, 20494, 1);
INSERT INTO 'dancesstepsmap' VALUES (31123, 20494, 2);
INSERT INTO 'dancesstepsmap' VALUES (31124, 20495, 1);
INSERT INTO 'dancesstepsmap' VALUES (31125, 17763, 1);
INSERT INTO 'dancesstepsmap' VALUES (31126, 17763, 2);
INSERT INTO 'dancesstepsmap' VALUES (31127, 17763, 3);
INSERT INTO 'dancesstepsmap' VALUES (31128, 17765, 2);
INSERT INTO 'dancesstepsmap' VALUES (31129, 17765, 1);
INSERT INTO 'dancesstepsmap' VALUES (31130, 17765, 3);
INSERT INTO 'dancesstepsmap' VALUES (31131, 17762, 5);
INSERT INTO 'dancesstepsmap' VALUES (31132, 17762, 4);
INSERT INTO 'dancesstepsmap' VALUES (31133, 19132, 4);
INSERT INTO 'dancesstepsmap' VALUES (31134, 19132, 5);
INSERT INTO 'dancesstepsmap' VALUES (31135, 20496, 4);
INSERT INTO 'dancesstepsmap' VALUES (31136, 20496, 5);
INSERT INTO 'dancesstepsmap' VALUES (31137, 10261, 2);
INSERT INTO 'dancesstepsmap' VALUES (31138, 20497, 1);
INSERT INTO 'dancesstepsmap' VALUES (31139, 3906, 2);
INSERT INTO 'dancesstepsmap' VALUES (31140, 2093, 4);
INSERT INTO 'dancesstepsmap' VALUES (31141, 2093, 10);
INSERT INTO 'dancesstepsmap' VALUES (31142, 2093, 1);
INSERT INTO 'dancesstepsmap' VALUES (31143, 2093, 2);
INSERT INTO 'dancesstepsmap' VALUES (31144, 2093, 8);
INSERT INTO 'dancesstepsmap' VALUES (31145, 20498, 2);
INSERT INTO 'dancesstepsmap' VALUES (31146, 20498, 1);
INSERT INTO 'dancesstepsmap' VALUES (31147, 20498, 3);
INSERT INTO 'dancesstepsmap' VALUES (31148, 20499, 1);
INSERT INTO 'dancesstepsmap' VALUES (31149, 20499, 2);
INSERT INTO 'dancesstepsmap' VALUES (31150, 20500, 1);
INSERT INTO 'dancesstepsmap' VALUES (31151, 20501, 1);
INSERT INTO 'dancesstepsmap' VALUES (31152, 20502, 1);
INSERT INTO 'dancesstepsmap' VALUES (31154, 9548, 1);
INSERT INTO 'dancesstepsmap' VALUES (31155, 20513, 4);
INSERT INTO 'dancesstepsmap' VALUES (31156, 20513, 5);
INSERT INTO 'dancesstepsmap' VALUES (31157, 20513, 1);
INSERT INTO 'dancesstepsmap' VALUES (31158, 20513, 2);
INSERT INTO 'dancesstepsmap' VALUES (31159, 20514, 1);
INSERT INTO 'dancesstepsmap' VALUES (31160, 20514, 3);
INSERT INTO 'dancesstepsmap' VALUES (31161, 20515, 4);
INSERT INTO 'dancesstepsmap' VALUES (31162, 20515, 5);
INSERT INTO 'dancesstepsmap' VALUES (31163, 20516, 1);
INSERT INTO 'dancesstepsmap' VALUES (31164, 20516, 3);
INSERT INTO 'dancesstepsmap' VALUES (31165, 20516, 2);
INSERT INTO 'dancesstepsmap' VALUES (31166, 20517, 1);
INSERT INTO 'dancesstepsmap' VALUES (31169, 20518, 4);
INSERT INTO 'dancesstepsmap' VALUES (31170, 20518, 5);
INSERT INTO 'dancesstepsmap' VALUES (31171, 20519, 1);
INSERT INTO 'dancesstepsmap' VALUES (31172, 20512, 1);
INSERT INTO 'dancesstepsmap' VALUES (31173, 20512, 2);
INSERT INTO 'dancesstepsmap' VALUES (31174, 20520, 1);
INSERT INTO 'dancesstepsmap' VALUES (31175, 20520, 3);
INSERT INTO 'dancesstepsmap' VALUES (31176, 20520, 2);
INSERT INTO 'dancesstepsmap' VALUES (31177, 20521, 5);
INSERT INTO 'dancesstepsmap' VALUES (31178, 20521, 4);
INSERT INTO 'dancesstepsmap' VALUES (31179, 20522, 1);
INSERT INTO 'dancesstepsmap' VALUES (31180, 20522, 2);
INSERT INTO 'dancesstepsmap' VALUES (31033, 20402, 3);
INSERT INTO 'dancesstepsmap' VALUES (31183, 20508, 1);
INSERT INTO 'dancesstepsmap' VALUES (31184, 20508, 2);
INSERT INTO 'dancesstepsmap' VALUES (31185, 20509, 1);
INSERT INTO 'dancesstepsmap' VALUES (31186, 20514, 2);
INSERT INTO 'dancesstepsmap' VALUES (31187, 20519, 2);
INSERT INTO 'dancesstepsmap' VALUES (31188, 18048, 4);
INSERT INTO 'dancesstepsmap' VALUES (31189, 18048, 5);
INSERT INTO 'dancesstepsmap' VALUES (31190, 20535, 4);
INSERT INTO 'dancesstepsmap' VALUES (31191, 20523, 2);
INSERT INTO 'dancesstepsmap' VALUES (31192, 20523, 1);
INSERT INTO 'dancesstepsmap' VALUES (31193, 20523, 3);
INSERT INTO 'dancesstepsmap' VALUES (31194, 20524, 5);
INSERT INTO 'dancesstepsmap' VALUES (31195, 20524, 4);
INSERT INTO 'dancesstepsmap' VALUES (31196, 20525, 2);
INSERT INTO 'dancesstepsmap' VALUES (31197, 20525, 1);
INSERT INTO 'dancesstepsmap' VALUES (31198, 20526, 2);
INSERT INTO 'dancesstepsmap' VALUES (31199, 20526, 1);
INSERT INTO 'dancesstepsmap' VALUES (31200, 20526, 3);
INSERT INTO 'dancesstepsmap' VALUES (31201, 20527, 2);
INSERT INTO 'dancesstepsmap' VALUES (31202, 20527, 1);
INSERT INTO 'dancesstepsmap' VALUES (31203, 20528, 2);
INSERT INTO 'dancesstepsmap' VALUES (31204, 20528, 1);
INSERT INTO 'dancesstepsmap' VALUES (31205, 20528, 5);
INSERT INTO 'dancesstepsmap' VALUES (31206, 20528, 4);
INSERT INTO 'dancesstepsmap' VALUES (31207, 20529, 2);
INSERT INTO 'dancesstepsmap' VALUES (31208, 20529, 1);
INSERT INTO 'dancesstepsmap' VALUES (31209, 20530, 5);
INSERT INTO 'dancesstepsmap' VALUES (31210, 20530, 4);
INSERT INTO 'dancesstepsmap' VALUES (31211, 20531, 1);
INSERT INTO 'dancesstepsmap' VALUES (31212, 20531, 3);
INSERT INTO 'dancesstepsmap' VALUES (31213, 20532, 1);
INSERT INTO 'dancesstepsmap' VALUES (31214, 20533, 2);
INSERT INTO 'dancesstepsmap' VALUES (31215, 20533, 1);
INSERT INTO 'dancesstepsmap' VALUES (31216, 20534, 1);
INSERT INTO 'dancesstepsmap' VALUES (31217, 20536, 2);
INSERT INTO 'dancesstepsmap' VALUES (31218, 20536, 1);
INSERT INTO 'dancesstepsmap' VALUES (31219, 20536, 3);
INSERT INTO 'dancesstepsmap' VALUES (31220, 20537, 1);
INSERT INTO 'dancesstepsmap' VALUES (31221, 20537, 2);
INSERT INTO 'dancesstepsmap' VALUES (31223, 20538, 4);
INSERT INTO 'dancesstepsmap' VALUES (31224, 20538, 5);
INSERT INTO 'dancesstepsmap' VALUES (31225, 20539, 4);
INSERT INTO 'dancesstepsmap' VALUES (31226, 20539, 5);
INSERT INTO 'dancesstepsmap' VALUES (31227, 20540, 1);
INSERT INTO 'dancesstepsmap' VALUES (31228, 20540, 2);
INSERT INTO 'dancesstepsmap' VALUES (31229, 20541, 4);
INSERT INTO 'dancesstepsmap' VALUES (31230, 20541, 5);
INSERT INTO 'dancesstepsmap' VALUES (31231, 20542, 1);
INSERT INTO 'dancesstepsmap' VALUES (31232, 20542, 2);
INSERT INTO 'dancesstepsmap' VALUES (31233, 20542, 3);
INSERT INTO 'dancesstepsmap' VALUES (31234, 20543, 1);
INSERT INTO 'dancesstepsmap' VALUES (31235, 20543, 2);
INSERT INTO 'dancesstepsmap' VALUES (31236, 20544, 4);
INSERT INTO 'dancesstepsmap' VALUES (31237, 20544, 5);
INSERT INTO 'dancesstepsmap' VALUES (31238, 20545, 1);
INSERT INTO 'dancesstepsmap' VALUES (31239, 20545, 2);
INSERT INTO 'dancesstepsmap' VALUES (31240, 20546, 1);
INSERT INTO 'dancesstepsmap' VALUES (31241, 20546, 3);
INSERT INTO 'dancesstepsmap' VALUES (31242, 20547, 1);
INSERT INTO 'dancesstepsmap' VALUES (31243, 20548, 4);
INSERT INTO 'dancesstepsmap' VALUES (31244, 20548, 5);
INSERT INTO 'dancesstepsmap' VALUES (31245, 20549, 4);
INSERT INTO 'dancesstepsmap' VALUES (31246, 20549, 5);
INSERT INTO 'dancesstepsmap' VALUES (31247, 20550, 2);
INSERT INTO 'dancesstepsmap' VALUES (31248, 20550, 1);
INSERT INTO 'dancesstepsmap' VALUES (31249, 20551, 1);
INSERT INTO 'dancesstepsmap' VALUES (31250, 20551, 2);
INSERT INTO 'dancesstepsmap' VALUES (31251, 20551, 4);
INSERT INTO 'dancesstepsmap' VALUES (31252, 20551, 3);
INSERT INTO 'dancesstepsmap' VALUES (31253, 20552, 1);
INSERT INTO 'dancesstepsmap' VALUES (31254, 20553, 1);
INSERT INTO 'dancesstepsmap' VALUES (31255, 20553, 3);
INSERT INTO 'dancesstepsmap' VALUES (31256, 3014, 2);
INSERT INTO 'dancesstepsmap' VALUES (31257, 18671, 2);
INSERT INTO 'dancesstepsmap' VALUES (31258, 18671, 1);
INSERT INTO 'dancesstepsmap' VALUES (31259, 107, 2);
INSERT INTO 'dancesstepsmap' VALUES (31260, 20554, 1);
INSERT INTO 'dancesstepsmap' VALUES (31261, 20554, 3);
INSERT INTO 'dancesstepsmap' VALUES (31262, 6718, 3);
INSERT INTO 'dancesstepsmap' VALUES (31263, 2331, 2);
INSERT INTO 'dancesstepsmap' VALUES (31264, 2331, 3);
INSERT INTO 'dancesstepsmap' VALUES (29256, 20149, 1);
INSERT INTO 'dancesstepsmap' VALUES (29257, 20149, 2);
INSERT INTO 'dancesstepsmap' VALUES (31265, 20555, 2);
INSERT INTO 'dancesstepsmap' VALUES (31266, 20555, 1);
INSERT INTO 'dancesstepsmap' VALUES (31267, 20556, 2);
INSERT INTO 'dancesstepsmap' VALUES (31268, 20556, 3);
INSERT INTO 'dancesstepsmap' VALUES (31269, 20556, 1);
INSERT INTO 'dancesstepsmap' VALUES (16748, 14331, 4);
INSERT INTO 'dancesstepsmap' VALUES (16749, 14331, 5);
INSERT INTO 'dancesstepsmap' VALUES (31270, 20557, 2);
INSERT INTO 'dancesstepsmap' VALUES (31271, 20557, 3);
INSERT INTO 'dancesstepsmap' VALUES (31272, 20557, 1);
INSERT INTO 'dancesstepsmap' VALUES (31273, 20558, 1);
INSERT INTO 'dancesstepsmap' VALUES (31274, 20558, 3);
INSERT INTO 'dancesstepsmap' VALUES (31275, 20558, 2);
INSERT INTO 'dancesstepsmap' VALUES (31276, 20457, 3);
INSERT INTO 'dancesstepsmap' VALUES (31277, 20559, 1);
INSERT INTO 'dancesstepsmap' VALUES (20935, 16729, 4);
INSERT INTO 'dancesstepsmap' VALUES (20936, 16729, 5);
INSERT INTO 'dancesstepsmap' VALUES (31278, 3094, 5);
INSERT INTO 'dancesstepsmap' VALUES (31279, 20560, 4);
INSERT INTO 'dancesstepsmap' VALUES (31280, 20560, 5);
INSERT INTO 'dancesstepsmap' VALUES (31281, 20561, 5);
INSERT INTO 'dancesstepsmap' VALUES (31282, 20561, 4);
INSERT INTO 'dancesstepsmap' VALUES (31283, 20562, 1);
INSERT INTO 'dancesstepsmap' VALUES (31284, 20562, 2);
INSERT INTO 'dancesstepsmap' VALUES (31285, 17191, 2);
INSERT INTO 'dancesstepsmap' VALUES (31286, 17191, 1);
INSERT INTO 'dancesstepsmap' VALUES (31287, 17191, 3);
INSERT INTO 'dancesstepsmap' VALUES (31288, 16671, 1);
INSERT INTO 'dancesstepsmap' VALUES (31289, 16671, 2);
INSERT INTO 'dancesstepsmap' VALUES (31290, 16671, 3);
INSERT INTO 'dancesstepsmap' VALUES (31167, 20517, 2);
INSERT INTO 'dancesstepsmap' VALUES (31168, 20517, 3);
INSERT INTO 'dancesstepsmap' VALUES (31291, 20563, 4);
INSERT INTO 'dancesstepsmap' VALUES (31292, 20563, 5);
INSERT INTO 'dancesstepsmap' VALUES (31293, 20315, 1);
INSERT INTO 'dancesstepsmap' VALUES (31294, 20315, 2);
INSERT INTO 'dancesstepsmap' VALUES (31295, 20315, 3);
INSERT INTO 'dancesstepsmap' VALUES (31296, 20320, 1);
INSERT INTO 'dancesstepsmap' VALUES (31297, 20320, 2);
INSERT INTO 'dancesstepsmap' VALUES (31298, 20320, 3);
INSERT INTO 'dancesstepsmap' VALUES (31181, 20506, 4);
INSERT INTO 'dancesstepsmap' VALUES (31299, 14430, 3);
INSERT INTO 'dancesstepsmap' VALUES (31300, 20564, 4);
INSERT INTO 'dancesstepsmap' VALUES (31301, 20564, 5);
INSERT INTO 'dancesstepsmap' VALUES (31302, 20565, 1);
INSERT INTO 'dancesstepsmap' VALUES (31303, 20565, 2);
INSERT INTO 'dancesstepsmap' VALUES (31304, 20566, 1);
INSERT INTO 'dancesstepsmap' VALUES (31305, 20566, 2);
INSERT INTO 'dancesstepsmap' VALUES (31306, 20567, 5);
INSERT INTO 'dancesstepsmap' VALUES (31307, 20567, 4);
INSERT INTO 'dancesstepsmap' VALUES (31308, 20568, 1);
INSERT INTO 'dancesstepsmap' VALUES (31309, 20569, 2);
INSERT INTO 'dancesstepsmap' VALUES (31310, 20569, 1);
INSERT INTO 'dancesstepsmap' VALUES (31311, 20570, 5);
INSERT INTO 'dancesstepsmap' VALUES (31312, 20570, 4);
INSERT INTO 'dancesstepsmap' VALUES (31313, 20571, 1);
INSERT INTO 'dancesstepsmap' VALUES (31314, 20571, 2);
INSERT INTO 'dancesstepsmap' VALUES (31315, 20573, 2);
INSERT INTO 'dancesstepsmap' VALUES (31316, 20573, 1);
INSERT INTO 'dancesstepsmap' VALUES (31317, 20572, 2);
INSERT INTO 'dancesstepsmap' VALUES (31318, 20572, 1);
INSERT INTO 'dancesstepsmap' VALUES (31319, 20572, 3);
INSERT INTO 'dancesstepsmap' VALUES (31320, 20574, 4);
INSERT INTO 'dancesstepsmap' VALUES (31321, 20574, 5);
INSERT INTO 'dancesstepsmap' VALUES (31322, 338, 2);
INSERT INTO 'dancesstepsmap' VALUES (31323, 9579, 5);
INSERT INTO 'dancesstepsmap' VALUES (31324, 20575, 3);
INSERT INTO 'dancesstepsmap' VALUES (31325, 20575, 1);
INSERT INTO 'dancesstepsmap' VALUES (31326, 13181, 2);
INSERT INTO 'dancesstepsmap' VALUES (31327, 20576, 4);
INSERT INTO 'dancesstepsmap' VALUES (31328, 20576, 5);
INSERT INTO 'dancesstepsmap' VALUES (31329, 20577, 1);
INSERT INTO 'dancesstepsmap' VALUES (31330, 20577, 2);
INSERT INTO 'dancesstepsmap' VALUES (31331, 20578, 1);
INSERT INTO 'dancesstepsmap' VALUES (31333, 20579, 4);
INSERT INTO 'dancesstepsmap' VALUES (31334, 20579, 5);
INSERT INTO 'dancesstepsmap' VALUES (31335, 10129, 2);
INSERT INTO 'dancesstepsmap' VALUES (31336, 10129, 1);
INSERT INTO 'dancesstepsmap' VALUES (31050, 20452, 1);
INSERT INTO 'dancesstepsmap' VALUES (31051, 20452, 2);
INSERT INTO 'dancesstepsmap' VALUES (31337, 13539, 1);
INSERT INTO 'dancesstepsmap' VALUES (31338, 13539, 3);
INSERT INTO 'dancesstepsmap' VALUES (31339, 20593, 1);
INSERT INTO 'dancesstepsmap' VALUES (31340, 20593, 3);
INSERT INTO 'dancesstepsmap' VALUES (31341, 20594, 1);
INSERT INTO 'dancesstepsmap' VALUES (31342, 20595, 4);
INSERT INTO 'dancesstepsmap' VALUES (31343, 20596, 1);
INSERT INTO 'dancesstepsmap' VALUES (31344, 20597, 1);
INSERT INTO 'dancesstepsmap' VALUES (31345, 20597, 2);
INSERT INTO 'dancesstepsmap' VALUES (31346, 20598, 5);
INSERT INTO 'dancesstepsmap' VALUES (31347, 20598, 4);
INSERT INTO 'dancesstepsmap' VALUES (31348, 20599, 2);
INSERT INTO 'dancesstepsmap' VALUES (31349, 20599, 1);
INSERT INTO 'dancesstepsmap' VALUES (31350, 20600, 1);
INSERT INTO 'dancesstepsmap' VALUES (31351, 20601, 1);
INSERT INTO 'dancesstepsmap' VALUES (31352, 20601, 3);
INSERT INTO 'dancesstepsmap' VALUES (31353, 20602, 1);
INSERT INTO 'dancesstepsmap' VALUES (31354, 20602, 2);
INSERT INTO 'dancesstepsmap' VALUES (31355, 20603, 2);
INSERT INTO 'dancesstepsmap' VALUES (31356, 20603, 1);
INSERT INTO 'dancesstepsmap' VALUES (31357, 20603, 3);
INSERT INTO 'dancesstepsmap' VALUES (31358, 20604, 4);
INSERT INTO 'dancesstepsmap' VALUES (31359, 20604, 5);
INSERT INTO 'dancesstepsmap' VALUES (31360, 20605, 5);
INSERT INTO 'dancesstepsmap' VALUES (31361, 20605, 4);
INSERT INTO 'dancesstepsmap' VALUES (31362, 20606, 1);
INSERT INTO 'dancesstepsmap' VALUES (31363, 20606, 2);
INSERT INTO 'dancesstepsmap' VALUES (31364, 20606, 3);
INSERT INTO 'dancesstepsmap' VALUES (31365, 20608, 4);
INSERT INTO 'dancesstepsmap' VALUES (31366, 20609, 1);
INSERT INTO 'dancesstepsmap' VALUES (31367, 20609, 2);
INSERT INTO 'dancesstepsmap' VALUES (31368, 20610, 1);
INSERT INTO 'dancesstepsmap' VALUES (31369, 20610, 3);
INSERT INTO 'dancesstepsmap' VALUES (31370, 20611, 4);
INSERT INTO 'dancesstepsmap' VALUES (31371, 20611, 1);
INSERT INTO 'dancesstepsmap' VALUES (31372, 20611, 2);
INSERT INTO 'dancesstepsmap' VALUES (31373, 20612, 5);
INSERT INTO 'dancesstepsmap' VALUES (31374, 20612, 4);
INSERT INTO 'dancesstepsmap' VALUES (31375, 20613, 2);
INSERT INTO 'dancesstepsmap' VALUES (31376, 20613, 3);
INSERT INTO 'dancesstepsmap' VALUES (31377, 20613, 1);
INSERT INTO 'dancesstepsmap' VALUES (31378, 20614, 1);
INSERT INTO 'dancesstepsmap' VALUES (31379, 20614, 2);
INSERT INTO 'dancesstepsmap' VALUES (31380, 20615, 3);
INSERT INTO 'dancesstepsmap' VALUES (31381, 20615, 1);
INSERT INTO 'dancesstepsmap' VALUES (31382, 20616, 4);
INSERT INTO 'dancesstepsmap' VALUES (31383, 20616, 5);
INSERT INTO 'dancesstepsmap' VALUES (31384, 20617, 1);
INSERT INTO 'dancesstepsmap' VALUES (31385, 20617, 3);
INSERT INTO 'dancesstepsmap' VALUES (31386, 20617, 2);
INSERT INTO 'dancesstepsmap' VALUES (31387, 20618, 1);
INSERT INTO 'dancesstepsmap' VALUES (31388, 20618, 2);
INSERT INTO 'dancesstepsmap' VALUES (31389, 20619, 1);
INSERT INTO 'dancesstepsmap' VALUES (31390, 20619, 2);
INSERT INTO 'dancesstepsmap' VALUES (31391, 20623, 1);
INSERT INTO 'dancesstepsmap' VALUES (31392, 20624, 5);
INSERT INTO 'dancesstepsmap' VALUES (31393, 20624, 4);
INSERT INTO 'dancesstepsmap' VALUES (31394, 20620, 1);
INSERT INTO 'dancesstepsmap' VALUES (31395, 20625, 4);
INSERT INTO 'dancesstepsmap' VALUES (31396, 20625, 5);
INSERT INTO 'dancesstepsmap' VALUES (31397, 3624, 5);
INSERT INTO 'dancesstepsmap' VALUES (31398, 4101, 3);
INSERT INTO 'dancesstepsmap' VALUES (31399, 20632, 4);
INSERT INTO 'dancesstepsmap' VALUES (31400, 20633, 1);
INSERT INTO 'dancesstepsmap' VALUES (31401, 20633, 2);
INSERT INTO 'dancesstepsmap' VALUES (31402, 20633, 3);
INSERT INTO 'dancesstepsmap' VALUES (31403, 20634, 3);
INSERT INTO 'dancesstepsmap' VALUES (31404, 20634, 1);
INSERT INTO 'dancesstepsmap' VALUES (31405, 20636, 4);
INSERT INTO 'dancesstepsmap' VALUES (31406, 20636, 5);
INSERT INTO 'dancesstepsmap' VALUES (31407, 20637, 1);
INSERT INTO 'dancesstepsmap' VALUES (31408, 20637, 2);
INSERT INTO 'dancesstepsmap' VALUES (31409, 3681, 2);
INSERT INTO 'dancesstepsmap' VALUES (31410, 15712, 4);
INSERT INTO 'dancesstepsmap' VALUES (31411, 15712, 5);
INSERT INTO 'dancesstepsmap' VALUES (31412, 15712, 3);
INSERT INTO 'dancesstepsmap' VALUES (31413, 15712, 1);
INSERT INTO 'dancesstepsmap' VALUES (31414, 15712, 2);
INSERT INTO 'dancesstepsmap' VALUES (31415, 7648, 5);
INSERT INTO 'dancesstepsmap' VALUES (31416, 6264, 5);
INSERT INTO 'dancesstepsmap' VALUES (31417, 20635, 1);
INSERT INTO 'dancesstepsmap' VALUES (31418, 20635, 2);
INSERT INTO 'dancesstepsmap' VALUES (31419, 20635, 3);
INSERT INTO 'dancesstepsmap' VALUES (31420, 17356, 4);
INSERT INTO 'dancesstepsmap' VALUES (31421, 17356, 5);
INSERT INTO 'dancesstepsmap' VALUES (31422, 20639, 2);
INSERT INTO 'dancesstepsmap' VALUES (31423, 20639, 1);
INSERT INTO 'dancesstepsmap' VALUES (31424, 3001, 5);
INSERT INTO 'dancesstepsmap' VALUES (31425, 20640, 4);
INSERT INTO 'dancesstepsmap' VALUES (31426, 20641, 1);
INSERT INTO 'dancesstepsmap' VALUES (31427, 20642, 1);
INSERT INTO 'dancesstepsmap' VALUES (31428, 20642, 2);
INSERT INTO 'dancesstepsmap' VALUES (31429, 5574, 2);
INSERT INTO 'dancesstepsmap' VALUES (31430, 5455, 5);
INSERT INTO 'dancesstepsmap' VALUES (31431, 20659, 1);
INSERT INTO 'dancesstepsmap' VALUES (31434, 20661, 4);
INSERT INTO 'dancesstepsmap' VALUES (31435, 20661, 5);
INSERT INTO 'dancesstepsmap' VALUES (31436, 20663, 1);
INSERT INTO 'dancesstepsmap' VALUES (31437, 20663, 2);
INSERT INTO 'dancesstepsmap' VALUES (31438, 20664, 4);
INSERT INTO 'dancesstepsmap' VALUES (31439, 20664, 5);
INSERT INTO 'dancesstepsmap' VALUES (31440, 20665, 1);
INSERT INTO 'dancesstepsmap' VALUES (31441, 20665, 2);
INSERT INTO 'dancesstepsmap' VALUES (31442, 20318, 1);
INSERT INTO 'dancesstepsmap' VALUES (31443, 20318, 2);
INSERT INTO 'dancesstepsmap' VALUES (31444, 20318, 3);
INSERT INTO 'dancesstepsmap' VALUES (31445, 20666, 5);
INSERT INTO 'dancesstepsmap' VALUES (31446, 20666, 4);
INSERT INTO 'dancesstepsmap' VALUES (31447, 20666, 2);
INSERT INTO 'dancesstepsmap' VALUES (31448, 20666, 1);
INSERT INTO 'dancesstepsmap' VALUES (31449, 20666, 3);
INSERT INTO 'dancesstepsmap' VALUES (31450, 20667, 4);
INSERT INTO 'dancesstepsmap' VALUES (31451, 20668, 1);
INSERT INTO 'dancesstepsmap' VALUES (31452, 20668, 2);
INSERT INTO 'dancesstepsmap' VALUES (31453, 20668, 3);
INSERT INTO 'dancesstepsmap' VALUES (31454, 11562, 5);
INSERT INTO 'dancesstepsmap' VALUES (31455, 1960, 2);
INSERT INTO 'dancesstepsmap' VALUES (31456, 20669, 4);
INSERT INTO 'dancesstepsmap' VALUES (31457, 20669, 5);
INSERT INTO 'dancesstepsmap' VALUES (31458, 20669, 1);
INSERT INTO 'dancesstepsmap' VALUES (31459, 20669, 2);
INSERT INTO 'dancesstepsmap' VALUES (31460, 20669, 3);
INSERT INTO 'dancesstepsmap' VALUES (31461, 20670, 2);
INSERT INTO 'dancesstepsmap' VALUES (31462, 20670, 1);
INSERT INTO 'dancesstepsmap' VALUES (31464, 20670, 3);
INSERT INTO 'dancesstepsmap' VALUES (31465, 1508, 5);
INSERT INTO 'dancesstepsmap' VALUES (31466, 5678, 2);
INSERT INTO 'dancesstepsmap' VALUES (31467, 5678, 3);
INSERT INTO 'dancesstepsmap' VALUES (31468, 2858, 3);
INSERT INTO 'dancesstepsmap' VALUES (31469, 20671, 4);
INSERT INTO 'dancesstepsmap' VALUES (31470, 20671, 5);
INSERT INTO 'dancesstepsmap' VALUES (31471, 17559, 2);
INSERT INTO 'dancesstepsmap' VALUES (31472, 17559, 1);
INSERT INTO 'dancesstepsmap' VALUES (31473, 17559, 3);
INSERT INTO 'dancesstepsmap' VALUES (31474, 20674, 4);
INSERT INTO 'dancesstepsmap' VALUES (31475, 20674, 5);
INSERT INTO 'dancesstepsmap' VALUES (31476, 20645, 4);
INSERT INTO 'dancesstepsmap' VALUES (31477, 20645, 5);
INSERT INTO 'dancesstepsmap' VALUES (31478, 20675, 5);
INSERT INTO 'dancesstepsmap' VALUES (31479, 20675, 4);
INSERT INTO 'dancesstepsmap' VALUES (31480, 20676, 1);
INSERT INTO 'dancesstepsmap' VALUES (31481, 20676, 2);
INSERT INTO 'dancesstepsmap' VALUES (31482, 20676, 3);
INSERT INTO 'dancesstepsmap' VALUES (31483, 3128, 2);
INSERT INTO 'dancesstepsmap' VALUES (31484, 3128, 3);
INSERT INTO 'dancesstepsmap' VALUES (31485, 20702, 1);
INSERT INTO 'dancesstepsmap' VALUES (31486, 20702, 2);
INSERT INTO 'dancesstepsmap' VALUES (31487, 20702, 3);
INSERT INTO 'dancesstepsmap' VALUES (31488, 20704, 1);
INSERT INTO 'dancesstepsmap' VALUES (31489, 20705, 4);
INSERT INTO 'dancesstepsmap' VALUES (31490, 20705, 5);
INSERT INTO 'dancesstepsmap' VALUES (31491, 20706, 1);
INSERT INTO 'dancesstepsmap' VALUES (31492, 20706, 2);
INSERT INTO 'dancesstepsmap' VALUES (31493, 20706, 3);
INSERT INTO 'dancesstepsmap' VALUES (31494, 20707, 2);
INSERT INTO 'dancesstepsmap' VALUES (31495, 20707, 1);
INSERT INTO 'dancesstepsmap' VALUES (31496, 20707, 3);
INSERT INTO 'dancesstepsmap' VALUES (31497, 20708, 5);
INSERT INTO 'dancesstepsmap' VALUES (31498, 20708, 4);
INSERT INTO 'dancesstepsmap' VALUES (31499, 19854, 1);
INSERT INTO 'dancesstepsmap' VALUES (31500, 19854, 2);
INSERT INTO 'dancesstepsmap' VALUES (31501, 20649, 2);
INSERT INTO 'dancesstepsmap' VALUES (31502, 20649, 1);
INSERT INTO 'dancesstepsmap' VALUES (31503, 20718, 4);
INSERT INTO 'dancesstepsmap' VALUES (31504, 20718, 5);
INSERT INTO 'dancesstepsmap' VALUES (31505, 20719, 4);
INSERT INTO 'dancesstepsmap' VALUES (31506, 6545, 2);
INSERT INTO 'dancesstepsmap' VALUES (31507, 13894, 4);
INSERT INTO 'dancesstepsmap' VALUES (31508, 13894, 5);
INSERT INTO 'dancesstepsmap' VALUES (31509, 20721, 1);
INSERT INTO 'dancesstepsmap' VALUES (31510, 20721, 2);
INSERT INTO 'dancesstepsmap' VALUES (31511, 20722, 4);
INSERT INTO 'dancesstepsmap' VALUES (31512, 20722, 5);
INSERT INTO 'dancesstepsmap' VALUES (31513, 20723, 1);
INSERT INTO 'dancesstepsmap' VALUES (31514, 20723, 2);
INSERT INTO 'dancesstepsmap' VALUES (31515, 20724, 1);
INSERT INTO 'dancesstepsmap' VALUES (31516, 20724, 2);
INSERT INTO 'dancesstepsmap' VALUES (31517, 20725, 1);
INSERT INTO 'dancesstepsmap' VALUES (31518, 20725, 2);
INSERT INTO 'dancesstepsmap' VALUES (31519, 20726, 4);
INSERT INTO 'dancesstepsmap' VALUES (31520, 20726, 5);
INSERT INTO 'dancesstepsmap' VALUES (31521, 19601, 5);
INSERT INTO 'dancesstepsmap' VALUES (31522, 19601, 4);
INSERT INTO 'dancesstepsmap' VALUES (31523, 19601, 1);
INSERT INTO 'dancesstepsmap' VALUES (31524, 19601, 2);
INSERT INTO 'dancesstepsmap' VALUES (31525, 20727, 4);
INSERT INTO 'dancesstepsmap' VALUES (31526, 20727, 5);
INSERT INTO 'dancesstepsmap' VALUES (31527, 20728, 4);
INSERT INTO 'dancesstepsmap' VALUES (31528, 20728, 5);
INSERT INTO 'dancesstepsmap' VALUES (31529, 20728, 6);
INSERT INTO 'dancesstepsmap' VALUES (31530, 20728, 1);
INSERT INTO 'dancesstepsmap' VALUES (31531, 20728, 2);
INSERT INTO 'dancesstepsmap' VALUES (31532, 20728, 3);
INSERT INTO 'dancesstepsmap' VALUES (31533, 13778, 1);
INSERT INTO 'dancesstepsmap' VALUES (31534, 17244, 1);
INSERT INTO 'dancesstepsmap' VALUES (31535, 17244, 2);
INSERT INTO 'dancesstepsmap' VALUES (31536, 20729, 1);
INSERT INTO 'dancesstepsmap' VALUES (31537, 20729, 3);
INSERT INTO 'dancesstepsmap' VALUES (31538, 20730, 3);
INSERT INTO 'dancesstepsmap' VALUES (31539, 20730, 1);
INSERT INTO 'dancesstepsmap' VALUES (31540, 20730, 2);
INSERT INTO 'dancesstepsmap' VALUES (31541, 20731, 2);
INSERT INTO 'dancesstepsmap' VALUES (31542, 20731, 1);
INSERT INTO 'dancesstepsmap' VALUES (31543, 20731, 3);
INSERT INTO 'dancesstepsmap' VALUES (31544, 20732, 5);
INSERT INTO 'dancesstepsmap' VALUES (31545, 20732, 4);
INSERT INTO 'dancesstepsmap' VALUES (31546, 20733, 3);
INSERT INTO 'dancesstepsmap' VALUES (31547, 20733, 2);
INSERT INTO 'dancesstepsmap' VALUES (31548, 20734, 5);
INSERT INTO 'dancesstepsmap' VALUES (31549, 20734, 4);
INSERT INTO 'dancesstepsmap' VALUES (31552, 20736, 4);
INSERT INTO 'dancesstepsmap' VALUES (31553, 20736, 5);
INSERT INTO 'dancesstepsmap' VALUES (31554, 20737, 1);
INSERT INTO 'dancesstepsmap' VALUES (31555, 20737, 2);
INSERT INTO 'dancesstepsmap' VALUES (31556, 20738, 1);
INSERT INTO 'dancesstepsmap' VALUES (31557, 20739, 4);
INSERT INTO 'dancesstepsmap' VALUES (31558, 20739, 5);
INSERT INTO 'dancesstepsmap' VALUES (31559, 20740, 1);
INSERT INTO 'dancesstepsmap' VALUES (31560, 20740, 2);
INSERT INTO 'dancesstepsmap' VALUES (31561, 20741, 1);
INSERT INTO 'dancesstepsmap' VALUES (31564, 20743, 1);
INSERT INTO 'dancesstepsmap' VALUES (31565, 20743, 2);
INSERT INTO 'dancesstepsmap' VALUES (31566, 20743, 3);
INSERT INTO 'dancesstepsmap' VALUES (31567, 20744, 4);
INSERT INTO 'dancesstepsmap' VALUES (31568, 20744, 5);
INSERT INTO 'dancesstepsmap' VALUES (31569, 20745, 2);
INSERT INTO 'dancesstepsmap' VALUES (31570, 20745, 1);
INSERT INTO 'dancesstepsmap' VALUES (31571, 20746, 1);
INSERT INTO 'dancesstepsmap' VALUES (31572, 20746, 2);
INSERT INTO 'dancesstepsmap' VALUES (31573, 20747, 4);
INSERT INTO 'dancesstepsmap' VALUES (31574, 20747, 5);
INSERT INTO 'dancesstepsmap' VALUES (31575, 20748, 1);
INSERT INTO 'dancesstepsmap' VALUES (31576, 20748, 2);
INSERT INTO 'dancesstepsmap' VALUES (31577, 20673, 4);
INSERT INTO 'dancesstepsmap' VALUES (31578, 20673, 5);
INSERT INTO 'dancesstepsmap' VALUES (31579, 20673, 1);
INSERT INTO 'dancesstepsmap' VALUES (31580, 20673, 2);
INSERT INTO 'dancesstepsmap' VALUES (31581, 20673, 3);
INSERT INTO 'dancesstepsmap' VALUES (31582, 1064, 5);
INSERT INTO 'dancesstepsmap' VALUES (31583, 1445, 5);
INSERT INTO 'dancesstepsmap' VALUES (31584, 20749, 4);
INSERT INTO 'dancesstepsmap' VALUES (31585, 20749, 1);
INSERT INTO 'dancesstepsmap' VALUES (31586, 20749, 3);
INSERT INTO 'dancesstepsmap' VALUES (31587, 20672, 1);
INSERT INTO 'dancesstepsmap' VALUES (31588, 20672, 2);
INSERT INTO 'dancesstepsmap' VALUES (31589, 11302, 1);
INSERT INTO 'dancesstepsmap' VALUES (31590, 20753, 1);
INSERT INTO 'dancesstepsmap' VALUES (31591, 20753, 2);
INSERT INTO 'dancesstepsmap' VALUES (31592, 20766, 2);
INSERT INTO 'dancesstepsmap' VALUES (31593, 20766, 1);
INSERT INTO 'dancesstepsmap' VALUES (31594, 20766, 3);
INSERT INTO 'dancesstepsmap' VALUES (31595, 20767, 3);
INSERT INTO 'dancesstepsmap' VALUES (31596, 20767, 1);
INSERT INTO 'dancesstepsmap' VALUES (31597, 20767, 2);
INSERT INTO 'dancesstepsmap' VALUES (31598, 20770, 4);
INSERT INTO 'dancesstepsmap' VALUES (31599, 20770, 5);
INSERT INTO 'dancesstepsmap' VALUES (31600, 17975, 4);
INSERT INTO 'dancesstepsmap' VALUES (31601, 17975, 5);
INSERT INTO 'dancesstepsmap' VALUES (31602, 20771, 1);
INSERT INTO 'dancesstepsmap' VALUES (31603, 20771, 2);
INSERT INTO 'dancesstepsmap' VALUES (31604, 20771, 3);
INSERT INTO 'dancesstepsmap' VALUES (31605, 20772, 2);
INSERT INTO 'dancesstepsmap' VALUES (31606, 20772, 1);
INSERT INTO 'dancesstepsmap' VALUES (31607, 20773, 2);
INSERT INTO 'dancesstepsmap' VALUES (31608, 20773, 1);
INSERT INTO 'dancesstepsmap' VALUES (31609, 20778, 4);
INSERT INTO 'dancesstepsmap' VALUES (31610, 20778, 5);
INSERT INTO 'dancesstepsmap' VALUES (31611, 20779, 4);
INSERT INTO 'dancesstepsmap' VALUES (31612, 20779, 5);
INSERT INTO 'dancesstepsmap' VALUES (31613, 20780, 1);
INSERT INTO 'dancesstepsmap' VALUES (31614, 20780, 2);
INSERT INTO 'dancesstepsmap' VALUES (31615, 20780, 3);
INSERT INTO 'dancesstepsmap' VALUES (31616, 7171, 5);
INSERT INTO 'dancesstepsmap' VALUES (31617, 13911, 4);
INSERT INTO 'dancesstepsmap' VALUES (31618, 13911, 5);
INSERT INTO 'dancesstepsmap' VALUES (31619, 20781, 1);
INSERT INTO 'dancesstepsmap' VALUES (31620, 20781, 2);
INSERT INTO 'dancesstepsmap' VALUES (31621, 20782, 2);
INSERT INTO 'dancesstepsmap' VALUES (31622, 20782, 1);
INSERT INTO 'dancesstepsmap' VALUES (31623, 20783, 2);
INSERT INTO 'dancesstepsmap' VALUES (31624, 20783, 1);
INSERT INTO 'dancesstepsmap' VALUES (31625, 20784, 2);
INSERT INTO 'dancesstepsmap' VALUES (31626, 20784, 1);
INSERT INTO 'dancesstepsmap' VALUES (31627, 20784, 3);
INSERT INTO 'dancesstepsmap' VALUES (31628, 20785, 2);
INSERT INTO 'dancesstepsmap' VALUES (31629, 20785, 1);
INSERT INTO 'dancesstepsmap' VALUES (31630, 20786, 2);
INSERT INTO 'dancesstepsmap' VALUES (31631, 20786, 1);
INSERT INTO 'dancesstepsmap' VALUES (31632, 20787, 5);
INSERT INTO 'dancesstepsmap' VALUES (31633, 20787, 4);
INSERT INTO 'dancesstepsmap' VALUES (31634, 20788, 5);
INSERT INTO 'dancesstepsmap' VALUES (31635, 20788, 4);
INSERT INTO 'dancesstepsmap' VALUES (31636, 20789, 5);
INSERT INTO 'dancesstepsmap' VALUES (31637, 20789, 4);
INSERT INTO 'dancesstepsmap' VALUES (31638, 20790, 5);
INSERT INTO 'dancesstepsmap' VALUES (31639, 20790, 4);
INSERT INTO 'dancesstepsmap' VALUES (31640, 20791, 5);
INSERT INTO 'dancesstepsmap' VALUES (31641, 20791, 4);
INSERT INTO 'dancesstepsmap' VALUES (31642, 20792, 5);
INSERT INTO 'dancesstepsmap' VALUES (31643, 20792, 4);
INSERT INTO 'dancesstepsmap' VALUES (31644, 20793, 5);
INSERT INTO 'dancesstepsmap' VALUES (31645, 20793, 4);
INSERT INTO 'dancesstepsmap' VALUES (31646, 20794, 4);
INSERT INTO 'dancesstepsmap' VALUES (31647, 20794, 5);
INSERT INTO 'dancesstepsmap' VALUES (31648, 20794, 2);
INSERT INTO 'dancesstepsmap' VALUES (31649, 20794, 1);
INSERT INTO 'dancesstepsmap' VALUES (31650, 20795, 1);
INSERT INTO 'dancesstepsmap' VALUES (31651, 20795, 2);
INSERT INTO 'dancesstepsmap' VALUES (31652, 20796, 1);
INSERT INTO 'dancesstepsmap' VALUES (31653, 20797, 1);
INSERT INTO 'dancesstepsmap' VALUES (31654, 20797, 3);
INSERT INTO 'dancesstepsmap' VALUES (31655, 20798, 2);
INSERT INTO 'dancesstepsmap' VALUES (31656, 20798, 3);
INSERT INTO 'dancesstepsmap' VALUES (31657, 20798, 1);
INSERT INTO 'dancesstepsmap' VALUES (31658, 20799, 5);
INSERT INTO 'dancesstepsmap' VALUES (31659, 20799, 4);
INSERT INTO 'dancesstepsmap' VALUES (31660, 20800, 2);
INSERT INTO 'dancesstepsmap' VALUES (31661, 20800, 1);
INSERT INTO 'dancesstepsmap' VALUES (31662, 20800, 3);
INSERT INTO 'dancesstepsmap' VALUES (31663, 20801, 1);
INSERT INTO 'dancesstepsmap' VALUES (31664, 20804, 2);
INSERT INTO 'dancesstepsmap' VALUES (31665, 20804, 1);
INSERT INTO 'dancesstepsmap' VALUES (31666, 20805, 5);
INSERT INTO 'dancesstepsmap' VALUES (31667, 20805, 4);
INSERT INTO 'dancesstepsmap' VALUES (31668, 17114, 2);
INSERT INTO 'dancesstepsmap' VALUES (31669, 17114, 1);
INSERT INTO 'dancesstepsmap' VALUES (31670, 2026, 5);
INSERT INTO 'dancesstepsmap' VALUES (31671, 1915, 5);
INSERT INTO 'dancesstepsmap' VALUES (31672, 20806, 2);
INSERT INTO 'dancesstepsmap' VALUES (31673, 20806, 1);
INSERT INTO 'dancesstepsmap' VALUES (31674, 20807, 4);
INSERT INTO 'dancesstepsmap' VALUES (31675, 20807, 5);
INSERT INTO 'dancesstepsmap' VALUES (31676, 20808, 4);
INSERT INTO 'dancesstepsmap' VALUES (31677, 20809, 1);
INSERT INTO 'dancesstepsmap' VALUES (31678, 20809, 2);
INSERT INTO 'dancesstepsmap' VALUES (31679, 20810, 4);
INSERT INTO 'dancesstepsmap' VALUES (31680, 20810, 5);
INSERT INTO 'dancesstepsmap' VALUES (31681, 20811, 1);
INSERT INTO 'dancesstepsmap' VALUES (31682, 20811, 2);
INSERT INTO 'dancesstepsmap' VALUES (31683, 20812, 3);
INSERT INTO 'dancesstepsmap' VALUES (31684, 20812, 2);
INSERT INTO 'dancesstepsmap' VALUES (31685, 20812, 1);
INSERT INTO 'dancesstepsmap' VALUES (31686, 20813, 4);
INSERT INTO 'dancesstepsmap' VALUES (31687, 20813, 5);
INSERT INTO 'dancesstepsmap' VALUES (31688, 20814, 2);
INSERT INTO 'dancesstepsmap' VALUES (31689, 20814, 1);
INSERT INTO 'dancesstepsmap' VALUES (31690, 20815, 1);
INSERT INTO 'dancesstepsmap' VALUES (31691, 20815, 2);
INSERT INTO 'dancesstepsmap' VALUES (31692, 20815, 3);
INSERT INTO 'dancesstepsmap' VALUES (31693, 20816, 1);
INSERT INTO 'dancesstepsmap' VALUES (31694, 20816, 2);
INSERT INTO 'dancesstepsmap' VALUES (31695, 20817, 2);
INSERT INTO 'dancesstepsmap' VALUES (31696, 20817, 1);
INSERT INTO 'dancesstepsmap' VALUES (31697, 20818, 1);
INSERT INTO 'dancesstepsmap' VALUES (31698, 20818, 2);
INSERT INTO 'dancesstepsmap' VALUES (31699, 20768, 2);
INSERT INTO 'dancesstepsmap' VALUES (31700, 20768, 1);
INSERT INTO 'dancesstepsmap' VALUES (31701, 20769, 1);
INSERT INTO 'dancesstepsmap' VALUES (31702, 20769, 2);
INSERT INTO 'dancesstepsmap' VALUES (31706, 20820, 4);
INSERT INTO 'dancesstepsmap' VALUES (31707, 20821, 5);
INSERT INTO 'dancesstepsmap' VALUES (31708, 20821, 4);
INSERT INTO 'dancesstepsmap' VALUES (31709, 20822, 3);
INSERT INTO 'dancesstepsmap' VALUES (31710, 20822, 1);
INSERT INTO 'dancesstepsmap' VALUES (31711, 20823, 4);
INSERT INTO 'dancesstepsmap' VALUES (31712, 20824, 2);
INSERT INTO 'dancesstepsmap' VALUES (31713, 20824, 1);
INSERT INTO 'dancesstepsmap' VALUES (31714, 20825, 5);
INSERT INTO 'dancesstepsmap' VALUES (31715, 20825, 4);
INSERT INTO 'dancesstepsmap' VALUES (31716, 20826, 5);
INSERT INTO 'dancesstepsmap' VALUES (31717, 20826, 4);
INSERT INTO 'dancesstepsmap' VALUES (31718, 20827, 2);
INSERT INTO 'dancesstepsmap' VALUES (31719, 20827, 1);
INSERT INTO 'dancesstepsmap' VALUES (31720, 20828, 5);
INSERT INTO 'dancesstepsmap' VALUES (31721, 20828, 4);
INSERT INTO 'dancesstepsmap' VALUES (31722, 20829, 2);
INSERT INTO 'dancesstepsmap' VALUES (31723, 20829, 1);
INSERT INTO 'dancesstepsmap' VALUES (31724, 20829, 3);
INSERT INTO 'dancesstepsmap' VALUES (31725, 20830, 3);
INSERT INTO 'dancesstepsmap' VALUES (31726, 20830, 1);
INSERT INTO 'dancesstepsmap' VALUES (31727, 20830, 2);
INSERT INTO 'dancesstepsmap' VALUES (31728, 20831, 4);
INSERT INTO 'dancesstepsmap' VALUES (31729, 20832, 1);
INSERT INTO 'dancesstepsmap' VALUES (31730, 20833, 4);
INSERT INTO 'dancesstepsmap' VALUES (31731, 20833, 5);
INSERT INTO 'dancesstepsmap' VALUES (31732, 20834, 2);
INSERT INTO 'dancesstepsmap' VALUES (31733, 20834, 1);
INSERT INTO 'dancesstepsmap' VALUES (31734, 20835, 4);
INSERT INTO 'dancesstepsmap' VALUES (31735, 20836, 3);
INSERT INTO 'dancesstepsmap' VALUES (31736, 20836, 2);
INSERT INTO 'dancesstepsmap' VALUES (31737, 20836, 1);
INSERT INTO 'dancesstepsmap' VALUES (31738, 20837, 4);
INSERT INTO 'dancesstepsmap' VALUES (31739, 20837, 5);
INSERT INTO 'dancesstepsmap' VALUES (31740, 20838, 2);
INSERT INTO 'dancesstepsmap' VALUES (31741, 20838, 1);
INSERT INTO 'dancesstepsmap' VALUES (31742, 20838, 3);
INSERT INTO 'dancesstepsmap' VALUES (31743, 20839, 2);
INSERT INTO 'dancesstepsmap' VALUES (31744, 20839, 1);
INSERT INTO 'dancesstepsmap' VALUES (31745, 20840, 2);
INSERT INTO 'dancesstepsmap' VALUES (31746, 20840, 3);
INSERT INTO 'dancesstepsmap' VALUES (31747, 20841, 5);
INSERT INTO 'dancesstepsmap' VALUES (31748, 20841, 4);
INSERT INTO 'dancesstepsmap' VALUES (31749, 20842, 2);
INSERT INTO 'dancesstepsmap' VALUES (31750, 20842, 1);
INSERT INTO 'dancesstepsmap' VALUES (31751, 20843, 3);
INSERT INTO 'dancesstepsmap' VALUES (31752, 20843, 2);
INSERT INTO 'dancesstepsmap' VALUES (31753, 20843, 1);
INSERT INTO 'dancesstepsmap' VALUES (31754, 20844, 3);
INSERT INTO 'dancesstepsmap' VALUES (31755, 20844, 1);
INSERT INTO 'dancesstepsmap' VALUES (31756, 20844, 2);
INSERT INTO 'dancesstepsmap' VALUES (31757, 20845, 4);
INSERT INTO 'dancesstepsmap' VALUES (31758, 20845, 5);
INSERT INTO 'dancesstepsmap' VALUES (31759, 20846, 2);
INSERT INTO 'dancesstepsmap' VALUES (31760, 20846, 1);
INSERT INTO 'dancesstepsmap' VALUES (31761, 20847, 2);
INSERT INTO 'dancesstepsmap' VALUES (31762, 20847, 1);
INSERT INTO 'dancesstepsmap' VALUES (31763, 20847, 3);
INSERT INTO 'dancesstepsmap' VALUES (31764, 20848, 2);
INSERT INTO 'dancesstepsmap' VALUES (31765, 20848, 1);
INSERT INTO 'dancesstepsmap' VALUES (31766, 20848, 3);
INSERT INTO 'dancesstepsmap' VALUES (31767, 20849, 4);
INSERT INTO 'dancesstepsmap' VALUES (31768, 20850, 2);
INSERT INTO 'dancesstepsmap' VALUES (31769, 20850, 1);
INSERT INTO 'dancesstepsmap' VALUES (31770, 20851, 2);
INSERT INTO 'dancesstepsmap' VALUES (31771, 20851, 1);
INSERT INTO 'dancesstepsmap' VALUES (31772, 20851, 3);
INSERT INTO 'dancesstepsmap' VALUES (31773, 20852, 4);
INSERT INTO 'dancesstepsmap' VALUES (31774, 20852, 5);
INSERT INTO 'dancesstepsmap' VALUES (31775, 20853, 1);
INSERT INTO 'dancesstepsmap' VALUES (31776, 20853, 2);
INSERT INTO 'dancesstepsmap' VALUES (31777, 20853, 3);
INSERT INTO 'dancesstepsmap' VALUES (31778, 20854, 2);
INSERT INTO 'dancesstepsmap' VALUES (31779, 20854, 1);
INSERT INTO 'dancesstepsmap' VALUES (31780, 20854, 3);
INSERT INTO 'dancesstepsmap' VALUES (31781, 20855, 2);
INSERT INTO 'dancesstepsmap' VALUES (31782, 20855, 1);
INSERT INTO 'dancesstepsmap' VALUES (31783, 20855, 3);
INSERT INTO 'dancesstepsmap' VALUES (31784, 20856, 2);
INSERT INTO 'dancesstepsmap' VALUES (31785, 20856, 3);
INSERT INTO 'dancesstepsmap' VALUES (31786, 20856, 1);
INSERT INTO 'dancesstepsmap' VALUES (31787, 20857, 4);
INSERT INTO 'dancesstepsmap' VALUES (31788, 20857, 5);
INSERT INTO 'dancesstepsmap' VALUES (31789, 20858, 1);
INSERT INTO 'dancesstepsmap' VALUES (31790, 20859, 4);
INSERT INTO 'dancesstepsmap' VALUES (31791, 20859, 5);
INSERT INTO 'dancesstepsmap' VALUES (31792, 20861, 4);
INSERT INTO 'dancesstepsmap' VALUES (31793, 20861, 5);
INSERT INTO 'dancesstepsmap' VALUES (31794, 20862, 1);
INSERT INTO 'dancesstepsmap' VALUES (31795, 20862, 2);
INSERT INTO 'dancesstepsmap' VALUES (31796, 20862, 3);
INSERT INTO 'dancesstepsmap' VALUES (31797, 20864, 5);
INSERT INTO 'dancesstepsmap' VALUES (31798, 20864, 4);
INSERT INTO 'dancesstepsmap' VALUES (31799, 20865, 5);
INSERT INTO 'dancesstepsmap' VALUES (31800, 20865, 4);
INSERT INTO 'dancesstepsmap' VALUES (31801, 20865, 2);
INSERT INTO 'dancesstepsmap' VALUES (31802, 20865, 1);
INSERT INTO 'dancesstepsmap' VALUES (31803, 20865, 10);
INSERT INTO 'dancesstepsmap' VALUES (31804, 20866, 1);
INSERT INTO 'dancesstepsmap' VALUES (31805, 20866, 2);
INSERT INTO 'dancesstepsmap' VALUES (31806, 20867, 5);
INSERT INTO 'dancesstepsmap' VALUES (31807, 20867, 4);
INSERT INTO 'dancesstepsmap' VALUES (31808, 20868, 4);
INSERT INTO 'dancesstepsmap' VALUES (31809, 20869, 1);
INSERT INTO 'dancesstepsmap' VALUES (31810, 20869, 2);
INSERT INTO 'dancesstepsmap' VALUES (31811, 20869, 3);
INSERT INTO 'dancesstepsmap' VALUES (31812, 20863, 2);
INSERT INTO 'dancesstepsmap' VALUES (31813, 20863, 1);
INSERT INTO 'dancesstepsmap' VALUES (31814, 14116, 5);
INSERT INTO 'dancesstepsmap' VALUES (31815, 14116, 4);
INSERT INTO 'dancesstepsmap' VALUES (31816, 20871, 1);
INSERT INTO 'dancesstepsmap' VALUES (31817, 20871, 2);
INSERT INTO 'dancesstepsmap' VALUES (31818, 20871, 3);
INSERT INTO 'dancesstepsmap' VALUES (31819, 20872, 1);
INSERT INTO 'dancesstepsmap' VALUES (31820, 20872, 2);
INSERT INTO 'dancesstepsmap' VALUES (31821, 20873, 4);
INSERT INTO 'dancesstepsmap' VALUES (31822, 20873, 5);
INSERT INTO 'dancesstepsmap' VALUES (31823, 20874, 1);
INSERT INTO 'dancesstepsmap' VALUES (31824, 20874, 2);
INSERT INTO 'dancesstepsmap' VALUES (31825, 20875, 5);
INSERT INTO 'dancesstepsmap' VALUES (31826, 20875, 4);
INSERT INTO 'dancesstepsmap' VALUES (31827, 20876, 1);
INSERT INTO 'dancesstepsmap' VALUES (31828, 20877, 1);
INSERT INTO 'dancesstepsmap' VALUES (31829, 20877, 3);
INSERT INTO 'dancesstepsmap' VALUES (31830, 20877, 2);
INSERT INTO 'dancesstepsmap' VALUES (31831, 20878, 1);
INSERT INTO 'dancesstepsmap' VALUES (31832, 20878, 2);
INSERT INTO 'dancesstepsmap' VALUES (31833, 20879, 5);
INSERT INTO 'dancesstepsmap' VALUES (31834, 20879, 4);
INSERT INTO 'dancesstepsmap' VALUES (31835, 20880, 1);
INSERT INTO 'dancesstepsmap' VALUES (31836, 20880, 2);
INSERT INTO 'dancesstepsmap' VALUES (31837, 20881, 5);
INSERT INTO 'dancesstepsmap' VALUES (31838, 20881, 4);
INSERT INTO 'dancesstepsmap' VALUES (31839, 20882, 1);
INSERT INTO 'dancesstepsmap' VALUES (31840, 20882, 3);
INSERT INTO 'dancesstepsmap' VALUES (31841, 20883, 4);
INSERT INTO 'dancesstepsmap' VALUES (31842, 20883, 5);
INSERT INTO 'dancesstepsmap' VALUES (31843, 20884, 3);
INSERT INTO 'dancesstepsmap' VALUES (31844, 20884, 2);
INSERT INTO 'dancesstepsmap' VALUES (31845, 20884, 1);
INSERT INTO 'dancesstepsmap' VALUES (31846, 20885, 1);
INSERT INTO 'dancesstepsmap' VALUES (31847, 20885, 2);
INSERT INTO 'dancesstepsmap' VALUES (31848, 20885, 3);
INSERT INTO 'dancesstepsmap' VALUES (31849, 20886, 4);
INSERT INTO 'dancesstepsmap' VALUES (31850, 20886, 5);
INSERT INTO 'dancesstepsmap' VALUES (31853, 20888, 1);
INSERT INTO 'dancesstepsmap' VALUES (31854, 1906, 2);
INSERT INTO 'dancesstepsmap' VALUES (31855, 20891, 1);
INSERT INTO 'dancesstepsmap' VALUES (31856, 20891, 2);
INSERT INTO 'dancesstepsmap' VALUES (31703, 20819, 5);
INSERT INTO 'dancesstepsmap' VALUES (31704, 20819, 4);
INSERT INTO 'dancesstepsmap' VALUES (31857, 20891, 3);
INSERT INTO 'dancesstepsmap' VALUES (31858, 16737, 3);
INSERT INTO 'dancesstepsmap' VALUES (31861, 20893, 5);
INSERT INTO 'dancesstepsmap' VALUES (31862, 20893, 4);
INSERT INTO 'dancesstepsmap' VALUES (31863, 7630, 3);
INSERT INTO 'dancesstepsmap' VALUES (31864, 7630, 2);
INSERT INTO 'dancesstepsmap' VALUES (31865, 811, 5);
INSERT INTO 'dancesstepsmap' VALUES (31866, 20679, 1);
INSERT INTO 'dancesstepsmap' VALUES (31867, 20679, 2);
INSERT INTO 'dancesstepsmap' VALUES (31868, 20679, 3);
INSERT INTO 'dancesstepsmap' VALUES (31869, 5956, 2);
INSERT INTO 'dancesstepsmap' VALUES (31870, 5956, 3);
INSERT INTO 'dancesstepsmap' VALUES (31871, 20682, 4);
INSERT INTO 'dancesstepsmap' VALUES (31872, 20682, 5);
INSERT INTO 'dancesstepsmap' VALUES (31873, 20100, 3);
INSERT INTO 'dancesstepsmap' VALUES (31874, 20895, 2);
INSERT INTO 'dancesstepsmap' VALUES (31875, 20895, 1);
INSERT INTO 'dancesstepsmap' VALUES (31876, 20895, 3);
INSERT INTO 'dancesstepsmap' VALUES (31877, 6787, 2);
INSERT INTO 'dancesstepsmap' VALUES (31878, 20896, 4);
INSERT INTO 'dancesstepsmap' VALUES (31879, 20896, 5);
INSERT INTO 'dancesstepsmap' VALUES (31851, 20887, 1);
INSERT INTO 'dancesstepsmap' VALUES (31852, 20887, 2);
INSERT INTO 'dancesstepsmap' VALUES (31880, 20898, 4);
INSERT INTO 'dancesstepsmap' VALUES (31881, 20898, 5);
INSERT INTO 'dancesstepsmap' VALUES (31882, 20897, 1);
INSERT INTO 'dancesstepsmap' VALUES (31883, 20897, 2);
INSERT INTO 'dancesstepsmap' VALUES (31884, 18756, 1);
INSERT INTO 'dancesstepsmap' VALUES (31885, 20899, 5);
INSERT INTO 'dancesstepsmap' VALUES (31886, 20899, 4);
INSERT INTO 'dancesstepsmap' VALUES (31887, 20900, 1);
INSERT INTO 'dancesstepsmap' VALUES (31888, 20900, 2);
INSERT INTO 'dancesstepsmap' VALUES (31889, 20901, 4);
INSERT INTO 'dancesstepsmap' VALUES (31890, 20901, 5);
INSERT INTO 'dancesstepsmap' VALUES (31891, 20902, 4);
INSERT INTO 'dancesstepsmap' VALUES (31892, 20902, 5);
INSERT INTO 'dancesstepsmap' VALUES (31893, 20903, 1);
INSERT INTO 'dancesstepsmap' VALUES (31894, 20903, 2);
INSERT INTO 'dancesstepsmap' VALUES (31895, 20904, 1);
INSERT INTO 'dancesstepsmap' VALUES (31896, 20904, 2);
INSERT INTO 'dancesstepsmap' VALUES (31897, 20904, 3);
INSERT INTO 'dancesstepsmap' VALUES (31898, 20906, 4);
INSERT INTO 'dancesstepsmap' VALUES (31899, 20906, 5);
INSERT INTO 'dancesstepsmap' VALUES (31900, 20907, 4);
INSERT INTO 'dancesstepsmap' VALUES (31901, 20907, 5);
INSERT INTO 'dancesstepsmap' VALUES (31902, 20908, 1);
INSERT INTO 'dancesstepsmap' VALUES (31903, 20908, 2);
INSERT INTO 'dancesstepsmap' VALUES (31904, 20909, 1);
INSERT INTO 'dancesstepsmap' VALUES (31905, 20909, 2);
INSERT INTO 'dancesstepsmap' VALUES (31906, 20910, 4);
INSERT INTO 'dancesstepsmap' VALUES (31907, 20910, 5);
INSERT INTO 'dancesstepsmap' VALUES (31908, 20911, 1);
INSERT INTO 'dancesstepsmap' VALUES (31909, 20911, 2);
INSERT INTO 'dancesstepsmap' VALUES (31910, 20912, 1);
INSERT INTO 'dancesstepsmap' VALUES (31911, 20912, 2);
INSERT INTO 'dancesstepsmap' VALUES (31912, 20913, 1);
INSERT INTO 'dancesstepsmap' VALUES (31913, 20913, 2);
INSERT INTO 'dancesstepsmap' VALUES (31914, 20914, 1);
INSERT INTO 'dancesstepsmap' VALUES (31915, 20914, 2);
INSERT INTO 'dancesstepsmap' VALUES (31918, 20916, 1);
INSERT INTO 'dancesstepsmap' VALUES (31919, 20916, 2);
INSERT INTO 'dancesstepsmap' VALUES (31920, 20917, 1);
INSERT INTO 'dancesstepsmap' VALUES (31921, 20917, 2);
INSERT INTO 'dancesstepsmap' VALUES (31922, 20918, 1);
INSERT INTO 'dancesstepsmap' VALUES (31923, 20918, 2);
INSERT INTO 'dancesstepsmap' VALUES (31924, 20918, 3);
INSERT INTO 'dancesstepsmap' VALUES (31925, 20919, 1);
INSERT INTO 'dancesstepsmap' VALUES (31926, 20919, 2);
INSERT INTO 'dancesstepsmap' VALUES (31927, 20919, 3);
INSERT INTO 'dancesstepsmap' VALUES (31928, 20920, 4);
INSERT INTO 'dancesstepsmap' VALUES (31929, 20920, 5);
INSERT INTO 'dancesstepsmap' VALUES (31930, 20921, 1);
INSERT INTO 'dancesstepsmap' VALUES (31931, 20921, 2);
INSERT INTO 'dancesstepsmap' VALUES (31932, 20921, 3);
INSERT INTO 'dancesstepsmap' VALUES (31933, 20921, 10);
INSERT INTO 'dancesstepsmap' VALUES (31934, 20922, 1);
INSERT INTO 'dancesstepsmap' VALUES (31935, 20922, 2);
INSERT INTO 'dancesstepsmap' VALUES (31936, 20922, 3);
INSERT INTO 'dancesstepsmap' VALUES (31937, 16595, 4);
INSERT INTO 'dancesstepsmap' VALUES (31938, 16595, 5);
INSERT INTO 'dancesstepsmap' VALUES (31939, 16595, 1);
INSERT INTO 'dancesstepsmap' VALUES (31940, 16595, 2);
INSERT INTO 'dancesstepsmap' VALUES (31941, 16595, 3);
INSERT INTO 'dancesstepsmap' VALUES (31942, 20923, 1);
INSERT INTO 'dancesstepsmap' VALUES (31943, 20923, 3);
INSERT INTO 'dancesstepsmap' VALUES (31944, 20924, 1);
INSERT INTO 'dancesstepsmap' VALUES (31945, 20924, 2);
INSERT INTO 'dancesstepsmap' VALUES (31946, 20925, 1);
INSERT INTO 'dancesstepsmap' VALUES (31947, 20925, 2);
INSERT INTO 'dancesstepsmap' VALUES (31948, 20927, 1);
INSERT INTO 'dancesstepsmap' VALUES (31949, 20927, 2);
INSERT INTO 'dancesstepsmap' VALUES (31950, 20928, 1);
INSERT INTO 'dancesstepsmap' VALUES (31951, 20928, 2);
INSERT INTO 'dancesstepsmap' VALUES (31952, 20929, 1);
INSERT INTO 'dancesstepsmap' VALUES (31953, 20929, 2);
INSERT INTO 'dancesstepsmap' VALUES (31954, 6679, 2);
INSERT INTO 'dancesstepsmap' VALUES (15131, 12422, 4);
INSERT INTO 'dancesstepsmap' VALUES (31955, 12422, 5);
INSERT INTO 'dancesstepsmap' VALUES (31956, 10958, 2);
INSERT INTO 'dancesstepsmap' VALUES (31957, 20930, 1);
INSERT INTO 'dancesstepsmap' VALUES (31958, 6903, 3);
INSERT INTO 'dancesstepsmap' VALUES (31959, 6903, 2);
INSERT INTO 'dancesstepsmap' VALUES (31960, 20931, 1);
INSERT INTO 'dancesstepsmap' VALUES (31961, 20931, 2);
INSERT INTO 'dancesstepsmap' VALUES (31962, 20931, 3);
INSERT INTO 'dancesstepsmap' VALUES (31963, 20932, 2);
INSERT INTO 'dancesstepsmap' VALUES (31964, 20932, 1);
INSERT INTO 'dancesstepsmap' VALUES (31965, 20933, 1);
INSERT INTO 'dancesstepsmap' VALUES (31966, 20934, 1);
INSERT INTO 'dancesstepsmap' VALUES (31967, 20934, 2);
INSERT INTO 'dancesstepsmap' VALUES (31968, 20935, 4);
INSERT INTO 'dancesstepsmap' VALUES (31969, 20935, 5);
INSERT INTO 'dancesstepsmap' VALUES (31970, 20936, 4);
INSERT INTO 'dancesstepsmap' VALUES (31971, 20936, 5);
INSERT INTO 'dancesstepsmap' VALUES (31972, 20937, 1);
INSERT INTO 'dancesstepsmap' VALUES (31973, 20937, 2);
INSERT INTO 'dancesstepsmap' VALUES (31974, 20938, 4);
INSERT INTO 'dancesstepsmap' VALUES (31975, 20939, 4);
INSERT INTO 'dancesstepsmap' VALUES (31976, 20939, 1);
INSERT INTO 'dancesstepsmap' VALUES (31977, 20939, 3);
INSERT INTO 'dancesstepsmap' VALUES (31978, 20939, 5);
INSERT INTO 'dancesstepsmap' VALUES (31979, 20939, 2);
INSERT INTO 'dancesstepsmap' VALUES (31980, 20940, 1);
INSERT INTO 'dancesstepsmap' VALUES (31981, 20940, 2);
INSERT INTO 'dancesstepsmap' VALUES (31982, 20941, 1);
INSERT INTO 'dancesstepsmap' VALUES (31983, 20941, 2);
INSERT INTO 'dancesstepsmap' VALUES (31984, 20942, 2);
INSERT INTO 'dancesstepsmap' VALUES (31985, 20942, 1);
INSERT INTO 'dancesstepsmap' VALUES (31986, 20943, 2);
INSERT INTO 'dancesstepsmap' VALUES (31987, 20943, 1);
INSERT INTO 'dancesstepsmap' VALUES (31988, 20943, 3);
INSERT INTO 'dancesstepsmap' VALUES (31989, 20944, 1);
INSERT INTO 'dancesstepsmap' VALUES (31990, 20944, 3);
INSERT INTO 'dancesstepsmap' VALUES (31991, 20945, 2);
INSERT INTO 'dancesstepsmap' VALUES (31992, 20945, 1);
INSERT INTO 'dancesstepsmap' VALUES (31993, 20946, 5);
INSERT INTO 'dancesstepsmap' VALUES (31994, 20946, 4);
INSERT INTO 'dancesstepsmap' VALUES (31995, 5924, 2);
INSERT INTO 'dancesstepsmap' VALUES (31996, 20947, 1);
INSERT INTO 'dancesstepsmap' VALUES (31997, 20947, 2);
INSERT INTO 'dancesstepsmap' VALUES (31998, 20948, 1);
INSERT INTO 'dancesstepsmap' VALUES (31999, 20948, 3);
INSERT INTO 'dancesstepsmap' VALUES (32000, 20949, 4);
INSERT INTO 'dancesstepsmap' VALUES (32001, 20949, 5);
INSERT INTO 'dancesstepsmap' VALUES (32002, 20950, 1);
INSERT INTO 'dancesstepsmap' VALUES (32003, 20950, 2);
INSERT INTO 'dancesstepsmap' VALUES (32004, 20950, 3);
INSERT INTO 'dancesstepsmap' VALUES (32005, 20953, 1);
INSERT INTO 'dancesstepsmap' VALUES (32006, 20953, 2);
INSERT INTO 'dancesstepsmap' VALUES (32007, 20951, 4);
INSERT INTO 'dancesstepsmap' VALUES (32008, 20951, 5);
INSERT INTO 'dancesstepsmap' VALUES (32009, 20957, 4);
INSERT INTO 'dancesstepsmap' VALUES (32010, 20957, 5);
INSERT INTO 'dancesstepsmap' VALUES (32011, 20958, 1);
INSERT INTO 'dancesstepsmap' VALUES (32012, 7099, 5);
INSERT INTO 'dancesstepsmap' VALUES (32013, 20959, 1);
INSERT INTO 'dancesstepsmap' VALUES (32014, 20959, 2);
INSERT INTO 'dancesstepsmap' VALUES (32015, 20959, 3);
INSERT INTO 'dancesstepsmap' VALUES (32016, 20960, 1);
INSERT INTO 'dancesstepsmap' VALUES (32017, 20960, 2);
INSERT INTO 'dancesstepsmap' VALUES (32018, 20960, 3);
INSERT INTO 'dancesstepsmap' VALUES (32019, 20961, 1);
INSERT INTO 'dancesstepsmap' VALUES (32020, 20961, 2);
INSERT INTO 'dancesstepsmap' VALUES (32021, 20962, 1);
INSERT INTO 'dancesstepsmap' VALUES (32022, 20963, 1);
INSERT INTO 'dancesstepsmap' VALUES (32023, 5637, 5);
INSERT INTO 'dancesstepsmap' VALUES (32024, 3998, 5);
INSERT INTO 'dancesstepsmap' VALUES (32025, 185, 5);
INSERT INTO 'dancesstepsmap' VALUES (32026, 262, 5);
INSERT INTO 'dancesstepsmap' VALUES (32027, 292, 5);
INSERT INTO 'dancesstepsmap' VALUES (32028, 390, 5);
INSERT INTO 'dancesstepsmap' VALUES (32029, 599, 5);
INSERT INTO 'dancesstepsmap' VALUES (32030, 649, 5);
INSERT INTO 'dancesstepsmap' VALUES (32031, 698, 5);
INSERT INTO 'dancesstepsmap' VALUES (32032, 838, 5);
INSERT INTO 'dancesstepsmap' VALUES (32033, 907, 5);
INSERT INTO 'dancesstepsmap' VALUES (32034, 20964, 5);
INSERT INTO 'dancesstepsmap' VALUES (32035, 20964, 4);
INSERT INTO 'dancesstepsmap' VALUES (32036, 20965, 1);
INSERT INTO 'dancesstepsmap' VALUES (32037, 20965, 2);
INSERT INTO 'dancesstepsmap' VALUES (32038, 20965, 3);
INSERT INTO 'dancesstepsmap' VALUES (32039, 1089, 5);
INSERT INTO 'dancesstepsmap' VALUES (32040, 1259, 5);
INSERT INTO 'dancesstepsmap' VALUES (32041, 1518, 5);
INSERT INTO 'dancesstepsmap' VALUES (32042, 1556, 5);
INSERT INTO 'dancesstepsmap' VALUES (32043, 1586, 5);
INSERT INTO 'dancesstepsmap' VALUES (32044, 1618, 5);
INSERT INTO 'dancesstepsmap' VALUES (32045, 1766, 5);
INSERT INTO 'dancesstepsmap' VALUES (32046, 2328, 6);
INSERT INTO 'dancesstepsmap' VALUES (32047, 2395, 5);
INSERT INTO 'dancesstepsmap' VALUES (32048, 3052, 5);
INSERT INTO 'dancesstepsmap' VALUES (32049, 3234, 5);
INSERT INTO 'dancesstepsmap' VALUES (32050, 3313, 5);
INSERT INTO 'dancesstepsmap' VALUES (32051, 3402, 5);
INSERT INTO 'dancesstepsmap' VALUES (32052, 3453, 5);
INSERT INTO 'dancesstepsmap' VALUES (32053, 14027, 1);
INSERT INTO 'dancesstepsmap' VALUES (32054, 14027, 3);
INSERT INTO 'dancesstepsmap' VALUES (32055, 14027, 99);
INSERT INTO 'dancesstepsmap' VALUES (32056, 3775, 5);
INSERT INTO 'dancesstepsmap' VALUES (32057, 3888, 5);
INSERT INTO 'dancesstepsmap' VALUES (32058, 4131, 5);
INSERT INTO 'dancesstepsmap' VALUES (32059, 4381, 5);
INSERT INTO 'dancesstepsmap' VALUES (32060, 4486, 5);
INSERT INTO 'dancesstepsmap' VALUES (32061, 4675, 5);
INSERT INTO 'dancesstepsmap' VALUES (32062, 4769, 5);
INSERT INTO 'dancesstepsmap' VALUES (32063, 4779, 5);
INSERT INTO 'dancesstepsmap' VALUES (32064, 5165, 5);
INSERT INTO 'dancesstepsmap' VALUES (32065, 5582, 5);
INSERT INTO 'dancesstepsmap' VALUES (32066, 5831, 5);
INSERT INTO 'dancesstepsmap' VALUES (32067, 6159, 6);
INSERT INTO 'dancesstepsmap' VALUES (32068, 6596, 5);
INSERT INTO 'dancesstepsmap' VALUES (32069, 7376, 5);
INSERT INTO 'dancesstepsmap' VALUES (32070, 7435, 5);
INSERT INTO 'dancesstepsmap' VALUES (32071, 7500, 5);
INSERT INTO 'dancesstepsmap' VALUES (32072, 8217, 5);
INSERT INTO 'dancesstepsmap' VALUES (32073, 8283, 5);
INSERT INTO 'dancesstepsmap' VALUES (32074, 8925, 6);
INSERT INTO 'dancesstepsmap' VALUES (32075, 12670, 5);
INSERT INTO 'dancesstepsmap' VALUES (32076, 9177, 5);
INSERT INTO 'dancesstepsmap' VALUES (32077, 9177, 4);
INSERT INTO 'dancesstepsmap' VALUES (32078, 9177, 6);
INSERT INTO 'dancesstepsmap' VALUES (32079, 9573, 6);
INSERT INTO 'dancesstepsmap' VALUES (32080, 10272, 5);
INSERT INTO 'dancesstepsmap' VALUES (32081, 14728, 6);
INSERT INTO 'dancesstepsmap' VALUES (32082, 16357, 6);
INSERT INTO 'dancesstepsmap' VALUES (32083, 20796, 2);
INSERT INTO 'dancesstepsmap' VALUES (31916, 20915, 4);
INSERT INTO 'dancesstepsmap' VALUES (31917, 20915, 5);
INSERT INTO 'dancesstepsmap' VALUES (32084, 20966, 2);
INSERT INTO 'dancesstepsmap' VALUES (32085, 20966, 1);
INSERT INTO 'dancesstepsmap' VALUES (32086, 20967, 5);
INSERT INTO 'dancesstepsmap' VALUES (32087, 20967, 4);
INSERT INTO 'dancesstepsmap' VALUES (32088, 20968, 4);
INSERT INTO 'dancesstepsmap' VALUES (32089, 20968, 5);
INSERT INTO 'dancesstepsmap' VALUES (32090, 20968, 1);
INSERT INTO 'dancesstepsmap' VALUES (29885, 8914, 4);
INSERT INTO 'dancesstepsmap' VALUES (29886, 8914, 5);
INSERT INTO 'dancesstepsmap' VALUES (12789, 11461, 4);
INSERT INTO 'dancesstepsmap' VALUES (12790, 11461, 5);
INSERT INTO 'dancesstepsmap' VALUES (15529, 13159, 4);
INSERT INTO 'dancesstepsmap' VALUES (15530, 13159, 5);
INSERT INTO 'dancesstepsmap' VALUES (32091, 14352, 4);
INSERT INTO 'dancesstepsmap' VALUES (32092, 14352, 5);
INSERT INTO 'dancesstepsmap' VALUES (32093, 14595, 4);
INSERT INTO 'dancesstepsmap' VALUES (32094, 14595, 5);
INSERT INTO 'dancesstepsmap' VALUES (32095, 16439, 4);
INSERT INTO 'dancesstepsmap' VALUES (24832, 19174, 4);
INSERT INTO 'dancesstepsmap' VALUES (32096, 20273, 4);
INSERT INTO 'dancesstepsmap' VALUES (32097, 20273, 5);
INSERT INTO 'dancesstepsmap' VALUES (32098, 20969, 2);
INSERT INTO 'dancesstepsmap' VALUES (32099, 20969, 1);
INSERT INTO 'dancesstepsmap' VALUES (32100, 20970, 2);
INSERT INTO 'dancesstepsmap' VALUES (32101, 20970, 1);
INSERT INTO 'dancesstepsmap' VALUES (32102, 20971, 2);
INSERT INTO 'dancesstepsmap' VALUES (32103, 20971, 5);
INSERT INTO 'dancesstepsmap' VALUES (32104, 20971, 1);
INSERT INTO 'dancesstepsmap' VALUES (32105, 20971, 4);
INSERT INTO 'dancesstepsmap' VALUES (32106, 20971, 3);
INSERT INTO 'dancesstepsmap' VALUES (32107, 20972, 5);
INSERT INTO 'dancesstepsmap' VALUES (32108, 20972, 4);
INSERT INTO 'dancesstepsmap' VALUES (32109, 20973, 2);
INSERT INTO 'dancesstepsmap' VALUES (32110, 20973, 1);
INSERT INTO 'dancesstepsmap' VALUES (32111, 20973, 3);
INSERT INTO 'dancesstepsmap' VALUES (32112, 20974, 5);
INSERT INTO 'dancesstepsmap' VALUES (32113, 20974, 4);
INSERT INTO 'dancesstepsmap' VALUES (32114, 20975, 4);
INSERT INTO 'dancesstepsmap' VALUES (32115, 20976, 1);
INSERT INTO 'dancesstepsmap' VALUES (32116, 20977, 2);
INSERT INTO 'dancesstepsmap' VALUES (32117, 20977, 1);
INSERT INTO 'dancesstepsmap' VALUES (32118, 20978, 5);
INSERT INTO 'dancesstepsmap' VALUES (32119, 20978, 4);
INSERT INTO 'dancesstepsmap' VALUES (32120, 20979, 2);
INSERT INTO 'dancesstepsmap' VALUES (32121, 20979, 1);
INSERT INTO 'dancesstepsmap' VALUES (32122, 20980, 2);
INSERT INTO 'dancesstepsmap' VALUES (32123, 20980, 1);
INSERT INTO 'dancesstepsmap' VALUES (32124, 20980, 3);
INSERT INTO 'dancesstepsmap' VALUES (32125, 20981, 5);
INSERT INTO 'dancesstepsmap' VALUES (32126, 20981, 4);
INSERT INTO 'dancesstepsmap' VALUES (32127, 20982, 5);
INSERT INTO 'dancesstepsmap' VALUES (32128, 20982, 4);
INSERT INTO 'dancesstepsmap' VALUES (32129, 20983, 2);
INSERT INTO 'dancesstepsmap' VALUES (32130, 20983, 1);
INSERT INTO 'dancesstepsmap' VALUES (32131, 20984, 2);
INSERT INTO 'dancesstepsmap' VALUES (32132, 20984, 1);
INSERT INTO 'dancesstepsmap' VALUES (32133, 20984, 3);
INSERT INTO 'dancesstepsmap' VALUES (32134, 20985, 6);
INSERT INTO 'dancesstepsmap' VALUES (32135, 20985, 4);
INSERT INTO 'dancesstepsmap' VALUES (32136, 20985, 2);
INSERT INTO 'dancesstepsmap' VALUES (32137, 20985, 1);
INSERT INTO 'dancesstepsmap' VALUES (32138, 20985, 3);
INSERT INTO 'dancesstepsmap' VALUES (32139, 20986, 5);
INSERT INTO 'dancesstepsmap' VALUES (32140, 20986, 4);
INSERT INTO 'dancesstepsmap' VALUES (32141, 20987, 3);
INSERT INTO 'dancesstepsmap' VALUES (32142, 20987, 2);
INSERT INTO 'dancesstepsmap' VALUES (32143, 20987, 1);
INSERT INTO 'dancesstepsmap' VALUES (32144, 20988, 5);
INSERT INTO 'dancesstepsmap' VALUES (32145, 20988, 4);
INSERT INTO 'dancesstepsmap' VALUES (32146, 20988, 6);
INSERT INTO 'dancesstepsmap' VALUES (32147, 20989, 5);
INSERT INTO 'dancesstepsmap' VALUES (32148, 20989, 4);
INSERT INTO 'dancesstepsmap' VALUES (32149, 20989, 2);
INSERT INTO 'dancesstepsmap' VALUES (32150, 20989, 1);
INSERT INTO 'dancesstepsmap' VALUES (32151, 20991, 4);
INSERT INTO 'dancesstepsmap' VALUES (32152, 20991, 5);
INSERT INTO 'dancesstepsmap' VALUES (32153, 20992, 5);
INSERT INTO 'dancesstepsmap' VALUES (32154, 20992, 4);
INSERT INTO 'dancesstepsmap' VALUES (32155, 20992, 1);
INSERT INTO 'dancesstepsmap' VALUES (32156, 20992, 2);
INSERT INTO 'dancesstepsmap' VALUES (32157, 43, 3);
INSERT INTO 'dancesstepsmap' VALUES (32158, 104, 3);
INSERT INTO 'dancesstepsmap' VALUES (32159, 230, 3);
INSERT INTO 'dancesstepsmap' VALUES (32160, 401, 3);
INSERT INTO 'dancesstepsmap' VALUES (32161, 401, 2);
INSERT INTO 'dancesstepsmap' VALUES (32162, 647, 3);
INSERT INTO 'dancesstepsmap' VALUES (32163, 681, 3);
INSERT INTO 'dancesstepsmap' VALUES (32164, 761, 3);
INSERT INTO 'dancesstepsmap' VALUES (32165, 868, 3);
INSERT INTO 'dancesstepsmap' VALUES (32166, 1080, 3);
INSERT INTO 'dancesstepsmap' VALUES (32167, 1186, 3);
INSERT INTO 'dancesstepsmap' VALUES (32168, 1196, 3);
INSERT INTO 'dancesstepsmap' VALUES (32169, 1603, 3);
INSERT INTO 'dancesstepsmap' VALUES (32170, 1841, 3);
INSERT INTO 'dancesstepsmap' VALUES (32171, 1958, 3);
INSERT INTO 'dancesstepsmap' VALUES (32172, 19852, 3);
INSERT INTO 'dancesstepsmap' VALUES (32173, 2068, 3);
INSERT INTO 'dancesstepsmap' VALUES (32174, 2172, 3);
INSERT INTO 'dancesstepsmap' VALUES (32175, 2348, 3);
INSERT INTO 'dancesstepsmap' VALUES (32176, 20994, 5);
INSERT INTO 'dancesstepsmap' VALUES (32177, 20994, 4);
INSERT INTO 'dancesstepsmap' VALUES (32178, 2894, 3);
INSERT INTO 'dancesstepsmap' VALUES (32179, 3293, 3);
INSERT INTO 'dancesstepsmap' VALUES (32180, 4075, 3);
INSERT INTO 'dancesstepsmap' VALUES (32181, 4559, 3);
INSERT INTO 'dancesstepsmap' VALUES (32182, 4637, 3);
INSERT INTO 'dancesstepsmap' VALUES (32183, 4257, 3);
INSERT INTO 'dancesstepsmap' VALUES (32184, 4696, 3);
INSERT INTO 'dancesstepsmap' VALUES (32185, 4974, 3);
INSERT INTO 'dancesstepsmap' VALUES (32186, 5434, 3);
INSERT INTO 'dancesstepsmap' VALUES (32187, 5475, 102);
INSERT INTO 'dancesstepsmap' VALUES (32188, 5475, 3);
INSERT INTO 'dancesstepsmap' VALUES (32189, 5642, 3);
INSERT INTO 'dancesstepsmap' VALUES (32190, 5746, 3);
INSERT INTO 'dancesstepsmap' VALUES (32191, 5803, 3);
INSERT INTO 'dancesstepsmap' VALUES (32192, 5972, 3);
INSERT INTO 'dancesstepsmap' VALUES (32193, 5972, 2);
INSERT INTO 'dancesstepsmap' VALUES (32194, 6148, 3);
INSERT INTO 'dancesstepsmap' VALUES (32195, 6290, 3);
INSERT INTO 'dancesstepsmap' VALUES (32196, 6326, 3);
INSERT INTO 'dancesstepsmap' VALUES (32197, 6436, 3);
INSERT INTO 'dancesstepsmap' VALUES (32198, 6521, 3);
INSERT INTO 'dancesstepsmap' VALUES (32199, 6645, 3);
INSERT INTO 'dancesstepsmap' VALUES (32200, 6873, 3);
INSERT INTO 'dancesstepsmap' VALUES (32201, 2550, 3);
INSERT INTO 'dancesstepsmap' VALUES (32202, 4371, 2);
INSERT INTO 'dancesstepsmap' VALUES (32203, 4371, 3);
INSERT INTO 'dancesstepsmap' VALUES (32204, 7077, 3);
INSERT INTO 'dancesstepsmap' VALUES (32205, 7302, 3);
INSERT INTO 'dancesstepsmap' VALUES (32206, 7504, 3);
INSERT INTO 'dancesstepsmap' VALUES (32207, 7866, 3);
INSERT INTO 'dancesstepsmap' VALUES (32208, 7928, 3);
INSERT INTO 'dancesstepsmap' VALUES (32209, 8104, 3);
INSERT INTO 'dancesstepsmap' VALUES (32210, 8526, 3);
INSERT INTO 'dancesstepsmap' VALUES (32211, 8546, 3);
INSERT INTO 'dancesstepsmap' VALUES (32212, 8991, 3);
INSERT INTO 'dancesstepsmap' VALUES (32213, 9245, 3);
INSERT INTO 'dancesstepsmap' VALUES (32214, 9366, 3);
INSERT INTO 'dancesstepsmap' VALUES (32215, 9640, 3);
INSERT INTO 'dancesstepsmap' VALUES (32216, 9663, 3);
INSERT INTO 'dancesstepsmap' VALUES (32217, 9880, 3);
INSERT INTO 'dancesstepsmap' VALUES (32218, 10555, 3);
INSERT INTO 'dancesstepsmap' VALUES (32219, 10647, 3);
INSERT INTO 'dancesstepsmap' VALUES (32220, 10661, 3);
INSERT INTO 'dancesstepsmap' VALUES (21401, 10745, 3);
INSERT INTO 'dancesstepsmap' VALUES (32221, 11805, 1);
INSERT INTO 'dancesstepsmap' VALUES (32222, 11805, 3);
INSERT INTO 'dancesstepsmap' VALUES (32223, 12085, 1);
INSERT INTO 'dancesstepsmap' VALUES (32224, 12085, 2);
INSERT INTO 'dancesstepsmap' VALUES (32225, 12085, 3);
INSERT INTO 'dancesstepsmap' VALUES (32226, 20995, 4);
INSERT INTO 'dancesstepsmap' VALUES (32228, 20995, 1);
INSERT INTO 'dancesstepsmap' VALUES (32229, 20995, 3);
INSERT INTO 'dancesstepsmap' VALUES (32230, 13106, 3);
INSERT INTO 'dancesstepsmap' VALUES (20609, 1039, 5);
INSERT INTO 'dancesstepsmap' VALUES (20466, 4995, 2);
INSERT INTO 'dancesstepsmap' VALUES (30390, 5422, 3);
INSERT INTO 'dancesstepsmap' VALUES (31153, 9368, 2);
INSERT INTO 'dancesstepsmap' VALUES (13076, 11389, 1);
INSERT INTO 'dancesstepsmap' VALUES (18370, 13132, 3);
INSERT INTO 'dancesstepsmap' VALUES (26090, 14565, 5);
INSERT INTO 'dancesstepsmap' VALUES (18098, 15212, 3);
INSERT INTO 'dancesstepsmap' VALUES (23024, 17100, 1);
INSERT INTO 'dancesstepsmap' VALUES (24337, 17116, 5);
INSERT INTO 'dancesstepsmap' VALUES (32231, 18850, 4);
INSERT INTO 'dancesstepsmap' VALUES (32232, 18850, 5);
INSERT INTO 'dancesstepsmap' VALUES (22142, 17631, 2);
INSERT INTO 'dancesstepsmap' VALUES (23121, 18243, 5);
INSERT INTO 'dancesstepsmap' VALUES (23899, 18555, 1);
INSERT INTO 'dancesstepsmap' VALUES (24011, 18604, 4);
INSERT INTO 'dancesstepsmap' VALUES (24215, 18954, 5);
INSERT INTO 'dancesstepsmap' VALUES (25642, 19275, 3);
INSERT INTO 'dancesstepsmap' VALUES (27492, 19982, 3);
INSERT INTO 'dancesstepsmap' VALUES (32233, 13338, 1);
INSERT INTO 'dancesstepsmap' VALUES (32234, 13338, 3);
INSERT INTO 'dancesstepsmap' VALUES (32235, 13468, 3);
INSERT INTO 'dancesstepsmap' VALUES (32236, 13818, 3);
INSERT INTO 'dancesstepsmap' VALUES (32237, 13898, 3);
INSERT INTO 'dancesstepsmap' VALUES (32238, 13913, 3);
INSERT INTO 'dancesstepsmap' VALUES (32239, 14389, 3);
INSERT INTO 'dancesstepsmap' VALUES (32240, 14424, 3);
INSERT INTO 'dancesstepsmap' VALUES (32241, 14571, 1);
INSERT INTO 'dancesstepsmap' VALUES (32242, 14571, 3);
INSERT INTO 'dancesstepsmap' VALUES (32243, 14600, 3);
INSERT INTO 'dancesstepsmap' VALUES (32244, 14658, 3);
INSERT INTO 'dancesstepsmap' VALUES (32245, 14689, 3);
INSERT INTO 'dancesstepsmap' VALUES (32246, 14818, 3);
INSERT INTO 'dancesstepsmap' VALUES (32248, 14832, 2);
INSERT INTO 'dancesstepsmap' VALUES (32249, 14901, 3);
INSERT INTO 'dancesstepsmap' VALUES (32250, 15193, 3);
INSERT INTO 'dancesstepsmap' VALUES (32251, 15195, 3);
INSERT INTO 'dancesstepsmap' VALUES (32252, 15198, 3);
INSERT INTO 'dancesstepsmap' VALUES (32253, 15202, 3);
INSERT INTO 'dancesstepsmap' VALUES (32254, 15206, 3);
INSERT INTO 'dancesstepsmap' VALUES (32255, 15215, 3);
INSERT INTO 'dancesstepsmap' VALUES (32256, 15222, 3);
INSERT INTO 'dancesstepsmap' VALUES (32257, 15226, 3);
INSERT INTO 'dancesstepsmap' VALUES (32258, 15422, 3);
INSERT INTO 'dancesstepsmap' VALUES (32259, 15852, 3);
INSERT INTO 'dancesstepsmap' VALUES (32260, 15955, 3);
INSERT INTO 'dancesstepsmap' VALUES (32261, 16147, 3);
INSERT INTO 'dancesstepsmap' VALUES (32262, 16147, 2);
INSERT INTO 'dancesstepsmap' VALUES (32263, 16222, 3);
INSERT INTO 'dancesstepsmap' VALUES (32264, 16277, 3);
INSERT INTO 'dancesstepsmap' VALUES (32265, 16285, 3);
INSERT INTO 'dancesstepsmap' VALUES (32266, 16726, 3);
INSERT INTO 'dancesstepsmap' VALUES (32267, 16847, 3);
INSERT INTO 'dancesstepsmap' VALUES (32268, 16921, 3);
INSERT INTO 'dancesstepsmap' VALUES (32269, 1091, 2);
INSERT INTO 'dancesstepsmap' VALUES (32247, 14832, 3);
INSERT INTO 'dancesstepsmap' VALUES (32270, 17282, 3);
INSERT INTO 'dancesstepsmap' VALUES (32271, 17348, 3);
INSERT INTO 'dancesstepsmap' VALUES (32272, 17409, 3);
INSERT INTO 'dancesstepsmap' VALUES (32273, 17430, 3);
INSERT INTO 'dancesstepsmap' VALUES (32274, 17470, 3);
INSERT INTO 'dancesstepsmap' VALUES (32275, 17689, 3);
INSERT INTO 'dancesstepsmap' VALUES (32276, 17771, 1);
INSERT INTO 'dancesstepsmap' VALUES (32277, 17771, 3);
INSERT INTO 'dancesstepsmap' VALUES (32278, 18130, 3);
INSERT INTO 'dancesstepsmap' VALUES (32279, 18184, 3);
INSERT INTO 'dancesstepsmap' VALUES (32280, 18348, 3);
INSERT INTO 'dancesstepsmap' VALUES (32281, 18388, 1);
INSERT INTO 'dancesstepsmap' VALUES (32282, 18388, 3);
INSERT INTO 'dancesstepsmap' VALUES (32283, 18473, 3);
INSERT INTO 'dancesstepsmap' VALUES (32284, 19380, 3);
INSERT INTO 'dancesstepsmap' VALUES (32285, 19602, 3);
INSERT INTO 'dancesstepsmap' VALUES (32286, 19650, 3);
INSERT INTO 'dancesstepsmap' VALUES (32287, 19686, 3);
INSERT INTO 'dancesstepsmap' VALUES (32288, 19785, 3);
INSERT INTO 'dancesstepsmap' VALUES (32289, 19785, 2);
INSERT INTO 'dancesstepsmap' VALUES (32290, 19785, 1);
INSERT INTO 'dancesstepsmap' VALUES (32291, 19854, 3);
INSERT INTO 'dancesstepsmap' VALUES (32292, 19961, 3);
INSERT INTO 'dancesstepsmap' VALUES (32293, 20012, 3);
INSERT INTO 'dancesstepsmap' VALUES (32294, 20213, 1);
INSERT INTO 'dancesstepsmap' VALUES (32295, 20213, 2);
INSERT INTO 'dancesstepsmap' VALUES (32296, 20213, 3);
INSERT INTO 'dancesstepsmap' VALUES (30192, 20301, 1);
INSERT INTO 'dancesstepsmap' VALUES (32297, 20301, 3);
INSERT INTO 'dancesstepsmap' VALUES (32298, 20326, 3);
INSERT INTO 'dancesstepsmap' VALUES (24227, 18978, 5);
INSERT INTO 'dancesstepsmap' VALUES (31182, 20506, 5);
INSERT INTO 'dancesstepsmap' VALUES (32299, 20398, 3);
INSERT INTO 'dancesstepsmap' VALUES (32300, 20399, 3);
INSERT INTO 'dancesstepsmap' VALUES (32301, 20609, 3);
INSERT INTO 'dancesstepsmap' VALUES (32302, 20620, 3);
INSERT INTO 'dancesstepsmap' VALUES (32303, 20839, 3);
INSERT INTO 'dancesstepsmap' VALUES (32227, 20995, 5);
INSERT INTO 'dancesstepsmap' VALUES (31562, 20742, 4);
INSERT INTO 'dancesstepsmap' VALUES (31563, 20742, 5);
INSERT INTO 'dancesstepsmap' VALUES (32304, 4348, 5);
INSERT INTO 'dancesstepsmap' VALUES (32305, 4351, 5);
INSERT INTO 'dancesstepsmap' VALUES (32306, 8407, 5);
INSERT INTO 'dancesstepsmap' VALUES (32307, 9427, 2);
INSERT INTO 'dancesstepsmap' VALUES (32308, 9427, 3);
INSERT INTO 'dancesstepsmap' VALUES (32309, 11451, 5);
INSERT INTO 'dancesstepsmap' VALUES (32310, 11620, 5);
INSERT INTO 'dancesstepsmap' VALUES (32311, 12486, 2);
INSERT INTO 'dancesstepsmap' VALUES (32312, 13150, 5);
INSERT INTO 'dancesstepsmap' VALUES (32313, 13170, 5);
INSERT INTO 'dancesstepsmap' VALUES (32314, 13187, 5);
INSERT INTO 'dancesstepsmap' VALUES (32315, 18741, 5);
INSERT INTO 'dancesstepsmap' VALUES (32316, 19972, 5);
INSERT INTO 'dancesstepsmap' VALUES (32317, 18745, 2);
INSERT INTO 'dancesstepsmap' VALUES (32318, 18745, 1);
INSERT INTO 'dancesstepsmap' VALUES (32319, 454, 3);
INSERT INTO 'dancesstepsmap' VALUES (32320, 6959, 3);
INSERT INTO 'dancesstepsmap' VALUES (32321, 7206, 3);
INSERT INTO 'dancesstepsmap' VALUES (32322, 8162, 3);
INSERT INTO 'dancesstepsmap' VALUES (32323, 10938, 3);
INSERT INTO 'dancesstepsmap' VALUES (32324, 13614, 3);
INSERT INTO 'dancesstepsmap' VALUES (32325, 16283, 3);
INSERT INTO 'dancesstepsmap' VALUES (32326, 20306, 3);
INSERT INTO 'dancesstepsmap' VALUES (32327, 9733, 2);
INSERT INTO 'dancesstepsmap' VALUES (32328, 473, 5);
INSERT INTO 'dancesstepsmap' VALUES (32329, 508, 3);
INSERT INTO 'dancesstepsmap' VALUES (32330, 508, 2);
INSERT INTO 'dancesstepsmap' VALUES (32331, 2139, 5);
INSERT INTO 'dancesstepsmap' VALUES (32332, 3910, 5);
INSERT INTO 'dancesstepsmap' VALUES (32333, 892, 5);
INSERT INTO 'dancesstepsmap' VALUES (32334, 1460, 5);
INSERT INTO 'dancesstepsmap' VALUES (32335, 1831, 5);
INSERT INTO 'dancesstepsmap' VALUES (32336, 2211, 5);
INSERT INTO 'dancesstepsmap' VALUES (32337, 2595, 5);
INSERT INTO 'dancesstepsmap' VALUES (32338, 3411, 5);
INSERT INTO 'dancesstepsmap' VALUES (32339, 3463, 5);
INSERT INTO 'dancesstepsmap' VALUES (32340, 4198, 5);
INSERT INTO 'dancesstepsmap' VALUES (32341, 4263, 5);
INSERT INTO 'dancesstepsmap' VALUES (32342, 4290, 5);
INSERT INTO 'dancesstepsmap' VALUES (32343, 4803, 2);
INSERT INTO 'dancesstepsmap' VALUES (32344, 4950, 5);
INSERT INTO 'dancesstepsmap' VALUES (32345, 5244, 5);
INSERT INTO 'dancesstepsmap' VALUES (32346, 5854, 5);
INSERT INTO 'dancesstepsmap' VALUES (32347, 5976, 5);
INSERT INTO 'dancesstepsmap' VALUES (32348, 6389, 5);
INSERT INTO 'dancesstepsmap' VALUES (32349, 7042, 5);
INSERT INTO 'dancesstepsmap' VALUES (32350, 7476, 5);
INSERT INTO 'dancesstepsmap' VALUES (32351, 7530, 2);
INSERT INTO 'dancesstepsmap' VALUES (32352, 7540, 5);
INSERT INTO 'dancesstepsmap' VALUES (32353, 10471, 2);
INSERT INTO 'dancesstepsmap' VALUES (32354, 10579, 2);
INSERT INTO 'dancesstepsmap' VALUES (32355, 12781, 2);
INSERT INTO 'dancesstepsmap' VALUES (32356, 13347, 5);
INSERT INTO 'dancesstepsmap' VALUES (32357, 17998, 2);
INSERT INTO 'dancesstepsmap' VALUES (32358, 17998, 1);
INSERT INTO 'dancesstepsmap' VALUES (32359, 14970, 1);
INSERT INTO 'dancesstepsmap' VALUES (32360, 14970, 2);
INSERT INTO 'dancesstepsmap' VALUES (32361, 17539, 2);
INSERT INTO 'dancesstepsmap' VALUES (32362, 1850, 10);
INSERT INTO 'dancesstepsmap' VALUES (32363, 6535, 2);
INSERT INTO 'dancesstepsmap' VALUES (32364, 6535, 3);
INSERT INTO 'dancesstepsmap' VALUES (32365, 8227, 2);
INSERT INTO 'dancesstepsmap' VALUES (32366, 8227, 3);
INSERT INTO 'dancesstepsmap' VALUES (32367, 15196, 2);
INSERT INTO 'dancesstepsmap' VALUES (32368, 636, 2);
INSERT INTO 'dancesstepsmap' VALUES (32369, 860, 2);
INSERT INTO 'dancesstepsmap' VALUES (32370, 1657, 5);
INSERT INTO 'dancesstepsmap' VALUES (32371, 2337, 5);
INSERT INTO 'dancesstepsmap' VALUES (32372, 3022, 5);
INSERT INTO 'dancesstepsmap' VALUES (32373, 3122, 2);
INSERT INTO 'dancesstepsmap' VALUES (32374, 3608, 2);
INSERT INTO 'dancesstepsmap' VALUES (32375, 3692, 2);
INSERT INTO 'dancesstepsmap' VALUES (32376, 3729, 2);
INSERT INTO 'dancesstepsmap' VALUES (32377, 4389, 2);
INSERT INTO 'dancesstepsmap' VALUES (32378, 5317, 2);
INSERT INTO 'dancesstepsmap' VALUES (32379, 5890, 5);
INSERT INTO 'dancesstepsmap' VALUES (32380, 5986, 2);
INSERT INTO 'dancesstepsmap' VALUES (32381, 6006, 2);
INSERT INTO 'dancesstepsmap' VALUES (32382, 6401, 5);
INSERT INTO 'dancesstepsmap' VALUES (32383, 6457, 2);
INSERT INTO 'dancesstepsmap' VALUES (32384, 6619, 2);
INSERT INTO 'dancesstepsmap' VALUES (32385, 7364, 2);
INSERT INTO 'dancesstepsmap' VALUES (32386, 7428, 2);
INSERT INTO 'dancesstepsmap' VALUES (32387, 7432, 5);
INSERT INTO 'dancesstepsmap' VALUES (28908, 9369, 2);
INSERT INTO 'dancesstepsmap' VALUES (32388, 11592, 2);
INSERT INTO 'dancesstepsmap' VALUES (32389, 12434, 5);
INSERT INTO 'dancesstepsmap' VALUES (32390, 13116, 2);
INSERT INTO 'dancesstepsmap' VALUES (32391, 4389, 3);
INSERT INTO 'dancesstepsmap' VALUES (32392, 20997, 4);
INSERT INTO 'dancesstepsmap' VALUES (32393, 20997, 5);
INSERT INTO 'dancesstepsmap' VALUES (32394, 20997, 1);
INSERT INTO 'dancesstepsmap' VALUES (32395, 20998, 4);
INSERT INTO 'dancesstepsmap' VALUES (32396, 20998, 6);
INSERT INTO 'dancesstepsmap' VALUES (32397, 20999, 1);
INSERT INTO 'dancesstepsmap' VALUES (32398, 20999, 2);
INSERT INTO 'dancesstepsmap' VALUES (32399, 21000, 1);
INSERT INTO 'dancesstepsmap' VALUES (32400, 21000, 2);
INSERT INTO 'dancesstepsmap' VALUES (32401, 21000, 3);
INSERT INTO 'dancesstepsmap' VALUES (32402, 21001, 1);
INSERT INTO 'dancesstepsmap' VALUES (32403, 21001, 2);
INSERT INTO 'dancesstepsmap' VALUES (32404, 12250, 6);
INSERT INTO 'dancesstepsmap' VALUES (32405, 21002, 1);
INSERT INTO 'dancesstepsmap' VALUES (32406, 21002, 3);
INSERT INTO 'dancesstepsmap' VALUES (32407, 21003, 1);
INSERT INTO 'dancesstepsmap' VALUES (32408, 21004, 1);
INSERT INTO 'dancesstepsmap' VALUES (32409, 21004, 2);
INSERT INTO 'dancesstepsmap' VALUES (32410, 21005, 2);
INSERT INTO 'dancesstepsmap' VALUES (32411, 21005, 1);
INSERT INTO 'dancesstepsmap' VALUES (32412, 21006, 4);
INSERT INTO 'dancesstepsmap' VALUES (32413, 21006, 5);
INSERT INTO 'dancesstepsmap' VALUES (32414, 21007, 2);
INSERT INTO 'dancesstepsmap' VALUES (32415, 21007, 1);
INSERT INTO 'dancesstepsmap' VALUES (32416, 21008, 1);
INSERT INTO 'dancesstepsmap' VALUES (32417, 21008, 2);
INSERT INTO 'dancesstepsmap' VALUES (32418, 21009, 1);
INSERT INTO 'dancesstepsmap' VALUES (32419, 21009, 2);
INSERT INTO 'dancesstepsmap' VALUES (32420, 21010, 4);
INSERT INTO 'dancesstepsmap' VALUES (32421, 21010, 5);
INSERT INTO 'dancesstepsmap' VALUES (32422, 21011, 1);
INSERT INTO 'dancesstepsmap' VALUES (32423, 21011, 2);
INSERT INTO 'dancesstepsmap' VALUES (32424, 21012, 1);
INSERT INTO 'dancesstepsmap' VALUES (32425, 21012, 2);
INSERT INTO 'dancesstepsmap' VALUES (32426, 21013, 4);
INSERT INTO 'dancesstepsmap' VALUES (32427, 21013, 5);
INSERT INTO 'dancesstepsmap' VALUES (32428, 21014, 1);
INSERT INTO 'dancesstepsmap' VALUES (32429, 21014, 2);
INSERT INTO 'dancesstepsmap' VALUES (32430, 21015, 2);
INSERT INTO 'dancesstepsmap' VALUES (32431, 21015, 1);
INSERT INTO 'dancesstepsmap' VALUES (32432, 21016, 1);
INSERT INTO 'dancesstepsmap' VALUES (32433, 21016, 2);
INSERT INTO 'dancesstepsmap' VALUES (32434, 21017, 2);
INSERT INTO 'dancesstepsmap' VALUES (32435, 21017, 1);
INSERT INTO 'dancesstepsmap' VALUES (32436, 21018, 1);
INSERT INTO 'dancesstepsmap' VALUES (32437, 21019, 1);
INSERT INTO 'dancesstepsmap' VALUES (32438, 21019, 2);
INSERT INTO 'dancesstepsmap' VALUES (32439, 21020, 4);
INSERT INTO 'dancesstepsmap' VALUES (32440, 21020, 5);
INSERT INTO 'dancesstepsmap' VALUES (32441, 21021, 1);
INSERT INTO 'dancesstepsmap' VALUES (32442, 21021, 2);
INSERT INTO 'dancesstepsmap' VALUES (32443, 21022, 2);
INSERT INTO 'dancesstepsmap' VALUES (32444, 21022, 1);
INSERT INTO 'dancesstepsmap' VALUES (32445, 21023, 1);
INSERT INTO 'dancesstepsmap' VALUES (32446, 21023, 2);
INSERT INTO 'dancesstepsmap' VALUES (32447, 21023, 4);
INSERT INTO 'dancesstepsmap' VALUES (32448, 21023, 5);
INSERT INTO 'dancesstepsmap' VALUES (32449, 21024, 1);
INSERT INTO 'dancesstepsmap' VALUES (32450, 21024, 2);
INSERT INTO 'dancesstepsmap' VALUES (32451, 21025, 4);
INSERT INTO 'dancesstepsmap' VALUES (32452, 21025, 5);
INSERT INTO 'dancesstepsmap' VALUES (32453, 21026, 1);
INSERT INTO 'dancesstepsmap' VALUES (32454, 21026, 2);
INSERT INTO 'dancesstepsmap' VALUES (32455, 21027, 4);
INSERT INTO 'dancesstepsmap' VALUES (32456, 21027, 5);
INSERT INTO 'dancesstepsmap' VALUES (32457, 21028, 1);
INSERT INTO 'dancesstepsmap' VALUES (32458, 21028, 2);
INSERT INTO 'dancesstepsmap' VALUES (32459, 21028, 3);
INSERT INTO 'dancesstepsmap' VALUES (32460, 21029, 4);
INSERT INTO 'dancesstepsmap' VALUES (32461, 21029, 5);
INSERT INTO 'dancesstepsmap' VALUES (32462, 21030, 4);
INSERT INTO 'dancesstepsmap' VALUES (32463, 21030, 5);
INSERT INTO 'dancesstepsmap' VALUES (32464, 21031, 1);
INSERT INTO 'dancesstepsmap' VALUES (32465, 21032, 4);
INSERT INTO 'dancesstepsmap' VALUES (32466, 21032, 5);
INSERT INTO 'dancesstepsmap' VALUES (32467, 21033, 1);
INSERT INTO 'dancesstepsmap' VALUES (32468, 21033, 2);
INSERT INTO 'dancesstepsmap' VALUES (32469, 21034, 4);
INSERT INTO 'dancesstepsmap' VALUES (32470, 21034, 5);
INSERT INTO 'dancesstepsmap' VALUES (32471, 21035, 5);
INSERT INTO 'dancesstepsmap' VALUES (32472, 21035, 4);
INSERT INTO 'dancesstepsmap' VALUES (32473, 21036, 2);
INSERT INTO 'dancesstepsmap' VALUES (32474, 21036, 1);
INSERT INTO 'dancesstepsmap' VALUES (32475, 21037, 1);
INSERT INTO 'dancesstepsmap' VALUES (32476, 21037, 2);
INSERT INTO 'dancesstepsmap' VALUES (32477, 21038, 1);
INSERT INTO 'dancesstepsmap' VALUES (32478, 21039, 2);
INSERT INTO 'dancesstepsmap' VALUES (32479, 21039, 1);
INSERT INTO 'dancesstepsmap' VALUES (32480, 21040, 4);
INSERT INTO 'dancesstepsmap' VALUES (32481, 21040, 5);
INSERT INTO 'dancesstepsmap' VALUES (32482, 21041, 2);
INSERT INTO 'dancesstepsmap' VALUES (32483, 21041, 1);
INSERT INTO 'dancesstepsmap' VALUES (32484, 21042, 2);
INSERT INTO 'dancesstepsmap' VALUES (32485, 21042, 1);
INSERT INTO 'dancesstepsmap' VALUES (32488, 21044, 5);
INSERT INTO 'dancesstepsmap' VALUES (32489, 21044, 4);
INSERT INTO 'dancesstepsmap' VALUES (32490, 21045, 4);
INSERT INTO 'dancesstepsmap' VALUES (32491, 21045, 5);
INSERT INTO 'dancesstepsmap' VALUES (32492, 21046, 2);
INSERT INTO 'dancesstepsmap' VALUES (32493, 21046, 1);
INSERT INTO 'dancesstepsmap' VALUES (32494, 21047, 2);
INSERT INTO 'dancesstepsmap' VALUES (32495, 21047, 1);
INSERT INTO 'dancesstepsmap' VALUES (32496, 21048, 1);
INSERT INTO 'dancesstepsmap' VALUES (32497, 21049, 1);
INSERT INTO 'dancesstepsmap' VALUES (32498, 21050, 1);
INSERT INTO 'dancesstepsmap' VALUES (32499, 21050, 2);
INSERT INTO 'dancesstepsmap' VALUES (32500, 21051, 1);
INSERT INTO 'dancesstepsmap' VALUES (32501, 21052, 5);
INSERT INTO 'dancesstepsmap' VALUES (32502, 21052, 4);
INSERT INTO 'dancesstepsmap' VALUES (32503, 21053, 4);
INSERT INTO 'dancesstepsmap' VALUES (32504, 21053, 5);
INSERT INTO 'dancesstepsmap' VALUES (32505, 21054, 1);
INSERT INTO 'dancesstepsmap' VALUES (32506, 21054, 2);
INSERT INTO 'dancesstepsmap' VALUES (32507, 21055, 1);
INSERT INTO 'dancesstepsmap' VALUES (32508, 21055, 2);
INSERT INTO 'dancesstepsmap' VALUES (32509, 21056, 1);
INSERT INTO 'dancesstepsmap' VALUES (32510, 21056, 2);
INSERT INTO 'dancesstepsmap' VALUES (32511, 21057, 2);
INSERT INTO 'dancesstepsmap' VALUES (32512, 21057, 1);
INSERT INTO 'dancesstepsmap' VALUES (32513, 21058, 1);
INSERT INTO 'dancesstepsmap' VALUES (32514, 21058, 2);
INSERT INTO 'dancesstepsmap' VALUES (32515, 21059, 1);
INSERT INTO 'dancesstepsmap' VALUES (32516, 21059, 2);
INSERT INTO 'dancesstepsmap' VALUES (32517, 21060, 1);
INSERT INTO 'dancesstepsmap' VALUES (32518, 21061, 1);
INSERT INTO 'dancesstepsmap' VALUES (32519, 21061, 2);
INSERT INTO 'dancesstepsmap' VALUES (32520, 21062, 1);
INSERT INTO 'dancesstepsmap' VALUES (32521, 21062, 2);
INSERT INTO 'dancesstepsmap' VALUES (32522, 21063, 4);
INSERT INTO 'dancesstepsmap' VALUES (32523, 21064, 1);
INSERT INTO 'dancesstepsmap' VALUES (32524, 21064, 2);
INSERT INTO 'dancesstepsmap' VALUES (32486, 21043, 4);
INSERT INTO 'dancesstepsmap' VALUES (32487, 21043, 5);
INSERT INTO 'dancesstepsmap' VALUES (32525, 21065, 2);
INSERT INTO 'dancesstepsmap' VALUES (32526, 21065, 1);
INSERT INTO 'dancesstepsmap' VALUES (32527, 21066, 2);
INSERT INTO 'dancesstepsmap' VALUES (32528, 21066, 1);
INSERT INTO 'dancesstepsmap' VALUES (32529, 21067, 4);
INSERT INTO 'dancesstepsmap' VALUES (32530, 21067, 5);
INSERT INTO 'dancesstepsmap' VALUES (32531, 21068, 1);
INSERT INTO 'dancesstepsmap' VALUES (32532, 21069, 1);
INSERT INTO 'dancesstepsmap' VALUES (32533, 21070, 2);
INSERT INTO 'dancesstepsmap' VALUES (32534, 21070, 1);
INSERT INTO 'dancesstepsmap' VALUES (32535, 21071, 1);
INSERT INTO 'dancesstepsmap' VALUES (32536, 21072, 1);
INSERT INTO 'dancesstepsmap' VALUES (32537, 21073, 1);
INSERT INTO 'dancesstepsmap' VALUES (32538, 21073, 2);
INSERT INTO 'dancesstepsmap' VALUES (32539, 21074, 4);
INSERT INTO 'dancesstepsmap' VALUES (32540, 21074, 5);
INSERT INTO 'dancesstepsmap' VALUES (32541, 21075, 1);
INSERT INTO 'dancesstepsmap' VALUES (32542, 21076, 4);
INSERT INTO 'dancesstepsmap' VALUES (32543, 21076, 5);
INSERT INTO 'dancesstepsmap' VALUES (32544, 21077, 1);
INSERT INTO 'dancesstepsmap' VALUES (32545, 21078, 4);
INSERT INTO 'dancesstepsmap' VALUES (32546, 21078, 5);
INSERT INTO 'dancesstepsmap' VALUES (32547, 21079, 4);
INSERT INTO 'dancesstepsmap' VALUES (32548, 21080, 2);
INSERT INTO 'dancesstepsmap' VALUES (32549, 21080, 1);
INSERT INTO 'dancesstepsmap' VALUES (32550, 21081, 1);
INSERT INTO 'dancesstepsmap' VALUES (32551, 21082, 1);
INSERT INTO 'dancesstepsmap' VALUES (32552, 21083, 4);
INSERT INTO 'dancesstepsmap' VALUES (32553, 21083, 5);
INSERT INTO 'dancesstepsmap' VALUES (32554, 21084, 4);
INSERT INTO 'dancesstepsmap' VALUES (32555, 21084, 5);
INSERT INTO 'dancesstepsmap' VALUES (32556, 21085, 4);
INSERT INTO 'dancesstepsmap' VALUES (32557, 21085, 5);
INSERT INTO 'dancesstepsmap' VALUES (32558, 21086, 5);
INSERT INTO 'dancesstepsmap' VALUES (32559, 21086, 4);
INSERT INTO 'dancesstepsmap' VALUES (32560, 21087, 2);
INSERT INTO 'dancesstepsmap' VALUES (32561, 21087, 1);
INSERT INTO 'dancesstepsmap' VALUES (32562, 21088, 1);
INSERT INTO 'dancesstepsmap' VALUES (32563, 21088, 2);
INSERT INTO 'dancesstepsmap' VALUES (32564, 21089, 1);
INSERT INTO 'dancesstepsmap' VALUES (32565, 21090, 4);
INSERT INTO 'dancesstepsmap' VALUES (32566, 21090, 5);
INSERT INTO 'dancesstepsmap' VALUES (32567, 21091, 1);
INSERT INTO 'dancesstepsmap' VALUES (32568, 21091, 2);
INSERT INTO 'dancesstepsmap' VALUES (32569, 21092, 4);
INSERT INTO 'dancesstepsmap' VALUES (32570, 21092, 5);
INSERT INTO 'dancesstepsmap' VALUES (32571, 21093, 1);
INSERT INTO 'dancesstepsmap' VALUES (32572, 21093, 2);
INSERT INTO 'dancesstepsmap' VALUES (32573, 21094, 1);
INSERT INTO 'dancesstepsmap' VALUES (32574, 21094, 2);
INSERT INTO 'dancesstepsmap' VALUES (32575, 21095, 5);
INSERT INTO 'dancesstepsmap' VALUES (32576, 21095, 4);
INSERT INTO 'dancesstepsmap' VALUES (32577, 20693, 1);
INSERT INTO 'dancesstepsmap' VALUES (32578, 20693, 3);
INSERT INTO 'dancesstepsmap' VALUES (32579, 20693, 2);
INSERT INTO 'dancesstepsmap' VALUES (32580, 20692, 1);
INSERT INTO 'dancesstepsmap' VALUES (32581, 20692, 3);
INSERT INTO 'dancesstepsmap' VALUES (32582, 20692, 2);
INSERT INTO 'dancesstepsmap' VALUES (32583, 21096, 1);
INSERT INTO 'dancesstepsmap' VALUES (32584, 21096, 2);
INSERT INTO 'dancesstepsmap' VALUES (32585, 21097, 1);
INSERT INTO 'dancesstepsmap' VALUES (32586, 21097, 2);
INSERT INTO 'dancesstepsmap' VALUES (32587, 21097, 3);
INSERT INTO 'dancesstepsmap' VALUES (32588, 19075, 1);
INSERT INTO 'dancesstepsmap' VALUES (32589, 19075, 2);
INSERT INTO 'dancesstepsmap' VALUES (32590, 19075, 3);
INSERT INTO 'dancesstepsmap' VALUES (32591, 21098, 4);
INSERT INTO 'dancesstepsmap' VALUES (32592, 21098, 5);
INSERT INTO 'dancesstepsmap' VALUES (32593, 14794, 4);
INSERT INTO 'dancesstepsmap' VALUES (32594, 14794, 5);
INSERT INTO 'dancesstepsmap' VALUES (32595, 14794, 1);
INSERT INTO 'dancesstepsmap' VALUES (32596, 14794, 2);
INSERT INTO 'dancesstepsmap' VALUES (32599, 20643, 1);
INSERT INTO 'dancesstepsmap' VALUES (32601, 20646, 1);
INSERT INTO 'dancesstepsmap' VALUES (32602, 20646, 2);
INSERT INTO 'dancesstepsmap' VALUES (32603, 20646, 3);
INSERT INTO 'dancesstepsmap' VALUES (32604, 20647, 1);
INSERT INTO 'dancesstepsmap' VALUES (32605, 20647, 2);
INSERT INTO 'dancesstepsmap' VALUES (32606, 20648, 2);
INSERT INTO 'dancesstepsmap' VALUES (32607, 20648, 1);
INSERT INTO 'dancesstepsmap' VALUES (32608, 20650, 1);
INSERT INTO 'dancesstepsmap' VALUES (32609, 20650, 3);
INSERT INTO 'dancesstepsmap' VALUES (32610, 20651, 1);
INSERT INTO 'dancesstepsmap' VALUES (32611, 20651, 2);
INSERT INTO 'dancesstepsmap' VALUES (32612, 20652, 1);
INSERT INTO 'dancesstepsmap' VALUES (32613, 20652, 2);
INSERT INTO 'dancesstepsmap' VALUES (32614, 20652, 3);
INSERT INTO 'dancesstepsmap' VALUES (32615, 20653, 2);
INSERT INTO 'dancesstepsmap' VALUES (32616, 20653, 1);
INSERT INTO 'dancesstepsmap' VALUES (32617, 20653, 3);
INSERT INTO 'dancesstepsmap' VALUES (32618, 20654, 1);
INSERT INTO 'dancesstepsmap' VALUES (32619, 20654, 3);
INSERT INTO 'dancesstepsmap' VALUES (32600, 20644, 4);
INSERT INTO 'dancesstepsmap' VALUES (32620, 20655, 4);
INSERT INTO 'dancesstepsmap' VALUES (32621, 20655, 5);
INSERT INTO 'dancesstepsmap' VALUES (32622, 20656, 1);
INSERT INTO 'dancesstepsmap' VALUES (32623, 20656, 3);
INSERT INTO 'dancesstepsmap' VALUES (32624, 20657, 4);
INSERT INTO 'dancesstepsmap' VALUES (32625, 20657, 5);
INSERT INTO 'dancesstepsmap' VALUES (32626, 20658, 1);
INSERT INTO 'dancesstepsmap' VALUES (32627, 20658, 2);
INSERT INTO 'dancesstepsmap' VALUES (32628, 20658, 3);
INSERT INTO 'dancesstepsmap' VALUES (32629, 19823, 2);
INSERT INTO 'dancesstepsmap' VALUES (32630, 19823, 1);
INSERT INTO 'dancesstepsmap' VALUES (32631, 19824, 1);
INSERT INTO 'dancesstepsmap' VALUES (32632, 19824, 2);
INSERT INTO 'dancesstepsmap' VALUES (32633, 19825, 5);
INSERT INTO 'dancesstepsmap' VALUES (32634, 19825, 4);
INSERT INTO 'dancesstepsmap' VALUES (32635, 19827, 5);
INSERT INTO 'dancesstepsmap' VALUES (32636, 19827, 4);
INSERT INTO 'dancesstepsmap' VALUES (32637, 19829, 2);
INSERT INTO 'dancesstepsmap' VALUES (32638, 19829, 1);
INSERT INTO 'dancesstepsmap' VALUES (32639, 21100, 1);
INSERT INTO 'dancesstepsmap' VALUES (32640, 21100, 2);
INSERT INTO 'dancesstepsmap' VALUES (32641, 19618, 1);
INSERT INTO 'dancesstepsmap' VALUES (32642, 19618, 2);
INSERT INTO 'dancesstepsmap' VALUES (32643, 12256, 2);
INSERT INTO 'dancesstepsmap' VALUES (32644, 12318, 2);
INSERT INTO 'dancesstepsmap' VALUES (32645, 1932, 5);
INSERT INTO 'dancesstepsmap' VALUES (32646, 1932, 6);
INSERT INTO 'dancesstepsmap' VALUES (32647, 4781, 4);
INSERT INTO 'dancesstepsmap' VALUES (32648, 4781, 5);
INSERT INTO 'dancesstepsmap' VALUES (32649, 4781, 1);
INSERT INTO 'dancesstepsmap' VALUES (32650, 4781, 3);
INSERT INTO 'dancesstepsmap' VALUES (32651, 5046, 2);
INSERT INTO 'dancesstepsmap' VALUES (32652, 6404, 10);
INSERT INTO 'dancesstepsmap' VALUES (32653, 6949, 2);
INSERT INTO 'dancesstepsmap' VALUES (32654, 8121, 2);
INSERT INTO 'dancesstepsmap' VALUES (32655, 8258, 2);
INSERT INTO 'dancesstepsmap' VALUES (32656, 8418, 2);
INSERT INTO 'dancesstepsmap' VALUES (32657, 10749, 1);
INSERT INTO 'dancesstepsmap' VALUES (32658, 10749, 3);
INSERT INTO 'dancesstepsmap' VALUES (32659, 10749, 2);
INSERT INTO 'dancesstepsmap' VALUES (32660, 12192, 2);
INSERT INTO 'dancesstepsmap' VALUES (32661, 13777, 2);
INSERT INTO 'dancesstepsmap' VALUES (32662, 13777, 1);
INSERT INTO 'dancesstepsmap' VALUES (32663, 14490, 4);
INSERT INTO 'dancesstepsmap' VALUES (32664, 14490, 5);
INSERT INTO 'dancesstepsmap' VALUES (32665, 14792, 2);
INSERT INTO 'dancesstepsmap' VALUES (32666, 14792, 1);
INSERT INTO 'dancesstepsmap' VALUES (32667, 15531, 4);
INSERT INTO 'dancesstepsmap' VALUES (32668, 15531, 5);
INSERT INTO 'dancesstepsmap' VALUES (32669, 15531, 3);
INSERT INTO 'dancesstepsmap' VALUES (32670, 15531, 1);
INSERT INTO 'dancesstepsmap' VALUES (32671, 15531, 2);
INSERT INTO 'dancesstepsmap' VALUES (32672, 21101, 1);
INSERT INTO 'dancesstepsmap' VALUES (32673, 21101, 2);
INSERT INTO 'dancesstepsmap' VALUES (32674, 21102, 5);
INSERT INTO 'dancesstepsmap' VALUES (32675, 21102, 4);
INSERT INTO 'dancesstepsmap' VALUES (32676, 20990, 1);
INSERT INTO 'dancesstepsmap' VALUES (32677, 21103, 1);
INSERT INTO 'dancesstepsmap' VALUES (32678, 21103, 2);
INSERT INTO 'dancesstepsmap' VALUES (32679, 13424, 103);
INSERT INTO 'dancesstepsmap' VALUES (32680, 21106, 1);
INSERT INTO 'dancesstepsmap' VALUES (32681, 12863, 3);
INSERT INTO 'dancesstepsmap' VALUES (32682, 12639, 1);
INSERT INTO 'dancesstepsmap' VALUES (32683, 12639, 2);
INSERT INTO 'dancesstepsmap' VALUES (32684, 12410, 2);
INSERT INTO 'dancesstepsmap' VALUES (32685, 12377, 2);
INSERT INTO 'dancesstepsmap' VALUES (32686, 12372, 2);
INSERT INTO 'dancesstepsmap' VALUES (32687, 12314, 5);
INSERT INTO 'dancesstepsmap' VALUES (32688, 12314, 4);
INSERT INTO 'dancesstepsmap' VALUES (32689, 12144, 1);
INSERT INTO 'dancesstepsmap' VALUES (32690, 21109, 1);
INSERT INTO 'dancesstepsmap' VALUES (32691, 21109, 3);
INSERT INTO 'dancesstepsmap' VALUES (32692, 21110, 4);
INSERT INTO 'dancesstepsmap' VALUES (32693, 21110, 5);
INSERT INTO 'dancesstepsmap' VALUES (32694, 7838, 2);
INSERT INTO 'dancesstepsmap' VALUES (32695, 4306, 3);
INSERT INTO 'dancesstepsmap' VALUES (32696, 21108, 1);
INSERT INTO 'dancesstepsmap' VALUES (32697, 21108, 2);
INSERT INTO 'dancesstepsmap' VALUES (32698, 11980, 1);
INSERT INTO 'dancesstepsmap' VALUES (32699, 11980, 2);
INSERT INTO 'dancesstepsmap' VALUES (32700, 11816, 2);
INSERT INTO 'dancesstepsmap' VALUES (32701, 11790, 4);
INSERT INTO 'dancesstepsmap' VALUES (32702, 11785, 1);
INSERT INTO 'dancesstepsmap' VALUES (32703, 11574, 2);
INSERT INTO 'dancesstepsmap' VALUES (32704, 11606, 1);
INSERT INTO 'dancesstepsmap' VALUES (32705, 11530, 2);
INSERT INTO 'dancesstepsmap' VALUES (32706, 11455, 2);
INSERT INTO 'dancesstepsmap' VALUES (32707, 11420, 5);
INSERT INTO 'dancesstepsmap' VALUES (32708, 20996, 4);
INSERT INTO 'dancesstepsmap' VALUES (32709, 20996, 5);
INSERT INTO 'dancesstepsmap' VALUES (32710, 20955, 1);
INSERT INTO 'dancesstepsmap' VALUES (32711, 20955, 2);
INSERT INTO 'dancesstepsmap' VALUES (32712, 20954, 4);
INSERT INTO 'dancesstepsmap' VALUES (32713, 20954, 5);
INSERT INTO 'dancesstepsmap' VALUES (32714, 20954, 1);
INSERT INTO 'dancesstepsmap' VALUES (32715, 20954, 2);
INSERT INTO 'dancesstepsmap' VALUES (32716, 20860, 4);
INSERT INTO 'dancesstepsmap' VALUES (32717, 20860, 5);
INSERT INTO 'dancesstepsmap' VALUES (32718, 20860, 8);
INSERT INTO 'dancesstepsmap' VALUES (32719, 20860, 2);
INSERT INTO 'dancesstepsmap' VALUES (32720, 20703, 4);
INSERT INTO 'dancesstepsmap' VALUES (32721, 20703, 5);
INSERT INTO 'dancesstepsmap' VALUES (32722, 20662, 1);
INSERT INTO 'dancesstepsmap' VALUES (32723, 20405, 1);
INSERT INTO 'dancesstepsmap' VALUES (32724, 20405, 2);
INSERT INTO 'dancesstepsmap' VALUES (32725, 17257, 1);
INSERT INTO 'dancesstepsmap' VALUES (32726, 17257, 2);
INSERT INTO 'dancesstepsmap' VALUES (32727, 17257, 3);
INSERT INTO 'dancesstepsmap' VALUES (32728, 21111, 4);
INSERT INTO 'dancesstepsmap' VALUES (32729, 21112, 1);
INSERT INTO 'dancesstepsmap' VALUES (32730, 21112, 3);
INSERT INTO 'dancesstepsmap' VALUES (32731, 10940, 5);
INSERT INTO 'dancesstepsmap' VALUES (32732, 10897, 1);
INSERT INTO 'dancesstepsmap' VALUES (32733, 10897, 3);
INSERT INTO 'dancesstepsmap' VALUES (32734, 10897, 2);
INSERT INTO 'dancesstepsmap' VALUES (32735, 10861, 1);
INSERT INTO 'dancesstepsmap' VALUES (32736, 10271, 2);
INSERT INTO 'dancesstepsmap' VALUES (32737, 10092, 3);
INSERT INTO 'dancesstepsmap' VALUES (32738, 10009, 1);
INSERT INTO 'dancesstepsmap' VALUES (32739, 9926, 3);
INSERT INTO 'dancesstepsmap' VALUES (32740, 9901, 5);
INSERT INTO 'dancesstepsmap' VALUES (32741, 9892, 2);
INSERT INTO 'dancesstepsmap' VALUES (32742, 9892, 3);
INSERT INTO 'dancesstepsmap' VALUES (32743, 9810, 1);
INSERT INTO 'dancesstepsmap' VALUES (32744, 9770, 2);
INSERT INTO 'dancesstepsmap' VALUES (32745, 9770, 1);
INSERT INTO 'dancesstepsmap' VALUES (32746, 9726, 5);
INSERT INTO 'dancesstepsmap' VALUES (32747, 9708, 2);
INSERT INTO 'dancesstepsmap' VALUES (32748, 9708, 1);
INSERT INTO 'dancesstepsmap' VALUES (32749, 21115, 2);
INSERT INTO 'dancesstepsmap' VALUES (32750, 21115, 1);
INSERT INTO 'dancesstepsmap' VALUES (32751, 21124, 2);
INSERT INTO 'dancesstepsmap' VALUES (32752, 21124, 1);
INSERT INTO 'dancesstepsmap' VALUES (32753, 21116, 4);
INSERT INTO 'dancesstepsmap' VALUES (32754, 21116, 5);
INSERT INTO 'dancesstepsmap' VALUES (32755, 21131, 5);
INSERT INTO 'dancesstepsmap' VALUES (32756, 21131, 4);
INSERT INTO 'dancesstepsmap' VALUES (32757, 10502, 2);
INSERT INTO 'dancesstepsmap' VALUES (32758, 21113, 1);
INSERT INTO 'dancesstepsmap' VALUES (32759, 21113, 2);
INSERT INTO 'dancesstepsmap' VALUES (32760, 21114, 1);
INSERT INTO 'dancesstepsmap' VALUES (32761, 21114, 2);
INSERT INTO 'dancesstepsmap' VALUES (32762, 9686, 2);
INSERT INTO 'dancesstepsmap' VALUES (32763, 9686, 3);
INSERT INTO 'dancesstepsmap' VALUES (32764, 9682, 2);
INSERT INTO 'dancesstepsmap' VALUES (32765, 9537, 2);
INSERT INTO 'dancesstepsmap' VALUES (32766, 9242, 1);
INSERT INTO 'dancesstepsmap' VALUES (32767, 9101, 1);
INSERT INTO 'dancesstepsmap' VALUES (32768, 21141, 4);
INSERT INTO 'dancesstepsmap' VALUES (32769, 21141, 5);
INSERT INTO 'dancesstepsmap' VALUES (32770, 9099, 1);
INSERT INTO 'dancesstepsmap' VALUES (32771, 21142, 1);
INSERT INTO 'dancesstepsmap' VALUES (32772, 21142, 2);
INSERT INTO 'dancesstepsmap' VALUES (32773, 21140, 1);
INSERT INTO 'dancesstepsmap' VALUES (32774, 21140, 2);
INSERT INTO 'dancesstepsmap' VALUES (32775, 9042, 5);
INSERT INTO 'dancesstepsmap' VALUES (32776, 8933, 5);
INSERT INTO 'dancesstepsmap' VALUES (32777, 8521, 2);
INSERT INTO 'dancesstepsmap' VALUES (32778, 21139, 4);
INSERT INTO 'dancesstepsmap' VALUES (32779, 21137, 1);
INSERT INTO 'dancesstepsmap' VALUES (32780, 21137, 2);
INSERT INTO 'dancesstepsmap' VALUES (32781, 21144, 1);
INSERT INTO 'dancesstepsmap' VALUES (32782, 21144, 2);
INSERT INTO 'dancesstepsmap' VALUES (32783, 21144, 3);
INSERT INTO 'dancesstepsmap' VALUES (32784, 21144, 4);
INSERT INTO 'dancesstepsmap' VALUES (32785, 21144, 5);
INSERT INTO 'dancesstepsmap' VALUES (32786, 21145, 1);
INSERT INTO 'dancesstepsmap' VALUES (32787, 21136, 1);
INSERT INTO 'dancesstepsmap' VALUES (32788, 21136, 3);
INSERT INTO 'dancesstepsmap' VALUES (32789, 21138, 1);
INSERT INTO 'dancesstepsmap' VALUES (32790, 21138, 2);
INSERT INTO 'dancesstepsmap' VALUES (32791, 21148, 4);
INSERT INTO 'dancesstepsmap' VALUES (32792, 21148, 5);
INSERT INTO 'dancesstepsmap' VALUES (32793, 21147, 1);
INSERT INTO 'dancesstepsmap' VALUES (32794, 21147, 2);
INSERT INTO 'dancesstepsmap' VALUES (32795, 21123, 4);
INSERT INTO 'dancesstepsmap' VALUES (32796, 21123, 5);
INSERT INTO 'dancesstepsmap' VALUES (32797, 2830, 2);
INSERT INTO 'dancesstepsmap' VALUES (32798, 21120, 2);
INSERT INTO 'dancesstepsmap' VALUES (32799, 21120, 1);
INSERT INTO 'dancesstepsmap' VALUES (32800, 21118, 5);
INSERT INTO 'dancesstepsmap' VALUES (32801, 21118, 4);
INSERT INTO 'dancesstepsmap' VALUES (32802, 21122, 1);
INSERT INTO 'dancesstepsmap' VALUES (32803, 21122, 3);
INSERT INTO 'dancesstepsmap' VALUES (32804, 21117, 2);
INSERT INTO 'dancesstepsmap' VALUES (32805, 21117, 1);
INSERT INTO 'dancesstepsmap' VALUES (32806, 21119, 5);
INSERT INTO 'dancesstepsmap' VALUES (32807, 21119, 4);
INSERT INTO 'dancesstepsmap' VALUES (32808, 21121, 2);
INSERT INTO 'dancesstepsmap' VALUES (32809, 21121, 1);
INSERT INTO 'dancesstepsmap' VALUES (32810, 21121, 3);
INSERT INTO 'dancesstepsmap' VALUES (32811, 10849, 2);
INSERT INTO 'dancesstepsmap' VALUES (11586, 8176, 2);
INSERT INTO 'dancesstepsmap' VALUES (32812, 8133, 2);
INSERT INTO 'dancesstepsmap' VALUES (32813, 8053, 2);
INSERT INTO 'dancesstepsmap' VALUES (32814, 17697, 1);
INSERT INTO 'dancesstepsmap' VALUES (32815, 21149, 4);
INSERT INTO 'dancesstepsmap' VALUES (32816, 21149, 5);
INSERT INTO 'dancesstepsmap' VALUES (32817, 21150, 4);
INSERT INTO 'dancesstepsmap' VALUES (32818, 21150, 5);
INSERT INTO 'dancesstepsmap' VALUES (32819, 21151, 1);
INSERT INTO 'dancesstepsmap' VALUES (32820, 21152, 1);
INSERT INTO 'dancesstepsmap' VALUES (32821, 21152, 3);
INSERT INTO 'dancesstepsmap' VALUES (32822, 21133, 1);
INSERT INTO 'dancesstepsmap' VALUES (32823, 21133, 2);
INSERT INTO 'dancesstepsmap' VALUES (32824, 7605, 5);
INSERT INTO 'dancesstepsmap' VALUES (32825, 7423, 2);
INSERT INTO 'dancesstepsmap' VALUES (32826, 7373, 2);
INSERT INTO 'dancesstepsmap' VALUES (32827, 7353, 5);
INSERT INTO 'dancesstepsmap' VALUES (32828, 7190, 5);
INSERT INTO 'dancesstepsmap' VALUES (32829, 7174, 2);
INSERT INTO 'dancesstepsmap' VALUES (32830, 7092, 2);
INSERT INTO 'dancesstepsmap' VALUES (32831, 21126, 2);
INSERT INTO 'dancesstepsmap' VALUES (32832, 21126, 1);
INSERT INTO 'dancesstepsmap' VALUES (32833, 21153, 1);
INSERT INTO 'dancesstepsmap' VALUES (32834, 21153, 2);
INSERT INTO 'dancesstepsmap' VALUES (32835, 21153, 3);
INSERT INTO 'dancesstepsmap' VALUES (32836, 21154, 4);
INSERT INTO 'dancesstepsmap' VALUES (32837, 21154, 5);
INSERT INTO 'dancesstepsmap' VALUES (32838, 1606, 3);
INSERT INTO 'dancesstepsmap' VALUES (32839, 21128, 4);
INSERT INTO 'dancesstepsmap' VALUES (32840, 21128, 5);
INSERT INTO 'dancesstepsmap' VALUES (32841, 21128, 1);
INSERT INTO 'dancesstepsmap' VALUES (32842, 21128, 2);
INSERT INTO 'dancesstepsmap' VALUES (32843, 21125, 1);
INSERT INTO 'dancesstepsmap' VALUES (32844, 21125, 2);
INSERT INTO 'dancesstepsmap' VALUES (32845, 21134, 1);
INSERT INTO 'dancesstepsmap' VALUES (32846, 21134, 3);
INSERT INTO 'dancesstepsmap' VALUES (32847, 21130, 2);
INSERT INTO 'dancesstepsmap' VALUES (32848, 21130, 1);
INSERT INTO 'dancesstepsmap' VALUES (32849, 21129, 4);
INSERT INTO 'dancesstepsmap' VALUES (32850, 21129, 5);
INSERT INTO 'dancesstepsmap' VALUES (32851, 21155, 1);
INSERT INTO 'dancesstepsmap' VALUES (32852, 21155, 3);
INSERT INTO 'dancesstepsmap' VALUES (32853, 21156, 4);
INSERT INTO 'dancesstepsmap' VALUES (32854, 21156, 5);
INSERT INTO 'dancesstepsmap' VALUES (32855, 21127, 1);
INSERT INTO 'dancesstepsmap' VALUES (32856, 21127, 2);
INSERT INTO 'dancesstepsmap' VALUES (32857, 21157, 1);
INSERT INTO 'dancesstepsmap' VALUES (32858, 21158, 4);
INSERT INTO 'dancesstepsmap' VALUES (32859, 21158, 5);
INSERT INTO 'dancesstepsmap' VALUES (32860, 6962, 2);
INSERT INTO 'dancesstepsmap' VALUES (32861, 6946, 2);
INSERT INTO 'dancesstepsmap' VALUES (32863, 6904, 5);
INSERT INTO 'dancesstepsmap' VALUES (32864, 6721, 5);
INSERT INTO 'dancesstepsmap' VALUES (32865, 6704, 2);
INSERT INTO 'dancesstepsmap' VALUES (32866, 6686, 2);
INSERT INTO 'dancesstepsmap' VALUES (32867, 6685, 2);
INSERT INTO 'dancesstepsmap' VALUES (32868, 730, 2);
INSERT INTO 'dancesstepsmap' VALUES (32869, 275, 5);
INSERT INTO 'dancesstepsmap' VALUES (32870, 1000, 4);
INSERT INTO 'dancesstepsmap' VALUES (32871, 1000, 1);
INSERT INTO 'dancesstepsmap' VALUES (32872, 1000, 2);
INSERT INTO 'dancesstepsmap' VALUES (32873, 1000, 3);
INSERT INTO 'dancesstepsmap' VALUES (32874, 6310, 6);
INSERT INTO 'dancesstepsmap' VALUES (32875, 6219, 2);
INSERT INTO 'dancesstepsmap' VALUES (32876, 6204, 2);
INSERT INTO 'dancesstepsmap' VALUES (32877, 5917, 2);
INSERT INTO 'dancesstepsmap' VALUES (32878, 5808, 2);
INSERT INTO 'dancesstepsmap' VALUES (32879, 5721, 2);
INSERT INTO 'dancesstepsmap' VALUES (32880, 5680, 2);
INSERT INTO 'dancesstepsmap' VALUES (32881, 5654, 5);
INSERT INTO 'dancesstepsmap' VALUES (32882, 5584, 2);
INSERT INTO 'dancesstepsmap' VALUES (32883, 5559, 2);
INSERT INTO 'dancesstepsmap' VALUES (32884, 5511, 2);
INSERT INTO 'dancesstepsmap' VALUES (32885, 5445, 5);
INSERT INTO 'dancesstepsmap' VALUES (32886, 21159, 4);
INSERT INTO 'dancesstepsmap' VALUES (32887, 21159, 5);
INSERT INTO 'dancesstepsmap' VALUES (32890, 7158, 2);
INSERT INTO 'dancesstepsmap' VALUES (32891, 9670, 5);
INSERT INTO 'dancesstepsmap' VALUES (32892, 21161, 1);
INSERT INTO 'dancesstepsmap' VALUES (32893, 21161, 2);
INSERT INTO 'dancesstepsmap' VALUES (32894, 21162, 1);
INSERT INTO 'dancesstepsmap' VALUES (32895, 21163, 1);
INSERT INTO 'dancesstepsmap' VALUES (32896, 21163, 2);
INSERT INTO 'dancesstepsmap' VALUES (32897, 21164, 2);
INSERT INTO 'dancesstepsmap' VALUES (32898, 21164, 1);
INSERT INTO 'dancesstepsmap' VALUES (32899, 21164, 3);
INSERT INTO 'dancesstepsmap' VALUES (32900, 21165, 4);
INSERT INTO 'dancesstepsmap' VALUES (32901, 21165, 5);
INSERT INTO 'dancesstepsmap' VALUES (32902, 21166, 4);
INSERT INTO 'dancesstepsmap' VALUES (32903, 21166, 5);
INSERT INTO 'dancesstepsmap' VALUES (32904, 5187, 2);
INSERT INTO 'dancesstepsmap' VALUES (32905, 5083, 2);
INSERT INTO 'dancesstepsmap' VALUES (32906, 5064, 2);
INSERT INTO 'dancesstepsmap' VALUES (32907, 5019, 5);
INSERT INTO 'dancesstepsmap' VALUES (32908, 4916, 5);
INSERT INTO 'dancesstepsmap' VALUES (32909, 4815, 2);
INSERT INTO 'dancesstepsmap' VALUES (32910, 21167, 2);
INSERT INTO 'dancesstepsmap' VALUES (32911, 21167, 1);
INSERT INTO 'dancesstepsmap' VALUES (32912, 21168, 1);
INSERT INTO 'dancesstepsmap' VALUES (32913, 21169, 2);
INSERT INTO 'dancesstepsmap' VALUES (32914, 21169, 1);
INSERT INTO 'dancesstepsmap' VALUES (32915, 21169, 5);
INSERT INTO 'dancesstepsmap' VALUES (32916, 21169, 4);
INSERT INTO 'dancesstepsmap' VALUES (32917, 21170, 5);
INSERT INTO 'dancesstepsmap' VALUES (32918, 21170, 4);
INSERT INTO 'dancesstepsmap' VALUES (32919, 21167, 3);
INSERT INTO 'dancesstepsmap' VALUES (32920, 21171, 1);
INSERT INTO 'dancesstepsmap' VALUES (32921, 4674, 2);
INSERT INTO 'dancesstepsmap' VALUES (32922, 4673, 2);
INSERT INTO 'dancesstepsmap' VALUES (32923, 4628, 2);
INSERT INTO 'dancesstepsmap' VALUES (32924, 4602, 5);
INSERT INTO 'dancesstepsmap' VALUES (32925, 4601, 2);
INSERT INTO 'dancesstepsmap' VALUES (32926, 4564, 2);
INSERT INTO 'dancesstepsmap' VALUES (32927, 4537, 5);
INSERT INTO 'dancesstepsmap' VALUES (32928, 4528, 2);
INSERT INTO 'dancesstepsmap' VALUES (32929, 4498, 2);
INSERT INTO 'dancesstepsmap' VALUES (32930, 3684, 2);
INSERT INTO 'dancesstepsmap' VALUES (32931, 14585, 2);
INSERT INTO 'dancesstepsmap' VALUES (32932, 14585, 1);
INSERT INTO 'dancesstepsmap' VALUES (32933, 14585, 3);
INSERT INTO 'dancesstepsmap' VALUES (32934, 20956, 1);
INSERT INTO 'dancesstepsmap' VALUES (32935, 20956, 2);
INSERT INTO 'dancesstepsmap' VALUES (32936, 20956, 3);
INSERT INTO 'dancesstepsmap' VALUES (32937, 21185, 5);
INSERT INTO 'dancesstepsmap' VALUES (32938, 21185, 4);
INSERT INTO 'dancesstepsmap' VALUES (32939, 21186, 2);
INSERT INTO 'dancesstepsmap' VALUES (32940, 21186, 1);
INSERT INTO 'dancesstepsmap' VALUES (32941, 6543, 2);
INSERT INTO 'dancesstepsmap' VALUES (32942, 12746, 2);
INSERT INTO 'dancesstepsmap' VALUES (32943, 6270, 2);
INSERT INTO 'dancesstepsmap' VALUES (32944, 6270, 3);
INSERT INTO 'dancesstepsmap' VALUES (32945, 13389, 8);
INSERT INTO 'dancesstepsmap' VALUES (32946, 16463, 4);
INSERT INTO 'dancesstepsmap' VALUES (32947, 16463, 5);
INSERT INTO 'dancesstepsmap' VALUES (32948, 10751, 1);
INSERT INTO 'dancesstepsmap' VALUES (32949, 10751, 2);
INSERT INTO 'dancesstepsmap' VALUES (32950, 10753, 4);
INSERT INTO 'dancesstepsmap' VALUES (32951, 10753, 5);
INSERT INTO 'dancesstepsmap' VALUES (32952, 16572, 5);
INSERT INTO 'dancesstepsmap' VALUES (32953, 16572, 4);
INSERT INTO 'dancesstepsmap' VALUES (32954, 16573, 1);
INSERT INTO 'dancesstepsmap' VALUES (32955, 16573, 2);
INSERT INTO 'dancesstepsmap' VALUES (32956, 16574, 5);
INSERT INTO 'dancesstepsmap' VALUES (32957, 16574, 4);
INSERT INTO 'dancesstepsmap' VALUES (32958, 16575, 2);
INSERT INTO 'dancesstepsmap' VALUES (32959, 16575, 1);
INSERT INTO 'dancesstepsmap' VALUES (32960, 16577, 1);
INSERT INTO 'dancesstepsmap' VALUES (32961, 16577, 2);
INSERT INTO 'dancesstepsmap' VALUES (32962, 16577, 3);
INSERT INTO 'dancesstepsmap' VALUES (32963, 16578, 4);
INSERT INTO 'dancesstepsmap' VALUES (32964, 16578, 6);
INSERT INTO 'dancesstepsmap' VALUES (32965, 16578, 5);
INSERT INTO 'dancesstepsmap' VALUES (32966, 16579, 4);
INSERT INTO 'dancesstepsmap' VALUES (32967, 16579, 5);
INSERT INTO 'dancesstepsmap' VALUES (32968, 16579, 1);
INSERT INTO 'dancesstepsmap' VALUES (32969, 16579, 2);
INSERT INTO 'dancesstepsmap' VALUES (32970, 16579, 3);
INSERT INTO 'dancesstepsmap' VALUES (32971, 21189, 4);
INSERT INTO 'dancesstepsmap' VALUES (32972, 21189, 5);
INSERT INTO 'dancesstepsmap' VALUES (32973, 4651, 2);
INSERT INTO 'dancesstepsmap' VALUES (32974, 4499, 5);
INSERT INTO 'dancesstepsmap' VALUES (32975, 4393, 5);
INSERT INTO 'dancesstepsmap' VALUES (32976, 4299, 5);
INSERT INTO 'dancesstepsmap' VALUES (32977, 16596, 2);
INSERT INTO 'dancesstepsmap' VALUES (32978, 16596, 1);
INSERT INTO 'dancesstepsmap' VALUES (32979, 16597, 4);
INSERT INTO 'dancesstepsmap' VALUES (32980, 16597, 5);
INSERT INTO 'dancesstepsmap' VALUES (32981, 16598, 2);
INSERT INTO 'dancesstepsmap' VALUES (32982, 16598, 1);
INSERT INTO 'dancesstepsmap' VALUES (32983, 16600, 4);
INSERT INTO 'dancesstepsmap' VALUES (32984, 16600, 5);
INSERT INTO 'dancesstepsmap' VALUES (32985, 16603, 5);
INSERT INTO 'dancesstepsmap' VALUES (32986, 16603, 4);
INSERT INTO 'dancesstepsmap' VALUES (32987, 16611, 5);
INSERT INTO 'dancesstepsmap' VALUES (32988, 16611, 4);
INSERT INTO 'dancesstepsmap' VALUES (32989, 4110, 5);
INSERT INTO 'dancesstepsmap' VALUES (32990, 4105, 5);
INSERT INTO 'dancesstepsmap' VALUES (32991, 4063, 5);
INSERT INTO 'dancesstepsmap' VALUES (32992, 4002, 2);
INSERT INTO 'dancesstepsmap' VALUES (32993, 16664, 4);
INSERT INTO 'dancesstepsmap' VALUES (32994, 16664, 5);
INSERT INTO 'dancesstepsmap' VALUES (32996, 17112, 4);
INSERT INTO 'dancesstepsmap' VALUES (32997, 17112, 5);
INSERT INTO 'dancesstepsmap' VALUES (32998, 17119, 4);
INSERT INTO 'dancesstepsmap' VALUES (32999, 20064, 1);
INSERT INTO 'dancesstepsmap' VALUES (33000, 20064, 2);
INSERT INTO 'dancesstepsmap' VALUES (33001, 21146, 2);
INSERT INTO 'dancesstepsmap' VALUES (33002, 21146, 1);
INSERT INTO 'dancesstepsmap' VALUES (33003, 21146, 3);
INSERT INTO 'dancesstepsmap' VALUES (33004, 21191, 1);
INSERT INTO 'dancesstepsmap' VALUES (33005, 21192, 4);
INSERT INTO 'dancesstepsmap' VALUES (33006, 21192, 5);
INSERT INTO 'dancesstepsmap' VALUES (33007, 19870, 4);
INSERT INTO 'dancesstepsmap' VALUES (33008, 19870, 5);
INSERT INTO 'dancesstepsmap' VALUES (33009, 21193, 1);
INSERT INTO 'dancesstepsmap' VALUES (33010, 21193, 2);
INSERT INTO 'dancesstepsmap' VALUES (33011, 21194, 4);
INSERT INTO 'dancesstepsmap' VALUES (33012, 21194, 5);
INSERT INTO 'dancesstepsmap' VALUES (33013, 21195, 1);
INSERT INTO 'dancesstepsmap' VALUES (33014, 21195, 2);
INSERT INTO 'dancesstepsmap' VALUES (33015, 3892, 5);
INSERT INTO 'dancesstepsmap' VALUES (33016, 3882, 5);
INSERT INTO 'dancesstepsmap' VALUES (33017, 3800, 3);
INSERT INTO 'dancesstepsmap' VALUES (33018, 3776, 2);
INSERT INTO 'dancesstepsmap' VALUES (33019, 3765, 5);
INSERT INTO 'dancesstepsmap' VALUES (33020, 3737, 2);
INSERT INTO 'dancesstepsmap' VALUES (33021, 3726, 5);
INSERT INTO 'dancesstepsmap' VALUES (33022, 3699, 5);
INSERT INTO 'dancesstepsmap' VALUES (33023, 3689, 2);
INSERT INTO 'dancesstepsmap' VALUES (33024, 3689, 3);
INSERT INTO 'dancesstepsmap' VALUES (33025, 3592, 5);
INSERT INTO 'dancesstepsmap' VALUES (33026, 3586, 5);
INSERT INTO 'dancesstepsmap' VALUES (33027, 21197, 4);
INSERT INTO 'dancesstepsmap' VALUES (33028, 21197, 5);
INSERT INTO 'dancesstepsmap' VALUES (33029, 12004, 1);
INSERT INTO 'dancesstepsmap' VALUES (33030, 12004, 3);
INSERT INTO 'dancesstepsmap' VALUES (33031, 21199, 1);
INSERT INTO 'dancesstepsmap' VALUES (33032, 21199, 2);
INSERT INTO 'dancesstepsmap' VALUES (33033, 21199, 3);
INSERT INTO 'dancesstepsmap' VALUES (33034, 727, 5);
INSERT INTO 'dancesstepsmap' VALUES (33035, 21200, 1);
INSERT INTO 'dancesstepsmap' VALUES (33036, 21200, 2);
INSERT INTO 'dancesstepsmap' VALUES (33037, 21201, 5);
INSERT INTO 'dancesstepsmap' VALUES (33038, 21201, 4);
INSERT INTO 'dancesstepsmap' VALUES (33039, 21202, 1);
INSERT INTO 'dancesstepsmap' VALUES (33040, 21202, 2);
INSERT INTO 'dancesstepsmap' VALUES (33041, 21203, 4);
INSERT INTO 'dancesstepsmap' VALUES (33042, 21203, 5);
INSERT INTO 'dancesstepsmap' VALUES (33043, 21204, 4);
INSERT INTO 'dancesstepsmap' VALUES (33044, 21204, 5);
INSERT INTO 'dancesstepsmap' VALUES (33045, 21205, 2);
INSERT INTO 'dancesstepsmap' VALUES (33046, 21205, 1);
INSERT INTO 'dancesstepsmap' VALUES (33047, 21206, 2);
INSERT INTO 'dancesstepsmap' VALUES (33048, 21206, 1);
INSERT INTO 'dancesstepsmap' VALUES (33049, 3578, 102);
INSERT INTO 'dancesstepsmap' VALUES (33050, 3578, 2);
INSERT INTO 'dancesstepsmap' VALUES (33051, 21207, 4);
INSERT INTO 'dancesstepsmap' VALUES (33052, 21207, 5);
INSERT INTO 'dancesstepsmap' VALUES (33053, 304, 4);
INSERT INTO 'dancesstepsmap' VALUES (33054, 304, 1);
INSERT INTO 'dancesstepsmap' VALUES (33055, 304, 2);
INSERT INTO 'dancesstepsmap' VALUES (33056, 270, 5);
INSERT INTO 'dancesstepsmap' VALUES (33057, 21208, 4);
INSERT INTO 'dancesstepsmap' VALUES (33058, 6134, 5);
INSERT INTO 'dancesstepsmap' VALUES (33059, 6134, 4);
INSERT INTO 'dancesstepsmap' VALUES (33060, 6134, 1);
INSERT INTO 'dancesstepsmap' VALUES (33061, 6134, 3);
INSERT INTO 'dancesstepsmap' VALUES (33062, 6134, 2);
INSERT INTO 'dancesstepsmap' VALUES (33063, 3553, 5);
INSERT INTO 'dancesstepsmap' VALUES (33064, 3529, 2);
INSERT INTO 'dancesstepsmap' VALUES (33065, 21213, 4);
INSERT INTO 'dancesstepsmap' VALUES (33066, 21213, 5);
INSERT INTO 'dancesstepsmap' VALUES (33067, 21215, 5);
INSERT INTO 'dancesstepsmap' VALUES (33068, 21215, 4);
INSERT INTO 'dancesstepsmap' VALUES (33069, 21215, 2);
INSERT INTO 'dancesstepsmap' VALUES (33070, 21215, 1);
INSERT INTO 'dancesstepsmap' VALUES (33071, 21216, 1);
INSERT INTO 'dancesstepsmap' VALUES (33072, 21216, 2);
INSERT INTO 'dancesstepsmap' VALUES (33073, 21216, 3);
INSERT INTO 'dancesstepsmap' VALUES (33074, 21217, 1);
INSERT INTO 'dancesstepsmap' VALUES (33075, 21218, 4);
INSERT INTO 'dancesstepsmap' VALUES (33076, 21218, 5);
INSERT INTO 'dancesstepsmap' VALUES (33077, 21218, 1);
INSERT INTO 'dancesstepsmap' VALUES (33078, 21218, 2);
INSERT INTO 'dancesstepsmap' VALUES (33079, 21219, 1);
INSERT INTO 'dancesstepsmap' VALUES (33080, 21219, 2);
INSERT INTO 'dancesstepsmap' VALUES (33081, 21220, 1);
INSERT INTO 'dancesstepsmap' VALUES (33082, 21221, 4);
INSERT INTO 'dancesstepsmap' VALUES (33083, 21221, 5);
INSERT INTO 'dancesstepsmap' VALUES (33084, 17913, 1);
INSERT INTO 'dancesstepsmap' VALUES (33085, 17913, 2);
INSERT INTO 'dancesstepsmap' VALUES (33086, 885, 5);
INSERT INTO 'dancesstepsmap' VALUES (33087, 885, 4);
INSERT INTO 'dancesstepsmap' VALUES (33088, 885, 2);
INSERT INTO 'dancesstepsmap' VALUES (33089, 885, 1);
INSERT INTO 'dancesstepsmap' VALUES (33090, 885, 3);
INSERT INTO 'dancesstepsmap' VALUES (33091, 920, 2);
INSERT INTO 'dancesstepsmap' VALUES (33092, 955, 2);
INSERT INTO 'dancesstepsmap' VALUES (33093, 1003, 2);
INSERT INTO 'dancesstepsmap' VALUES (33094, 1003, 3);
INSERT INTO 'dancesstepsmap' VALUES (33095, 1172, 2);
INSERT INTO 'dancesstepsmap' VALUES (33096, 1172, 3);
INSERT INTO 'dancesstepsmap' VALUES (33097, 2094, 2);
INSERT INTO 'dancesstepsmap' VALUES (33098, 21228, 1);
INSERT INTO 'dancesstepsmap' VALUES (33099, 21228, 2);
INSERT INTO 'dancesstepsmap' VALUES (33100, 21230, 1);
INSERT INTO 'dancesstepsmap' VALUES (33102, 21230, 3);
INSERT INTO 'dancesstepsmap' VALUES (33103, 21230, 4);
INSERT INTO 'dancesstepsmap' VALUES (33104, 21230, 5);
INSERT INTO 'dancesstepsmap' VALUES (33105, 21229, 4);
INSERT INTO 'dancesstepsmap' VALUES (33106, 21229, 5);
INSERT INTO 'dancesstepsmap' VALUES (33101, 21230, 2);
INSERT INTO 'dancesstepsmap' VALUES (33107, 10401, 1);
INSERT INTO 'dancesstepsmap' VALUES (33108, 10401, 2);
INSERT INTO 'dancesstepsmap' VALUES (33109, 10401, 3);
INSERT INTO 'dancesstepsmap' VALUES (33110, 21277, 1);
INSERT INTO 'dancesstepsmap' VALUES (33111, 21277, 3);
INSERT INTO 'dancesstepsmap' VALUES (33112, 5203, 2);
INSERT INTO 'dancesstepsmap' VALUES (33113, 21278, 1);
INSERT INTO 'dancesstepsmap' VALUES (33114, 21278, 3);
INSERT INTO 'dancesstepsmap' VALUES (9213, 2700, 2);
INSERT INTO 'dancesstepsmap' VALUES (33115, 21279, 1);
INSERT INTO 'dancesstepsmap' VALUES (33116, 21279, 2);
INSERT INTO 'dancesstepsmap' VALUES (33117, 21279, 3);
INSERT INTO 'dancesstepsmap' VALUES (33118, 3511, 2);
INSERT INTO 'dancesstepsmap' VALUES (33119, 3433, 2);
INSERT INTO 'dancesstepsmap' VALUES (33120, 3433, 3);
INSERT INTO 'dancesstepsmap' VALUES (33121, 3415, 2);
INSERT INTO 'dancesstepsmap' VALUES (33122, 3393, 5);
INSERT INTO 'dancesstepsmap' VALUES (33123, 3351, 5);
INSERT INTO 'dancesstepsmap' VALUES (33124, 21179, 2);
INSERT INTO 'dancesstepsmap' VALUES (33125, 21179, 1);
INSERT INTO 'dancesstepsmap' VALUES (33126, 20777, 1);
INSERT INTO 'dancesstepsmap' VALUES (33127, 20776, 1);
INSERT INTO 'dancesstepsmap' VALUES (33128, 20776, 2);
INSERT INTO 'dancesstepsmap' VALUES (33129, 20775, 2);
INSERT INTO 'dancesstepsmap' VALUES (33130, 20775, 1);
INSERT INTO 'dancesstepsmap' VALUES (33131, 20774, 5);
INSERT INTO 'dancesstepsmap' VALUES (33132, 20774, 4);
INSERT INTO 'dancesstepsmap' VALUES (33133, 3349, 2);
INSERT INTO 'dancesstepsmap' VALUES (33134, 3331, 5);
INSERT INTO 'dancesstepsmap' VALUES (33135, 3245, 2);
INSERT INTO 'dancesstepsmap' VALUES (33136, 3233, 2);
INSERT INTO 'dancesstepsmap' VALUES (33137, 2195, 2);
INSERT INTO 'dancesstepsmap' VALUES (33138, 21280, 5);
INSERT INTO 'dancesstepsmap' VALUES (33139, 21280, 1);
INSERT INTO 'dancesstepsmap' VALUES (33140, 21280, 2);
INSERT INTO 'dancesstepsmap' VALUES (33141, 21280, 99);
INSERT INTO 'dancesstepsmap' VALUES (33142, 21281, 99);
INSERT INTO 'dancesstepsmap' VALUES (33143, 21282, 10);
INSERT INTO 'dancesstepsmap' VALUES (33144, 21282, 2);
INSERT INTO 'dancesstepsmap' VALUES (33145, 21282, 1);
INSERT INTO 'dancesstepsmap' VALUES (33146, 14303, 10);
INSERT INTO 'dancesstepsmap' VALUES (33147, 21285, 99);
INSERT INTO 'dancesstepsmap' VALUES (33148, 21286, 1);
INSERT INTO 'dancesstepsmap' VALUES (33149, 21286, 2);
INSERT INTO 'dancesstepsmap' VALUES (33150, 21287, 3);
INSERT INTO 'dancesstepsmap' VALUES (33151, 21287, 2);
INSERT INTO 'dancesstepsmap' VALUES (33152, 21287, 10);
INSERT INTO 'dancesstepsmap' VALUES (33153, 21287, 8);
INSERT INTO 'dancesstepsmap' VALUES (33154, 21288, 1);
INSERT INTO 'dancesstepsmap' VALUES (33155, 21288, 2);
INSERT INTO 'dancesstepsmap' VALUES (33156, 21288, 8);
INSERT INTO 'dancesstepsmap' VALUES (33157, 21289, 1);
INSERT INTO 'dancesstepsmap' VALUES (33158, 21289, 2);
INSERT INTO 'dancesstepsmap' VALUES (33159, 21289, 3);
INSERT INTO 'dancesstepsmap' VALUES (33160, 21290, 10);
INSERT INTO 'dancesstepsmap' VALUES (33161, 21291, 101);
INSERT INTO 'dancesstepsmap' VALUES (33162, 21292, 7);
INSERT INTO 'dancesstepsmap' VALUES (33163, 21293, 7);
INSERT INTO 'dancesstepsmap' VALUES (33164, 21295, 10);
INSERT INTO 'dancesstepsmap' VALUES (33165, 21294, 10);
INSERT INTO 'dancesstepsmap' VALUES (33166, 21296, 99);
INSERT INTO 'dancesstepsmap' VALUES (33167, 21298, 99);
INSERT INTO 'dancesstepsmap' VALUES (33168, 21299, 99);
INSERT INTO 'dancesstepsmap' VALUES (33169, 3614, 99);
INSERT INTO 'dancesstepsmap' VALUES (33170, 18125, 1);
INSERT INTO 'dancesstepsmap' VALUES (33171, 18125, 2);
INSERT INTO 'dancesstepsmap' VALUES (33172, 21301, 4);
INSERT INTO 'dancesstepsmap' VALUES (33173, 21302, 1);
INSERT INTO 'dancesstepsmap' VALUES (33174, 21302, 2);
INSERT INTO 'dancesstepsmap' VALUES (33175, 21303, 1);
INSERT INTO 'dancesstepsmap' VALUES (33176, 21304, 3);
INSERT INTO 'dancesstepsmap' VALUES (33177, 21304, 1);
INSERT INTO 'dancesstepsmap' VALUES (33178, 21304, 2);
INSERT INTO 'dancesstepsmap' VALUES (33179, 21305, 1);
INSERT INTO 'dancesstepsmap' VALUES (33180, 21305, 3);
INSERT INTO 'dancesstepsmap' VALUES (33181, 21306, 1);
INSERT INTO 'dancesstepsmap' VALUES (33182, 21306, 2);
INSERT INTO 'dancesstepsmap' VALUES (33183, 21307, 1);
INSERT INTO 'dancesstepsmap' VALUES (33184, 21307, 3);
INSERT INTO 'dancesstepsmap' VALUES (33185, 21308, 1);
INSERT INTO 'dancesstepsmap' VALUES (33186, 21308, 2);
INSERT INTO 'dancesstepsmap' VALUES (33187, 21309, 1);
INSERT INTO 'dancesstepsmap' VALUES (33188, 21310, 1);
INSERT INTO 'dancesstepsmap' VALUES (33189, 21311, 2);
INSERT INTO 'dancesstepsmap' VALUES (33190, 21311, 1);
INSERT INTO 'dancesstepsmap' VALUES (33191, 3113, 5);
INSERT INTO 'dancesstepsmap' VALUES (33192, 3114, 4);
INSERT INTO 'dancesstepsmap' VALUES (33193, 3114, 5);
INSERT INTO 'dancesstepsmap' VALUES (33194, 3114, 1);
INSERT INTO 'dancesstepsmap' VALUES (33195, 3114, 2);
INSERT INTO 'dancesstepsmap' VALUES (33196, 2981, 2);
INSERT INTO 'dancesstepsmap' VALUES (33197, 2941, 2);
INSERT INTO 'dancesstepsmap' VALUES (33198, 2897, 2);
INSERT INTO 'dancesstepsmap' VALUES (33199, 2886, 2);
INSERT INTO 'dancesstepsmap' VALUES (33200, 2828, 2);
INSERT INTO 'dancesstepsmap' VALUES (33201, 2752, 2);
INSERT INTO 'dancesstepsmap' VALUES (33202, 2749, 5);
INSERT INTO 'dancesstepsmap' VALUES (33203, 2716, 2);
INSERT INTO 'dancesstepsmap' VALUES (33204, 2698, 2);
INSERT INTO 'dancesstepsmap' VALUES (33205, 2695, 2);
INSERT INTO 'dancesstepsmap' VALUES (33206, 2667, 2);
INSERT INTO 'dancesstepsmap' VALUES (33207, 21312, 2);
INSERT INTO 'dancesstepsmap' VALUES (33208, 21312, 1);
INSERT INTO 'dancesstepsmap' VALUES (33209, 21313, 3);
INSERT INTO 'dancesstepsmap' VALUES (33210, 21313, 2);
INSERT INTO 'dancesstepsmap' VALUES (33211, 21313, 1);
INSERT INTO 'dancesstepsmap' VALUES (33212, 21314, 4);
INSERT INTO 'dancesstepsmap' VALUES (33213, 21314, 5);
INSERT INTO 'dancesstepsmap' VALUES (33214, 21315, 1);
INSERT INTO 'dancesstepsmap' VALUES (33215, 21316, 4);
INSERT INTO 'dancesstepsmap' VALUES (33216, 21316, 5);
INSERT INTO 'dancesstepsmap' VALUES (33217, 5852, 2);
INSERT INTO 'dancesstepsmap' VALUES (33218, 21317, 1);
INSERT INTO 'dancesstepsmap' VALUES (33219, 21317, 2);
INSERT INTO 'dancesstepsmap' VALUES (33220, 21318, 1);
INSERT INTO 'dancesstepsmap' VALUES (33221, 21318, 2);
INSERT INTO 'dancesstepsmap' VALUES (33222, 730, 3);
INSERT INTO 'dancesstepsmap' VALUES (33223, 20776, 3);
INSERT INTO 'dancesstepsmap' VALUES (33224, 21319, 4);
INSERT INTO 'dancesstepsmap' VALUES (33225, 21319, 5);
INSERT INTO 'dancesstepsmap' VALUES (33226, 18367, 1);
INSERT INTO 'dancesstepsmap' VALUES (33227, 18367, 2);
INSERT INTO 'dancesstepsmap' VALUES (33228, 21320, 2);
INSERT INTO 'dancesstepsmap' VALUES (33229, 21320, 1);
INSERT INTO 'dancesstepsmap' VALUES (33230, 21320, 3);
INSERT INTO 'dancesstepsmap' VALUES (33231, 21321, 2);
INSERT INTO 'dancesstepsmap' VALUES (33232, 21321, 1);
INSERT INTO 'dancesstepsmap' VALUES (33233, 21322, 5);
INSERT INTO 'dancesstepsmap' VALUES (33234, 21322, 4);
INSERT INTO 'dancesstepsmap' VALUES (33235, 21323, 3);
INSERT INTO 'dancesstepsmap' VALUES (33236, 21323, 1);
INSERT INTO 'dancesstepsmap' VALUES (33237, 21323, 2);
INSERT INTO 'dancesstepsmap' VALUES (33238, 21324, 5);
INSERT INTO 'dancesstepsmap' VALUES (33239, 21324, 4);
INSERT INTO 'dancesstepsmap' VALUES (33242, 21326, 1);
INSERT INTO 'dancesstepsmap' VALUES (33243, 21326, 2);
INSERT INTO 'dancesstepsmap' VALUES (33244, 21327, 2);
INSERT INTO 'dancesstepsmap' VALUES (33245, 21327, 1);
INSERT INTO 'dancesstepsmap' VALUES (33246, 21328, 1);
INSERT INTO 'dancesstepsmap' VALUES (33247, 21328, 2);
INSERT INTO 'dancesstepsmap' VALUES (33248, 21328, 5);
INSERT INTO 'dancesstepsmap' VALUES (33249, 21328, 4);
INSERT INTO 'dancesstepsmap' VALUES (33250, 21329, 5);
INSERT INTO 'dancesstepsmap' VALUES (33251, 21329, 4);
INSERT INTO 'dancesstepsmap' VALUES (33254, 21331, 2);
INSERT INTO 'dancesstepsmap' VALUES (33255, 21331, 1);
INSERT INTO 'dancesstepsmap' VALUES (33256, 21332, 2);
INSERT INTO 'dancesstepsmap' VALUES (33257, 21332, 1);
INSERT INTO 'dancesstepsmap' VALUES (33258, 21332, 3);
INSERT INTO 'dancesstepsmap' VALUES (33259, 21333, 2);
INSERT INTO 'dancesstepsmap' VALUES (33260, 21333, 1);
INSERT INTO 'dancesstepsmap' VALUES (33261, 21334, 5);
INSERT INTO 'dancesstepsmap' VALUES (33262, 21334, 4);
INSERT INTO 'dancesstepsmap' VALUES (33263, 21335, 4);
INSERT INTO 'dancesstepsmap' VALUES (33264, 21335, 1);
INSERT INTO 'dancesstepsmap' VALUES (33265, 21335, 5);
INSERT INTO 'dancesstepsmap' VALUES (33266, 21335, 2);
INSERT INTO 'dancesstepsmap' VALUES (33267, 18137, 2);
INSERT INTO 'dancesstepsmap' VALUES (33268, 2613, 3);
INSERT INTO 'dancesstepsmap' VALUES (33269, 2575, 2);
INSERT INTO 'dancesstepsmap' VALUES (33270, 2530, 2);
INSERT INTO 'dancesstepsmap' VALUES (33271, 2488, 4);
INSERT INTO 'dancesstepsmap' VALUES (33272, 2488, 5);
INSERT INTO 'dancesstepsmap' VALUES (33273, 2488, 1);
INSERT INTO 'dancesstepsmap' VALUES (33274, 2488, 2);
INSERT INTO 'dancesstepsmap' VALUES (33275, 2472, 3);
INSERT INTO 'dancesstepsmap' VALUES (33276, 2380, 5);
INSERT INTO 'dancesstepsmap' VALUES (33277, 2380, 6);
INSERT INTO 'dancesstepsmap' VALUES (33278, 2199, 5);
INSERT INTO 'dancesstepsmap' VALUES (33279, 21333, 3);
INSERT INTO 'dancesstepsmap' VALUES (33280, 21336, 2);
INSERT INTO 'dancesstepsmap' VALUES (33281, 21336, 1);
INSERT INTO 'dancesstepsmap' VALUES (33282, 18886, 4);
INSERT INTO 'dancesstepsmap' VALUES (33283, 18886, 5);
INSERT INTO 'dancesstepsmap' VALUES (33284, 21337, 5);
INSERT INTO 'dancesstepsmap' VALUES (33285, 21337, 4);
INSERT INTO 'dancesstepsmap' VALUES (33286, 21338, 2);
INSERT INTO 'dancesstepsmap' VALUES (33287, 21338, 1);
INSERT INTO 'dancesstepsmap' VALUES (33288, 21338, 3);
INSERT INTO 'dancesstepsmap' VALUES (33289, 21339, 4);
INSERT INTO 'dancesstepsmap' VALUES (33290, 21339, 5);
INSERT INTO 'dancesstepsmap' VALUES (33291, 21135, 4);
INSERT INTO 'dancesstepsmap' VALUES (33292, 21135, 5);
INSERT INTO 'dancesstepsmap' VALUES (33293, 21135, 1);
INSERT INTO 'dancesstepsmap' VALUES (33294, 21135, 2);
INSERT INTO 'dancesstepsmap' VALUES (33295, 19326, 4);
INSERT INTO 'dancesstepsmap' VALUES (33296, 19326, 5);
INSERT INTO 'dancesstepsmap' VALUES (33297, 19326, 6);
INSERT INTO 'dancesstepsmap' VALUES (33298, 19326, 3);
INSERT INTO 'dancesstepsmap' VALUES (33299, 19326, 1);
INSERT INTO 'dancesstepsmap' VALUES (33300, 19326, 2);
INSERT INTO 'dancesstepsmap' VALUES (33301, 1877, 5);
INSERT INTO 'dancesstepsmap' VALUES (33302, 2158, 2);
INSERT INTO 'dancesstepsmap' VALUES (33303, 2103, 2);
INSERT INTO 'dancesstepsmap' VALUES (33304, 2095, 5);
INSERT INTO 'dancesstepsmap' VALUES (33305, 2072, 5);
INSERT INTO 'dancesstepsmap' VALUES (33306, 2030, 5);
INSERT INTO 'dancesstepsmap' VALUES (33307, 1992, 3);
INSERT INTO 'dancesstepsmap' VALUES (33308, 1955, 2);
INSERT INTO 'dancesstepsmap' VALUES (33309, 1905, 2);
INSERT INTO 'dancesstepsmap' VALUES (33310, 1851, 2);
INSERT INTO 'dancesstepsmap' VALUES (33311, 13891, 1);
INSERT INTO 'dancesstepsmap' VALUES (33312, 13891, 2);
INSERT INTO 'dancesstepsmap' VALUES (33313, 13891, 8);
INSERT INTO 'dancesstepsmap' VALUES (33314, 21340, 5);
INSERT INTO 'dancesstepsmap' VALUES (33315, 21340, 4);
INSERT INTO 'dancesstepsmap' VALUES (33316, 1842, 2);
INSERT INTO 'dancesstepsmap' VALUES (33317, 1807, 6);
INSERT INTO 'dancesstepsmap' VALUES (33318, 1807, 5);
INSERT INTO 'dancesstepsmap' VALUES (33319, 1801, 5);
INSERT INTO 'dancesstepsmap' VALUES (33320, 1776, 5);
INSERT INTO 'dancesstepsmap' VALUES (33321, 1643, 2);
INSERT INTO 'dancesstepsmap' VALUES (33322, 6286, 3);
INSERT INTO 'dancesstepsmap' VALUES (33323, 1608, 2);
INSERT INTO 'dancesstepsmap' VALUES (33324, 1595, 5);
INSERT INTO 'dancesstepsmap' VALUES (33325, 1535, 2);
INSERT INTO 'dancesstepsmap' VALUES (33326, 1524, 2);
INSERT INTO 'dancesstepsmap' VALUES (33327, 1499, 2);
INSERT INTO 'dancesstepsmap' VALUES (33328, 17830, 2);
INSERT INTO 'dancesstepsmap' VALUES (33329, 17830, 1);
INSERT INTO 'dancesstepsmap' VALUES (33330, 17830, 3);
INSERT INTO 'dancesstepsmap' VALUES (33331, 21341, 1);
INSERT INTO 'dancesstepsmap' VALUES (33332, 21341, 2);
INSERT INTO 'dancesstepsmap' VALUES (33333, 17807, 1);
INSERT INTO 'dancesstepsmap' VALUES (33334, 21342, 1);
INSERT INTO 'dancesstepsmap' VALUES (33335, 17809, 1);
INSERT INTO 'dancesstepsmap' VALUES (33336, 1488, 3);
INSERT INTO 'dancesstepsmap' VALUES (33337, 1452, 2);
INSERT INTO 'dancesstepsmap' VALUES (33338, 1390, 2);
INSERT INTO 'dancesstepsmap' VALUES (33339, 1314, 2);
INSERT INTO 'dancesstepsmap' VALUES (33340, 1261, 2);
INSERT INTO 'dancesstepsmap' VALUES (33341, 1238, 2);
INSERT INTO 'dancesstepsmap' VALUES (33342, 1145, 2);
INSERT INTO 'dancesstepsmap' VALUES (33343, 1097, 5);
INSERT INTO 'dancesstepsmap' VALUES (33344, 1085, 3);
INSERT INTO 'dancesstepsmap' VALUES (33345, 1059, 2);
INSERT INTO 'dancesstepsmap' VALUES (33346, 1037, 5);
INSERT INTO 'dancesstepsmap' VALUES (33347, 9426, 1);
INSERT INTO 'dancesstepsmap' VALUES (33348, 9426, 2);
INSERT INTO 'dancesstepsmap' VALUES (33349, 9426, 102);
INSERT INTO 'dancesstepsmap' VALUES (33350, 9426, 3);
INSERT INTO 'dancesstepsmap' VALUES (33351, 21343, 4);
INSERT INTO 'dancesstepsmap' VALUES (33352, 21343, 5);
INSERT INTO 'dancesstepsmap' VALUES (33353, 21344, 1);
INSERT INTO 'dancesstepsmap' VALUES (33354, 977, 2);
INSERT INTO 'dancesstepsmap' VALUES (33355, 977, 3);
INSERT INTO 'dancesstepsmap' VALUES (33356, 954, 2);
INSERT INTO 'dancesstepsmap' VALUES (33357, 934, 6);
INSERT INTO 'dancesstepsmap' VALUES (33358, 925, 2);
INSERT INTO 'dancesstepsmap' VALUES (33359, 850, 5);
INSERT INTO 'dancesstepsmap' VALUES (33360, 827, 2);
INSERT INTO 'dancesstepsmap' VALUES (33361, 815, 5);
INSERT INTO 'dancesstepsmap' VALUES (33362, 767, 2);
INSERT INTO 'dancesstepsmap' VALUES (33363, 762, 5);
INSERT INTO 'dancesstepsmap' VALUES (33364, 21345, 2);
INSERT INTO 'dancesstepsmap' VALUES (33365, 21345, 1);
INSERT INTO 'dancesstepsmap' VALUES (33366, 21345, 5);
INSERT INTO 'dancesstepsmap' VALUES (33367, 21345, 4);
INSERT INTO 'dancesstepsmap' VALUES (33368, 21346, 5);
INSERT INTO 'dancesstepsmap' VALUES (33369, 21346, 4);
INSERT INTO 'dancesstepsmap' VALUES (33370, 21347, 2);
INSERT INTO 'dancesstepsmap' VALUES (33371, 21347, 1);
INSERT INTO 'dancesstepsmap' VALUES (33372, 21347, 3);
INSERT INTO 'dancesstepsmap' VALUES (33373, 21348, 1);
INSERT INTO 'dancesstepsmap' VALUES (33374, 21349, 4);
INSERT INTO 'dancesstepsmap' VALUES (33375, 21349, 5);
INSERT INTO 'dancesstepsmap' VALUES (33376, 21350, 5);
INSERT INTO 'dancesstepsmap' VALUES (33377, 21350, 4);


--
INSERT INTO 'dancestunesmap' VALUES (2, 17, 106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3, 17, 1713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4, 17, 1774, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9, 50, 777, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8881, 14926, 127, 10, '');
INSERT INTO 'dancestunesmap' VALUES (20, 79, 1048, 10, '');
INSERT INTO 'dancestunesmap' VALUES (22, 90, 1282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (25, 108, 30, 10, '');
INSERT INTO 'dancestunesmap' VALUES (26, 108, 509, 10, '');
INSERT INTO 'dancestunesmap' VALUES (28, 113, 32, 10, '');
INSERT INTO 'dancestunesmap' VALUES (29, 116, 34, 10, '');
INSERT INTO 'dancestunesmap' VALUES (35, 152, 40, 10, '');
INSERT INTO 'dancestunesmap' VALUES (54, 215, 53, 10, '');
INSERT INTO 'dancestunesmap' VALUES (56, 221, 1356, 10, '');
INSERT INTO 'dancestunesmap' VALUES (59, 223, 55, 10, '');
INSERT INTO 'dancestunesmap' VALUES (68, 279, 1084, 10, '');
INSERT INTO 'dancestunesmap' VALUES (74, 309, 1598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (75, 311, 1243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (77, 314, 698, 10, '');
INSERT INTO 'dancestunesmap' VALUES (78, 321, 1624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (87, 350, 79, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7736, 4334, 636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (98, 391, 228, 10, '');
INSERT INTO 'dancestunesmap' VALUES (99, 392, 91, 10, '');
INSERT INTO 'dancestunesmap' VALUES (110, 415, 947, 10, '');
INSERT INTO 'dancestunesmap' VALUES (111, 425, 186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (114, 434, 256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (115, 434, 611, 10, '');
INSERT INTO 'dancestunesmap' VALUES (119, 444, 122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (120, 444, 1542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (126, 480, 661, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1, 6, 8, 10, '');
INSERT INTO 'dancestunesmap' VALUES (132, 520, 471, 10, '');
INSERT INTO 'dancestunesmap' VALUES (139, 542, 1460, 10, '');
INSERT INTO 'dancestunesmap' VALUES (147, 577, 1132, 10, '');
INSERT INTO 'dancestunesmap' VALUES (152, 607, 136, 10, '');
INSERT INTO 'dancestunesmap' VALUES (153, 608, 137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (154, 610, 138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (160, 651, 345, 10, '');
INSERT INTO 'dancestunesmap' VALUES (159, 635, 146, 1, '');
INSERT INTO 'dancestunesmap' VALUES (91, 360, 1008, 1, '');
INSERT INTO 'dancestunesmap' VALUES (52, 190, 68, 10, '');
INSERT INTO 'dancestunesmap' VALUES (33, 132, 1370, 11, '');
INSERT INTO 'dancestunesmap' VALUES (32, 132, 35, 10, '');
INSERT INTO 'dancestunesmap' VALUES (45, 173, 958, 10, '');
INSERT INTO 'dancestunesmap' VALUES (44, 173, 162, 10, '');
INSERT INTO 'dancestunesmap' VALUES (143, 567, 1278, 10, '');
INSERT INTO 'dancestunesmap' VALUES (47, 178, 813, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7737, 4830, 2366, 10, '');
INSERT INTO 'dancestunesmap' VALUES (89, 353, 81, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11, 54, 964, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7735, 3915, 3078, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6, 40, 1214, 10, '');
INSERT INTO 'dancestunesmap' VALUES (182, 716, 234, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10, 51, 205, 10, '');
INSERT INTO 'dancestunesmap' VALUES (128, 495, 730, 10, '');
INSERT INTO 'dancestunesmap' VALUES (63, 261, 60, 10, '');
INSERT INTO 'dancestunesmap' VALUES (134, 522, 121, 10, '');
INSERT INTO 'dancestunesmap' VALUES (138, 541, 124, 10, '');
INSERT INTO 'dancestunesmap' VALUES (108, 410, 1393, 11, '');
INSERT INTO 'dancestunesmap' VALUES (107, 410, 97, 10, '');
INSERT INTO 'dancestunesmap' VALUES (174, 682, 1163, 10, '');
INSERT INTO 'dancestunesmap' VALUES (58, 222, 1333, 11, '');
INSERT INTO 'dancestunesmap' VALUES (19, 78, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (156, 611, 1776, 11, '');
INSERT INTO 'dancestunesmap' VALUES (155, 611, 1355, 10, '');
INSERT INTO 'dancestunesmap' VALUES (53, 192, 1755, 10, '');
INSERT INTO 'dancestunesmap' VALUES (94, 373, 84, 10, '');
INSERT INTO 'dancestunesmap' VALUES (148, 584, 128, 10, '');
INSERT INTO 'dancestunesmap' VALUES (135, 522, 306, 11, '');
INSERT INTO 'dancestunesmap' VALUES (5, 18, 1476, 10, '');
INSERT INTO 'dancestunesmap' VALUES (60, 232, 1685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (149, 588, 129, 10, '');
INSERT INTO 'dancestunesmap' VALUES (112, 428, 1426, 10, '');
INSERT INTO 'dancestunesmap' VALUES (40, 163, 649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (176, 691, 167, 10, '');
INSERT INTO 'dancestunesmap' VALUES (90, 355, 82, 10, '');
INSERT INTO 'dancestunesmap' VALUES (164, 658, 156, 10, '');
INSERT INTO 'dancestunesmap' VALUES (150, 590, 1225, 10, '');
INSERT INTO 'dancestunesmap' VALUES (186, 736, 175, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7734, 3111, 3952, 10, '');
INSERT INTO 'dancestunesmap' VALUES (177, 694, 1605, 10, '');
INSERT INTO 'dancestunesmap' VALUES (161, 652, 1733, 10, '');
INSERT INTO 'dancestunesmap' VALUES (83, 327, 1010, 10, '');
INSERT INTO 'dancestunesmap' VALUES (23, 91, 27, 10, '');
INSERT INTO 'dancestunesmap' VALUES (97, 389, 90, 10, '');
INSERT INTO 'dancestunesmap' VALUES (41, 164, 47, 1, '');
INSERT INTO 'dancestunesmap' VALUES (39, 159, 5, 10, '');
INSERT INTO 'dancestunesmap' VALUES (71, 289, 705, 10, '');
INSERT INTO 'dancestunesmap' VALUES (48, 183, 329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (168, 670, 1606, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10209, 10540, 5080, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10210, 17918, 13842, 10, '');
INSERT INTO 'dancestunesmap' VALUES (13, 56, 295, 10, '');
INSERT INTO 'dancestunesmap' VALUES (46, 174, 1707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (67, 276, 687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (146, 576, 127, 10, '');
INSERT INTO 'dancestunesmap' VALUES (79, 323, 6945, 10, 'As “The Burnt Potato”');
INSERT INTO 'dancestunesmap' VALUES (80, 324, 75, 1, '');
INSERT INTO 'dancestunesmap' VALUES (100, 394, 93, 10, '');
INSERT INTO 'dancestunesmap' VALUES (103, 399, 816, 10, '');
INSERT INTO 'dancestunesmap' VALUES (140, 543, 125, 10, '');
INSERT INTO 'dancestunesmap' VALUES (144, 570, 172, 10, '');
INSERT INTO 'dancestunesmap' VALUES (88, 352, 80, 10, '');
INSERT INTO 'dancestunesmap' VALUES (76, 312, 73, 10, '');
INSERT INTO 'dancestunesmap' VALUES (166, 665, 166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (109, 414, 944, 10, '');
INSERT INTO 'dancestunesmap' VALUES (137, 535, 532, 10, '');
INSERT INTO 'dancestunesmap' VALUES (158, 633, 601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (131, 510, 115, 10, '');
INSERT INTO 'dancestunesmap' VALUES (17, 76, 23, 10, '');
INSERT INTO 'dancestunesmap' VALUES (18, 76, 1518, 11, '');
INSERT INTO 'dancestunesmap' VALUES (27, 109, 31, 10, '');
INSERT INTO 'dancestunesmap' VALUES (178, 704, 129, 10, '');
INSERT INTO 'dancestunesmap' VALUES (179, 704, 148, 10, '');
INSERT INTO 'dancestunesmap' VALUES (96, 386, 88, 10, '');
INSERT INTO 'dancestunesmap' VALUES (92, 365, 83, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7746, 778, 2168, 10, '');
INSERT INTO 'dancestunesmap' VALUES (12, 55, 14, 10, '');
INSERT INTO 'dancestunesmap' VALUES (24, 93, 1651, 10, '');
INSERT INTO 'dancestunesmap' VALUES (38, 155, 44, 10, '');
INSERT INTO 'dancestunesmap' VALUES (55, 219, 54, 10, '');
INSERT INTO 'dancestunesmap' VALUES (163, 656, 1276, 10, '');
INSERT INTO 'dancestunesmap' VALUES (170, 674, 160, 10, '');
INSERT INTO 'dancestunesmap' VALUES (121, 445, 537, 10, '');
INSERT INTO 'dancestunesmap' VALUES (14, 68, 673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (127, 491, 113, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7742, 5766, 4483, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7740, 5421, 4435, 10, '');
INSERT INTO 'dancestunesmap' VALUES (117, 441, 1067, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7739, 5402, 4429, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7738, 5358, 9623, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7733, 2970, 3801, 10, '');
INSERT INTO 'dancestunesmap' VALUES (113, 430, 1644, 10, '');
INSERT INTO 'dancestunesmap' VALUES (21, 81, 1812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7747, 1034, 2022, 10, '');
INSERT INTO 'dancestunesmap' VALUES (175, 687, 1496, 10, '');
INSERT INTO 'dancestunesmap' VALUES (172, 680, 1542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (169, 671, 146, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7745, 655, 3353, 10, '');
INSERT INTO 'dancestunesmap' VALUES (162, 654, 346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (151, 598, 132, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7743, 578, 8177, 10, '');
INSERT INTO 'dancestunesmap' VALUES (145, 571, 126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (142, 549, 1744, 10, '');
INSERT INTO 'dancestunesmap' VALUES (136, 530, 1118, 10, '');
INSERT INTO 'dancestunesmap' VALUES (129, 497, 269, 10, '');
INSERT INTO 'dancestunesmap' VALUES (125, 475, 773, 10, '');
INSERT INTO 'dancestunesmap' VALUES (124, 474, 1765, 10, '');
INSERT INTO 'dancestunesmap' VALUES (118, 442, 46, 10, '');
INSERT INTO 'dancestunesmap' VALUES (106, 407, 96, 10, '');
INSERT INTO 'dancestunesmap' VALUES (104, 400, 95, 10, '');
INSERT INTO 'dancestunesmap' VALUES (95, 377, 1284, 10, '');
INSERT INTO 'dancestunesmap' VALUES (86, 340, 1530, 10, '');
INSERT INTO 'dancestunesmap' VALUES (84, 335, 818, 10, '');
INSERT INTO 'dancestunesmap' VALUES (81, 326, 489, 10, '');
INSERT INTO 'dancestunesmap' VALUES (64, 274, 1629, 10, '');
INSERT INTO 'dancestunesmap' VALUES (34, 140, 36, 10, '');
INSERT INTO 'dancestunesmap' VALUES (157, 627, 144, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7755, 3585, 2385, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7768, 5754, 4481, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7773, 7173, 2994, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7775, 12023, 1093, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7779, 11997, 9518, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7780, 11998, 9522, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7781, 11999, 8828, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7782, 11994, 9523, 10, '');
INSERT INTO 'dancestunesmap' VALUES (189, 741, 178, 10, '');
INSERT INTO 'dancestunesmap' VALUES (190, 741, 308, 10, '');
INSERT INTO 'dancestunesmap' VALUES (37, 153, 41, 10, '');
INSERT INTO 'dancestunesmap' VALUES (72, 301, 764, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7741, 5688, 2050, 10, '');
INSERT INTO 'dancestunesmap' VALUES (133, 521, 1834, 10, '');
INSERT INTO 'dancestunesmap' VALUES (69, 282, 1198, 10, '');
INSERT INTO 'dancestunesmap' VALUES (105, 401, 660, 10, '');
INSERT INTO 'dancestunesmap' VALUES (66, 275, 1038, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7, 43, 12, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8, 43, 1128, 11, '');
INSERT INTO 'dancestunesmap' VALUES (7754, 3529, 492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (62, 245, 1018, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7748, 1019, 2019, 10, '');
INSERT INTO 'dancestunesmap' VALUES (192, 743, 179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (193, 745, 180, 10, '');
INSERT INTO 'dancestunesmap' VALUES (205, 775, 758, 10, '');
INSERT INTO 'dancestunesmap' VALUES (206, 775, 1257, 10, '');
INSERT INTO 'dancestunesmap' VALUES (207, 783, 527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (208, 783, 776, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10238, 18235, 3165, 10, '');
INSERT INTO 'dancestunesmap' VALUES (256, 949, 256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (265, 981, 1438, 10, '');
INSERT INTO 'dancestunesmap' VALUES (271, 993, 1623, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7784, 12000, 9526, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7786, 11992, 9528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7787, 11993, 9529, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7788, 11991, 9638, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7789, 11995, 744, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7798, 12536, 1921, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7799, 3587, 2963, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7800, 12537, 1051, 10, '');
INSERT INTO 'dancestunesmap' VALUES (219, 816, 196, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7804, 12540, 1024, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7806, 12289, 2855, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7809, 12544, 7237, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7812, 12570, 512, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7816, 12573, 5999, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7821, 12593, 9648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7823, 12604, 9020, 10, '');
INSERT INTO 'dancestunesmap' VALUES (196, 754, 183, 10, '');
INSERT INTO 'dancestunesmap' VALUES (272, 1002, 838, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7792, 12002, 186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (203, 773, 1766, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7802, 12538, 9644, 10, '');
INSERT INTO 'dancestunesmap' VALUES (243, 902, 347, 10, '');
INSERT INTO 'dancestunesmap' VALUES (266, 984, 1499, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7762, 4434, 1615, 11, 'As per the Ashley Album, and SCD#8, p15.');
INSERT INTO 'dancestunesmap' VALUES (275, 1015, 1750, 10, '');
INSERT INTO 'dancestunesmap' VALUES (232, 881, 78, 10, '');
INSERT INTO 'dancestunesmap' VALUES (218, 812, 1382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (183, 716, 857, 10, '');
INSERT INTO 'dancestunesmap' VALUES (238, 894, 216, 1, '');
INSERT INTO 'dancestunesmap' VALUES (7819, 12580, 9650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7791, 12002, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (187, 738, 176, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7820, 12600, 9652, 10, '');
INSERT INTO 'dancestunesmap' VALUES (233, 887, 1096, 10, '');
INSERT INTO 'dancestunesmap' VALUES (188, 739, 1682, 10, '');
INSERT INTO 'dancestunesmap' VALUES (273, 1007, 246, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7777, 12528, 8285, 10, 'The Falkirk Millennium Wheel played by Gordon Shand Band');
INSERT INTO 'dancestunesmap' VALUES (7778, 9867, 9515, 10, '');
INSERT INTO 'dancestunesmap' VALUES (231, 877, 589, 10, '');
INSERT INTO 'dancestunesmap' VALUES (199, 763, 66, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7776, 12508, 121, 10, '');
INSERT INTO 'dancestunesmap' VALUES (185, 732, 671, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7803, 12539, 5708, 10, '');
INSERT INTO 'dancestunesmap' VALUES (254, 940, 573, 10, '');
INSERT INTO 'dancestunesmap' VALUES (248, 909, 807, 10, 'Customary “original” tune');
INSERT INTO 'dancestunesmap' VALUES (294, 1060, 261, 10, '');
INSERT INTO 'dancestunesmap' VALUES (305, 1094, 268, 10, '');
INSERT INTO 'dancestunesmap' VALUES (204, 774, 963, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7764, 4638, 4281, 10, '');
INSERT INTO 'dancestunesmap' VALUES (222, 833, 239, 10, '');
INSERT INTO 'dancestunesmap' VALUES (236, 890, 519, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7769, 5889, 4509, 10, '');
INSERT INTO 'dancestunesmap' VALUES (195, 753, 1062, 10, '');
INSERT INTO 'dancestunesmap' VALUES (202, 769, 186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7771, 6061, 4532, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7795, 10590, 8267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7810, 12567, 1448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (212, 794, 1425, 10, '');
INSERT INTO 'dancestunesmap' VALUES (241, 899, 1295, 11, '');
INSERT INTO 'dancestunesmap' VALUES (7753, 3424, 3997, 10, '');
INSERT INTO 'dancestunesmap' VALUES (291, 1051, 425, 10, '');
INSERT INTO 'dancestunesmap' VALUES (211, 784, 1536, 10, '');
INSERT INTO 'dancestunesmap' VALUES (250, 924, 1069, 10, '');
INSERT INTO 'dancestunesmap' VALUES (267, 985, 601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (399, 1447, 1737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (244, 905, 220, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7766, 4932, 4341, 10, '');
INSERT INTO 'dancestunesmap' VALUES (298, 1071, 1647, 10, '');
INSERT INTO 'dancestunesmap' VALUES (285, 1032, 166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (234, 888, 215, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7793, 11746, 9639, 10, '');
INSERT INTO 'dancestunesmap' VALUES (230, 875, 1582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (194, 752, 182, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7818, 12577, 9649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7811, 12568, 371, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7805, 12416, 6378, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7807, 12216, 320, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7785, 12001, 9527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7790, 11996, 445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7797, 11748, 9642, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7794, 11747, 9640, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7822, 10572, 9657, 10, '');
INSERT INTO 'dancestunesmap' VALUES (191, 742, 1349, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7783, 10501, 9525, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7813, 12569, 413, 1, '');
INSERT INTO 'dancestunesmap' VALUES (225, 845, 67, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7774, 7073, 2976, 10, '');
INSERT INTO 'dancestunesmap' VALUES (237, 893, 1831, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7767, 5028, 4358, 10, '');
INSERT INTO 'dancestunesmap' VALUES (216, 805, 1042, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7760, 4196, 4192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7759, 3931, 4074, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7758, 3723, 2565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7757, 3638, 1737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7756, 3595, 2185, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7752, 2781, 2087, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7750, 1909, 1459, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7765, 4919, 687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7749, 1367, 3594, 10, '');
INSERT INTO 'dancestunesmap' VALUES (249, 910, 447, 10, '');
INSERT INTO 'dancestunesmap' VALUES (306, 1096, 727, 10, '');
INSERT INTO 'dancestunesmap' VALUES (302, 1074, 452, 10, '');
INSERT INTO 'dancestunesmap' VALUES (299, 1072, 263, 10, '');
INSERT INTO 'dancestunesmap' VALUES (296, 1068, 262, 10, '');
INSERT INTO 'dancestunesmap' VALUES (300, 1073, 264, 10, '');
INSERT INTO 'dancestunesmap' VALUES (301, 1073, 1196, 10, '');
INSERT INTO 'dancestunesmap' VALUES (295, 1066, 1266, 10, '');
INSERT INTO 'dancestunesmap' VALUES (284, 1029, 1538, 10, '');
INSERT INTO 'dancestunesmap' VALUES (283, 1022, 255, 10, '');
INSERT INTO 'dancestunesmap' VALUES (280, 1020, 897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (278, 1018, 253, 10, '');
INSERT INTO 'dancestunesmap' VALUES (279, 1018, 475, 11, '');
INSERT INTO 'dancestunesmap' VALUES (276, 1017, 251, 10, '');
INSERT INTO 'dancestunesmap' VALUES (277, 1017, 307, 11, '');
INSERT INTO 'dancestunesmap' VALUES (269, 992, 94, 10, '');
INSERT INTO 'dancestunesmap' VALUES (270, 992, 335, 10, '');
INSERT INTO 'dancestunesmap' VALUES (263, 980, 236, 10, '');
INSERT INTO 'dancestunesmap' VALUES (261, 974, 931, 10, '');
INSERT INTO 'dancestunesmap' VALUES (260, 972, 773, 11, '');
INSERT INTO 'dancestunesmap' VALUES (258, 958, 328, 10, '');
INSERT INTO 'dancestunesmap' VALUES (255, 942, 287, 10, '');
INSERT INTO 'dancestunesmap' VALUES (235, 889, 1206, 10, '');
INSERT INTO 'dancestunesmap' VALUES (228, 852, 597, 10, '');
INSERT INTO 'dancestunesmap' VALUES (226, 848, 1721, 10, '');
INSERT INTO 'dancestunesmap' VALUES (223, 842, 204, 10, '');
INSERT INTO 'dancestunesmap' VALUES (220, 819, 198, 10, '');
INSERT INTO 'dancestunesmap' VALUES (217, 807, 237, 10, '');
INSERT INTO 'dancestunesmap' VALUES (165, 662, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7824, 12663, 1405, 10, '');
INSERT INTO 'dancestunesmap' VALUES (317, 1144, 695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (318, 1144, 781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (325, 1177, 218, 10, '');
INSERT INTO 'dancestunesmap' VALUES (331, 1210, 283, 10, '');
INSERT INTO 'dancestunesmap' VALUES (334, 1233, 1116, 10, '');
INSERT INTO 'dancestunesmap' VALUES (336, 1240, 1, 10, '');
INSERT INTO 'dancestunesmap' VALUES (337, 1244, 173, 10, '');
INSERT INTO 'dancestunesmap' VALUES (340, 1260, 272, 10, '');
INSERT INTO 'dancestunesmap' VALUES (341, 1260, 294, 10, '');
INSERT INTO 'dancestunesmap' VALUES (348, 1284, 641, 10, '');
INSERT INTO 'dancestunesmap' VALUES (349, 1291, 793, 10, '');
INSERT INTO 'dancestunesmap' VALUES (352, 1299, 312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (353, 1299, 782, 10, '');
INSERT INTO 'dancestunesmap' VALUES (363, 1348, 318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (370, 1375, 331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7843, 11735, 9742, 10, '');
INSERT INTO 'dancestunesmap' VALUES (240, 896, 217, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7815, 12166, 9646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7808, 12542, 9645, 10, '');
INSERT INTO 'dancestunesmap' VALUES (268, 986, 12082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (245, 907, 143, 10, '');
INSERT INTO 'dancestunesmap' VALUES (253, 936, 1316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (246, 907, 221, 10, '');
INSERT INTO 'dancestunesmap' VALUES (239, 895, 1467, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7838, 12691, 8842, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7829, 12682, 9695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7796, 11530, 9641, 10, '');
INSERT INTO 'dancestunesmap' VALUES (229, 862, 210, 10, '');
INSERT INTO 'dancestunesmap' VALUES (322, 1163, 742, 10, '');
INSERT INTO 'dancestunesmap' VALUES (357, 1307, 314, 10, '');
INSERT INTO 'dancestunesmap' VALUES (330, 1195, 1331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (319, 1145, 402, 10, '');
INSERT INTO 'dancestunesmap' VALUES (307, 1097, 959, 10, '');
INSERT INTO 'dancestunesmap' VALUES (293, 1059, 260, 10, '');
INSERT INTO 'dancestunesmap' VALUES (251, 934, 1805, 10, '');
INSERT INTO 'dancestunesmap' VALUES (221, 827, 398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (201, 767, 1528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (198, 762, 185, 10, '');
INSERT INTO 'dancestunesmap' VALUES (197, 760, 392, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7844, 10090, 9743, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7845, 11736, 9737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7846, 11737, 9744, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7847, 7856, 9745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7848, 11738, 9746, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7853, 1947, 3027, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7860, 12738, 9803, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7864, 12741, 9807, 10, '');
INSERT INTO 'dancestunesmap' VALUES (373, 1379, 1257, 10, '');
INSERT INTO 'dancestunesmap' VALUES (376, 1386, 80, 10, '');
INSERT INTO 'dancestunesmap' VALUES (385, 1410, 1099, 10, '');
INSERT INTO 'dancestunesmap' VALUES (383, 1406, 420, 10, '');
INSERT INTO 'dancestunesmap' VALUES (414, 1478, 350, 10, '');
INSERT INTO 'dancestunesmap' VALUES (415, 1480, 1828, 10, '');
INSERT INTO 'dancestunesmap' VALUES (427, 1542, 1748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (313, 1125, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7862, 12740, 9805, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7858, 12736, 9801, 10, '');
INSERT INTO 'dancestunesmap' VALUES (332, 1218, 285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (393, 1430, 1200, 10, '');
INSERT INTO 'dancestunesmap' VALUES (314, 1128, 1648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (343, 1274, 300, 10, '');
INSERT INTO 'dancestunesmap' VALUES (362, 1323, 141, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7861, 12739, 9804, 10, '');
INSERT INTO 'dancestunesmap' VALUES (308, 1100, 269, 10, '');
INSERT INTO 'dancestunesmap' VALUES (387, 1415, 1343, 11, '');
INSERT INTO 'dancestunesmap' VALUES (333, 1227, 721, 1, '');
INSERT INTO 'dancestunesmap' VALUES (390, 1425, 657, 10, '');
INSERT INTO 'dancestunesmap' VALUES (292, 1058, 666, 10, '');
INSERT INTO 'dancestunesmap' VALUES (409, 1470, 240, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7851, 7311, 9760, 10, '');
INSERT INTO 'dancestunesmap' VALUES (360, 1318, 1731, 10, '');
INSERT INTO 'dancestunesmap' VALUES (359, 1318, 1585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (426, 1539, 267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (423, 1507, 790, 10, '');
INSERT INTO 'dancestunesmap' VALUES (380, 1399, 839, 10, '');
INSERT INTO 'dancestunesmap' VALUES (379, 1393, 336, 10, '');
INSERT INTO 'dancestunesmap' VALUES (372, 1378, 369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (361, 1319, 1588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (290, 1050, 1455, 10, '');
INSERT INTO 'dancestunesmap' VALUES (289, 1045, 258, 10, '');
INSERT INTO 'dancestunesmap' VALUES (288, 1045, 59, 10, '');
INSERT INTO 'dancestunesmap' VALUES (417, 1495, 361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (405, 1465, 1576, 10, '');
INSERT INTO 'dancestunesmap' VALUES (377, 1387, 334, 10, '');
INSERT INTO 'dancestunesmap' VALUES (389, 1424, 562, 10, '');
INSERT INTO 'dancestunesmap' VALUES (432, 1548, 1413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (446, 1588, 381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (447, 1593, 968, 10, '');
INSERT INTO 'dancestunesmap' VALUES (451, 1617, 1609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (456, 1632, 1031, 10, '');
INSERT INTO 'dancestunesmap' VALUES (459, 1641, 340, 10, '');
INSERT INTO 'dancestunesmap' VALUES (461, 1659, 168, 10, '');
INSERT INTO 'dancestunesmap' VALUES (462, 1659, 259, 10, '');
INSERT INTO 'dancestunesmap' VALUES (316, 1142, 109, 10, '');
INSERT INTO 'dancestunesmap' VALUES (378, 1392, 187, 10, '');
INSERT INTO 'dancestunesmap' VALUES (358, 1315, 454, 10, '');
INSERT INTO 'dancestunesmap' VALUES (455, 1625, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7854, 12719, 9769, 10, '');
INSERT INTO 'dancestunesmap' VALUES (408, 1469, 506, 10, '');
INSERT INTO 'dancestunesmap' VALUES (304, 1077, 267, 1, '');
INSERT INTO 'dancestunesmap' VALUES (347, 1283, 1002, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7839, 12692, 5852, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7841, 12694, 9700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7828, 12681, 9694, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7868, 12745, 9811, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7867, 12744, 9810, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7866, 12743, 9809, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7865, 12742, 9808, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7840, 12693, 9699, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7837, 12690, 9698, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7835, 12688, 9697, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7834, 12687, 2649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7833, 12686, 4953, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7832, 12685, 2523, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7831, 12684, 9696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7830, 12683, 7806, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7863, 12675, 9806, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7826, 12672, 5168, 10, '');
INSERT INTO 'dancestunesmap' VALUES (303, 1075, 265, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7856, 11801, 3179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7857, 11704, 1331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (374, 1383, 333, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7859, 12737, 9802, 10, '');
INSERT INTO 'dancestunesmap' VALUES (429, 1544, 371, 10, '');
INSERT INTO 'dancestunesmap' VALUES (422, 1505, 867, 10, '');
INSERT INTO 'dancestunesmap' VALUES (354, 1300, 297, 10, 'preferred');
INSERT INTO 'dancestunesmap' VALUES (442, 1579, 133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (440, 1564, 316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (438, 1558, 372, 10, '');
INSERT INTO 'dancestunesmap' VALUES (431, 1547, 1045, 10, '');
INSERT INTO 'dancestunesmap' VALUES (428, 1543, 135, 10, '');
INSERT INTO 'dancestunesmap' VALUES (421, 1501, 364, 10, '');
INSERT INTO 'dancestunesmap' VALUES (419, 1498, 1365, 10, '');
INSERT INTO 'dancestunesmap' VALUES (418, 1496, 362, 10, '');
INSERT INTO 'dancestunesmap' VALUES (412, 1475, 1784, 10, '');
INSERT INTO 'dancestunesmap' VALUES (407, 1467, 320, 10, '');
INSERT INTO 'dancestunesmap' VALUES (404, 1457, 1363, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7849, 12302, 9747, 10, '');
INSERT INTO 'dancestunesmap' VALUES (398, 1446, 9, 10, '');
INSERT INTO 'dancestunesmap' VALUES (394, 1431, 343, 10, '');
INSERT INTO 'dancestunesmap' VALUES (395, 1431, 654, 11, '');
INSERT INTO 'dancestunesmap' VALUES (391, 1427, 342, 10, '');
INSERT INTO 'dancestunesmap' VALUES (384, 1409, 766, 10, '');
INSERT INTO 'dancestunesmap' VALUES (371, 1376, 1288, 10, '');
INSERT INTO 'dancestunesmap' VALUES (367, 1366, 902, 11, '');
INSERT INTO 'dancestunesmap' VALUES (365, 1359, 861, 10, '');
INSERT INTO 'dancestunesmap' VALUES (364, 1350, 320, 10, '');
INSERT INTO 'dancestunesmap' VALUES (351, 1296, 310, 10, '');
INSERT INTO 'dancestunesmap' VALUES (350, 1293, 851, 10, '');
INSERT INTO 'dancestunesmap' VALUES (346, 1280, 825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (339, 1252, 682, 10, '');
INSERT INTO 'dancestunesmap' VALUES (338, 1246, 290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (323, 1171, 1215, 10, '');
INSERT INTO 'dancestunesmap' VALUES (368, 1368, 327, 10, '');
INSERT INTO 'dancestunesmap' VALUES (320, 1154, 1210, 10, '');
INSERT INTO 'dancestunesmap' VALUES (315, 1141, 662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (310, 1103, 1399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (400, 1451, 123, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7850, 9420, 9750, 10, '');
INSERT INTO 'dancestunesmap' VALUES (356, 1304, 1194, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7901, 12778, 1059, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7902, 8044, 318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (435, 1551, 1233, 10, '');
INSERT INTO 'dancestunesmap' VALUES (498, 1799, 451, 10, '');
INSERT INTO 'dancestunesmap' VALUES (500, 1809, 455, 10, '');
INSERT INTO 'dancestunesmap' VALUES (505, 1820, 1300, 10, '');
INSERT INTO 'dancestunesmap' VALUES (443, 1582, 382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (444, 1582, 706, 11, '');
INSERT INTO 'dancestunesmap' VALUES (529, 1895, 62, 10, '');
INSERT INTO 'dancestunesmap' VALUES (539, 1930, 609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (541, 1936, 1728, 10, '');
INSERT INTO 'dancestunesmap' VALUES (542, 1936, 1729, 10, '');
INSERT INTO 'dancestunesmap' VALUES (563, 2053, 500, 10, '');
INSERT INTO 'dancestunesmap' VALUES (564, 2055, 405, 10, '');
INSERT INTO 'dancestunesmap' VALUES (502, 1817, 458, 1, '');
INSERT INTO 'dancestunesmap' VALUES (565, 2055, 501, 10, '');
INSERT INTO 'dancestunesmap' VALUES (569, 2074, 503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (570, 2074, 1696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (573, 2082, 951, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7890, 12765, 9823, 10, '');
INSERT INTO 'dancestunesmap' VALUES (476, 1758, 419, 10, '');
INSERT INTO 'dancestunesmap' VALUES (463, 1672, 445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7892, 12767, 9825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7900, 3593, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (424, 1508, 91, 10, '');
INSERT INTO 'dancestunesmap' VALUES (369, 1372, 1625, 10, '');
INSERT INTO 'dancestunesmap' VALUES (458, 1639, 398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (439, 1562, 374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (510, 1841, 2037, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7842, 12695, 9701, 10, '');
INSERT INTO 'dancestunesmap' VALUES (287, 1039, 993, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7882, 12758, 5134, 10, '');
INSERT INTO 'dancestunesmap' VALUES (381, 1400, 1338, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7852, 4797, 7176, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7895, 6204, 52, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7869, 12746, 9812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7870, 12747, 3901, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7879, 12755, 9814, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7872, 12749, 2115, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7874, 12751, 2123, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7880, 12756, 3908, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7876, 12752, 649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7871, 12748, 7661, 10, '');
INSERT INTO 'dancestunesmap' VALUES (528, 1891, 1179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (457, 1635, 1424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (448, 1595, 436, 10, '');
INSERT INTO 'dancestunesmap' VALUES (441, 1578, 378, 10, '');
INSERT INTO 'dancestunesmap' VALUES (420, 1499, 1817, 10, '');
INSERT INTO 'dancestunesmap' VALUES (416, 1488, 354, 10, '');
INSERT INTO 'dancestunesmap' VALUES (413, 1476, 349, 10, '');
INSERT INTO 'dancestunesmap' VALUES (401, 1452, 863, 10, '');
INSERT INTO 'dancestunesmap' VALUES (397, 1437, 344, 10, '');
INSERT INTO 'dancestunesmap' VALUES (396, 1437, 143, 11, '');
INSERT INTO 'dancestunesmap' VALUES (392, 1428, 342, 10, '');
INSERT INTO 'dancestunesmap' VALUES (382, 1405, 1762, 10, '');
INSERT INTO 'dancestunesmap' VALUES (375, 1384, 1298, 10, '');
INSERT INTO 'dancestunesmap' VALUES (335, 1238, 1181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (342, 1261, 295, 10, '');
INSERT INTO 'dancestunesmap' VALUES (329, 1195, 382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (483, 1775, 439, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7909, 12635, 6462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (550, 1985, 166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (460, 1647, 247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (523, 1876, 476, 10, '');
INSERT INTO 'dancestunesmap' VALUES (501, 1816, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8456, 13908, 11621, 10, '');
INSERT INTO 'dancestunesmap' VALUES (506, 1821, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (514, 1854, 474, 10, '');
INSERT INTO 'dancestunesmap' VALUES (472, 1729, 1205, 10, '');
INSERT INTO 'dancestunesmap' VALUES (471, 1729, 409, 10, '');
INSERT INTO 'dancestunesmap' VALUES (536, 1916, 486, 10, '');
INSERT INTO 'dancestunesmap' VALUES (485, 1777, 431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7887, 12762, 9820, 10, '');
INSERT INTO 'dancestunesmap' VALUES (494, 1792, 202, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7896, 7274, 9755, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7886, 12761, 9819, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7883, 12759, 9816, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7889, 12764, 9822, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7893, 12768, 9826, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7894, 7296, 9839, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7888, 12763, 9821, 10, '');
INSERT INTO 'dancestunesmap' VALUES (522, 1873, 1613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10095, 17896, 6574, 10, '');
INSERT INTO 'dancestunesmap' VALUES (562, 2052, 397, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7885, 12760, 9818, 10, '');
INSERT INTO 'dancestunesmap' VALUES (450, 1615, 385, 10, '');
INSERT INTO 'dancestunesmap' VALUES (535, 1913, 1555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (534, 1913, 1258, 10, '');
INSERT INTO 'dancestunesmap' VALUES (473, 1731, 1662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (452, 1621, 1657, 10, '');
INSERT INTO 'dancestunesmap' VALUES (507, 1833, 461, 10, '');
INSERT INTO 'dancestunesmap' VALUES (487, 1781, 515, 2, 'ABCABC');
INSERT INTO 'dancestunesmap' VALUES (434, 1551, 924, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7921, 12814, 8165, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7922, 12815, 3206, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7927, 12826, 9870, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7931, 7278, 3718, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7934, 12834, 1687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7939, 12843, 9884, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7940, 12844, 9885, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7941, 12847, 9886, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7942, 12851, 9887, 10, '');
INSERT INTO 'dancestunesmap' VALUES (575, 2085, 1165, 10, '');
INSERT INTO 'dancestunesmap' VALUES (576, 2099, 510, 10, '');
INSERT INTO 'dancestunesmap' VALUES (579, 2116, 81, 10, '');
INSERT INTO 'dancestunesmap' VALUES (580, 2136, 1444, 10, '');
INSERT INTO 'dancestunesmap' VALUES (587, 2166, 598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (588, 2166, 685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (595, 2178, 1687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (598, 2190, 310, 10, '');
INSERT INTO 'dancestunesmap' VALUES (599, 2190, 1290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (601, 2210, 1158, 10, '');
INSERT INTO 'dancestunesmap' VALUES (602, 2210, 1330, 10, '');
INSERT INTO 'dancestunesmap' VALUES (603, 2219, 979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7928, 12828, 9880, 10, '');
INSERT INTO 'dancestunesmap' VALUES (491, 1782, 441, 10, '');
INSERT INTO 'dancestunesmap' VALUES (607, 2247, 285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (499, 1806, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (482, 1773, 432, 10, '');
INSERT INTO 'dancestunesmap' VALUES (467, 1701, 1716, 10, '');
INSERT INTO 'dancestunesmap' VALUES (553, 2010, 1739, 10, '');
INSERT INTO 'dancestunesmap' VALUES (492, 1783, 120, 10, '');
INSERT INTO 'dancestunesmap' VALUES (556, 2024, 520, 10, '');
INSERT INTO 'dancestunesmap' VALUES (512, 1848, 466, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7903, 7935, 9840, 10, '');
INSERT INTO 'dancestunesmap' VALUES (474, 1751, 414, 10, '');
INSERT INTO 'dancestunesmap' VALUES (508, 1838, 1721, 10, '');
INSERT INTO 'dancestunesmap' VALUES (509, 1840, 1615, 10, '');
INSERT INTO 'dancestunesmap' VALUES (552, 2008, 1336, 10, '');
INSERT INTO 'dancestunesmap' VALUES (567, 2069, 1086, 10, '');
INSERT INTO 'dancestunesmap' VALUES (566, 2063, 188, 10, '');
INSERT INTO 'dancestunesmap' VALUES (623, 2305, 1459, 10, '');
INSERT INTO 'dancestunesmap' VALUES (679, 2485, 584, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7925, 12821, 778, 10, '');
INSERT INTO 'dancestunesmap' VALUES (481, 1768, 427, 10, '');
INSERT INTO 'dancestunesmap' VALUES (594, 2173, 525, 10, '');
INSERT INTO 'dancestunesmap' VALUES (480, 1767, 1299, 10, '');
INSERT INTO 'dancestunesmap' VALUES (493, 1790, 446, 10, '');
INSERT INTO 'dancestunesmap' VALUES (524, 1881, 1340, 10, '');
INSERT INTO 'dancestunesmap' VALUES (543, 1937, 1358, 10, '');
INSERT INTO 'dancestunesmap' VALUES (574, 2084, 1557, 10, '');
INSERT INTO 'dancestunesmap' VALUES (503, 1818, 346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7935, 12836, 5821, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7917, 12809, 9869, 10, '');
INSERT INTO 'dancestunesmap' VALUES (596, 2189, 528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7907, 12634, 9844, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7910, 12636, 7216, 10, '');
INSERT INTO 'dancestunesmap' VALUES (479, 1763, 425, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7936, 11990, 7680, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7933, 11629, 5390, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7930, 10014, 8170, 10, '');
INSERT INTO 'dancestunesmap' VALUES (466, 1698, 405, 10, '');
INSERT INTO 'dancestunesmap' VALUES (533, 1908, 485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (532, 1907, 276, 10, '');
INSERT INTO 'dancestunesmap' VALUES (516, 1862, 1289, 10, '');
INSERT INTO 'dancestunesmap' VALUES (430, 1544, 1769, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7911, 12637, 9846, 10, '');
INSERT INTO 'dancestunesmap' VALUES (585, 2157, 1810, 10, '');
INSERT INTO 'dancestunesmap' VALUES (572, 2079, 513, 10, '');
INSERT INTO 'dancestunesmap' VALUES (559, 2042, 762, 10, '');
INSERT INTO 'dancestunesmap' VALUES (558, 2033, 849, 10, '');
INSERT INTO 'dancestunesmap' VALUES (548, 1966, 497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (547, 1965, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (546, 1961, 490, 10, '');
INSERT INTO 'dancestunesmap' VALUES (540, 1931, 382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (527, 1884, 480, 10, '');
INSERT INTO 'dancestunesmap' VALUES (520, 1866, 472, 10, '');
INSERT INTO 'dancestunesmap' VALUES (515, 1857, 1609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (511, 1847, 542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (486, 1780, 730, 10, '');
INSERT INTO 'dancestunesmap' VALUES (477, 1762, 424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (475, 1757, 418, 10, '');
INSERT INTO 'dancestunesmap' VALUES (470, 1722, 958, 10, '');
INSERT INTO 'dancestunesmap' VALUES (469, 1707, 322, 10, '');
INSERT INTO 'dancestunesmap' VALUES (464, 1677, 396, 10, '');
INSERT INTO 'dancestunesmap' VALUES (465, 1677, 1203, 11, '');
INSERT INTO 'dancestunesmap' VALUES (449, 1596, 407, 10, '');
INSERT INTO 'dancestunesmap' VALUES (560, 2044, 497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (545, 1952, 2179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (561, 2045, 186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (608, 2249, 26, 10, '');
INSERT INTO 'dancestunesmap' VALUES (613, 2265, 1822, 10, '');
INSERT INTO 'dancestunesmap' VALUES (624, 2309, 688, 10, '');
INSERT INTO 'dancestunesmap' VALUES (664, 2436, 568, 10, '');
INSERT INTO 'dancestunesmap' VALUES (629, 2326, 1183, 10, '');
INSERT INTO 'dancestunesmap' VALUES (645, 2388, 273, 10, '');
INSERT INTO 'dancestunesmap' VALUES (646, 2388, 855, 10, '');
INSERT INTO 'dancestunesmap' VALUES (648, 2390, 1225, 10, '');
INSERT INTO 'dancestunesmap' VALUES (650, 2408, 559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (655, 2420, 694, 10, '');
INSERT INTO 'dancestunesmap' VALUES (662, 2434, 1238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (663, 2434, 1241, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7946, 12858, 9891, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7947, 12860, 9892, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7950, 12864, 9895, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7951, 12865, 9896, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7974, 12945, 1294, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7978, 3712, 109, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7979, 7609, 1122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7980, 4706, 2737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7981, 7931, 68, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7982, 7760, 850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7983, 7618, 2718, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7984, 7726, 1352, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7985, 7771, 242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (667, 2440, 571, 10, '');
INSERT INTO 'dancestunesmap' VALUES (668, 2442, 829, 10, '');
INSERT INTO 'dancestunesmap' VALUES (672, 2466, 576, 10, '');
INSERT INTO 'dancestunesmap' VALUES (676, 2474, 579, 10, '');
INSERT INTO 'dancestunesmap' VALUES (677, 2476, 133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7908, 11908, 9845, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7906, 12633, 9843, 10, '');
INSERT INTO 'dancestunesmap' VALUES (554, 2021, 495, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7904, 12631, 2531, 10, '');
INSERT INTO 'dancestunesmap' VALUES (328, 1195, 200, 10, '');
INSERT INTO 'dancestunesmap' VALUES (445, 1586, 1094, 10, '');
INSERT INTO 'dancestunesmap' VALUES (593, 2172, 787, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7898, 6148, 9748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (531, 1903, 484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7953, 12423, 6980, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7954, 12377, 3305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4760, 4815, 1319, 10, '');
INSERT INTO 'dancestunesmap' VALUES (630, 2332, 542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7878, 12754, 9813, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7877, 12753, 4830, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7881, 12757, 655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7875, 11703, 369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (641, 2380, 1026, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7952, 12861, 9897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (621, 2297, 740, 10, '');
INSERT INTO 'dancestunesmap' VALUES (619, 2289, 673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (586, 2158, 482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (577, 2103, 285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (557, 2030, 894, 10, '');
INSERT INTO 'dancestunesmap' VALUES (568, 2072, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7899, 1927, 4382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (513, 1852, 464, 10, '');
INSERT INTO 'dancestunesmap' VALUES (454, 1624, 1164, 11, '');
INSERT INTO 'dancestunesmap' VALUES (484, 1776, 925, 10, '');
INSERT INTO 'dancestunesmap' VALUES (683, 2494, 290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (684, 2494, 1223, 10, '');
INSERT INTO 'dancestunesmap' VALUES (685, 2496, 586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (689, 2508, 604, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7955, 12800, 9940, 10, '');
INSERT INTO 'dancestunesmap' VALUES (606, 2242, 533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (666, 2437, 271, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7913, 12793, 9847, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7920, 12813, 5127, 10, '');
INSERT INTO 'dancestunesmap' VALUES (631, 2344, 545, 10, '');
INSERT INTO 'dancestunesmap' VALUES (633, 2346, 546, 10, '');
INSERT INTO 'dancestunesmap' VALUES (678, 2481, 583, 10, '');
INSERT INTO 'dancestunesmap' VALUES (669, 2443, 572, 10, '');
INSERT INTO 'dancestunesmap' VALUES (612, 2263, 256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7914, 12794, 4766, 10, '');
INSERT INTO 'dancestunesmap' VALUES (661, 2432, 273, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7919, 12812, 1782, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7926, 12824, 2191, 10, '');
INSERT INTO 'dancestunesmap' VALUES (651, 2409, 781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (600, 2208, 1265, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7957, 12803, 9942, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7976, 12399, 2920, 10, '');
INSERT INTO 'dancestunesmap' VALUES (671, 2462, 1490, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7977, 12996, 9967, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7916, 12632, 9842, 10, '');
INSERT INTO 'dancestunesmap' VALUES (690, 2508, 1745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (694, 2521, 598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (699, 2546, 605, 10, '');
INSERT INTO 'dancestunesmap' VALUES (700, 2546, 1397, 10, '');
INSERT INTO 'dancestunesmap' VALUES (702, 2562, 1209, 10, '');
INSERT INTO 'dancestunesmap' VALUES (703, 2565, 110, 10, '');
INSERT INTO 'dancestunesmap' VALUES (710, 2600, 1674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (709, 2598, 1744, 10, '');
INSERT INTO 'dancestunesmap' VALUES (715, 2619, 1135, 10, '');
INSERT INTO 'dancestunesmap' VALUES (716, 2622, 365, 10, '');
INSERT INTO 'dancestunesmap' VALUES (722, 2646, 1186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (730, 2677, 1505, 10, '');
INSERT INTO 'dancestunesmap' VALUES (731, 2682, 627, 10, '');
INSERT INTO 'dancestunesmap' VALUES (732, 2692, 629, 10, '');
INSERT INTO 'dancestunesmap' VALUES (734, 2696, 630, 10, '');
INSERT INTO 'dancestunesmap' VALUES (735, 2696, 1818, 10, '');
INSERT INTO 'dancestunesmap' VALUES (737, 2703, 1148, 10, '');
INSERT INTO 'dancestunesmap' VALUES (747, 2728, 450, 10, '');
INSERT INTO 'dancestunesmap' VALUES (748, 2728, 1788, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7986, 3779, 5162, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7987, 8007, 1380, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7992, 12976, 9972, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7993, 9987, 2766, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7994, 13004, 9973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7996, 13069, 9975, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7965, 12885, 9951, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7944, 12855, 9889, 10, '');
INSERT INTO 'dancestunesmap' VALUES (578, 2110, 514, 10, '');
INSERT INTO 'dancestunesmap' VALUES (695, 2525, 599, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7918, 12810, 8898, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7997, 13070, 9898, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7961, 12914, 2002, 10, '');
INSERT INTO 'dancestunesmap' VALUES (618, 2288, 1683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (625, 2315, 540, 1, '');
INSERT INTO 'dancestunesmap' VALUES (634, 2349, 722, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7968, 12366, 9954, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7972, 12936, 9956, 10, '');
INSERT INTO 'dancestunesmap' VALUES (686, 2498, 588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7960, 12916, 9947, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7966, 12924, 9952, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7948, 12862, 9893, 10, '');
INSERT INTO 'dancestunesmap' VALUES (691, 2510, 394, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7964, 12921, 9950, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7937, 10458, 7453, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7969, 12930, 9955, 10, '');
INSERT INTO 'dancestunesmap' VALUES (584, 2153, 523, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7973, 12939, 9957, 10, '');
INSERT INTO 'dancestunesmap' VALUES (610, 2257, 114, 10, '');
INSERT INTO 'dancestunesmap' VALUES (611, 2257, 908, 11, '');
INSERT INTO 'dancestunesmap' VALUES (582, 2140, 1673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7956, 12802, 9941, 10, '');
INSERT INTO 'dancestunesmap' VALUES (636, 2353, 548, 10, '');
INSERT INTO 'dancestunesmap' VALUES (605, 2232, 492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (617, 2276, 535, 1, '');
INSERT INTO 'dancestunesmap' VALUES (656, 2421, 166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (660, 2431, 390, 10, '');
INSERT INTO 'dancestunesmap' VALUES (681, 2492, 1642, 10, '');
INSERT INTO 'dancestunesmap' VALUES (755, 2757, 1483, 10, '');
INSERT INTO 'dancestunesmap' VALUES (697, 2536, 1640, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7924, 2664, 3919, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7923, 2664, 1805, 10, '');
INSERT INTO 'dancestunesmap' VALUES (696, 2534, 602, 10, '');
INSERT INTO 'dancestunesmap' VALUES (756, 2757, 1814, 10, '');
INSERT INTO 'dancestunesmap' VALUES (743, 2713, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8022, 13209, 10015, 10, '');
INSERT INTO 'dancestunesmap' VALUES (609, 2250, 534, 10, '');
INSERT INTO 'dancestunesmap' VALUES (622, 2302, 539, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7995, 13056, 3613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (729, 2674, 39, 10, '');
INSERT INTO 'dancestunesmap' VALUES (652, 2415, 563, 10, '');
INSERT INTO 'dancestunesmap' VALUES (653, 2415, 1152, 11, '');
INSERT INTO 'dancestunesmap' VALUES (7975, 12962, 9966, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7967, 12927, 9953, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7945, 12856, 9890, 10, '');
INSERT INTO 'dancestunesmap' VALUES (688, 2506, 1088, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7912, 12790, 1785, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7929, 9811, 9883, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7970, 12901, 717, 10, '');
INSERT INTO 'dancestunesmap' VALUES (640, 2367, 551, 10, '');
INSERT INTO 'dancestunesmap' VALUES (754, 2753, 645, 10, '');
INSERT INTO 'dancestunesmap' VALUES (746, 2727, 638, 10, '');
INSERT INTO 'dancestunesmap' VALUES (674, 2471, 1122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (673, 2469, 1429, 10, '');
INSERT INTO 'dancestunesmap' VALUES (657, 2423, 565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (654, 2419, 564, 11, '');
INSERT INTO 'dancestunesmap' VALUES (647, 2389, 13, 10, '');
INSERT INTO 'dancestunesmap' VALUES (637, 2354, 549, 10, '');
INSERT INTO 'dancestunesmap' VALUES (635, 2352, 45, 10, '');
INSERT INTO 'dancestunesmap' VALUES (692, 2514, 664, 10, '');
INSERT INTO 'dancestunesmap' VALUES (616, 2275, 632, 10, '');
INSERT INTO 'dancestunesmap' VALUES (614, 2267, 1154, 10, '');
INSERT INTO 'dancestunesmap' VALUES (589, 2169, 1639, 10, '');
INSERT INTO 'dancestunesmap' VALUES (615, 2269, 505, 10, '');
INSERT INTO 'dancestunesmap' VALUES (717, 2629, 1361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7938, 11970, 9167, 10, '');
INSERT INTO 'dancestunesmap' VALUES (659, 2428, 1672, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7998, 13071, 9901, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7999, 13072, 5787, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8001, 13074, 9977, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8003, 3712, 58, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8004, 13076, 1424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8007, 12248, 9514, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8010, 13081, 1912, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8014, 8815, 9978, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8015, 13112, 41, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8020, 13207, 5666, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8021, 13208, 148, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8023, 13210, 10016, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8026, 12441, 9595, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8027, 13213, 9595, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8028, 13220, 202, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8029, 13224, 10044, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8032, 8701, 10046, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8033, 11743, 10048, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8035, 10611, 1565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8036, 10612, 3257, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8037, 10613, 3124, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8038, 10613, 10049, 10, '');
INSERT INTO 'dancestunesmap' VALUES (760, 2783, 378, 10, '');
INSERT INTO 'dancestunesmap' VALUES (761, 2783, 1505, 10, '');
INSERT INTO 'dancestunesmap' VALUES (762, 2796, 649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (769, 2819, 1190, 10, '');
INSERT INTO 'dancestunesmap' VALUES (773, 2824, 790, 10, '');
INSERT INTO 'dancestunesmap' VALUES (781, 2860, 672, 10, '');
INSERT INTO 'dancestunesmap' VALUES (786, 2872, 673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (787, 2874, 675, 10, '');
INSERT INTO 'dancestunesmap' VALUES (789, 2885, 679, 10, '');
INSERT INTO 'dancestunesmap' VALUES (792, 2904, 1360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (796, 2916, 226, 10, '');
INSERT INTO 'dancestunesmap' VALUES (801, 2933, 1763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (804, 2940, 1184, 10, '');
INSERT INTO 'dancestunesmap' VALUES (807, 2946, 699, 10, '');
INSERT INTO 'dancestunesmap' VALUES (821, 2986, 649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7991, 12884, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8024, 13211, 10025, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8034, 13269, 1700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (757, 2770, 1663, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7988, 10478, 824, 10, '');
INSERT INTO 'dancestunesmap' VALUES (721, 2645, 1069, 11, '');
INSERT INTO 'dancestunesmap' VALUES (7962, 12913, 9948, 10, '');
INSERT INTO 'dancestunesmap' VALUES (803, 2935, 694, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7915, 12630, 9841, 10, '');
INSERT INTO 'dancestunesmap' VALUES (687, 2501, 1218, 10, '');
INSERT INTO 'dancestunesmap' VALUES (627, 2323, 324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (708, 2595, 1636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7932, 10471, 3869, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8019, 12867, 9998, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7943, 12852, 9888, 10, '');
INSERT INTO 'dancestunesmap' VALUES (724, 2669, 625, 10, '');
INSERT INTO 'dancestunesmap' VALUES (797, 2918, 498, 10, '');
INSERT INTO 'dancestunesmap' VALUES (736, 2700, 631, 10, '');
INSERT INTO 'dancestunesmap' VALUES (805, 2941, 796, 10, '');
INSERT INTO 'dancestunesmap' VALUES (733, 2695, 1329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (726, 2673, 957, 12, '');
INSERT INTO 'dancestunesmap' VALUES (713, 2613, 615, 10, '');
INSERT INTO 'dancestunesmap' VALUES (705, 2575, 304, 10, '');
INSERT INTO 'dancestunesmap' VALUES (658, 2427, 1697, 10, '');
INSERT INTO 'dancestunesmap' VALUES (693, 2516, 596, 10, '');
INSERT INTO 'dancestunesmap' VALUES (723, 2661, 624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (749, 2737, 86, 10, '');
INSERT INTO 'dancestunesmap' VALUES (798, 2924, 804, 10, '');
INSERT INTO 'dancestunesmap' VALUES (742, 2711, 1744, 10, '');
INSERT INTO 'dancestunesmap' VALUES (820, 2984, 1790, 10, '');
INSERT INTO 'dancestunesmap' VALUES (799, 2925, 909, 10, '');
INSERT INTO 'dancestunesmap' VALUES (720, 2645, 623, 10, '');
INSERT INTO 'dancestunesmap' VALUES (753, 2747, 411, 10, '');
INSERT INTO 'dancestunesmap' VALUES (752, 2747, 111, 11, '');
INSERT INTO 'dancestunesmap' VALUES (806, 2943, 508, 10, '');
INSERT INTO 'dancestunesmap' VALUES (795, 2911, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (778, 2842, 667, 10, '');
INSERT INTO 'dancestunesmap' VALUES (774, 2825, 825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8013, 13083, 9914, 10, '');
INSERT INTO 'dancestunesmap' VALUES (810, 2956, 512, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7990, 12997, 9970, 10, '');
INSERT INTO 'dancestunesmap' VALUES (765, 2809, 38, 10, '');
INSERT INTO 'dancestunesmap' VALUES (800, 2930, 1083, 10, '');
INSERT INTO 'dancestunesmap' VALUES (750, 2739, 639, 10, '');
INSERT INTO 'dancestunesmap' VALUES (794, 2911, 842, 10, '');
INSERT INTO 'dancestunesmap' VALUES (739, 2708, 1319, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8006, 13078, 3845, 10, '');
INSERT INTO 'dancestunesmap' VALUES (704, 2574, 155, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7989, 9836, 9969, 10, '');
INSERT INTO 'dancestunesmap' VALUES (824, 2996, 716, 10, '');
INSERT INTO 'dancestunesmap' VALUES (825, 3000, 1466, 10, '');
INSERT INTO 'dancestunesmap' VALUES (827, 3018, 524, 10, '');
INSERT INTO 'dancestunesmap' VALUES (828, 3023, 541, 10, '');
INSERT INTO 'dancestunesmap' VALUES (829, 3024, 910, 10, '');
INSERT INTO 'dancestunesmap' VALUES (830, 3027, 209, 10, '');
INSERT INTO 'dancestunesmap' VALUES (831, 3027, 1687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (833, 3032, 725, 10, '');
INSERT INTO 'dancestunesmap' VALUES (835, 3040, 728, 10, '');
INSERT INTO 'dancestunesmap' VALUES (836, 3044, 1419, 10, '');
INSERT INTO 'dancestunesmap' VALUES (844, 3073, 832, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8039, 10614, 1624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8053, 13323, 916, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8059, 13328, 10057, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8067, 12433, 1778, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8069, 13333, 4372, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8070, 13334, 267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8071, 13335, 1797, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8074, 9745, 10070, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8079, 12442, 2442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8080, 12439, 10071, 10, '');
INSERT INTO 'dancestunesmap' VALUES (855, 3130, 752, 10, '');
INSERT INTO 'dancestunesmap' VALUES (858, 3148, 656, 10, '');
INSERT INTO 'dancestunesmap' VALUES (859, 3151, 1294, 10, '');
INSERT INTO 'dancestunesmap' VALUES (862, 3156, 14, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8050, 13320, 2554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (808, 2947, 700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8016, 8932, 9979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8011, 13082, 1651, 10, '');
INSERT INTO 'dancestunesmap' VALUES (802, 2934, 7568, 10, '');
INSERT INTO 'dancestunesmap' VALUES (759, 2780, 532, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8008, 13079, 2892, 10, '');
INSERT INTO 'dancestunesmap' VALUES (706, 2593, 610, 10, '');
INSERT INTO 'dancestunesmap' VALUES (766, 2812, 654, 10, '');
INSERT INTO 'dancestunesmap' VALUES (843, 3063, 1704, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8065, 6687, 1812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (102, 399, 451, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8041, 11807, 2072, 10, '');
INSERT INTO 'dancestunesmap' VALUES (701, 2552, 318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (698, 2544, 604, 10, '');
INSERT INTO 'dancestunesmap' VALUES (790, 2890, 680, 10, '');
INSERT INTO 'dancestunesmap' VALUES (780, 2849, 670, 10, '');
INSERT INTO 'dancestunesmap' VALUES (763, 2806, 652, 10, '');
INSERT INTO 'dancestunesmap' VALUES (861, 3154, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8025, 13212, 10026, 10, '');
INSERT INTO 'dancestunesmap' VALUES (823, 2992, 713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8002, 13075, 9904, 10, '');
INSERT INTO 'dancestunesmap' VALUES (741, 2709, 1592, 10, '');
INSERT INTO 'dancestunesmap' VALUES (771, 2822, 1575, 10, '');
INSERT INTO 'dancestunesmap' VALUES (791, 2900, 683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (815, 2962, 702, 10, '');
INSERT INTO 'dancestunesmap' VALUES (850, 3108, 1036, 10, '');
INSERT INTO 'dancestunesmap' VALUES (894, 3281, 1021, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8030, 13228, 9892, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8031, 13233, 10045, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8018, 13128, 9996, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8009, 13080, 9676, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8000, 13073, 9976, 10, '');
INSERT INTO 'dancestunesmap' VALUES (816, 2978, 708, 10, '');
INSERT INTO 'dancestunesmap' VALUES (719, 2644, 622, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8017, 12696, 9999, 10, '');
INSERT INTO 'dancestunesmap' VALUES (712, 2607, 1093, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8072, 9584, 10069, 10, '');
INSERT INTO 'dancestunesmap' VALUES (768, 2813, 975, 20, '');
INSERT INTO 'dancestunesmap' VALUES (8044, 2491, 2574, 10, '');
INSERT INTO 'dancestunesmap' VALUES (777, 2840, 668, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8068, 6563, 2473, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8060, 4181, 10065, 10, '');
INSERT INTO 'dancestunesmap' VALUES (860, 3152, 755, 10, '');
INSERT INTO 'dancestunesmap' VALUES (845, 3084, 194, 10, '');
INSERT INTO 'dancestunesmap' VALUES (764, 2807, 552, 10, '');
INSERT INTO 'dancestunesmap' VALUES (842, 3054, 734, 10, '');
INSERT INTO 'dancestunesmap' VALUES (840, 3047, 731, 10, '');
INSERT INTO 'dancestunesmap' VALUES (822, 2990, 713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (817, 2979, 1457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (809, 2952, 19, 10, '');
INSERT INTO 'dancestunesmap' VALUES (793, 2910, 1360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (812, 2957, 701, 10, '');
INSERT INTO 'dancestunesmap' VALUES (811, 2957, 526, 11, '');
INSERT INTO 'dancestunesmap' VALUES (788, 2878, 677, 10, '');
INSERT INTO 'dancestunesmap' VALUES (785, 2871, 649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (782, 2861, 81, 10, '');
INSERT INTO 'dancestunesmap' VALUES (775, 2826, 384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (770, 2821, 597, 10, '');
INSERT INTO 'dancestunesmap' VALUES (751, 2742, 640, 10, '');
INSERT INTO 'dancestunesmap' VALUES (745, 2725, 637, 10, '');
INSERT INTO 'dancestunesmap' VALUES (839, 3046, 732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8061, 941, 10066, 10, '');
INSERT INTO 'dancestunesmap' VALUES (776, 2836, 536, 10, '');
INSERT INTO 'dancestunesmap' VALUES (863, 3165, 1497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (867, 3178, 352, 10, '');
INSERT INTO 'dancestunesmap' VALUES (868, 3178, 368, 10, '');
INSERT INTO 'dancestunesmap' VALUES (870, 3190, 1006, 10, '');
INSERT INTO 'dancestunesmap' VALUES (871, 3194, 765, 10, '');
INSERT INTO 'dancestunesmap' VALUES (879, 3239, 369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (880, 3240, 772, 10, '');
INSERT INTO 'dancestunesmap' VALUES (883, 3249, 1748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (890, 3270, 1775, 10, '');
INSERT INTO 'dancestunesmap' VALUES (891, 3275, 784, 10, '');
INSERT INTO 'dancestunesmap' VALUES (873, 3220, 441, 10, '');
INSERT INTO 'dancestunesmap' VALUES (931, 3413, 1481, 10, '');
INSERT INTO 'dancestunesmap' VALUES (902, 3315, 798, 10, '');
INSERT INTO 'dancestunesmap' VALUES (904, 3322, 805, 10, '');
INSERT INTO 'dancestunesmap' VALUES (907, 3330, 1013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (914, 3347, 650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (936, 3435, 1435, 10, '');
INSERT INTO 'dancestunesmap' VALUES (942, 3451, 1814, 10, '');
INSERT INTO 'dancestunesmap' VALUES (944, 3458, 971, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8081, 13336, 874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8083, 13337, 3600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8085, 13339, 1398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8086, 13340, 5018, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8087, 13341, 10073, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8088, 13342, 2442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8089, 13344, 947, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8090, 13345, 727, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8091, 13346, 10066, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8094, 13349, 2607, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8097, 13373, 10318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8045, 12320, 33, 10, '');
INSERT INTO 'dancestunesmap' VALUES (941, 3448, 1791, 10, '');
INSERT INTO 'dancestunesmap' VALUES (834, 3038, 29, 10, '');
INSERT INTO 'dancestunesmap' VALUES (927, 3406, 1439, 10, '');
INSERT INTO 'dancestunesmap' VALUES (849, 3104, 743, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8057, 13327, 1020, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8095, 13350, 171, 10, '');
INSERT INTO 'dancestunesmap' VALUES (826, 3001, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (853, 3128, 747, 10, '');
INSERT INTO 'dancestunesmap' VALUES (925, 3402, 836, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8075, 9573, 5018, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8066, 12440, 1398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8084, 13338, 1398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8092, 13347, 1585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8103, 13555, 11005, 10, '');
INSERT INTO 'dancestunesmap' VALUES (851, 3119, 576, 10, '');
INSERT INTO 'dancestunesmap' VALUES (878, 3236, 771, 10, '');
INSERT INTO 'dancestunesmap' VALUES (938, 3437, 850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (932, 3415, 1505, 10, '');
INSERT INTO 'dancestunesmap' VALUES (928, 3407, 840, 10, '');
INSERT INTO 'dancestunesmap' VALUES (916, 3351, 1837, 10, '');
INSERT INTO 'dancestunesmap' VALUES (915, 3349, 1656, 10, '');
INSERT INTO 'dancestunesmap' VALUES (881, 3245, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (877, 3235, 770, 10, '');
INSERT INTO 'dancestunesmap' VALUES (876, 3233, 452, 10, '');
INSERT INTO 'dancestunesmap' VALUES (872, 3218, 1057, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8099, 13547, 951, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8100, 13547, 1857, 10, '');
INSERT INTO 'dancestunesmap' VALUES (856, 3142, 973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (847, 3091, 1820, 10, '');
INSERT INTO 'dancestunesmap' VALUES (846, 3091, 1119, 11, '');
INSERT INTO 'dancestunesmap' VALUES (819, 2981, 1799, 10, '');
INSERT INTO 'dancestunesmap' VALUES (818, 2981, 1584, 10, '');
INSERT INTO 'dancestunesmap' VALUES (714, 2616, 1801, 10, '');
INSERT INTO 'dancestunesmap' VALUES (711, 2604, 611, 10, '');
INSERT INTO 'dancestunesmap' VALUES (772, 2823, 659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8058, 9333, 10056, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8042, 13218, 6364, 10, '');
INSERT INTO 'dancestunesmap' VALUES (918, 3357, 559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8049, 13316, 10054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8102, 13554, 2555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (875, 3231, 769, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8051, 13319, 2332, 10, '');
INSERT INTO 'dancestunesmap' VALUES (838, 3045, 1285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (837, 3045, 1030, 11, '');
INSERT INTO 'dancestunesmap' VALUES (8043, 13276, 6364, 10, '');
INSERT INTO 'dancestunesmap' VALUES (869, 3186, 1476, 10, '');
INSERT INTO 'dancestunesmap' VALUES (920, 3375, 829, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8052, 13321, 9331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8054, 13324, 1291, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8055, 13325, 5130, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8056, 13326, 1042, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8046, 13305, 10051, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8076, 9572, 220, 10, '');
INSERT INTO 'dancestunesmap' VALUES (922, 3389, 356, 10, '');
INSERT INTO 'dancestunesmap' VALUES (917, 3352, 646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (896, 3284, 1191, 10, '');
INSERT INTO 'dancestunesmap' VALUES (924, 3398, 713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (886, 3265, 779, 10, '');
INSERT INTO 'dancestunesmap' VALUES (900, 3310, 794, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1051, 3735, 962, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8122, 13605, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (945, 3458, 1198, 10, '');
INSERT INTO 'dancestunesmap' VALUES (946, 3462, 798, 10, '');
INSERT INTO 'dancestunesmap' VALUES (953, 3495, 164, 10, '');
INSERT INTO 'dancestunesmap' VALUES (957, 3500, 874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (963, 3515, 728, 10, '');
INSERT INTO 'dancestunesmap' VALUES (983, 3577, 435, 10, '');
INSERT INTO 'dancestunesmap' VALUES (990, 3585, 883, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1033, 3695, 1797, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1008, 3622, 917, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1029, 3682, 942, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1039, 3709, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1040, 3709, 470, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1043, 3725, 958, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1056, 3743, 1665, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1054, 3741, 963, 10, '');
INSERT INTO 'dancestunesmap' VALUES (885, 3257, 775, 1, '');
INSERT INTO 'dancestunesmap' VALUES (8078, 9581, 6981, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8107, 13559, 10228, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1013, 3632, 608, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8096, 13353, 5590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (884, 3251, 52, 10, '');
INSERT INTO 'dancestunesmap' VALUES (933, 3424, 846, 10, '');
INSERT INTO 'dancestunesmap' VALUES (857, 3147, 355, 10, '');
INSERT INTO 'dancestunesmap' VALUES (887, 3267, 1735, 10, '');
INSERT INTO 'dancestunesmap' VALUES (903, 3320, 803, 10, '');
INSERT INTO 'dancestunesmap' VALUES (905, 3325, 814, 10, '');
INSERT INTO 'dancestunesmap' VALUES (948, 3472, 1252, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8101, 13553, 1418, 10, '');
INSERT INTO 'dancestunesmap' VALUES (921, 3380, 1786, 10, '');
INSERT INTO 'dancestunesmap' VALUES (954, 3499, 478, 10, '');
INSERT INTO 'dancestunesmap' VALUES (919, 3373, 828, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1036, 3700, 1280, 10, '');
INSERT INTO 'dancestunesmap' VALUES (939, 3444, 594, 10, '');
INSERT INTO 'dancestunesmap' VALUES (969, 3525, 745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (981, 3570, 879, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8063, 1084, 10067, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1011, 3625, 453, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8123, 13601, 11323, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8116, 13602, 2610, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8124, 13601, 11324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8117, 13598, 11317, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8047, 13310, 3825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (985, 3580, 1598, 11, '');
INSERT INTO 'dancestunesmap' VALUES (8073, 9571, 6966, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1028, 3680, 941, 10, '');
INSERT INTO 'dancestunesmap' VALUES (937, 3436, 849, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1073, 3778, 976, 10, '');
INSERT INTO 'dancestunesmap' VALUES (874, 3225, 768, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8098, 13449, 2049, 10, '');
INSERT INTO 'dancestunesmap' VALUES (934, 3428, 1131, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1044, 3728, 1550, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1042, 3722, 953, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1038, 3702, 946, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1037, 3701, 482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1027, 3678, 1249, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1019, 3645, 1169, 10, '');
INSERT INTO 'dancestunesmap' VALUES (982, 3575, 880, 10, '');
INSERT INTO 'dancestunesmap' VALUES (980, 3569, 878, 10, '');
INSERT INTO 'dancestunesmap' VALUES (977, 3563, 877, 10, '');
INSERT INTO 'dancestunesmap' VALUES (973, 3528, 872, 10, '');
INSERT INTO 'dancestunesmap' VALUES (943, 3454, 1334, 10, '');
INSERT INTO 'dancestunesmap' VALUES (929, 3412, 843, 10, '');
INSERT INTO 'dancestunesmap' VALUES (930, 3412, 1081, 11, '');
INSERT INTO 'dancestunesmap' VALUES (912, 3342, 824, 10, '');
INSERT INTO 'dancestunesmap' VALUES (898, 3287, 429, 10, '');
INSERT INTO 'dancestunesmap' VALUES (913, 3342, 1680, 11, '');
INSERT INTO 'dancestunesmap' VALUES (909, 3338, 808, 10, '');
INSERT INTO 'dancestunesmap' VALUES (906, 3326, 815, 10, '');
INSERT INTO 'dancestunesmap' VALUES (901, 3314, 797, 10, '');
INSERT INTO 'dancestunesmap' VALUES (866, 3177, 1281, 11, '');
INSERT INTO 'dancestunesmap' VALUES (888, 3268, 496, 11, '');
INSERT INTO 'dancestunesmap' VALUES (889, 3268, 1537, 10, '');
INSERT INTO 'dancestunesmap' VALUES (865, 3177, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (988, 3584, 882, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8062, 942, 4899, 10, '');
INSERT INTO 'dancestunesmap' VALUES (882, 3246, 1732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (975, 3543, 1447, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8126, 13599, 11320, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8147, 13466, 2797, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8151, 13647, 11489, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1067, 3772, 1408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1068, 3772, 1641, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1078, 3790, 342, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1079, 3796, 1628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1081, 3802, 982, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1017, 3637, 1410, 11, '');
INSERT INTO 'dancestunesmap' VALUES (8105, 13557, 4132, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1032, 3693, 1698, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8141, 13628, 7845, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1030, 3685, 911, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1053, 3739, 767, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8138, 13626, 636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8145, 13639, 10690, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8140, 13628, 2442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8135, 13619, 3394, 10, '');
INSERT INTO 'dancestunesmap' VALUES (998, 3607, 901, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8114, 13577, 7194, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8127, 13273, 11330, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8125, 13608, 1542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8129, 13606, 295, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8128, 13606, 713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8106, 13558, 11011, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1016, 3637, 926, 10, '');
INSERT INTO 'dancestunesmap' VALUES (987, 3583, 1326, 10, '');
INSERT INTO 'dancestunesmap' VALUES (992, 3588, 1137, 11, '');
INSERT INTO 'dancestunesmap' VALUES (991, 3588, 886, 10, '');
INSERT INTO 'dancestunesmap' VALUES (986, 3583, 881, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1062, 3759, 967, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1061, 3759, 861, 11, '');
INSERT INTO 'dancestunesmap' VALUES (958, 3506, 864, 10, '');
INSERT INTO 'dancestunesmap' VALUES (962, 3514, 1707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (961, 3514, 1655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8142, 13629, 11470, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8144, 13633, 11471, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8143, 13634, 11471, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8146, 13641, 11472, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8152, 13587, 2975, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1015, 3635, 6, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8131, 13609, 416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8130, 13609, 2905, 10, '');
INSERT INTO 'dancestunesmap' VALUES (960, 3509, 724, 10, '');
INSERT INTO 'dancestunesmap' VALUES (959, 3509, 196, 10, '');
INSERT INTO 'dancestunesmap' VALUES (997, 3601, 896, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1060, 3753, 1148, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1090, 3843, 169, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1093, 3849, 586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1094, 3849, 1112, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1101, 3863, 603, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1113, 3890, 1003, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1114, 3891, 1392, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8185, 11158, 7881, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1129, 3940, 1015, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1025, 3665, 1704, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1071, 3775, 974, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8113, 13576, 11122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1120, 3910, 1464, 10, '');
INSERT INTO 'dancestunesmap' VALUES (947, 3463, 854, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1045, 3729, 960, 10, '');
INSERT INTO 'dancestunesmap' VALUES (923, 3397, 387, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1080, 3800, 1560, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8139, 13627, 11469, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1052, 3737, 961, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1035, 3699, 254, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1018, 3642, 928, 10, '');
INSERT INTO 'dancestunesmap' VALUES (995, 3592, 741, 10, '');
INSERT INTO 'dancestunesmap' VALUES (979, 3567, 1509, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1065, 3765, 400, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1020, 3651, 933, 10, '');
INSERT INTO 'dancestunesmap' VALUES (951, 3490, 1771, 10, '');
INSERT INTO 'dancestunesmap' VALUES (935, 3433, 1528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (911, 3339, 823, 10, '');
INSERT INTO 'dancestunesmap' VALUES (908, 3331, 811, 10, '');
INSERT INTO 'dancestunesmap' VALUES (892, 3277, 599, 10, '');
INSERT INTO 'dancestunesmap' VALUES (848, 3101, 943, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8082, 12432, 2113, 10, 'for the Madoma version');
INSERT INTO 'dancestunesmap' VALUES (996, 3594, 932, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1134, 3961, 940, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1140, 3985, 1403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1150, 4021, 1613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8153, 13660, 11490, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8154, 13522, 10879, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8156, 13678, 11493, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1202, 4179, 1074, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8161, 13682, 11505, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8163, 13690, 11512, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8164, 13683, 11506, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8165, 13684, 2252, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8166, 13685, 11507, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8167, 13686, 11508, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8179, 13591, 11528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8180, 13591, 501, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8181, 13591, 996, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8182, 13591, 11035, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8183, 11833, 11529, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8184, 11834, 9140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8186, 11836, 11530, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8187, 11838, 9651, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8189, 13692, 11539, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8190, 13692, 11540, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8192, 13694, 11543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8193, 13694, 1126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1164, 4069, 1368, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1168, 4078, 1047, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1169, 4079, 17, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1172, 4090, 1502, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1174, 4094, 1055, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1106, 3883, 998, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1066, 3770, 13969, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1163, 4068, 1046, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1075, 3783, 977, 10, '');
INSERT INTO 'dancestunesmap' VALUES (972, 3526, 1421, 10, '');
INSERT INTO 'dancestunesmap' VALUES (971, 3526, 679, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1034, 3697, 491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8112, 13575, 1926, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8134, 13618, 11364, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1156, 4052, 570, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1157, 4052, 1211, 10, '');
INSERT INTO 'dancestunesmap' VALUES (965, 3524, 870, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1049, 3732, 297, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1070, 3774, 1565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1082, 3813, 984, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1076, 3786, 981, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1116, 3894, 1599, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1146, 4017, 686, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8137, 13621, 1085, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8104, 13556, 3694, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8108, 13560, 8316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1121, 3912, 277, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8170, 13584, 11175, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8191, 13693, 749, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1057, 3748, 318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8119, 13600, 11321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (952, 3493, 1357, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1002, 3611, 64, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1012, 3631, 1361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1107, 3885, 852, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8176, 10376, 1895, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8159, 13589, 10653, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8136, 13620, 4989, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8133, 13617, 1198, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8132, 13604, 11328, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8121, 13603, 1101, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8120, 13597, 4907, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8118, 13275, 11332, 10, '');
INSERT INTO 'dancestunesmap' VALUES (949, 3474, 857, 10, '');
INSERT INTO 'dancestunesmap' VALUES (976, 3558, 1195, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1004, 3615, 912, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1072, 3777, 164, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1144, 4014, 408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8149, 13644, 3545, 10, 'as The Merry-Go-Round');
INSERT INTO 'dancestunesmap' VALUES (1148, 4019, 421, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1128, 3938, 517, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1125, 3932, 969, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1118, 3900, 321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1097, 3861, 129, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1096, 3859, 991, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1091, 3845, 236, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1083, 3829, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1084, 3829, 1374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8160, 13681, 11504, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1074, 3781, 1207, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1064, 3763, 590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1041, 3711, 949, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1010, 3623, 918, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1009, 3623, 567, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1007, 3620, 1029, 10, '');
INSERT INTO 'dancestunesmap' VALUES (993, 3589, 887, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1003, 3613, 350, 10, '');
INSERT INTO 'dancestunesmap' VALUES (994, 3589, 1138, 11, '');
INSERT INTO 'dancestunesmap' VALUES (974, 3541, 873, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1175, 4097, 1056, 10, '');
INSERT INTO 'dancestunesmap' VALUES (950, 3475, 433, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1176, 4097, 1420, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1077, 3788, 997, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8115, 13592, 11249, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1022, 3656, 820, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1021, 3656, 481, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1183, 4114, 1664, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1186, 4132, 1124, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1195, 4171, 416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1200, 4177, 907, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1205, 4195, 1078, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1208, 4212, 1246, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1213, 4236, 317, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1222, 4288, 800, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1223, 4288, 1334, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10211, 18249, 13843, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1227, 4294, 428, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1228, 4294, 429, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1229, 4294, 643, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8169, 13688, 11510, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1215, 4252, 1448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1138, 3972, 986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8171, 13585, 10764, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8168, 13687, 11509, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8188, 13691, 10163, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1092, 3846, 65, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1122, 3917, 920, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8174, 13590, 11183, 10, 'RSCDS publication');
INSERT INTO 'dancestunesmap' VALUES (8172, 13586, 11178, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1100, 3862, 1710, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1099, 3862, 992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1171, 4086, 1315, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1170, 4086, 1051, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1214, 4239, 1095, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1203, 4190, 1075, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1173, 4092, 1054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1117, 3899, 1800, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8178, 12941, 1126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1191, 4154, 1071, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1190, 4145, 101, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1102, 3864, 410, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1124, 3921, 1235, 12, '');
INSERT INTO 'dancestunesmap' VALUES (1185, 4127, 1066, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1160, 4065, 1015, 1, '');
INSERT INTO 'dancestunesmap' VALUES (8173, 13588, 3601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1136, 3965, 1026, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1089, 3838, 988, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1233, 4311, 1232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1237, 4325, 1108, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1238, 4325, 1329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1239, 4326, 323, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1240, 4326, 332, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1241, 4326, 634, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8197, 11846, 11547, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8198, 11845, 9142, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8199, 11849, 2814, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8201, 11850, 11534, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8202, 11851, 11535, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8203, 11856, 11536, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8204, 11855, 2484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8205, 11859, 11537, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8206, 11861, 11538, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8207, 11863, 6792, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8208, 11864, 11548, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8228, 13695, 6953, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8230, 13712, 1391, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8232, 13713, 6692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8233, 13714, 236, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8234, 13715, 1036, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8235, 13717, 8998, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8236, 13718, 1178, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1152, 4026, 1523, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1024, 3659, 937, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1001, 3609, 906, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1105, 3876, 996, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1047, 3730, 960, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8175, 13149, 11177, 10, 'RSCDS Book 46 tune');
INSERT INTO 'dancestunesmap' VALUES (999, 3608, 904, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8218, 13378, 6500, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8162, 13689, 11511, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1194, 4170, 12, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1180, 4105, 1446, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1112, 3888, 1000, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1087, 3833, 337, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1088, 3833, 1689, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1256, 4395, 542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1260, 4413, 1049, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1261, 4413, 1661, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1262, 4414, 51, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1267, 4433, 1780, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1298, 4514, 1199, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1302, 4548, 1219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1221, 4282, 857, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1232, 4309, 1105, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1206, 4209, 1086, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1153, 4032, 1041, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1285, 4471, 1175, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1313, 4595, 238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1179, 4103, 49, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1189, 4144, 1240, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10212, 18251, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1141, 3986, 704, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1126, 3934, 1012, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1127, 3934, 1155, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1133, 3953, 1019, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1263, 4424, 309, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1231, 4301, 1832, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1207, 4211, 1087, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1139, 3980, 1781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1147, 4018, 404, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1135, 3963, 1025, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1204, 4192, 1077, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1211, 4225, 1090, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1257, 4401, 1017, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1317, 4610, 985, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1311, 4585, 1241, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1327, 4642, 139, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8229, 13696, 2522, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1243, 4354, 502, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8209, 13697, 322, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8231, 13698, 1013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8237, 13719, 6724, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8155, 13677, 11492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1167, 4073, 1402, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1322, 4635, 1020, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1095, 3857, 895, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1166, 4073, 1400, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1177, 4100, 1309, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1197, 4175, 72, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1198, 4175, 105, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1254, 4394, 249, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1255, 4394, 1122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1295, 4500, 973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1274, 4444, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1289, 4477, 469, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1258, 4404, 580, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1299, 4518, 1204, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1300, 4521, 398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1319, 4620, 1342, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8158, 13679, 11499, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8210, 13596, 11311, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8194, 13303, 11541, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1226, 4293, 1103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1154, 4043, 1037, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1131, 3941, 1013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8221, 13380, 10329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8222, 13512, 10794, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8220, 13379, 10328, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1119, 3909, 1470, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8213, 13376, 10317, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8212, 13374, 10312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8223, 12290, 10330, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8217, 13377, 10324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8219, 9261, 81, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1286, 4474, 1177, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1306, 4561, 1228, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1279, 4451, 1161, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1284, 4466, 1181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1271, 4441, 1146, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1235, 4318, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1225, 4291, 1524, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1218, 4262, 685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1212, 4227, 1091, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1209, 4222, 211, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1199, 4176, 950, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1196, 4173, 425, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1193, 4169, 1046, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1192, 4155, 1474, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1184, 4126, 1066, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1181, 4106, 1590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1151, 4024, 1039, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1123, 3918, 1754, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1110, 3887, 1001, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1216, 4253, 825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1104, 3866, 1821, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1331, 4645, 1699, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8247, 13615, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8253, 13730, 11065, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8254, 13731, 11067, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8261, 13747, 497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8196, 11842, 1113, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1325, 4639, 1253, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1330, 4644, 1256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1314, 4596, 598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1323, 4636, 1293, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1297, 4511, 1197, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1340, 4662, 1683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1249, 4365, 1113, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1282, 4461, 1167, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1310, 4579, 919, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8226, 13381, 10333, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1326, 4641, 923, 10, 'Customary “original” tune');
INSERT INTO 'dancestunesmap' VALUES (8256, 13742, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1244, 4356, 1110, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1304, 4558, 1226, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1303, 4550, 1220, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1338, 4654, 684, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1318, 4612, 860, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1252, 4386, 376, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8255, 13741, 11556, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8276, 13462, 9317, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8281, 13461, 10573, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1356, 4718, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1357, 4718, 613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1358, 4718, 978, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1370, 4778, 1328, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1388, 4831, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1389, 4831, 1793, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1402, 4870, 1158, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1475, 5122, 1073, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10214, 18253, 13845, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1379, 4808, 819, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1428, 4939, 117, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1429, 4939, 929, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1430, 4939, 985, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1431, 4939, 1364, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8289, 13390, 10399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8291, 13395, 10415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8295, 13770, 11559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8302, 74, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8307, 6381, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1435, 4946, 1396, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1441, 4964, 1261, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1444, 4973, 225, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1447, 4993, 1115, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1345, 4679, 1262, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1265, 4431, 1141, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1296, 4506, 1017, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1373, 4796, 1544, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8243, 13318, 2316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1273, 4442, 1232, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1432, 4940, 1023, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1360, 4725, 952, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1247, 4359, 1111, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1369, 4767, 1320, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1275, 4445, 1153, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1287, 4475, 1366, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8216, 1173, 10322, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10213, 18252, 13844, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1158, 4064, 1043, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1305, 4559, 1227, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1324, 4637, 1195, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1250, 4371, 1114, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8300, 10283, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8195, 10290, 11542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1553, 5412, 1156, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1392, 4845, 1368, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1321, 4630, 1408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1341, 4663, 673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1316, 4602, 715, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1315, 4601, 1250, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1312, 4594, 1247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1308, 4563, 1587, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1301, 4528, 1575, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1336, 4651, 857, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1293, 4499, 71, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1253, 4393, 1118, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1246, 4358, 1689, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1242, 4336, 724, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1348, 4695, 488, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1145, 4015, 1624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1349, 4695, 575, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1219, 4271, 232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1290, 4484, 1368, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8290, 13387, 10403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1291, 4489, 1185, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1333, 4650, 156, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1391, 4844, 61, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1433, 4941, 845, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1434, 4941, 1395, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8314, 2192, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1234, 4312, 9714, 10, 'As “The Countess of Dalkeith''s Strathspey”');
INSERT INTO 'dancestunesmap' VALUES (8285, 13758, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1264, 4431, 557, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1390, 4840, 1028, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8308, 4903, 11561, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1436, 4947, 1808, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8317, 5238, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8323, 5327, 918, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8313, 6168, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8319, 6417, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8269, 13460, 10572, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8270, 13463, 10578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8271, 13465, 10583, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8278, 13467, 10586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8282, 13469, 2578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8273, 13471, 10588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8274, 13472, 9267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8241, 13511, 10775, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8238, 13720, 8310, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8249, 13721, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8242, 13722, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8244, 13725, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8248, 13728, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8257, 13743, 189, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8259, 13745, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8260, 13746, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8262, 13748, 1655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8263, 13749, 4371, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8265, 13750, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8286, 13759, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8288, 13764, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8292, 13767, 11558, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1386, 4828, 1798, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8239, 13723, 11552, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8303, 2660, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1288, 4476, 1178, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1347, 4692, 1264, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1437, 4951, 1398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8251, 13729, 1834, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8266, 13751, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1403, 4871, 1346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8268, 12364, 8312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8225, 11873, 10332, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8252, 10007, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1450, 5007, 1006, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8321, 5521, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8318, 6414, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1371, 4782, 1329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1332, 4646, 1257, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8316, 5005, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1346, 4680, 948, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1380, 4813, 108, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1406, 4882, 1381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1413, 4908, 124, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1372, 4784, 1331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1366, 4752, 1312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1363, 4744, 955, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1359, 4720, 1287, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1343, 4677, 1004, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1344, 4677, 1311, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1320, 4629, 1173, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1309, 4565, 1230, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1281, 4455, 1321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1278, 4450, 1740, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1270, 4440, 1239, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1268, 4438, 222, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1251, 4374, 351, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8309, 2308, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1416, 4919, 1387, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1236, 4324, 1107, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8287, 13760, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8294, 13769, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1354, 4715, 1279, 1, '');
INSERT INTO 'dancestunesmap' VALUES (1460, 5047, 967, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1465, 5065, 1554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1467, 5087, 1676, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1471, 5111, 1243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1472, 5115, 973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1452, 5016, 1013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1387, 4830, 1362, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1424, 4933, 394, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1461, 5054, 1424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1438, 4953, 1532, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1409, 4894, 1401, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8311, 6513, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1418, 4925, 1192, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1365, 4750, 1310, 1, '');
INSERT INTO 'dancestunesmap' VALUES (8250, 713, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8306, 13774, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8305, 13774, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1458, 5033, 1351, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8304, 4180, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1421, 4929, 1559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1463, 5055, 789, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1462, 5055, 183, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1449, 4998, 399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1364, 4749, 1308, 1, '');
INSERT INTO 'dancestunesmap' VALUES (1351, 4707, 1271, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1352, 4708, 1273, 1, '');
INSERT INTO 'dancestunesmap' VALUES (8280, 13473, 10589, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8277, 13464, 10580, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1419, 4927, 669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8293, 13768, 1505, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1381, 4818, 1385, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1468, 5090, 1678, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1439, 4954, 1520, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1408, 4890, 413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1481, 5140, 1818, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1486, 5153, 515, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1488, 5156, 1223, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1494, 5190, 84, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1495, 5194, 507, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1498, 5205, 847, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1501, 5212, 1491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1502, 5216, 1376, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1503, 5216, 1666, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1514, 5262, 1748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1515, 5263, 1491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1520, 5290, 980, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1530, 5321, 582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1531, 5321, 1471, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1534, 5333, 844, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1535, 5339, 411, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1536, 5342, 702, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1547, 5386, 737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8329, 5620, 1796, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8330, 5620, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8335, 12796, 9931, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8336, 7629, 9933, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8337, 12797, 2692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8338, 12798, 9935, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8340, 12801, 2122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8341, 12804, 9943, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8343, 12806, 2459, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1559, 5435, 1492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1560, 5436, 1493, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1562, 5439, 996, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1568, 5449, 760, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1569, 5450, 1503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1583, 5512, 350, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1584, 5512, 742, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1592, 5532, 1513, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1595, 5548, 1282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1602, 5585, 32, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1603, 5586, 1008, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1605, 5606, 1753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1509, 5234, 1501, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1612, 5623, 424, 3, '');
INSERT INTO 'dancestunesmap' VALUES (1508, 5234, 817, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1622, 5640, 431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1623, 5641, 1535, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1625, 5651, 1566, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1570, 5455, 1610, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8279, 13470, 9316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1420, 4928, 1389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1393, 4857, 696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8267, 13755, 68, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8312, 2640, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8272, 13468, 1084, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1526, 5317, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10239, 18285, 2222, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1597, 5559, 116, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1593, 5542, 1517, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1587, 5520, 578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1582, 5511, 382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8297, 13772, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8298, 13772, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1469, 5093, 1427, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1456, 5032, 1415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1453, 5019, 810, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1342, 4669, 1388, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1493, 5176, 735, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1407, 4888, 98, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1626, 5651, 1611, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1627, 5653, 778, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1628, 5653, 1789, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8339, 12799, 625, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1394, 4858, 753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8301, 13773, 11560, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1464, 5062, 1307, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8283, 13353, 7562, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1574, 5471, 874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1496, 5198, 1448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1606, 5609, 1525, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1440, 4959, 1404, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1537, 5347, 1237, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1385, 4827, 1360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1411, 4907, 1080, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1410, 4907, 889, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1377, 4806, 810, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1350, 4701, 1268, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1423, 4931, 1391, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1398, 4864, 363, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1427, 4935, 1082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1397, 4863, 1375, 1, '');
INSERT INTO 'dancestunesmap' VALUES (1404, 4873, 1378, 1, '');
INSERT INTO 'dancestunesmap' VALUES (1422, 4930, 98, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8322, 4965, 1897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1533, 5330, 958, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1616, 5628, 1531, 1, '');
INSERT INTO 'dancestunesmap' VALUES (1524, 5310, 1719, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8310, 1295, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1478, 5129, 1433, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1480, 5139, 1436, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8326, 5264, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8324, 5327, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8331, 5327, 11561, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8332, 5388, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8328, 5605, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1579, 5500, 1373, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1355, 4716, 1282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1479, 5136, 1435, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1362, 4728, 1290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1459, 5040, 169, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1512, 5243, 1463, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1528, 5320, 620, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1529, 5320, 1170, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1538, 5351, 1473, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1594, 5543, 720, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1507, 5223, 1454, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8334, 12795, 9930, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1396, 4862, 1374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8333, 10049, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8325, 545, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1473, 5118, 40, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1376, 4805, 248, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1484, 5142, 1437, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8320, 6834, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1624, 5643, 1695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1522, 5303, 1347, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1615, 5624, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1604, 5591, 761, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1598, 5564, 1834, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1532, 5326, 203, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1518, 5282, 238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1517, 5276, 1462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1497, 5204, 1768, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1491, 5161, 207, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1485, 5147, 748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1470, 5099, 1286, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1455, 5027, 1709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1443, 4968, 819, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1405, 4875, 1380, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1400, 4865, 1200, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1401, 4865, 1277, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1375, 4804, 1460, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1367, 4755, 1186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1640, 5701, 784, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1641, 5701, 786, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1642, 5702, 452, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1644, 5705, 87, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1645, 5705, 367, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1596, 5555, 1497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8327, 2401, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1572, 5462, 1504, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1552, 5407, 1345, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1580, 5503, 1386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10240, 18304, 9286, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1571, 5460, 1407, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1548, 5389, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1521, 5296, 1465, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1511, 5239, 1458, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1546, 5376, 1482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1573, 5463, 1506, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1589, 5522, 1512, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1499, 5207, 989, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1643, 5703, 1549, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1636, 5686, 1811, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1555, 5413, 1592, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1516, 5271, 1383, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1500, 5208, 1830, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1492, 5168, 1445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8344, 12807, 9945, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1648, 5711, 116, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8354, 13783, 307, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8355, 13783, 1179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8366, 13795, 610, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8371, 13798, 93, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8374, 13800, 1533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8375, 13801, 917, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8376, 13802, 917, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8377, 12605, 408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8378, 13803, 14, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1653, 5729, 429, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1659, 5733, 1556, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1660, 5734, 1480, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1666, 5758, 1291, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1671, 5784, 648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1672, 5784, 914, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1674, 5793, 1565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1681, 5805, 494, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1689, 5847, 1650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1691, 5849, 324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1692, 5849, 555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1694, 5860, 1567, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1696, 5867, 1570, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1697, 5874, 1096, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1701, 5880, 1582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1702, 5881, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1703, 5881, 1701, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1713, 5921, 899, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1714, 5922, 1141, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1723, 5948, 574, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1726, 5963, 1592, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1727, 5964, 1593, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1728, 5965, 212, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1729, 5982, 1371, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1731, 5993, 63, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1732, 5993, 1367, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8393, 13842, 11573, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8395, 13844, 11575, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8396, 13844, 11576, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8399, 13846, 11579, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8405, 13438, 10499, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1709, 5898, 1578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8398, 13846, 8953, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1708, 5894, 1577, 1, '');
INSERT INTO 'dancestunesmap' VALUES (8413, 13445, 10521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8414, 13445, 10522, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8391, 13840, 11571, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8384, 13809, 8282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1661, 5740, 5634, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1743, 6046, 170, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1581, 5504, 1456, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1710, 5904, 1008, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1734, 6017, 606, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1718, 5934, 1583, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1577, 5497, 1511, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1685, 5825, 403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1540, 5354, 1475, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1707, 5893, 757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1600, 5576, 318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1505, 5222, 1453, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1446, 4991, 1408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1647, 5708, 1552, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1651, 5721, 401, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1724, 5952, 395, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1733, 6012, 357, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8400, 13847, 10650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1525, 5316, 5, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1617, 5637, 224, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1575, 5480, 1510, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1374, 4803, 1354, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8403, 13437, 10494, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1563, 5441, 24, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1712, 5917, 831, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1683, 5808, 1488, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1601, 5584, 76, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1629, 5654, 703, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1567, 5445, 714, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1554, 5412, 1202, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1487, 5154, 1440, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1544, 5366, 439, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1466, 5083, 774, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1687, 5831, 1000, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8352, 13782, 35, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8347, 13780, 1727, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8348, 13780, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1266, 4432, 1140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1611, 5621, 1528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1635, 5674, 1541, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1658, 5732, 1448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1849, 6482, 859, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1657, 5731, 1553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8412, 13444, 10517, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8350, 13781, 5708, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8351, 13781, 9214, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8386, 13835, 11565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1551, 5403, 916, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1561, 5437, 840, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1565, 5443, 543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1586, 5519, 1151, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1607, 5612, 243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1610, 5616, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1609, 5616, 993, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1740, 6036, 465, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8380, 13807, 4646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1670, 5773, 1484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8408, 13441, 10506, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8407, 13440, 10501, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8402, 13436, 10491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1719, 5937, 145, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1482, 5141, 234, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1599, 5575, 1521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1677, 5799, 482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8345, 13776, 318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1631, 5658, 1540, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1566, 5444, 1500, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1646, 5707, 230, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1737, 6025, 973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1735, 6018, 1595, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1715, 5927, 1585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1717, 5932, 943, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1706, 5888, 1574, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1695, 5865, 1569, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1632, 5661, 1130, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1510, 5236, 281, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1690, 5848, 1650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8410, 1474, 11581, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1667, 5759, 256, 1, '');
INSERT INTO 'dancestunesmap' VALUES (1662, 5741, 717, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1638, 5691, 1759, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1637, 5687, 467, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1633, 5669, 856, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1576, 5493, 874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1550, 5398, 1487, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1549, 5398, 440, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1543, 5364, 1478, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1542, 5364, 208, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1490, 5160, 1442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1639, 5699, 1263, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1682, 5807, 1646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8369, 13797, 93, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8416, 13448, 10529, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8346, 13775, 4899, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8367, 13796, 1757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8368, 13796, 710, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1751, 6057, 795, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1745, 6051, 1604, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8429, 13869, 11594, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1736, 6020, 391, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1725, 5957, 702, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8349, 13779, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1698, 5875, 1478, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1693, 5859, 1452, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8390, 13838, 11569, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8426, 13873, 11591, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8423, 13872, 11588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8422, 13871, 11587, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8421, 13870, 11586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8420, 13870, 11585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8425, 13873, 11590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8359, 13788, 1118, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8357, 13786, 1118, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1716, 5931, 1787, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8381, 13811, 19, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1705, 5885, 1461, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8394, 13843, 11574, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8385, 13813, 1526, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8361, 13790, 4848, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8360, 13789, 916, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8362, 13791, 1290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8364, 13793, 7660, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8363, 13792, 1360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8373, 13799, 3361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8365, 13794, 1831, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1747, 6052, 1605, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1746, 6052, 133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1650, 5713, 1293, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8358, 13787, 1118, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1753, 6069, 1579, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1755, 6080, 1385, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1764, 6113, 665, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1765, 6114, 544, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1768, 6140, 635, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1769, 6140, 636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1778, 6171, 417, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1779, 6175, 1072, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1782, 6182, 1629, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1783, 6192, 558, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1784, 6195, 1633, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1791, 6233, 1638, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1793, 6250, 1068, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1796, 6276, 1652, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1807, 6329, 614, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1810, 6359, 415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1811, 6359, 547, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1816, 6366, 1672, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1817, 6366, 1721, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1822, 6384, 993, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1823, 6384, 1818, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1832, 6421, 652, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8430, 13885, 11595, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8435, 13888, 11600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8436, 13888, 11601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8438, 13890, 11603, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8443, 13895, 11609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1853, 6501, 970, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1856, 6511, 1544, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1876, 6589, 1795, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1885, 6610, 816, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1886, 6610, 1331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1887, 6610, 1720, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1891, 6626, 26, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1897, 6648, 835, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1809, 6349, 1283, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1808, 6349, 305, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1821, 6382, 983, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1879, 6597, 1419, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1878, 6597, 25, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1785, 6199, 1231, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1836, 6431, 1085, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1884, 6609, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1770, 6150, 333, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1844, 6453, 1681, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1843, 6453, 456, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8471, 13922, 11635, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1795, 6271, 1172, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8445, 13897, 2851, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1652, 5723, 1701, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1786, 6206, 403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1669, 5765, 1188, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1815, 6363, 743, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8389, 13837, 8952, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1700, 5878, 905, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1813, 6362, 1306, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1845, 6461, 1548, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1875, 6585, 1621, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1890, 6616, 1723, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1859, 6523, 920, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1757, 6091, 890, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1688, 5843, 256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1675, 5794, 377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1739, 6029, 1597, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1738, 6028, 1596, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1722, 5945, 1814, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1590, 5525, 430, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1869, 6545, 497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8442, 13894, 11607, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1896, 6637, 1651, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8382, 13817, 11562, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1892, 6627, 1668, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1558, 5422, 1568, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1826, 6389, 339, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1730, 5986, 1571, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10217, 18078, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1893, 6632, 1726, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1830, 6407, 1508, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1777, 6162, 1585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1673, 5788, 295, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1678, 5800, 1761, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1655, 5730, 1187, 1, '');
INSERT INTO 'dancestunesmap' VALUES (8409, 13442, 10510, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1868, 6543, 995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8401, 13852, 10659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8404, 9875, 9715, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8439, 13891, 11604, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1761, 6103, 689, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1802, 6316, 1661, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1741, 6037, 445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1840, 6434, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1877, 6592, 1715, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1790, 6224, 1637, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8383, 13822, 7667, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1684, 5818, 1126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1756, 6085, 1451, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1792, 6249, 146, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1800, 6306, 1658, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8356, 13785, 1674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8392, 13841, 11572, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8379, 13804, 3215, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8433, 13886, 11598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8434, 13887, 11599, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8459, 13910, 11624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1686, 5830, 1669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1861, 6532, 164, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1862, 6532, 1423, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1780, 6177, 1626, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1787, 6207, 1486, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1880, 6599, 1717, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8431, 8654, 11596, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8411, 13443, 1694, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1704, 5882, 1573, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1812, 6360, 232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8415, 13446, 10524, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1855, 6510, 477, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1874, 6575, 643, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1852, 6492, 1472, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1847, 6477, 1692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1846, 6471, 1691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1841, 6444, 503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1827, 6391, 1213, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1825, 6387, 1469, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1824, 6386, 1144, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1805, 6327, 1667, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1797, 6285, 393, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1788, 6210, 837, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1781, 6178, 1627, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1776, 6161, 315, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1773, 6152, 1621, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1754, 6077, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1752, 6058, 1248, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1750, 6055, 1372, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1744, 6048, 1603, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1668, 5763, 930, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8417, 7120, 5697, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8418, 4552, 11582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1676, 5798, 1757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1664, 5749, 1770, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1649, 5712, 1696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1865, 6536, 278, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1758, 6094, 792, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1775, 6153, 1070, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1806, 6328, 1491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10219, 18257, 1401, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1831, 6420, 614, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8461, 13912, 11626, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1866, 6539, 1301, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1867, 6539, 1825, 11, '');
INSERT INTO 'dancestunesmap' VALUES (8448, 13900, 11613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8450, 13902, 11615, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8452, 13904, 11617, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8469, 13920, 1140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8470, 13921, 11634, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8453, 13905, 11618, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8451, 13903, 11616, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8458, 13909, 11623, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8455, 13907, 11620, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8444, 13896, 11610, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8466, 13917, 11631, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8454, 13906, 11619, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8467, 13918, 11632, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1798, 6287, 1171, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8468, 13919, 11633, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1872, 6569, 741, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1839, 6432, 1683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1774, 6153, 719, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8437, 13889, 11602, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1889, 6615, 700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1883, 6609, 384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1882, 6609, 353, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1900, 6658, 1734, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1909, 6703, 1024, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1910, 6703, 1151, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1918, 6723, 288, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1919, 6734, 197, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8492, 13524, 1352, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8493, 13525, 2312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8494, 13526, 10880, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8495, 13527, 10881, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8497, 13529, 10884, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8498, 13530, 10886, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8499, 13531, 10889, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8500, 13532, 333, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8501, 13533, 10891, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8502, 13534, 10892, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8503, 13535, 8319, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8504, 13536, 10893, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8505, 13537, 10894, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8509, 14177, 8244, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8510, 14178, 11345, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8511, 14179, 2906, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8512, 14179, 2947, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8513, 14180, 5846, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1946, 6825, 806, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1957, 6871, 160, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1961, 6891, 1232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1962, 6897, 756, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1963, 6897, 1772, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1964, 6897, 1779, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1982, 6978, 1313, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1983, 6980, 293, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1984, 6980, 1052, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1986, 6984, 1038, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1989, 7014, 1783, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1995, 7023, 763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2002, 7061, 736, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2003, 7061, 1645, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2012, 7095, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2013, 7095, 1757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2014, 7095, 1835, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8477, 13928, 11641, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2020, 7109, 1809, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2026, 7139, 99, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2027, 7139, 1449, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2028, 7139, 1813, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8474, 13925, 11638, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8476, 13927, 11640, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1981, 6978, 6945, 10, 'As “The Burnt Potato”');
INSERT INTO 'dancestunesmap' VALUES (2041, 7182, 1834, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2000, 7053, 493, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8485, 10339, 10547, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8484, 10339, 10546, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8508, 14174, 8792, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1922, 6744, 462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1998, 7041, 841, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1969, 6922, 1775, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8483, 13934, 11646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8464, 13915, 11629, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1987, 6990, 102, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1924, 6751, 1581, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8491, 13458, 10567, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8465, 13916, 11630, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2025, 7137, 1092, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1818, 6368, 1280, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8463, 13914, 11628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1767, 6130, 382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1959, 6885, 1428, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1895, 6634, 1727, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1894, 6634, 753, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1921, 6739, 1724, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8441, 13893, 11606, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1799, 6294, 123, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1947, 6826, 4, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1801, 6309, 955, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1988, 6995, 1785, 1, '');
INSERT INTO 'dancestunesmap' VALUES (1850, 6482, 1693, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1971, 6947, 1459, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1953, 6849, 710, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2006, 7068, 1804, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1996, 7030, 1705, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1979, 6967, 1707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1679, 5802, 791, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8460, 13911, 11625, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8446, 13898, 11611, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1904, 6679, 780, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8447, 13899, 11612, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8462, 13913, 11627, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1908, 6701, 360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2038, 7175, 711, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1759, 6098, 284, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1967, 6915, 313, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1966, 6904, 1773, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1945, 6824, 1297, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1829, 6407, 250, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1763, 6112, 1619, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1748, 6053, 713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1742, 6044, 1600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8472, 13923, 11636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1819, 6373, 476, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2024, 7113, 663, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8486, 13453, 2655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8489, 13456, 10563, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8496, 13528, 10883, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8506, 13538, 10895, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8473, 13924, 11637, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1766, 6116, 159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8449, 13901, 11614, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1835, 6424, 1027, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8514, 14181, 3394, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8487, 10324, 10549, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8481, 13932, 11644, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1975, 6965, 384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1976, 6965, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1854, 6505, 1700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2032, 7157, 133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2033, 7157, 1818, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2021, 7110, 431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2022, 7110, 1824, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2019, 7107, 1529, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2010, 7088, 850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2011, 7093, 280, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2009, 7075, 1807, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2007, 7071, 163, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2008, 7071, 1803, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1990, 7016, 154, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1972, 6952, 803, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1968, 6919, 209, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1985, 6981, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1903, 6675, 1166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1954, 6849, 1757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1950, 6847, 358, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1941, 6816, 1341, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1920, 6736, 57, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1911, 6710, 1251, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1955, 6853, 1758, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1901, 6661, 619, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1927, 6764, 2478, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1888, 6614, 100, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1848, 6481, 43, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1858, 6518, 1100, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1820, 6380, 1414, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1804, 6323, 1327, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2031, 7144, 653, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1994, 7020, 1792, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1906, 6691, 1217, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1907, 6691, 1411, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1917, 6722, 1833, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1905, 6682, 522, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1870, 6555, 1712, 1, '');
INSERT INTO 'dancestunesmap' VALUES (2016, 7101, 990, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1898, 6650, 1526, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1902, 6670, 1061, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8480, 13931, 5864, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8478, 13929, 11642, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1952, 6848, 1618, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1951, 6848, 1348, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1956, 6859, 1760, 1, '');
INSERT INTO 'dancestunesmap' VALUES (1914, 6719, 769, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2034, 7161, 1683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10220, 18258, 2312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2039, 7180, 1585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1944, 6819, 460, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1948, 6829, 1736, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1937, 6801, 746, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1929, 6775, 1649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1923, 6748, 1741, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1899, 6655, 406, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1993, 7017, 1730, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1938, 6805, 1134, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8507, 14173, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2044, 7194, 1836, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2047, 7202, 1320, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2051, 7212, 1675, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2052, 7212, 1764, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8521, 13580, 11158, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8526, 14241, 11479, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8530, 14263, 7151, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8534, 14272, 11725, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2137, 4553, 2614, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2065, 7253, 1670, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2068, 7263, 1064, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2073, 7286, 16, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2074, 7286, 282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2075, 1265, 2478, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2076, 1265, 1291, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2078, 2066, 1096, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2094, 5964, 850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2102, 6978, 1781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2103, 1593, 510, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2105, 6089, 195, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2109, 3636, 1916, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2113, 6142, 1991, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2116, 3825, 1907, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2122, 4730, 1132, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2126, 4776, 1353, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2130, 3756, 1042, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2134, 2034, 3068, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2135, 7573, 2607, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2136, 7574, 132, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2142, 1473, 2948, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8535, 14273, 11726, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8537, 14275, 11728, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8538, 14277, 11730, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2046, 7201, 1418, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8542, 14279, 11734, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8543, 14280, 11735, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8576, 13359, 10143, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8561, 14317, 11559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8562, 7973, 1703, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8567, 14039, 4500, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8568, 13569, 11075, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8570, 14323, 6204, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8571, 14323, 1219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8572, 14323, 488, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8577, 13364, 10154, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2156, 1574, 3232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8522, 13581, 11168, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8528, 14244, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2079, 2479, 581, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8541, 14278, 11733, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8540, 14278, 11732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2091, 7404, 130, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2095, 4046, 2021, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8516, 14183, 37, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8554, 14288, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8533, 14271, 11724, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8552, 14286, 413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8558, 14292, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8555, 14289, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2070, 7282, 206, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8557, 14291, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8556, 14290, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2160, 2585, 3235, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2141, 7135, 569, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2119, 3617, 1546, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2059, 7234, 1685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8573, 14324, 413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8529, 14262, 1261, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2127, 3418, 2829, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2138, 5006, 2614, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2158, 1796, 3234, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2093, 7420, 157, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2088, 7351, 20, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8515, 14182, 11695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2140, 2556, 1589, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8520, 13579, 11157, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1940, 6813, 1042, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8525, 12792, 9849, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1974, 6957, 964, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1935, 6800, 347, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1936, 6800, 1260, 11, '');
INSERT INTO 'dancestunesmap' VALUES (2101, 323, 1781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2153, 3653, 2443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2082, 3747, 756, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2067, 7261, 1844, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1997, 7037, 759, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8548, 13131, 10006, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8479, 13930, 1860, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2132, 100, 1865, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8531, 14270, 11722, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8536, 14274, 11727, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2115, 4278, 2935, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2100, 3710, 801, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2072, 7285, 1826, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8544, 12910, 11736, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8566, 14038, 1370, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8475, 13926, 11639, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1932, 6792, 1380, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8482, 13933, 11645, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2157, 1618, 3233, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1999, 7042, 1212, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2154, 860, 2396, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2165, 4306, 1858, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2064, 7247, 1843, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1915, 6721, 602, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2162, 3140, 1154, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2161, 3113, 1578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2147, 2722, 1048, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2120, 2317, 1257, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2112, 954, 1990, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8517, 14184, 129, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2118, 5007, 733, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2069, 7267, 809, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2001, 7055, 1533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6241, 7490, 5293, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2085, 7466, 318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2089, 7368, 89, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2087, 7350, 1413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2066, 7257, 275, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8569, 7289, 4684, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2056, 7220, 468, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2057, 7220, 1840, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2030, 7143, 1359, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2018, 7105, 1714, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2121, 6996, 2386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8550, 9261, 10327, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1970, 6941, 65, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2035, 7162, 1823, 1, '');
INSERT INTO 'dancestunesmap' VALUES (1960, 6890, 24, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1943, 6817, 1201, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1934, 6797, 1751, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1912, 6711, 181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1928, 6767, 1086, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1913, 6711, 1132, 11, '');
INSERT INTO 'dancestunesmap' VALUES (7098, 9883, 8467, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2107, 5539, 2986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2150, 5217, 3150, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2151, 5188, 673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1926, 6756, 437, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2106, 3828, 1795, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2164, 3847, 1266, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2080, 3280, 788, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2110, 4853, 1796, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2145, 2278, 2000, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2037, 7172, 1829, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2123, 1192, 2706, 3, '');
INSERT INTO 'dancestunesmap' VALUES (2155, 1131, 3231, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2108, 919, 1705, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2096, 7557, 1985, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2097, 7557, 165, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2048, 7204, 1711, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8575, 14325, 5077, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8524, 13385, 544, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8553, 14287, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8564, 11553, 6443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2139, 5686, 3124, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8551, 14285, 1648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2086, 7339, 11, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2149, 6640, 2939, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2148, 6035, 2869, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2152, 354, 2443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2163, 3441, 3236, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2077, 1834, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2058, 7230, 865, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2045, 7197, 835, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8563, 3328, 2940, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8532, 13127, 11723, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2166, 4375, 3237, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2168, 6145, 1416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2173, 6985, 1284, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2174, 7059, 3240, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2175, 7130, 3241, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2196, 949, 850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2199, 564, 1745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2211, 1492, 2209, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2213, 4618, 2638, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2219, 329, 3263, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2220, 413, 943, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2221, 518, 2413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2228, 2126, 3265, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2236, 5384, 3268, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8599, 13355, 10122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8579, 14327, 3497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8587, 13521, 10876, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8588, 13262, 10875, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8590, 13261, 10254, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8592, 13264, 10459, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8593, 13266, 10488, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8596, 13268, 10247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8598, 14328, 4722, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8604, 11285, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2205, 3021, 1687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2261, 1078, 267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2262, 1078, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2267, 1649, 3092, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2268, 1699, 1084, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2269, 1721, 407, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2276, 1633, 2654, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2290, 948, 3282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2291, 2735, 3283, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2300, 8, 3296, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2301, 575, 3299, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2302, 149, 3300, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2303, 7787, 1765, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2304, 7788, 3093, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2305, 7818, 2159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2306, 7819, 2512, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2307, 5162, 2749, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2309, 7840, 853, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2310, 6117, 853, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8595, 13267, 5490, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2195, 7539, 3247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2210, 7124, 2193, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2232, 4943, 3163, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8600, 13356, 10134, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8609, 14344, 11985, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2285, 2563, 3278, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2171, 6909, 3238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8616, 14357, 11987, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2260, 1708, 111, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8583, 13362, 10151, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2238, 6459, 133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2187, 5256, 3242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8613, 14351, 1166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2181, 4355, 2610, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8614, 14353, 2452, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8611, 14348, 11986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8617, 14358, 11987, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8619, 14360, 8888, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8618, 14360, 8887, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8612, 14350, 9898, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2143, 6823, 1664, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8608, 14343, 10993, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2277, 451, 965, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8519, 14185, 398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8607, 14342, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2222, 700, 3185, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2053, 7215, 1648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8584, 13360, 10146, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2202, 2396, 3253, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8591, 13263, 10476, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2250, 695, 3271, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2299, 3996, 3290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2190, 7474, 463, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2055, 7219, 1839, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2133, 899, 2609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2104, 6523, 2920, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2249, 485, 2443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2194, 7534, 2850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8589, 13260, 10253, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8560, 14294, 11758, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2144, 6862, 1745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2170, 6450, 2506, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2209, 202, 3261, 1, '');
INSERT INTO 'dancestunesmap' VALUES (2191, 7517, 3244, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2235, 5237, 2887, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2050, 7210, 1838, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2192, 7527, 3245, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2233, 5034, 3178, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2193, 7529, 3246, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2189, 7465, 3249, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2090, 7375, 107, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2251, 708, 2025, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2023, 7111, 1620, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2271, 1960, 1896, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8586, 13365, 10157, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2244, 2125, 2482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2275, 1556, 3260, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2266, 868, 841, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2292, 5976, 3284, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2092, 7406, 149, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2188, 7388, 3248, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2043, 7193, 862, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2243, 7043, 2815, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2169, 6219, 2031, 10, 'Played ABAB');
INSERT INTO 'dancestunesmap' VALUES (2283, 5685, 3276, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2214, 4273, 2242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8565, 14040, 2905, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2231, 4411, 1364, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2206, 3553, 2125, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2128, 822, 2830, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2180, 3381, 2602, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2185, 3114, 2633, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8615, 14354, 8518, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2159, 2199, 305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2286, 2124, 3279, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2270, 1905, 3258, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2201, 1851, 1068, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2227, 1535, 3249, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2225, 1285, 2473, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2258, 1145, 386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2063, 7245, 1842, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2062, 7242, 1841, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2278, 7195, 1945, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2042, 7189, 695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2129, 2453, 2832, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2179, 1573, 2604, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2240, 6913, 3269, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2208, 6961, 3256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7097, 9883, 8466, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2207, 6621, 3255, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2282, 1896, 2110, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2263, 218, 55, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2183, 4809, 2617, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2114, 4022, 1748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2297, 3791, 3289, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2288, 3538, 1856, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2216, 3317, 2261, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2177, 3309, 792, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2203, 2568, 2219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2217, 2333, 2267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2212, 2237, 2217, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2280, 1760, 3274, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2281, 1712, 3275, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2223, 904, 266, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2218, 107, 3262, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2246, 549, 1937, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2245, 439, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2247, 387, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2198, 382, 88, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2197, 378, 3250, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2241, 268, 591, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2060, 7239, 48, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2257, 929, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8578, 14326, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8581, 13366, 10158, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8585, 13361, 10150, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10303, 18536, 2932, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8582, 13358, 2269, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8610, 14346, 3469, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2265, 7531, 996, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2264, 7531, 3257, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2184, 7262, 2618, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2239, 7060, 3270, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2178, 6229, 2606, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2289, 5593, 3281, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2234, 5199, 3267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2167, 4668, 1897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2284, 4575, 3277, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2259, 3755, 1133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2230, 3504, 2996, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2229, 3461, 1636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2287, 2433, 3280, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2295, 2050, 2190, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2255, 1566, 3272, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2224, 1250, 1403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2176, 1654, 2591, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2226, 1426, 3264, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2326, 11, 1166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2327, 11, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2328, 12, 764, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2332, 19, 1759, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8632, 14369, 8399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8634, 14378, 495, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2334, 21, 3310, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2336, 24, 3311, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2337, 25, 3312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2338, 27, 3313, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2341, 28, 1665, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2343, 35, 3314, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2344, 36, 482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2345, 37, 3315, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2346, 3, 1284, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2348, 41, 3316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2349, 42, 1762, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2353, 6937, 3319, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2356, 7136, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2357, 7136, 3321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2359, 49, 352, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2360, 61, 3322, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2361, 62, 1765, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2362, 63, 17, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2366, 70, 3323, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2367, 71, 3324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2368, 75, 915, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2373, 84, 1270, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2374, 86, 3327, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2375, 87, 3328, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2378, 7290, 3330, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2379, 7294, 719, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2380, 101, 3331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2382, 94, 3332, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2385, 105, 2802, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2386, 106, 3334, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2391, 99, 3337, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2392, 110, 3338, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2393, 111, 3339, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2395, 115, 32, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2397, 121, 664, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2398, 122, 312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2399, 118, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2400, 125, 2123, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2401, 133, 121, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2402, 134, 2415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2404, 3736, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2405, 136, 601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2406, 142, 369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2407, 143, 3340, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2409, 145, 3342, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2411, 147, 3343, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2412, 148, 808, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2413, 7562, 1226, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2414, 151, 3344, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2418, 167, 3347, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2423, 7579, 1311, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2424, 7580, 1428, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2425, 180, 2611, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2389, 97, 90, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8649, 11279, 858, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8650, 11279, 598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8651, 11279, 1503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8652, 11288, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8653, 11291, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8654, 11295, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8661, 12334, 2597, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8666, 8378, 12083, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8684, 14465, 1894, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8686, 14467, 2386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8703, 3426, 98, 10, 'Tune now recommended (2012)');
INSERT INTO 'dancestunesmap' VALUES (8704, 14485, 7409, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8705, 14486, 2588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8708, 14518, 10058, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8710, 14520, 503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8624, 14366, 11989, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2408, 144, 3341, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2384, 95, 3333, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8663, 14425, 12044, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8620, 14362, 11988, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8629, 14375, 11991, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8656, 14419, 10062, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2352, 48, 360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8719, 9911, 1059, 1, '');
INSERT INTO 'dancestunesmap' VALUES (8720, 9911, 9538, 2, '');
INSERT INTO 'dancestunesmap' VALUES (8640, 14392, 12000, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8700, 11587, 5951, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8635, 14379, 11994, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8701, 11949, 559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8647, 12983, 7046, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8627, 14373, 821, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8633, 14372, 11993, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2421, 6337, 593, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2396, 117, 1193, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8641, 14394, 2702, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2355, 54, 299, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2388, 7359, 3336, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2387, 7359, 3335, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8657, 13593, 11269, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8646, 14403, 1691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8637, 14381, 3140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8638, 14384, 872, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8678, 14428, 2650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2347, 38, 1261, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8622, 14364, 8521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8662, 14420, 5436, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2410, 146, 2482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8709, 14519, 7660, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2204, 2805, 3254, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2422, 175, 829, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2394, 114, 32, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2420, 171, 3348, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2200, 946, 3251, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2324, 9, 3306, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2371, 83, 2731, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8658, 13594, 11272, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2296, 3383, 3288, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2377, 7272, 3329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2340, 30, 2007, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2279, 7159, 3273, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2363, 345, 360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8679, 14429, 3033, 10, 'Strathspey');
INSERT INTO 'dancestunesmap' VALUES (2381, 92, 209, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8683, 14460, 12162, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8630, 14371, 11992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2256, 280, 1834, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8628, 14377, 11990, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2331, 16, 3308, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8725, 12569, 156, 3, '');
INSERT INTO 'dancestunesmap' VALUES (8639, 14386, 11995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2330, 14, 1971, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2376, 88, 62, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2416, 162, 3345, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2321, 8049, 534, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8623, 14365, 1830, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8648, 587, 10314, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2272, 3180, 3259, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2372, 77, 3326, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2323, 5378, 3058, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2322, 2686, 1659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2325, 10, 3307, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2358, 59, 982, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2403, 135, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2312, 2882, 237, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2311, 7852, 1840, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2319, 2513, 417, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2383, 103, 1346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2370, 82, 1015, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2369, 81, 3325, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8707, 14013, 10287, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8625, 14368, 1940, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2339, 29, 2396, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2317, 916, 3304, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2390, 7421, 1757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2316, 916, 3303, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8659, 10256, 528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8668, 14432, 12054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8667, 14432, 12053, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2417, 160, 3346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2364, 67, 663, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2320, 8069, 2696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8732, 14538, 11553, 10, 'see notes');
INSERT INTO 'dancestunesmap' VALUES (8733, 14539, 424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8734, 14539, 992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8735, 14539, 2218, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2476, 255, 3366, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8738, 13405, 10025, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8740, 5755, 5634, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8742, 14559, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8743, 3343, 11553, 10, 'the author adds "(or reel)"');
INSERT INTO 'dancestunesmap' VALUES (8747, 14569, 9984, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8749, 14575, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8765, 14594, 1963, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2455, 7589, 3359, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2426, 180, 2536, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2430, 158, 68, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2432, 196, 3350, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2433, 7584, 3351, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2434, 199, 1453, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2435, 199, 692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2439, 7341, 2986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2440, 201, 1328, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2441, 204, 1378, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2443, 7585, 614, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2444, 7586, 1870, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2445, 207, 51, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2446, 208, 3353, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2449, 211, 424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2451, 7588, 3355, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2452, 7588, 3356, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2453, 217, 3357, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2454, 217, 3358, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2457, 225, 186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2458, 227, 1748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2462, 234, 2543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2463, 233, 3362, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2466, 236, 586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2468, 238, 3363, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2469, 239, 1600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2473, 251, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2474, 252, 3365, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2475, 254, 3004, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2477, 256, 3142, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2478, 247, 3367, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2479, 260, 769, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2482, 266, 1880, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2484, 272, 3370, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2487, 263, 1687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2489, 277, 68, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2490, 283, 1621, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2491, 284, 1137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2493, 285, 1135, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2497, 293, 430, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2500, 296, 1232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2501, 297, 66, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2502, 299, 3373, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2506, 7596, 1940, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2507, 305, 3374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2511, 310, 1533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2513, 5, 1243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2514, 315, 822, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2515, 317, 3321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2516, 7346, 1227, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2518, 325, 769, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2520, 7599, 342, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2522, 331, 32, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2528, 7601, 671, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2529, 343, 763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2530, 349, 78, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2531, 351, 81, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2532, 356, 1514, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2534, 363, 243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2537, 369, 1081, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2538, 370, 71, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2539, 376, 2165, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2540, 347, 1213, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2541, 379, 3386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2542, 381, 3387, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2543, 381, 3388, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2544, 383, 2423, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2545, 384, 3389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2546, 388, 3390, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2550, 346, 590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2552, 402, 3392, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2553, 403, 256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2481, 265, 3369, 2, '');
INSERT INTO 'dancestunesmap' VALUES (2480, 265, 3368, 1, '');
INSERT INTO 'dancestunesmap' VALUES (8687, 14468, 12172, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8702, 1520, 6692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8706, 14487, 6492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8711, 14521, 858, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2555, 408, 1482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2556, 7606, 2055, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2558, 412, 3394, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2559, 415, 655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2521, 328, 3378, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8726, 14532, 5865, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8745, 1358, 12201, 20, '');
INSERT INTO 'dancestunesmap' VALUES (8764, 14593, 7845, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8763, 14593, 2442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2495, 291, 1875, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2533, 361, 3383, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2554, 405, 3393, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2494, 286, 1618, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2461, 231, 3361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8748, 9889, 768, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8727, 14533, 5949, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2547, 7604, 88, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2517, 318, 3376, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2438, 200, 1082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8754, 14580, 2816, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2427, 189, 329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2335, 22, 2576, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2437, 198, 49, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2419, 168, 1875, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8736, 14540, 1262, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2512, 313, 73, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2415, 154, 1198, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2450, 212, 495, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8752, 14572, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8750, 14573, 8386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2354, 52, 3320, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2351, 47, 3318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2442, 205, 2451, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2498, 294, 1424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2350, 46, 3317, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2472, 249, 1460, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2535, 366, 3384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2342, 32, 3002, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2499, 295, 1424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2447, 209, 1374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2429, 185, 3349, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2496, 292, 3372, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8766, 14595, 2177, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8751, 14571, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2524, 334, 3380, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2510, 275, 2321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2527, 337, 2120, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2523, 333, 76, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2519, 322, 3377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1474, 5120, 5634, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2318, 4120, 3305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2505, 304, 68, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2483, 270, 64, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8685, 14466, 12170, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8670, 14433, 12054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8693, 14476, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2470, 240, 3364, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2436, 197, 3352, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8771, 14598, 12231, 20, '2nd tune');
INSERT INTO 'dancestunesmap' VALUES (8655, 13447, 10526, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2557, 411, 318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8741, 14551, 7710, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8724, 12569, 1613, 2, '');
INSERT INTO 'dancestunesmap' VALUES (2467, 237, 280, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8768, 14596, 973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2485, 273, 1942, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2549, 397, 763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2525, 335, 3381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2503, 300, 3373, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2464, 235, 355, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2459, 228, 3360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8744, 13259, 4889, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8682, 14430, 12097, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8664, 14426, 12049, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2172, 4704, 3239, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2536, 367, 3385, 1, '');
INSERT INTO 'dancestunesmap' VALUES (2456, 224, 1331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2488, 264, 3371, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2471, 7591, 159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8728, 14534, 9456, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2551, 398, 434, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2548, 385, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8739, 14543, 12200, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2448, 210, 3354, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2562, 7607, 3395, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2563, 421, 3396, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2564, 426, 599, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2565, 422, 3397, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2567, 429, 3398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2568, 433, 1797, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2569, 435, 542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2570, 436, 109, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2571, 437, 3399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2572, 438, 3400, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2575, 448, 3297, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2576, 449, 3298, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2577, 450, 2774, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2662, 6240, 3439, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2579, 460, 3404, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2583, 3554, 1328, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2585, 468, 602, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2586, 469, 761, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2588, 478, 1915, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2590, 481, 3408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2595, 488, 3410, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2596, 490, 1605, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2598, 492, 3412, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2600, 496, 342, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2605, 506, 3417, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2607, 512, 3420, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2610, 524, 3421, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2611, 525, 1023, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2612, 526, 1565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2613, 527, 3422, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2617, 558, 1940, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2618, 536, 123, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2619, 537, 429, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2624, 552, 657, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2627, 554, 1774, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2630, 563, 2262, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2631, 565, 3256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2632, 562, 742, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2633, 568, 305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2634, 569, 3427, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2636, 579, 1361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2643, 591, 2159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2644, 592, 3432, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8671, 14434, 12060, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8712, 14522, 1745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8757, 14579, 2616, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8777, 14552, 12240, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8778, 14619, 12238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8779, 14612, 12236, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8781, 14634, 12286, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8783, 14637, 9173, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8789, 11518, 568, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8798, 1557, 2645, 20, '');
INSERT INTO 'dancestunesmap' VALUES (8800, 4921, 12430, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8804, 14701, 8016, 10, 'From the suggested recording');
INSERT INTO 'dancestunesmap' VALUES (8805, 14705, 2575, 10, 'From the suggested recording');
INSERT INTO 'dancestunesmap' VALUES (8806, 14706, 1971, 10, 'Played AABBB''');
INSERT INTO 'dancestunesmap' VALUES (8807, 14707, 2321, 10, 'From the suggested recording');
INSERT INTO 'dancestunesmap' VALUES (8808, 14707, 2988, 10, 'From the suggested recording');
INSERT INTO 'dancestunesmap' VALUES (8809, 14710, 7656, 10, 'From the suggested recording');
INSERT INTO 'dancestunesmap' VALUES (8815, 14718, 179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2649, 602, 133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2651, 613, 1687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2652, 615, 521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2653, 616, 3435, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2654, 617, 3436, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2655, 619, 374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2656, 618, 3437, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2658, 620, 834, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2661, 621, 1766, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2663, 623, 1016, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2665, 631, 2123, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2666, 634, 911, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2667, 1394, 1146, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2668, 6917, 1167, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2670, 637, 834, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2671, 637, 2717, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2672, 639, 3458, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2677, 643, 150, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2681, 648, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2683, 651, 68, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2685, 653, 3461, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2687, 659, 1542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2688, 661, 1790, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2689, 663, 236, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2690, 667, 1957, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8665, 14427, 12050, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8791, 14686, 12424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8790, 10819, 12422, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8785, 14648, 1458, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2599, 495, 3413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2566, 423, 1744, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2692, 673, 2792, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8729, 14535, 9853, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2673, 640, 148, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2597, 489, 3411, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8775, 10655, 2219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8782, 14636, 259, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8787, 14661, 12410, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2646, 595, 3433, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2609, 523, 1748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8784, 5430, 12359, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2645, 594, 3405, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8776, 12243, 10038, 10, 'JG: The tune has specially constructed phrasing to fit the dance');
INSERT INTO 'dancestunesmap' VALUES (2676, 642, 3336, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2675, 642, 3335, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2642, 590, 3431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2635, 573, 1943, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8688, 14469, 12173, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8803, 14694, 7775, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2628, 556, 2680, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2587, 476, 1914, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2581, 464, 2704, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2623, 551, 2559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2674, 641, 2611, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2615, 533, 122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2582, 463, 3407, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2589, 479, 111, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2593, 431, 614, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2603, 498, 551, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2629, 557, 3426, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2584, 467, 312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2684, 684, 3460, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2594, 484, 1918, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2592, 483, 3409, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8811, 14578, 2458, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8812, 8202, 11360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2608, 513, 285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8694, 14479, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8695, 14480, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2648, 597, 916, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2650, 603, 992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2637, 583, 3428, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2647, 596, 3434, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8788, 11774, 1414, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2486, 262, 593, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8774, 14458, 12155, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2641, 599, 1948, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2682, 649, 3457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2460, 230, 482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2606, 508, 3418, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2669, 636, 2579, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2508, 307, 71, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2561, 418, 100, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2693, 675, 1962, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2604, 503, 3416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2622, 550, 2442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8786, 13613, 11352, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2639, 587, 953, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10242, 7164, 1674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2626, 559, 1656, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2691, 672, 3463, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2686, 660, 3462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2678, 644, 1809, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2621, 547, 932, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2601, 497, 3414, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2574, 443, 3401, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2573, 440, 2577, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2431, 157, 3053, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8780, 12665, 2212, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2657, 605, 241, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2614, 529, 3423, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10241, 18310, 9700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2591, 482, 1917, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2659, 606, 3438, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2664, 630, 3440, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2694, 678, 1674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2698, 709, 3466, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2705, 706, 3469, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2708, 714, 3471, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2709, 601, 3472, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2714, 718, 310, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2717, 724, 3474, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2718, 725, 3475, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2721, 734, 3478, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2722, 757, 715, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2723, 746, 413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2724, 747, 3479, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2725, 748, 3480, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2731, 1779, 137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2732, 764, 3483, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2734, 766, 247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2735, 770, 176, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2736, 772, 2597, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2738, 777, 3485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8689, 14470, 12175, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8713, 14523, 2556, 10, 'Original tune');
INSERT INTO 'dancestunesmap' VALUES (8714, 14523, 1117, 11, 'Alternative tune');
INSERT INTO 'dancestunesmap' VALUES (2740, 787, 3487, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2741, 788, 3488, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2743, 792, 3192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2744, 793, 2507, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2746, 798, 3491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2747, 799, 2118, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2748, 799, 2738, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2750, 808, 242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2751, 5588, 1582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2761, 825, 558, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2762, 826, 2531, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2763, 826, 3496, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2765, 832, 1644, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2767, 836, 1988, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2772, 847, 695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2773, 849, 558, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2774, 851, 1143, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2778, 864, 3499, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2779, 865, 3500, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2780, 866, 3312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2782, 872, 3501, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2784, 879, 663, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2786, 882, 3504, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2791, 901, 3492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2792, 911, 3506, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2793, 912, 224, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2794, 913, 3507, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2797, 918, 432, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2798, 7625, 671, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2800, 921, 763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2804, 927, 430, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2806, 930, 3510, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2809, 943, 380, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2810, 7626, 722, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2811, 944, 3512, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2812, 951, 232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2813, 952, 3513, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2814, 953, 1788, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2815, 953, 3513, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2816, 957, 3514, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2817, 961, 382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2821, 967, 2561, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2822, 967, 188, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2823, 966, 672, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2824, 968, 234, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2825, 969, 3517, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8715, 14524, 12195, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2830, 979, 3521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2831, 982, 1408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8759, 14586, 12206, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8760, 14586, 32, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8793, 14684, 12426, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2832, 7628, 171, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2834, 993, 1582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2837, 996, 2790, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2838, 3707, 242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2839, 997, 3524, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2845, 1006, 346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2848, 1010, 3528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2849, 1011, 81, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2852, 1014, 2017, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2853, 1016, 2018, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2854, 1021, 254, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2855, 1026, 2531, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2856, 1026, 3531, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2858, 1023, 3533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2697, 696, 3465, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2818, 963, 3515, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2790, 900, 1958, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2739, 780, 3486, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8672, 14435, 12064, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2805, 928, 228, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2827, 959, 3518, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2771, 846, 1753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2826, 970, 1620, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2712, 6839, 1140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2711, 716, 1140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2808, 938, 521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2700, 699, 3467, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8697, 14482, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8792, 14685, 12425, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2783, 873, 1992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2777, 863, 3498, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2801, 917, 3312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2820, 965, 761, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8690, 14471, 12176, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2759, 820, 717, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2755, 810, 1089, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2737, 776, 188, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2727, 751, 3481, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2625, 560, 3424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8731, 14537, 9050, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2807, 935, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8730, 14536, 12198, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2730, 759, 1974, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2616, 534, 122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2775, 854, 3110, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2760, 824, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2695, 686, 3464, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2704, 705, 2016, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2770, 843, 1142, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2844, 1004, 3526, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2857, 1027, 3532, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2850, 1013, 3529, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2715, 721, 3192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2840, 999, 3408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2795, 128, 1462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2829, 976, 3520, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3581, 2430, 3818, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2729, 737, 182, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2707, 712, 9833, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2745, 795, 3490, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2819, 964, 1659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2776, 861, 358, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8758, 14583, 12205, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8772, 14599, 12232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2699, 698, 183, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2756, 811, 2472, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2768, 838, 1658, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2680, 647, 1957, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2789, 892, 3505, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2787, 885, 3438, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2706, 7353, 1775, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2860, 1037, 3384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2841, 1000, 955, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2560, 416, 98, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2846, 1009, 3527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2847, 1009, 1907, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2742, 790, 3489, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2719, 727, 3476, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2835, 994, 3523, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2788, 885, 3318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2799, 920, 226, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2843, 1003, 3525, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2720, 730, 3477, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2851, 1012, 3530, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2802, 925, 3508, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2766, 834, 1448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2758, 815, 3495, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8801, 1609, 1361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2796, 915, 2423, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2781, 871, 545, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2769, 841, 1638, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2749, 807, 3492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2733, 765, 3484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2728, 735, 3482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2716, 722, 76, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2696, 629, 369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8696, 14481, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2764, 828, 3497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2803, 926, 3509, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2757, 813, 1984, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2726, 751, 27, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2836, 995, 242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2861, 7632, 76, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2862, 7633, 3534, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2863, 1036, 3535, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2865, 1041, 3536, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2866, 1043, 2964, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2867, 7634, 3537, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2868, 1047, 3538, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2869, 1052, 3539, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2870, 1054, 3541, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2871, 1055, 419, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2873, 1063, 1662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2875, 7638, 358, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2878, 7639, 3542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2879, 1076, 3543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2880, 7640, 1146, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2881, 1079, 3544, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2885, 1092, 3546, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2887, 1095, 2029, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2888, 1081, 324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2889, 1081, 555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2890, 1083, 1578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2891, 1098, 62, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2892, 1082, 939, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2895, 1101, 1603, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2896, 1102, 2031, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2897, 1104, 3548, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2898, 1105, 1673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2900, 1111, 1533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2901, 7643, 3549, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2903, 1118, 81, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2904, 1116, 128, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2905, 1115, 1082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2907, 1121, 2326, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2909, 1126, 1407, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2910, 1126, 921, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2911, 1129, 3550, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2912, 1129, 829, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2913, 7361, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2914, 1130, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2917, 1134, 3551, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2918, 1137, 802, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2919, 1135, 1512, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2920, 1138, 1797, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2921, 1140, 427, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2923, 1149, 1374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8675, 14437, 12074, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8761, 14587, 116, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2927, 1156, 2796, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2929, 1159, 1643, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2931, 1164, 1198, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2933, 1166, 3192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2934, 1167, 2616, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2935, 1169, 3558, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2940, 1181, 3559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2941, 1185, 3430, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2942, 1035, 3560, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2951, 1199, 802, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2864, 1040, 2559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2954, 1205, 2995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2955, 1206, 3565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2957, 1209, 2369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2958, 1214, 860, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2960, 1216, 2305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2962, 1219, 284, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2963, 1222, 649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2965, 1224, 100, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2966, 1225, 763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2967, 1228, 2626, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2968, 1230, 2971, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2970, 1236, 384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2972, 1239, 915, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2973, 1241, 378, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2975, 1243, 3569, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2977, 1248, 3570, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2979, 1249, 2378, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2980, 1253, 3572, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2981, 7650, 3573, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2984, 1258, 3575, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2988, 1266, 297, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2989, 1270, 3577, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2991, 1263, 3578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2992, 1272, 3579, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2995, 1276, 303, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2997, 1279, 1914, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2999, 1284, 1166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3000, 1284, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3002, 1286, 3581, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3004, 1289, 305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3006, 1290, 299, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3007, 1292, 3584, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3009, 1301, 1582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3011, 1303, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3012, 1305, 1609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3013, 1306, 669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3014, 1309, 1024, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3015, 1309, 1915, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3016, 1310, 3585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3018, 1312, 1482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3019, 1317, 3586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3022, 1324, 1846, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3023, 1325, 2611, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3024, 1325, 168, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3025, 1326, 2525, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3026, 1327, 3358, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3027, 7655, 568, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3030, 1334, 1511, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3031, 3556, 1741, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3032, 1337, 1965, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3034, 1341, 3588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3037, 1346, 1171, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3038, 1351, 3590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2916, 7362, 498, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3029, 1330, 1785, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2915, 1133, 1744, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3035, 1344, 3589, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2994, 1274, 1757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2874, 1062, 1503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8698, 14483, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2922, 1148, 3449, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2944, 1187, 2138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3008, 1298, 3390, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2859, 1025, 3360, 1, '');
INSERT INTO 'dancestunesmap' VALUES (2986, 1264, 3576, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2987, 1267, 297, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8794, 14683, 12427, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2947, 1197, 1448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2877, 1069, 450, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2876, 1065, 1659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2998, 1282, 1692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2952, 1204, 3564, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3003, 1288, 3582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3001, 1287, 3580, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2969, 1235, 217, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2899, 1108, 2050, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2924, 1151, 3553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2996, 1278, 2527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2978, 897, 3571, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2993, 1273, 179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2894, 931, 280, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10222, 17799, 13605, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2908, 7360, 1213, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2884, 1086, 285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3021, 1322, 1459, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2930, 1160, 3556, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2982, 1256, 2503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2976, 8086, 290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3033, 1342, 3587, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2928, 1155, 1842, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2956, 1207, 3566, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2906, 1119, 1507, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2893, 1099, 1621, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2990, 1262, 295, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3039, 1353, 1683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2939, 1180, 3361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3028, 1329, 2457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3017, 1311, 3394, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2964, 1223, 2279, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2937, 1173, 3113, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2985, 1259, 1618, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2882, 1080, 1949, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2943, 1186, 2038, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3010, 7653, 981, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3020, 1320, 2063, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2872, 1056, 238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2936, 1172, 278, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2938, 1178, 2037, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2974, 1242, 3568, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2950, 1200, 186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2932, 1165, 3557, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2946, 1194, 1781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2926, 1153, 1849, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2902, 1113, 2254, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2925, 1152, 3554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2886, 1093, 3547, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3005, 7652, 3583, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3040, 1347, 1401, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3042, 1355, 3592, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3044, 1361, 2725, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3045, 1362, 3593, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3047, 1369, 3595, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3048, 1371, 3596, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3049, 1374, 451, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3050, 1377, 3597, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3051, 1380, 3599, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3052, 1381, 3600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8692, 14473, 12178, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8717, 14526, 12197, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8795, 14682, 12428, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3057, 1391, 3602, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3058, 1397, 338, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3060, 1408, 3604, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3061, 1411, 3605, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3064, 7660, 1290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3065, 1419, 3606, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3067, 1423, 3149, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3069, 2470, 3609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3071, 1433, 1792, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3074, 1440, 342, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3076, 7663, 671, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3077, 1442, 3633, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3078, 1448, 2966, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3081, 7665, 3634, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3084, 1462, 137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3085, 8089, 3312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3086, 1468, 3635, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3087, 1468, 2988, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3089, 1482, 352, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3094, 1493, 2077, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3096, 1497, 761, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3097, 1502, 608, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3099, 1509, 97, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3102, 1512, 3639, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3103, 1514, 1557, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3104, 1516, 503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3105, 1525, 181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3108, 1522, 3641, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3110, 1523, 1096, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3112, 1532, 1179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3113, 1531, 3642, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3115, 1538, 368, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3117, 1545, 650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3122, 1557, 3646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3123, 1559, 2305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3129, 1570, 3649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3131, 1576, 376, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3132, 1575, 375, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3134, 1580, 2091, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3136, 7673, 3651, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3138, 1589, 2556, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3139, 1594, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3140, 3757, 3652, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3141, 1597, 1290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3142, 1598, 958, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3144, 1602, 1470, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3145, 1604, 3654, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8677, 14439, 12078, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3106, 1520, 241, 10, 'Tune not mentioned on the original description');
INSERT INTO 'dancestunesmap' VALUES (3178, 7681, 3309, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3147, 1583, 722, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3148, 1585, 388, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3150, 1630, 3655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3151, 1630, 3656, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3152, 7675, 441, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3153, 1610, 533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3154, 1611, 3657, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3155, 1612, 3658, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3158, 7676, 3661, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3160, 1619, 2259, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3161, 1620, 3662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3163, 1623, 2101, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3165, 1627, 3663, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3167, 1631, 388, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3168, 7677, 452, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3175, 1658, 41, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3176, 1662, 425, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3180, 7379, 342, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3181, 1670, 3431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3182, 1670, 2413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3186, 1680, 3669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3187, 1682, 648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3189, 1683, 3670, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3190, 1673, 3671, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3191, 1675, 3672, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3192, 1685, 3673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3193, 1686, 3674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3195, 1687, 403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3197, 1691, 790, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3198, 1691, 3673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3199, 1693, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3200, 1694, 390, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3109, 1528, 608, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3203, 7683, 3675, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3204, 1702, 3676, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3205, 1703, 2118, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3206, 1705, 346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3207, 1706, 3677, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3209, 1710, 2119, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3212, 1718, 3679, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3214, 1723, 981, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3215, 1724, 3680, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3216, 1727, 3681, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3092, 1485, 3637, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3070, 1430, 1166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8699, 14484, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3043, 1358, 322, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3146, 1605, 1621, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3098, 1506, 3638, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3068, 7662, 3608, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3210, 1713, 3678, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3166, 1629, 558, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3114, 1537, 655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3063, 1417, 1426, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3082, 1458, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3093, 1486, 1762, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3080, 1456, 238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3208, 1709, 124, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3120, 1554, 3644, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3211, 1716, 3321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3185, 1679, 3668, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3170, 1638, 3664, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3119, 1549, 2959, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3100, 1510, 305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3054, 1388, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3118, 7670, 1834, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3137, 1489, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3095, 1494, 360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3174, 1655, 3666, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3090, 1484, 3636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3130, 1571, 3650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3217, 1728, 3682, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3218, 1734, 287, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3219, 1730, 1015, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3220, 1737, 3321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3221, 1738, 3684, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3213, 1719, 246, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3202, 1696, 663, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3079, 1449, 1121, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3177, 1664, 3667, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3149, 1584, 384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3159, 1616, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3066, 1420, 3607, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3126, 1563, 209, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3055, 1389, 1401, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3091, 1481, 1068, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3135, 1581, 3186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3072, 1438, 346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3062, 1413, 2152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3124, 1560, 3312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3041, 1354, 3591, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3194, 1688, 403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3179, 7382, 1582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3133, 1577, 1775, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3127, 1567, 195, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3125, 1564, 141, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3111, 1526, 919, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3121, 1513, 3572, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3059, 1402, 1091, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8676, 14438, 12077, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3083, 1460, 1683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3073, 1443, 347, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3196, 1689, 403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3164, 1626, 390, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3162, 1622, 2456, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3173, 1652, 1482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3188, 1681, 13, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3184, 1678, 398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3171, 1643, 2253, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3169, 1634, 3248, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3056, 1390, 3601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3053, 1382, 333, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3046, 1364, 873, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3116, 1541, 3643, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3222, 1739, 3685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3223, 7684, 3685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3224, 1740, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3228, 1746, 3686, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3229, 1748, 3687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3232, 7685, 1621, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3234, 1753, 552, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3236, 1754, 1903, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3237, 6359, 1942, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8797, 14431, 12423, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3239, 1755, 2118, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3240, 1759, 423, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3241, 1761, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3247, 1778, 432, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3248, 1785, 432, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3250, 1788, 3690, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3254, 1797, 3693, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3255, 1798, 450, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3257, 1803, 452, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3259, 1810, 3696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3260, 1812, 3697, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3261, 1815, 456, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3265, 1828, 3484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3269, 1827, 3701, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3271, 1836, 3702, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3272, 1837, 1557, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3339, 1969, 932, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3276, 1845, 1404, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3277, 1846, 463, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3278, 1849, 467, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3280, 7693, 2611, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3281, 7693, 168, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3283, 1855, 3706, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3284, 1859, 3707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3286, 1863, 3590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3288, 1865, 3709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3292, 7697, 588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3293, 1871, 3643, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3294, 1874, 278, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3300, 1886, 481, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3301, 1887, 2910, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3304, 1890, 159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3308, 1900, 1193, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3310, 1904, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3314, 1910, 1428, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3316, 1917, 346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3318, 1918, 3714, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3319, 1919, 3715, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3321, 1922, 312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3322, 1923, 2825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3323, 1925, 3716, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3327, 1933, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3328, 7700, 122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3329, 7701, 1257, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3330, 1941, 2163, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3334, 1950, 688, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3338, 1964, 419, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3340, 1970, 3721, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3341, 1971, 2021, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3342, 1973, 1540, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3343, 1975, 3722, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3345, 1976, 3724, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3347, 1978, 1228, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3349, 1980, 1578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3353, 7703, 3727, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3354, 1988, 3728, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3355, 1988, 3197, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3357, 1991, 3729, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3358, 1993, 1297, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3359, 1994, 3730, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3361, 1999, 1013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3363, 2007, 234, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3364, 7706, 1084, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3366, 7391, 1748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3369, 2017, 1377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3372, 2022, 3735, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3375, 2028, 3738, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3376, 5965, 545, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3377, 2029, 3739, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3379, 2031, 1618, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3383, 2043, 90, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3384, 7709, 498, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3385, 2046, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3386, 2047, 2413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3389, 2057, 3056, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3391, 2061, 2150, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3393, 2065, 517, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3396, 2070, 3741, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3397, 2080, 1621, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3399, 2083, 930, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3400, 2086, 2180, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3350, 1981, 3725, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3235, 7686, 226, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3356, 1989, 2169, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3233, 1752, 350, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3348, 1979, 533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3315, 1912, 2021, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3370, 2018, 1600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3309, 1902, 3712, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3231, 3378, 2737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3367, 2014, 1683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3335, 1951, 2853, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3373, 2023, 3736, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3270, 1833, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3225, 1742, 2128, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3253, 1795, 1022, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3305, 1898, 3711, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3295, 1875, 2151, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3230, 1484, 3688, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3371, 2019, 384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3403, 2092, 55, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3409, 8109, 3748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3412, 8090, 1952, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3413, 8090, 3749, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3274, 7692, 3703, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3289, 1867, 1453, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3398, 2081, 17, 10, 'as Alex Maxwell''s Farewell to Balmerino');
INSERT INTO 'dancestunesmap' VALUES (3390, 2060, 178, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3320, 1921, 2162, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3362, 2002, 3733, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3404, 2093, 3745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3306, 1901, 1825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3282, 1853, 3705, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3410, 7656, 3007, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3346, 1977, 2326, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3411, 7656, 3011, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3243, 7687, 1687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3387, 2051, 2092, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3245, 1772, 3689, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3326, 1934, 753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3378, 2039, 3740, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3365, 2013, 1360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3287, 7696, 471, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3324, 6601, 1238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3244, 1770, 429, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3360, 1997, 3732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3368, 2016, 3734, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3267, 1830, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3266, 1829, 3700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3262, 1819, 1554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3258, 1804, 3695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3392, 2064, 1753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3297, 1878, 1766, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3246, 1774, 433, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3238, 1756, 2442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3380, 2032, 1582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3298, 1882, 558, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3285, 1861, 3708, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3337, 1962, 1729, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3263, 1823, 3698, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3414, 8099, 1604, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3416, 2096, 3750, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3374, 2026, 3737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3302, 1888, 68, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3311, 1906, 3713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3317, 1915, 1683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3242, 1766, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3336, 1958, 3719, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3331, 1942, 3717, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3395, 2068, 2640, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3268, 1831, 1642, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3279, 1850, 3704, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3325, 1932, 1636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3415, 8107, 2772, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3332, 1949, 3381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3264, 1822, 3699, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3299, 1885, 2410, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3401, 2087, 3743, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3394, 2067, 1965, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3382, 126, 319, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3249, 1787, 532, 1, '');
INSERT INTO 'dancestunesmap' VALUES (3252, 1791, 3692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3296, 1877, 68, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3344, 2095, 3723, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3352, 1983, 3726, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3291, 1868, 1185, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3256, 1801, 3694, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3275, 1843, 2577, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3227, 1668, 2473, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3418, 2098, 510, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3423, 2106, 3752, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3427, 2111, 3754, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3428, 2112, 3149, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3429, 2117, 2696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3430, 7713, 3755, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3431, 2120, 3756, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3432, 2127, 1401, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3433, 2132, 637, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3435, 2138, 3759, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3439, 2146, 1763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3440, 2149, 1979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3442, 2152, 3762, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3445, 2160, 613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3446, 2161, 3765, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3447, 8101, 1613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3448, 2167, 3766, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3456, 2187, 3769, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3459, 2185, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3460, 2194, 128, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3463, 2198, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3464, 2198, 98, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3465, 2202, 3772, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3466, 2200, 2180, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3467, 2201, 530, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3468, 2204, 423, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3470, 2209, 3773, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3471, 2214, 3774, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3472, 2214, 3775, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3473, 1750, 3776, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3474, 2218, 3777, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3475, 2220, 3778, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3476, 2221, 3779, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3477, 1813, 874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3523, 2310, 1283, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3479, 2230, 1193, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3481, 2234, 3780, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3483, 2240, 2806, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3484, 2241, 2973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3485, 2243, 3782, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3486, 2036, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3489, 2248, 589, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3490, 2359, 3783, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3493, 2249, 1542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3494, 2256, 1503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3497, 2765, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3499, 2262, 3787, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3500, 2264, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3502, 2268, 3507, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3504, 2273, 2779, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3505, 2274, 2862, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3506, 4740, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3507, 2283, 1313, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3509, 2282, 3788, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3510, 2286, 3789, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3511, 2287, 1565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3512, 2277, 3790, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3514, 2299, 122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3519, 2293, 14, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3520, 2303, 2654, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3521, 2316, 533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3522, 2307, 3792, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3524, 2311, 3494, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3527, 5694, 358, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3528, 2319, 3793, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3529, 2318, 541, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3530, 2320, 3794, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3532, 6083, 3796, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3533, 2324, 1542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3534, 2327, 892, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3536, 2330, 3405, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3538, 2338, 3798, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3539, 2340, 3493, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3541, 2341, 3800, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3542, 2343, 1571, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3551, 2365, 819, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3546, 2347, 3803, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3547, 2358, 2188, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3548, 2362, 550, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3552, 2366, 763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3553, 2373, 1474, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3554, 2374, 3805, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3555, 7717, 3806, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3556, 7718, 2136, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3558, 2377, 3807, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3559, 2378, 3808, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3560, 2381, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3561, 2382, 3809, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3562, 2384, 3810, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3563, 2385, 3811, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3564, 2390, 3431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3566, 2392, 3813, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3568, 7721, 3814, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3569, 2397, 3219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3571, 2411, 3816, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3572, 2412, 649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3573, 2417, 1309, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3574, 2418, 1729, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3575, 2418, 1728, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3576, 2422, 1781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3578, 2429, 1672, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3579, 2425, 3817, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3580, 2424, 3817, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3583, 2438, 2202, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3586, 2444, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3518, 2291, 769, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3584, 2439, 1353, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3454, 2182, 3336, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3480, 2231, 521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3469, 2206, 763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3513, 2290, 451, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3531, 2322, 3795, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3567, 2393, 1704, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3565, 2391, 3812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3570, 2401, 3815, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3488, 2246, 3559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3458, 1744, 1624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3402, 2089, 1098, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3450, 8097, 376, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5924, 7106, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3585, 2441, 713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4527, 4399, 1618, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3508, 2281, 3014, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3436, 2141, 81, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3408, 8098, 3747, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3420, 2101, 2053, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3543, 6966, 3801, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3589, 2446, 3822, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3590, 7724, 3312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3591, 7725, 1099, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3592, 7725, 1628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3593, 2451, 3823, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3595, 2449, 2430, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3597, 2454, 802, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3598, 2455, 1002, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3601, 2460, 1110, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3516, 2295, 433, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3425, 2075, 1690, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3421, 2102, 2185, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3438, 2147, 2737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3501, 2271, 1509, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3441, 2150, 3761, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3426, 2076, 3753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3417, 2097, 3751, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3596, 2450, 3825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3526, 5409, 1416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3422, 2073, 503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3515, 2296, 2543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3540, 2339, 3799, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3424, 2108, 3491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3496, 2259, 2418, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3407, 4931, 3527, 11, '');
INSERT INTO 'dancestunesmap' VALUES (3462, 2196, 872, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3582, 2430, 3819, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3587, 7723, 3820, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3434, 2134, 3758, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3604, 2465, 3828, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3599, 2456, 1426, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3603, 2464, 3827, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3550, 2364, 3804, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3495, 2258, 3786, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3491, 2254, 3784, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3487, 2245, 533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3449, 2171, 778, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3452, 2177, 763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3492, 2255, 3785, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3503, 2269, 2973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3451, 3094, 3767, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3606, 2478, 2910, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3611, 2490, 601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3613, 2494, 329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3616, 2500, 2964, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3617, 2502, 590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3444, 2155, 524, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3537, 2334, 543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3609, 2487, 3830, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3461, 2195, 3771, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3443, 2154, 3763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3545, 2345, 3405, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3455, 2183, 3768, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3437, 2145, 3111, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3525, 2317, 2106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3517, 2298, 3791, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3621, 2520, 503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3623, 2523, 2214, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3624, 2508, 2443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3627, 2528, 3837, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10224, 18238, 1515, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3631, 2511, 14, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3632, 2512, 1659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3634, 2532, 1122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3636, 2537, 1171, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3640, 2541, 119, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3641, 2545, 166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3642, 2549, 1997, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3644, 2554, 3841, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3645, 2555, 3842, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3647, 2558, 502, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3648, 2565, 671, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3649, 2567, 2219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3656, 2581, 305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3657, 2584, 3844, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3658, 7732, 1075, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3659, 2586, 3845, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3662, 7733, 3846, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3663, 7734, 3847, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3664, 2592, 3848, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3666, 2599, 1051, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3667, 2603, 761, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3668, 2605, 3850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3674, 2612, 295, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3675, 2615, 3853, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3677, 2618, 3854, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3678, 2620, 3855, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3679, 2624, 861, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3680, 2626, 353, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3681, 2627, 3856, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3685, 2633, 1356, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3686, 2634, 172, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3691, 2647, 2181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3692, 2648, 628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3696, 2659, 849, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3697, 2659, 1226, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3698, 2662, 3862, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3699, 7408, 133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3700, 2665, 2236, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3703, 7740, 3863, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3704, 2672, 3732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3707, 2676, 3866, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3708, 2678, 2240, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3709, 2679, 1707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3712, 2684, 2241, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3715, 1491, 3870, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3716, 2691, 3871, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3717, 2693, 1565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3718, 2694, 938, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3719, 2699, 1765, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3724, 2710, 64, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3731, 2720, 3876, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3732, 2721, 3876, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3733, 2721, 2180, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3734, 2729, 700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3735, 2733, 3877, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3736, 2738, 3590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3737, 2740, 3878, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3745, 2750, 3882, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3747, 2755, 3884, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3748, 7742, 3885, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3749, 2756, 1448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3751, 2761, 2312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3752, 2759, 1542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3753, 2764, 3765, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3754, 2771, 1748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3755, 2772, 1619, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3756, 2773, 3887, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3757, 2774, 2986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3759, 2776, 3888, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3760, 2778, 267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3761, 2779, 3889, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3762, 2784, 145, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3763, 2785, 647, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3764, 2785, 3890, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3766, 2788, 958, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3768, 2790, 3893, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3770, 2792, 3895, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3771, 2795, 3896, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3772, 2798, 3635, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3629, 2509, 68, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3688, 2638, 3859, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3633, 2533, 3839, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3594, 2447, 3824, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3711, 2683, 3868, 1, '');
INSERT INTO 'dancestunesmap' VALUES (3615, 2499, 3833, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3723, 2705, 3872, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3618, 2503, 590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3695, 2657, 242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3750, 2760, 3886, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3728, 2718, 3875, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3740, 2743, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3673, 2611, 3852, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3639, 2540, 1443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3638, 2540, 1606, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3602, 2462, 3744, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3738, 2741, 3879, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3742, 2751, 3880, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3714, 2690, 628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3600, 2459, 3826, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3773, 2798, 2988, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3775, 2804, 650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3778, 2818, 3897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3779, 2829, 614, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3782, 7413, 1475, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3783, 2614, 3898, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3784, 2837, 3899, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3785, 2838, 665, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3787, 2844, 1609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3788, 2841, 3900, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3792, 2853, 890, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3793, 2857, 1042, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3797, 2863, 2309, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3729, 2719, 347, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3661, 2588, 3846, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3791, 2851, 1340, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3622, 2522, 3674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3796, 3785, 2602, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3652, 2572, 2455, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3705, 2670, 3864, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3669, 2606, 3850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3607, 2480, 3829, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3620, 2507, 3835, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3758, 2775, 4, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3619, 2506, 3514, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3710, 2681, 3867, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3628, 2529, 3330, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3777, 7412, 377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3612, 2491, 3831, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3689, 2639, 76, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3684, 2632, 264, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3665, 2597, 81, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3706, 2675, 3865, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3701, 2666, 1700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3767, 2789, 3892, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3741, 2745, 2055, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3694, 2656, 3861, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3690, 2642, 887, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3683, 2630, 3857, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3660, 2587, 1426, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3654, 2578, 1748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3650, 2571, 3843, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3637, 2538, 1571, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3614, 2497, 3832, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3626, 2527, 3836, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3605, 2467, 3497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3687, 2636, 912, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3693, 2649, 3860, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3798, 2862, 3904, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3799, 2869, 3905, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3800, 2876, 3906, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3801, 2870, 3013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3805, 2875, 2806, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3806, 2867, 3908, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3807, 2867, 3909, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3808, 2879, 3910, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3809, 3903, 5, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3810, 2888, 3911, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3813, 2889, 3679, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3815, 2891, 1166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3713, 2687, 1117, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3670, 2608, 613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3643, 2550, 3840, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3635, 2535, 602, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3780, 2830, 2555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3608, 2482, 1419, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3765, 2787, 648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3769, 2791, 3894, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3682, 2628, 620, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3776, 2814, 407, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3746, 2752, 3883, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3722, 2704, 1762, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3744, 2749, 3881, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3726, 2716, 3713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3725, 2714, 3873, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3721, 2702, 632, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3702, 2667, 429, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3625, 2526, 1401, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3816, 2892, 3913, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3817, 2893, 2799, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3819, 2895, 3914, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3824, 2909, 686, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3825, 2915, 3916, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3826, 2921, 1108, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3829, 2929, 2270, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3831, 2899, 682, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3833, 2902, 1470, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3836, 2939, 3918, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3837, 2942, 698, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3840, 2948, 3920, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3842, 2951, 3922, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3843, 2950, 3199, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3846, 2959, 3924, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3847, 2960, 3628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3848, 2961, 100, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3852, 2967, 228, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3853, 2972, 3381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3855, 2971, 3926, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3856, 2982, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3860, 2987, 3927, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3861, 2991, 713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3862, 2995, 715, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3863, 2998, 1228, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3864, 7744, 3928, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3865, 3002, 1066, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3866, 3004, 1261, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3867, 3005, 1276, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3868, 3007, 3929, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3873, 3015, 1282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3876, 3029, 1920, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3879, 3034, 726, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3880, 3035, 2662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3882, 7746, 1172, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3885, 3055, 3937, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3907, 7751, 239, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3888, 3060, 3939, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3889, 3039, 3940, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3893, 3070, 1791, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3894, 3049, 2479, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3896, 3073, 332, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3898, 3089, 3943, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3899, 3090, 512, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3902, 3097, 741, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3903, 3077, 1283, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3904, 3078, 172, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3905, 3098, 3945, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3906, 3079, 385, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3909, 3081, 1578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3910, 3082, 3947, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3911, 3099, 3948, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3912, 7752, 3949, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3914, 3107, 3951, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3915, 7753, 2596, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3916, 3112, 3463, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3918, 3118, 3954, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3919, 3121, 1613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3922, 3126, 1771, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3927, 3132, 2559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3900, 3092, 693, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3933, 7754, 1813, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3934, 3141, 1629, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3935, 3143, 3957, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3936, 3149, 3958, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3937, 3150, 3938, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3938, 3153, 1814, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3940, 3157, 695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3943, 3161, 2457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3944, 3164, 3850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3945, 3167, 1346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3946, 3159, 1662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3948, 7756, 799, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3949, 3176, 3960, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3950, 3181, 3961, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3951, 3182, 3232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3952, 3182, 503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3954, 3184, 3962, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3955, 7757, 358, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3956, 3191, 3963, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3957, 3192, 1704, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3958, 3193, 1550, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3959, 3195, 2725, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3878, 3017, 521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3895, 3071, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3743, 2746, 643, 1, '');
INSERT INTO 'dancestunesmap' VALUES (3932, 3043, 3520, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3838, 2711, 3732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3857, 2983, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3870, 3009, 3930, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3854, 2973, 3925, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3924, 3127, 2737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1489, 5158, 1117, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3928, 3134, 2559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3789, 2832, 2386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3841, 2949, 3921, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3897, 3088, 607, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3962, 3204, 756, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3963, 7759, 445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3964, 3205, 182, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3965, 3209, 3965, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3966, 3211, 3966, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3968, 7762, 434, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3969, 3213, 768, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3971, 3222, 2336, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3972, 3223, 3968, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3973, 3226, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3974, 7763, 3969, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3975, 3215, 2457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3976, 3217, 3970, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3980, 3243, 2597, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3986, 3262, 3975, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3987, 3269, 256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3989, 3271, 743, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3990, 3272, 1971, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3991, 3273, 783, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3872, 3012, 3931, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3941, 3168, 2903, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3901, 3096, 742, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3839, 2945, 3919, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3891, 3048, 3942, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3874, 3025, 3933, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3820, 2896, 1642, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3812, 2887, 3912, 1, '');
INSERT INTO 'dancestunesmap' VALUES (3925, 3136, 1448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3983, 3266, 3973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3832, 2901, 1112, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3851, 2965, 2278, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3917, 3115, 3953, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3984, 3253, 2326, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3871, 3010, 3226, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3814, 2884, 679, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3844, 2953, 3923, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3822, 2907, 1731, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3830, 2932, 692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3939, 3146, 1102, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3953, 3183, 1958, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3982, 3173, 2321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3803, 2589, 675, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3887, 3058, 3938, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3774, 2801, 2159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3802, 2877, 3907, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3849, 7419, 3381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3804, 7416, 671, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3884, 3053, 3367, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3883, 3051, 3936, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3858, 2980, 1003, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3913, 3106, 3950, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3985, 3261, 3974, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3960, 3200, 3964, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3850, 2966, 2278, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3845, 2955, 1195, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3827, 2926, 1542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3821, 2906, 3915, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3930, 3135, 1426, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3834, 2936, 871, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3892, 3069, 2123, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3881, 3036, 3935, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3992, 3274, 3977, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3993, 3276, 3009, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3994, 3278, 3978, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3995, 3279, 3979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3996, 3074, 3980, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3997, 3532, 3981, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4000, 3286, 1857, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4002, 3171, 3983, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4003, 5942, 337, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4005, 3301, 2413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4006, 3301, 3984, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4007, 3302, 1745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4008, 3303, 3985, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4009, 3306, 791, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4010, 3308, 792, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4011, 3311, 3986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4012, 3312, 91, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3929, 3133, 2559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3923, 3128, 2309, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3979, 3234, 3972, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3818, 2894, 3914, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3859, 2985, 2957, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3947, 3174, 3959, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3811, 2886, 3912, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3875, 3019, 3934, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4017, 3335, 3987, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4022, 3341, 1627, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4023, 6604, 295, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4024, 7431, 3988, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4028, 3334, 3258, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4029, 3292, 1135, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4030, 3346, 3990, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4032, 3294, 3992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4033, 3353, 3993, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4034, 3354, 3364, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4035, 3355, 3994, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4036, 3356, 3995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4037, 3359, 3600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4039, 3362, 2118, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4040, 3362, 3017, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4042, 3361, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4045, 3369, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4052, 3384, 333, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4053, 3385, 1406, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4054, 3386, 299, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4117, 3527, 2349, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4058, 7777, 724, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4063, 3401, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4066, 3410, 64, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4069, 3417, 503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4070, 3419, 2382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4073, 3425, 3998, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4049, 7775, 493, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4076, 3429, 2383, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4077, 3430, 1624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4079, 3434, 3999, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4081, 3442, 4001, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4082, 3450, 284, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4085, 3455, 234, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4086, 3455, 122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4088, 3464, 669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4090, 3471, 923, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4092, 3476, 4000, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4093, 3478, 860, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4097, 3484, 861, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4098, 3484, 1447, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4100, 3501, 52, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3926, 3137, 3956, 1, '');
INSERT INTO 'dancestunesmap' VALUES (4103, 3488, 4004, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4104, 3494, 1021, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4106, 3505, 4005, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4108, 3497, 1019, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4111, 3508, 2397, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4118, 3530, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4119, 3530, 598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4120, 3530, 1009, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4121, 3534, 1019, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4122, 3535, 1116, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4123, 3533, 4008, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4125, 3550, 4009, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4128, 3546, 2845, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4129, 3548, 4011, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4132, 3582, 2411, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4136, 3591, 3832, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4138, 3597, 1121, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4139, 3599, 1759, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4140, 3600, 895, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4141, 3603, 84, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4143, 3605, 4016, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4144, 3606, 4017, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4145, 7789, 902, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4331, 4010, 4088, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3981, 3247, 403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4071, 3420, 2382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4089, 3466, 4002, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4064, 3405, 655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4096, 3483, 861, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4102, 3489, 4004, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4116, 7783, 867, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4109, 3506, 4006, 11, '');
INSERT INTO 'dancestunesmap' VALUES (3967, 3221, 3967, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3977, 3216, 3971, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4113, 3516, 2399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4114, 3517, 2399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4115, 3520, 200, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4095, 3482, 1166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4057, 3389, 2368, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4038, 3358, 662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3978, 3219, 2457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3961, 3202, 767, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4135, 3590, 4014, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4074, 3426, 1401, 10, 'Tune oiginally recommended ');
INSERT INTO 'dancestunesmap' VALUES (4146, 3612, 4019, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4151, 3630, 176, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4152, 3633, 4021, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4154, 7791, 4022, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4155, 3643, 166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4156, 3644, 930, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4157, 3647, 1688, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4163, 3657, 1943, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4168, 3676, 4030, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4172, 3683, 4031, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4174, 3686, 4032, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10215, 18254, 12534, 10, '“Any good romantic tune” (deviser)');
INSERT INTO 'dancestunesmap' VALUES (4094, 3480, 4003, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4001, 3291, 3982, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4018, 3337, 2696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4080, 7778, 1624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4167, 3666, 4028, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4130, 3628, 2436, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4320, 3979, 3581, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4131, 3574, 4012, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4112, 3510, 4007, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3998, 5371, 695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4164, 3660, 4027, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4142, 3602, 897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4137, 3596, 891, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4110, 3507, 2396, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4046, 3371, 2375, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4016, 3324, 807, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4087, 3459, 713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4014, 3321, 1361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4148, 3619, 915, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4004, 3299, 3223, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4059, 3390, 1082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4050, 3382, 1415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4020, 3336, 2470, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4127, 3542, 874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4134, 3568, 1997, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4101, 7781, 736, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4091, 3473, 129, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4099, 3485, 2413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4165, 3662, 1000, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4126, 3544, 4010, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4107, 3502, 1468, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4068, 3416, 2860, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4065, 3409, 627, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4055, 3387, 1374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4060, 3391, 833, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4047, 3377, 3219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4027, 3345, 3989, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4170, 3679, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4021, 3340, 817, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4158, 3646, 4023, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3988, 3263, 778, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3999, 1141, 1857, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4150, 3629, 3312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4201, 3724, 4046, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4184, 7794, 4038, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4192, 3717, 3004, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4194, 3734, 4044, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4195, 3736, 713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4196, 3727, 2418, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4202, 3742, 963, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4203, 3744, 1713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4205, 3749, 2136, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4206, 3754, 1099, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4207, 3754, 1699, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4208, 3760, 452, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4209, 3761, 769, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4211, 6105, 971, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4216, 3773, 649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4219, 7798, 90, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4221, 7799, 1875, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4227, 3795, 4054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4232, 7800, 4058, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4234, 3804, 654, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4235, 3809, 4061, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4048, 7774, 3996, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4026, 3333, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4084, 3453, 3457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4031, 3293, 3991, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4067, 3411, 867, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4178, 3692, 1476, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4013, 3318, 2356, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4198, 3720, 951, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4147, 3618, 914, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4176, 3689, 1414, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4083, 3449, 2236, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4133, 3586, 2563, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4153, 3634, 613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4124, 3537, 2737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4218, 3782, 295, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4072, 3422, 2873, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4043, 3365, 2596, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4051, 1624, 388, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4236, 3810, 4062, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4237, 3811, 2503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4239, 3815, 4064, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4242, 3819, 3381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4243, 3820, 3321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4244, 3823, 1489, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4245, 3823, 366, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4246, 3826, 4065, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4247, 3827, 4066, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4248, 3827, 218, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4249, 7801, 823, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4252, 3839, 4068, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4253, 3840, 2556, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4254, 3841, 2471, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4255, 7804, 610, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4256, 3844, 2473, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4257, 7805, 1232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4258, 3848, 4069, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4259, 3850, 3946, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4260, 7806, 4070, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4262, 3880, 2480, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4263, 3881, 2021, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4265, 3856, 676, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4266, 7807, 707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4267, 3858, 3156, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4269, 3886, 2482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4273, 3873, 995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4274, 3874, 1356, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4275, 3895, 520, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4276, 3902, 2328, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4277, 3905, 133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4279, 7808, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4283, 3913, 1324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4286, 3919, 1732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4290, 3926, 2104, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4291, 3927, 4072, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4292, 3928, 1006, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4293, 3929, 21, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4294, 3929, 4073, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4295, 3930, 1319, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4296, 3935, 4075, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4298, 3939, 2489, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4302, 3947, 1023, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4303, 3950, 4078, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4305, 3952, 2492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4306, 3954, 1491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4310, 3716, 4080, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4315, 3969, 532, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4316, 3971, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4317, 3970, 4082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4318, 3975, 4083, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4321, 3981, 4085, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4304, 3951, 2492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4323, 3991, 4087, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4324, 3995, 2503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4328, 4001, 688, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4329, 7813, 1118, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4169, 3677, 318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4179, 3693, 993, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4204, 3746, 1426, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4289, 3924, 3853, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4287, 3922, 1513, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4190, 3713, 4042, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4264, 3855, 18, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4191, 3715, 4043, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4161, 3650, 1757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4175, 3687, 4033, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4250, 3834, 2696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4311, 3959, 1613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4233, 3806, 4060, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4220, 3789, 3321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4177, 3690, 4034, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4308, 3955, 4079, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4301, 3945, 2802, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4327, 3999, 920, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4332, 4011, 4089, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4333, 4250, 4091, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4334, 4013, 3635, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4335, 4013, 2988, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4340, 4259, 2492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4341, 4260, 3014, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4346, 4034, 126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4348, 4036, 4097, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4351, 4040, 1729, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4352, 4040, 1728, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4354, 4269, 4099, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4357, 4006, 1691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4361, 4275, 4102, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4362, 4276, 3394, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4365, 4281, 350, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4366, 4049, 4104, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4367, 4050, 121, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4372, 8114, 4138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4373, 8115, 4139, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4377, 8119, 4143, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4380, 8122, 4146, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4378, 8120, 4144, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4360, 4274, 4101, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4188, 3705, 655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4371, 4052, 4107, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4228, 3797, 4055, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4186, 3703, 4040, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4213, 3769, 13969, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4241, 3818, 580, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4222, 3787, 4052, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4284, 3916, 700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4270, 5961, 2886, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4226, 3794, 1732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4238, 3812, 4063, 10, 'played ABAB');
INSERT INTO 'dancestunesmap' VALUES (4271, 3889, 1003, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4297, 3937, 4076, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4325, 3997, 3312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4229, 7790, 4055, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4182, 7793, 4037, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4225, 3793, 979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4199, 3721, 952, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4309, 3956, 1022, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4230, 3798, 4056, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4183, 3700, 3930, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4374, 8116, 4140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4342, 4258, 4096, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4212, 3767, 4047, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4240, 3816, 1329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4353, 4041, 145, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4375, 8117, 4141, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4330, 7814, 3445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4343, 4261, 1096, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4364, 4047, 4103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4307, 3957, 1566, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4288, 3923, 4071, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4280, 3908, 3848, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4261, 3854, 932, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4224, 3792, 3398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4197, 3731, 2576, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4189, 3706, 419, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4187, 3704, 4041, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4272, 3877, 90, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4214, 3771, 2449, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4215, 3768, 4048, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4268, 3860, 1753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4363, 4007, 432, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4385, 8126, 4152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4389, 8130, 4158, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4393, 4056, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4394, 4287, 4162, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4395, 4062, 4163, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4397, 4059, 4165, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4398, 4060, 4166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4399, 4066, 1044, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4400, 4067, 4167, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4403, 4076, 416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4404, 4089, 3325, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4405, 4080, 1049, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4407, 4084, 4170, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4409, 4095, 3752, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4410, 4096, 4171, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4412, 4104, 1511, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4414, 8134, 3496, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4415, 4108, 2520, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4416, 4109, 4173, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4422, 4125, 4177, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4423, 4130, 176, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4426, 4134, 4178, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4427, 4137, 4179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4428, 3750, 41, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4425, 4131, 1659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4281, 3910, 3036, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4392, 8133, 4161, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4379, 8121, 4145, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4285, 7545, 2484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4420, 4124, 4176, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4345, 4028, 4092, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4418, 4113, 4175, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4312, 3962, 2971, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4319, 3976, 1030, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4313, 7812, 4081, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4417, 4110, 4174, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4396, 4063, 4164, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4160, 3649, 4025, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4217, 3776, 4049, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4193, 3726, 3590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4429, 4139, 4180, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4430, 4146, 4182, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4431, 4143, 2527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4432, 3993, 1300, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4437, 4157, 1781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4440, 4162, 2531, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4441, 4163, 662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4442, 4164, 4185, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4445, 4166, 4186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4446, 4167, 3192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4450, 4178, 964, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4452, 4182, 2532, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4453, 4184, 1748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4454, 4186, 4189, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4457, 4194, 4191, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4458, 4197, 4193, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4461, 4208, 2538, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4463, 4210, 4195, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4464, 4210, 4196, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4466, 4220, 4197, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4467, 4221, 1374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4471, 4228, 1361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4472, 4229, 4199, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4474, 4234, 4201, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4475, 4235, 2214, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4476, 4235, 4202, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4477, 4237, 192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4482, 4242, 874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4483, 7451, 4203, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4484, 4247, 1089, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4486, 4289, 4204, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4488, 4295, 2737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4489, 4296, 669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4490, 4298, 805, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4493, 4305, 4209, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4494, 4307, 2145, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4495, 4315, 1082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4496, 4316, 4210, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4498, 4322, 2762, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4499, 4340, 4211, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4500, 4341, 4212, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4501, 4327, 571, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4503, 4328, 347, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4504, 4328, 262, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4505, 4331, 4213, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4507, 4344, 1687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4508, 4345, 3853, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4511, 4353, 4217, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4512, 4360, 98, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4513, 4361, 4218, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4515, 4367, 698, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4516, 4369, 4219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4517, 4372, 4220, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4408, 4088, 1052, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4387, 8128, 4154, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4347, 4266, 1042, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4349, 4037, 1625, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4502, 7825, 3980, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4350, 4039, 4098, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4470, 4226, 1091, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4444, 4165, 3168, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4369, 4286, 1099, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4485, 4248, 819, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4519, 4376, 2737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4521, 4387, 3321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4522, 4391, 3682, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4524, 4378, 1116, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4525, 4392, 2545, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4530, 4400, 3497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4531, 6516, 3233, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4534, 4406, 4223, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4535, 4415, 4224, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4536, 4416, 1398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4538, 4418, 2564, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4542, 4423, 764, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4543, 7832, 281, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4547, 4429, 4228, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4548, 4430, 1137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4549, 7833, 4229, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4550, 4437, 4230, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4551, 4443, 4231, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4552, 4446, 3992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4555, 4453, 4233, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4557, 4456, 4234, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4560, 4458, 4235, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4460, 4199, 963, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4411, 4098, 1059, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4435, 4153, 4183, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4514, 4362, 1112, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4433, 4149, 1691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4406, 4082, 4169, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4481, 4241, 4092, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4355, 4042, 1129, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4456, 4193, 1080, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4537, 4417, 4225, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4376, 8118, 4142, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4388, 8129, 4157, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4386, 8127, 4153, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4391, 8132, 4160, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4390, 8131, 4159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4447, 4172, 1721, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4419, 4129, 2140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4421, 4122, 2830, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4553, 4448, 1158, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4558, 4457, 1164, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4439, 4160, 4184, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4559, 4459, 2587, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4381, 8123, 4147, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4497, 4320, 1655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4556, 4454, 835, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4438, 4158, 2531, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4526, 4398, 4221, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4434, 4151, 3582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4383, 8124, 4150, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4443, 7455, 1790, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4338, 8102, 4034, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4510, 4350, 1767, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4468, 7256, 3956, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4518, 4373, 2545, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4506, 4337, 4214, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4492, 4303, 4208, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4451, 4181, 1986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4449, 4176, 4042, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4370, 4051, 4106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4539, 4420, 2565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4413, 3559, 4172, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4545, 4426, 4227, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4424, 4123, 1005, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4473, 4231, 4200, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4561, 4465, 2590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4562, 4467, 667, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4563, 4462, 4236, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4564, 4463, 4237, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4565, 4603, 3267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4566, 4470, 1184, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4568, 4478, 1179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4572, 4482, 1181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4573, 4485, 4240, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4577, 4490, 1186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4578, 4492, 1181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4581, 4496, 1674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4582, 4501, 4241, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4583, 4502, 1192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4584, 4503, 1193, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4585, 4504, 4242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4586, 4505, 2438, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4587, 4507, 4243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4588, 4509, 1195, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4589, 4510, 4244, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4591, 4513, 4246, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4592, 4513, 4247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4593, 7836, 4248, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4596, 4515, 4250, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4597, 4520, 2717, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4599, 4523, 4252, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4600, 4526, 4253, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4604, 7839, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4605, 4532, 1208, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4469, 4217, 4198, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4528, 4381, 4222, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4574, 4486, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4402, 4075, 4168, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4459, 4198, 1072, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4487, 4290, 4206, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4601, 7838, 1051, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4336, 7605, 3391, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4344, 4030, 1942, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4533, 4412, 1126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4532, 4410, 1126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4579, 4493, 1190, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4576, 4488, 1184, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4598, 4519, 4251, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4546, 4428, 1136, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4554, 4449, 4232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4569, 4480, 2394, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4491, 4299, 4207, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4462, 4224, 4194, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4455, 4191, 4190, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4465, 4215, 2054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4436, 4156, 1533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4401, 4070, 2305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4479, 4246, 416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4606, 4533, 4255, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4609, 4539, 4258, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4610, 4540, 656, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4611, 4542, 4259, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4612, 4546, 2609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4614, 4547, 1218, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4615, 4551, 1221, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4619, 4566, 1232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4621, 4570, 4262, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4623, 4573, 1238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4624, 4576, 4264, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4625, 4577, 4265, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4627, 4580, 2628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4628, 4582, 4267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4632, 4587, 1243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4633, 4588, 1578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4636, 4592, 2804, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4637, 4593, 2636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4638, 7843, 4271, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4640, 4598, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4641, 4604, 2144, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4642, 4606, 1060, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4644, 4608, 4274, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4645, 4609, 1814, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4646, 4611, 2012, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4649, 4619, 434, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4650, 7846, 4276, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4651, 4623, 3362, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4652, 4624, 4277, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4653, 4624, 1800, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4654, 4626, 4278, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4655, 4627, 819, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4656, 4631, 1453, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4657, 4631, 692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4660, 4643, 4282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4661, 4648, 890, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4662, 4649, 4283, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4666, 4657, 2645, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4670, 4670, 1542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4671, 4671, 1613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4674, 4676, 4288, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4675, 4678, 4289, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4676, 4682, 1119, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4677, 4683, 1582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4681, 4686, 1263, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4683, 4691, 1264, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4684, 4700, 1267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4687, 4699, 525, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4689, 4703, 2652, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4693, 4711, 4294, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4695, 4713, 2567, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4696, 4714, 2654, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4699, 4723, 4296, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4700, 4724, 1288, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4702, 4729, 1291, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4703, 4731, 3192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4704, 4732, 1293, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4669, 4667, 4287, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4616, 4555, 4260, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4523, 7828, 3682, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4643, 4607, 4273, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4618, 4560, 4261, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4631, 4586, 4269, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4544, 4425, 4226, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4694, 4712, 4295, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4630, 4584, 1241, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4707, 4735, 1294, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4708, 4739, 1296, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4710, 7853, 4300, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4711, 4743, 2327, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4712, 4743, 1472, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4713, 7854, 1618, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4714, 4745, 2808, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4717, 4748, 4303, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4721, 4754, 1313, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4722, 4756, 2799, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4725, 4762, 4306, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4727, 4764, 4308, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4728, 7857, 1926, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4729, 7858, 1926, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4731, 4766, 4309, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4734, 4770, 4311, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4735, 4771, 4312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4736, 4772, 4313, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4737, 4773, 4314, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4738, 4775, 849, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4740, 4795, 2369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4742, 4786, 719, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4743, 4787, 4316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4744, 4790, 1300, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4746, 7861, 1943, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4748, 4793, 706, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4749, 4794, 1039, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4750, 4798, 4319, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4751, 4798, 4320, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4719, 4751, 1311, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4608, 4536, 4257, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4741, 4783, 2680, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4634, 4590, 4270, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4658, 4632, 4279, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4647, 5720, 4275, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4659, 4634, 4280, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4607, 4535, 4256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4692, 4710, 4293, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4720, 4753, 4304, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4629, 4583, 4268, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4602, 4530, 4254, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4613, 4545, 2757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4617, 4557, 3431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4663, 4653, 757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4567, 4476, 3588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4603, 4531, 2136, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4678, 4684, 1077, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4665, 4656, 2644, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4570, 7835, 4238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4664, 4655, 2644, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4706, 4738, 4298, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4724, 4760, 4305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4680, 4685, 1213, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4718, 7468, 819, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4730, 4765, 1319, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4745, 4791, 4317, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4715, 4746, 4301, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4668, 4666, 4286, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4639, 4597, 4272, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4590, 4512, 4245, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4575, 4487, 2076, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4540, 4421, 2565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4595, 4517, 4249, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4682, 4688, 1082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4747, 4792, 3590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4688, 2012, 4291, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4752, 7862, 82, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4754, 4801, 1237, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4756, 4807, 4322, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4757, 4810, 3398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4759, 4814, 4323, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4764, 4826, 3056, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4765, 4823, 4327, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4766, 4117, 671, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4767, 4829, 2103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4768, 4829, 2772, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4770, 4833, 1193, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4771, 5226, 4328, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4774, 4842, 2386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4775, 5565, 4330, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4777, 4852, 4332, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4778, 4854, 1370, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4779, 4855, 2702, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4780, 4861, 4333, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4781, 4867, 186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4782, 4868, 1376, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4784, 6493, 1578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4788, 4883, 1592, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4790, 4886, 2152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4794, 4901, 1015, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4795, 4902, 1827, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4798, 4910, 1559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4800, 4912, 1385, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4801, 4944, 1328, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4802, 4913, 2180, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4803, 4915, 1797, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4804, 7864, 4337, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4805, 4918, 1380, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4807, 4922, 2542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4808, 4923, 4340, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4809, 8135, 1511, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4811, 4934, 1393, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4814, 4955, 4171, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4685, 4696, 581, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4810, 4950, 1371, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4792, 4893, 1401, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4667, 4664, 4285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4690, 4705, 4292, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4626, 4578, 4266, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4686, 4698, 4290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4732, 4757, 4310, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4758, 4812, 3543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4620, 4569, 2622, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4697, 4717, 1282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4705, 4736, 2516, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4672, 4673, 1651, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4673, 4617, 2008, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4817, 4961, 4344, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4819, 7869, 393, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4821, 4962, 1992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4822, 4973, 3312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4825, 4976, 1659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4827, 4979, 4348, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4828, 4980, 4349, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4772, 4834, 4329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4832, 4996, 3057, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4833, 4997, 1044, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4838, 5002, 974, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4839, 7749, 1585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4840, 5003, 1585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4701, 4726, 4297, 1, '');
INSERT INTO 'dancestunesmap' VALUES (4841, 5004, 2050, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4843, 5021, 951, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4844, 5022, 3944, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4846, 5011, 4353, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10218, 18256, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4848, 5024, 4354, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4849, 5025, 4355, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4850, 5025, 4356, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4852, 5014, 2093, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4853, 5015, 4359, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4854, 5018, 4360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4855, 7875, 4361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4856, 5031, 1351, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4858, 5012, 4362, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4859, 5042, 4363, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4860, 5043, 1423, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4861, 5045, 4364, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4862, 5050, 1036, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4864, 5057, 570, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4865, 5058, 2456, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4866, 5059, 4365, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4869, 5066, 2737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4871, 5067, 1997, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4872, 5071, 4366, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4873, 5074, 951, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4874, 5075, 427, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4875, 5085, 4367, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4876, 5086, 4368, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4878, 5091, 78, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4879, 5092, 4369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4880, 5076, 2670, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4883, 8136, 312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4885, 5101, 4372, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4887, 5103, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4888, 5105, 1377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4835, 5000, 975, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4877, 5089, 3860, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4763, 4825, 4326, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4831, 4987, 497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4799, 4911, 2575, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4726, 4763, 4307, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4818, 3327, 4345, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4762, 4820, 4325, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4884, 5097, 1540, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4716, 7855, 4302, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4793, 4897, 3381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4867, 5060, 1008, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4870, 7480, 2738, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4776, 7472, 4331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4789, 4884, 778, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4739, 4777, 4315, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4709, 1484, 4299, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4890, 5107, 1700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4893, 5112, 324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4894, 5112, 555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4895, 5113, 4373, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4896, 5114, 1612, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4897, 6588, 1674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4898, 5116, 4374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4900, 5119, 242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4901, 5121, 3353, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4902, 5123, 1919, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4903, 5124, 4376, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4904, 7879, 4377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4906, 5127, 4039, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4907, 5130, 1209, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4908, 5132, 4378, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4909, 5135, 1448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4910, 5138, 1319, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5050, 5368, 4423, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4912, 5143, 1437, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4914, 5145, 626, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4915, 5146, 4379, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4917, 5149, 4380, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4918, 5150, 4381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4920, 5156, 3406, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4921, 7881, 247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4922, 5157, 4382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4925, 5164, 1582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4927, 5166, 4384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4928, 5167, 1445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4929, 5169, 4385, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4932, 5173, 911, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4934, 5175, 273, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4936, 5180, 4389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4937, 5177, 4390, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4938, 7882, 736, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4939, 7883, 4391, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4940, 5183, 664, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4941, 5184, 1964, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4942, 5182, 4348, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4868, 5063, 724, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4773, 4840, 1367, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4786, 4878, 4334, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4842, 7873, 281, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4761, 4816, 4324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9328, 15836, 13069, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4916, 7880, 2744, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4891, 5109, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4824, 7547, 2676, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4943, 7484, 364, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4836, 5001, 4351, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4892, 5109, 713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4851, 5026, 4357, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4791, 4895, 1402, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4834, 4999, 4350, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4919, 5151, 248, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4886, 5102, 755, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4816, 4965, 4343, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4882, 5080, 12, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4924, 5163, 2746, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4889, 5106, 3732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4944, 5185, 2214, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4945, 5185, 3903, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4949, 5193, 1689, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4950, 5193, 337, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4952, 5195, 195, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4953, 5196, 2746, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4954, 5197, 1447, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4955, 5201, 1331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4958, 5218, 161, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4959, 7886, 1304, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4961, 7887, 2995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4962, 5227, 3252, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4963, 5228, 4149, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4965, 5235, 1463, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4966, 5230, 4188, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4967, 5231, 2964, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4970, 5241, 2513, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4971, 5246, 4284, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4973, 5247, 1557, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4975, 5249, 159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4976, 5250, 4394, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4977, 7891, 1223, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4978, 7891, 3406, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4982, 7893, 616, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4985, 5270, 4397, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4980, 5255, 4395, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4987, 5273, 2672, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4990, 5277, 743, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4992, 7895, 1462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4994, 5280, 1297, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4995, 5283, 4398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4997, 5285, 692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4998, 5288, 451, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5000, 5258, 4401, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5001, 7896, 874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5002, 5294, 1228, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5004, 5297, 4403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5005, 5298, 4404, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5006, 5299, 517, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5008, 5304, 4405, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4881, 5079, 4371, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4926, 5165, 1186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4787, 6678, 4335, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4826, 4974, 3367, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4972, 5244, 1046, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4785, 4874, 2706, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4813, 4952, 3159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4845, 5010, 3377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4857, 5038, 2094, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4815, 4956, 1503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4947, 5187, 4393, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4863, 5053, 850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4783, 4877, 2614, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4931, 5172, 2156, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4820, 4970, 2789, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4956, 5203, 3493, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5011, 5309, 266, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5012, 5311, 2773, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5013, 5312, 2774, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5014, 5313, 1588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5015, 5315, 4406, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5017, 8137, 4407, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5018, 5322, 4408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5019, 5323, 1277, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5020, 5329, 4409, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5021, 5328, 4409, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5022, 5334, 1472, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5023, 5335, 1472, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5024, 5336, 652, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5025, 5873, 3527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5026, 131, 4410, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5027, 5337, 4411, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5028, 5340, 148, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5029, 5341, 834, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5030, 5341, 329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5031, 5343, 1533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5033, 5346, 3146, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5034, 5348, 1565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5036, 5352, 4414, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5037, 5353, 2556, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5039, 5357, 4415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5041, 5360, 4417, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5043, 5363, 4418, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5044, 5365, 4419, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5045, 5369, 145, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5046, 5374, 4420, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5048, 5370, 1425, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5049, 5367, 4422, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5051, 5381, 1582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5052, 5382, 1329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5054, 5383, 2780, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5055, 5383, 3764, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5059, 723, 171, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5061, 5393, 4427, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5062, 5396, 4428, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5065, 5405, 4430, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5066, 5406, 119, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5067, 5408, 4431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5069, 5411, 4432, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5071, 5415, 121, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5072, 5415, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5073, 5416, 3860, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5074, 5417, 1489, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4957, 5209, 281, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4988, 5274, 1819, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4905, 5126, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4999, 5289, 4400, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5070, 5414, 4433, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4935, 5178, 4388, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4913, 5144, 3154, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4989, 5275, 285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5038, 5355, 1476, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4899, 5117, 4375, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5064, 5404, 1970, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5056, 5387, 2415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5032, 5345, 4412, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5009, 5305, 1167, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5075, 5417, 366, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5076, 5424, 3744, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5078, 5427, 424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5079, 5431, 390, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5080, 5433, 1707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5082, 5436, 3156, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5083, 5420, 4434, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5084, 5423, 798, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5085, 5442, 3192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5086, 5447, 1590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5089, 7894, 2696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5092, 5453, 1745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5093, 7898, 3537, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5094, 5454, 451, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5095, 5456, 4438, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5098, 5461, 1505, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5104, 5470, 4443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5105, 7899, 342, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5106, 5472, 3093, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5109, 5476, 4445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5110, 5482, 2699, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5111, 7900, 179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5112, 7901, 1319, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5113, 5486, 1917, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5116, 5507, 1979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5120, 5508, 3314, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5122, 5515, 981, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5125, 5537, 1013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5128, 5533, 1693, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5130, 5538, 382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5131, 5540, 217, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5132, 5541, 4453, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5133, 5544, 3614, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5134, 5545, 542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5135, 5546, 575, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5137, 5551, 1091, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5140, 7904, 4454, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5142, 5561, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5143, 5563, 4456, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5144, 5566, 4457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5145, 5567, 4458, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5149, 5577, 369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5040, 5359, 2721, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4993, 5279, 2185, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4951, 5191, 908, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5058, 5390, 4425, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5088, 5448, 649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4979, 7892, 2995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4984, 7487, 1629, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5060, 5392, 4426, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4923, 5159, 4383, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4948, 5189, 3157, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4983, 5265, 4396, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5103, 7496, 1391, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5129, 5534, 1013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5053, 5385, 608, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5115, 5494, 4446, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5068, 5410, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5035, 5350, 4413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4981, 5261, 1753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4996, 5281, 4399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4991, 5278, 3013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5114, 5491, 2790, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5007, 5300, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4946, 5186, 4392, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5139, 5554, 374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5151, 7906, 4459, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5152, 5587, 57, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5153, 5595, 1328, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5154, 5596, 4460, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5156, 5598, 4461, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5157, 5600, 1609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5158, 5603, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5160, 5607, 3498, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5161, 5610, 1166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5162, 5611, 1013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5163, 5613, 153, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5164, 7909, 1501, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5166, 5634, 4463, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5167, 5627, 4464, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5168, 5629, 4465, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5170, 5631, 20, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5172, 8139, 911, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5174, 5633, 2279, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5177, 5645, 3042, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5178, 5649, 2016, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5180, 5652, 382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5182, 5656, 4468, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5183, 5657, 4469, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5184, 5659, 312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5185, 5660, 1542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5190, 5664, 1853, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5191, 17, 1853, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5193, 5666, 1578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5196, 5668, 4473, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5198, 5672, 742, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5200, 5684, 1541, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5201, 5695, 4474, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5204, 5697, 4476, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5205, 5698, 3732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5206, 5701, 3846, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5207, 5701, 2318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5209, 5705, 763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5210, 5716, 4477, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5212, 5709, 4479, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5214, 5714, 1377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5218, 7916, 1774, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5219, 5737, 155, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5220, 5739, 1557, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5221, 5743, 1624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4969, 5225, 1455, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5010, 5307, 117, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5188, 5678, 1598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5057, 5292, 4424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5016, 5316, 172, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4933, 4217, 4387, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4974, 7890, 4336, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4960, 5220, 2761, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5189, 5680, 4006, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4930, 5170, 4386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5217, 5736, 1482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5173, 5638, 3405, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5225, 5747, 1003, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5227, 5751, 441, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5228, 7919, 116, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5229, 5761, 3408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5230, 7920, 4482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5231, 5767, 1648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5232, 7921, 4484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5233, 5770, 4485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5234, 5771, 4486, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5237, 5774, 4488, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5239, 5778, 4490, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5240, 5783, 3628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5199, 5673, 220, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5241, 7505, 1638, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5244, 5789, 4491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5245, 5790, 3312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5246, 5791, 270, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5247, 5792, 4492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5250, 5815, 806, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5257, 5820, 10, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5258, 5821, 81, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5202, 5696, 4475, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5260, 5822, 4493, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5259, 5822, 2807, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5107, 5473, 1701, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5175, 7911, 3456, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5226, 5750, 1797, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5147, 5569, 1514, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5091, 5451, 4437, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5192, 5682, 344, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5101, 5468, 482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5203, 5690, 1621, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5102, 5469, 1428, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5087, 5446, 1501, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5119, 5502, 4448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5118, 5498, 673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5236, 5775, 4487, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5213, 5719, 1293, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5171, 5636, 246, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5159, 5619, 4462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5124, 5518, 4450, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5121, 5509, 4251, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5126, 5528, 4452, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5187, 5662, 4470, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5155, 5597, 1407, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5265, 5833, 1230, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5266, 5834, 4324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5267, 7927, 4495, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5278, 5855, 911, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5282, 7929, 1374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5285, 5863, 1992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5287, 7930, 4504, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5288, 7930, 4505, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5289, 5866, 81, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5291, 5870, 1572, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5292, 7933, 3732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5293, 5876, 76, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5294, 5879, 4507, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5295, 5883, 543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5298, 5892, 4510, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5299, 5887, 2821, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5300, 5895, 4216, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5301, 5896, 926, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5302, 7937, 4348, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5304, 5899, 4511, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5306, 5901, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5307, 5903, 4512, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5309, 5909, 4513, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5310, 5910, 4514, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5311, 5912, 2587, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5312, 5913, 787, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5313, 5914, 4515, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5314, 5916, 4516, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5316, 5918, 4517, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5317, 5920, 4382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5318, 5923, 2536, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5320, 5925, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5321, 5930, 889, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5322, 5933, 981, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5324, 5935, 1586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5326, 5943, 2565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5330, 5959, 1590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5333, 5969, 4521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5334, 5970, 1192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5335, 5970, 3199, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5215, 5723, 749, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5100, 5466, 4442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5099, 5465, 4441, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5336, 5979, 2845, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5248, 5795, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5255, 5819, 601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5169, 5630, 3568, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5179, 5650, 4466, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5235, 5772, 90, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5148, 5575, 1424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5181, 5655, 4467, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5243, 8140, 62, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5077, 5426, 1491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5097, 5458, 4440, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5308, 5905, 1508, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5268, 5836, 647, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5261, 5824, 4494, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5254, 5817, 3390, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5222, 5744, 196, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5211, 5717, 4478, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5208, 5704, 1550, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5165, 5617, 1082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5146, 5568, 628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5117, 5496, 4447, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5251, 5809, 1647, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5331, 5962, 953, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5197, 5671, 3627, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5341, 5977, 1361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5342, 5988, 4323, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5343, 5988, 4413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5346, 6000, 4523, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5347, 6000, 4524, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5348, 6005, 3192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5349, 6007, 1361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5350, 6008, 4525, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5351, 6009, 1082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5352, 6010, 2846, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5356, 7942, 1753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5357, 6014, 445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5358, 6015, 4527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5359, 6019, 4528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5360, 7514, 2054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5361, 2142, 3590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5363, 5742, 955, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5366, 6031, 2847, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5367, 6033, 3019, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5368, 6034, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5369, 6027, 1582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5370, 6026, 231, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5371, 5745, 4530, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5372, 6040, 4531, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5374, 6041, 4277, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5375, 6042, 3752, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5376, 6043, 1600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5377, 6045, 2636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5378, 6046, 3192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5379, 669, 1606, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5380, 6054, 2050, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5381, 6059, 1415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5382, 6062, 4533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5383, 6063, 4371, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5384, 6064, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5385, 6065, 1665, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5389, 5938, 434, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5394, 6097, 1282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5395, 6084, 4189, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5396, 6086, 3398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5397, 6088, 1491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5399, 7945, 3145, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5400, 6092, 1585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5402, 6100, 1027, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5403, 6102, 2830, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5405, 6106, 3033, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5407, 6108, 4536, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5408, 6109, 4537, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5409, 6110, 4538, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5411, 6115, 3152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5412, 6119, 4539, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5413, 6121, 4540, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5238, 3561, 3600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5256, 7520, 2035, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5329, 5956, 3760, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5081, 5434, 1491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5224, 5746, 4480, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5274, 7928, 4499, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5277, 5854, 427, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5269, 5837, 4496, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5249, 5796, 676, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5252, 5810, 2636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5253, 5810, 1647, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5275, 5844, 2877, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5296, 5884, 829, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5315, 5917, 388, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5242, 5787, 2827, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5271, 5838, 4294, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5150, 5581, 3497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5276, 5852, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5415, 6125, 4542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5416, 6126, 4543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5417, 6132, 1813, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5423, 6137, 1554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5424, 6138, 4544, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5425, 6138, 39, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5426, 6139, 299, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5430, 6154, 3192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5431, 6156, 4546, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5432, 5785, 4547, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5433, 6157, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5437, 6160, 2857, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5439, 6164, 2860, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5442, 6166, 4553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5444, 6179, 192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5339, 5983, 4522, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5390, 6075, 352, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5332, 5950, 2559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5391, 6078, 4534, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5263, 5829, 156, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5280, 5856, 1728, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5440, 6170, 4551, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5272, 5841, 4498, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5305, 5900, 4006, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5362, 6023, 4529, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5429, 6151, 1835, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5262, 5826, 3528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5323, 5936, 2353, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5392, 6081, 172, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5286, 5864, 4503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5398, 7944, 195, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5353, 7940, 1707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5325, 5939, 4520, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5281, 5857, 4500, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5345, 5999, 4464, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5328, 5955, 3766, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5414, 6123, 4541, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5445, 6181, 1628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5448, 6189, 4555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5449, 6190, 1453, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5450, 6190, 692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5452, 6198, 1328, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5453, 6200, 2386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5454, 6194, 1426, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5455, 6202, 4557, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5456, 6172, 977, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5457, 6174, 3390, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5460, 6215, 497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5461, 6216, 93, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5464, 7953, 4559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5465, 7953, 4560, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5466, 6211, 4561, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5468, 6213, 1098, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5469, 6214, 1636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5471, 6225, 4562, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5472, 6228, 4563, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5475, 6235, 1368, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5476, 6235, 532, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5477, 6237, 51, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5478, 6237, 1291, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5479, 6237, 1334, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5480, 6238, 1185, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5481, 6247, 1111, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5482, 6248, 4566, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5484, 6253, 4567, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5485, 6256, 4568, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5487, 6255, 2871, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5488, 6257, 3361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5489, 6258, 1361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10225, 2697, 1762, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5491, 6262, 1814, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5493, 6265, 4570, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5494, 6266, 2312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5497, 6269, 1331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5498, 6272, 2490, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5499, 6279, 1430, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5500, 6280, 2071, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5501, 6278, 983, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5502, 6281, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5503, 6274, 1647, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5504, 6275, 4277, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5505, 6275, 1541, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5507, 6284, 4572, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5508, 6288, 4573, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5511, 6296, 1656, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5563, 6395, 801, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5516, 6302, 1609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5518, 6304, 2443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5519, 6305, 4574, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5418, 6133, 1655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5393, 6096, 4535, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5273, 5843, 2862, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5355, 6013, 671, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5427, 6146, 2554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5462, 6217, 4558, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5483, 6252, 1488, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5421, 7950, 1689, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5386, 6066, 1609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5340, 5984, 685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5528, 6319, 2488, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5509, 6289, 2317, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5443, 6167, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5486, 6254, 2076, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5438, 6163, 4550, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5434, 6158, 4548, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5303, 5897, 4508, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5364, 6024, 1825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5365, 6024, 3318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5388, 6067, 3516, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5373, 6039, 1598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5517, 6301, 4392, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5506, 6283, 1582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5406, 6107, 3433, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5338, 5978, 4518, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5520, 7958, 1658, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5521, 6307, 1590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5522, 6308, 4575, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5526, 6315, 159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5529, 6321, 914, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5531, 6325, 4577, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5533, 7959, 280, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5535, 6331, 4579, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5536, 6333, 2115, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5537, 6334, 3433, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5538, 6338, 4580, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5539, 6339, 1462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5540, 6340, 1662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5542, 6344, 2910, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5543, 6351, 4581, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5544, 6356, 1118, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5549, 6365, 3919, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5551, 6370, 122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5553, 6372, 517, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5555, 6376, 2019, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5556, 6377, 73, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5557, 6378, 4584, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5559, 6385, 1072, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5560, 6388, 4585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5564, 6396, 1489, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5565, 6396, 366, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5567, 6400, 4586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5568, 6402, 4253, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5572, 6403, 1223, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5573, 6403, 3138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5574, 6408, 4588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5576, 6413, 4589, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5577, 6411, 1619, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5580, 6415, 928, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5512, 6295, 350, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5582, 6423, 4590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5583, 6425, 431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5584, 6435, 3504, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5585, 7964, 4591, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5586, 6437, 763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5588, 6441, 497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5589, 7965, 4592, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5591, 7525, 1992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5593, 6445, 599, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5594, 6446, 2054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5596, 6451, 1372, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5597, 6452, 868, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5601, 6458, 1870, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5602, 6462, 4253, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5605, 6467, 1778, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5606, 6468, 611, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5607, 6469, 1312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5264, 5832, 4348, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5344, 5995, 1732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5436, 6159, 1624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5319, 5924, 4519, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5337, 5972, 3013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5428, 6148, 4545, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5510, 6290, 1655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5410, 6111, 1618, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5561, 6390, 2895, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5524, 6310, 1659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5290, 5868, 1571, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5496, 6270, 4571, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5419, 6134, 445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5525, 6312, 4576, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5401, 4283, 468, 20, '');
INSERT INTO 'dancestunesmap' VALUES (5600, 6428, 4594, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5608, 791, 1377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5609, 6470, 1689, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5610, 6470, 337, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5612, 6474, 3248, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5613, 6475, 4595, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5614, 6476, 41, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5615, 6480, 1704, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5620, 6483, 100, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5623, 6486, 3715, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5624, 6487, 669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5626, 6491, 1582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5627, 6494, 4404, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5628, 6495, 3935, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5630, 6498, 1462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5631, 6499, 4600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5451, 6191, 4556, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5598, 6449, 1781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5541, 6341, 41, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5513, 6297, 1656, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5495, 6267, 1644, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5459, 6205, 1181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5473, 6230, 558, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5592, 6443, 1509, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5554, 6375, 3956, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5534, 6328, 576, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5474, 6234, 4564, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5467, 6212, 2448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5458, 6209, 341, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5632, 6502, 411, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5633, 6503, 1699, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5634, 7971, 4601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5636, 6517, 145, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5637, 6519, 76, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5641, 6524, 1368, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5642, 6507, 55, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5644, 6531, 586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5645, 6534, 2138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5646, 6538, 1003, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5648, 6542, 627, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5650, 6544, 2832, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5651, 6553, 3846, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5652, 6553, 2318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5653, 6554, 4604, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5654, 6548, 1842, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5655, 6548, 1705, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5658, 6561, 1193, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5659, 6562, 996, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5661, 7973, 4606, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5662, 6570, 4607, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5664, 6572, 4608, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5665, 6580, 2138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5666, 6576, 3067, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5668, 6578, 346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5671, 6590, 825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5672, 7977, 1051, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5675, 6598, 3114, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5676, 7978, 1512, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5677, 6602, 4612, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5682, 6617, 3305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5684, 6622, 148, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5685, 6622, 13, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5686, 6623, 342, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5691, 6625, 4615, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5693, 6636, 358, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5695, 6639, 4616, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5734, 6719, 2650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5697, 6641, 4617, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5699, 6647, 4618, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5701, 6652, 3120, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5705, 6663, 4619, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5706, 6664, 4620, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5707, 6667, 2138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5708, 6665, 403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5709, 6668, 4621, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5552, 6371, 4583, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5694, 6638, 2396, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5635, 6508, 2095, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5669, 6579, 1714, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5703, 6656, 352, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5547, 6361, 4582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5545, 6357, 1668, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5647, 6540, 2922, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5550, 6367, 1540, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5446, 6186, 2113, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5587, 6439, 1943, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5687, 6624, 4613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5562, 6392, 256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5681, 6613, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5678, 6606, 2725, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5689, 6631, 874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5660, 6563, 4605, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5622, 6484, 2862, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5611, 6472, 1772, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5621, 6485, 247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5604, 6463, 181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5578, 6412, 3876, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5575, 6410, 2635, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5566, 6397, 3507, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5527, 6317, 1662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5515, 6299, 39, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5603, 6464, 350, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5579, 6416, 2899, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5625, 6429, 4599, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5595, 6447, 1685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5673, 6595, 1716, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5700, 6649, 2943, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5523, 6311, 1659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5670, 6587, 4610, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5710, 6669, 1146, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5712, 6674, 1656, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5715, 6681, 281, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5716, 6684, 1739, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5719, 6692, 1046, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5720, 6693, 148, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5721, 6695, 1458, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5722, 7983, 4623, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5724, 7984, 434, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5725, 6700, 802, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5726, 7985, 434, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5728, 6706, 1462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5730, 6747, 3535, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5731, 7989, 4623, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5732, 7991, 665, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5735, 7993, 398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5739, 7995, 4627, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5740, 6727, 4628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5657, 6560, 1003, 10, 'Given as »Wemyss Place Hornpipe«, from that dance.');
INSERT INTO 'dancestunesmap' VALUES (5688, 6629, 1648, 10, 'Played AABBAB');
INSERT INTO 'dancestunesmap' VALUES (5743, 6731, 4630, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5744, 6732, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5745, 6735, 3455, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5746, 6737, 97, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5751, 6742, 81, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5753, 6749, 1126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5754, 6749, 4104, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5755, 6752, 4634, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5756, 6753, 1744, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5757, 6754, 27, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5758, 6755, 374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5759, 6759, 1745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5760, 6760, 1745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5761, 6761, 4611, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5763, 7996, 1566, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5766, 7997, 360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5767, 6776, 4636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5768, 6777, 4637, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5769, 6778, 97, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5773, 6789, 3424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5774, 6790, 4639, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5775, 6795, 4640, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5776, 6793, 4641, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5777, 6796, 2161, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5780, 6810, 4642, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5781, 6812, 768, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5786, 6820, 133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5787, 6821, 1223, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5788, 6821, 3406, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5789, 6822, 1196, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5790, 6822, 1179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5791, 6831, 4645, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5792, 6832, 4646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5795, 6840, 542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5797, 6842, 1036, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5799, 6850, 4648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5800, 6857, 3915, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5801, 6863, 4649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5698, 6645, 1732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5590, 6436, 1146, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5530, 6322, 1664, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5683, 6619, 3732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5570, 6404, 4587, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5717, 6686, 447, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5690, 6632, 4614, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5667, 6583, 4609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5629, 6497, 3150, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5599, 6455, 4593, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5581, 6419, 2571, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5616, 7966, 4596, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5649, 6543, 4603, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5618, 7968, 4598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5617, 7967, 4597, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5804, 6865, 2456, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5805, 6866, 2815, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5806, 6867, 4650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5807, 6869, 2556, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5810, 6871, 2556, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5811, 6874, 4651, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5812, 6875, 413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5813, 6878, 874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5815, 6882, 12, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5816, 6883, 4653, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5702, 6653, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5796, 6841, 1766, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5713, 6676, 771, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5764, 6768, 858, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5711, 6670, 49, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5692, 6633, 3716, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5679, 6611, 1721, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5723, 6699, 4624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5714, 6677, 86, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5742, 6729, 3744, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5704, 6662, 730, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5779, 6807, 3850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5741, 6728, 4629, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5784, 6815, 4643, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5818, 6888, 1475, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5820, 6895, 4654, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5823, 6905, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5824, 6906, 2069, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5826, 6914, 2294, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5827, 6925, 1193, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5943, 7145, 1814, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5831, 6927, 248, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5834, 6942, 4657, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5836, 6944, 4659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5837, 6945, 1732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5838, 8010, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5840, 6938, 1361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5842, 6940, 593, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5844, 8011, 51, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5845, 8011, 1291, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5846, 8011, 1334, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5847, 6958, 1956, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5850, 6960, 781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5852, 6970, 928, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5854, 6973, 2214, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5855, 6973, 3903, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5856, 6977, 1781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5857, 6979, 849, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5858, 357, 269, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5859, 357, 4664, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5861, 6983, 4323, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5862, 6983, 4665, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5863, 6986, 4666, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5864, 6987, 4668, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5865, 6987, 4669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5866, 6988, 55, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5867, 6994, 1753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5869, 6998, 4670, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5872, 7011, 4671, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5875, 7005, 1788, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5876, 7006, 4672, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5877, 7007, 1820, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5878, 7008, 4673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5879, 7010, 1820, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5880, 858, 4675, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5882, 7015, 148, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5886, 7021, 3552, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5887, 7022, 1915, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5890, 7032, 497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5892, 6528, 1956, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5894, 7040, 669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5897, 7046, 369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5898, 7047, 4679, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5899, 6968, 2986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5839, 6936, 4660, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5752, 6743, 4633, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5737, 2593, 2310, 11, '');
INSERT INTO 'dancestunesmap' VALUES (5718, 6687, 3885, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5738, 6725, 4253, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5680, 6612, 2737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5747, 6738, 4631, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5785, 6818, 4644, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5868, 6996, 13, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5794, 6838, 295, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5821, 6901, 98, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5733, 6713, 3674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5833, 6933, 1683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5891, 7036, 4569, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5771, 6784, 1566, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5736, 6724, 1700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5828, 6930, 2561, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5883, 7016, 3457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5889, 7028, 802, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5881, 7013, 4676, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5814, 6879, 4652, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5817, 6876, 2637, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5748, 7980, 4632, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5802, 6860, 3823, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5798, 6846, 4647, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5793, 6833, 613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5783, 6814, 1722, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5770, 6783, 1748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5762, 6764, 1291, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5656, 6551, 4047, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5643, 6526, 1585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5639, 6522, 2918, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5809, 6870, 2399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5808, 3563, 1198, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5778, 6803, 1513, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5772, 6786, 1290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5901, 7050, 4680, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5902, 7056, 713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5905, 8012, 4682, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5906, 7063, 1800, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5910, 7069, 4685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5911, 7070, 872, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5912, 7064, 2806, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5915, 7083, 4686, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5917, 7086, 3381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5919, 7089, 1351, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5920, 7095, 2737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5922, 7103, 4688, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5923, 7102, 4689, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5925, 7126, 4691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5926, 7114, 64, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5927, 7127, 4692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5932, 7122, 4695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5933, 7122, 4696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5934, 7131, 4697, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5937, 7134, 3357, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5941, 7094, 1986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5945, 7152, 2680, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5948, 7214, 4700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5949, 7160, 3138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5950, 7165, 2986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5951, 7166, 1379, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5952, 7169, 2990, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5953, 7170, 1825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5955, 8015, 1766, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5956, 7167, 2988, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5957, 7154, 4702, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5958, 7155, 4703, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5959, 7176, 1870, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5960, 7185, 1331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5961, 7186, 992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5962, 7187, 4704, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5963, 7187, 4705, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5966, 7179, 4706, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5968, 7198, 1589, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5970, 7203, 1198, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5971, 7208, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5972, 7205, 3405, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5973, 7209, 1753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5974, 7213, 1044, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5975, 8017, 4392, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5976, 7216, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5978, 7217, 1821, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5979, 7217, 979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5980, 7217, 1458, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5981, 7222, 590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5983, 7225, 3002, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5986, 8018, 4708, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5987, 7221, 3255, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5988, 7228, 698, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5990, 7235, 4709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5991, 8020, 13, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5993, 7246, 1043, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5994, 7248, 1638, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5995, 7241, 4710, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5997, 7254, 247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5998, 7255, 1590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5921, 7099, 692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5640, 6521, 2918, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5871, 7000, 1469, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5860, 6982, 117, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5851, 6962, 4662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5727, 6704, 3140, 10, 'played AABB');
INSERT INTO 'dancestunesmap' VALUES (5967, 7183, 2995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5874, 7002, 2967, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5947, 7158, 1821, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5765, 6769, 4635, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5939, 7140, 1745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5999, 7258, 698, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6002, 7266, 3004, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5895, 7039, 2644, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5873, 7012, 807, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5908, 6964, 4684, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5946, 7149, 4699, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5843, 6955, 4661, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5870, 6999, 1003, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5835, 6943, 4658, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5913, 7080, 3637, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5849, 6956, 1026, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5929, 7118, 4693, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5819, 6887, 4348, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5992, 7238, 1419, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5936, 7133, 4698, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5977, 7218, 3484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5884, 7018, 166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6003, 8021, 49, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6004, 7268, 4712, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6005, 248, 1736, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6008, 8025, 3849, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6009, 1254, 611, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6010, 1644, 1377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6011, 2272, 4677, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6014, 5094, 3980, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6015, 5314, 1280, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6016, 8031, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6017, 8032, 1213, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6018, 5760, 247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6019, 5762, 1532, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6020, 8035, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6021, 8036, 551, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6023, 8038, 332, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6024, 3445, 825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6025, 4866, 179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6026, 6929, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6027, 6470, 1659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6028, 6470, 2576, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6031, 548, 4715, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6035, 8143, 2696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6036, 7553, 1332, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6039, 8160, 3598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6040, 7552, 2004, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6043, 8563, 4850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6044, 8563, 3158, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6048, 7745, 369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6049, 7745, 1089, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6051, 4325, 2572, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6052, 2843, 1435, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6055, 612, 724, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6056, 3237, 3151, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6058, 6984, 1898, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6060, 8652, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6061, 711, 2647, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6068, 7232, 1775, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6074, 1053, 2413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6078, 5523, 2802, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6081, 3271, 2151, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6082, 4843, 5308, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6083, 4343, 5308, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6084, 6791, 3959, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6086, 1548, 4451, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6087, 2637, 3858, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6095, 8657, 5345, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6096, 8657, 4215, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6097, 8657, 4969, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6098, 8657, 4992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6099, 4027, 5343, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6072, 3562, 876, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6071, 189, 1805, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2428, 184, 1648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5841, 6939, 2031, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5985, 7227, 1897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5918, 7087, 2873, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6030, 4983, 4714, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6054, 371, 724, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5982, 7223, 4707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6092, 3196, 2054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5903, 7534, 4681, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5909, 7067, 2587, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6063, 3013, 2285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6034, 3041, 730, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5825, 6912, 4656, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6101, 8728, 384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5907, 7062, 4683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6059, 8653, 2047, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6013, 8029, 3450, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6007, 8024, 3448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6094, 5118, 2054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6001, 7260, 2081, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5996, 7252, 4711, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5965, 7189, 3643, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5964, 7188, 3507, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5930, 7121, 4694, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5914, 7081, 674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5900, 7049, 2695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5832, 6932, 2680, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6093, 3329, 2054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5938, 2130, 3757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6069, 2495, 4361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6070, 4048, 4111, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6062, 471, 2224, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6053, 3232, 2442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5928, 7117, 700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5969, 7199, 3363, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6102, 7612, 807, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6109, 8000, 2249, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6114, 5397, 6048, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6115, 6794, 4638, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6117, 5076, 4830, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6120, 5599, 2307, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6121, 5993, 914, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6123, 225, 3946, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6125, 4409, 724, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6133, 8769, 6424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6135, 8771, 1232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6136, 8772, 1152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6137, 8773, 6428, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6138, 8774, 6429, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6140, 8776, 6431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6143, 8783, 6435, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6148, 8571, 6439, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6151, 8570, 3243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6153, 8576, 6443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6154, 3849, 1880, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6156, 6896, 579, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6157, 4004, 542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6163, 3780, 6494, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6164, 3780, 6495, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6165, 3780, 6496, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6166, 3780, 6497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6168, 4838, 6498, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6170, 5646, 2724, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6171, 8807, 6500, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6172, 8808, 6501, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6180, 8712, 5933, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6175, 8809, 6504, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6127, 3834, 987, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6187, 8830, 1533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6188, 8841, 1425, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6047, 1998, 1404, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6122, 5463, 2486, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6033, 5524, 232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6100, 5625, 5343, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6142, 1708, 6434, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6160, 859, 1013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6139, 8775, 6430, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6129, 8738, 2106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6131, 8748, 750, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6128, 8744, 5346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6186, 8829, 2076, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6108, 2820, 2249, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6029, 5296, 3749, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6091, 2711, 2054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6159, 358, 6491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6169, 5291, 6499, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6045, 8579, 4851, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6088, 2925, 2670, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6064, 2101, 2285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6038, 8157, 2288, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6067, 6185, 4554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6079, 3978, 4801, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6085, 2782, 2689, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6161, 1124, 6492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6134, 8770, 2614, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6080, 5858, 4801, 10, 'As “Mrs Macleod of Geastow”');
INSERT INTO 'dancestunesmap' VALUES (6118, 3610, 209, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6132, 6389, 4311, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6107, 8732, 5711, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6041, 7551, 1091, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5954, 7174, 4701, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6089, 6479, 1749, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6124, 5980, 3946, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6106, 5219, 5710, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6141, 5170, 6432, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6000, 7259, 1048, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5935, 7132, 2978, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6167, 3994, 1042, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6177, 3578, 5219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6116, 955, 1983, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5848, 6959, 1505, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6012, 2398, 4713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6065, 732, 2577, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6146, 3252, 6437, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6149, 8574, 6440, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6193, 1450, 219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6198, 7344, 71, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6199, 8843, 1727, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6200, 8844, 6894, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6202, 8846, 3262, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6203, 8848, 830, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6212, 8854, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6213, 7893, 592, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6220, 8842, 1245, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6221, 8845, 1834, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6226, 7568, 2896, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6230, 4328, 143, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6231, 4328, 1326, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6232, 4328, 252, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6233, 4328, 421, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6235, 5206, 1221, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6242, 723, 6101, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10227, 11048, 13873, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6246, 5963, 5381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6251, 25, 225, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6253, 4472, 398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6254, 7600, 6703, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6256, 437, 5072, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6262, 741, 1349, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6264, 4847, 920, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6271, 4859, 4324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6272, 4936, 429, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6276, 2761, 1012, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6279, 3070, 92, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6344, 8980, 7181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6283, 8336, 693, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6285, 3647, 238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6289, 8337, 525, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6296, 4570, 4115, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6297, 4570, 1112, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6301, 5114, 284, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6304, 7563, 2837, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6305, 5442, 170, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6309, 3560, 1539, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6316, 6929, 6, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6319, 6537, 1992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6323, 2532, 249, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6214, 4309, 966, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6209, 7577, 5859, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6147, 8578, 6438, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6189, 1773, 5369, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6218, 6460, 612, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6006, 8023, 1745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6103, 7613, 5707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6174, 6056, 6503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6192, 323, 219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6248, 6477, 4974, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6288, 3980, 1313, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6217, 6245, 1059, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6182, 8816, 967, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6162, 1143, 6493, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6152, 8577, 6442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6173, 5035, 6502, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6022, 8037, 862, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6104, 8729, 5708, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6292, 5391, 76, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6303, 5351, 129, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6066, 3444, 2577, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6113, 3625, 6001, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6105, 8730, 5709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6184, 7265, 6690, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6196, 7009, 2421, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6274, 2430, 904, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6179, 8812, 996, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6037, 7548, 842, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6112, 8739, 5979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6111, 8737, 5960, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6046, 8246, 1491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6223, 8178, 3781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6206, 7569, 2278, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6219, 7564, 2855, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6249, 7528, 2631, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6334, 7490, 5294, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6191, 7450, 601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6250, 7107, 2020, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6073, 3805, 876, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6050, 4051, 3384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6194, 6426, 219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6315, 3563, 42, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6119, 3105, 2307, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6183, 2859, 1762, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6076, 6394, 5390, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6270, 2060, 308, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6306, 5513, 819, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6267, 1296, 4381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6155, 867, 579, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6077, 530, 2442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6257, 440, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6255, 397, 367, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6216, 359, 6895, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6110, 7557, 2152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6327, 4574, 1238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6333, 8150, 2090, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6339, 8957, 2974, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6340, 8958, 4652, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6341, 8959, 6156, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6345, 8983, 7252, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6347, 8994, 7258, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6348, 8995, 1487, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6351, 8999, 1707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6364, 9013, 7286, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6374, 2623, 7350, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6375, 4200, 7351, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6343, 6861, 2307, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6350, 8998, 2971, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6259, 541, 3496, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6281, 3221, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6227, 8333, 4674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6237, 7485, 1979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6224, 8332, 1842, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6277, 3020, 649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6207, 2238, 2418, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6325, 3650, 710, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6313, 6337, 4800, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6312, 6337, 71, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6326, 57, 3073, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6355, 9004, 7283, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6268, 1388, 1281, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6365, 9014, 7287, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6298, 4641, 1009, 11, 'Original tune as published');
INSERT INTO 'dancestunesmap' VALUES (6197, 358, 3382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10305, 15577, 7537, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6260, 8328, 1621, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6295, 4356, 3109, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6294, 4356, 1257, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6302, 5239, 318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6376, 7240, 7352, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6336, 7349, 5078, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6320, 4187, 1186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6357, 9006, 7284, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6208, 8851, 1005, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6240, 7488, 2397, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6291, 7458, 5283, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6317, 6149, 666, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6328, 3921, 6946, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6269, 8193, 3012, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6225, 8193, 2489, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6377, 3199, 7353, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6380, 4989, 7356, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6382, 1929, 7358, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6383, 4891, 7359, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6384, 6398, 7360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6385, 4694, 7361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6393, 9057, 7405, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6396, 9060, 7408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6398, 9062, 11570, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6399, 9063, 7412, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6400, 9063, 7411, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6402, 9065, 2833, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6403, 9066, 7414, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6404, 4289, 4205, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6407, 9068, 7418, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6412, 9072, 7359, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6421, 9081, 7433, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6422, 1828, 2054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6423, 1828, 7434, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6424, 6794, 7435, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6432, 9087, 2069, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6457, 4718, 423, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6300, 4928, 6685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6266, 1259, 1359, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6282, 3453, 154, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6273, 2337, 892, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6444, 9101, 7493, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6322, 1949, 952, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6430, 9084, 1881, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6392, 9056, 7404, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6358, 9007, 1221, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6228, 7423, 5077, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6321, 3598, 4811, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6190, 2410, 5369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6195, 4695, 1313, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6362, 9011, 7285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6458, 8699, 5573, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6464, 9112, 7564, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6465, 9112, 7565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6472, 8174, 5769, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6479, 6763, 6764, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6481, 9118, 2680, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6482, 9119, 7572, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6483, 9119, 7573, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6486, 9129, 568, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6487, 9131, 1533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6426, 3897, 4239, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6489, 804, 1216, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6493, 9149, 4759, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6494, 9150, 5227, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6497, 9154, 2800, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6498, 9155, 2324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6501, 4802, 1352, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6502, 9169, 3050, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6503, 7694, 2348, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6480, 9117, 7571, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6359, 9008, 4371, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6485, 9040, 1127, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6261, 624, 971, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6389, 9052, 7400, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6414, 9075, 7426, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6204, 1786, 1628, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6429, 1413, 3584, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6386, 9049, 7397, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6463, 3898, 7563, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6410, 7994, 7421, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6263, 8330, 137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6243, 8339, 4852, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6363, 9012, 2963, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6460, 8670, 2268, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6245, 5547, 1326, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6324, 1790, 1329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6299, 4827, 330, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6413, 9074, 7425, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6500, 9165, 2835, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6446, 9103, 7544, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6492, 9158, 283, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6468, 9113, 1391, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6445, 9102, 7543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6441, 9098, 7489, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6435, 9092, 929, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6433, 9089, 3002, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6431, 9085, 2031, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6427, 9082, 1890, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6420, 9080, 7432, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6419, 9079, 7431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6418, 9078, 7430, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6415, 9076, 7427, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6390, 9054, 7402, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6388, 9051, 7399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6342, 8970, 1434, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6366, 9015, 2758, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6361, 9010, 699, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6356, 9005, 3408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6354, 9003, 2419, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6353, 9002, 7282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6352, 9001, 1498, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6346, 8981, 7253, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6370, 9021, 7291, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6337, 8922, 580, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6275, 2632, 1196, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6467, 8715, 7567, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6368, 9019, 7289, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6466, 8660, 7566, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6329, 8568, 3035, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6476, 8177, 5783, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6470, 8173, 5766, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6469, 8172, 5765, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6477, 8087, 7568, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6293, 7826, 1468, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6201, 7576, 2511, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6330, 7409, 5076, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6367, 9016, 7288, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6471, 6336, 4109, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6234, 4565, 1221, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6252, 4397, 2544, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6210, 4136, 2631, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6349, 8996, 7281, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6456, 971, 3516, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6372, 9046, 7311, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6373, 9047, 7320, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6205, 8850, 2031, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6332, 8567, 746, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6381, 6894, 7357, 1, '');
INSERT INTO 'dancestunesmap' VALUES (6507, 9194, 4321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6508, 9195, 4750, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6510, 9198, 778, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6513, 9225, 2396, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6425, 3897, 3679, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6520, 9237, 1648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6521, 9238, 6108, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6524, 9178, 2366, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6526, 9188, 7580, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6528, 9340, 2246, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6535, 9370, 7647, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6539, 9374, 1448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6540, 9375, 7650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6542, 9377, 2791, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6543, 9378, 7652, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6544, 9379, 183, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6546, 9381, 7600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6550, 5100, 7661, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6556, 9390, 7655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6387, 9050, 7398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6495, 9151, 1917, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6448, 9105, 7546, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6484, 9124, 422, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6405, 8705, 7415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6496, 9153, 109, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6538, 9373, 7649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6452, 9109, 7550, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6379, 4380, 7355, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6545, 9380, 3049, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6563, 9405, 7686, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6555, 9389, 7667, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6525, 9187, 7136, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6438, 9095, 7484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6440, 9097, 7487, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6397, 9061, 7409, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6406, 8658, 7416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6551, 7849, 3860, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6518, 9233, 5513, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6568, 9409, 822, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6569, 9410, 7694, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6570, 9411, 7691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6571, 9412, 3542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6573, 9414, 7693, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6574, 9415, 7695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6575, 9416, 5905, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6576, 9416, 5904, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6580, 1421, 6806, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6584, 9432, 497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6585, 9433, 5126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6595, 9480, 771, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6638, 3170, 104, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6605, 8839, 2952, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6612, 9502, 7714, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6640, 5506, 14, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6616, 9498, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6637, 2038, 7752, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6622, 9517, 7712, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6623, 9518, 7722, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6624, 9519, 7725, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6625, 9520, 7726, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6626, 9521, 7729, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6627, 9522, 7731, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6629, 9524, 7735, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6630, 9525, 7736, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6631, 9526, 7737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6645, 9559, 2392, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6658, 9585, 2201, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6659, 9599, 7763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6660, 9600, 7764, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6661, 9601, 7765, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6443, 9100, 7491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6307, 5525, 1591, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6447, 9104, 7545, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10243, 10768, 84, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6461, 8708, 6117, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6582, 9428, 7700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6310, 5972, 682, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6531, 9366, 4543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6579, 9427, 7698, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6634, 9537, 7740, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6553, 9386, 7665, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6522, 9242, 1424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6453, 9110, 7551, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6442, 9099, 7490, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6428, 9083, 7436, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6474, 8138, 5778, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6475, 8176, 5780, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6504, 4121, 7401, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6606, 8840, 10129, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6290, 4283, 1302, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6529, 4265, 11911, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6649, 7543, 2562, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6360, 9009, 5162, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6578, 9426, 7697, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6662, 9602, 7766, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6663, 9603, 7767, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6664, 9604, 7642, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6665, 9605, 7768, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6666, 9606, 7769, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6670, 9610, 1096, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6671, 9611, 1179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6672, 9612, 1171, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6673, 9613, 736, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6674, 9614, 1234, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6676, 9616, 382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6678, 9619, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6679, 9620, 482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6680, 9621, 3321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6682, 9623, 3497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6683, 9624, 1282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6684, 9625, 91, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6685, 9626, 159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6686, 9627, 736, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6687, 9628, 1051, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6688, 9629, 695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6690, 9631, 3403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6641, 9545, 7755, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6700, 9641, 7777, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6693, 9634, 7772, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6450, 9107, 7548, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6408, 9069, 7419, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6411, 9071, 7422, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6527, 9190, 7581, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6515, 9229, 3525, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6698, 9639, 7775, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6705, 9649, 7818, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6706, 9650, 7820, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6709, 9651, 1089, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6710, 9652, 7822, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6711, 9653, 7823, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6646, 9353, 4030, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6602, 8836, 972, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6541, 9376, 7651, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1307, 4562, 1229, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6459, 8672, 7561, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6478, 9115, 7569, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6558, 9391, 2905, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6620, 9513, 7306, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6648, 9560, 3115, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6708, 9560, 7819, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6559, 9387, 7681, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6560, 9387, 2134, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6519, 9236, 1360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6654, 5904, 1327, 20, '');
INSERT INTO 'dancestunesmap' VALUES (6564, 9406, 7687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6514, 9227, 3035, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6594, 9463, 7703, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6593, 9456, 1565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6562, 9404, 7685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6592, 9454, 4382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6561, 9403, 7684, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6552, 9385, 7664, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6536, 9371, 318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6532, 9367, 7645, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6530, 9365, 5725, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6554, 9388, 7666, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6577, 9331, 186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6511, 9196, 4763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6505, 9193, 5593, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6586, 9435, 7701, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6451, 9108, 7549, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6437, 9094, 1164, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6517, 8977, 923, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6604, 8838, 2227, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6548, 2387, 2769, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6509, 9197, 4833, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6512, 9199, 4824, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6599, 8833, 7706, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6598, 8832, 7705, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6473, 8175, 5771, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6632, 9536, 7738, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6689, 9630, 568, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6639, 5039, 6116, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6537, 4819, 7648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6677, 9617, 2559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6506, 9192, 2916, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6490, 802, 1314, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6725, 9665, 7847, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6726, 9666, 1629, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6731, 9673, 7848, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6734, 9689, 7850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6735, 9690, 7851, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6736, 9691, 7852, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6737, 9692, 7853, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6738, 9693, 7854, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6739, 9694, 1458, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6740, 9694, 2761, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6741, 9695, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6742, 9695, 6335, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6743, 9696, 7855, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6744, 9697, 3690, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6746, 9703, 1516, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6747, 9703, 4412, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6748, 9704, 2798, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6749, 9704, 247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6750, 9706, 512, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6751, 9707, 2983, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6729, 9669, 5911, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6635, 9540, 7741, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6675, 9615, 2559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6653, 5829, 1613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6609, 9499, 7711, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6667, 9607, 7770, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6668, 9608, 7771, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6724, 9664, 1368, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6610, 9500, 1119, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6615, 9504, 7717, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6732, 9674, 1603, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6572, 9413, 7692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6657, 9565, 7762, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6656, 9564, 7761, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6603, 8837, 4176, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6600, 8834, 7707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6613, 9503, 7715, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6608, 8831, 6691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6644, 9554, 1586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6695, 9636, 7773, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6583, 9431, 2107, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6587, 9436, 7702, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6581, 6672, 7699, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6753, 9709, 1659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6757, 9712, 273, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6758, 9713, 141, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6759, 9714, 1008, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6760, 9715, 2054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6761, 9716, 1674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6764, 9717, 932, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6765, 9718, 4361, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6766, 9719, 1080, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6767, 9719, 1683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6768, 9720, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6769, 9720, 26, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6770, 9721, 392, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6772, 9723, 1728, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6773, 9723, 1729, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6778, 9727, 196, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6779, 9727, 986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6780, 9729, 1346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6781, 8962, 1371, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6784, 9732, 973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6785, 9732, 1732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6788, 9737, 1711, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6789, 2641, 1831, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6793, 9739, 434, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6794, 9744, 1970, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6795, 9747, 1010, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6796, 9748, 1501, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6797, 9749, 874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6798, 9750, 2561, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6799, 9751, 4372, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6812, 9618, 6492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6814, 9806, 231, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6827, 9821, 2660, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6829, 9823, 6459, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6832, 9825, 2388, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6833, 9826, 7943, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6834, 9827, 7944, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6838, 3198, 7833, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6843, 9912, 434, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6844, 9921, 1603, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6845, 9924, 2484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6854, 9946, 7972, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6455, 9111, 7553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6647, 7654, 7760, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6534, 9369, 7646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6650, 9561, 536, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6394, 9058, 7406, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6533, 9368, 3156, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6791, 4351, 3384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6809, 9770, 3484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6777, 9726, 1618, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6752, 9708, 145, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6697, 9638, 7774, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6439, 9096, 7485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6728, 9668, 888, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6703, 5366, 445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6601, 8835, 10864, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6855, 9948, 7973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6856, 9951, 7976, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6857, 9952, 7977, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6858, 9953, 7978, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6859, 9954, 7979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6860, 5233, 5223, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6861, 8491, 7980, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6862, 9955, 7981, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6863, 9956, 7982, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6864, 9957, 7984, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6865, 9958, 7986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6866, 9959, 7987, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6867, 9960, 1929, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6868, 9961, 2871, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6869, 9961, 7989, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6870, 9962, 7990, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6871, 9963, 7991, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6872, 8711, 7992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6873, 8711, 7993, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6874, 9964, 7994, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6875, 9965, 7995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6876, 9966, 7996, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6877, 3259, 5884, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6878, 9905, 8001, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6879, 9968, 7997, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6880, 9842, 7998, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6881, 9969, 7999, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6882, 9970, 8000, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6883, 9971, 8002, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6885, 9979, 8003, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6886, 9982, 8004, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6890, 9992, 8006, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6891, 9994, 890, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6892, 9995, 1425, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6607, 9497, 7708, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6633, 9354, 7739, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6806, 9766, 7879, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6713, 9655, 7825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6718, 9658, 533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6771, 9722, 824, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6636, 9332, 6951, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6723, 9661, 1458, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6669, 9609, 159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6701, 9642, 7778, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6702, 9643, 7779, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6716, 9657, 7828, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6719, 9659, 7830, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6712, 9654, 7824, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6884, 9837, 3300, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2005, 7068, 1136, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6808, 9768, 7880, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6730, 9672, 991, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6824, 9803, 7348, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6826, 9820, 4482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6888, 9989, 3309, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6589, 9446, 1262, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6790, 9017, 7867, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6714, 9656, 7826, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6643, 9425, 7757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6816, 9814, 7931, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6803, 9759, 7876, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6804, 9760, 7877, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6754, 9710, 580, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6733, 9688, 7849, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6727, 9667, 2170, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6721, 9662, 1802, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6694, 9635, 3145, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6692, 9633, 4732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6651, 9562, 6109, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6825, 9547, 655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6628, 9523, 7734, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6591, 9451, 1474, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6566, 9407, 7689, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6813, 5648, 688, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6821, 9022, 7936, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6590, 8725, 12952, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6523, 9336, 6760, 1, '');
INSERT INTO 'dancestunesmap' VALUES (6704, 9167, 7817, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6597, 7243, 7704, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6652, 9563, 6612, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6896, 10002, 8010, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6904, 10047, 8017, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6919, 10098, 8024, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6931, 10146, 2294, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6932, 10146, 2753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6933, 10146, 2336, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6776, 9725, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6848, 9928, 1368, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6898, 8684, 601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6818, 9816, 7933, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6783, 9731, 1385, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6817, 9815, 7932, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6850, 9934, 2798, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6852, 9939, 3853, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6842, 8722, 7969, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6828, 9822, 7941, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6927, 10142, 8029, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6792, 9738, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6756, 9711, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6846, 8956, 122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6851, 9938, 7578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6923, 8923, 1264, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6805, 9762, 7878, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6929, 10144, 8030, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6853, 9945, 7970, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6820, 9818, 7935, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6924, 10141, 8028, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6902, 10017, 41, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6934, 10147, 2624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6787, 9735, 273, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6899, 9168, 7840, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6928, 10143, 1774, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6936, 10149, 8032, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6930, 10145, 1731, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6935, 10148, 8031, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6938, 10186, 8034, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6940, 10189, 7503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6941, 10190, 8035, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6942, 10192, 8035, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6946, 10230, 8048, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6950, 206, 6713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6956, 10289, 448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6960, 10318, 8180, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6961, 10319, 8181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6964, 10331, 120, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6968, 8359, 2756, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6969, 10337, 8172, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6970, 10340, 8179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6971, 10343, 8184, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6972, 10348, 8185, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6974, 10350, 8186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6975, 6630, 1391, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6976, 2564, 372, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6980, 6651, 607, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6982, 10362, 1620, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6983, 8381, 1162, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6984, 8383, 1337, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6985, 8383, 1883, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6986, 8383, 3379, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6990, 10378, 2270, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6991, 10378, 1243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6994, 7003, 2138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6996, 10397, 8205, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7001, 10425, 8222, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7002, 10426, 8223, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7004, 10450, 8224, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7005, 10453, 6570, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7006, 3868, 7213, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7009, 10316, 4181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7023, 10517, 5957, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7024, 10517, 5959, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7034, 9976, 1578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7035, 8377, 8242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7036, 10527, 8243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7047, 7870, 521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7048, 10582, 7557, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7049, 10584, 7557, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7050, 8382, 7128, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7051, 8384, 4346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7052, 10585, 3484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7055, 10586, 8251, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7056, 10588, 8256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7011, 10484, 7226, 10, 'AAB');
INSERT INTO 'dancestunesmap' VALUES (7063, 10598, 8264, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7068, 10643, 8318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6720, 9660, 7831, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6887, 9986, 7975, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7007, 9838, 6977, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6915, 10073, 8021, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6917, 10074, 8022, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6699, 9640, 2388, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6997, 10401, 382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7058, 10591, 8258, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7044, 10548, 6422, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6918, 10085, 122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6762, 9679, 2399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6978, 9670, 372, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6987, 4537, 3647, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6722, 9663, 982, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6977, 3892, 372, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7043, 10428, 37, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6948, 1314, 1084, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6981, 8380, 1109, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6763, 8811, 382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7040, 10546, 8246, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6945, 10195, 8046, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6949, 4848, 1084, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7061, 10595, 8261, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6937, 10150, 8033, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6979, 4323, 607, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6920, 10151, 8025, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6841, 7738, 5072, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6836, 9829, 7965, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7067, 10642, 7280, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6947, 10231, 8049, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6802, 9757, 7875, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6911, 10062, 4904, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7064, 10599, 8263, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7062, 10597, 8262, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7042, 10547, 4801, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7039, 10545, 8245, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7015, 4140, 5339, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7032, 10523, 1021, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7031, 10522, 2065, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7028, 10520, 2482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7026, 10519, 8240, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7027, 10519, 8241, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6895, 9999, 8009, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6993, 10356, 8189, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6988, 10364, 8187, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7000, 10424, 5231, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6962, 10329, 1878, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6921, 10153, 2997, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6914, 10068, 8020, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6913, 10066, 8019, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6912, 10065, 1112, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6910, 10061, 2947, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6909, 10060, 8018, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6908, 10059, 5929, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6907, 10058, 7502, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6905, 10049, 2905, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6811, 9802, 7881, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6837, 9834, 122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6831, 9824, 7942, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6823, 9819, 7938, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6822, 9819, 7937, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6815, 9813, 7929, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6810, 9775, 7873, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6800, 9752, 1569, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6900, 9740, 1995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6775, 9724, 1841, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6952, 10275, 867, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6953, 10273, 1583, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7025, 8937, 6728, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6954, 10282, 206, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7019, 8929, 2029, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6965, 8033, 3329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7053, 7970, 216, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6992, 10367, 8188, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7038, 10544, 4833, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6973, 7031, 2949, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6903, 2458, 1781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6943, 10193, 8045, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6939, 9899, 5905, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6819, 9817, 7934, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6835, 9828, 6464, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7065, 8996, 2316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7014, 1555, 3645, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7066, 1296, 8316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7016, 10507, 8238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6893, 8088, 3613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7017, 10513, 8239, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7070, 10645, 8373, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7071, 10646, 8374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7072, 10640, 2342, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7073, 10648, 8375, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7074, 10648, 8376, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7085, 10677, 8386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7086, 10665, 8389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7087, 10676, 8392, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7089, 10233, 8395, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7093, 10650, 8377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7108, 5140, 1066, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7111, 10787, 2418, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7119, 10795, 7927, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7120, 10796, 8437, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6967, 10334, 3201, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7114, 10790, 8472, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6966, 7501, 7009, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7083, 10662, 920, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7059, 10592, 8259, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7003, 8778, 8194, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7075, 10652, 8378, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7077, 10654, 8381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7095, 10402, 8465, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7081, 10660, 3431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7079, 10658, 8383, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7054, 9812, 760, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7118, 10794, 3330, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7069, 10644, 8372, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7091, 10702, 5414, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7076, 10651, 8379, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6958, 2020, 4123, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6957, 2020, 4136, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7122, 10797, 8308, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7018, 10515, 2258, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7092, 10703, 8399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7133, 10463, 7, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7135, 10771, 1852, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7144, 10825, 3860, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7145, 10827, 5131, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7146, 10829, 8479, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7147, 10830, 384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7151, 10835, 1744, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7152, 10836, 160, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7153, 10837, 2443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7154, 10838, 3433, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7155, 10841, 1691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7158, 10850, 1858, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7162, 10853, 8484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7180, 10867, 8304, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7182, 10868, 2152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7183, 10869, 2918, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7184, 10870, 1208, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7185, 10871, 451, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7187, 10873, 1332, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7188, 10874, 2773, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7190, 10876, 132, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7193, 10911, 8497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7196, 10913, 4055, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7202, 10716, 1462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7203, 10979, 267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7204, 10980, 2212, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7205, 10981, 8580, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7207, 10983, 510, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7208, 10984, 8581, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7209, 10985, 8582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7211, 10987, 8583, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7212, 10988, 8584, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7213, 10989, 8585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7214, 10991, 1091, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7215, 10990, 4073, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7216, 10993, 333, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7217, 11012, 4517, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7235, 11035, 749, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7236, 11056, 8591, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7238, 11077, 6322, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7242, 10526, 8596, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7244, 10536, 1578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7245, 11083, 3690, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7246, 11084, 109, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7247, 11085, 2410, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7248, 11086, 5143, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7249, 11087, 1988, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7250, 11089, 3020, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7252, 11093, 2696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7253, 11096, 8599, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7254, 11098, 476, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7255, 11099, 8600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7256, 9978, 1291, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7257, 10342, 7294, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7258, 7982, 2545, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7260, 5148, 2762, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7268, 7481, 1209, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7271, 11165, 8809, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7272, 11166, 521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7273, 11167, 503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7274, 11168, 1437, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7275, 11169, 760, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7276, 11153, 5905, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7156, 10843, 1552, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7057, 10589, 8257, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7012, 9442, 989, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6906, 10057, 1767, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7082, 10661, 8384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6925, 8925, 3024, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7121, 7530, 8438, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7265, 11111, 8424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7199, 10917, 6392, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7173, 10861, 2650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7165, 10857, 8487, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7132, 10769, 7501, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7046, 8965, 8249, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6989, 10370, 3405, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7143, 998, 5021, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7277, 11184, 8838, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7045, 10549, 8248, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7088, 10678, 8393, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7110, 10653, 944, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7164, 10855, 8486, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7113, 10789, 8380, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7195, 10912, 2865, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7239, 11081, 8593, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7078, 10656, 8382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6944, 10194, 5825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7150, 10834, 7313, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7175, 10863, 8282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7178, 10865, 8293, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7219, 11014, 100, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7222, 11017, 2912, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7116, 10792, 8474, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6955, 10286, 8156, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7090, 10695, 4848, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7138, 10774, 1352, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7115, 10791, 8473, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7126, 10799, 8461, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7163, 10854, 8485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7168, 10859, 8490, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7103, 10405, 8469, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7266, 11112, 4125, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7263, 11109, 8408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7262, 11108, 8404, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7008, 10459, 821, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7218, 11013, 8586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7201, 10943, 295, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7241, 10931, 8595, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7198, 10915, 2867, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7191, 10877, 2424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7177, 10864, 8288, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7112, 10788, 760, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7102, 10783, 8468, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7194, 10782, 7537, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7179, 10778, 8301, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7109, 7157, 1066, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7131, 10770, 2888, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7094, 10672, 1116, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7084, 10663, 8385, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7240, 10542, 8594, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7033, 10525, 1605, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7022, 10516, 5933, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7021, 10516, 2668, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7096, 10308, 2696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7105, 10404, 1785, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6995, 10395, 3224, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7106, 10406, 1818, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7107, 10406, 8471, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6951, 10052, 7620, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7167, 10049, 8489, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7134, 10007, 1264, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6959, 9974, 8178, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7060, 9774, 8260, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7166, 10858, 8488, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7140, 10776, 272, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7099, 9883, 8468, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7270, 8218, 2608, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7129, 10803, 1871, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7287, 9534, 8873, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7292, 11199, 8870, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7297, 11212, 3959, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7299, 7621, 8882, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7307, 5697, 7417, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7308, 10332, 8182, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7142, 10824, 5598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7278, 11185, 8839, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7281, 11188, 8846, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7243, 10575, 8597, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7269, 8226, 1398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7210, 10986, 2691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7237, 11076, 8592, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7264, 11110, 8416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7137, 10773, 5581, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7160, 10856, 416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7189, 10875, 281, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7306, 10532, 2577, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7298, 9898, 2265, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7124, 9888, 8452, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7224, 11019, 5961, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7227, 11021, 5048, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7228, 11022, 7214, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7229, 11023, 2588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7232, 11026, 8589, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7220, 11015, 573, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7234, 11028, 8590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7230, 11024, 8588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7221, 11016, 233, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7176, 9854, 8285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7259, 1996, 2762, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7170, 8702, 8492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7309, 11268, 8902, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7311, 3641, 8890, 10, '');
INSERT INTO 'dancestunesmap' VALUES (665, 2436, 1322, 11, '');
INSERT INTO 'dancestunesmap' VALUES (7316, 11269, 8904, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7317, 1967, 8687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7318, 11277, 8967, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7319, 11278, 8968, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7320, 11280, 8969, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7321, 11281, 8970, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7324, 11286, 8973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7326, 11293, 8975, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7328, 725, 8982, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7329, 11297, 7381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7331, 5025, 8980, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7332, 5283, 8981, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7333, 4289, 8983, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7335, 11301, 3012, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7338, 11304, 8935, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7339, 11305, 1978, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7342, 11306, 8987, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7343, 11307, 8988, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7345, 11292, 3040, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7346, 11356, 8989, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7347, 11355, 8990, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7348, 11355, 8991, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7349, 11355, 8992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7350, 11355, 8993, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7351, 11354, 8994, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7352, 11361, 8995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7358, 11374, 1852, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7378, 11396, 2636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7384, 2168, 2217, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7385, 11376, 1466, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7387, 8781, 283, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7388, 11432, 2017, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7389, 11432, 685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7392, 11428, 2255, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7393, 11430, 8850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7407, 11540, 237, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7409, 3395, 128, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7412, 11557, 8946, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7390, 11434, 5407, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7414, 11559, 9023, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7415, 11560, 9072, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7421, 11566, 9077, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7428, 11571, 9082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7429, 11572, 9084, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7432, 11576, 9087, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7433, 11578, 9088, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7434, 11578, 9089, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7435, 11580, 9090, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7436, 11580, 9091, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7437, 11580, 9092, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7438, 11580, 9093, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7450, 11593, 403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7452, 11599, 9158, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7453, 11599, 9159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7462, 11614, 137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7465, 11619, 749, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7468, 11624, 2240, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7469, 11626, 93, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7470, 11626, 624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7471, 11626, 1600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7441, 8344, 7577, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7372, 11392, 7797, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7136, 10772, 1881, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7379, 11397, 2594, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7357, 11370, 3865, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7139, 10578, 1087, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7117, 10793, 8475, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7399, 11482, 9046, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7417, 11562, 9074, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7336, 11302, 8984, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7449, 11592, 2357, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7267, 11107, 8789, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7327, 11294, 8976, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7370, 11389, 9024, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7466, 11620, 624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7443, 10682, 8396, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7461, 11610, 674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7459, 11608, 5387, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7386, 11403, 7234, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7430, 11574, 9085, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7431, 11574, 9086, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7127, 10800, 975, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7186, 10872, 1565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7226, 11020, 10129, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7171, 10860, 13356, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7181, 9352, 1067, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7280, 11187, 8844, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7405, 4279, 8692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7467, 11621, 5154, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7206, 10982, 790, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7231, 11025, 2167, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7291, 8529, 523, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7148, 10832, 8480, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7251, 11091, 8598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7295, 11197, 8874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7290, 11198, 122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7293, 11200, 8871, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7296, 11201, 8875, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7294, 11202, 8872, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7261, 7245, 723, 11, '');
INSERT INTO 'dancestunesmap' VALUES (7464, 11618, 2704, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7419, 11564, 9081, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7223, 11018, 2896, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7420, 11565, 9076, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7310, 2668, 8023, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7458, 11607, 137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7457, 11603, 2957, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7455, 11600, 9161, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7451, 11598, 9157, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7416, 11561, 9073, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7411, 11554, 7573, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7403, 11486, 9052, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7402, 11485, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7401, 11484, 9050, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7398, 11481, 9045, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7383, 11400, 106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7381, 11399, 9029, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7376, 11395, 1137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7371, 11391, 9025, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7369, 11390, 2269, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7367, 11373, 9006, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7364, 11371, 9003, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7360, 11368, 8999, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7425, 11193, 9032, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7283, 11190, 8849, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7233, 11027, 7531, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7197, 10914, 1415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7304, 10957, 5208, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7305, 10097, 5713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7192, 9148, 8441, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7286, 11195, 8867, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7285, 11192, 8857, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7448, 11591, 904, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7427, 8375, 9083, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7130, 9903, 8477, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7289, 11196, 8869, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7284, 11191, 8858, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7282, 11189, 8847, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7394, 9121, 5080, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7439, 11582, 9095, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7315, 5853, 8903, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7472, 11626, 1566, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7480, 10901, 2806, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7482, 11657, 6764, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7485, 11681, 9240, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7489, 11705, 9241, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7373, 10105, 8840, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7473, 11627, 9162, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7493, 11714, 9244, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7491, 11712, 9242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7354, 11363, 4913, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7492, 11713, 9243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7494, 11715, 9245, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7366, 11372, 9005, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7340, 10232, 2457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7374, 11393, 9026, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7325, 9701, 8974, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7426, 11570, 2316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7423, 11568, 9079, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7408, 9728, 1290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10244, 18316, 11276, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7344, 11289, 3072, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7322, 11282, 8971, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7410, 11553, 7664, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7397, 11480, 9044, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7404, 11487, 9055, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7454, 11516, 9160, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7474, 11628, 9163, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7447, 10460, 8390, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7500, 11753, 109, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7505, 11766, 1566, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7506, 11767, 3446, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7513, 11543, 3061, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7519, 7365, 2138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7525, 9202, 9380, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7526, 9241, 7626, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7528, 11877, 9382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7531, 11880, 9416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7532, 11881, 9417, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7533, 11882, 9418, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7534, 11883, 9419, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7539, 11886, 9424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7541, 11888, 9426, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7542, 11889, 9427, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7543, 11889, 9428, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7547, 7008, 8715, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7553, 9782, 9439, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7555, 5777, 9441, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7556, 9784, 9442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7558, 9786, 9444, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7566, 11912, 9449, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7567, 11912, 9450, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7569, 11916, 9452, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7570, 11917, 9453, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7572, 11930, 792, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7573, 1799, 4360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7574, 4035, 4360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7575, 5131, 4360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7576, 11931, 1022, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7577, 11932, 4095, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7578, 11933, 9461, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7580, 11935, 2214, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7581, 11935, 2316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7582, 11936, 9463, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7583, 11938, 9464, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7584, 11937, 2048, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7586, 11940, 835, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7588, 11942, 9481, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7589, 11943, 9482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7590, 11944, 9483, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7591, 11945, 9484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7592, 11941, 9485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7595, 11951, 149, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7598, 7213, 403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7551, 9781, 858, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7610, 4203, 1084, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7611, 11974, 3489, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7614, 8195, 652, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7615, 8195, 2456, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7616, 8197, 488, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7593, 874, 3502, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7617, 8197, 242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7620, 2862, 8727, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7622, 5973, 7245, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7623, 5241, 2510, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7624, 5913, 765, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7625, 7154, 2556, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7626, 12008, 2126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7627, 12009, 5505, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7628, 12010, 9061, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7629, 12011, 9301, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7630, 12012, 9336, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7631, 12013, 9536, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7634, 12061, 9561, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7635, 12062, 9562, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7636, 12070, 9545, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7637, 12069, 9554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7638, 12072, 122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7646, 7345, 3192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7647, 7502, 159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7648, 7483, 137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7649, 7535, 1578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7650, 7405, 1159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7644, 1158, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7651, 7398, 1377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7652, 7497, 3497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7653, 7403, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7654, 7482, 269, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7655, 7491, 754, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7656, 7491, 759, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7657, 7492, 2123, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7658, 7479, 269, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7659, 7426, 2279, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7660, 7493, 271, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7518, 1191, 2138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7585, 11939, 1594, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7157, 10844, 6732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7456, 11602, 3457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7301, 10083, 8798, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7520, 11816, 3068, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7444, 10647, 8045, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7640, 11785, 9563, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7488, 9926, 1620, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7557, 9785, 9443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7594, 5884, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7300, 9869, 6215, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7418, 11563, 9075, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7550, 9780, 9438, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7477, 11631, 135, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7368, 11375, 9007, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1142, 3986, 1160, 11, '');
INSERT INTO 'dancestunesmap' VALUES (7323, 11283, 8972, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7641, 11780, 9563, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7356, 11366, 8997, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7645, 3244, 1542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7487, 11684, 512, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7529, 11878, 9413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7618, 8200, 3682, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7535, 11884, 9420, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7536, 11885, 9421, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7579, 11934, 9462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7502, 11762, 4677, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7446, 10580, 8388, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7568, 11913, 9451, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7540, 11887, 9425, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7530, 11879, 9415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7642, 11787, 9564, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7511, 11772, 2522, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7565, 11749, 9447, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7499, 11727, 2047, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7490, 11707, 2455, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7314, 6720, 6639, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7479, 11637, 3321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7476, 11632, 3448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7463, 11616, 4324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7424, 11569, 9080, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7422, 11567, 9078, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7406, 11523, 1198, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7395, 11478, 9051, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7496, 11402, 9248, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7375, 11394, 9027, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7359, 11367, 8998, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7609, 10866, 9513, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7486, 10775, 8478, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7440, 10351, 9094, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7554, 9783, 9440, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7668, 5487, 977, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7377, 9127, 9028, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7587, 11533, 9480, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7619, 8200, 9514, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7501, 11758, 9277, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7484, 11680, 9239, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7643, 4948, 4339, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7497, 4727, 1257, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7601, 2571, 3767, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7603, 3957, 1225, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7475, 4313, 1913, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7560, 10512, 9445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7561, 10512, 1466, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7562, 10804, 8476, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7661, 7425, 3590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7662, 7410, 1351, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7663, 7445, 273, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7664, 7512, 532, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7665, 7363, 2305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7666, 7522, 872, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7667, 7354, 271, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7675, 12251, 3287, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7504, 11764, 1261, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7521, 11876, 7252, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7507, 6964, 9281, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7671, 12124, 568, 20, 'Original tune as per dance author');
INSERT INTO 'dancestunesmap' VALUES (7679, 10102, 5933, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7548, 9778, 9436, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7510, 11770, 1922, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7604, 3945, 49, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7442, 11583, 773, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7600, 5589, 2536, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7632, 12024, 173, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7677, 12278, 9587, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7522, 9408, 9393, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7639, 11524, 1224, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7523, 5430, 9378, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7672, 11522, 2258, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7527, 9207, 7896, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7613, 8113, 8143, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7612, 8113, 942, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7552, 4841, 6119, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7546, 4388, 1117, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7681, 12435, 9594, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7682, 12444, 9596, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8882, 14926, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7693, 10101, 9598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7694, 11977, 9599, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7698, 12447, 9603, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7707, 12452, 9609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7710, 12461, 1659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7711, 12463, 367, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7722, 779, 2523, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7724, 1024, 8701, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8826, 14729, 2757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8827, 14731, 2580, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8828, 14733, 671, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8829, 14733, 200, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8830, 14734, 7191, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8831, 14735, 4290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8832, 14735, 1742, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8833, 14736, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8834, 14737, 1472, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8839, 14742, 6191, 10, 'EMI ''One up'' OU2157 1976');
INSERT INTO 'dancestunesmap' VALUES (8843, 14742, 739, 10, 'EMI ''One up'' OU2157 1976');
INSERT INTO 'dancestunesmap' VALUES (8857, 14799, 3246, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8858, 14811, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8859, 14811, 5099, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8865, 14910, 1995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8866, 14910, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8867, 14911, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8869, 14913, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8870, 14914, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8871, 14915, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8872, 14916, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8874, 14918, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8875, 14919, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8878, 14923, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8879, 14924, 12534, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8883, 14927, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8886, 14928, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8887, 14929, 3483, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8888, 14929, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8890, 8704, 2841, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8891, 8704, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8893, 14931, 992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8894, 14931, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8897, 13092, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8898, 13093, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8900, 13095, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8901, 13096, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8902, 13097, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8903, 13098, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8908, 14932, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8909, 14933, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8910, 14934, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8911, 14935, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8912, 14936, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8913, 14937, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8914, 14938, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8915, 14939, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8916, 14939, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8917, 14939, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8919, 8782, 8201, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8920, 12838, 3613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8921, 14611, 12235, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8922, 14610, 12234, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8923, 13757, 7482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8284, 13757, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8877, 14921, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8932, 14974, 12570, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8933, 14975, 543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8934, 14976, 12571, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8935, 14977, 12572, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8928, 14963, 12566, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8941, 15019, 12577, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8942, 15026, 4273, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8943, 15027, 12578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7700, 8727, 9605, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8892, 14930, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7731, 2631, 2780, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8845, 14566, 12524, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7690, 10433, 9597, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8850, 14793, 12526, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8838, 14741, 12523, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8846, 14790, 12525, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8863, 14813, 12529, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8822, 14725, 6586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7692, 5872, 2152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7633, 12056, 8885, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7704, 12450, 2473, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7680, 12434, 9593, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8854, 14796, 5931, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8918, 13103, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8825, 14728, 11516, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8851, 14794, 186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8852, 14794, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8848, 14792, 2031, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7697, 12446, 9602, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7564, 8926, 2140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10228, 18275, 13874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7355, 11365, 5979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7730, 2504, 3834, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7723, 934, 3511, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8905, 13101, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7674, 12247, 3032, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7687, 12454, 6507, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7691, 10820, 2152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7728, 2156, 3764, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7549, 9779, 9437, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7512, 11773, 9285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8856, 14798, 11522, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8864, 14814, 12530, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8931, 14972, 12569, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8936, 14979, 12075, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7683, 8238, 6732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7685, 10381, 3299, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8926, 14942, 12535, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7545, 11892, 9435, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8847, 14791, 8108, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7699, 12448, 9604, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7676, 12277, 2047, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8907, 2934, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7563, 9343, 9446, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7544, 11890, 1981, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7515, 11771, 9284, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7498, 11727, 2316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7684, 11512, 2187, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7695, 10564, 9600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7509, 9787, 9279, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7596, 11968, 1332, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7524, 9234, 9379, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7621, 8855, 934, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4200, 7795, 4045, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7508, 11769, 3137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7706, 12451, 2670, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7705, 12451, 234, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7719, 2903, 3437, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7670, 11257, 9585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7732, 2713, 9622, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7597, 2372, 8026, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8836, 14739, 3068, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7725, 1733, 3683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7721, 140, 2166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7673, 12106, 9586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7669, 1533, 9584, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8939, 14989, 506, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8895, 13090, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8876, 14920, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8896, 13091, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8889, 13099, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8861, 14816, 12532, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8868, 14912, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7713, 2113, 1078, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7712, 319, 1078, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7689, 10433, 7323, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8821, 14724, 12519, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7709, 12457, 2798, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7715, 5137, 1078, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7708, 12455, 2155, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8823, 14726, 12520, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8819, 14722, 12517, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8862, 14817, 12533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8938, 14987, 604, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8817, 14720, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8873, 14917, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7688, 10535, 674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8880, 14925, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8860, 14815, 12531, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8906, 13102, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8927, 14961, 2369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8937, 14984, 10060, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7701, 11756, 9606, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8944, 15028, 1862, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8945, 15029, 11987, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8960, 15045, 12536, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8962, 15047, 12542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8968, 15053, 2308, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8969, 15054, 12560, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8971, 14546, 9676, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8972, 14546, 3290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8947, 15031, 1565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8974, 15077, 12592, 1, '');
INSERT INTO 'dancestunesmap' VALUES (8975, 15078, 973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8976, 15081, 2559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8977, 8679, 12593, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8986, 15132, 495, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8987, 15133, 12620, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8988, 15133, 7719, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8989, 15135, 9003, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8990, 15135, 12621, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8991, 15142, 7779, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8992, 15143, 8758, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8993, 15144, 93, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8996, 15146, 58, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8997, 15147, 8045, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4162, 3654, 4026, 1, '');
INSERT INTO 'dancestunesmap' VALUES (70, 287, 718, 1, '');
INSERT INTO 'dancestunesmap' VALUES (468, 1704, 246, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9008, 15100, 12666, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9003, 14295, 11777, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9016, 15107, 12673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9044, 9773, 8955, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9045, 9773, 11567, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9049, 7473, 1301, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9050, 15274, 3072, 10, 'as »Waulkin'' the Fauld«');
INSERT INTO 'dancestunesmap' VALUES (9054, 15278, 12700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9055, 15279, 12701, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9056, 15280, 12704, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9058, 15282, 12707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9059, 15283, 12708, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9060, 15284, 12081, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9007, 15099, 12665, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9073, 3083, 5186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9074, 3083, 1171, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9076, 13740, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9077, 14996, 521, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9078, 14998, 12622, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9080, 14527, 12737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9082, 15337, 141, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9089, 15265, 5390, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9105, 14014, 5080, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9106, 1749, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9037, 15230, 1467, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9098, 15365, 2255, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9088, 15360, 12829, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9086, 14356, 12716, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9066, 15308, 12714, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9006, 15210, 12641, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9084, 14363, 12712, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8983, 14604, 1541, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8984, 15128, 12619, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9096, 15363, 121, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9005, 13117, 19, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9046, 15268, 7490, 10, '');
INSERT INTO 'dancestunesmap' VALUES (344, 1277, 302, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9071, 15313, 9998, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9051, 15275, 12695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8952, 15038, 12583, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9004, 13117, 2980, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8982, 15098, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8966, 15051, 10226, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9019, 15110, 12676, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8973, 15074, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (309, 1100, 891, 12, '');
INSERT INTO 'dancestunesmap' VALUES (1842, 6448, 550, 1, '');
INSERT INTO 'dancestunesmap' VALUES (8948, 15032, 12580, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9031, 15122, 12688, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8985, 15129, 614, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9021, 15112, 12678, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9013, 15104, 12670, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9091, 15375, 2896, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9052, 15276, 12698, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9083, 15338, 1878, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9081, 8569, 5123, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9067, 15309, 12715, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9062, 15286, 12710, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9022, 15113, 12680, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8955, 15041, 1785, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9085, 7560, 3930, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8954, 15040, 12585, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9065, 15307, 12713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8904, 13100, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8964, 15049, 12550, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7720, 15, 2160, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9107, 2276, 1087, 2, '');
INSERT INTO 'dancestunesmap' VALUES (7729, 2419, 1518, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7696, 12445, 9601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (257, 950, 231, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9108, 950, 2806, 2, '');
INSERT INTO 'dancestunesmap' VALUES (8835, 14739, 791, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2004, 7065, 1802, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9070, 15311, 12663, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9029, 15120, 12686, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7703, 12453, 9608, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10229, 18276, 13876, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7382, 7941, 576, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7726, 1793, 2183, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9079, 15179, 10158, 1, '');
INSERT INTO 'dancestunesmap' VALUES (7714, 4302, 1078, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8930, 14967, 12567, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8994, 15145, 1255, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7559, 11267, 1208, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7717, 2342, 2646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9090, 15374, 1882, 10, '');
INSERT INTO 'dancestunesmap' VALUES (620, 2294, 538, 1, '');
INSERT INTO 'dancestunesmap' VALUES (8979, 8674, 12595, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8929, 14965, 9522, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8946, 15030, 3197, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8958, 15033, 9703, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8949, 15034, 12581, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8959, 15036, 12587, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8957, 15043, 10306, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9012, 15103, 12669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9020, 15111, 12677, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8820, 14723, 12518, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9092, 15361, 2110, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9095, 15362, 10409, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9099, 15366, 8886, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9100, 15367, 129, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9101, 15368, 9187, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9103, 15370, 7881, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9104, 15372, 12876, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7702, 12449, 9607, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9000, 6712, 12639, 1, 'Official tune');
INSERT INTO 'dancestunesmap' VALUES (9033, 15123, 12690, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9093, 12517, 7927, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9094, 11156, 121, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6745, 9702, 1234, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8978, 8669, 12594, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9057, 15281, 12705, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8981, 14247, 84, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8980, 14247, 21, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5447, 6188, 2703, 1, '');
INSERT INTO 'dancestunesmap' VALUES (6618, 6188, 6276, 2, '');
INSERT INTO 'dancestunesmap' VALUES (7727, 2004, 2082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9034, 15124, 12691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8597, 13357, 5535, 10, 'The Cape Breton version, not the one from Kerr''s Collection');
INSERT INTO 'dancestunesmap' VALUES (2959, 1215, 875, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8998, 1215, 3665, 20, '');
INSERT INTO 'dancestunesmap' VALUES (9014, 15105, 12671, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9030, 15121, 12687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8956, 15042, 12586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9026, 14361, 12692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9048, 13153, 1221, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9017, 15108, 12674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9011, 15102, 12668, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9027, 15118, 12684, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9018, 15109, 12675, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9024, 15115, 12682, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9025, 15116, 12683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9023, 15114, 12681, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9063, 15299, 12711, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9036, 15229, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9072, 11360, 195, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8961, 15046, 12539, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8951, 15037, 12215, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9087, 13135, 10010, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8963, 15048, 12546, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9115, 5590, 1948, 1, '');
INSERT INTO 'dancestunesmap' VALUES (1545, 5373, 1481, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9175, 14898, 12990, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1613, 5623, 1190, 1, '');
INSERT INTO 'dancestunesmap' VALUES (1614, 5623, 1734, 2, '');
INSERT INTO 'dancestunesmap' VALUES (9122, 10486, 1745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9123, 14996, 1952, 2, '');
INSERT INTO 'dancestunesmap' VALUES (9125, 8734, 6490, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9126, 12035, 2299, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9128, 12037, 10153, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9130, 12038, 12626, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9131, 12039, 12627, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9132, 12040, 1578, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9133, 12041, 4323, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9134, 12042, 12628, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9135, 12043, 12629, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9137, 15415, 12820, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9140, 15421, 12916, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9148, 15448, 650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (214, 801, 192, 1, '');
INSERT INTO 'dancestunesmap' VALUES (4368, 4285, 4105, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9151, 1725, 12949, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9152, 8410, 1772, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9156, 15470, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9159, 15529, 8174, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9163, 15532, 3007, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9164, 15533, 2483, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9165, 15535, 2081, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9167, 15537, 7131, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9168, 488, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9177, 14902, 9913, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9180, 8058, 7882, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9184, 15619, 763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9185, 15619, 11554, 11, '');
INSERT INTO 'dancestunesmap' VALUES (9187, 15623, 1942, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9188, 12335, 3477, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9199, 13884, 2468, 10, '');
INSERT INTO 'dancestunesmap' VALUES (213, 796, 1368, 10, 'Tune mentioned in the SDA original, not in Carnforth 3');
INSERT INTO 'dancestunesmap' VALUES (9206, 15687, 10175, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9207, 15688, 13019, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9211, 15692, 13022, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9212, 15694, 2224, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9214, 15696, 8882, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9216, 12390, 8340, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9226, 9292, 12633, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9227, 9292, 11560, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9230, 9295, 12635, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9231, 9295, 12636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2237, 5842, 3166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8802, 14688, 12437, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7516, 11763, 9286, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7503, 11763, 3507, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9138, 14548, 1334, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9244, 15405, 12957, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9247, 8482, 9354, 10, 'According to Third Graded Book.');
INSERT INTO 'dancestunesmap' VALUES (4078, 3431, 1505, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9250, 15713, 7705, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9251, 13435, 10486, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9252, 13434, 10480, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7400, 11483, 9047, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9208, 15689, 13020, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5729, 6709, 41, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9200, 15665, 9846, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9232, 9296, 12637, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9142, 12699, 1013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9215, 14672, 13025, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9238, 15684, 9051, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3226, 1743, 2317, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9210, 15691, 13021, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9205, 5797, 7287, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9121, 10477, 5262, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9172, 8068, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9127, 12036, 12624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9118, 4821, 1254, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9178, 14903, 10148, 20, 'Deviser''s original suggestion');
INSERT INTO 'dancestunesmap' VALUES (4806, 4920, 4338, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9145, 15427, 12927, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9202, 5179, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9240, 7316, 2830, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1161, 4065, 1329, 3, '');
INSERT INTO 'dancestunesmap' VALUES (5141, 5558, 4455, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9173, 14895, 3047, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1283, 4464, 1168, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9174, 14897, 4563, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10245, 18218, 4297, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9039, 15241, 12693, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9160, 15530, 1064, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9149, 15455, 1620, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9110, 2887, 12910, 2, '');
INSERT INTO 'dancestunesmap' VALUES (9166, 15536, 285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9220, 9288, 7596, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9195, 15656, 195, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9241, 15697, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9189, 15638, 12999, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9192, 15653, 6544, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9194, 15654, 13018, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9224, 9291, 7597, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9146, 15444, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9129, 12020, 12625, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9109, 2383, 675, 2, '');
INSERT INTO 'dancestunesmap' VALUES (9111, 4863, 1380, 2, '');
INSERT INTO 'dancestunesmap' VALUES (9028, 15119, 12685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9069, 15310, 12717, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6145, 8573, 6436, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9223, 9290, 12632, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9228, 9294, 7583, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9233, 9297, 7588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9197, 15634, 551, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9155, 14553, 398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9239, 15704, 2366, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9097, 15364, 2048, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9203, 15686, 906, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9234, 10563, 435, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9243, 8526, 19, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9102, 15369, 9256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10230, 18277, 13875, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9161, 15531, 7167, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9169, 15564, 3452, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1656, 5730, 1659, 3, '');
INSERT INTO 'dancestunesmap' VALUES (9170, 15564, 1146, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9116, 6393, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7716, 2317, 2646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3478, 2228, 3545, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9010, 15101, 3358, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9009, 15101, 12667, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9144, 15429, 12926, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9183, 15593, 1225, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9190, 15639, 13000, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9191, 15640, 13001, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9147, 12397, 9101, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9209, 15690, 9322, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9213, 15695, 13023, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9225, 9293, 12634, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8967, 15052, 12553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9181, 14365, 12672, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9143, 15430, 12, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9245, 15411, 1788, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9249, 15406, 3373, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8950, 15035, 12582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9204, 10494, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9221, 9289, 12630, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6619, 6188, 7102, 3, '');
INSERT INTO 'dancestunesmap' VALUES (9157, 8725, 828, 20, 'Original author''s suggestion');
INSERT INTO 'dancestunesmap' VALUES (9150, 2135, 1897, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9042, 7548, 2029, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9041, 7548, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9237, 15460, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4056, 3388, 332, 10, '');
INSERT INTO 'dancestunesmap' VALUES (327, 1192, 751, 2, '');
INSERT INTO 'dancestunesmap' VALUES (9182, 15576, 12991, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9196, 15631, 1408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9038, 14991, 7660, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1591, 5529, 1515, 10, '');
INSERT INTO 'dancestunesmap' VALUES (682, 2493, 585, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9620, 15401, 12953, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9219, 9287, 7595, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9218, 9287, 7594, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9124, 15005, 1293, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9158, 15526, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9154, 15459, 12951, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2071, 7284, 1270, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9117, 4112, 685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9171, 8068, 10164, 10, '');
INSERT INTO 'dancestunesmap' VALUES (489, 1781, 1120, 1, 'AABBAB');
INSERT INTO 'dancestunesmap' VALUES (488, 1781, 606, 3, 'AABAAB');
INSERT INTO 'dancestunesmap' VALUES (9246, 13727, 2427, 10, 'According to Third Graded Book.');
INSERT INTO 'dancestunesmap' VALUES (8246, 13727, 11555, 20, '');
INSERT INTO 'dancestunesmap' VALUES (9255, 8264, 13047, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9260, 15731, 13052, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9261, 15732, 7579, 10, 'Suggested music Auchinellan Jig recorded by Lothian Band on HL10');
INSERT INTO 'dancestunesmap' VALUES (9263, 15734, 1535, 10, 'Sugg recording for Breeze Bay by Gordon Shand');
INSERT INTO 'dancestunesmap' VALUES (9264, 15735, 1895, 10, 'Sugg recording Acklam Reelers by David Cunningham');
INSERT INTO 'dancestunesmap' VALUES (9265, 15736, 955, 10, 'Sugg recording Lads & Lasses by Neil Barron, Vallin 1');
INSERT INTO 'dancestunesmap' VALUES (9268, 15739, 3804, 10, 'Sugg recording Furth o'' Clyde by George Meikle on Birmingham Dia');
INSERT INTO 'dancestunesmap' VALUES (9270, 15741, 10635, 10, 'Sugg recording Lady from the West by Gordon Shand');
INSERT INTO 'dancestunesmap' VALUES (8837, 14740, 12522, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9272, 15742, 2983, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9273, 15743, 9914, 10, 'Sugg recording Dancing Girls by Marian Anderson');
INSERT INTO 'dancestunesmap' VALUES (9274, 15745, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9275, 15746, 3243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9277, 15748, 403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9278, 15749, 1373, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9279, 15750, 1448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9280, 15751, 1857, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9281, 15752, 7457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9282, 15753, 669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9283, 15754, 709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9284, 15755, 2980, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9285, 15756, 1542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9286, 15757, 5933, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9287, 15758, 1581, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9288, 15759, 2830, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9289, 15760, 297, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9290, 15761, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9298, 15770, 8066, 10, 'Sugg: Selection of jigs Tr9 on Scottish Dance Country by B Brown');
INSERT INTO 'dancestunesmap' VALUES (10232, 18278, 6462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9307, 15782, 6525, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9308, 15782, 6526, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9310, 15783, 13053, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9311, 15783, 13054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1006, 3616, 913, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9075, 161, 623, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2040, 7182, 1179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9136, 10048, 973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9345, 15873, 7656, 10, 'Suitable Rec: Special Request 5 Tr11 SPCD005');
INSERT INTO 'dancestunesmap' VALUES (9346, 15874, 9979, 10, 'Suitable Music:  The Hyperactive Reel - RSCDS CD69, Tr11 on CD#2');
INSERT INTO 'dancestunesmap' VALUES (9347, 15875, 6568, 10, 'eg: Celtic Fire in the Music - Bobby Brown BRG024-CD (Tr10 CD#2)');
INSERT INTO 'dancestunesmap' VALUES (9348, 15876, 4208, 10, 'Recording: Memory Lane - TAC005CD Tr1');
INSERT INTO 'dancestunesmap' VALUES (406, 1466, 348, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1871, 6566, 907, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9349, 15877, 336, 10, 'eg: Celtic Fire in the Music - Bobby Brown BRG024-CD  (Tr6 CD#2)');
INSERT INTO 'dancestunesmap' VALUES (9350, 15878, 1145, 10, 'Recording: RSCDS Music for Book30');
INSERT INTO 'dancestunesmap' VALUES (9351, 15879, 2638, 10, 'eg: The Moffat Weavers - Spec. Requests 1  Tr8  SRCD001');
INSERT INTO 'dancestunesmap' VALUES (3143, 1600, 3653, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9312, 15822, 13055, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9313, 15823, 13056, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2017, 7104, 783, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9317, 15827, 13059, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9332, 15839, 13071, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9333, 15840, 13072, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9336, 15845, 13075, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9335, 15844, 13074, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8737, 14542, 12199, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9340, 15870, 10648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9341, 15870, 288, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9342, 15870, 10649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9344, 15872, 8201, 10, 'Suitable Music: Lord McDonald''s Quadrille on SICD02');
INSERT INTO 'dancestunesmap' VALUES (9355, 15893, 2609, 10, 'Suggested Music: Where Friends Meet on CD Magic Medicine by Sand');
INSERT INTO 'dancestunesmap' VALUES (5195, 5667, 4472, 10, 'Reel tune');
INSERT INTO 'dancestunesmap' VALUES (5194, 5667, 4471, 10, 'Strathspey tune');
INSERT INTO 'dancestunesmap' VALUES (9356, 15895, 548, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9357, 15898, 12082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9358, 15899, 401, 10, 'Sugg. music: Rover''s Rant on CD "Haste Ye Back" by M.l Johnstone');
INSERT INTO 'dancestunesmap' VALUES (2701, 702, 3468, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6516, 9231, 1809, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9359, 15900, 13083, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9354, 15892, 115, 10, 'Sugg. music: Bill Hendry''s Reel on Magic Medicine by Sandy Nixon');
INSERT INTO 'dancestunesmap' VALUES (9319, 15828, 8940, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9267, 15738, 9963, 10, 'Sugg recording Return to Broadford Bay by Neil Barron');
INSERT INTO 'dancestunesmap' VALUES (9321, 15830, 13062, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9353, 13450, 10533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9271, 8453, 854, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9315, 15825, 13057, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1368, 4759, 1317, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9339, 15854, 1785, 10, 'or any good jig in 10 bar phrasing');
INSERT INTO 'dancestunesmap' VALUES (9330, 15837, 8941, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6755, 9711, 781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9334, 15843, 13073, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9316, 15826, 13058, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9112, 4873, 4543, 2, '');
INSERT INTO 'dancestunesmap' VALUES (9318, 12279, 13060, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9320, 15829, 13061, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9113, 6995, 963, 2, '');
INSERT INTO 'dancestunesmap' VALUES (16, 73, 1814, 10, '');
INSERT INTO 'dancestunesmap' VALUES (15, 73, 19, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9327, 15835, 13068, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3908, 3080, 3946, 1, '');
INSERT INTO 'dancestunesmap' VALUES (9302, 15774, 1294, 10, 'Sugg: Selection of S''speys Tr5 by B Brown ScottisDanceCountry');
INSERT INTO 'dancestunesmap' VALUES (9292, 12729, 9784, 10, 'Sugg Music: Dancing Bells on Celtic Fire in the Music by B Brown');
INSERT INTO 'dancestunesmap' VALUES (6894, 9998, 8008, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9291, 15764, 3132, 10, 'Sugg Music. Reel Tr9 on All Set by David Cunningham');
INSERT INTO 'dancestunesmap' VALUES (9258, 15730, 13050, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9276, 15747, 2264, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9242, 14567, 13044, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8970, 14352, 12584, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9061, 15285, 9552, 10, 'Erroneously attributed to Muriel Johnstone.');
INSERT INTO 'dancestunesmap' VALUES (10231, 17998, 13652, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9256, 15728, 13048, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9266, 15737, 858, 10, 'Sugg recording Tullyvolan recorded by George Meikle on HL10');
INSERT INTO 'dancestunesmap' VALUES (9305, 15781, 1995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9259, 14680, 13051, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9326, 8520, 13067, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9294, 15766, 10603, 10, 'Sugg: Crieff Hydro on Reels and Wheels by Gordon Shand');
INSERT INTO 'dancestunesmap' VALUES (6238, 8338, 3760, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9299, 15771, 1089, 10, 'Sugg Music: Brigs of Ayr Tr2 on Bath SD by Craigellachie');
INSERT INTO 'dancestunesmap' VALUES (9304, 15776, 4550, 10, 'Sugg Music: Snibbet Biblio Tr8 on Platinum by David Cunningham');
INSERT INTO 'dancestunesmap' VALUES (9293, 15765, 8078, 10, 'Sugg:Selection of Reels on Scottish Dance Country by Bobby Brown');
INSERT INTO 'dancestunesmap' VALUES (9297, 15769, 1013, 10, 'Sugg: Lord McLay''s Reel Tr11 on All Set by David Cunningham');
INSERT INTO 'dancestunesmap' VALUES (9301, 15773, 4372, 10, 'Sugg Music: Jigs Tr7 on G''father Mountain Gala by Bobby Brown');
INSERT INTO 'dancestunesmap' VALUES (5830, 6931, 1319, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9236, 15460, 3749, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9306, 15781, 4750, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9322, 15831, 13063, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9325, 15834, 13066, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9337, 15846, 13076, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9257, 15729, 13049, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9254, 15727, 13046, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9331, 15838, 3678, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9363, 15924, 13084, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9364, 15928, 514, 10, 'Sugg Music: Father Connelly''s Jig by Marian Anderson (HRMCD512)');
INSERT INTO 'dancestunesmap' VALUES (9365, 15931, 610, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9435, 16110, 920, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9436, 16110, 445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9366, 15954, 13085, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8527, 14244, 9510, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9367, 15959, 12084, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1050, 3735, 338, 11, '');
INSERT INTO 'dancestunesmap' VALUES (9372, 15962, 13090, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9376, 15966, 13093, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9379, 15969, 3910, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9381, 15973, 13095, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9382, 15974, 13097, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9437, 16110, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9438, 15270, 13109, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9439, 15267, 4825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9440, 15269, 13110, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9248, 15177, 2433, 10, 'According to Third Graded Book.');
INSERT INTO 'dancestunesmap' VALUES (9388, 15983, 2063, 10, 'Sugg music: Streets of Milan by Luke Brady''s SDB');
INSERT INTO 'dancestunesmap' VALUES (9394, 15989, 9944, 10, 'Sugg music: South Street Harbourne by George Meikle&The Lothians');
INSERT INTO 'dancestunesmap' VALUES (9403, 15998, 5290, 10, 'Sugg music: Cool as a Cucumber on Tartan Capers by White Cockade');
INSERT INTO 'dancestunesmap' VALUES (9408, 16004, 13099, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9409, 16005, 13100, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9378, 15967, 13088, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9414, 16016, 2487, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9415, 16024, 4408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9417, 14962, 7963, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9418, 14962, 12770, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9419, 13756, 2316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10234, 16794, 3507, 10, 'Deviser''s suitable substitute');
INSERT INTO 'dancestunesmap' VALUES (9450, 16128, 9912, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9442, 16125, 3517, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1217, 4256, 1516, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9422, 16059, 1903, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9423, 16063, 1533, 10, 'Music: West''s Hornpipe played by Don Bartlett on TAC002CD');
INSERT INTO 'dancestunesmap' VALUES (9424, 16064, 3741, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9425, 16064, 5004, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9426, 16064, 13103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9427, 16064, 5406, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9428, 16065, 13104, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6280, 8334, 2076, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9429, 16023, 5238, 10, 'It is one of the tunes on a Gay Gordon track on a Jim McLeod LP');
INSERT INTO 'dancestunesmap' VALUES (7200, 10920, 7575, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9430, 16078, 13105, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9447, 10298, 4690, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9433, 16090, 13107, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9434, 16108, 13108, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8040, 10298, 6970, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9448, 6073, 13112, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9449, 16127, 13113, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9468, 16178, 5584, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9452, 16129, 13115, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9453, 16130, 13116, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9454, 16131, 2675, 10, 'Mrs Eileen Cowan');
INSERT INTO 'dancestunesmap' VALUES (9455, 16132, 13117, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9457, 16134, 13119, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9458, 16135, 13120, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9459, 4943, 13121, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9460, 9931, 13122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9462, 16152, 11973, 10, 'played by Jimmy Shand on SP MEO 10090');
INSERT INTO 'dancestunesmap' VALUES (9463, 12740, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6782, 9731, 673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8539, 14278, 11731, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9467, 14528, 1059, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7801, 12538, 9643, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9466, 16156, 422, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9464, 11500, 8840, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2785, 880, 6945, 10, 'As “The Burnt Potato”');
INSERT INTO 'dancestunesmap' VALUES (4075, 3427, 6945, 10, 'As “The Burnt Potato”');
INSERT INTO 'dancestunesmap' VALUES (4847, 7874, 41, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9461, 16143, 40, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9443, 16126, 1164, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9397, 15992, 124, 10, 'Sugg music: Reels(Simple) 3x32 6xthrough the Danceby M.Johnstone');
INSERT INTO 'dancestunesmap' VALUES (9431, 5696, 267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9444, 13270, 11260, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9421, 16055, 11554, 10, 'Four very different tunes');
INSERT INTO 'dancestunesmap' VALUES (5696, 6644, 3382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9361, 15915, 1727, 10, 'Music: Todlen Hame 6x32J track # 1 with M Johnstone and K Smith');
INSERT INTO 'dancestunesmap' VALUES (9416, 16044, 318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9400, 15995, 157, 10, 'Sugg music: Hope Little''s S''spey by Muriel Johnstone SDB');
INSERT INTO 'dancestunesmap' VALUES (9401, 15996, 2212, 10, 'Sugg music: Annam Reel on We Twa by Kenny Thomson&WardlawSDB');
INSERT INTO 'dancestunesmap' VALUES (9399, 15994, 4632, 10, 'Sugg music: Tom''s Friends by Muriel Johnstone');
INSERT INTO 'dancestunesmap' VALUES (9398, 15993, 7283, 10, 'Sugg music: Elisabeth Hunter S''spey by M. Johnstone SDB');
INSERT INTO 'dancestunesmap' VALUES (9405, 16000, 106, 10, 'Sugg music: Vintage ''62 on Vintage Goldring by M Johnstone,Keith');
INSERT INTO 'dancestunesmap' VALUES (9406, 16001, 7423, 10, 'Sugg music: Misses Cramb of Linlithgow by Craigowl SDB');
INSERT INTO 'dancestunesmap' VALUES (9404, 15999, 5080, 10, 'Sugg music: 8x32 Reels on First Stop by Waverly Station');
INSERT INTO 'dancestunesmap' VALUES (9402, 15997, 1203, 10, 'Sugg music: Set of S''speys 4x32 by Terpsichore on CaledonianMuse');
INSERT INTO 'dancestunesmap' VALUES (9392, 15987, 2830, 10, 'Sugg music: Broadford Bay by M. Johnstone SDB or Colin Dewar SDB');
INSERT INTO 'dancestunesmap' VALUES (9393, 15988, 2151, 10, 'Sugg music: Sel. of S''speys (3x32) on Celtic Fire by Bobby Brown');
INSERT INTO 'dancestunesmap' VALUES (9396, 15991, 700, 10, 'Sugg music: Hogmanay Jig by Marian Anderson SDB');
INSERT INTO 'dancestunesmap' VALUES (9384, 15980, 9454, 10, 'Sugg. music: Robbie over the Waves by Colin Dewar');
INSERT INTO 'dancestunesmap' VALUES (9374, 15964, 162, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9389, 15984, 1137, 10, 'Sugg music: In Campbell Country by Muriel Johnstone, Keith Smith');
INSERT INTO 'dancestunesmap' VALUES (9391, 15986, 6406, 10, 'Sugg music: Spirit of the Dance by Muriel Johnstone, Keith Smith');
INSERT INTO 'dancestunesmap' VALUES (9390, 15985, 1264, 10, 'Sugg music: Moving Cloud by Alan Gardiner SDB');
INSERT INTO 'dancestunesmap' VALUES (9395, 15990, 9316, 10, 'Sugg music: "Figure It Out" by Jim Lindsay & M. Johnstone');
INSERT INTO 'dancestunesmap' VALUES (9385, 15981, 1018, 10, 'Sugg. music: Glittering Calves by Roy Hendrie SDB');
INSERT INTO 'dancestunesmap' VALUES (7772, 6552, 4602, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3630, 2531, 3838, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9380, 15972, 13094, 10, 'or any good jig');
INSERT INTO 'dancestunesmap' VALUES (9386, 14738, 13098, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9377, 15967, 13087, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9412, 16014, 2877, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9411, 16014, 4843, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9413, 16015, 13102, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9375, 15965, 13092, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9373, 15963, 13091, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4322, 3989, 4086, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9371, 10352, 13089, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9410, 16006, 13101, 10, '');
INSERT INTO 'dancestunesmap' VALUES (518, 1864, 470, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3273, 1838, 1462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9383, 3066, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9432, 14393, 12073, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9446, 15023, 12647, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8643, 12071, 750, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9465, 13614, 11355, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9368, 15960, 13086, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9360, 15914, 10227, 10, 'Sugg music: That Pinewoods Sound, Tr#5 by Susie Petrov & Ensembl');
INSERT INTO 'dancestunesmap' VALUES (5404, 6104, 2834, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9338, 15847, 13077, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9329, 15836, 13070, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9323, 15832, 13064, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9324, 15833, 13065, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9253, 15726, 13045, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9445, 6689, 13111, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7037, 10306, 8244, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6617, 8741, 1665, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9300, 15772, 1029, 10, 'Sugg Music: Lady Mary Cochrane''s Rell on Book26 by Alan Gardiner');
INSERT INTO 'dancestunesmap' VALUES (4382, 4965, 4148, 10, '');
INSERT INTO 'dancestunesmap' VALUES (345, 1280, 473, 11, '');
INSERT INTO 'dancestunesmap' VALUES (9362, 15923, 10143, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9456, 16133, 13118, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9546, 16440, 11555, 10, 'Any 5 x 48 Strathspey selection');
INSERT INTO 'dancestunesmap' VALUES (9470, 16187, 13125, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9475, 9224, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9477, 16213, 13130, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9478, 16213, 13131, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9480, 16245, 5702, 10, 'Suitable music: Miss McLean of Inverness by Kafoozalum');
INSERT INTO 'dancestunesmap' VALUES (9482, 16247, 1090, 10, 'Suitable music: Maskelia by Bobby Brown on From Scotia''s Shores');
INSERT INTO 'dancestunesmap' VALUES (9483, 16248, 2122, 10, 'Suitable music: And Happy Meet Again on Diam Jubilee Dance Book');
INSERT INTO 'dancestunesmap' VALUES (9484, 16249, 10058, 10, 'The St Andrews Platinum Reel played by D. Cunningham');
INSERT INTO 'dancestunesmap' VALUES (9485, 16250, 2832, 10, 'Suit music:Georgie''s Jig on Platinum by D Cunningham');
INSERT INTO 'dancestunesmap' VALUES (9486, 16251, 9753, 10, 'Suit music: Barton Barbecue on We Twa by Kenny Thomson');
INSERT INTO 'dancestunesmap' VALUES (9487, 16252, 4737, 10, 'Suit music: Follow the Fiddler played by Callum Wilson');
INSERT INTO 'dancestunesmap' VALUES (9488, 16253, 1636, 10, 'Suit music: Golden Ring played by Bobby Brown');
INSERT INTO 'dancestunesmap' VALUES (8721, 9911, 1705, 3, '');
INSERT INTO 'dancestunesmap' VALUES (9494, 16260, 13132, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9495, 16261, 5416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9496, 16263, 2730, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9497, 16264, 148, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9498, 16265, 3215, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9499, 16266, 517, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9500, 16267, 5273, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9501, 16268, 713, 10, 'rec music: Hot Toddy by Lothian Band');
INSERT INTO 'dancestunesmap' VALUES (9502, 16269, 3361, 10, 'rec music "The Armstrong Rant" on H.I.S.C.D. by Bobby Brown');
INSERT INTO 'dancestunesmap' VALUES (9503, 16270, 797, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9504, 16271, 2797, 10, 'Rec music: Rannoch Moor on Jim Lindsay&Muriel Johnstone,Reel On');
INSERT INTO 'dancestunesmap' VALUES (9505, 16273, 3068, 10, 'Fair Jenny''s Jig on Golden Gate by Fiddlesticks');
INSERT INTO 'dancestunesmap' VALUES (9506, 15618, 8343, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9507, 16276, 4173, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9508, 16276, 7673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9509, 16276, 6757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9514, 16278, 2083, 10, 'rec music: Best Set in the Hall by Catherine Fraser&Duncan Smith');
INSERT INTO 'dancestunesmap' VALUES (9516, 16280, 2279, 10, 'Rec music: The Clansman played by Green Ginger');
INSERT INTO 'dancestunesmap' VALUES (9518, 16284, 1284, 10, 'Played by Scottish Weekend Ensemble');
INSERT INTO 'dancestunesmap' VALUES (9515, 16279, 2631, 10, 'rec music: Many Happy Returns by Hanneke Cassel & Dave Wiesler');
INSERT INTO 'dancestunesmap' VALUES (9521, 16334, 3381, 10, 'rec music: Honeymoon played by David Cunningham and his SDB');
INSERT INTO 'dancestunesmap' VALUES (9522, 16335, 1839, 10, 'rec music:Woo''d and Mairried and A'' played by Bobby Crowe SDB');
INSERT INTO 'dancestunesmap' VALUES (9523, 16336, 5634, 10, 'Royal Wedding played by Ron Gonnella Quartet');
INSERT INTO 'dancestunesmap' VALUES (9524, 16417, 7520, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9525, 11989, 13137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9528, 16419, 5126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9529, 16419, 2706, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9530, 16420, 1598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9531, 16421, 13139, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9532, 16422, 13140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9535, 16424, 13142, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9536, 16425, 5643, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9539, 16427, 13143, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9526, 16418, 13138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9527, 11679, 9830, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9540, 16428, 11554, 10, 'with a moderate beat or Alistair Hunter''s Reel of the Gordon HLs');
INSERT INTO 'dancestunesmap' VALUES (9541, 16431, 11555, 10, 'Any 4x32 Strathspey selection with a pastoral feel to it.');
INSERT INTO 'dancestunesmap' VALUES (670, 2445, 1694, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9543, 16435, 11554, 10, '128 or 4x32 bars reel with a moderate beat and pace');
INSERT INTO 'dancestunesmap' VALUES (9544, 16438, 11554, 10, '3x32 or 6x32 reel selection with a moderate pace and beat');
INSERT INTO 'dancestunesmap' VALUES (9547, 16444, 11553, 10, 'Any 4 x 32 jig with a good beat.');
INSERT INTO 'dancestunesmap' VALUES (9548, 16447, 11555, 10, 'Any 4 x 32 Strathspey selection with a pastoral air.');
INSERT INTO 'dancestunesmap' VALUES (9549, 16451, 11555, 10, 'Any 4 x 32 strathspey selection with a medium beat.');
INSERT INTO 'dancestunesmap' VALUES (9550, 16452, 1544, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9552, 16453, 11555, 10, 'Any 5 x 40 bar strathspey selecton with a moderate beat.');
INSERT INTO 'dancestunesmap' VALUES (9553, 16455, 11554, 10, 'Any 5 x 32 reel selection with a good beat.');
INSERT INTO 'dancestunesmap' VALUES (1201, 4179, 801, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9551, 1430, 2815, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9554, 16458, 13144, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9559, 16472, 13162, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9555, 16459, 13151, 10, '');
INSERT INTO 'dancestunesmap' VALUES (403, 1453, 103, 10, '');
INSERT INTO 'dancestunesmap' VALUES (242, 902, 1995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9558, 16471, 13161, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6185, 7561, 1953, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8716, 14525, 12196, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8849, 14793, 12527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9564, 13113, 13166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9565, 13113, 1876, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9566, 13113, 967, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9567, 13113, 10753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9568, 13113, 333, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9570, 16480, 13167, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9569, 11716, 9246, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9573, 3432, 1147, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9574, 16483, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9575, 16484, 13170, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9576, 16485, 13171, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9577, 16486, 4093, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9578, 16486, 13172, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8427, 13869, 11592, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9537, 11988, 730, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9481, 16246, 9940, 10, 'Suitable music: New Dixon Quadrille played by Georg&Lothian Band');
INSERT INTO 'dancestunesmap' VALUES (1426, 4933, 1767, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8428, 13869, 11593, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9561, 16474, 13164, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9571, 16481, 13168, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9476, 16212, 13129, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9572, 16482, 13169, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9560, 16473, 13163, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9556, 16466, 13159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1588, 5522, 945, 11, '');
INSERT INTO 'dancestunesmap' VALUES (9562, 16475, 13165, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1425, 4933, 1653, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8457, 13908, 11622, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9490, 5440, 4320, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9472, 14719, 13126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9579, 16487, 13173, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9603, 16515, 12815, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9675, 7436, 1748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9001, 3065, 1600, 10, 'Suggested on Strathspey 2009-04-16');
INSERT INTO 'dancestunesmap' VALUES (1864, 6532, 1659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1863, 6532, 1629, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9032, 15123, 12689, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9469, 9648, 5186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9493, 16258, 8840, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9474, 16200, 13128, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9607, 13648, 4327, 11, 'From the RSCDS publication');
INSERT INTO 'dancestunesmap' VALUES (9711, 12074, 13265, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1930, 6792, 730, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1931, 6792, 750, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9520, 16287, 1283, 10, 'Strathglass House as recorded on Delaware Valley');
INSERT INTO 'dancestunesmap' VALUES (9545, 16439, 11555, 10, 'Strathspey selection with a moderately strong beat');
INSERT INTO 'dancestunesmap' VALUES (9510, 16277, 13133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9511, 16277, 5958, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9517, 16283, 7620, 10, 'Recorded by Green Ginger');
INSERT INTO 'dancestunesmap' VALUES (6335, 7524, 5288, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9473, 16197, 13127, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9491, 7469, 655, 10, 'rec music: Lantern of the North on L H C by Antrew Rankine');
INSERT INTO 'dancestunesmap' VALUES (9479, 16227, 1426, 10, '(recording of Bauldy Bain''s Fiddle by Bobby Brown on Ready..And!');
INSERT INTO 'dancestunesmap' VALUES (9542, 1087, 3545, 10, 'As “Flirtation Hornpipe”, original author''s tune (popular in NZ)');
INSERT INTO 'dancestunesmap' VALUES (9519, 16286, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9538, 16426, 206, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2883, 1084, 1613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9619, 16537, 13196, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9623, 14712, 7904, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9627, 12124, 2812, 10, 'Tune published with the dance in RSCDS Book 48');
INSERT INTO 'dancestunesmap' VALUES (9596, 16502, 13181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9653, 16690, 13221, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9631, 16618, 5535, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9709, 16183, 13263, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9634, 16621, 10025, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9635, 16622, 247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9637, 16673, 1137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9638, 16674, 8316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9639, 16675, 7587, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9641, 16677, 8386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9689, 14982, 13244, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9633, 16620, 1515, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9646, 16683, 13214, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9651, 16688, 13219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9654, 16691, 13222, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9656, 16693, 13223, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9658, 16695, 13225, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9655, 16692, 13222, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9636, 16623, 8840, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9608, 16522, 13189, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9661, 8079, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9692, 16568, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9714, 8371, 1628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9616, 16535, 13194, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9622, 13163, 1413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9612, 16526, 13192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9630, 16617, 2636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9615, 16534, 13193, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9613, 16527, 7612, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9594, 16498, 365, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9673, 14405, 13160, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9680, 16736, 1648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9685, 16785, 13241, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9674, 16731, 3003, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3453, 2182, 3335, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9597, 16507, 11445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9697, 16709, 13246, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9696, 10950, 415, 10, 'or any tune in 9/8 time');
INSERT INTO 'dancestunesmap' VALUES (9611, 16525, 13191, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9699, 14025, 11667, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9621, 15402, 4871, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9700, 16733, 9223, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9683, 16772, 1038, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9687, 16735, 2798, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6547, 9382, 7660, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9640, 16676, 9322, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9604, 16516, 13184, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9676, 13276, 773, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9657, 16694, 13224, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9690, 8064, 12082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9598, 16508, 9167, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9713, 16840, 13268, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7571, 11919, 9454, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9650, 16687, 13218, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9614, 16533, 2416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9582, 16490, 13175, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9584, 16492, 13176, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9593, 16497, 4849, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9585, 16493, 13177, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9586, 16493, 2729, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9589, 16494, 9757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9592, 16496, 13180, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9652, 16689, 13220, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9599, 16509, 10191, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9580, 16488, 9779, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9595, 16499, 5560, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9668, 16728, 13236, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9648, 16685, 13216, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9625, 15403, 12954, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9642, 16679, 13210, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9643, 16681, 13212, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9645, 16682, 13213, 10, '');
INSERT INTO 'dancestunesmap' VALUES (495, 1792, 289, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9644, 16680, 13211, 10, '');
INSERT INTO 'dancestunesmap' VALUES (496, 1792, 448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9701, 16838, 4323, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9583, 16491, 1219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9712, 16706, 13266, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9581, 16489, 8811, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9702, 16838, 13932, 11, 'From the RSCDS publication');
INSERT INTO 'dancestunesmap' VALUES (9667, 16727, 13235, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9649, 16686, 13217, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9691, 15326, 8895, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9686, 16678, 13242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9647, 16684, 13215, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9671, 16730, 13239, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9672, 16725, 13240, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9602, 16514, 10858, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9703, 16839, 13257, 10, '');
INSERT INTO 'dancestunesmap' VALUES (123, 462, 156, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9788, 17010, 3076, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9789, 17011, 2176, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9814, 13623, 6290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9775, 16965, 4880, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9730, 10610, 652, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9731, 10596, 90, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9732, 10609, 2880, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9733, 10608, 1648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9734, 14643, 5038, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9729, 16872, 768, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3781, 2833, 2483, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6691, 9632, 2057, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9609, 16523, 7472, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9664, 16729, 13232, 10, '');
INSERT INTO 'dancestunesmap' VALUES (966, 3524, 1101, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6287, 3980, 6945, 10, 'As “The Burnt Potato”');
INSERT INTO 'dancestunesmap' VALUES (9628, 14138, 12955, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9739, 15607, 2948, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9705, 16700, 13259, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8770, 14598, 12230, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9725, 16854, 365, 10, 'Recording: Uncle Bill''s Jig on Reel On by Jim Lindsay & M. Johns');
INSERT INTO 'dancestunesmap' VALUES (9724, 16853, 12732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9723, 16852, 3323, 10, 'Recording: Cardross House on Moments in Time by M. Johnstone');
INSERT INTO 'dancestunesmap' VALUES (9721, 16850, 9903, 10, 'Recording:"The Open Road" on Kangaroo Paw by Marian Anderson');
INSERT INTO 'dancestunesmap' VALUES (9719, 16848, 2325, 10, 'Burns Hornpipe on Delaware Valley');
INSERT INTO 'dancestunesmap' VALUES (9717, 16846, 12044, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9716, 16845, 12705, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9715, 16844, 8840, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10235, 13679, 12664, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9591, 16495, 13179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9590, 16495, 2115, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9670, 12907, 13238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9629, 15404, 12956, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9698, 16822, 1619, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9601, 16513, 13183, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9606, 16518, 13186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9600, 16512, 13182, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9660, 16697, 13218, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4019, 3336, 2466, 10, '');
INSERT INTO 'dancestunesmap' VALUES (758, 2777, 626, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9710, 12074, 13264, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9706, 14387, 13260, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9677, 13705, 11549, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9678, 13705, 11550, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9815, 17133, 13290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9669, 15341, 13237, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9605, 16517, 13185, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9704, 16734, 13258, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9790, 1883, 4726, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9665, 16724, 13233, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9618, 16536, 2872, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9624, 13766, 143, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9682, 15710, 5590, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9659, 16696, 13226, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9610, 16524, 13190, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9681, 16737, 77, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1618, 5637, 1053, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9662, 16222, 13231, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9666, 16726, 13234, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9684, 16774, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8796, 14681, 12429, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9728, 10879, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4159, 3649, 4024, 10, '');
INSERT INTO 'dancestunesmap' VALUES (727, 2673, 1654, 10, '');
INSERT INTO 'dancestunesmap' VALUES (728, 2673, 1699, 11, '');
INSERT INTO 'dancestunesmap' VALUES (9626, 14649, 5018, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9679, 13705, 11551, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10306, 14398, 13945, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9632, 16619, 8248, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9663, 16699, 332, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9740, 13117, 13273, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9748, 16930, 2975, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9796, 17056, 730, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9797, 17057, 1181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9798, 13371, 10296, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9726, 16478, 13269, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9800, 17070, 106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9755, 2355, 141, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9756, 2355, 4943, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9757, 2355, 68, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9758, 2355, 4942, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5279, 5856, 1729, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4180, 3693, 4035, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4181, 3693, 4036, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9760, 8210, 794, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9761, 8208, 212, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9762, 8205, 874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7013, 10496, 8237, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9763, 16944, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9764, 16945, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9765, 16946, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9801, 17071, 408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9766, 16948, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9767, 16950, 4324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4830, 4987, 915, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9738, 16904, 4897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6849, 9934, 6215, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9770, 5536, 160, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9771, 5536, 1364, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9772, 6715, 3074, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9773, 6717, 6025, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9774, 6717, 11848, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6614, 9504, 7716, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9745, 16773, 13274, 10, 'Tentative; to be confirmed.');
INSERT INTO 'dancestunesmap' VALUES (9736, 16896, 9167, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9799, 17067, 283, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9777, 16971, 876, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9778, 16991, 6101, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9779, 16999, 492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9782, 17009, 13278, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9783, 17012, 5871, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9784, 17013, 2136, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9786, 17015, 5870, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9787, 17016, 5901, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4648, 4614, 186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5470, 6223, 1290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8245, 13726, 1005, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9808, 17135, 3956, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3388, 2056, 2369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5750, 6741, 624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1329, 4644, 270, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9813, 17194, 13289, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9759, 523, 215, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9781, 17008, 13277, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9824, 16054, 13292, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9120, 4821, 1407, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9827, 2913, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9828, 5929, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9387, 15982, 9989, 10, 'Sugg music: Catch the Wind by The Music Makars');
INSERT INTO 'dancestunesmap' VALUES (7608, 3945, 1386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9780, 17007, 13276, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8424, 13873, 11589, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9751, 15480, 13275, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9747, 14239, 3896, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9742, 16018, 13208, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9812, 17186, 13288, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9829, 17031, 13294, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9830, 17263, 13295, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8048, 13316, 10053, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9588, 16493, 1989, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10236, 15622, 13662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9741, 16907, 12728, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9842, 17314, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9832, 17304, 13296, 30, '');
INSERT INTO 'dancestunesmap' VALUES (10237, 16776, 13664, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9806, 17132, 5403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9807, 17123, 13279, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9804, 17130, 2931, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9727, 16478, 13270, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9825, 17249, 3342, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9820, 17233, 815, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9802, 17113, 1629, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7125, 10798, 8454, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1991, 7017, 618, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1992, 7017, 819, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7607, 3945, 2016, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7606, 3945, 5986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9737, 16901, 8475, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9931, 17469, 13415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9940, 17404, 12096, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9851, 17333, 49, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9850, 17333, 2017, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9853, 17353, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9856, 17373, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9857, 17374, 13325, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9859, 17379, 13324, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9858, 17379, 13323, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8419, 13870, 11584, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9941, 12457, 12639, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9925, 17458, 13413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9935, 17473, 2101, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9862, 16614, 867, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3931, 3043, 3519, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9864, 16570, 7557, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9942, 17481, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9865, 17394, 13350, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9866, 17395, 13328, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10249, 18340, 8396, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9872, 318, 13353, 11, '');
INSERT INTO 'dancestunesmap' VALUES (9869, 2683, 6646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9793, 17050, 2922, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3201, 1695, 376, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9868, 17397, 13333, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9826, 5272, 13293, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4986, 5272, 2906, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9834, 17307, 10674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2125, 6585, 1352, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9776, 16952, 2631, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9838, 17310, 13302, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3646, 2557, 2646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9818, 17230, 4109, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9753, 3812, 156, 10, 'played AABC');
INSERT INTO 'dancestunesmap' VALUES (9754, 3812, 1086, 10, 'played ABAB');
INSERT INTO 'dancestunesmap' VALUES (2828, 976, 3519, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9768, 16784, 1506, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9988, 17027, 1897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9791, 17048, 51, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9792, 17049, 196, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9794, 17052, 857, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9795, 17054, 106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9805, 17131, 4323, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9811, 17175, 13287, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9816, 17228, 9898, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9817, 17229, 514, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9821, 17234, 10678, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9835, 17306, 13298, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9833, 17305, 13297, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9836, 17308, 13300, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9840, 17312, 13304, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9843, 17315, 13305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9841, 17313, 12053, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9855, 17372, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9873, 6186, 13354, 11, '');
INSERT INTO 'dancestunesmap' VALUES (2953, 1190, 586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9852, 10398, 3433, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1220, 4282, 104, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9871, 162, 13352, 11, '');
INSERT INTO 'dancestunesmap' VALUES (9860, 17386, 4907, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9752, 14601, 1707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6130, 8747, 2054, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9809, 17149, 2252, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4823, 7547, 2588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2274, 3180, 566, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9810, 17150, 13280, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9746, 4366, 4242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (130, 497, 891, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7761, 4270, 4100, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9750, 16939, 929, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9749, 16939, 10683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9744, 14453, 12143, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9743, 14453, 12144, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9803, 17121, 3001, 20, 'Deviser''s original suggestion');
INSERT INTO 'dancestunesmap' VALUES (9785, 17014, 2657, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9823, 17244, 13291, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9718, 16847, 10670, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9819, 17232, 8399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2298, 454, 332, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2578, 454, 3402, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9849, 8714, 239, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9848, 8714, 3576, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9831, 17267, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9769, 9210, 892, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7718, 2317, 1939, 10, '');
INSERT INTO 'dancestunesmap' VALUES (538, 1927, 893, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9844, 17316, 13306, 10, '');
INSERT INTO 'dancestunesmap' VALUES (57, 222, 56, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9947, 15605, 13455, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9946, 15605, 1024, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9960, 17496, 5946, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9863, 16613, 1687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9889, 16855, 10577, 10, 'Recording: Time to Meet on Reel on by Jim Lindsay & M. Johnstone');
INSERT INTO 'dancestunesmap' VALUES (9961, 17497, 90, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9891, 17417, 4407, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9901, 17432, 13380, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9943, 17485, 13454, 10, 'Official tune');
INSERT INTO 'dancestunesmap' VALUES (9944, 17485, 9026, 20, 'Deviser''s original suggestion');
INSERT INTO 'dancestunesmap' VALUES (9899, 17429, 13378, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9894, 2048, 551, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9895, 2048, 2680, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9902, 17433, 13381, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9896, 17440, 78, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9929, 17467, 2792, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1339, 4662, 431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4384, 8125, 4151, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9982, 17615, 6443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9981, 8125, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9951, 17489, 807, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9953, 17490, 7315, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9918, 7503, 13391, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9955, 17492, 2221, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9956, 17493, 9170, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9957, 17494, 8885, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9976, 17541, 396, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9966, 17503, 93, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9967, 17504, 2903, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9969, 15399, 4522, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9971, 17507, 9018, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7159, 10856, 2379, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9979, 17575, 2048, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9959, 17495, 1733, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9945, 17459, 12662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9949, 17488, 6818, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10248, 18339, 1181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3544, 7401, 6312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7413, 11558, 8960, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9986, 11601, 13517, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9990, 17028, 13520, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9991, 17029, 13521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9993, 11906, 13523, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9994, 11906, 3960, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9995, 11906, 5311, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9996, 11906, 1586, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9997, 11906, 9538, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9998, 17032, 13524, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9999, 17033, 13525, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10000, 17034, 13526, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10001, 17038, 13527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9907, 17438, 51, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9892, 8676, 3884, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9906, 17437, 333, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9916, 17448, 13390, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9905, 17436, 13384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9870, 1902, 13351, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6588, 9444, 683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9924, 17457, 13184, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9927, 17465, 8786, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9972, 17508, 13457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6488, 9137, 7574, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9923, 17456, 13392, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9921, 17454, 4412, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9922, 17455, 3195, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9909, 17441, 13385, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9919, 17452, 6138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9897, 17450, 945, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9917, 17449, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9954, 17491, 3470, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9915, 17447, 13389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9914, 17446, 1166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9962, 17498, 939, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9926, 17464, 5130, 10, '');
INSERT INTO 'dancestunesmap' VALUES (247, 909, 223, 11, 'Original tune as published');
INSERT INTO 'dancestunesmap' VALUES (10006, 16255, 12733, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10002, 17195, 13528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10007, 17626, 5535, 10, '');
INSERT INTO 'dancestunesmap' VALUES (497, 1792, 1503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2948, 1202, 3562, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10251, 18340, 9141, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10250, 18340, 9140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10010, 17637, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10096, 17897, 13621, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10019, 17667, 1027, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10029, 17671, 13559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10030, 17671, 685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10031, 17671, 3156, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10032, 17672, 13560, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10033, 17672, 347, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10036, 17674, 13563, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10114, 17988, 13637, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9881, 17401, 13340, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9884, 17402, 13336, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9875, 17398, 13330, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9933, 17471, 2641, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9874, 17398, 13331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9867, 17396, 13343, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10024, 12247, 13554, 10, 'used in The Emigrant Scot');
INSERT INTO 'dancestunesmap' VALUES (10013, 7572, 13544, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10023, 17670, 13553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9879, 17399, 13339, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10014, 7572, 13545, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10015, 7935, 13546, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10021, 17669, 13551, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10022, 11724, 13552, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7313, 2357, 9714, 10, 'As “The Countess of Dalkeith''s Strathspey”');
INSERT INTO 'dancestunesmap' VALUES (9877, 8992, 13349, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9876, 8992, 13347, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10016, 17664, 13547, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10017, 17665, 13548, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9964, 17501, 7189, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10039, 17681, 13566, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10074, 17792, 12662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3886, 3057, 2973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6181, 8816, 1373, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9880, 17400, 13326, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10051, 17718, 13572, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9989, 15612, 13519, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9978, 15641, 5855, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9985, 17026, 13516, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1103, 3866, 819, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9904, 17435, 13383, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9910, 17442, 4830, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9911, 17443, 13386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9913, 17445, 13388, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9920, 17453, 3315, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9928, 17466, 10514, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9937, 17475, 2219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9938, 17476, 13310, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9948, 17487, 13455, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9963, 17499, 2905, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9965, 17502, 3470, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9968, 17505, 491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9970, 17506, 9272, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10003, 17620, 13529, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9980, 17580, 11375, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10011, 17656, 13543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1276, 4447, 1157, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2083, 5200, 398, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10020, 17668, 13550, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10018, 17666, 13549, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9952, 16337, 9165, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9934, 17472, 13416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9908, 17439, 861, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9992, 17030, 13522, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10026, 2413, 13556, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5136, 5547, 881, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10034, 17673, 13561, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10035, 17673, 13562, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10027, 2413, 13557, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10028, 2413, 13558, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5514, 6299, 4323, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9235, 15460, 1967, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9885, 5897, 13356, 10, '');
INSERT INTO 'dancestunesmap' VALUES (366, 1366, 898, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9898, 17428, 13377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9958, 17265, 13456, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10110, 17948, 12, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10106, 17922, 13625, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10043, 8047, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10086, 17885, 4760, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10045, 16456, 13570, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10041, 17688, 13568, 10, '');
INSERT INTO 'dancestunesmap' VALUES (386, 1415, 341, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10049, 17704, 13569, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10075, 16292, 2043, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9878, 14901, 13355, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9890, 17349, 13376, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9900, 17430, 13379, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9932, 17470, 1322, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9975, 17539, 13458, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9984, 15599, 13514, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9977, 10370, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9983, 17619, 12950, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10065, 17745, 421, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10052, 17719, 13573, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10054, 17721, 13574, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10055, 17725, 1557, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8810, 13590, 1565, 20, 'Original publication (Exeter 40)');
INSERT INTO 'dancestunesmap' VALUES (10056, 17727, 11966, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9587, 16493, 13178, 10, '');
INSERT INTO 'dancestunesmap' VALUES (173, 682, 177, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10085, 17886, 5620, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10070, 17764, 443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10069, 17764, 3243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1417, 4925, 900, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10072, 17786, 13600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3457, 1744, 3770, 10, '');
INSERT INTO 'dancestunesmap' VALUES (93, 373, 21, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10073, 17787, 13601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10089, 17890, 1683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10091, 17892, 13618, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10094, 17895, 9411, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10098, 17899, 7716, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10064, 17744, 51, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10101, 17901, 7028, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10102, 17902, 12700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (433, 1551, 364, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10076, 17879, 9804, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10090, 17891, 13617, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10008, 16608, 10205, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10092, 17893, 13619, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10109, 17927, 103, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10108, 17927, 2939, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10046, 15702, 2107, 1, '');
INSERT INTO 'dancestunesmap' VALUES (10113, 17987, 13636, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10115, 17991, 1456, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10088, 17889, 2336, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10042, 16963, 4907, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10119, 8705, 8938, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6239, 7488, 453, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10129, 17946, 13650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10128, 17944, 13647, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10130, 17947, 13651, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10126, 17997, 13649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10127, 17943, 13646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10132, 17999, 13653, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10137, 18004, 13658, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10134, 18001, 13655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10050, 8063, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10133, 18000, 13654, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10012, 17663, 2732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10084, 4239, 2773, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10099, 9486, 926, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10135, 18002, 13656, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8824, 14727, 12521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10136, 18003, 13657, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10104, 17630, 2459, 10, '');
INSERT INTO 'dancestunesmap' VALUES (895, 3284, 191, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10100, 17900, 13623, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10149, 2635, 13674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10180, 18104, 13710, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10189, 13573, 11082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10190, 18120, 13793, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10253, 18341, 13887, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10191, 17789, 5504, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10192, 18142, 13794, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10153, 8947, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10152, 8947, 2252, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10246, 18337, 5300, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10204, 18232, 13811, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10282, 17138, 13312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10196, 17757, 10039, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10197, 14983, 13808, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10260, 16789, 360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10259, 16961, 2055, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10200, 3713, 950, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10151, 18016, 13606, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10195, 17452, 12581, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9119, 4821, 650, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10226, 18263, 10158, 10, '');
INSERT INTO 'dancestunesmap' VALUES (940, 3448, 92, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10162, 18055, 13767, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10163, 18073, 1732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10203, 18231, 382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10164, 18074, 685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10263, 16469, 1373, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10276, 14401, 13930, 10, 'From the RSCDS publication');
INSERT INTO 'dancestunesmap' VALUES (10116, 10052, 7621, 15, '');
INSERT INTO 'dancestunesmap' VALUES (6244, 5497, 6101, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10067, 17760, 13597, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10066, 17760, 13598, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1188, 4144, 326, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10048, 17715, 13571, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10081, 794, 13616, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1272, 4442, 1147, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2054, 7219, 1561, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10038, 17678, 3477, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10040, 17682, 13567, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10307, 16610, 1613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (581, 2140, 1122, 11, '');
INSERT INTO 'dancestunesmap' VALUES (101, 399, 77, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9912, 17444, 13387, 10, '');
INSERT INTO 'dancestunesmap' VALUES (209, 784, 571, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1115, 3894, 833, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1137, 3968, 1027, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10131, 16775, 13645, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10058, 17732, 3052, 30, '');
INSERT INTO 'dancestunesmap' VALUES (1069, 3774, 1562, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10111, 17949, 220, 10, 'Reel');
INSERT INTO 'dancestunesmap' VALUES (9939, 17478, 13417, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10059, 17730, 13575, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10060, 17731, 13576, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10061, 17733, 13577, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10062, 17734, 13578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10063, 17735, 13579, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10087, 17887, 96, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10112, 17981, 13635, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10093, 16803, 13620, 10, '');
INSERT INTO 'dancestunesmap' VALUES (626, 2321, 1135, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10079, 14339, 11370, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1833, 6424, 73, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3653, 8094, 2455, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1506, 5223, 603, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10161, 17694, 3289, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10103, 17903, 26, 10, '');
INSERT INTO 'dancestunesmap' VALUES (984, 3580, 1450, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10009, 12869, 13542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (282, 1022, 252, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10078, 12428, 2687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6042, 8166, 1897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10053, 17720, 12514, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2124, 4562, 2706, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10082, 2360, 964, 10, 'Customary, as for Fergus McIver/Waverley');
INSERT INTO 'dancestunesmap' VALUES (9043, 7548, 806, 10, '');
INSERT INTO 'dancestunesmap' VALUES (767, 2813, 656, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2061, 7242, 888, 11, '');
INSERT INTO 'dancestunesmap' VALUES (2029, 7143, 1344, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1942, 6817, 244, 11, '');
INSERT INTO 'dancestunesmap' VALUES (7686, 1087, 2152, 10, 'Tune published by the RSCDS');
INSERT INTO 'dancestunesmap' VALUES (10254, 18346, 705, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1771, 6152, 142, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10156, 18023, 13676, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1277, 4450, 1159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1269, 4440, 1145, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1224, 4291, 1101, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5387, 5823, 1609, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10080, 3541, 13615, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10155, 12532, 13675, 10, '');
INSERT INTO 'dancestunesmap' VALUES (259, 972, 274, 10, '');
INSERT INTO 'dancestunesmap' VALUES (227, 848, 1834, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10083, 654, 1731, 11, '');
INSERT INTO 'dancestunesmap' VALUES (7080, 10659, 1624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10172, 18085, 695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10173, 18086, 12060, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10266, 15662, 7064, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10171, 17383, 13770, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10269, 18408, 13923, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6922, 8923, 8027, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10181, 18105, 13711, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10182, 18108, 13707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10206, 12504, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9708, 16183, 13262, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10207, 18241, 13777, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9930, 17468, 13414, 10, 'As “Miss Isabelle Reid''s Reel”');
INSERT INTO 'dancestunesmap' VALUES (9707, 16183, 13261, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9441, 6259, 2019, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10183, 18110, 2406, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10202, 18228, 13810, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10279, 14456, 12150, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10105, 17921, 13610, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10158, 18036, 1670, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10201, 17100, 10864, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10071, 17689, 1971, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10165, 9800, 8229, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10255, 18348, 1101, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10185, 18112, 1581, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10186, 18113, 5371, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10188, 18116, 376, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10187, 18114, 7069, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10280, 18393, 13933, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10184, 18111, 5979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8397, 13845, 11577, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10275, 18410, 13929, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10284, 16838, 3001, 19, 'Originally proposed by deviser');
INSERT INTO 'dancestunesmap' VALUES (7330, 11298, 11580, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10270, 18409, 13924, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10140, 17711, 13661, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10271, 17460, 13925, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10208, 18244, 13812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10145, 18011, 13669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10143, 18009, 13667, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10148, 18014, 13672, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10147, 18013, 13671, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10150, 18015, 13673, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10125, 17997, 13648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10146, 18012, 13670, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10138, 18005, 13659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10142, 18008, 13665, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10144, 18010, 13668, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10274, 18272, 13928, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10277, 17122, 13931, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10199, 18207, 13809, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10252, 17920, 13193, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10278, 14903, 10126, 10, 'From the RSCDS publication');
INSERT INTO 'dancestunesmap' VALUES (3828, 2927, 3917, 1, '');
INSERT INTO 'dancestunesmap' VALUES (7891, 12766, 9824, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10141, 18007, 13663, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4812, 4938, 4342, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10281, 14959, 13406, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10288, 17882, 13935, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10290, 18492, 13937, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10291, 18493, 13938, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10287, 18490, 13934, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10293, 18486, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10294, 18486, 1374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10295, 18486, 835, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10283, 17137, 13311, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10268, 18309, 1334, 10, '');
INSERT INTO 'dancestunesmap' VALUES (43, 173, 161, 10, '');
INSERT INTO 'dancestunesmap' VALUES (274, 1015, 551, 10, '');
INSERT INTO 'dancestunesmap' VALUES (521, 1873, 1428, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10302, 18538, 13943, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10265, 18385, 9622, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10258, 16788, 4907, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10057, 17728, 8850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10194, 17452, 2318, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10257, 16787, 2399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10160, 18044, 73, 10, '');
INSERT INTO 'dancestunesmap' VALUES (311, 1125, 600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (312, 1125, 726, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10179, 18102, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10262, 18380, 1757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10175, 18097, 9700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10267, 18385, 457, 10, 'This seems to be an alternative name fo Ha! Ha! The Wooin'' O'' It');
INSERT INTO 'dancestunesmap' VALUES (7123, 9888, 8451, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10223, 18246, 7878, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8816, 14720, 451, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10308, 18580, 13946, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10309, 17254, 3165, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10367, 18246, 13974, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4964, 7888, 823, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10310, 18594, 2559, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10311, 18595, 11446, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10315, 18598, 7094, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10317, 18600, 7153, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10318, 18601, 8065, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7905, 12219, 2800, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10323, 18605, 835, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10324, 18607, 1683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10325, 18608, 3192, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9489, 5440, 4319, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10328, 18610, 4907, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10329, 18631, 8850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9903, 17434, 13382, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10193, 17452, 9962, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10332, 18635, 6818, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10333, 18637, 5080, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9269, 15740, 8842, 10, 'Sugg recording Can You Repeat That by Colin Dewar');
INSERT INTO 'dancestunesmap' VALUES (10371, 19090, 1528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10334, 18643, 13959, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10335, 18645, 577, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10372, 19091, 3019, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10370, 19087, 1897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10336, 396, 13960, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10356, 15608, 10727, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10429, 16615, 11052, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10337, 18657, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10331, 18634, 534, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10330, 18634, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10304, 18550, 12729, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10340, 18853, 137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6596, 9486, 13414, 10, 'RSCDS publication');
INSERT INTO 'dancestunesmap' VALUES (10341, 1656, 13962, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10377, 19108, 9633, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8799, 3832, 218, 10, 'Played both as a strathspey and as a reel');
INSERT INTO 'dancestunesmap' VALUES (10375, 19105, 764, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10384, 19116, 911, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10177, 17746, 1731, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10421, 19153, 3241, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10289, 18491, 13936, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4911, 5013, 3136, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10314, 18597, 665, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10365, 12935, 13972, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10176, 17747, 13792, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10286, 10820, 12622, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10347, 18965, 3246, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10368, 13296, 12619, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10326, 14952, 3145, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10327, 14952, 801, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10273, 16566, 13927, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10301, 17477, 11179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10157, 18024, 13677, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10320, 18603, 1374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10344, 18944, 6917, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10292, 18494, 13939, 10, '');
INSERT INTO 'dancestunesmap' VALUES (893, 3281, 421, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6840, 7738, 3399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10159, 8630, 5387, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10345, 18953, 1408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10139, 18006, 13660, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10261, 16791, 1181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10285, 13648, 2057, 19, 'Originally proposed by deviser');
INSERT INTO 'dancestunesmap' VALUES (10316, 18599, 10071, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10300, 13206, 7667, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10299, 13206, 7543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9217, 9286, 7587, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6314, 6505, 1431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7341, 8853, 8986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8840, 14750, 1897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2273, 3180, 760, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10174, 18087, 3860, 10, 'Suggested music: Ythanside, track 7 HISCD');
INSERT INTO 'dancestunesmap' VALUES (10366, 3923, 13973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1280, 4455, 1182, 11, '');
INSERT INTO 'dancestunesmap' VALUES (4594, 4517, 1017, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10167, 18082, 38, 10, 'haste Ye Back  played by Muriel Johnstone''s Band');
INSERT INTO 'dancestunesmap' VALUES (9201, 15676, 7023, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10296, 2835, 1766, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2640, 600, 1447, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8200, 11852, 2248, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10351, 19021, 2249, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8372, 13799, 2049, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10423, 19159, 300, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10352, 19024, 5351, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10353, 18495, 13964, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10357, 9878, 13967, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5638, 6520, 2973, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6378, 4380, 7354, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8605, 13975, 11651, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10406, 18941, 1264, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10358, 19050, 13098, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10391, 19130, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10374, 19103, 7263, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10380, 19111, 13975, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10378, 19109, 7176, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10407, 18956, 13990, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10381, 19113, 10188, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10376, 19106, 209, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10390, 19107, 13981, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1055, 3743, 78, 11, '');
INSERT INTO 'dancestunesmap' VALUES (9295, 15767, 8060, 10, 'Sugg: Selection of Reels Tr4 on Scottish Dance Country by BBrown');
INSERT INTO 'dancestunesmap' VALUES (10205, 14446, 12108, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10409, 14448, 1181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10411, 14447, 12116, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9617, 16536, 13195, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8214, 1173, 10320, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10382, 18355, 13976, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5571, 6405, 3884, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10322, 18604, 1809, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10321, 18604, 156, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10346, 18954, 1619, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10121, 17941, 13644, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10297, 13984, 8343, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7225, 11020, 1852, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3498, 2260, 1528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3156, 1613, 3659, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10369, 19071, 589, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10393, 19129, 13983, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10398, 2484, 11445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2315, 916, 3302, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2314, 916, 3301, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10388, 15492, 3640, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10373, 19104, 2031, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10403, 18946, 13984, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10387, 19124, 13980, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10379, 19110, 2140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10434, 18760, 1292, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10436, 19181, 312, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10437, 19182, 6945, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10438, 12669, 7844, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5090, 5451, 4436, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10338, 18658, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10408, 18655, 13994, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10339, 18851, 10575, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10359, 19051, 940, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10433, 12190, 2734, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10319, 18602, 1401, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10441, 19188, 14005, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10511, 19412, 7304, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10497, 19359, 14043, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10442, 19195, 7575, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8594, 13267, 9854, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10480, 19274, 14038, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10481, 8149, 848, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10444, 19199, 10510, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10233, 16794, 1609, 10, 'Deviser''s preference');
INSERT INTO 'dancestunesmap' VALUES (7884, 12760, 9817, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10449, 19222, 9047, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10450, 7443, 2296, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10451, 7443, 2637, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10452, 7448, 2189, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3795, 7414, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3794, 7414, 1166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10453, 7387, 7437, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10454, 7358, 1657, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3419, 2101, 2029, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1838, 6432, 1244, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1837, 6432, 431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10458, 12392, 1262, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5284, 5862, 4502, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5283, 5862, 4501, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1457, 5033, 1296, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10455, 19233, 14010, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8093, 13348, 9833, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10482, 17152, 9968, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4231, 3799, 4057, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10460, 19239, 10597, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5186, 5662, 3947, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5619, 7969, 1916, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3739, 2743, 1166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3672, 2611, 3851, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3557, 2376, 1683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10439, 11178, 1073, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4061, 3396, 1166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4062, 3396, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2949, 1202, 3563, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2182, 710, 2163, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10477, 19272, 1929, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10476, 19272, 7575, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10430, 17156, 13891, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7678, 12426, 2083, 11, 'Deviser''s original tune');
INSERT INTO 'dancestunesmap' VALUES (10405, 19135, 12171, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10404, 19134, 4543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10459, 8360, 3002, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10385, 19118, 13979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10472, 18288, 14032, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10364, 12934, 13971, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10363, 12928, 13970, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10443, 19194, 14006, 10, '');
INSERT INTO 'dancestunesmap' VALUES (167, 670, 1443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10392, 19131, 13982, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10362, 19054, 10130, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10422, 19154, 290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10417, 19148, 4297, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10414, 19145, 6784, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10416, 19147, 8846, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10426, 19163, 1391, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10418, 19149, 8240, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10425, 19162, 5018, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2702, 705, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (680, 2492, 1600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7897, 7293, 9758, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1048, 3732, 118, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3312, 7544, 2088, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10383, 19114, 13977, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7334, 11300, 2443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9987, 17027, 13518, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10343, 18943, 2163, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10350, 18966, 3816, 10, '');
INSERT INTO 'dancestunesmap' VALUES (814, 2962, 537, 11, '');
INSERT INTO 'dancestunesmap' VALUES (2084, 5200, 320, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1608, 5616, 848, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10432, 18718, 5078, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9114, 6995, 3136, 3, '');
INSERT INTO 'dancestunesmap' VALUES (3313, 7544, 2573, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10499, 13737, 1230, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10445, 19192, 14007, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7445, 10580, 8387, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6369, 9020, 7290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10440, 18553, 3243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10410, 14442, 12101, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10448, 19200, 14009, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10435, 19180, 14429, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6774, 9724, 1692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10360, 9478, 384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (224, 845, 22, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10355, 19034, 13966, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5942, 7142, 628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10415, 19146, 624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5096, 5458, 4439, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1721, 5945, 1588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1720, 5945, 1123, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10462, 18356, 14033, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6222, 4397, 1547, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4478, 4238, 482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2710, 715, 3473, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2099, 7558, 291, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10386, 19119, 13507, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10354, 19035, 13965, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10431, 19166, 14003, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10478, 19272, 2549, 12, '');
INSERT INTO 'dancestunesmap' VALUES (10483, 19281, 1656, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5803, 6861, 3013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7605, 3945, 1940, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10512, 19413, 2203, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10500, 19364, 10507, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10514, 19415, 2929, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9887, 16817, 9700, 10, 'Recorded on: SSCD21 "Todlen Hame" track: Well Kent');
INSERT INTO 'dancestunesmap' VALUES (10484, 19284, 152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10465, 14502, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10502, 19366, 14046, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10503, 19377, 8848, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10504, 19390, 14047, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10466, 14474, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10467, 19257, 9904, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10486, 19286, 2790, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10469, 19261, 6378, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10471, 19268, 11049, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10485, 19286, 2905, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10489, 19285, 12700, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10494, 19335, 14040, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10495, 13622, 11387, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10520, 19421, 2369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10515, 19416, 3643, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10526, 19475, 2886, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10496, 19355, 14042, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10516, 19417, 3113, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10419, 18537, 14001, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10498, 18053, 12562, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6454, 9111, 7552, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10400, 14441, 12098, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10394, 14443, 12105, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10402, 14445, 12112, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10395, 14449, 12126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10396, 14450, 12131, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10397, 14451, 12992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10399, 14452, 12139, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10412, 12368, 12146, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10413, 14457, 12152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10401, 14459, 12159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10457, 19236, 790, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10446, 19198, 14008, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6401, 9064, 7413, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1556, 5422, 1479, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10479, 10268, 1262, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10361, 19053, 13968, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10490, 19306, 14039, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10428, 19165, 4372, 11, '');
INSERT INTO 'dancestunesmap' VALUES (2215, 5911, 2250, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10513, 19414, 7942, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10473, 13637, 133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10474, 13637, 1605, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2146, 2722, 316, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10527, 19477, 364, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10522, 19310, 5471, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8642, 14401, 11553, 20, '[»Any good, light, flowing jig, not too fast!«]');
INSERT INTO 'dancestunesmap' VALUES (10517, 19418, 2788, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10523, 19357, 8769, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10530, 19481, 283, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10531, 19484, 755, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10532, 19485, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10534, 19487, 8840, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10456, 19235, 8694, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10518, 19419, 2930, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10519, 19420, 3026, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10521, 19422, 2007, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10524, 19431, 5702, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10525, 18117, 14072, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1939, 6811, 1084, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10540, 19494, 4833, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10528, 19479, 4852, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10533, 19486, 389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10535, 19488, 441, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10538, 19491, 14075, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10537, 19491, 14074, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10536, 19491, 14073, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10539, 19493, 12560, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7599, 5589, 685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10548, 19502, 7577, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10549, 19503, 124, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10550, 19504, 1001, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10551, 18855, 97, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10552, 19506, 408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10553, 19509, 1499, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1159, 4065, 449, 2, '');
INSERT INTO 'dancestunesmap' VALUES (1162, 4065, 1503, 4, '');
INSERT INTO 'dancestunesmap' VALUES (490, 1781, 1801, 4, 'ABCABC');
INSERT INTO 'dancestunesmap' VALUES (10558, 19522, 14079, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10559, 19524, 1578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10560, 19525, 926, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10561, 19526, 223, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10562, 19528, 2731, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10564, 19537, 5990, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10565, 7133, 6435, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10583, 19544, 14099, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10584, 19517, 14081, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10682, 19757, 8256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10683, 19758, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10626, 19661, 1757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10627, 19662, 14134, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10634, 15498, 1228, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10667, 19742, 14150, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10613, 19557, 14109, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10679, 19754, 14152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10681, 19756, 14153, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10674, 19749, 14151, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10615, 19558, 14112, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2526, 336, 3014, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6032, 7283, 2748, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10589, 19554, 12046, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10588, 19554, 12645, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10587, 19554, 2877, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10628, 19684, 4789, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10593, 19562, 106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10592, 19561, 9848, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10638, 7378, 627, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10639, 19702, 14137, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10591, 19560, 867, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10590, 19560, 1118, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6847, 9928, 7971, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1059, 3753, 613, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10597, 19590, 14127, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10642, 19706, 14140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10595, 19567, 8776, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10603, 15247, 12646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10643, 19707, 14141, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10644, 19708, 3327, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10645, 19708, 1857, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10646, 19709, 14143, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10647, 19710, 14144, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10632, 19689, 1197, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10631, 19689, 2115, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10649, 19713, 14146, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10650, 19714, 14147, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10651, 19715, 14148, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10652, 19716, 14149, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10585, 19549, 10856, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2036, 7172, 425, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10510, 19411, 7305, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3128, 1569, 3648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10464, 184, 14037, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10507, 19393, 14050, 10, '');
INSERT INTO 'dancestunesmap' VALUES (82, 327, 566, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10684, 19730, 14155, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10599, 15239, 13999, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10586, 19551, 14100, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10664, 19738, 10191, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8518, 14185, 78, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10570, 12918, 14086, 20, '2nd/3rd tune');
INSERT INTO 'dancestunesmap' VALUES (10566, 19542, 14082, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10602, 15244, 14131, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10604, 4625, 12843, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10596, 19581, 9757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10600, 15233, 14128, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10581, 12924, 14093, 20, '2nd/3rd tune');
INSERT INTO 'dancestunesmap' VALUES (740, 2709, 201, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10582, 12924, 14096, 20, '2nd/3rd tune');
INSERT INTO 'dancestunesmap' VALUES (10601, 15236, 14130, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10563, 19514, 14080, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10493, 19308, 9153, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10580, 12908, 14092, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10543, 12274, 14076, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10492, 19308, 10682, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10491, 19308, 2217, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10625, 8368, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10572, 19131, 14087, 20, '2nd/3rd tune');
INSERT INTO 'dancestunesmap' VALUES (10576, 19394, 14097, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10575, 19394, 14090, 20, '2nd tune');
INSERT INTO 'dancestunesmap' VALUES (10577, 12923, 14091, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10641, 19705, 14139, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10568, 19543, 14084, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10569, 19543, 14085, 20, '2nd tune');
INSERT INTO 'dancestunesmap' VALUES (10505, 16857, 14048, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10529, 19480, 2252, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4723, 4758, 1317, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10542, 12252, 10721, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10544, 19501, 4837, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10541, 19497, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10506, 16857, 14049, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10640, 17628, 14138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7169, 8702, 8491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7161, 8702, 1964, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10037, 17677, 13565, 10, 'A Decade of Fun and Delight!');
INSERT INTO 'dancestunesmap' VALUES (388, 1424, 521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10607, 19023, 753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10554, 19510, 13498, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10611, 19646, 14132, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10555, 19510, 1566, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10556, 19510, 13499, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10614, 19559, 11674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10610, 19556, 14105, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10609, 19657, 4004, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10616, 250, 1514, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10621, 8351, 384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10622, 8356, 669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10623, 8356, 1023, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10658, 19719, 695, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10659, 19719, 133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10654, 19721, 1600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10660, 19727, 1419, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10636, 19688, 14136, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10665, 19739, 11244, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10666, 19740, 122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10686, 19736, 3825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10637, 15481, 1540, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10668, 19743, 2392, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10669, 19744, 11320, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10670, 19745, 2929, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10671, 19746, 2896, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10673, 19748, 1898, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10675, 19750, 259, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10676, 19751, 820, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10677, 19752, 1618, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10678, 19753, 5078, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10680, 19755, 896, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10178, 17748, 10190, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10688, 19741, 14156, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10689, 19728, 14157, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10662, 19732, 14160, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10690, 19734, 14154, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10635, 18785, 8873, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10706, 5252, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10605, 19635, 13471, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4796, 4904, 593, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10608, 19555, 11672, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10573, 12913, 14088, 20, '2nd tune');
INSERT INTO 'dancestunesmap' VALUES (10463, 19247, 14036, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10557, 19362, 993, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10468, 19258, 1294, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10648, 19711, 14145, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10612, 19650, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10598, 19604, 13479, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10694, 16962, 180, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10707, 5252, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6807, 9767, 1963, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2015, 7096, 921, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10704, 14717, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (854, 3129, 749, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6211, 8852, 2457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8005, 13077, 9907, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10695, 7679, 604, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10696, 19774, 1214, 10, 'or any good traditional strathspey');
INSERT INTO 'dancestunesmap' VALUES (3482, 2236, 2680, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10687, 19759, 1677, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2504, 303, 68, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5944, 7147, 2680, 10, '');
INSERT INTO 'dancestunesmap' VALUES (649, 2394, 1303, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8177, 12426, 11180, 10, 'RSCDS-published “original”');
INSERT INTO 'dancestunesmap' VALUES (8602, 14332, 1845, 10, 'also known as Mor a'' Cheannaich');
INSERT INTO 'dancestunesmap' VALUES (1711, 5906, 1580, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2365, 66, 1858, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3036, 1345, 317, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7302, 10093, 284, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7303, 10093, 1814, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10691, 18149, 24, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7483, 11654, 6764, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10461, 19243, 494, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10692, 10694, 4848, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1292, 4491, 1662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10004, 8720, 7172, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6839, 8710, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1259, 4407, 628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9688, 14985, 13243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10685, 19729, 14158, 10, '');
INSERT INTO 'dancestunesmap' VALUES (51, 189, 1600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (50, 189, 1331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8899, 13094, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2754, 809, 3494, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2753, 809, 133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2752, 809, 3493, 10, '');
INSERT INTO 'dancestunesmap' VALUES (49, 189, 834, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7817, 12594, 9647, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3877, 3031, 2815, 10, '');
INSERT INTO 'dancestunesmap' VALUES (832, 3031, 1200, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6338, 8743, 2063, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10698, 10747, 14166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (324, 1176, 233, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1353, 4709, 1448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5885, 7019, 4677, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7827, 12680, 5562, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9533, 16423, 8496, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9534, 16423, 13141, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10693, 19772, 1834, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10712, 5615, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9309, 14310, 1435, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10701, 19798, 4181, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10702, 16072, 13886, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8755, 14580, 2017, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8756, 14580, 2321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4769, 4832, 1668, 10, '');
INSERT INTO 'dancestunesmap' VALUES (744, 2715, 943, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10618, 8349, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7353, 11359, 8996, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9882, 17402, 13334, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9883, 17402, 13335, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9141, 15423, 10844, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10619, 8349, 384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10620, 8349, 1835, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9047, 13544, 5535, 10, 'The Cape Breton version, not the one from Kerr''s Collection');
INSERT INTO 'dancestunesmap' VALUES (3381, 2035, 3140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10661, 19731, 14159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3290, 1867, 692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10663, 19737, 1179, 10, '');
INSERT INTO 'dancestunesmap' VALUES (643, 2383, 553, 1, '');
INSERT INTO 'dancestunesmap' VALUES (10708, 19820, 933, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7959, 12918, 9946, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10672, 19747, 7815, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4968, 5232, 3956, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10629, 19687, 14135, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10656, 19723, 1626, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10710, 8724, 1714, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1949, 6830, 1514, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8606, 14342, 11984, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4448, 4174, 4187, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5984, 7226, 357, 10, 'Dance two reel steps to each bar of the music');
INSERT INTO 'dancestunesmap' VALUES (4041, 3360, 656, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9837, 17309, 13301, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10714, 7397, 431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8814, 13583, 11172, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10715, 1114, 7815, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7010, 10482, 447, 1, 'designated tune for Cadies Lady');
INSERT INTO 'dancestunesmap' VALUES (8885, 10482, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8884, 10482, 441, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10711, 19832, 14170, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10718, 19843, 14207, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10720, 19841, 794, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10719, 19841, 1621, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5463, 6221, 1683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10722, 16906, 14208, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10655, 19722, 2661, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10699, 19797, 4907, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2509, 308, 3375, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10657, 19724, 2543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10571, 12918, 14095, 20, '2nd/3rd tune');
INSERT INTO 'dancestunesmap' VALUES (10624, 8363, 730, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1155, 4044, 190, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10716, 15647, 8602, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10717, 19842, 14206, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6491, 6490, 220, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8547, 11814, 10004, 10, '');
INSERT INTO 'dancestunesmap' VALUES (571, 2077, 1687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10501, 19365, 14045, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8631, 14370, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10617, 8348, 4496, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10606, 456, 4678, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4359, 4045, 2117, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2252, 1232, 2654, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10731, 19843, 14211, 20, '2nd/other tune');
INSERT INTO 'dancestunesmap' VALUES (10723, 19847, 2493, 10, '');
INSERT INTO 'dancestunesmap' VALUES (544, 1946, 488, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1445, 4975, 1406, 1, '');
INSERT INTO 'dancestunesmap' VALUES (519, 1864, 1318, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1334, 4650, 300, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10724, 19851, 7675, 10, '');
INSERT INTO 'dancestunesmap' VALUES (583, 2153, 133, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1335, 4650, 1389, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1699, 5878, 885, 11, '');
INSERT INTO 'dancestunesmap' VALUES (555, 2024, 292, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10574, 19131, 14089, 20, '2nd/3rd tune');
INSERT INTO 'dancestunesmap' VALUES (1014, 3632, 927, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7362, 11370, 9001, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7363, 11370, 9002, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10753, 19979, 14245, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5548, 6362, 2282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1973, 6957, 299, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10727, 19856, 7216, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10728, 19849, 10654, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1248, 4359, 1418, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1132, 3953, 728, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1399, 4864, 1079, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10508, 19393, 14051, 11, '2nd/3rd tune');
INSERT INTO 'dancestunesmap' VALUES (10509, 19393, 14052, 12, '2nd/3rd tune');
INSERT INTO 'dancestunesmap' VALUES (7763, 4543, 2648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10170, 18084, 9797, 10, 'Celtic Fire in the Music, Bobby Brown, track13 disk2');
INSERT INTO 'dancestunesmap' VALUES (5327, 5951, 3002, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7963, 12920, 9949, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6178, 1786, 1882, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10757, 20000, 5702, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10758, 18446, 652, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10736, 19887, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3251, 1789, 3691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10737, 17391, 7577, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8012, 13082, 2056, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1925, 6751, 1742, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7279, 11186, 8841, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10567, 19542, 14083, 20, '2nd tune');
INSERT INTO 'dancestunesmap' VALUES (10759, 18451, 1110, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10734, 19878, 1737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10741, 19944, 13896, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10760, 20003, 8157, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10761, 20004, 1897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10762, 20009, 13984, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1851, 6489, 1236, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10097, 17898, 13622, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1680, 5804, 1234, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10721, 16011, 1360, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2333, 20, 3309, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10703, 681, 2997, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10705, 1196, 2040, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4339, 4257, 429, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5176, 5642, 4073, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1000, 3608, 1325, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10633, 19690, 5367, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1873, 6571, 300, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10700, 18711, 1287, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10740, 9896, 1897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1187, 4133, 380, 1, '');
INSERT INTO 'dancestunesmap' VALUES (8999, 4133, 9800, 2, '');
INSERT INTO 'dancestunesmap' VALUES (1539, 5354, 287, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8559, 14135, 1929, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4571, 4481, 4239, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10743, 19968, 4799, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10742, 19967, 1282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8353, 13782, 78, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10745, 8326, 71, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10744, 8326, 4800, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3921, 3123, 3478, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6963, 10329, 2264, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10726, 13263, 8309, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10747, 17695, 10469, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10748, 15435, 12936, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3790, 2827, 3902, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4299, 3942, 4077, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1762, 6103, 1614, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10766, 18245, 14276, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10750, 6928, 1937, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10025, 12247, 13555, 10, 'used in The Emigrant Scot');
INSERT INTO 'dancestunesmap' VALUES (10787, 20075, 6491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9296, 15768, 6406, 10, 'Sugg: Spirit of the Dance Tr9 on Campbell''s Birl by M Johnstone');
INSERT INTO 'dancestunesmap' VALUES (1958, 6885, 1274, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10767, 18208, 408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10768, 17593, 13687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (171, 674, 1193, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10769, 15646, 13006, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6801, 9753, 1415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10755, 13089, 422, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9407, 16002, 1963, 10, 'Sugg music: King''s Croft on Reel Friends by David Hall');
INSERT INTO 'dancestunesmap' VALUES (6311, 6029, 892, 11, '');
INSERT INTO 'dancestunesmap' VALUES (5888, 7025, 2349, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2254, 6236, 1639, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2679, 645, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (286, 1032, 257, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4015, 3323, 806, 1, '');
INSERT INTO 'dancestunesmap' VALUES (10424, 19161, 6518, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7481, 11661, 1839, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10774, 20059, 5837, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2703, 705, 685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (210, 784, 1522, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10773, 13122, 6732, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3307, 1901, 1112, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3549, 2363, 1027, 10, '');
INSERT INTO 'dancestunesmap' VALUES (725, 2671, 518, 10, '');
INSERT INTO 'dancestunesmap' VALUES (964, 3521, 867, 10, '');
INSERT INTO 'dancestunesmap' VALUES (967, 3524, 1125, 10, '');
INSERT INTO 'dancestunesmap' VALUES (968, 3524, 1778, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4185, 3703, 4039, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9193, 15635, 13017, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10749, 19903, 1095, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10776, 19892, 14287, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10775, 19901, 14286, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10738, 19897, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10778, 17604, 13698, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10779, 17597, 13691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10780, 17592, 13686, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10781, 17588, 13683, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10782, 17585, 13679, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10783, 17584, 7403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10784, 20072, 14288, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10786, 20073, 9210, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3183, 1676, 2110, 10, '');
INSERT INTO 'dancestunesmap' VALUES (73, 306, 70, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5123, 5516, 880, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6150, 7793, 6441, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5422, 7950, 337, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6696, 9637, 1336, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6707, 9650, 7821, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6717, 9657, 7829, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10790, 10605, 14289, 10, '');
INSERT INTO 'dancestunesmap' VALUES (180, 704, 647, 10, '');
INSERT INTO 'dancestunesmap' VALUES (181, 704, 1044, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4044, 3366, 1800, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3890, 7748, 3941, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8488, 13455, 10560, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8275, 13472, 7628, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8258, 13743, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10763, 20010, 4323, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1378, 4806, 1352, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10730, 19843, 14210, 20, '2nd/other tune');
INSERT INTO 'dancestunesmap' VALUES (10579, 12923, 14098, 20, '2nd/3rd tune');
INSERT INTO 'dancestunesmap' VALUES (10578, 12923, 14094, 20, '2nd/3rd tune');
INSERT INTO 'dancestunesmap' VALUES (1328, 4642, 1255, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7041, 10546, 8247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6715, 9656, 7827, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1005, 3615, 1014, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1476, 5128, 295, 10, '32 bars each for Entry/Exit');
INSERT INTO 'dancestunesmap' VALUES (2945, 5324, 3561, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7971, 12901, 3853, 10, '');
INSERT INTO 'dancestunesmap' VALUES (116, 441, 3, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1477, 5128, 697, 10, 'For the actual dance (88 bars)');
INSERT INTO 'dancestunesmap' VALUES (215, 805, 91, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10752, 19976, 11555, 10, 'Example: 12 Coates Crescent');
INSERT INTO 'dancestunesmap' VALUES (3107, 1521, 763, 10, '');
INSERT INTO 'dancestunesmap' VALUES (597, 2189, 693, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10751, 1943, 1230, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9229, 9294, 12638, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8264, 13749, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2983, 1256, 3574, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8626, 14376, 10678, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3655, 2579, 608, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8669, 14433, 12053, 10, '');
INSERT INTO 'dancestunesmap' VALUES (551, 1990, 1377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10791, 20086, 14290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10793, 20102, 10684, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1058, 3748, 423, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3823, 2907, 2247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10795, 14949, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10820, 19180, 14004, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10821, 19201, 14432, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10794, 20121, 7212, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10796, 16881, 3243, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10798, 17053, 234, 20, 'Suitable');
INSERT INTO 'dancestunesmap' VALUES (10797, 17053, 10363, 10, 'Preferred');
INSERT INTO 'dancestunesmap' VALUES (10803, 20181, 14384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10799, 1768, 3189, 20, 'Alternative');
INSERT INTO 'dancestunesmap' VALUES (4025, 3332, 812, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10800, 13983, 13329, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9936, 17474, 1138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4480, 4240, 2307, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4314, 3966, 1026, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10801, 20140, 14333, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6395, 9059, 7407, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10349, 18966, 6928, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10348, 18966, 1089, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6436, 9093, 760, 10, 'Tune published with the dance in »The Silver Thistle Collection«');
INSERT INTO 'dancestunesmap' VALUES (784, 2868, 1489, 10, '');
INSERT INTO 'dancestunesmap' VALUES (783, 2868, 366, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10805, 19619, 14386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6434, 9091, 7482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (970, 3525, 871, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1108, 3885, 1098, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4580, 4494, 3309, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1361, 4728, 150, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1585, 5519, 1024, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1834, 6424, 426, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5896, 7045, 1003, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2131, 7570, 2975, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8432, 8654, 11597, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6621, 9513, 7709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10792, 20090, 7907, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10733, 19842, 14214, 20, '2nd/3rd tune');
INSERT INTO 'dancestunesmap' VALUES (10732, 19842, 14213, 20, '2nd/3rd tune');
INSERT INTO 'dancestunesmap' VALUES (10729, 19843, 14209, 20, '2nd/other tune');
INSERT INTO 'dancestunesmap' VALUES (7537, 11885, 9422, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7538, 11885, 9423, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8545, 12910, 11737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8546, 12910, 11738, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3577, 129, 209, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10917, 3987, 7139, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10789, 18854, 2115, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7514, 11797, 9313, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10770, 19956, 14279, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10739, 19258, 2017, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10764, 17754, 14274, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10772, 20049, 14281, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10447, 19197, 14008, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8299, 13772, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4755, 4803, 2608, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10754, 19981, 10130, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10802, 20147, 14383, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10765, 20012, 14275, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1143, 3988, 71, 1, 'played AABAAB');
INSERT INTO 'dancestunesmap' VALUES (10746, 17693, 2905, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7172, 10860, 8494, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10756, 13771, 13371, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4622, 4571, 2624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (437, 1552, 866, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9720, 16849, 2575, 10, 'New Ashludie Rant on Marian Anderson''s Scottish Dances Vol 12');
INSERT INTO 'dancestunesmap' VALUES (8580, 13363, 10152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7855, 12719, 9770, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9886, 16801, 1501, 10, 'Recorded on: LCOM9007 Rob Gordon "The Compleat Caledonian Ball"');
INSERT INTO 'dancestunesmap' VALUES (9492, 16257, 933, 10, '80 bar recording for "The Laird o'' Dochart''s Reel"');
INSERT INTO 'dancestunesmap' VALUES (4529, 4382, 1835, 10, '');
INSERT INTO 'dancestunesmap' VALUES (504, 1818, 459, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2660, 609, 1648, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10807, 609, 5525, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8603, 14341, 11983, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10817, 17726, 850, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5127, 5530, 825, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1130, 3941, 767, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4679, 4684, 1721, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8406, 13439, 10454, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9839, 17311, 13303, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10298, 13206, 7334, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10808, 16106, 9341, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2049, 7210, 1050, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1483, 5141, 915, 11, '');
INSERT INTO 'dancestunesmap' VALUES (7104, 10405, 8470, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5916, 7084, 4687, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7391, 11427, 1565, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7836, 12689, 7317, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10816, 17724, 2008, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10822, 20222, 10119, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10823, 17723, 753, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10824, 11203, 996, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1978, 6965, 1835, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1977, 6965, 1757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (321, 1162, 1744, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8224, 11874, 10331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6642, 9425, 7756, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9973, 17509, 685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5829, 6930, 188, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1395, 4862, 835, 11, '');
INSERT INTO 'dancestunesmap' VALUES (7396, 11479, 9043, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8440, 13892, 11605, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7365, 11371, 9004, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7361, 11369, 9000, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10809, 9552, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7174, 10862, 8278, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7101, 10783, 8467, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7100, 10783, 8466, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10810, 20217, 5764, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10811, 10760, 2991, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7030, 10521, 682, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7029, 10520, 2492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10117, 10052, 7622, 15, '');
INSERT INTO 'dancestunesmap' VALUES (10118, 10052, 7623, 15, '');
INSERT INTO 'dancestunesmap' VALUES (10825, 4041, 601, 20, '');
INSERT INTO 'dancestunesmap' VALUES (10813, 6355, 12534, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6901, 9855, 8016, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10814, 9851, 7607, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6830, 9824, 3629, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10806, 9227, 12182, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10815, 11204, 14430, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6371, 9043, 4776, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10818, 17722, 14431, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1451, 5007, 1691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10819, 20219, 3491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10834, 20250, 1518, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10835, 8951, 7208, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8660, 6712, 473, 2, 'Official tune');
INSERT INTO 'dancestunesmap' VALUES (10826, 18076, 13676, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6557, 9384, 7662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3676, 2617, 1512, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9222, 9289, 12631, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9040, 7548, 1997, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6126, 6712, 2798, 10, 'Not Official');
INSERT INTO 'dancestunesmap' VALUES (10836, 8954, 7211, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10804, 20182, 14385, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10838, 6666, 295, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10827, 9184, 10071, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10837, 8946, 7203, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6449, 9106, 7547, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10829, 20230, 14433, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10833, 20235, 14434, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7517, 9093, 9291, 10, 'Tune published with the dance in RSCDS Book 44');
INSERT INTO 'dancestunesmap' VALUES (6549, 2387, 1696, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10840, 20254, 14435, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7020, 8929, 3113, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10839, 19712, 1067, 2, '');
INSERT INTO 'dancestunesmap' VALUES (10841, 19712, 14436, 1, '');
INSERT INTO 'dancestunesmap' VALUES (6417, 9077, 7429, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10842, 19059, 1933, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10843, 19060, 14437, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10844, 19061, 1373, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10845, 19063, 14438, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10846, 19064, 14439, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10847, 19076, 14440, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10848, 19077, 14441, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10849, 19078, 2932, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10850, 19079, 14442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10851, 19080, 14443, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10852, 19081, 4034, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10853, 19082, 1757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10854, 19083, 14444, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5216, 5726, 2822, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6889, 8703, 8005, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4837, 5001, 4352, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10812, 20002, 14388, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10831, 9123, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (989, 3584, 1058, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10830, 2203, 7011, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10832, 9122, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10857, 8557, 3452, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10858, 8557, 3453, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10859, 8558, 14446, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10860, 8556, 796, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10862, 8555, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10861, 8555, 3454, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10863, 8554, 1368, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10864, 8554, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7751, 2350, 2779, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9303, 15775, 8312, 10, 'Sugg Tune: Chas Reel Tr17 on Reels & Wheels by Gordon Shand');
INSERT INTO 'dancestunesmap' VALUES (6265, 8178, 2240, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10865, 8084, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10866, 20282, 14447, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10867, 7814, 11554, 20, '');
INSERT INTO 'dancestunesmap' VALUES (3588, 7723, 3821, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10911, 2251, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4105, 7440, 1491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10868, 7533, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10869, 7532, 8271, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10870, 7369, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10912, 2251, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10872, 7356, 2108, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10871, 7366, 3258, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10873, 7340, 1856, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10874, 7338, 6792, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10875, 7336, 6781, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1630, 5658, 560, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9002, 3065, 1497, 10, 'Suggested on Strathspey 2009-04-16');
INSERT INTO 'dancestunesmap' VALUES (5931, 7129, 3325, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10876, 7027, 14448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10877, 20294, 14449, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7288, 11196, 8868, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1933, 6797, 1686, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10878, 2651, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10879, 2651, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10913, 2171, 398, 12, '');
INSERT INTO 'dancestunesmap' VALUES (10914, 2171, 713, 13, '');
INSERT INTO 'dancestunesmap' VALUES (1881, 6601, 1718, 40, 'Possibly a mistaken entry?');
INSERT INTO 'dancestunesmap' VALUES (10881, 6601, 3195, 20, '');
INSERT INTO 'dancestunesmap' VALUES (10880, 6601, 1919, 30, '');
INSERT INTO 'dancestunesmap' VALUES (517, 1862, 1519, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10883, 7459, 6794, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10884, 6550, 7138, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1857, 6518, 433, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10885, 6478, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5546, 6358, 432, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1803, 6323, 1275, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1789, 6210, 1635, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5435, 6158, 4549, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10886, 5996, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7770, 5981, 3891, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6655, 5904, 1275, 20, '');
INSERT INTO 'dancestunesmap' VALUES (4166, 3662, 166, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10887, 20323, 14354, 10, '');
INSERT INTO 'dancestunesmap' VALUES (355, 1300, 530, 20, 'previously suggested tune');
INSERT INTO 'dancestunesmap' VALUES (3351, 1982, 2369, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10915, 1928, 7154, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10933, 20310, 14453, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5223, 5744, 3498, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1663, 5741, 1005, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10889, 5710, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10916, 472, 7152, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10855, 19084, 14445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10856, 19085, 3914, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10882, 2348, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6462, 8708, 7562, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1749, 6053, 1561, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1046, 3730, 903, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10918, 855, 7140, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1634, 5669, 1542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1519, 5282, 1688, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10919, 4835, 7143, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10890, 20335, 14450, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6416, 9077, 7428, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1442, 4968, 112, 11, '');
INSERT INTO 'dancestunesmap' VALUES (779, 2846, 199, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4358, 4044, 2492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10891, 4988, 7151, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10892, 4819, 3289, 20, '');
INSERT INTO 'dancestunesmap' VALUES (10893, 4819, 2559, 20, '');
INSERT INTO 'dancestunesmap' VALUES (1415, 4908, 1406, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1414, 4908, 864, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10897, 4746, 7939, 20, '');
INSERT INTO 'dancestunesmap' VALUES (10898, 4746, 849, 30, '');
INSERT INTO 'dancestunesmap' VALUES (10899, 4512, 268, 20, '');
INSERT INTO 'dancestunesmap' VALUES (10900, 4436, 1588, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4541, 4422, 2567, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1230, 4300, 1104, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1210, 4222, 266, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2242, 4222, 3269, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10166, 18082, 1663, 10, 'Happy Dancers played by Muriel Johnstone''s Band');
INSERT INTO 'dancestunesmap' VALUES (1149, 4019, 1032, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5063, 5399, 1621, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1109, 3887, 275, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1098, 3861, 1040, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1085, 3829, 1509, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1086, 3829, 1607, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4223, 3784, 4053, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1031, 3691, 1738, 10, '');
INSERT INTO 'dancestunesmap' VALUES (955, 3499, 1208, 10, '');
INSERT INTO 'dancestunesmap' VALUES (956, 3499, 1441, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10902, 3446, 2386, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10920, 5618, 7153, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10921, 4280, 7147, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10922, 6845, 7148, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10923, 5768, 7150, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2833, 991, 3522, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4635, 4591, 1485, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10903, 16832, 802, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2081, 3280, 869, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10904, 3152, 5355, 11, '');
INSERT INTO 'dancestunesmap' VALUES (841, 3047, 995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (813, 2957, 1551, 12, '');
INSERT INTO 'dancestunesmap' VALUES (10906, 2906, 2519, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10907, 2906, 2225, 12, '');
INSERT INTO 'dancestunesmap' VALUES (10908, 3085, 359, 10, '?');
INSERT INTO 'dancestunesmap' VALUES (2313, 3016, 1167, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10909, 10, 333, 5, '');
INSERT INTO 'dancestunesmap' VALUES (3727, 2717, 3874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (738, 2707, 633, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3651, 2571, 2957, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7602, 2571, 4578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (675, 2471, 1634, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10910, 2356, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10924, 8394, 435, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10925, 7138, 1986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5904, 7057, 669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10926, 7057, 341, 20, '');
INSERT INTO 'dancestunesmap' VALUES (478, 1762, 1350, 11, '');
INSERT INTO 'dancestunesmap' VALUES (549, 1966, 1401, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10927, 3852, 1662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10895, 20339, 1553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10894, 20338, 864, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5853, 6971, 4663, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2971, 1237, 211, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10896, 20341, 1897, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6278, 2936, 745, 10, '');
INSERT INTO 'dancestunesmap' VALUES (411, 1475, 993, 10, '');
INSERT INTO 'dancestunesmap' VALUES (410, 1475, 151, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2253, 1429, 2128, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5558, 6383, 3860, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2492, 281, 1331, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10928, 1561, 1796, 10, '');
INSERT INTO 'dancestunesmap' VALUES (326, 1192, 729, 1, '2x tonic, dominant, tonic');
INSERT INTO 'dancestunesmap' VALUES (3333, 1954, 2886, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3101, 1511, 544, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10938, 18383, 14458, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10935, 20312, 14456, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10937, 1093, 408, 10, '');
INSERT INTO 'dancestunesmap' VALUES (297, 1068, 595, 10, '');
INSERT INTO 'dancestunesmap' VALUES (281, 1020, 1267, 11, '');
INSERT INTO 'dancestunesmap' VALUES (264, 980, 1616, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10940, 20361, 10688, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10939, 20321, 14459, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10941, 853, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10942, 853, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2713, 717, 1665, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10945, 660, 4952, 12, '');
INSERT INTO 'dancestunesmap' VALUES (10946, 660, 14461, 11, '');
INSERT INTO 'dancestunesmap' VALUES (7744, 650, 3459, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10936, 20313, 14457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (141, 543, 1403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2620, 540, 100, 1, '');
INSERT INTO 'dancestunesmap' VALUES (10888, 20333, 14297, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2602, 497, 3415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10947, 20247, 10685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10948, 420, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2248, 387, 186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10951, 1962, 1728, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10952, 15323, 14464, 10, '');
INSERT INTO 'dancestunesmap' VALUES (65, 274, 1752, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10953, 271, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10954, 271, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2465, 235, 789, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10955, 229, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10956, 137, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10958, 14308, 11797, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10957, 14308, 11782, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10959, 6311, 267, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10960, 2527, 9684, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10961, 20324, 7802, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6897, 10003, 8011, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10962, 20370, 14465, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8370, 13797, 1982, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10545, 19501, 13150, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10546, 19501, 14077, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10547, 19501, 14078, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4753, 4800, 3384, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2098, 7557, 235, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7128, 10802, 2399, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10964, 10285, 8155, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10965, 20427, 2931, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10966, 17147, 11345, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10967, 17145, 14471, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10968, 17148, 11344, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10969, 20429, 958, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10973, 20437, 14473, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10974, 20438, 14476, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10977, 20440, 14479, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10970, 20432, 14472, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11032, 20568, 9256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10971, 20435, 14475, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10972, 20436, 14474, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11036, 20572, 14548, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10986, 20487, 14490, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10988, 20485, 14488, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10989, 20486, 14489, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10990, 20488, 14491, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11035, 20573, 14549, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10987, 20484, 14487, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10994, 20490, 14493, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10995, 20491, 14494, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10984, 20450, 14486, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10993, 20489, 14492, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10996, 15566, 10536, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10997, 17763, 7282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10998, 17765, 13599, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3405, 2093, 3746, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10999, 20421, 1504, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11000, 9548, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4300, 3944, 256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11003, 20516, 14505, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10985, 3681, 4737, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10982, 20445, 14483, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10983, 20446, 14484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10905, 20348, 3578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10963, 20390, 14466, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10934, 20311, 14455, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10929, 20314, 14452, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10901, 8112, 77, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10943, 761, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3920, 3122, 3955, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11033, 20570, 1043, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11009, 20521, 14511, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10950, 19975, 14463, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10949, 19975, 14462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11031, 20566, 14544, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10975, 20439, 14477, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10976, 20439, 14478, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10981, 20443, 14482, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10154, 18019, 1204, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10930, 3189, 3912, 10, 'March (to enter and exit)');
INSERT INTO 'dancestunesmap' VALUES (10978, 20441, 14480, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10979, 20441, 2197, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11010, 18349, 14512, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11011, 20522, 14513, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11001, 20514, 14503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11005, 20518, 14507, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11006, 20519, 14508, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11008, 20520, 14510, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11007, 20520, 14509, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11013, 19665, 14528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11017, 20556, 14530, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11002, 20515, 14504, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11019, 20560, 14531, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11004, 20517, 14506, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11020, 17621, 14454, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11023, 20319, 14538, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11024, 20317, 13019, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11026, 19792, 14536, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11027, 17706, 14539, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11028, 20316, 14534, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11022, 20322, 14540, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1026, 3672, 939, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6286, 3672, 1598, 11, '');
INSERT INTO 'dancestunesmap' VALUES (10470, 18017, 685, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10980, 20442, 14481, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11037, 20492, 14550, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11021, 20320, 14537, 10, '');
INSERT INTO 'dancestunesmap' VALUES (122, 453, 106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11025, 20315, 14533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9822, 17239, 10688, 10, '');
INSERT INTO 'dancestunesmap' VALUES (85, 338, 186, 10, '');
INSERT INTO 'dancestunesmap' VALUES (644, 2386, 85, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11065, 9758, 7874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8077, 9579, 2442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11054, 20620, 1238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11088, 20737, 1029, 10, 'Tune from Lady Mary Cochrane''s Reel - Alan Gardiner');
INSERT INTO 'dancestunesmap' VALUES (1523, 5308, 1158, 10, '');
INSERT INTO 'dancestunesmap' VALUES (864, 3172, 757, 1, '');
INSERT INTO 'dancestunesmap' VALUES (8746, 14568, 9984, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3075, 1445, 771, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3303, 1888, 3710, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10777, 17608, 13702, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11066, 20661, 14677, 10, '');
INSERT INTO 'dancestunesmap' VALUES (184, 729, 174, 10, '');
INSERT INTO 'dancestunesmap' VALUES (36, 153, 13, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1541, 5362, 1477, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5042, 5362, 824, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11039, 20577, 223, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8844, 14743, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10120, 17993, 13643, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8601, 14330, 11982, 10, '');
INSERT INTO 'dancestunesmap' VALUES (590, 2170, 516, 10, '');
INSERT INTO 'dancestunesmap' VALUES (591, 2170, 738, 10, '');
INSERT INTO 'dancestunesmap' VALUES (592, 2170, 1534, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11040, 13539, 10918, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11041, 20608, 231, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11042, 20608, 133, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11043, 20608, 1578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11044, 20608, 1713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11045, 20610, 12310, 10, 'Jennifer Lawson''s Reel?');
INSERT INTO 'dancestunesmap' VALUES (11046, 20613, 2468, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11047, 20615, 14552, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11048, 20616, 14553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11049, 20619, 2297, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11050, 20579, 14554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11051, 8648, 14625, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11053, 8650, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4797, 4904, 375, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11016, 20554, 14529, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11055, 4232, 2903, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11056, 6836, 1964, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11057, 5155, 12915, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4149, 3624, 920, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11058, 4101, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6916, 10016, 8021, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11059, 20628, 14674, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10420, 18537, 14002, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4171, 3681, 607, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9695, 16802, 3199, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9694, 16802, 979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9693, 16802, 13245, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1828, 6406, 1677, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2961, 7648, 1069, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11083, 20733, 14705, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6057, 1404, 1898, 20, 'Lead tune of recommended recording');
INSERT INTO 'dancestunesmap' VALUES (11060, 1404, 14675, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11029, 20318, 14535, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11069, 20666, 14678, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11064, 17356, 14676, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11063, 17356, 8471, 15, '');
INSERT INTO 'dancestunesmap' VALUES (11062, 17356, 1818, 15, '');
INSERT INTO 'dancestunesmap' VALUES (11061, 17356, 1622, 15, '');
INSERT INTO 'dancestunesmap' VALUES (9854, 17356, 11555, 20, '');
INSERT INTO 'dancestunesmap' VALUES (3088, 1479, 1091, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11068, 20666, 14679, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8769, 11284, 2151, 10, 'Info Source: Steve Wyrick on Strathspey 2012-11-01');
INSERT INTO 'dancestunesmap' VALUES (1504, 5222, 692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1513, 5260, 242, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5138, 5552, 1211, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6308, 5552, 570, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9451, 14673, 13114, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3869, 5708, 1513, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7380, 11398, 1126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8773, 5952, 8457, 10, '"Official" tune in the Merse Collection');
INSERT INTO 'dancestunesmap' VALUES (6611, 9501, 7713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8342, 12805, 9944, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1980, 6972, 189, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6215, 5574, 1521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8523, 13582, 10655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7337, 11303, 8985, 10, '');
INSERT INTO 'dancestunesmap' VALUES (526, 1883, 1617, 11, '');
INSERT INTO 'dancestunesmap' VALUES (11070, 20668, 374, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1023, 3659, 50, 11, '');
INSERT INTO 'dancestunesmap' VALUES (11072, 20669, 14681, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11071, 20669, 14680, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7814, 12166, 3523, 10, '');
INSERT INTO 'dancestunesmap' VALUES (425, 1508, 267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3730, 2723, 3206, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9471, 16191, 5535, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11082, 20732, 7283, 10, 'Tune from Elizabeth Hunter''s S/S - Peter Elmes');
INSERT INTO 'dancestunesmap' VALUES (11074, 13286, 2262, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11075, 20705, 14703, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11076, 20705, 9855, 20, 'Alternative tune');
INSERT INTO 'dancestunesmap' VALUES (11077, 20706, 1691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11078, 20707, 1392, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11079, 20708, 14219, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11030, 20563, 14542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11092, 20740, 8238, 10, 'Tune from Bellstane - Marian Anderson');
INSERT INTO 'dancestunesmap' VALUES (10047, 5579, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11087, 20736, 13390, 10, 'Tune from Threave S/S - Scott Band');
INSERT INTO 'dancestunesmap' VALUES (11090, 20738, 1644, 10, 'Tune from The Bawk - David Cunningham');
INSERT INTO 'dancestunesmap' VALUES (11091, 20739, 13927, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11038, 20576, 14551, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11081, 20731, 9996, 10, 'Tune from Crawfords of Kerrera - Lothian');
INSERT INTO 'dancestunesmap' VALUES (11080, 20730, 6444, 10, 'Tune from Happy Returns - Olympians');
INSERT INTO 'dancestunesmap' VALUES (11015, 20553, 340, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11089, 20738, 765, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11095, 20743, 14708, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11097, 20747, 14710, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11098, 20748, 14711, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11099, 18204, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11012, 8864, 14527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1337, 4652, 1495, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11100, 9474, 8510, 10, 'Customary tune');
INSERT INTO 'dancestunesmap' VALUES (10272, 17121, 13926, 10, 'From the RSCDS publication');
INSERT INTO 'dancestunesmap' VALUES (11102, 20778, 8798, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11067, 19224, 11595, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8674, 14436, 12069, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5492, 6264, 656, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11101, 13132, 10007, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10697, 19785, 13450, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11094, 20742, 14707, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11093, 20741, 14706, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11096, 20746, 14709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9888, 17410, 1592, 10, 'Recorded on: DSMVF005 David South "Another Scottish Ramble"');
INSERT INTO 'dancestunesmap' VALUES (11052, 15418, 10859, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1178, 4102, 1059, 1, '');
INSERT INTO 'dancestunesmap' VALUES (8722, 4102, 9538, 2, '');
INSERT INTO 'dancestunesmap' VALUES (8723, 4102, 1705, 3, '');
INSERT INTO 'dancestunesmap' VALUES (11073, 20674, 14702, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5569, 7523, 3801, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6999, 10401, 377, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6998, 10401, 1457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11103, 20779, 7933, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8215, 1173, 10321, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11211, 7376, 14817, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11212, 7435, 442, 10, '');
INSERT INTO 'dancestunesmap' VALUES (628, 2323, 555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6786, 9733, 986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11226, 1831, 3702, 11, '');
INSERT INTO 'dancestunesmap' VALUES (8673, 14436, 12068, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10594, 19563, 2176, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6499, 9156, 3256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10771, 20049, 14280, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11104, 20797, 14247, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11106, 20799, 14736, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11107, 20800, 14737, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11108, 20801, 14246, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11110, 16007, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9262, 15733, 1537, 10, 'Suggested Music Jiggery Pokery recorded by Sandy Nixon on Repeat');
INSERT INTO 'dancestunesmap' VALUES (11111, 20808, 2489, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11109, 16008, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11213, 7500, 154, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11112, 20809, 747, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11114, 20811, 4578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11115, 20813, 14750, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11116, 20814, 2525, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11117, 20815, 699, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11118, 20816, 1939, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11113, 20810, 2106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7149, 10380, 267, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11119, 20820, 2012, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11121, 20822, 14751, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11125, 20826, 802, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11126, 20827, 2918, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11127, 20828, 4809, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11128, 20830, 2827, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11129, 20831, 4555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11130, 20832, 3515, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11131, 20833, 3484, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11132, 20834, 1942, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11133, 20835, 1462, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11134, 20836, 2806, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11135, 20837, 1050, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11136, 20838, 1410, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11120, 20821, 8447, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11138, 20840, 1136, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11139, 20841, 3111, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11140, 20843, 2755, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11141, 20844, 1858, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11143, 20846, 1644, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11144, 20847, 2817, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11145, 20848, 2449, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11146, 20849, 8448, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11183, 20907, 14764, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11124, 20825, 2561, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11214, 8217, 3860, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11122, 20823, 2711, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11147, 20850, 2094, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11148, 20851, 2757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11149, 20852, 1527, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11150, 20853, 2511, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11151, 20854, 971, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11152, 20855, 4240, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11153, 20856, 5713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11154, 20857, 895, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11155, 20858, 2593, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11156, 20859, 2300, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11142, 20845, 12755, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11157, 20625, 14752, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11158, 20625, 14753, 11, '');
INSERT INTO 'dancestunesmap' VALUES (11159, 20625, 14754, 12, '');
INSERT INTO 'dancestunesmap' VALUES (11160, 20873, 7216, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11164, 20880, 14756, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11167, 20883, 12546, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6926, 8925, 1099, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11034, 20571, 14547, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11198, 20915, 14782, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11170, 20885, 13002, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11168, 20884, 2050, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9053, 15277, 12699, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11172, 20887, 14758, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11166, 20882, 122, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11161, 20877, 2829, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11184, 20909, 14765, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8767, 14595, 4754, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11171, 20886, 5600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10198, 12186, 523, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11188, 20914, 14770, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11187, 20912, 14768, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11169, 20875, 14757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11173, 20875, 14759, 11, '2nd tune');
INSERT INTO 'dancestunesmap' VALUES (11177, 20902, 3846, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11176, 20901, 2115, 10, 'Alternative');
INSERT INTO 'dancestunesmap' VALUES (11175, 20901, 14763, 10, 'Preferred');
INSERT INTO 'dancestunesmap' VALUES (11179, 20904, 13333, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11178, 20903, 1600, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11162, 20878, 5837, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11163, 20879, 14755, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11189, 20916, 14771, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11193, 14994, 14775, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11215, 20991, 14826, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11192, 14994, 14774, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11191, 14994, 14773, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11220, 9368, 576, 11, '');
INSERT INTO 'dancestunesmap' VALUES (11216, 20993, 14827, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10944, 761, 11553, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11221, 9368, 2484, 12, '');
INSERT INTO 'dancestunesmap' VALUES (11199, 11839, 11532, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8853, 14796, 425, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11200, 10958, 9533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5822, 6903, 4655, 10, '');
INSERT INTO 'dancestunesmap' VALUES (252, 936, 303, 11, '');
INSERT INTO 'dancestunesmap' VALUES (11201, 20950, 16, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11202, 20950, 282, 11, '');
INSERT INTO 'dancestunesmap' VALUES (11203, 20959, 1772, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11105, 20798, 14735, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11186, 20911, 14767, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11204, 20864, 10736, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11180, 20908, 9119, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11182, 20913, 14769, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11181, 20913, 7191, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11205, 20960, 14815, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11206, 20961, 14816, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1619, 5637, 1063, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1620, 5637, 1670, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4326, 3998, 1818, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3535, 2328, 3797, 10, '');
INSERT INTO 'dancestunesmap' VALUES (926, 3402, 1624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11207, 14027, 11669, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11208, 4675, 11555, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4733, 4769, 849, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5674, 6596, 4611, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11209, 6596, 32, 11, '');
INSERT INTO 'dancestunesmap' VALUES (11210, 6596, 2847, 12, '');
INSERT INTO 'dancestunesmap' VALUES (9176, 14901, 4543, 10, 'played ABABB');
INSERT INTO 'dancestunesmap' VALUES (11223, 16147, 10821, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11217, 20994, 692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11194, 20918, 14776, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5108, 5475, 4444, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5532, 6326, 4578, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10735, 7077, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11218, 7504, 2558, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11219, 11805, 1372, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1448, 4995, 1116, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1557, 5422, 1494, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9512, 16277, 1424, 10, '');
INSERT INTO 'dancestunesmap' VALUES (9513, 16277, 1978, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10256, 18348, 1566, 11, '');
INSERT INTO 'dancestunesmap' VALUES (11224, 19380, 2779, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11137, 20839, 2761, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4509, 4348, 4216, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11225, 8407, 533, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8644, 12071, 778, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8645, 12071, 415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (530, 1903, 69, 11, '');
INSERT INTO 'dancestunesmap' VALUES (11227, 3411, 109, 11, '');
INSERT INTO 'dancestunesmap' VALUES (11228, 3411, 3014, 12, '');
INSERT INTO 'dancestunesmap' VALUES (2293, 5976, 3285, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2294, 5976, 3286, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11229, 7476, 1692, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11230, 7540, 1619, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11232, 8227, 1159, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11231, 17024, 9927, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11233, 3692, 11553, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1527, 5317, 816, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5297, 5890, 1624, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11234, 7428, 458, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11235, 7432, 180, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11197, 20921, 14779, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11185, 20910, 14766, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7949, 12863, 9894, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11165, 20881, 13593, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11222, 18555, 13944, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11174, 20900, 14762, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11123, 20824, 608, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11196, 20920, 14778, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11195, 20919, 14777, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11265, 21115, 14859, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8691, 14472, 12177, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11314, 21161, 14896, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11237, 20999, 14223, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11238, 21000, 14844, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5441, 6165, 4552, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4520, 4390, 1117, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4278, 3906, 2964, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11240, 21029, 10455, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11241, 21031, 8045, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11242, 21040, 8046, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11243, 21041, 8395, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11244, 21042, 8393, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11246, 21025, 1266, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11247, 21048, 9979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11249, 21055, 906, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11248, 21053, 8046, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11245, 21043, 2835, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11236, 20998, 10023, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1454, 5019, 1412, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6236, 4877, 3601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11250, 21092, 495, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8855, 14797, 12528, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11253, 8121, 11554, 11, '');
INSERT INTO 'dancestunesmap' VALUES (7460, 11608, 986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11254, 18248, 14855, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11252, 7460, 2988, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11251, 7460, 3635, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11255, 14792, 2992, 11, '');
INSERT INTO 'dancestunesmap' VALUES (9162, 15531, 7056, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1564, 5441, 1269, 11, '');
INSERT INTO 'dancestunesmap' VALUES (11256, 11980, 5105, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11257, 11722, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11258, 20703, 556, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11259, 170, 4126, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11315, 21170, 9665, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11260, 21111, 14856, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11261, 10476, 1662, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11262, 21116, 14861, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11266, 19835, 14860, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11274, 19637, 14868, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11276, 21124, 14870, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11278, 19049, 13877, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11282, 21131, 14877, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11291, 20665, 14884, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11294, 20773, 14887, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11299, 19638, 14891, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11300, 19640, 14892, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11272, 21122, 14866, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11273, 21122, 14867, 11, '');
INSERT INTO 'dancestunesmap' VALUES (11263, 21113, 14857, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4173, 3684, 649, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11316, 20562, 2308, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11285, 21132, 14878, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11268, 21118, 14704, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4337, 8103, 4093, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11333, 14155, 8420, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11317, 21186, 1282, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11301, 21141, 14893, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11318, 8689, 1072, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1294, 4499, 1174, 11, '');
INSERT INTO 'dancestunesmap' VALUES (1245, 4358, 337, 12, '');
INSERT INTO 'dancestunesmap' VALUES (11305, 21150, 9757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11298, 21140, 14890, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11303, 8241, 2995, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11286, 21133, 14879, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11296, 21139, 14543, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11307, 10872, 7666, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11308, 7464, 1933, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6331, 7373, 5290, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11309, 7352, 6401, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5989, 7233, 3086, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11290, 21136, 14883, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11320, 16597, 975, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11319, 16596, 1582, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11321, 16600, 599, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11292, 21137, 14885, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1760, 6098, 1612, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11239, 21001, 14845, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11322, 16600, 2012, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11323, 16603, 12642, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11302, 21142, 14894, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11297, 20929, 14889, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11324, 16611, 4022, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11267, 21117, 14862, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11325, 16612, 1445, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11279, 21126, 14872, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11326, 20064, 498, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11271, 21121, 14865, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11293, 19639, 14886, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11334, 12769, 3257, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11295, 21138, 14888, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11335, 14161, 38, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7478, 11635, 926, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5663, 6571, 1757, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11190, 20917, 14772, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11275, 21123, 14869, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8995, 15145, 139, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11328, 21195, 14809, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1063, 3762, 1065, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11264, 21114, 14858, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3157, 1614, 3660, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11311, 20734, 403, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11312, 11806, 601, 10, '');
INSERT INTO 'dancestunesmap' VALUES (6229, 3988, 274, 2, 'played AABAAB');
INSERT INTO 'dancestunesmap' VALUES (1111, 3888, 463, 11, '');
INSERT INTO 'dancestunesmap' VALUES (11281, 21128, 14874, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4251, 3837, 4067, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11329, 13, 14900, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11277, 21125, 14871, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11287, 21134, 14880, 10, '');
INSERT INTO 'dancestunesmap' VALUES (978, 3567, 457, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11269, 21119, 14863, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11330, 17266, 13853, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11284, 21130, 14876, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10475, 13637, 5709, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11283, 21129, 14875, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11270, 21120, 14864, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11280, 21127, 14873, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11313, 21158, 1373, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11310, 21153, 14895, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1965, 6902, 826, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1916, 6721, 1139, 11, '');
INSERT INTO 'dancestunesmap' VALUES (6090, 6479, 3121, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11306, 21151, 3713, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11304, 21149, 7803, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2842, 1000, 209, 10, '');
INSERT INTO 'dancestunesmap' VALUES (3786, 2839, 2806, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5270, 5837, 4497, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5749, 6740, 1322, 10, '');
INSERT INTO 'dancestunesmap' VALUES (852, 3119, 1044, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4698, 4722, 3148, 10, '');
INSERT INTO 'dancestunesmap' VALUES (4829, 4986, 1407, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10427, 19165, 1843, 10, '');
INSERT INTO 'dancestunesmap' VALUES (1654, 5730, 254, 2, '');
INSERT INTO 'dancestunesmap' VALUES (11331, 17534, 1915, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11336, 14161, 38, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11337, 21198, 691, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11338, 6312, 13467, 20, '');
INSERT INTO 'dancestunesmap' VALUES (11332, 16934, 992, 10, '');
INSERT INTO 'dancestunesmap' VALUES (10931, 3189, 2806, 11, 'Strathspey steps');
INSERT INTO 'dancestunesmap' VALUES (10932, 3189, 1435, 12, 'Reel step (as “O''er the Water to Charlie”)');
INSERT INTO 'dancestunesmap' VALUES (3610, 2487, 32, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5420, 6134, 62, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11339, 21214, 2323, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11341, 14665, 13156, 10, 'Now preferred');
INSERT INTO 'dancestunesmap' VALUES (61, 245, 58, 10, '');
INSERT INTO 'dancestunesmap' VALUES (7873, 12750, 481, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11342, 8138, 5779, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11345, 8749, 6914, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11343, 14665, 3050, 10, 'Original suggestion');
INSERT INTO 'dancestunesmap' VALUES (3406, 2094, 3521, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11344, 8749, 415, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11346, 21228, 14976, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11347, 21229, 14977, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11348, 21230, 14978, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11349, 21278, 1106, 10, '');
INSERT INTO 'dancestunesmap' VALUES (910, 3339, 227, 11, '');
INSERT INTO 'dancestunesmap' VALUES (11350, 1787, 10362, 2, '');
INSERT INTO 'dancestunesmap' VALUES (11351, 1787, 4350, 3, '');
INSERT INTO 'dancestunesmap' VALUES (11352, 1787, 1625, 4, '');
INSERT INTO 'dancestunesmap' VALUES (11353, 17261, 1747, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11354, 17261, 2761, 20, '');
INSERT INTO 'dancestunesmap' VALUES (11355, 21280, 1771, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11356, 21280, 275, 20, '');
INSERT INTO 'dancestunesmap' VALUES (11357, 21280, 12042, 30, '');
INSERT INTO 'dancestunesmap' VALUES (11358, 21280, 6606, 40, '');
INSERT INTO 'dancestunesmap' VALUES (11359, 21284, 5346, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11360, 21287, 1101, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11361, 21288, 2817, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11362, 21289, 4058, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11363, 21290, 816, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11364, 21290, 3013, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11365, 21290, 7787, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11366, 21294, 231, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11367, 5997, 1504, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11368, 21296, 14979, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11369, 21297, 6284, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11370, 20541, 9920, 10, 'Used in video');
INSERT INTO 'dancestunesmap' VALUES (3942, 3169, 182, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11371, 21191, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2580, 461, 3405, 10, '');
INSERT INTO 'dancestunesmap' VALUES (2186, 3114, 2632, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11372, 13149, 913, 20, 'deviser''s original suggestion');
INSERT INTO 'dancestunesmap' VALUES (3720, 2698, 3191, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11381, 21329, 3077, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11382, 21331, 14987, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11383, 21332, 14988, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11373, 21320, 12099, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11374, 21321, 14980, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11375, 21322, 14981, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11376, 21323, 14982, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11377, 21324, 10456, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11378, 21326, 14983, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11380, 21328, 14986, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11379, 21328, 2503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11385, 21334, 14989, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5940, 7140, 2383, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11386, 21335, 503, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11387, 2488, 3256, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11388, 2488, 5646, 10, '');
INSERT INTO 'dancestunesmap' VALUES (642, 2380, 1542, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11384, 21333, 11681, 10, '');
INSERT INTO 'dancestunesmap' VALUES (8681, 14429, 5956, 10, 'Jig');
INSERT INTO 'dancestunesmap' VALUES (8680, 14429, 2118, 10, 'Strathspey');
INSERT INTO 'dancestunesmap' VALUES (11288, 21135, 14881, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11289, 21135, 14882, 11, '');
INSERT INTO 'dancestunesmap' VALUES (537, 1927, 487, 10, '');
INSERT INTO 'dancestunesmap' VALUES (436, 1552, 74, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11389, 6286, 300, 10, '');
INSERT INTO 'dancestunesmap' VALUES (402, 1452, 1416, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11390, 1085, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (262, 977, 238, 10, '');
INSERT INTO 'dancestunesmap' VALUES (200, 767, 681, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11391, 21344, 11554, 10, '');
INSERT INTO 'dancestunesmap' VALUES (5003, 5295, 1261, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11393, 21350, 14997, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11394, 18264, 14998, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11395, 21349, 14999, 10, '');
INSERT INTO 'dancestunesmap' VALUES (11392, 9809, 1817, 10, '');


--
INSERT INTO 'dancetype' VALUES (1, 'Reel', 'R', 1, 1);
INSERT INTO 'dancetype' VALUES (2, 'Jig', 'J', 1, 1);
INSERT INTO 'dancetype' VALUES (3, 'Strathspey', 'S', 1, 1);
INSERT INTO 'dancetype' VALUES (4, 'Medley', 'M', 1, 1);
INSERT INTO 'dancetype' VALUES (5, 'Waltz', 'W', 1, 1);
INSERT INTO 'dancetype' VALUES (7, 'Step/Highland', 'h', 1, 1);
INSERT INTO 'dancetype' VALUES (10, 'Quadrille', 'Q', 1, 1);
INSERT INTO 'dancetype' VALUES (11, 'March', 'X', 1, 1);
INSERT INTO 'dancetype' VALUES (13, 'Polka', 'P', 1, 0);
INSERT INTO 'dancetype' VALUES (50, 'Other', '-', 1, 1);
INSERT INTO 'dancetype' VALUES (98, 'Listening', 'L', 1, 0);
INSERT INTO 'dancetype' VALUES (99, '(unknown)', '?', 1, 1);
INSERT INTO 'dancetype' VALUES (101, 'Jig (9/8)', 'j', 1, 1);
INSERT INTO 'dancetype' VALUES (6, 'Hornpipe (slow)', 'H', 1, 1);
INSERT INTO 'dancetype' VALUES (100, '3/4 time', '¾', 1, 1);
INSERT INTO 'dancetype' VALUES (102, 'Minuet', 'Min', 1, 1);


--
INSERT INTO 'danceurl' VALUES (3727, 'http://www.rscdsleeds.org.uk/dancecrib.asp?ID=52', 10, 93);
INSERT INTO 'danceurl' VALUES (3728, 'http://www.rscdsleeds.org.uk/dancecrib.asp?ID=59', 10, 107);
INSERT INTO 'danceurl' VALUES (3771, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#catch', 10, 1085);
INSERT INTO 'danceurl' VALUES (5283, 'https://my.strathspey.org/u/murrough/ChiswickJig.pdf', 10, 18246);
INSERT INTO 'danceurl' VALUES (5284, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxtaWR3ZXN0c2NvdHRpc2h3ZWVrZW5kfGd4OjZkZDdiODc5Mzg5YjRkYjU', 10, 18249);
INSERT INTO 'danceurl' VALUES (5285, 'https://my.strathspey.org/u/murrough/DanielAndRogersWedding.pdf', 10, 18250);
INSERT INTO 'danceurl' VALUES (3736, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#autumn', 10, 314);
INSERT INTO 'danceurl' VALUES (3759, 'http://www.rscds-sf.org/resources/dances/TripToParadise.html', 10, 802);
INSERT INTO 'danceurl' VALUES (4687, 'http://www.bstk.hu/rolling', 10, 14477);
INSERT INTO 'danceurl' VALUES (3781, 'http://www.scottishdance.net/ceilidh/dances.html#DashingWhite', 10, 1562);
INSERT INTO 'danceurl' VALUES (5157, 'https://dublinscdclub.files.wordpress.com/2017/03/lady-ryder-of-warsaw2.pdf', 10, 12074);
INSERT INTO 'danceurl' VALUES (5286, 'https://docs.wixstatic.com/ugd/613b84_e1f43016c2c14037bd706787c6e8ef91.pdf', 10, 14903);
INSERT INTO 'danceurl' VALUES (4240, 'http://www.scottishdance.net/dances/TheHappierMeeting.html', 10, 10393);
INSERT INTO 'danceurl' VALUES (4241, 'http://www.scottishdance.net/dances/SkyeBarbecue.html', 10, 10395);
INSERT INTO 'danceurl' VALUES (4242, 'http://www.scottishdance.net/dances/ThePalindrome.html', 10, 10396);
INSERT INTO 'danceurl' VALUES (4686, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#auckland', 10, 3588);
INSERT INTO 'danceurl' VALUES (3753, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#wig', 10, 650);
INSERT INTO 'danceurl' VALUES (4688, 'http://www.gordulotanc.hu/', 10, 14477);
INSERT INTO 'danceurl' VALUES (3789, 'http://moirastacey.wordpress.com/2-the-white-rose-and-the-yellow-waistcoat/', 10, 1784);
INSERT INTO 'danceurl' VALUES (3729, 'http://eddywest.nz/ancailind.html', 10, 128);
INSERT INTO 'danceurl' VALUES (3738, 'http://eddywest.nz/Awatiroj2.html', 10, 325);
INSERT INTO 'danceurl' VALUES (3741, 'http://eddywest.nz/Banksa.html', 10, 390);
INSERT INTO 'danceurl' VALUES (3773, 'http://eddywest.nz/Claresw.html', 10, 1225);
INSERT INTO 'danceurl' VALUES (3779, 'http://eddywest.nz/Dancefe.html', 10, 1518);
INSERT INTO 'danceurl' VALUES (3780, 'http://eddywest.nz/Dancingitd.html', 10, 1541);
INSERT INTO 'danceurl' VALUES (4698, 'http://eddywest.nz/barrysd.html', 10, 14486);
INSERT INTO 'danceurl' VALUES (4699, 'http://eddywest.nz/Avis.html', 10, 14485);
INSERT INTO 'danceurl' VALUES (5288, 'https://tunes.e-cribs.org/Many_Happy_Hours.pdf', 10, 13898);
INSERT INTO 'danceurl' VALUES (4683, 'http://www.strathspey.org/lists/strathspey%40strathspey.org/m/56073/', 10, 14403);
INSERT INTO 'danceurl' VALUES (3754, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/stronshiray.pdf', 10, 674);
INSERT INTO 'danceurl' VALUES (3755, 'https://www.rscdslondon.org.uk/sdata/dances/bonspiel/bonspiel.pdf', 10, 686);
INSERT INTO 'danceurl' VALUES (3756, 'https://www.rscdslondon.org.uk/sdata/dances/green_lochan/reivers.pdf', 10, 705);
INSERT INTO 'danceurl' VALUES (3757, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/brian.pdf', 10, 784);
INSERT INTO 'danceurl' VALUES (3758, 'https://www.rscdslondon.org.uk/sdata/dances/bonspiel/brier.pdf', 10, 800);
INSERT INTO 'danceurl' VALUES (3760, 'https://www.rscdslondon.org.uk/sdata/dances/bonspiel/bruce.pdf', 10, 843);
INSERT INTO 'danceurl' VALUES (3761, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/cairnsmore.pdf', 10, 924);
INSERT INTO 'danceurl' VALUES (3762, 'https://www.rscdslondon.org.uk/sdata/dances/bonspiel/caledon.pdf', 10, 932);
INSERT INTO 'danceurl' VALUES (3763, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/caledonian.pdf', 10, 937);
INSERT INTO 'danceurl' VALUES (3764, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/herrin.pdf', 10, 950);
INSERT INTO 'danceurl' VALUES (3765, 'https://www.rscdslondon.org.uk/sdata/dances/bonspiel/duntroon.pdf', 10, 975);
INSERT INTO 'danceurl' VALUES (3766, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/campsie.pdf', 10, 986);
INSERT INTO 'danceurl' VALUES (3767, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/capstan.pdf', 10, 1004);
INSERT INTO 'danceurl' VALUES (3768, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/henderson.pdf', 10, 1013);
INSERT INTO 'danceurl' VALUES (3769, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/captain.pdf', 10, 1027);
INSERT INTO 'danceurl' VALUES (3770, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/castles.pdf', 10, 1077);
INSERT INTO 'danceurl' VALUES (3772, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/christina.pdf', 10, 1195);
INSERT INTO 'danceurl' VALUES (3775, 'https://www.rscdslondon.org.uk/sdata/dances/bonspiel/craigellachie.pdf', 10, 1389);
INSERT INTO 'danceurl' VALUES (3776, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/creel.pdf', 10, 1413);
INSERT INTO 'danceurl' VALUES (3777, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/crossmichael.pdf', 10, 1447);
INSERT INTO 'danceurl' VALUES (3778, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/cutty.pdf', 10, 1488);
INSERT INTO 'danceurl' VALUES (3782, 'https://www.rscdslondon.org.uk/sdata/dances/green_lochan/davy_glen.pdf', 10, 1577);
INSERT INTO 'danceurl' VALUES (3783, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/davy.pdf', 10, 1578);
INSERT INTO 'danceurl' VALUES (3784, 'https://www.rscdslondon.org.uk/sdata/dances/farewell/gladys.pdf', 10, 1595);
INSERT INTO 'danceurl' VALUES (3786, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/drambuie.pdf', 10, 1747);
INSERT INTO 'danceurl' VALUES (3787, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/sword.pdf', 10, 1751);
INSERT INTO 'danceurl' VALUES (3791, 'https://www.rscdslondon.org.uk/sdata/dances/bonspiel/dunbar.pdf', 10, 1811);
INSERT INTO 'danceurl' VALUES (3793, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/duncan.pdf', 10, 1823);
INSERT INTO 'danceurl' VALUES (3794, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/dundrennan.pdf', 10, 1840);
INSERT INTO 'danceurl' VALUES (3731, 'https://dances.e-cribs.org/Ann_Skipper_s_Reel.pdf', 10, 157);
INSERT INTO 'danceurl' VALUES (3774, 'https://dances.e-cribs.org/Nancy_Holland_s_Strathspey.pdf', 10, 1255);
INSERT INTO 'danceurl' VALUES (4243, 'https://rscds-twincities.org/dance/andrews-excel-reel/', 10, 10407);
INSERT INTO 'danceurl' VALUES (3752, 'https://rscds-twincities.org/dance/bonnie-charlie/', 10, 644);
INSERT INTO 'danceurl' VALUES (3723, 'https://rscds-twincities.org/dance/absence-of-forethought/', 10, 16);
INSERT INTO 'danceurl' VALUES (3798, 'http://www.scottishdance.net/ceilidh/dances.html#Eightsome', 10, 1931);
INSERT INTO 'danceurl' VALUES (3802, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#ferla', 10, 2125);
INSERT INTO 'danceurl' VALUES (3814, 'http://www.scottishdance.net/dances/TheGeeseInTheBog.html', 10, 2423);
INSERT INTO 'danceurl' VALUES (3808, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#flying', 10, 2260);
INSERT INTO 'danceurl' VALUES (3803, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#gardens', 10, 2168);
INSERT INTO 'danceurl' VALUES (4248, 'http://www.rscds-twincities.org/dances/squashed.html', 10, 10423);
INSERT INTO 'danceurl' VALUES (4249, 'http://www.rscds-twincities.org/dances/tcfarewell.html', 10, 10424);
INSERT INTO 'danceurl' VALUES (4250, 'http://scottishweekend.org/dances/HaggartysBrig.PDF', 10, 10458);
INSERT INTO 'danceurl' VALUES (4251, 'http://scottishweekend.org/dances/TheFalkirkLass.PDF', 10, 10459);
INSERT INTO 'danceurl' VALUES (4252, 'http://www.rscds-sf.org/resources/dances/FoxInTheWood.htm', 10, 10460);
INSERT INTO 'danceurl' VALUES (3825, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#grant', 10, 2645);
INSERT INTO 'danceurl' VALUES (3841, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#fair', 10, 2910);
INSERT INTO 'danceurl' VALUES (3842, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#rambler', 10, 2924);
INSERT INTO 'danceurl' VALUES (3800, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#donald', 10, 2030);
INSERT INTO 'danceurl' VALUES (3846, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#hooper', 10, 2979);
INSERT INTO 'danceurl' VALUES (3879, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#glasgow', 10, 3607);
INSERT INTO 'danceurl' VALUES (4700, 'http://eddywest.nz/Celticsq.html', 10, 14487);
INSERT INTO 'danceurl' VALUES (4254, 'http://macrudi.de/resources/dances/mugtea.pdf', 10, 10492);
INSERT INTO 'danceurl' VALUES (4255, 'http://www.macrudi.de/resources/dances/smoker.pdf', 10, 10493);
INSERT INTO 'danceurl' VALUES (5332, 'https://tunes.e-cribs.org/Strathspey_Decadence.pdf', 10, 14524);
INSERT INTO 'danceurl' VALUES (5331, 'http://www.strathspey.org/libDances/sspbook.pdf', 10, 14525);
INSERT INTO 'danceurl' VALUES (4689, 'http://www.bstk.hu/dances/30-isnae-enaw/', 10, 14478);
INSERT INTO 'danceurl' VALUES (5329, 'https://tunes.e-cribs.org/To_have_and_to_hold.pdf', 10, 13928);
INSERT INTO 'danceurl' VALUES (5333, 'https://tunes.e-cribs.org/Stalking_a_Pidgeon.pdf', 10, 18007);
INSERT INTO 'danceurl' VALUES (3854, 'http://www.anselms.net/SCD/dances/jacks-delight.pdf', 10, 3180);
INSERT INTO 'danceurl' VALUES (3796, 'https://www.rscdslondon.org.uk/sdata/dances/green_lochan/ebba.pdf', 10, 1901);
INSERT INTO 'danceurl' VALUES (3799, 'https://www.rscdslondon.org.uk/sdata/dances/farewell/expert.pdf', 10, 2021);
INSERT INTO 'danceurl' VALUES (3804, 'https://www.rscdslondon.org.uk/sdata/dances/fettle.pdf', 10, 2171);
INSERT INTO 'danceurl' VALUES (3807, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/Flitting_orig.pdf', 10, 2232);
INSERT INTO 'danceurl' VALUES (3809, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/gold.pdf', 10, 2276);
INSERT INTO 'danceurl' VALUES (3810, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/fortnight.pdf', 10, 2300);
INSERT INTO 'danceurl' VALUES (3811, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/fountain.pdf', 10, 2305);
INSERT INTO 'danceurl' VALUES (3812, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/weaver.pdf', 10, 2383);
INSERT INTO 'danceurl' VALUES (3813, 'https://www.rscdslondon.org.uk/sdata/dances/green_lochan/gavin.pdf', 10, 2421);
INSERT INTO 'danceurl' VALUES (3815, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/ritchie.pdf', 10, 2427);
INSERT INTO 'danceurl' VALUES (3817, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/gladstone.pdf', 10, 2485);
INSERT INTO 'danceurl' VALUES (3818, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/glasgow.pdf', 10, 2492);
INSERT INTO 'danceurl' VALUES (3819, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/glenfiddich.pdf', 10, 2534);
INSERT INTO 'danceurl' VALUES (3820, 'https://www.rscdslondon.org.uk/sdata/dances/green_lochan/glenfinnan.pdf', 10, 2536);
INSERT INTO 'danceurl' VALUES (3821, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/glengrant.pdf', 10, 2544);
INSERT INTO 'danceurl' VALUES (3829, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/gushet.pdf', 10, 2707);
INSERT INTO 'danceurl' VALUES (3828, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/guid.pdf', 10, 2698);
INSERT INTO 'danceurl' VALUES (3826, 'https://www.rscdslondon.org.uk/sdata/dances/green_lochan/lochan.pdf', 10, 2664);
INSERT INTO 'danceurl' VALUES (3824, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/ring.pdf', 10, 2595);
INSERT INTO 'danceurl' VALUES (3823, 'https://www.rscdslondon.org.uk/sdata/dances/green_lochan/glenmore.pdf', 10, 2557);
INSERT INTO 'danceurl' VALUES (3822, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/glenlochar.pdf', 10, 2552);
INSERT INTO 'danceurl' VALUES (3848, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/hunters_run.pdf', 10, 3025);
INSERT INTO 'danceurl' VALUES (3847, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/hunter.pdf', 10, 3019);
INSERT INTO 'danceurl' VALUES (3840, 'https://www.rscdslondon.org.uk/sdata/dances/farewell/bridge.pdf', 10, 2896);
INSERT INTO 'danceurl' VALUES (3839, 'https://www.rscdslondon.org.uk/sdata/dances/farewell/kiwi.pdf', 10, 2890);
INSERT INTO 'danceurl' VALUES (3838, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/cope.pdf', 10, 2887);
INSERT INTO 'danceurl' VALUES (3837, 'https://www.rscdslondon.org.uk/sdata/dances/bonspiel/erroll.pdf', 10, 2851);
INSERT INTO 'danceurl' VALUES (3836, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/alma.pdf', 10, 2849);
INSERT INTO 'danceurl' VALUES (3835, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/danced.pdf', 10, 2826);
INSERT INTO 'danceurl' VALUES (3834, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/harvest.pdf', 10, 2806);
INSERT INTO 'danceurl' VALUES (3833, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/hand.pdf', 10, 2757);
INSERT INTO 'danceurl' VALUES (3832, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/hamish.pdf', 10, 2752);
INSERT INTO 'danceurl' VALUES (3830, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/half.pdf', 10, 2727);
INSERT INTO 'danceurl' VALUES (3851, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/inver.pdf', 10, 3101);
INSERT INTO 'danceurl' VALUES (3850, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/gaul.pdf', 10, 3080);
INSERT INTO 'danceurl' VALUES (3849, 'https://www.rscdslondon.org.uk/sdata/dances/powrie_ian.pdf', 10, 3057);
INSERT INTO 'danceurl' VALUES (3855, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/jamie.pdf', 10, 3196);
INSERT INTO 'danceurl' VALUES (3858, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/charlie.pdf', 10, 3266);
INSERT INTO 'danceurl' VALUES (3859, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/jimmy.pdf', 10, 3282);
INSERT INTO 'danceurl' VALUES (3860, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/jindalee.pdf', 10, 3285);
INSERT INTO 'danceurl' VALUES (3861, 'https://www.rscdslondon.org.uk/sdata/dances/bonspiel/jitney.pdf', 10, 3291);
INSERT INTO 'danceurl' VALUES (4245, 'https://rscds-twincities.org/dance/emilys-reel/', 10, 10412);
INSERT INTO 'danceurl' VALUES (4244, 'https://rscds-twincities.org/dance/the-baban/', 10, 10408);
INSERT INTO 'danceurl' VALUES (4247, 'https://rscds-twincities.org/dance/the-midnight-cats/', 10, 10417);
INSERT INTO 'danceurl' VALUES (4246, 'https://rscds-twincities.org/dance/the-garland/', 10, 10414);
INSERT INTO 'danceurl' VALUES (3797, 'http://scottishweekend.org/dances/LairdDance.pdf', 10, 1914);
INSERT INTO 'danceurl' VALUES (3869, 'https://suepetyt.e-cribs.org/Kate''s_Travels.pdf', 10, 3403);
INSERT INTO 'danceurl' VALUES (3792, 'http://suepetyt.e-cribs.org/Dunblane_Holiday.pdf', 10, 1814);
INSERT INTO 'danceurl' VALUES (3805, 'http://suepetyt.e-cribs.org/Fishermans_Reel.pdf', 10, 2203);
INSERT INTO 'danceurl' VALUES (3870, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#kelso', 10, 3424);
INSERT INTO 'danceurl' VALUES (3867, 'http://www.rscdsleeds.org.uk/dancecrib.asp?ID=1317', 10, 3326);
INSERT INTO 'danceurl' VALUES (3889, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#airy', 10, 3802);
INSERT INTO 'danceurl' VALUES (3865, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#mcalpin', 10, 3323);
INSERT INTO 'danceurl' VALUES (3877, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#fancy', 10, 3580);
INSERT INTO 'danceurl' VALUES (3890, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#light', 10, 3803);
INSERT INTO 'danceurl' VALUES (3881, 'http://www.rscdsleeds.org.uk/dancecrib.asp?ID=1428', 10, 3659);
INSERT INTO 'danceurl' VALUES (3845, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#honeymoon', 10, 2972);
INSERT INTO 'danceurl' VALUES (3862, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#gatlinburg', 10, 3300);
INSERT INTO 'danceurl' VALUES (4267, 'http://perso.wanadoo.fr/scots.in.france/dancesb.htm', 10, 10574);
INSERT INTO 'danceurl' VALUES (4268, 'http://www.rscds-sf.org/resources/dances/AustralianLaddie.htm', 10, 10580);
INSERT INTO 'danceurl' VALUES (4269, 'http://www.rscds-sf.org/resources/dances/GoldenGatewayReel.htm', 10, 10672);
INSERT INTO 'danceurl' VALUES (4705, 'http://www.users.on.net/~anguka/mairi.pdf', 10, 9911);
INSERT INTO 'danceurl' VALUES (4706, 'http://www.thesundayclass.org.uk/TRIBUTE%20TO%20AMANDA.html', 10, 14541);
INSERT INTO 'danceurl' VALUES (4707, 'http://www.rscdslondon.org.uk/080130Reel263.pdf', 10, 13618);
INSERT INTO 'danceurl' VALUES (4708, 'http://www.thesundayclass.org.uk/SIX%20MILE%20ROAD%20FROM%20PITLOCHRY.html', 10, 14545);
INSERT INTO 'danceurl' VALUES (3925, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#montgomery', 10, 4641);
INSERT INTO 'danceurl' VALUES (3913, 'http://www.scottishdance.net/dances/TheMillOfTowie.html', 10, 4388);
INSERT INTO 'danceurl' VALUES (4690, 'http://www.bstk.hu/book/', 10, 14479);
INSERT INTO 'danceurl' VALUES (5291, 'https://tunes.e-cribs.org/Mountain_Air.pdf', 10, 13899);
INSERT INTO 'danceurl' VALUES (5292, 'https://tunes.e-cribs.org/The_Faerie_Garden.pdf', 10, 13900);
INSERT INTO 'danceurl' VALUES (5293, 'https://tunes.e-cribs.org/Green_Meadows.pdf', 10, 13901);
INSERT INTO 'danceurl' VALUES (5276, 'http://www.scotchmist.ca/', 10, 17885);
INSERT INTO 'danceurl' VALUES (5294, 'https://tunes.e-cribs.org/Helen_Brown_of_Dunnington.pdf', 10, 13902);
INSERT INTO 'danceurl' VALUES (5295, 'https://tunes.e-cribs.org/Echoes_of_Strathglass.pdf', 10, 13903);
INSERT INTO 'danceurl' VALUES (5296, 'https://tunes.e-cribs.org/The_Elegant_Gentleman.pdf', 10, 13904);
INSERT INTO 'danceurl' VALUES (4258, 'http://macrudi.de/resources/dances/diarose.pdf', 10, 10498);
INSERT INTO 'danceurl' VALUES (4265, 'https://dances.e-cribs.org/The_Ring_Dance.pdf', 10, 10553);
INSERT INTO 'danceurl' VALUES (4703, 'https://sites.google.com/site/thefollyofrogues/cusrc-reelwiki/mairis-hangover', 10, 14528);
INSERT INTO 'danceurl' VALUES (4702, 'https://suedan.com/dances/instructions/custombuilder.html', 10, 14519);
INSERT INTO 'danceurl' VALUES (4259, 'http://www.macrudi.de/resources/dances/palindrome.pdf', 10, 10499);
INSERT INTO 'danceurl' VALUES (4257, 'https://www.anselms.net/pdf/scd-books/wbook.pdf', 10, 10496);
INSERT INTO 'danceurl' VALUES (5312, 'http://www.scotchmist.ca/', 10, 13847);
INSERT INTO 'danceurl' VALUES (3924, 'https://www.rscdslondon.org.uk/sdata/dances/hidden.pdf', 10, 4621);
INSERT INTO 'danceurl' VALUES (3864, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/grumlie.pdf', 10, 3320);
INSERT INTO 'danceurl' VALUES (3872, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/killiecrankie.pdf', 10, 3465);
INSERT INTO 'danceurl' VALUES (3873, 'https://www.rscdslondon.org.uk/sdata/dances/farewell/kilrymont.pdf', 10, 3472);
INSERT INTO 'danceurl' VALUES (3874, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/kinfauns.pdf', 10, 3485);
INSERT INTO 'danceurl' VALUES (3875, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/kirrie.pdf', 10, 3521);
INSERT INTO 'danceurl' VALUES (3880, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/laird.pdf', 10, 3653);
INSERT INTO 'danceurl' VALUES (3882, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/lake.pdf', 10, 3666);
INSERT INTO 'danceurl' VALUES (3884, 'https://www.rscdslondon.org.uk/sdata/dances/green_lochan/lanimer.pdf', 10, 3703);
INSERT INTO 'danceurl' VALUES (3885, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/leslie.pdf', 10, 3781);
INSERT INTO 'danceurl' VALUES (3886, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/medowie.pdf', 10, 3784);
INSERT INTO 'danceurl' VALUES (3888, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/shortland.pdf', 10, 3798);
INSERT INTO 'danceurl' VALUES (3891, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/lily.pdf', 10, 3813);
INSERT INTO 'danceurl' VALUES (3892, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/links.pdf', 10, 3828);
INSERT INTO 'danceurl' VALUES (3893, 'https://www.rscdslondon.org.uk/sdata/dances/lions.pdf', 10, 3837);
INSERT INTO 'danceurl' VALUES (3894, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/larrikin.pdf', 10, 3842);
INSERT INTO 'danceurl' VALUES (3895, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/doon.pdf', 10, 3857);
INSERT INTO 'danceurl' VALUES (3897, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/lochskerrow.pdf', 10, 3894);
INSERT INTO 'danceurl' VALUES (3898, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/london.pdf', 10, 3909);
INSERT INTO 'danceurl' VALUES (3900, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/malcolm.pdf', 10, 3943);
INSERT INTO 'danceurl' VALUES (3901, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/lovat.pdf', 10, 3968);
INSERT INTO 'danceurl' VALUES (3903, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/luckenbooth.pdf', 10, 3980);
INSERT INTO 'danceurl' VALUES (3904, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/macdonald.pdf', 10, 4015);
INSERT INTO 'danceurl' VALUES (3905, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/macfarlane.pdf', 10, 4024);
INSERT INTO 'danceurl' VALUES (3907, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/mackay.pdf', 10, 4033);
INSERT INTO 'danceurl' VALUES (3908, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/maclauclane.pdf', 10, 4042);
INSERT INTO 'danceurl' VALUES (3910, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/huntly.pdf', 10, 4192);
INSERT INTO 'danceurl' VALUES (3911, 'https://www.rscdslondon.org.uk/sdata/dances/farewell/maskelia.pdf', 10, 4225);
INSERT INTO 'danceurl' VALUES (3912, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/mattara.pdf', 10, 4231);
INSERT INTO 'danceurl' VALUES (3915, 'https://www.rscdslondon.org.uk/sdata/dances/bonspiel/donaldson.pdf', 10, 4427);
INSERT INTO 'danceurl' VALUES (3916, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/betsy.pdf', 10, 4432);
INSERT INTO 'danceurl' VALUES (3917, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/stewart.pdf', 10, 4445);
INSERT INTO 'danceurl' VALUES (3918, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/fleming.pdf', 10, 4475);
INSERT INTO 'danceurl' VALUES (3919, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/elchies.pdf', 10, 4489);
INSERT INTO 'danceurl' VALUES (3920, 'https://www.rscdslondon.org.uk/sdata/dances/farewell/johnstone.pdf', 10, 4521);
INSERT INTO 'danceurl' VALUES (3921, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/stewart.pdf', 10, 4585);
INSERT INTO 'danceurl' VALUES (3922, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/taylor.pdf', 10, 4590);
INSERT INTO 'danceurl' VALUES (3923, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/watt.pdf', 10, 4594);
INSERT INTO 'danceurl' VALUES (3896, 'https://dances.e-cribs.org/The_Loch_Michigan_Rant.pdf', 10, 3866);
INSERT INTO 'danceurl' VALUES (3856, 'https://suepetyt.e-cribs.org/Jane''s_Jig.pdf', 10, 3201);
INSERT INTO 'danceurl' VALUES (3945, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#speyside', 10, 5034);
INSERT INTO 'danceurl' VALUES (5297, 'http://nebula.wsimg.com/208cb47e219c2e800b6d22d2c1f8bdf2?AccessKeyId=B5EA6191A964E4BCD983&disposition=0&alloworigin=1', 10, 10653);
INSERT INTO 'danceurl' VALUES (3934, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#stewart', 10, 4805);
INSERT INTO 'danceurl' VALUES (3929, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#coalsons', 10, 4727);
INSERT INTO 'danceurl' VALUES (3947, 'http://www.scottishdance.net/dances/TheOneOClockCanon.html', 10, 5093);
INSERT INTO 'danceurl' VALUES (5334, 'https://tunes.e-cribs.org/A_Short_Visit.pdf', 10, 18009);
INSERT INTO 'danceurl' VALUES (3959, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#round', 10, 5713);
INSERT INTO 'danceurl' VALUES (3951, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#rakes', 10, 5462);
INSERT INTO 'danceurl' VALUES (3899, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#elgin', 10, 3932);
INSERT INTO 'danceurl' VALUES (3953, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#royal', 10, 5529);
INSERT INTO 'danceurl' VALUES (4709, 'http://www.thesundayclass.org.uk/ANNE%20DUCHESS%20OF%20WALTHAM.html', 10, 14546);
INSERT INTO 'danceurl' VALUES (3986, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#assembly', 10, 6380);
INSERT INTO 'danceurl' VALUES (3965, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#sandy', 10, 5889);
INSERT INTO 'danceurl' VALUES (5418, 'https://dances.e-cribs.org/Nymphaea_Caerulea.pdf', 10, 18386);
INSERT INTO 'danceurl' VALUES (3967, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#seann', 10, 5982);
INSERT INTO 'danceurl' VALUES (3975, 'http://moirastacey.wordpress.com/17-slainte-mhor/', 10, 6148);
INSERT INTO 'danceurl' VALUES (3978, 'http://moirastacey.wordpress.com/10-the-sound-of-cara/', 10, 6204);
INSERT INTO 'danceurl' VALUES (5424, 'https://my.strathspey.org/u/murrough/LukesLifeInLondon.pdf', 10, 18393);
INSERT INTO 'danceurl' VALUES (5427, 'https://drive.google.com/file/d/0B9R_Fl585MrbamcwbXNpTC0zbWc/view', 10, 15304);
INSERT INTO 'danceurl' VALUES (3976, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#sleepy', 10, 6152);
INSERT INTO 'danceurl' VALUES (4278, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#glenlivet', 10, 10923);
INSERT INTO 'danceurl' VALUES (3957, 'http://eddywest.nz/Rosetb.html', 10, 5673);
INSERT INTO 'danceurl' VALUES (3961, 'http://eddywest.nz/Staidansoh.html', 10, 5797);
INSERT INTO 'danceurl' VALUES (4691, 'http://www.bstk.hu/book/', 10, 14480);
INSERT INTO 'danceurl' VALUES (5428, 'https://drive.google.com/file/d/0B9R_Fl585MrbY1pfcFRlOWE1b3c/view', 12, 14363);
INSERT INTO 'danceurl' VALUES (4276, 'https://suedan.com/dances/instructions/ladies.html', 10, 10900);
INSERT INTO 'danceurl' VALUES (3991, 'https://dances.e-cribs.org/The_Silver_Square.pdf', 10, 6490);
INSERT INTO 'danceurl' VALUES (3964, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#saint', 10, 5829);
INSERT INTO 'danceurl' VALUES (4046, 'http://www.scottishdance.net/dances/ThePresidentsDilemma.html', 10, 8097);
INSERT INTO 'danceurl' VALUES (5298, 'http://nebula.wsimg.com/4c00da0f201d1fcff2cb01813901c86d?AccessKeyId=B5EA6191A964E4BCD983&disposition=0&alloworigin=1', 10, 18121);
INSERT INTO 'danceurl' VALUES (3927, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/moon.pdf', 10, 4650);
INSERT INTO 'danceurl' VALUES (3928, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/laing.pdf', 10, 4701);
INSERT INTO 'danceurl' VALUES (3931, 'https://www.rscdslondon.org.uk/sdata/dances/powrie_mrs.pdf', 10, 4768);
INSERT INTO 'danceurl' VALUES (3937, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/hoose.pdf', 10, 4848);
INSERT INTO 'danceurl' VALUES (3938, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/Heather_orig.pdf', 10, 4858);
INSERT INTO 'danceurl' VALUES (3939, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/mither.pdf', 10, 4863);
INSERT INTO 'danceurl' VALUES (3941, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/nancy.pdf', 10, 4882);
INSERT INTO 'danceurl' VALUES (3942, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/newcastle.pdf', 10, 4941);
INSERT INTO 'danceurl' VALUES (3944, 'https://www.rscdslondon.org.uk/sdata/dances/farewell/northern.pdf', 10, 4991);
INSERT INTO 'danceurl' VALUES (3946, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/wings.pdf', 10, 5083);
INSERT INTO 'danceurl' VALUES (3949, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/polharrow.pdf', 10, 5308);
INSERT INTO 'danceurl' VALUES (3954, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/riggs.pdf', 10, 5576);
INSERT INTO 'danceurl' VALUES (3955, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/jelly.pdf', 10, 5621);
INSERT INTO 'danceurl' VALUES (3956, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/rogue.pdf', 10, 5647);
INSERT INTO 'danceurl' VALUES (3958, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/rose.pdf', 10, 5674);
INSERT INTO 'danceurl' VALUES (3966, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/seahorse.pdf', 10, 5978);
INSERT INTO 'danceurl' VALUES (3968, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/shake.pdf', 10, 6017);
INSERT INTO 'danceurl' VALUES (3969, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/fair.pdf', 10, 6028);
INSERT INTO 'danceurl' VALUES (3970, 'https://www.rscdslondon.org.uk/sdata/dances/farewell/shetland.pdf', 10, 6044);
INSERT INTO 'danceurl' VALUES (3973, 'https://www.rscdslondon.org.uk/sdata/dances/farewell/baird.pdf', 10, 6112);
INSERT INTO 'danceurl' VALUES (3977, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/somebody.pdf', 10, 6188);
INSERT INTO 'danceurl' VALUES (3979, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/spey.pdf', 10, 6236);
INSERT INTO 'danceurl' VALUES (3980, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/speyside.pdf', 10, 6239);
INSERT INTO 'danceurl' VALUES (3981, 'https://www.rscdslondon.org.uk/sdata/dances/bonspiel/spruce.pdf', 10, 6263);
INSERT INTO 'danceurl' VALUES (3962, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/flag.pdf', 10, 5803);
INSERT INTO 'danceurl' VALUES (3982, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/stobhall.pdf', 10, 6316);
INSERT INTO 'danceurl' VALUES (3984, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/stroangassel.pdf', 10, 6360);
INSERT INTO 'danceurl' VALUES (3987, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/kilt.pdf', 10, 6424);
INSERT INTO 'danceurl' VALUES (3988, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/tamworth.pdf', 10, 6455);
INSERT INTO 'danceurl' VALUES (3989, 'https://www.rscdslondon.org.uk/sdata/dances/green_lochan/tapsalteerie.pdf', 10, 6464);
INSERT INTO 'danceurl' VALUES (3990, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/tartan.pdf', 10, 6482);
INSERT INTO 'danceurl' VALUES (3992, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/thorntonian.pdf', 10, 6558);
INSERT INTO 'danceurl' VALUES (3995, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/thrums.pdf', 10, 6592);
INSERT INTO 'danceurl' VALUES (3996, 'https://www.rscdslondon.org.uk/sdata/dances/farewell/traveller.pdf', 10, 6679);
INSERT INTO 'danceurl' VALUES (3998, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/vineyards.pdf', 10, 6738);
INSERT INTO 'danceurl' VALUES (3999, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/turtle.pdf', 10, 6781);
INSERT INTO 'danceurl' VALUES (4000, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/cats.pdf', 10, 6818);
INSERT INTO 'danceurl' VALUES (4001, 'https://www.rscdslondon.org.uk/sdata/dances/green_lochan/bairns.pdf', 10, 6901);
INSERT INTO 'danceurl' VALUES (4003, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/waterfall.pdf', 10, 6947);
INSERT INTO 'danceurl' VALUES (3935, 'https://rscds-twincities.org/dance/kettle-river/', 10, 4819);
INSERT INTO 'danceurl' VALUES (3972, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#tassie', 20, 6091);
INSERT INTO 'danceurl' VALUES (3930, 'https://suepetyt.e-cribs.org/Mrs_Bunty_Somes.pdf', 10, 4741);
INSERT INTO 'danceurl' VALUES (4274, 'https://suepetyt.e-cribs.org/Amber''s_Reel.pdf', 10, 10823);
INSERT INTO 'danceurl' VALUES (4273, 'https://suepetyt.e-cribs.org/Ian_and_Joan_McKenzie''s_Strathspey.pdf', 10, 10822);
INSERT INTO 'danceurl' VALUES (4272, 'https://suepetyt.e-cribs.org/Lady_Nelthorpe.pdf', 10, 10821);
INSERT INTO 'danceurl' VALUES (3932, 'http://suepetyt.e-cribs.org/Mrs_Leeman_Dances.pdf', 10, 4774);
INSERT INTO 'danceurl' VALUES (5299, 'http://nebula.wsimg.com/9df93dc384f8a97eded68a1f4af2399e?AccessKeyId=B5EA6191A964E4BCD983&disposition=0&alloworigin=1', 10, 17886);
INSERT INTO 'danceurl' VALUES (5300, 'http://nebula.wsimg.com/9df93dc384f8a97eded68a1f4af2399e?AccessKeyId=B5EA6191A964E4BCD983&disposition=0&alloworigin=1', 10, 3695);
INSERT INTO 'danceurl' VALUES (5301, 'http://nebula.wsimg.com/206a3360875b24139ab88a32e635ae53?AccessKeyId=B5EA6191A964E4BCD983&disposition=0&alloworigin=1', 10, 18047);
INSERT INTO 'danceurl' VALUES (4014, 'http://moirastacey.wordpress.com/4-horsewells-jig/', 10, 7274);
INSERT INTO 'danceurl' VALUES (4015, 'http://perso.wanadoo.fr/scots.in.france/dances.htm#MICHAEL', 10, 7281);
INSERT INTO 'danceurl' VALUES (4016, 'http://perso.wanadoo.fr/scots.in.france/dances.htm#KIRK', 10, 7287);
INSERT INTO 'danceurl' VALUES (4017, 'http://moirastacey.wordpress.com/6-we-twa-encore/', 10, 7289);
INSERT INTO 'danceurl' VALUES (4018, 'http://moirastacey.wordpress.com/7-renaissance/', 10, 7293);
INSERT INTO 'danceurl' VALUES (4019, 'http://perso.wanadoo.fr/scots.in.france/dancesb.htm', 10, 7295);
INSERT INTO 'danceurl' VALUES (4022, 'http://perso.wanadoo.fr/scots.in.france/dances.htm#CLACHAN', 10, 7305);
INSERT INTO 'danceurl' VALUES (4277, 'http://www.scn.org/arts/scottish/dances/fishjig.htm', 10, 10911);
INSERT INTO 'danceurl' VALUES (4281, 'http://scottishweekend.org/dances/Tree_Fern.pdf', 10, 10977);
INSERT INTO 'danceurl' VALUES (4282, 'http://scottishweekend.org/dances/Dance_for_Forty.pdf', 10, 10978);
INSERT INTO 'danceurl' VALUES (4286, 'http://perso.wanadoo.fr/scots.in.france/dancesb.htm', 10, 11413);
INSERT INTO 'danceurl' VALUES (4287, 'http://perso.wanadoo.fr/scots.in.france/dancesb.htm', 10, 11414);
INSERT INTO 'danceurl' VALUES (4710, 'http://www.thesundayclass.org.uk/SUMMER%20SUNDAY%20STRATHSPEY.html', 10, 14547);
INSERT INTO 'danceurl' VALUES (4711, 'http://www.thesundayclass.org.uk/SALUTE%20TO%20LARK%20HILL.html', 10, 14563);
INSERT INTO 'danceurl' VALUES (4712, 'http://ssa.nls.uk/film.cfm?fid=0313', 20, 5462);
INSERT INTO 'danceurl' VALUES (4714, 'http://rscds-greaterdc.org/nova_dances_0708.html', 10, 14564);
INSERT INTO 'danceurl' VALUES (4023, 'http://perso.wanadoo.fr/scots.in.france/dances.htm#LET''S', 10, 7310);
INSERT INTO 'danceurl' VALUES (4024, 'http://perso.wanadoo.fr/scots.in.france/dances.htm#WORLD', 10, 7320);
INSERT INTO 'danceurl' VALUES (4026, 'http://www.rscdsleeds.org.uk/dancecrib.asp?ID=46', 10, 7337);
INSERT INTO 'danceurl' VALUES (4027, 'http://www.rscdsleeds.org.uk/dancecrib.asp?ID=74', 10, 7339);
INSERT INTO 'danceurl' VALUES (4028, 'http://www.rscdsleeds.org.uk/dancecrib.asp?ID=1077', 10, 7406);
INSERT INTO 'danceurl' VALUES (4029, 'http://www.scottishdance.net/ceilidh/dances.html#GayGordons', 10, 7546);
INSERT INTO 'danceurl' VALUES (4030, 'http://www.scottishdance.net/ceilidh/dances.html#HighlandSchottische', 10, 7548);
INSERT INTO 'danceurl' VALUES (4032, 'http://www.scottishdance.net/ceilidh/dances.html#Military2Step', 10, 7552);
INSERT INTO 'danceurl' VALUES (4033, 'http://www.scottishdance.net/ceilidh/dances.html#CanadianBarn', 10, 7553);
INSERT INTO 'danceurl' VALUES (4034, 'http://www.scottishdance.net/ceilidh/dances.html#PrideOfErin', 10, 7554);
INSERT INTO 'danceurl' VALUES (4045, 'http://www.scottishdance.net/dances/TheGloomyWinter.html', 10, 8094);
INSERT INTO 'danceurl' VALUES (4280, 'https://dances.e-cribs.org/No_Haste_to_the_Wedding.pdf', 10, 10968);
INSERT INTO 'danceurl' VALUES (4049, 'http://www.scottishdance.net/ceilidh/dances.html#Britannia2Step', 10, 8143);
INSERT INTO 'danceurl' VALUES (4050, 'http://www.scottishdance.net/ceilidh/dances.html#StBernards', 10, 8154);
INSERT INTO 'danceurl' VALUES (4051, 'http://www.scottishdance.net/ceilidh/dances.html#VirginiaReel', 10, 8162);
INSERT INTO 'danceurl' VALUES (4055, 'http://scottishweekend.org/dances/iona.pdf', 10, 8567);
INSERT INTO 'danceurl' VALUES (4060, 'http://perso.wanadoo.fr/scots.in.france/dances.htm#GRENOBLE', 10, 8639);
INSERT INTO 'danceurl' VALUES (4061, 'http://perso.wanadoo.fr/scots.in.france/dances.htm#SLEEPLESS', 10, 8647);
INSERT INTO 'danceurl' VALUES (4062, 'http://perso.wanadoo.fr/scots.in.france/dancesb.htm', 10, 8671);
INSERT INTO 'danceurl' VALUES (4065, 'http://perso.wanadoo.fr/scots.in.france/spey-reel.htm', 10, 8712);
INSERT INTO 'danceurl' VALUES (4692, 'http://www.bstk.hu/book/', 10, 14481);
INSERT INTO 'danceurl' VALUES (4285, 'https://dances.e-cribs.org/Black_Leather_Kilt.pdf', 10, 11366);
INSERT INTO 'danceurl' VALUES (4038, 'https://dances.e-cribs.org/Banks_of_the_Limmat.pdf', 10, 7605);
INSERT INTO 'danceurl' VALUES (4037, 'http://www.anselms.net/SCD/dances/karlsruhe-anniversary.pdf', 10, 7561);
INSERT INTO 'danceurl' VALUES (4020, 'https://moirastacey.wordpress.com/15-rossway/', 10, 7296);
INSERT INTO 'danceurl' VALUES (4715, 'http://danciemaetion.imaginationprocessing.com/ShowDance.php?name=Mixed+Nuts&file=MIHTD/MixedNuts', 10, 14570);
INSERT INTO 'danceurl' VALUES (4279, 'https://dances.e-cribs.org/Betty_s_Delight.pdf', 10, 10967);
INSERT INTO 'danceurl' VALUES (4070, 'http://www.scottishdance.net/dances/AuldMahounsRevenge.html', 10, 8728);
INSERT INTO 'danceurl' VALUES (4072, 'http://perso.wanadoo.fr/scots.in.france/dances.htm#LINKS', 10, 8736);
INSERT INTO 'danceurl' VALUES (4073, 'http://www.scottishdance.net/dances/TheGairlochHornpipe.html', 10, 8739);
INSERT INTO 'danceurl' VALUES (5302, 'http://www.scotchmist.ca/', 10, 10653);
INSERT INTO 'danceurl' VALUES (4076, 'http://www.scottishdance.net/dances/BrodiesFancy.html', 10, 8812);
INSERT INTO 'danceurl' VALUES (4077, 'http://www.scottishdance.net/dances/Xakanaxa.html', 10, 8813);
INSERT INTO 'danceurl' VALUES (4289, 'http://www.pixton.org/scottishinsalem/bungeeplunge.html', 10, 11437);
INSERT INTO 'danceurl' VALUES (4290, 'http://www.pixton.org/scottishinsalem/lfthndfidlr.html', 10, 11438);
INSERT INTO 'danceurl' VALUES (4071, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#castor', 10, 8735);
INSERT INTO 'danceurl' VALUES (4713, 'http://ssa.nls.uk/film.cfm?fid=0850', 20, 5591);
INSERT INTO 'danceurl' VALUES (4059, 'http://math.uci.edu/~asilverb/scd/fahrrad.html', 10, 8630);
INSERT INTO 'danceurl' VALUES (4283, 'http://www.rscds-twincities.org/perfrep0506.html#dance2', 10, 11283);
INSERT INTO 'danceurl' VALUES (4041, 'https://www.rscdslondon.org.uk/sdata/dances/mare.pdf', 10, 7741);
INSERT INTO 'danceurl' VALUES (4042, 'https://www.rscdslondon.org.uk/sdata/dances/kenny.pdf', 10, 7778);
INSERT INTO 'danceurl' VALUES (4043, 'https://www.rscdslondon.org.uk/sdata/dances/kingdom.pdf', 10, 7780);
INSERT INTO 'danceurl' VALUES (4004, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/wattle.pdf', 10, 6954);
INSERT INTO 'danceurl' VALUES (4006, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/cooper.pdf', 10, 6995);
INSERT INTO 'danceurl' VALUES (4007, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/welcome.pdf', 10, 7013);
INSERT INTO 'danceurl' VALUES (4008, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/charlie.pdf', 10, 7065);
INSERT INTO 'danceurl' VALUES (4011, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/willie.pdf', 10, 7174);
INSERT INTO 'danceurl' VALUES (4012, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/witches.pdf', 10, 7207);
INSERT INTO 'danceurl' VALUES (4013, 'https://www.rscdslondon.org.uk/sdata/dances/rose_collection/tulloch.pdf', 10, 7261);
INSERT INTO 'danceurl' VALUES (4079, 'https://dances.e-cribs.org/Til_A_the_Seas_Gang_Dry.pdf', 10, 8816);
INSERT INTO 'danceurl' VALUES (4064, 'https://dances.e-cribs.org/Spiffin.pdf', 10, 8709);
INSERT INTO 'danceurl' VALUES (4081, 'http://www.anselms.net/SCD/wbook/wbook.pdf', 10, 8829);
INSERT INTO 'danceurl' VALUES (4082, 'http://www.anselms.net/SCD/wbook/wbook.pdf', 10, 8830);
INSERT INTO 'danceurl' VALUES (4087, 'http://www.pixton.org/scottishinsalem/deeinspring.html', 10, 8859);
INSERT INTO 'danceurl' VALUES (4088, 'http://sprott.physics.wisc.edu/mscd/ball98.htm', 10, 8862);
INSERT INTO 'danceurl' VALUES (4089, 'http://sprott.physics.wisc.edu/mscd/dec98.htm', 10, 8865);
INSERT INTO 'danceurl' VALUES (4091, 'http://scottishweekend.org/dances/SalmonfieldPoacher.pdf', 10, 8970);
INSERT INTO 'danceurl' VALUES (4092, 'http://www.scottishdance.net/dances/UpstairsDownstairs.html', 10, 8996);
INSERT INTO 'danceurl' VALUES (4093, 'http://www.scottishdance.net/dances/TheCottonReel.html', 10, 8997);
INSERT INTO 'danceurl' VALUES (4094, 'http://www.scottishdance.net/dances/TheBAMFAD.html', 10, 8998);
INSERT INTO 'danceurl' VALUES (4095, 'http://www.scottishdance.net/dances/TheBroderer.html', 10, 8999);
INSERT INTO 'danceurl' VALUES (4096, 'http://www.scottishdance.net/dances/ThePackhorseRant.html', 10, 9000);
INSERT INTO 'danceurl' VALUES (4097, 'http://www.rscdsleeds.org.uk/dancecrib.asp?ID=35', 10, 9001);
INSERT INTO 'danceurl' VALUES (4098, 'http://perso.wanadoo.fr/scots.in.france/dancesd.htm', 10, 9029);
INSERT INTO 'danceurl' VALUES (4100, 'http://www.ucs.mun.ca/~mulligan/dances/Bervie_Braes.html', 10, 9047);
INSERT INTO 'danceurl' VALUES (4107, 'http://www.rscds-sf.org/resources/dances/NaughtyNancy.html', 10, 9126);
INSERT INTO 'danceurl' VALUES (4109, 'http://perso.wanadoo.fr/scots.in.france/dancesb.htm', 10, 9141);
INSERT INTO 'danceurl' VALUES (4111, 'http://www.rscds-sf.org/resources/dances/TheMerrillGathering.htm', 10, 9166);
INSERT INTO 'danceurl' VALUES (4113, 'http://www.rscds-sf.org/resources/dances/BirksOfLafayette.html', 10, 9340);
INSERT INTO 'danceurl' VALUES (4114, 'http://www.rscds-sf.org/resources/dances/Casting%20Glances.htm', 10, 9341);
INSERT INTO 'danceurl' VALUES (4118, 'http://www.scottishdance.net/dances/NiftyShiftin.html', 10, 9391);
INSERT INTO 'danceurl' VALUES (4182, 'http://www.scottishdance.net/dances/TheMarmaladeSandwich.html', 10, 9834);
INSERT INTO 'danceurl' VALUES (4067, 'http://my.strathspey.org/u/anselm/dances/birgit/', 10, 8722);
INSERT INTO 'danceurl' VALUES (4101, 'https://dances.e-cribs.org/Getting_to_Know_You.pdf', 10, 9115);
INSERT INTO 'danceurl' VALUES (4693, 'http://www.bstk.hu/book/', 10, 14482);
INSERT INTO 'danceurl' VALUES (4063, 'http://macrudi.de/resources/dances/munsters.pdf', 10, 8692);
INSERT INTO 'danceurl' VALUES (4066, 'http://www.macrudi.de/resources/dances/gomatrip.pdf', 10, 8718);
INSERT INTO 'danceurl' VALUES (4075, 'https://dances.e-cribs.org/The_Devil_in_the_Bearpit.pdf', 10, 8811);
INSERT INTO 'danceurl' VALUES (4084, 'https://dances.e-cribs.org/Thorncliffe.pdf', 10, 8853);
INSERT INTO 'danceurl' VALUES (4108, 'https://dances.e-cribs.org/To_Karin.pdf', 10, 9128);
INSERT INTO 'danceurl' VALUES (4110, 'https://dances.e-cribs.org/Catriona_Joan_Stewart.pdf', 10, 9148);
INSERT INTO 'danceurl' VALUES (4112, 'https://dances.e-cribs.org/Cambusnethan.pdf', 10, 9167);
INSERT INTO 'danceurl' VALUES (4184, 'https://dances.e-cribs.org/The_Silver_Hamer.pdf', 10, 9898);
INSERT INTO 'danceurl' VALUES (4296, 'https://suedan.com/dances/instructions/aprilfool.html', 10, 11444);
INSERT INTO 'danceurl' VALUES (4302, 'https://suedan.com/dances/instructions/birl.html', 10, 11450);
INSERT INTO 'danceurl' VALUES (4305, 'https://suedan.com/dances/instructions/carlyncounting.html', 10, 11453);
INSERT INTO 'danceurl' VALUES (4293, 'https://suedan.com/dances/instructions/clockwork.html', 10, 11441);
INSERT INTO 'danceurl' VALUES (4306, 'https://suedan.com/dances/instructions/crossstitch.html', 10, 11454);
INSERT INTO 'danceurl' VALUES (4308, 'https://suedan.com/dances/instructions/dosequis.html', 10, 11456);
INSERT INTO 'danceurl' VALUES (4294, 'https://suedan.com/dances/instructions/flowersofspring.html', 10, 11442);
INSERT INTO 'danceurl' VALUES (4298, 'https://suedan.com/dances/instructions/formation.html', 10, 11446);
INSERT INTO 'danceurl' VALUES (4307, 'https://suedan.com/dances/instructions/gifts.html', 10, 11455);
INSERT INTO 'danceurl' VALUES (4295, 'https://suedan.com/dances/instructions/jacobite.html', 10, 11443);
INSERT INTO 'danceurl' VALUES (4309, 'https://suedan.com/dances/instructions/milkyway.html', 10, 11457);
INSERT INTO 'danceurl' VALUES (4301, 'https://suedan.com/dances/instructions/octothorpe.html', 10, 11449);
INSERT INTO 'danceurl' VALUES (4297, 'https://suedan.com/dances/instructions/onegoodturn.html', 10, 11445);
INSERT INTO 'danceurl' VALUES (4310, 'https://suedan.com/dances/instructions/ozma.html', 10, 11458);
INSERT INTO 'danceurl' VALUES (4303, 'https://suedan.com/dances/instructions/partners.html', 10, 11451);
INSERT INTO 'danceurl' VALUES (4304, 'https://suedan.com/dances/instructions/rose.html', 10, 11452);
INSERT INTO 'danceurl' VALUES (4299, 'https://suedan.com/dances/instructions/skating.html', 10, 11447);
INSERT INTO 'danceurl' VALUES (4292, 'https://suedan.com/dances/instructions/tiggerbounce.html', 10, 11440);
INSERT INTO 'danceurl' VALUES (4291, 'https://suedan.com/dances/instructions/truthpond.html', 10, 11439);
INSERT INTO 'danceurl' VALUES (4300, 'https://suedan.com/dances/instructions/twists.html', 10, 11448);
INSERT INTO 'danceurl' VALUES (4720, 'http://my.strathspey.org/u/anselm/dances/twoforthree/', 10, 14593);
INSERT INTO 'danceurl' VALUES (5303, 'http://www.scotchmist.ca/', 10, 18121);
INSERT INTO 'danceurl' VALUES (4723, 'https://www.youtube.com/watch?v=w4UimyKzFcc&list=PL38E0C98DE53FF366', 10, 14633);
INSERT INTO 'danceurl' VALUES (4724, 'http://www.youtube.com/watch?v=T9F7362yxjg', 10, 14637);
INSERT INTO 'danceurl' VALUES (5304, 'http://www.scotchmist.ca/', 10, 17886);
INSERT INTO 'danceurl' VALUES (5305, 'http://www.scotchmist.ca/', 10, 3695);
INSERT INTO 'danceurl' VALUES (5306, 'http://www.scotchmist.ca/', 10, 18048);
INSERT INTO 'danceurl' VALUES (5307, 'http://www.scotchmist.ca/', 10, 16522);
INSERT INTO 'danceurl' VALUES (5308, 'http://www.scotchmist.ca/', 10, 17887);
INSERT INTO 'danceurl' VALUES (4729, 'http://www.thesundayclass.org.uk/GEORGES%20BEES.html', 10, 14700);
INSERT INTO 'danceurl' VALUES (4163, 'http://www.scottishdance.net/dances/TeviotSquare.html', 10, 9536);
INSERT INTO 'danceurl' VALUES (4164, 'http://www.rscdsleeds.org.uk/dancecrib.asp?ID=25', 10, 9542);
INSERT INTO 'danceurl' VALUES (4170, 'http://www.rscds-twincities.org/annualball03.html#dance5', 10, 9609);
INSERT INTO 'danceurl' VALUES (4171, 'http://www.rscdsleeds.org.uk/dancecrib.asp?ID=26', 10, 9631);
INSERT INTO 'danceurl' VALUES (4172, 'http://home.att.net/~diannashipman/Spinning_Your_Wheels.html', 10, 9648);
INSERT INTO 'danceurl' VALUES (5309, 'http://www.scotchmist.ca/', 10, 7795);
INSERT INTO 'danceurl' VALUES (4176, 'http://www.rscds-sf.org/resources/dances/MissJaneMuirhead.htm', 10, 9701);
INSERT INTO 'danceurl' VALUES (4080, 'https://dances.e-cribs.org/Fiddler_s_Fancy.pdf', 10, 8817);
INSERT INTO 'danceurl' VALUES (4117, 'https://rscds-twincities.org/dance/rush-hour-reel/', 10, 9376);
INSERT INTO 'danceurl' VALUES (4116, 'https://rscds-twincities.org/dance/ebb-and-flow/', 10, 9372);
INSERT INTO 'danceurl' VALUES (4085, 'http://scottishweekend.org/dances/PhyllisDixonIvory.pdf', 10, 8857);
INSERT INTO 'danceurl' VALUES (4086, 'http://scottishweekend.org/dances/DancingMasterMoncton.pdf', 10, 8858);
INSERT INTO 'danceurl' VALUES (4124, 'https://suepetyt.e-cribs.org/Barton_Barbecue.pdf', 10, 9422);
INSERT INTO 'danceurl' VALUES (4126, 'https://suepetyt.e-cribs.org/After_Supper.pdf', 10, 9424);
INSERT INTO 'danceurl' VALUES (4123, 'https://suepetyt.e-cribs.org/Ashby_Petronella.pdf', 10, 9421);
INSERT INTO 'danceurl' VALUES (4119, 'https://suepetyt.e-cribs.org/Tartan_Rainbow.pdf', 10, 9417);
INSERT INTO 'danceurl' VALUES (4120, 'https://suepetyt.e-cribs.org/Moving_South.pdf', 10, 9418);
INSERT INTO 'danceurl' VALUES (4722, 'https://suepetyt.e-cribs.org/Corstorphine_Road.pdf', 10, 9420);
INSERT INTO 'danceurl' VALUES (4125, 'http://suepetyt.e-cribs.org/Golden_Heather.pdf', 10, 9423);
INSERT INTO 'danceurl' VALUES (4105, 'https://dances.e-cribs.org/The_July_28th_Jig.pdf', 10, 9123);
INSERT INTO 'danceurl' VALUES (4179, 'http://scottishweekend.org/dances/FoggyRiverReel.PDF', 10, 9802);
INSERT INTO 'danceurl' VALUES (5311, 'http://www.scotchmist.ca/', 10, 1087);
INSERT INTO 'danceurl' VALUES (5313, 'http://nebula.wsimg.com/386365270b4bd1ac0e727ac2edf071c8?AccessKeyId=B5EA6191A964E4BCD983&disposition=0&alloworigin=1', 10, 18049);
INSERT INTO 'danceurl' VALUES (5314, 'http://nebula.wsimg.com/30b86b87b08fca3a9cbbcc2044f2e21c?AccessKeyId=B5EA6191A964E4BCD983&disposition=0&alloworigin=1', 10, 17885);
INSERT INTO 'danceurl' VALUES (5315, 'http://nebula.wsimg.com/fe16adb5f7df2daec59c9348874f41a8?AccessKeyId=B5EA6191A964E4BCD983&disposition=0&alloworigin=1', 10, 13847);
INSERT INTO 'danceurl' VALUES (5316, 'http://nebula.wsimg.com/b46b4d17af816aefb345a90fa080de21?AccessKeyId=B5EA6191A964E4BCD983&disposition=0&alloworigin=1', 10, 1087);
INSERT INTO 'danceurl' VALUES (4694, 'http://www.bstk.hu/book/', 10, 14483);
INSERT INTO 'danceurl' VALUES (4726, 'https://8x32.e-cribs.org/index.php/a/outside-the-box', 10, 14661);
INSERT INTO 'danceurl' VALUES (5419, 'https://dublinscdclub.files.wordpress.com/2018/06/an-arizona-welcome.pdf', 10, 12073);
INSERT INTO 'danceurl' VALUES (4131, 'http://macrudi.de/resources/dances/chase.pdf', 10, 9441);
INSERT INTO 'danceurl' VALUES (4719, 'https://suedan.com/dances/instructions/sweetsurrender.html', 10, 14591);
INSERT INTO 'danceurl' VALUES (4150, 'https://suedan.com/dances/instructions/aweedifugue.html', 10, 9491);
INSERT INTO 'danceurl' VALUES (4169, 'https://suedan.com/dances/instructions/bowtie.html', 10, 9569);
INSERT INTO 'danceurl' VALUES (4315, 'https://suedan.com/dances/instructions/buttonbright.html', 10, 11463);
INSERT INTO 'danceurl' VALUES (4328, 'https://suedan.com/dances/instructions/catscradle.html', 10, 11476);
INSERT INTO 'danceurl' VALUES (4151, 'https://suedan.com/dances/instructions/celticknot.html', 10, 9492);
INSERT INTO 'danceurl' VALUES (4320, 'https://suedan.com/dances/instructions/corkscrew.html', 10, 11468);
INSERT INTO 'danceurl' VALUES (4152, 'https://suedan.com/dances/instructions/diagonaljig.html', 10, 9493);
INSERT INTO 'danceurl' VALUES (4313, 'https://suedan.com/dances/instructions/dishpan.html', 10, 11461);
INSERT INTO 'danceurl' VALUES (4147, 'https://suedan.com/dances/instructions/dougsstrathspey.html', 10, 9488);
INSERT INTO 'danceurl' VALUES (4153, 'https://suedan.com/dances/instructions/ducksonpond.html', 10, 9494);
INSERT INTO 'danceurl' VALUES (4311, 'https://suedan.com/dances/instructions/emeraldcity.html', 10, 11459);
INSERT INTO 'danceurl' VALUES (4141, 'https://suedan.com/dances/instructions/frolic.html', 10, 9482);
INSERT INTO 'danceurl' VALUES (4325, 'https://suedan.com/dances/instructions/glasscat.html', 10, 11473);
INSERT INTO 'danceurl' VALUES (4326, 'https://suedan.com/dances/instructions/glinda.html', 10, 11474);
INSERT INTO 'danceurl' VALUES (4321, 'https://suedan.com/dances/instructions/hourglass.html', 10, 11469);
INSERT INTO 'danceurl' VALUES (4319, 'https://suedan.com/dances/instructions/ianmichael.html', 10, 11467);
INSERT INTO 'danceurl' VALUES (4168, 'https://suedan.com/dances/instructions/ivy.html', 10, 9568);
INSERT INTO 'danceurl' VALUES (4142, 'https://suedan.com/dances/instructions/lacemaker.html', 10, 9483);
INSERT INTO 'danceurl' VALUES (4718, 'https://suedan.com/dances/instructions/lakewoodhigh.html', 10, 14590);
INSERT INTO 'danceurl' VALUES (4312, 'https://suedan.com/dances/instructions/merrygoround.html', 10, 11460);
INSERT INTO 'danceurl' VALUES (4144, 'https://suedan.com/dances/instructions/mhbd.html', 10, 9485);
INSERT INTO 'danceurl' VALUES (4323, 'https://suedan.com/dances/instructions/pedalpush.html', 10, 11471);
INSERT INTO 'danceurl' VALUES (4145, 'https://suedan.com/dances/instructions/plutoshead.html', 10, 9486);
INSERT INTO 'danceurl' VALUES (4154, 'https://suedan.com/dances/instructions/reelthing.html', 10, 9495);
INSERT INTO 'danceurl' VALUES (4317, 'https://suedan.com/dances/instructions/rockriver.html', 10, 11465);
INSERT INTO 'danceurl' VALUES (4717, 'https://suedan.com/dances/instructions/satinandlace.html', 10, 14589);
INSERT INTO 'danceurl' VALUES (4316, 'https://suedan.com/dances/instructions/sawhorse.html', 10, 11464);
INSERT INTO 'danceurl' VALUES (4322, 'https://suedan.com/dances/instructions/searchmacdonald.html', 10, 11470);
INSERT INTO 'danceurl' VALUES (4166, 'https://suedan.com/dances/instructions/silkenknot.html', 10, 9566);
INSERT INTO 'danceurl' VALUES (4149, 'https://suedan.com/dances/instructions/standrew.html', 10, 9490);
INSERT INTO 'danceurl' VALUES (4181, 'https://suedan.com/dances/instructions/tturkey.html', 10, 9833);
INSERT INTO 'danceurl' VALUES (4155, 'https://suedan.com/dances/instructions/two4one.html', 10, 9496);
INSERT INTO 'danceurl' VALUES (4327, 'https://suedan.com/dances/instructions/upsidedown.html', 10, 11475);
INSERT INTO 'danceurl' VALUES (4167, 'https://suedan.com/dances/instructions/waterfall.html', 10, 9567);
INSERT INTO 'danceurl' VALUES (4324, 'https://suedan.com/dances/instructions/wheelers.html', 10, 11472);
INSERT INTO 'danceurl' VALUES (4148, 'https://suedan.com/dances/instructions/whirlmady.html', 10, 9489);
INSERT INTO 'danceurl' VALUES (4143, 'https://suedan.com/dances/instructions/whirlybird.html', 10, 9484);
INSERT INTO 'danceurl' VALUES (4146, 'https://suedan.com/dances/instructions/y2chaos.html', 10, 9487);
INSERT INTO 'danceurl' VALUES (4128, 'http://www.macrudi.de/resources/dances/rudifault.pdf', 10, 9437);
INSERT INTO 'danceurl' VALUES (4127, 'http://www.macrudi.de/resources/dances/weepwillow.pdf', 10, 9436);
INSERT INTO 'danceurl' VALUES (4130, 'http://www.macrudi.de/resources/dances/twinckle.pdf', 10, 9439);
INSERT INTO 'danceurl' VALUES (4129, 'http://www.macrudi.de/resources/dances/noname.pdf', 10, 9438);
INSERT INTO 'danceurl' VALUES (3785, 'http://www.macrudi.de/resources/dances/chanpous.pdf', 10, 1609);
INSERT INTO 'danceurl' VALUES (4266, 'https://dances.e-cribs.org/The_Encore.pdf', 10, 10554);
INSERT INTO 'danceurl' VALUES (4174, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#rocky', 10, 9674);
INSERT INTO 'danceurl' VALUES (4173, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#mardi', 10, 9669);
INSERT INTO 'danceurl' VALUES (4696, 'http://www.bstk.hu/hb', 10, 14484);
INSERT INTO 'danceurl' VALUES (4187, 'http://www.timdoodle.com/scd/QuicksilverReel.html', 10, 10023);
INSERT INTO 'danceurl' VALUES (4188, 'http://www.timdoodle.com/scd/ReelyQuickOnTheSides.html', 10, 10024);
INSERT INTO 'danceurl' VALUES (4189, 'http://www.timdoodle.com/scd/ReelyQuickAcross.html', 10, 10025);
INSERT INTO 'danceurl' VALUES (4196, 'http://www.rscds-sf.org/resources/dances/ElusiveMuse.htm', 10, 10102);
INSERT INTO 'danceurl' VALUES (4197, 'http://perso.wanadoo.fr/scots.in.france/dancesd.htm', 10, 10114);
INSERT INTO 'danceurl' VALUES (4730, 'http://scottishdance.net/dances/Book/OrwellLodgeStrathspey.pdf', 10, 14536);
INSERT INTO 'danceurl' VALUES (4731, 'http://www.scottishdance.net/dances/Book/MapleDancing.pdf', 10, 12278);
INSERT INTO 'danceurl' VALUES (5310, 'http://www.scotchmist.ca/', 10, 17144);
INSERT INTO 'danceurl' VALUES (4238, 'http://www.anselms.net/SCD/wbook/wbook.pdf', 10, 10290);
INSERT INTO 'danceurl' VALUES (4352, 'http://www.rscds-sf.org/resources/dances/SummerSerendipity.htm', 10, 11549);
INSERT INTO 'danceurl' VALUES (4353, 'http://www.rscds-sf.org/resources/dances/Celebration.htm', 10, 11553);
INSERT INTO 'danceurl' VALUES (4192, 'http://hh2f2ns.wixsite.com/frederick-scd/dances-a', 10, 10053);
INSERT INTO 'danceurl' VALUES (4195, 'http://hh2f2ns.wixsite.com/frederick-scd/dances', 10, 10056);
INSERT INTO 'danceurl' VALUES (4194, 'http://hh2f2ns.wixsite.com/frederick-scd/dances', 10, 10055);
INSERT INTO 'danceurl' VALUES (4193, 'http://hh2f2ns.wixsite.com/frederick-scd/dances-d', 10, 10054);
INSERT INTO 'danceurl' VALUES (4695, 'http://www.bstk.hu/book/', 10, 14484);
INSERT INTO 'danceurl' VALUES (4237, 'http://www.davewiesler.com/HH_dances_w_FMK&SW.pdf', 10, 10286);
INSERT INTO 'danceurl' VALUES (4191, 'https://suepetyt.e-cribs.org/The_Dancer''s_Web.pdf', 10, 10051);
INSERT INTO 'danceurl' VALUES (4157, 'https://suepetyt.e-cribs.org/Iain''s_Obsession.pdf', 10, 9528);
INSERT INTO 'danceurl' VALUES (4121, 'https://suepetyt.e-cribs.org/London''s_Burning.pdf', 10, 9419);
INSERT INTO 'danceurl' VALUES (4159, 'https://suepetyt.e-cribs.org/The_Millennium_Bug.pdf', 10, 9530);
INSERT INTO 'danceurl' VALUES (4161, 'https://suepetyt.e-cribs.org/The_Three_Square_Strathspey.pdf', 10, 9532);
INSERT INTO 'danceurl' VALUES (4162, 'https://suepetyt.e-cribs.org/Two_Furlongs.pdf', 10, 9533);
INSERT INTO 'danceurl' VALUES (4156, 'http://suepetyt.e-cribs.org/Caledonian_Caper.pdf', 10, 9527);
INSERT INTO 'danceurl' VALUES (4177, 'https://dances.e-cribs.org/Dancing_Shadows.pdf', 10, 9775);
INSERT INTO 'danceurl' VALUES (4233, 'https://suedan.com/dances/instructions/ampersand.html', 10, 10269);
INSERT INTO 'danceurl' VALUES (4216, 'https://suedan.com/dances/instructions/arches.html', 10, 10252);
INSERT INTO 'danceurl' VALUES (4225, 'https://suedan.com/dances/instructions/betsyross.html', 10, 10261);
INSERT INTO 'danceurl' VALUES (4200, 'https://suedan.com/dances/instructions/bricks.html', 10, 10236);
INSERT INTO 'danceurl' VALUES (4332, 'https://suedan.com/dances/instructions/busybox.html', 10, 11491);
INSERT INTO 'danceurl' VALUES (4220, 'https://suedan.com/dances/instructions/butterchurn.html', 10, 10256);
INSERT INTO 'danceurl' VALUES (4229, 'https://suedan.com/dances/instructions/castles.html', 10, 10265);
INSERT INTO 'danceurl' VALUES (4349, 'https://suedan.com/dances/instructions/caterpillar.html', 10, 11508);
INSERT INTO 'danceurl' VALUES (4340, 'https://suedan.com/dances/instructions/childwonder.html', 10, 11499);
INSERT INTO 'danceurl' VALUES (4205, 'https://suedan.com/dances/instructions/coalesce.html', 10, 10241);
INSERT INTO 'danceurl' VALUES (4232, 'https://suedan.com/dances/instructions/copycat.html', 10, 10268);
INSERT INTO 'danceurl' VALUES (4227, 'https://suedan.com/dances/instructions/counterpoint.html', 10, 10263);
INSERT INTO 'danceurl' VALUES (4234, 'https://suedan.com/dances/instructions/dekalb.html', 10, 10270);
INSERT INTO 'danceurl' VALUES (4335, 'https://suedan.com/dances/instructions/fourposter.html', 10, 11494);
INSERT INTO 'danceurl' VALUES (4201, 'https://suedan.com/dances/instructions/foxriver.html', 10, 10237);
INSERT INTO 'danceurl' VALUES (4209, 'https://suedan.com/dances/instructions/friends.html', 10, 10245);
INSERT INTO 'danceurl' VALUES (4221, 'https://suedan.com/dances/instructions/funfermi.html', 10, 10257);
INSERT INTO 'danceurl' VALUES (4215, 'https://suedan.com/dances/instructions/glencairn.html', 10, 10251);
INSERT INTO 'danceurl' VALUES (4236, 'https://suedan.com/dances/instructions/glencoe.html', 10, 10272);
INSERT INTO 'danceurl' VALUES (4341, 'https://suedan.com/dances/instructions/greatbigsea.html', 10, 11500);
INSERT INTO 'danceurl' VALUES (4213, 'https://suedan.com/dances/instructions/hollyjoy.html', 10, 10249);
INSERT INTO 'danceurl' VALUES (4331, 'https://suedan.com/dances/instructions/imaginaryreel.html', 10, 11490);
INSERT INTO 'danceurl' VALUES (4350, 'https://suedan.com/dances/instructions/jinglebells.html', 10, 11509);
INSERT INTO 'danceurl' VALUES (4336, 'https://suedan.com/dances/instructions/kingtut.html', 10, 11495);
INSERT INTO 'danceurl' VALUES (4338, 'https://suedan.com/dances/instructions/lucechange.html', 10, 11497);
INSERT INTO 'danceurl' VALUES (4210, 'https://suedan.com/dances/instructions/mandala.html', 10, 10246);
INSERT INTO 'danceurl' VALUES (4337, 'https://suedan.com/dances/instructions/migration.html', 10, 11496);
INSERT INTO 'danceurl' VALUES (4343, 'https://suedan.com/dances/instructions/origami.html', 10, 11502);
INSERT INTO 'danceurl' VALUES (4333, 'https://suedan.com/dances/instructions/outamongstars.html', 10, 11492);
INSERT INTO 'danceurl' VALUES (4223, 'https://suedan.com/dances/instructions/peony.html', 10, 10259);
INSERT INTO 'danceurl' VALUES (4222, 'https://suedan.com/dances/instructions/perpetmotion.html', 10, 10258);
INSERT INTO 'danceurl' VALUES (4218, 'https://suedan.com/dances/instructions/pinballwiz.html', 10, 10254);
INSERT INTO 'danceurl' VALUES (4345, 'https://suedan.com/dances/instructions/playfulprogression.html', 10, 11504);
INSERT INTO 'danceurl' VALUES (4348, 'https://suedan.com/dances/instructions/reel2reel.html', 10, 11507);
INSERT INTO 'danceurl' VALUES (4212, 'https://suedan.com/dances/instructions/reversal.html', 10, 10248);
INSERT INTO 'danceurl' VALUES (4351, 'https://suedan.com/dances/instructions/ribbon.html', 10, 11510);
INSERT INTO 'danceurl' VALUES (4228, 'https://suedan.com/dances/instructions/scotland.html', 10, 10264);
INSERT INTO 'danceurl' VALUES (4230, 'https://suedan.com/dances/instructions/skye.html', 10, 10266);
INSERT INTO 'danceurl' VALUES (4344, 'https://suedan.com/dances/instructions/spirograph.html', 10, 11503);
INSERT INTO 'danceurl' VALUES (4203, 'https://suedan.com/dances/instructions/srequest.html', 10, 10239);
INSERT INTO 'danceurl' VALUES (4235, 'https://suedan.com/dances/instructions/sweetpotatoes.html', 10, 10271);
INSERT INTO 'danceurl' VALUES (4204, 'https://suedan.com/dances/instructions/t4two.html', 10, 10240);
INSERT INTO 'danceurl' VALUES (4224, 'https://suedan.com/dances/instructions/tease.html', 10, 10260);
INSERT INTO 'danceurl' VALUES (4339, 'https://suedan.com/dances/instructions/thorshammer.html', 10, 11498);
INSERT INTO 'danceurl' VALUES (4346, 'https://suedan.com/dances/instructions/tiddlywinks.html', 10, 11505);
INSERT INTO 'danceurl' VALUES (4334, 'https://suedan.com/dances/instructions/tiktok.html', 10, 11493);
INSERT INTO 'danceurl' VALUES (4347, 'https://suedan.com/dances/instructions/tit4tat.html', 10, 11506);
INSERT INTO 'danceurl' VALUES (4202, 'https://suedan.com/dances/instructions/tomsreel.html', 10, 10238);
INSERT INTO 'danceurl' VALUES (4208, 'https://suedan.com/dances/instructions/waterwheel.html', 10, 10244);
INSERT INTO 'danceurl' VALUES (4214, 'https://suedan.com/dances/instructions/wavesonsea.html', 10, 10250);
INSERT INTO 'danceurl' VALUES (4219, 'https://suedan.com/dances/instructions/weaveplaid.html', 10, 10255);
INSERT INTO 'danceurl' VALUES (4330, 'https://suedan.com/dances/instructions/weddingvows.html', 10, 11489);
INSERT INTO 'danceurl' VALUES (4206, 'https://suedan.com/dances/instructions/witching.html', 10, 10242);
INSERT INTO 'danceurl' VALUES (4207, 'https://suedan.com/dances/instructions/xando.html', 10, 10243);
INSERT INTO 'danceurl' VALUES (4226, 'https://suedan.com/dances/instructions/xyzzy.html', 10, 10262);
INSERT INTO 'danceurl' VALUES (4198, 'https://dances.e-cribs.org/The_Bishop_of_Columbus.pdf', 10, 10115);
INSERT INTO 'danceurl' VALUES (4199, 'https://dances.e-cribs.org/Pretty_Face.pdf', 10, 10116);
INSERT INTO 'danceurl' VALUES (4368, 'http://www.scottishdance.net/dances/GloomyWintersNooAwa.html', 10, 11707);
INSERT INTO 'danceurl' VALUES (4374, 'http://www.reeljig.com', 10, 11753);
INSERT INTO 'danceurl' VALUES (4375, 'http://www.reeljig.com', 10, 11754);
INSERT INTO 'danceurl' VALUES (4376, 'http://www.reeljig.com/', 10, 11755);
INSERT INTO 'danceurl' VALUES (4370, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#fifty', 10, 11719);
INSERT INTO 'danceurl' VALUES (5317, 'http://nebula.wsimg.com/d014c8182530c9ff6ec3eb3015723127?AccessKeyId=B5EA6191A964E4BCD983&disposition=0&alloworigin=1', 10, 17144);
INSERT INTO 'danceurl' VALUES (4382, 'http://www.timdoodle.com/scd/AustinSilver.html', 10, 11801);
INSERT INTO 'danceurl' VALUES (4399, 'http://scottishweekend.org/dances/CatchingFireflies.pdf', 10, 11968);
INSERT INTO 'danceurl' VALUES (4400, 'http://scottishweekend.org/dances/NIMBUS2002.html', 10, 11969);
INSERT INTO 'danceurl' VALUES (4402, 'http://scottishweekend.org/dances/GlenFruin.htm', 10, 11971);
INSERT INTO 'danceurl' VALUES (4403, 'http://scottishweekend.org/dances/MCLOUGHLIN.htm', 10, 11972);
INSERT INTO 'danceurl' VALUES (4407, 'http://www.scottishdance.net/ceilidh/dances.html#StripTheWillow2', 10, 12071);
INSERT INTO 'danceurl' VALUES (4415, 'http://www.rscds-sf.org/resources/dances/GaryScottsJig.htm', 10, 12427);
INSERT INTO 'danceurl' VALUES (4416, 'http://www.rscds-sf.org/resources/dances/Kathleen_and_Walter_%20McAdam.pdf', 10, 12475);
INSERT INTO 'danceurl' VALUES (4417, 'http://www.rscds-sf.org/resources/dances/Mr_Smiths_Delight.pdf', 10, 12476);
INSERT INTO 'danceurl' VALUES (4409, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#carriage', 10, 12170);
INSERT INTO 'danceurl' VALUES (4414, 'http://www.highlandmistdancers.org/HM3goldenoldies.html#thaddy', 10, 12399);
INSERT INTO 'danceurl' VALUES (5337, 'https://tunes.e-cribs.org/Reel_for_St_Columba_s_Church.pdf', 10, 13924);
INSERT INTO 'danceurl' VALUES (5420, 'https://dublinscdclub.files.wordpress.com/2017/03/dereks-dilemma-revised.pdf', 10, 8927);
INSERT INTO 'danceurl' VALUES (4383, 'https://www.rscdslondon.org.uk/sdata/dances/findlay.pdf', 10, 11807);
INSERT INTO 'danceurl' VALUES (4418, 'https://www.rscds-sf.org/resources/dances/The_Fiddlesticks_Frolic.pdf', 10, 12477);
INSERT INTO 'danceurl' VALUES (4395, 'https://suepetyt.e-cribs.org/Loch_Ness_Monster_Reel.pdf', 10, 11896);
INSERT INTO 'danceurl' VALUES (4396, 'https://suepetyt.e-cribs.org/The_Dumfries_Rambler.pdf', 10, 11897);
INSERT INTO 'danceurl' VALUES (4440, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 12605);
INSERT INTO 'danceurl' VALUES (4355, 'http://eddywest.nz/beachd.html', 10, 11587);
INSERT INTO 'danceurl' VALUES (4356, 'http://eddywest.nz/Celticl.html', 10, 11588);
INSERT INTO 'danceurl' VALUES (4357, 'http://eddywest.nz/Frond.html', 10, 11589);
INSERT INTO 'danceurl' VALUES (4358, 'http://eddywest.nz/Grahamf.html', 10, 11590);
INSERT INTO 'danceurl' VALUES (4359, 'http://eddywest.nz/hopefh.html', 10, 11591);
INSERT INTO 'danceurl' VALUES (4360, 'http://eddywest.nz/Janfj.html', 10, 11592);
INSERT INTO 'danceurl' VALUES (4361, 'http://eddywest.nz/Jeanss3.html', 10, 11593);
INSERT INTO 'danceurl' VALUES (4362, 'http://eddywest.nz/jigjan4.html', 10, 11594);
INSERT INTO 'danceurl' VALUES (4363, 'http://eddywest.nz/squarers.html', 10, 11595);
INSERT INTO 'danceurl' VALUES (4364, 'http://eddywest.nz/vicevers.html', 10, 11596);
INSERT INTO 'danceurl' VALUES (4365, 'http://eddywest.nz/whangareiw2.html', 10, 11597);
INSERT INTO 'danceurl' VALUES (4373, 'http://www.reeljig.com/', 10, 11752);
INSERT INTO 'danceurl' VALUES (4404, 'https://8x32.e-cribs.org/index.php/a/down-the-rabbit-hole', 10, 12003);
INSERT INTO 'danceurl' VALUES (4411, 'https://8x32.e-cribs.org/index.php/a/oot-dancing', 10, 12277);
INSERT INTO 'danceurl' VALUES (4412, 'https://8x32.e-cribs.org/index.php/a/maple-dancing', 20, 12278);
INSERT INTO 'danceurl' VALUES (4405, 'https://8x32.e-cribs.org/index.php/a/rice-and-lefse', 10, 12014);
INSERT INTO 'danceurl' VALUES (5425, 'https://dances.e-cribs.org/Padre_Donald_Wallace.pdf', 10, 12369);
INSERT INTO 'danceurl' VALUES (4366, 'https://dances.e-cribs.org/Just_a_wee_dance.pdf', 10, 11704);
INSERT INTO 'danceurl' VALUES (4367, 'https://dances.e-cribs.org/The_Lindworm.pdf', 10, 11706);
INSERT INTO 'danceurl' VALUES (4406, 'https://suedan.com/george/my88.html', 10, 12022);
INSERT INTO 'danceurl' VALUES (4378, 'https://suedan.com/dances/instructions/ateam.html', 10, 11759);
INSERT INTO 'danceurl' VALUES (4423, 'https://suedan.com/dances/instructions/auldredcat.html', 10, 12482);
INSERT INTO 'danceurl' VALUES (4408, 'https://suedan.com/dances/instructions/backtobarn.html', 10, 12142);
INSERT INTO 'danceurl' VALUES (4420, 'https://suedan.com/dances/instructions/buckeyesreel.html', 10, 12479);
INSERT INTO 'danceurl' VALUES (4410, 'https://suedan.com/dances/instructions/celticbraid.html', 10, 12173);
INSERT INTO 'danceurl' VALUES (4380, 'https://suedan.com/dances/instructions/citymove.html', 10, 11761);
INSERT INTO 'danceurl' VALUES (4428, 'https://suedan.com/dances/instructions/crosssquare.html', 10, 12488);
INSERT INTO 'danceurl' VALUES (4437, 'https://suedan.com/dances/instructions/cryhavoc.html', 10, 12500);
INSERT INTO 'danceurl' VALUES (4433, 'https://suedan.com/dances/instructions/frolic10.html', 10, 12493);
INSERT INTO 'danceurl' VALUES (4434, 'https://suedan.com/dances/instructions/hannahsjourney.html', 10, 12494);
INSERT INTO 'danceurl' VALUES (4377, 'https://suedan.com/dances/instructions/hans.html', 10, 11757);
INSERT INTO 'danceurl' VALUES (4430, 'https://suedan.com/dances/instructions/homeagain.html', 10, 12490);
INSERT INTO 'danceurl' VALUES (4427, 'https://suedan.com/dances/instructions/jubileered.html', 10, 12486);
INSERT INTO 'danceurl' VALUES (4424, 'https://suedan.com/dances/instructions/ladiesauxiliary.html', 10, 12483);
INSERT INTO 'danceurl' VALUES (4432, 'https://suedan.com/dances/instructions/leftagain.html', 10, 12492);
INSERT INTO 'danceurl' VALUES (4429, 'https://suedan.com/dances/instructions/lipstickknee.html', 10, 12489);
INSERT INTO 'danceurl' VALUES (4436, 'https://suedan.com/dances/instructions/majormilestones.html', 10, 12499);
INSERT INTO 'danceurl' VALUES (4379, 'https://suedan.com/dances/instructions/maryan.html', 10, 11760);
INSERT INTO 'danceurl' VALUES (4425, 'https://suedan.com/dances/instructions/newbeginning.html', 10, 12484);
INSERT INTO 'danceurl' VALUES (4426, 'https://suedan.com/dances/instructions/oregonspring.html', 10, 12485);
INSERT INTO 'danceurl' VALUES (4421, 'https://suedan.com/dances/instructions/pandorasbox.html', 10, 12480);
INSERT INTO 'danceurl' VALUES (4422, 'https://suedan.com/dances/instructions/pleatochac.html', 10, 12481);
INSERT INTO 'danceurl' VALUES (4435, 'https://suedan.com/dances/instructions/weecottages.html', 10, 12498);
INSERT INTO 'danceurl' VALUES (4431, 'https://suedan.com/dances/instructions/wizardswalk.html', 10, 12491);
INSERT INTO 'danceurl' VALUES (4419, 'https://suedan.com/dances/instructions/scrapsjig.html', 10, 12478);
INSERT INTO 'danceurl' VALUES (4438, 'https://suedan.com/dances/instructions/curlicue.html', 10, 12501);
INSERT INTO 'danceurl' VALUES (4385, 'https://dances.e-cribs.org/The_Norah_Link.pdf', 10, 11826);
INSERT INTO 'danceurl' VALUES (4384, 'https://dances.e-cribs.org/The_Space_Coaster.pdf', 10, 11815);
INSERT INTO 'danceurl' VALUES (4388, 'https://dances.e-cribs.org/This_One_s_Four_Isobel.pdf', 10, 11829);
INSERT INTO 'danceurl' VALUES (4387, 'https://dances.e-cribs.org/Four_of_Diamonds.pdf', 10, 11828);
INSERT INTO 'danceurl' VALUES (4442, 'http://www.rscds-twincities.org/perfrep.html#dance5', 10, 12639);
INSERT INTO 'danceurl' VALUES (4448, 'http://perso.wanadoo.fr/scots.in.france/dancesc.htm', 10, 12666);
INSERT INTO 'danceurl' VALUES (4449, 'http://perso.wanadoo.fr/scots.in.france/dancesc.htm', 10, 12667);
INSERT INTO 'danceurl' VALUES (5318, 'http://nebula.wsimg.com/ebc4fbd994e73520b8c31f9a0409ab94?AccessKeyId=B5EA6191A964E4BCD983&disposition=0&alloworigin=1', 10, 7795);
INSERT INTO 'danceurl' VALUES (4452, 'http://perso.wanadoo.fr/scots.in.france/dancesd.htm', 10, 12676);
INSERT INTO 'danceurl' VALUES (4453, 'http://perso.wanadoo.fr/scots.in.france/dancesd.htm', 10, 12677);
INSERT INTO 'danceurl' VALUES (4454, 'http://perso.wanadoo.fr/scots.in.france/dancesd.htm', 10, 12678);
INSERT INTO 'danceurl' VALUES (4455, 'http://perso.wanadoo.fr/scots.in.france/dancesd.htm', 10, 12679);
INSERT INTO 'danceurl' VALUES (4456, 'http://moirastacey.wordpress.com/5-heatherbrae/', 10, 12769);
INSERT INTO 'danceurl' VALUES (4460, 'https://www.rscdslondon.org.uk/sdata/dances/corriearrack.pdf', 10, 12816);
INSERT INTO 'danceurl' VALUES (4461, 'https://www.rscdslondon.org.uk/sdata/dances/donald_delight.pdf', 10, 12817);
INSERT INTO 'danceurl' VALUES (4462, 'https://www.rscdslondon.org.uk/sdata/dances/fiacaill.pdf', 10, 12818);
INSERT INTO 'danceurl' VALUES (4463, 'https://www.rscdslondon.org.uk/sdata/dances/hanselling.pdf', 10, 12819);
INSERT INTO 'danceurl' VALUES (4464, 'https://www.rscdslondon.org.uk/sdata/dances/gardener.pdf', 10, 12820);
INSERT INTO 'danceurl' VALUES (4465, 'https://www.rscdslondon.org.uk/sdata/dances/lord.pdf', 10, 12821);
INSERT INTO 'danceurl' VALUES (4466, 'https://www.rscdslondon.org.uk/sdata/dances/mill.pdf', 10, 12822);
INSERT INTO 'danceurl' VALUES (4467, 'https://www.rscdslondon.org.uk/sdata/dances/rigby.pdf', 10, 12823);
INSERT INTO 'danceurl' VALUES (4392, 'https://suepetyt.e-cribs.org/The_Dice_Dance.pdf', 10, 11893);
INSERT INTO 'danceurl' VALUES (4393, 'https://suepetyt.e-cribs.org/Red_Squirrel_Reel.pdf', 10, 11894);
INSERT INTO 'danceurl' VALUES (4398, 'https://suepetyt.e-cribs.org/The_Laird_of_Lochmaben.pdf', 10, 11899);
INSERT INTO 'danceurl' VALUES (4391, 'https://suepetyt.e-cribs.org/Mideltone_Silver.pdf', 10, 11892);
INSERT INTO 'danceurl' VALUES (4397, 'https://suepetyt.e-cribs.org/Queen_Elizabeth_of_Mey.pdf', 10, 11898);
INSERT INTO 'danceurl' VALUES (4394, 'https://suepetyt.e-cribs.org/Merton_Court_Medley.pdf', 10, 11895);
INSERT INTO 'danceurl' VALUES (4493, 'http://www.rscds-sf.org/resources/dances/LangdonKnot.1.pdf', 10, 12996);
INSERT INTO 'danceurl' VALUES (5422, 'https://my.strathspey.org/u/murrough/AlansRomp.pdf', 10, 18394);
INSERT INTO 'danceurl' VALUES (4506, 'https://suedan.com/dances/instructions/barbarasstrathspey.html', 10, 13149);
INSERT INTO 'danceurl' VALUES (4515, 'https://suedan.com/dances/instructions/blackpowderrifle.html', 10, 13158);
INSERT INTO 'danceurl' VALUES (4451, 'http://eddywest.nz/turnnsbe.html', 10, 12670);
INSERT INTO 'danceurl' VALUES (4489, 'https://8x32.e-cribs.org/index.php/a/miri-s-wedding', 10, 12929);
INSERT INTO 'danceurl' VALUES (4468, 'https://8x32.e-cribs.org/index.php/a/hasten-to-your-feet', 10, 12884);
INSERT INTO 'danceurl' VALUES (4498, 'https://8x32.e-cribs.org/index.php/a/just-a-lark', 10, 13002);
INSERT INTO 'danceurl' VALUES (4497, 'https://8x32.e-cribs.org/index.php/a/giants-of-foudland', 10, 13001);
INSERT INTO 'danceurl' VALUES (4496, 'https://8x32.e-cribs.org/index.php/a/blaine-s-double-date', 10, 13000);
INSERT INTO 'danceurl' VALUES (4495, 'https://8x32.e-cribs.org/index.php/a/two-s-company-three-s', 10, 12998);
INSERT INTO 'danceurl' VALUES (4443, 'https://8x32.e-cribs.org/index.php/a/the-founder', 10, 12640);
INSERT INTO 'danceurl' VALUES (4494, 'https://8x32.e-cribs.org/index.php/a/fenway-jig', 10, 12997);
INSERT INTO 'danceurl' VALUES (4459, 'https://8x32.e-cribs.org/index.php/a/dance-for-marjorie', 10, 12810);
INSERT INTO 'danceurl' VALUES (4503, 'https://8x32.e-cribs.org/index.php/a/silver-nutmeg', 10, 13104);
INSERT INTO 'danceurl' VALUES (4505, 'https://8x32.e-cribs.org/index.php/a/wee-bit-o-fun', 10, 13116);
INSERT INTO 'danceurl' VALUES (4504, 'https://8x32.e-cribs.org/index.php/a/saunter-in-savoy', 10, 13115);
INSERT INTO 'danceurl' VALUES (4458, 'https://8x32.e-cribs.org/index.php/a/whirlwind', 10, 12789);
INSERT INTO 'danceurl' VALUES (4499, 'https://8x32.e-cribs.org/index.php/a/bramble-jelly', 10, 13003);
INSERT INTO 'danceurl' VALUES (4508, 'https://suedan.com/dances/instructions/bubbaque.html', 10, 13151);
INSERT INTO 'danceurl' VALUES (4513, 'https://suedan.com/dances/instructions/catchifcan.html', 10, 13156);
INSERT INTO 'danceurl' VALUES (4519, 'https://suedan.com/dances/instructions/circlefriends.html', 10, 13162);
INSERT INTO 'danceurl' VALUES (4523, 'https://suedan.com/dances/instructions/coincollector.html', 10, 13166);
INSERT INTO 'danceurl' VALUES (4524, 'https://suedan.com/dances/instructions/dansreel.html', 10, 13167);
INSERT INTO 'danceurl' VALUES (4507, 'https://suedan.com/dances/instructions/eleanorsstrathspey.html', 10, 13150);
INSERT INTO 'danceurl' VALUES (4517, 'https://suedan.com/dances/instructions/fashiondesigner.html', 10, 13160);
INSERT INTO 'danceurl' VALUES (4512, 'https://suedan.com/dances/instructions/icedancing.html', 10, 13155);
INSERT INTO 'danceurl' VALUES (4514, 'https://suedan.com/dances/instructions/ladyisstar.html', 10, 13157);
INSERT INTO 'danceurl' VALUES (4526, 'https://suedan.com/dances/instructions/laurasreel.html', 10, 13169);
INSERT INTO 'danceurl' VALUES (4528, 'https://suedan.com/dances/instructions/mirrormirror.html', 10, 13171);
INSERT INTO 'danceurl' VALUES (4510, 'https://suedan.com/dances/instructions/olympicgold.html', 10, 13153);
INSERT INTO 'danceurl' VALUES (4511, 'https://suedan.com/dances/instructions/peppermill.html', 10, 13154);
INSERT INTO 'danceurl' VALUES (4518, 'https://suedan.com/dances/instructions/ropingwind.html', 10, 13161);
INSERT INTO 'danceurl' VALUES (4520, 'https://suedan.com/dances/instructions/ryetwist.html', 10, 13163);
INSERT INTO 'danceurl' VALUES (4527, 'https://suedan.com/dances/instructions/slightlyaskew.html', 10, 13170);
INSERT INTO 'danceurl' VALUES (4521, 'https://suedan.com/dances/instructions/snakebit.html', 10, 13164);
INSERT INTO 'danceurl' VALUES (4525, 'https://suedan.com/dances/instructions/wanderinggypsy.html', 10, 13168);
INSERT INTO 'danceurl' VALUES (5423, 'https://my.strathspey.org/u/murrough/HiddenHeart.pdf', 10, 18395);
INSERT INTO 'danceurl' VALUES (4573, 'http://my.strathspey.org/anselm/dances/missgranger.html', 10, 13301);
INSERT INTO 'danceurl' VALUES (4575, 'http://my.strathspey.org/anselm/dances/aerben.html', 10, 13303);
INSERT INTO 'danceurl' VALUES (4576, 'http://my.strathspey.org/anselm/dances/deldancie.html', 10, 13304);
INSERT INTO 'danceurl' VALUES (4577, 'http://www.scd-wuppertal.de/cms/upload/taenze/And_Again.pdf', 10, 13305);
INSERT INTO 'danceurl' VALUES (4578, 'http://www.scd-wuppertal.de/cms/upload/taenze/Dancing_on_Water.pdf', 10, 13306);
INSERT INTO 'danceurl' VALUES (4579, 'http://www.scd-wuppertal.de/cms/upload/taenze/Favourites_Partners_S4X32.pdf', 10, 13307);
INSERT INTO 'danceurl' VALUES (4580, 'http://www.scd-wuppertal.de/cms/upload/taenze/Foggy_Night_The.pdf', 10, 13308);
INSERT INTO 'danceurl' VALUES (4581, 'http://www.scd-wuppertal.de/cms/upload/taenze/Giradet_House.pdf', 10, 13309);
INSERT INTO 'danceurl' VALUES (4582, 'http://www.scd-wuppertal.de/cms/upload/taenze/Kays_Jig.pdf', 10, 13310);
INSERT INTO 'danceurl' VALUES (4583, 'http://www.scd-wuppertal.de/cms/upload/taenze/Mascads_Jig.pdf', 10, 13311);
INSERT INTO 'danceurl' VALUES (4584, 'http://www.scd-wuppertal.de/cms/upload/taenze/Secret_Wedding.pdf', 10, 13312);
INSERT INTO 'danceurl' VALUES (4585, 'http://www.scd-wuppertal.de/cms/upload/taenze/See_you_in_Arran.pdf', 10, 13313);
INSERT INTO 'danceurl' VALUES (4586, 'http://www.scd-wuppertal.de/cms/upload/taenze/Thank_You_Helen.pdf', 10, 13314);
INSERT INTO 'danceurl' VALUES (4589, 'http://www.rscdsleeds.org.uk/SearchResults.asp?Crib=Branches', 10, 13353);
INSERT INTO 'danceurl' VALUES (4591, 'http://www.rscds-sf.org/resources/dances/Kathleen%20McAdam%27s%20Scroll.pdf', 10, 13355);
INSERT INTO 'danceurl' VALUES (4592, 'http://www.rscds-sf.org/resources/dances/Blue%20Moon%20Rendezvous.pdf', 10, 13356);
INSERT INTO 'danceurl' VALUES (4595, 'http://www.scottishdance.net/dances/Book/Triskelion.pdf', 10, 13547);
INSERT INTO 'danceurl' VALUES (4604, 'http://www.anselms.net/SCD/wbook/wbook.pdf', 10, 13692);
INSERT INTO 'danceurl' VALUES (4598, 'http://my.strathspey.org/u/anselm/dances/tripletreat/', 10, 13628);
INSERT INTO 'danceurl' VALUES (4572, 'http://my.strathspey.org/u/anselm/dances/goldensnitch/', 10, 13300);
INSERT INTO 'danceurl' VALUES (4574, 'http://my.strathspey.org/anselm/u/dances/otterystc/', 10, 13302);
INSERT INTO 'danceurl' VALUES (4603, 'http://my.strathspey.org/u/anselm/dances/llap/', 10, 13680);
INSERT INTO 'danceurl' VALUES (4569, 'https://8x32.e-cribs.org/index.php/a/miss-anne-aldred-s-strathspey', 10, 13277);
INSERT INTO 'danceurl' VALUES (4564, 'https://8x32.e-cribs.org/index.php/a/timbit-for-george', 10, 13218);
INSERT INTO 'danceurl' VALUES (4568, 'https://8x32.e-cribs.org/index.php/a/timbit-for-janis', 10, 13276);
INSERT INTO 'danceurl' VALUES (4570, 'https://8x32.e-cribs.org/index.php/a/rug-beater', 10, 13278);
INSERT INTO 'danceurl' VALUES (4602, 'https://8x32.e-cribs.org/index.php/a/the-city-of-christchurch', 10, 13679);
INSERT INTO 'danceurl' VALUES (4599, 'https://8x32.e-cribs.org/index.php/a/examination-fever', 10, 13643);
INSERT INTO 'danceurl' VALUES (4588, 'https://8x32.e-cribs.org/index.php/a/shoplifting-seagulls', 10, 13352);
INSERT INTO 'danceurl' VALUES (4571, 'https://www.rscdslondon.org.uk/sdata/dances/class.pdf', 10, 13283);
INSERT INTO 'danceurl' VALUES (4600, 'https://my.strathspey.org/u/anselm/dances/jetsethp/', 10, 13644);
INSERT INTO 'danceurl' VALUES (4447, 'https://suepetyt.e-cribs.org/The_Annan_Reel.pdf', 10, 12665);
INSERT INTO 'danceurl' VALUES (4446, 'https://suepetyt.e-cribs.org/The_Moffat_Jig.pdf', 10, 12664);
INSERT INTO 'danceurl' VALUES (4445, 'https://suepetyt.e-cribs.org/The_Hartfell_Jig.pdf', 10, 12663);
INSERT INTO 'danceurl' VALUES (4444, 'https://suepetyt.e-cribs.org/Miss_Betty_Ferguson_of_Dumfries.pdf', 10, 12662);
INSERT INTO 'danceurl' VALUES (4590, 'https://8x32.e-cribs.org/index.php/a/irish-bride', 10, 13354);
INSERT INTO 'danceurl' VALUES (4597, 'https://8x32.e-cribs.org/index.php/a/high-society', 10, 13587);
INSERT INTO 'danceurl' VALUES (4593, 'http://www.davewiesler.com/HH_dances_w_FMK&SW.pdf', 10, 13450);
INSERT INTO 'danceurl' VALUES (4567, 'http://www.waverleyscottishsociety.com/Kennedy%20Castle.docx', 10, 13232);
INSERT INTO 'danceurl' VALUES (4537, 'https://suedan.com/dances/instructions/barnyarddance.html', 10, 13180);
INSERT INTO 'danceurl' VALUES (4544, 'https://suedan.com/dances/instructions/biloxi.html', 10, 13187);
INSERT INTO 'danceurl' VALUES (4563, 'https://suedan.com/dances/instructions/bubblesort.html', 10, 13206);
INSERT INTO 'danceurl' VALUES (4534, 'https://suedan.com/dances/instructions/calligraphy.html', 10, 13177);
INSERT INTO 'danceurl' VALUES (4560, 'https://suedan.com/dances/instructions/charade.html', 10, 13203);
INSERT INTO 'danceurl' VALUES (4562, 'https://suedan.com/dances/instructions/cloverleaf.html', 10, 13205);
INSERT INTO 'danceurl' VALUES (4547, 'https://suedan.com/dances/instructions/cottoncandy.html', 10, 13190);
INSERT INTO 'danceurl' VALUES (4557, 'https://suedan.com/dances/instructions/doubleduty.html', 10, 13200);
INSERT INTO 'danceurl' VALUES (4546, 'https://suedan.com/dances/instructions/engagementring.html', 10, 13189);
INSERT INTO 'danceurl' VALUES (4538, 'https://suedan.com/dances/instructions/followme.html', 10, 13181);
INSERT INTO 'danceurl' VALUES (4550, 'https://suedan.com/dances/instructions/inverlochy.html', 10, 13193);
INSERT INTO 'danceurl' VALUES (4556, 'https://suedan.com/dances/instructions/irregularprogression.html', 10, 13199);
INSERT INTO 'danceurl' VALUES (4530, 'https://suedan.com/dances/instructions/jennylee.html', 10, 13173);
INSERT INTO 'danceurl' VALUES (4553, 'https://suedan.com/dances/instructions/leadinglady.html', 10, 13196);
INSERT INTO 'danceurl' VALUES (4554, 'https://suedan.com/dances/instructions/missnora.html', 10, 13197);
INSERT INTO 'danceurl' VALUES (4545, 'https://suedan.com/dances/instructions/montyslady.html', 10, 13188);
INSERT INTO 'danceurl' VALUES (4549, 'https://suedan.com/dances/instructions/noghosts.html', 10, 13192);
INSERT INTO 'danceurl' VALUES (4543, 'https://suedan.com/dances/instructions/paulstournee.html', 10, 13186);
INSERT INTO 'danceurl' VALUES (4551, 'https://suedan.com/dances/instructions/quirinsreel.html', 10, 13194);
INSERT INTO 'danceurl' VALUES (4548, 'https://suedan.com/dances/instructions/roundnround.html', 10, 13191);
INSERT INTO 'danceurl' VALUES (4552, 'https://suedan.com/dances/instructions/rovinwillie.html', 10, 13195);
INSERT INTO 'danceurl' VALUES (4558, 'https://suedan.com/dances/instructions/sandsculptures.html', 10, 13201);
INSERT INTO 'danceurl' VALUES (4559, 'https://suedan.com/dances/instructions/shadowsonmoon.html', 10, 13202);
INSERT INTO 'danceurl' VALUES (4539, 'https://suedan.com/dances/instructions/silksatin.html', 10, 13182);
INSERT INTO 'danceurl' VALUES (4561, 'https://suedan.com/dances/instructions/snakeladder.html', 10, 13204);
INSERT INTO 'danceurl' VALUES (4531, 'https://suedan.com/dances/instructions/teach1.html', 10, 13174);
INSERT INTO 'danceurl' VALUES (4532, 'https://suedan.com/dances/instructions/teach2.html', 10, 13175);
INSERT INTO 'danceurl' VALUES (4533, 'https://suedan.com/dances/instructions/teach3.html', 10, 13176);
INSERT INTO 'danceurl' VALUES (4535, 'https://suedan.com/dances/instructions/triptoohio.html', 10, 13178);
INSERT INTO 'danceurl' VALUES (4541, 'https://suedan.com/dances/instructions/weirdsisters.html', 10, 13184);
INSERT INTO 'danceurl' VALUES (4529, 'https://suedan.com/dances/instructions/wherebuffaloroam.html', 10, 13172);
INSERT INTO 'danceurl' VALUES (4536, 'https://suedan.com/dances/instructions/whirlwind.html', 10, 13179);
INSERT INTO 'danceurl' VALUES (4542, 'https://suedan.com/dances/instructions/threescompany.html', 10, 13185);
INSERT INTO 'danceurl' VALUES (4610, 'http://www.rscds-norwich.org.uk/rscds50annivdances.html', 10, 13737);
INSERT INTO 'danceurl' VALUES (4605, 'http://www.rscds-norwich.org.uk/rscds50annivdances.html', 10, 13732);
INSERT INTO 'danceurl' VALUES (4606, 'http://www.rscds-norwich.org.uk/rscds50annivdances.html', 10, 13733);
INSERT INTO 'danceurl' VALUES (4607, 'http://www.rscds-norwich.org.uk/rscds50annivdances.html', 10, 13734);
INSERT INTO 'danceurl' VALUES (4608, 'http://www.rscds-norwich.org.uk/rscds50annivdances.html', 10, 13735);
INSERT INTO 'danceurl' VALUES (4609, 'http://www.rscds-norwich.org.uk/rscds50annivdances.html', 10, 13736);
INSERT INTO 'danceurl' VALUES (4611, 'http://www.rscds-norwich.org.uk/rscds50annivdances.html', 10, 13738);
INSERT INTO 'danceurl' VALUES (4613, 'http://www.rscds-norwich.org.uk/rscds50annivdances.html', 10, 13741);
INSERT INTO 'danceurl' VALUES (4614, 'http://www.wdsa.co.uk/Wembleys%20GEM.htm', 10, 13767);
INSERT INTO 'danceurl' VALUES (4615, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/book3.pdf', 10, 13779);
INSERT INTO 'danceurl' VALUES (4616, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/book3.pdf', 10, 13781);
INSERT INTO 'danceurl' VALUES (4618, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/book3.pdf', 10, 13783);
INSERT INTO 'danceurl' VALUES (4619, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/book3.pdf', 10, 13784);
INSERT INTO 'danceurl' VALUES (4620, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/book3.pdf', 10, 13785);
INSERT INTO 'danceurl' VALUES (4621, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/book3.pdf', 10, 13786);
INSERT INTO 'danceurl' VALUES (4622, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/book3.pdf', 10, 13787);
INSERT INTO 'danceurl' VALUES (4623, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/book3.pdf', 10, 13788);
INSERT INTO 'danceurl' VALUES (4624, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 13789);
INSERT INTO 'danceurl' VALUES (4625, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 13790);
INSERT INTO 'danceurl' VALUES (4626, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 13791);
INSERT INTO 'danceurl' VALUES (4627, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 13792);
INSERT INTO 'danceurl' VALUES (4628, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 13793);
INSERT INTO 'danceurl' VALUES (4629, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 13794);
INSERT INTO 'danceurl' VALUES (4630, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 13795);
INSERT INTO 'danceurl' VALUES (4631, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 13796);
INSERT INTO 'danceurl' VALUES (4632, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 13797);
INSERT INTO 'danceurl' VALUES (4633, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 13798);
INSERT INTO 'danceurl' VALUES (4634, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 13800);
INSERT INTO 'danceurl' VALUES (4635, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 13801);
INSERT INTO 'danceurl' VALUES (4636, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 13803);
INSERT INTO 'danceurl' VALUES (4641, 'http://www.rscds-sf.org/resources/dances/OccidentalCeilidh.pdf', 10, 14328);
INSERT INTO 'danceurl' VALUES (4642, 'http://www.rscds-sf.org/resources/dances/Miracle%20in%20Merrill.pdf', 10, 14330);
INSERT INTO 'danceurl' VALUES (4644, 'http://www.rscds-sf.org/resources/dances/Stargazers.pdf', 10, 14332);
INSERT INTO 'danceurl' VALUES (4645, 'http://www.rscds-sf.org/resources/dances/RETIRINGLASS.pdf', 10, 14333);
INSERT INTO 'danceurl' VALUES (4646, 'http://www.rscds-sf.org/resources/dances/TheDancingQ-Tip.pdf', 10, 14334);
INSERT INTO 'danceurl' VALUES (4647, 'http://www.rscds-sf.org/resources/dances/GranvilleBridge.pdf', 10, 14335);
INSERT INTO 'danceurl' VALUES (4648, 'http://www.rscds-sf.org/resources/dances/TheHomecomingReel.pdf', 10, 14336);
INSERT INTO 'danceurl' VALUES (4649, 'http://www.rscds-twincities.org/annualball02.html', 10, 14338);
INSERT INTO 'danceurl' VALUES (4640, 'http://www.strathspey.org/lists/strathspey%40strathspey.org/m/52576/', 10, 14318);
INSERT INTO 'danceurl' VALUES (4601, 'http://my.strathspey.org/u/anselm/dances/tobias/', 10, 13645);
INSERT INTO 'danceurl' VALUES (3806, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/flight-of-the-falcon.html', 10, 2222);
INSERT INTO 'danceurl' VALUES (5426, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/Well_orig.pdf', 10, 2671);
INSERT INTO 'danceurl' VALUES (4682, 'https://suepetyt.e-cribs.org/Fairyknowe_Lodge.pdf', 10, 14398);
INSERT INTO 'danceurl' VALUES (4643, 'https://www.rscds-sf.org/resources/dances/BillMcIversFancy.htm', 10, 14331);
INSERT INTO 'danceurl' VALUES (4732, 'http://www.hayesscottish.org.uk/Olive%20MacNeil%20of%20Hayes.doc', 10, 14799);
INSERT INTO 'danceurl' VALUES (4734, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 7333);
INSERT INTO 'danceurl' VALUES (4735, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14821);
INSERT INTO 'danceurl' VALUES (4736, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14822);
INSERT INTO 'danceurl' VALUES (4737, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14823);
INSERT INTO 'danceurl' VALUES (4738, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14826);
INSERT INTO 'danceurl' VALUES (4739, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14827);
INSERT INTO 'danceurl' VALUES (4740, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14828);
INSERT INTO 'danceurl' VALUES (4741, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14829);
INSERT INTO 'danceurl' VALUES (4680, 'http://my.strathspey.org/u/anselm/dances/juggling/', 10, 14386);
INSERT INTO 'danceurl' VALUES (4671, 'https://8x32.e-cribs.org/index.php/a/46664-jig', 10, 14365);
INSERT INTO 'danceurl' VALUES (4653, 'https://8x32.e-cribs.org/index.php/a/pumpking-baker', 10, 14347);
INSERT INTO 'danceurl' VALUES (4650, 'https://8x32.e-cribs.org/index.php/a/rosie-s-ceilidh', 10, 14342);
INSERT INTO 'danceurl' VALUES (4673, 'https://8x32.e-cribs.org/index.php/a/as-cedar-falls-so-falls', 10, 14367);
INSERT INTO 'danceurl' VALUES (4637, 'https://8x32.e-cribs.org/index.php/a/the-erlangen-reel', 10, 13804);
INSERT INTO 'danceurl' VALUES (4674, 'https://8x32.e-cribs.org/index.php/a/the-kolbls-reel', 10, 14368);
INSERT INTO 'danceurl' VALUES (4659, 'https://8x32.e-cribs.org/index.php/a/ladebraes', 10, 14353);
INSERT INTO 'danceurl' VALUES (4660, 'https://8x32.e-cribs.org/index.php/a/tribute-to-fred-demarse', 10, 14354);
INSERT INTO 'danceurl' VALUES (4654, 'https://8x32.e-cribs.org/index.php/a/auchindrain', 10, 14348);
INSERT INTO 'danceurl' VALUES (4678, 'https://8x32.e-cribs.org/index.php/a/ginger-sharks', 10, 14384);
INSERT INTO 'danceurl' VALUES (4664, 'https://8x32.e-cribs.org/index.php/a/lairds-chain', 10, 14358);
INSERT INTO 'danceurl' VALUES (4663, 'https://8x32.e-cribs.org/index.php/a/lairds-diamond', 10, 14357);
INSERT INTO 'danceurl' VALUES (4651, 'https://8x32.e-cribs.org/index.php/a/miss-ilona-brown', 10, 14345);
INSERT INTO 'danceurl' VALUES (4652, 'https://8x32.e-cribs.org/index.php/a/the-mentor', 10, 14346);
INSERT INTO 'danceurl' VALUES (4655, 'https://8x32.e-cribs.org/index.php/a/mary-stewart-ashworth', 10, 14349);
INSERT INTO 'danceurl' VALUES (4656, 'https://8x32.e-cribs.org/index.php/a/spice-it-up', 10, 14350);
INSERT INTO 'danceurl' VALUES (4661, 'https://8x32.e-cribs.org/index.php/a/old-ba-game', 10, 14355);
INSERT INTO 'danceurl' VALUES (4657, 'https://8x32.e-cribs.org/index.php/a/miss-dow-s-strathspey', 10, 14351);
INSERT INTO 'danceurl' VALUES (4658, 'https://8x32.e-cribs.org/index.php/a/twinkle-in-his-eye', 10, 14352);
INSERT INTO 'danceurl' VALUES (4662, 'https://8x32.e-cribs.org/index.php/a/audrey-peter-s-jubilee', 10, 14356);
INSERT INTO 'danceurl' VALUES (4665, 'https://8x32.e-cribs.org/index.php/a/triangle-reel', 10, 14359);
INSERT INTO 'danceurl' VALUES (4638, 'https://8x32.e-cribs.org/index.php/a/the-falls-of-lana', 10, 13810);
INSERT INTO 'danceurl' VALUES (4667, 'https://8x32.e-cribs.org/index.php/a/miss-mcburnie-s-wedding', 10, 14361);
INSERT INTO 'danceurl' VALUES (4668, 'https://8x32.e-cribs.org/index.php/a/laird-jim-s-60th', 10, 14362);
INSERT INTO 'danceurl' VALUES (4679, 'https://8x32.e-cribs.org/index.php/a/graduation-reel', 10, 14385);
INSERT INTO 'danceurl' VALUES (4676, 'https://8x32.e-cribs.org/index.php/a/just-a-dozen', 10, 14382);
INSERT INTO 'danceurl' VALUES (4675, 'https://8x32.e-cribs.org/index.php/a/redfoot-s-ramble', 10, 14379);
INSERT INTO 'danceurl' VALUES (4677, 'https://8x32.e-cribs.org/index.php/a/corners-hello', 10, 14383);
INSERT INTO 'danceurl' VALUES (4670, 'https://8x32.e-cribs.org/index.php/a/laird-of-dalnair', 10, 14364);
INSERT INTO 'danceurl' VALUES (4672, 'https://8x32.e-cribs.org/index.php/a/ke-nako-it-is-time', 10, 14366);
INSERT INTO 'danceurl' VALUES (4743, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14831);
INSERT INTO 'danceurl' VALUES (4745, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14833);
INSERT INTO 'danceurl' VALUES (4746, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14834);
INSERT INTO 'danceurl' VALUES (4747, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14835);
INSERT INTO 'danceurl' VALUES (4748, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14836);
INSERT INTO 'danceurl' VALUES (4749, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14837);
INSERT INTO 'danceurl' VALUES (4750, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14838);
INSERT INTO 'danceurl' VALUES (4751, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14839);
INSERT INTO 'danceurl' VALUES (4752, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14840);
INSERT INTO 'danceurl' VALUES (4753, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14841);
INSERT INTO 'danceurl' VALUES (4754, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14842);
INSERT INTO 'danceurl' VALUES (4755, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14843);
INSERT INTO 'danceurl' VALUES (4757, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 9144);
INSERT INTO 'danceurl' VALUES (4758, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14845);
INSERT INTO 'danceurl' VALUES (4759, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14846);
INSERT INTO 'danceurl' VALUES (4760, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14847);
INSERT INTO 'danceurl' VALUES (4761, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14848);
INSERT INTO 'danceurl' VALUES (4762, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14849);
INSERT INTO 'danceurl' VALUES (4763, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14850);
INSERT INTO 'danceurl' VALUES (4765, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14852);
INSERT INTO 'danceurl' VALUES (4766, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14853);
INSERT INTO 'danceurl' VALUES (4767, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14854);
INSERT INTO 'danceurl' VALUES (4768, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14855);
INSERT INTO 'danceurl' VALUES (4769, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14856);
INSERT INTO 'danceurl' VALUES (4770, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14857);
INSERT INTO 'danceurl' VALUES (4771, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14858);
INSERT INTO 'danceurl' VALUES (4772, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14859);
INSERT INTO 'danceurl' VALUES (4774, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14861);
INSERT INTO 'danceurl' VALUES (4775, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14862);
INSERT INTO 'danceurl' VALUES (4936, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16385);
INSERT INTO 'danceurl' VALUES (4776, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14863);
INSERT INTO 'danceurl' VALUES (4777, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14864);
INSERT INTO 'danceurl' VALUES (4778, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14865);
INSERT INTO 'danceurl' VALUES (4779, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14866);
INSERT INTO 'danceurl' VALUES (4780, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14867);
INSERT INTO 'danceurl' VALUES (4781, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14868);
INSERT INTO 'danceurl' VALUES (4782, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14869);
INSERT INTO 'danceurl' VALUES (4783, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14870);
INSERT INTO 'danceurl' VALUES (4784, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14871);
INSERT INTO 'danceurl' VALUES (4785, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14872);
INSERT INTO 'danceurl' VALUES (4786, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14873);
INSERT INTO 'danceurl' VALUES (4787, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14874);
INSERT INTO 'danceurl' VALUES (4788, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14875);
INSERT INTO 'danceurl' VALUES (4789, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14876);
INSERT INTO 'danceurl' VALUES (4790, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14877);
INSERT INTO 'danceurl' VALUES (4791, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14878);
INSERT INTO 'danceurl' VALUES (4792, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14879);
INSERT INTO 'danceurl' VALUES (4793, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14880);
INSERT INTO 'danceurl' VALUES (4794, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr.....', 10, 14881);
INSERT INTO 'danceurl' VALUES (4795, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14882);
INSERT INTO 'danceurl' VALUES (4796, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14883);
INSERT INTO 'danceurl' VALUES (4797, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14884);
INSERT INTO 'danceurl' VALUES (4798, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14885);
INSERT INTO 'danceurl' VALUES (4799, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14886);
INSERT INTO 'danceurl' VALUES (4800, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14887);
INSERT INTO 'danceurl' VALUES (4801, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14888);
INSERT INTO 'danceurl' VALUES (4802, 'http://docs.google.com/Doc?docid=0Aba-vCIa2vuIZGZ2ajV6OWJfMzJmczZmazhkZg&hl=fr', 10, 14889);
INSERT INTO 'danceurl' VALUES (5319, 'http://nebula.wsimg.com/5ff7d7f819f341939a29a033d0b5c147?AccessKeyId=B5EA6191A964E4BCD983&disposition=0&alloworigin=1', 10, 17887);
INSERT INTO 'danceurl' VALUES (4806, 'http://www.rscdsvancouver.org/timetospare.pdf', 10, 14994);
INSERT INTO 'danceurl' VALUES (4807, 'http://thesundayclass.org.uk/TIARAS%20AND%20TEAPOTS.html', 10, 15020);
INSERT INTO 'danceurl' VALUES (4808, 'http://thesundayclass.org.uk/JUST%20A%20DOZEN.html', 10, 14382);
INSERT INTO 'danceurl' VALUES (4809, 'http://thesundayclass.org.uk/CHRISS%20CROSS.html', 10, 15021);
INSERT INTO 'danceurl' VALUES (4810, 'http://thesundayclass.org.uk/LAVENDER%20STRATHSPEY.html', 10, 14955);
INSERT INTO 'danceurl' VALUES (4961, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16410);
INSERT INTO 'danceurl' VALUES (4811, 'http://thesundayclass.org.uk/BEES%20THEY%20ARE%20A%20DRUMMIN.html', 10, 15022);
INSERT INTO 'danceurl' VALUES (4812, 'http://thesundayclass.org.uk/JANETS%20CUP%20OF%20TEA.html', 10, 15023);
INSERT INTO 'danceurl' VALUES (5320, 'http://nebula.wsimg.com/7559db101cd2587580c55a1889a2c714?AccessKeyId=B5EA6191A964E4BCD983&disposition=0&alloworigin=1', 10, 16522);
INSERT INTO 'danceurl' VALUES (5321, 'http://nebula.wsimg.com/c742654bf74eed15404811f458a6c24b?AccessKeyId=B5EA6191A964E4BCD983&disposition=0&alloworigin=1', 10, 18048);
INSERT INTO 'danceurl' VALUES (4819, 'http://www.scottishfiddle.org/tullochgorum/tulldances.html', 10, 14295);
INSERT INTO 'danceurl' VALUES (4822, 'http://www.highlandmistdancers.org/HM3goldenoldies.html', 10, 15263);
INSERT INTO 'danceurl' VALUES (4824, 'http://www.rscdsvancouver.org/downloads/20131208c%20Gleneagles%20Ball%20Cribs.pdf', 10, 15267);
INSERT INTO 'danceurl' VALUES (3952, 'http://www.oocities.org/colosseum/midfield/Midfield/3705/Reelofthe51st.htm', 10, 5525);
INSERT INTO 'danceurl' VALUES (4825, 'http://portlandscottishdancers.org/dances.html#dance_53bf17c1cd0f16fd716b8048277a23c6bf070bc7', 10, 15314);
INSERT INTO 'danceurl' VALUES (4827, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/gypsy-girls-headscarf.html', 10, 15329);
INSERT INTO 'danceurl' VALUES (4828, 'http://www.bstk.hu/book/14-13.htm', 10, 15330);
INSERT INTO 'danceurl' VALUES (4612, 'http://www.rscds-norwich.org.uk/rscds50annivdances.html', 10, 13740);
INSERT INTO 'danceurl' VALUES (4834, 'http://web.archive.org/web/20041216100736/http://www.opendoor.com/heatherandrose/dances_brookeandchris.html#dish', 10, 15358);
INSERT INTO 'danceurl' VALUES (4838, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/twenty-candles-for-iberia.html', 10, 15378);
INSERT INTO 'danceurl' VALUES (4839, 'http://www.rscdswinnipeg.ca/docs/April32014programme.pdf', 10, 15398);
INSERT INTO 'danceurl' VALUES (4843, 'http://my.strathspey.org/dd/dance/15470/', 10, 15470);
INSERT INTO 'danceurl' VALUES (4844, 'http://www.lulu.com/shop/search.ep?type=&keyWords=longwood+collection&x=3&y=7&sitesearch=lulu.com&q=', 10, 15494);
INSERT INTO 'danceurl' VALUES (4845, 'http://sprott.physics.wisc.edu/mecds/ScotBook/AnnLindseysStrathspey.html', 10, 9042);
INSERT INTO 'danceurl' VALUES (4846, 'http://sprott.physics.wisc.edu/mecds/scotbook/SantaBarbara.html', 10, 15527);
INSERT INTO 'danceurl' VALUES (4847, 'http://sprott.physics.wisc.edu/mecds/scotbook/ByrnesReel.html', 10, 8863);
INSERT INTO 'danceurl' VALUES (4852, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/snowman.html', 10, 15569);
INSERT INTO 'danceurl' VALUES (4853, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/snow-in-october.html', 10, 15570);
INSERT INTO 'danceurl' VALUES (4850, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/glacier-express.html', 10, 15567);
INSERT INTO 'danceurl' VALUES (4854, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/snowball-fight.html', 10, 15571);
INSERT INTO 'danceurl' VALUES (4855, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/flakes-on-the-road.html', 10, 15572);
INSERT INTO 'danceurl' VALUES (4856, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/falling-leaves.html', 10, 15573);
INSERT INTO 'danceurl' VALUES (4857, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/first-snowdrops.html', 10, 15331);
INSERT INTO 'danceurl' VALUES (4813, 'https://www.scottishdance.net/dances/ThePrideOfDunblane.pdf', 10, 15097);
INSERT INTO 'danceurl' VALUES (4815, 'https://suepetyt.e-cribs.org/Welcome_Home.pdf', 10, 15148);
INSERT INTO 'danceurl' VALUES (4820, 'https://suepetyt.e-cribs.org/The_Kaleidoscope_Reel.pdf', 10, 12291);
INSERT INTO 'danceurl' VALUES (3950, 'http://suepetyt.e-cribs.org/Quick_and_Easy.pdf', 10, 5438);
INSERT INTO 'danceurl' VALUES (4862, 'http://www.thesundayclass.org.uk/SUNSHINE%20IN%20LAGOS.html', 10, 15600);
INSERT INTO 'danceurl' VALUES (4863, 'http://www.scd.za.net/home/dance-instructions', 10, 15622);
INSERT INTO 'danceurl' VALUES (4864, 'https://www.dropbox.com/s/cettkzxu6v63cpv/Farewell%20to%2049%20-%20R32%203c-4c%20-%20Bonn%20%2B%20Cologne%20SCD%20groups%202014.pdf?dl=0', 10, 15619);
INSERT INTO 'danceurl' VALUES (4865, 'http://www.bracknellreelclub.org.uk/douglas/rodneycelebration.html', 10, 15611);
INSERT INTO 'danceurl' VALUES (4866, 'http://bridportscottishdancers.org.uk/', 10, 15656);
INSERT INTO 'danceurl' VALUES (4869, 'http://www.thesundayclass.org.uk/FESTIVAL%20DREAM.html', 10, 15657);
INSERT INTO 'danceurl' VALUES (4870, 'http://www.zscdc.ch/docs/eng/just_for_you.pdf', 10, 15271);
INSERT INTO 'danceurl' VALUES (5323, 'https://tunes.e-cribs.org/Walking_on_Clouds.pdf', 10, 15123);
INSERT INTO 'danceurl' VALUES (5324, 'https://tunes.e-cribs.org/Visitors_from_York.pdf', 10, 15100);
INSERT INTO 'danceurl' VALUES (4875, 'http://www.thesundayclass.org.uk/CALM%20BEFORE%20STORM.html', 10, 15913);
INSERT INTO 'danceurl' VALUES (5325, 'https://tunes.e-cribs.org/Urisa_s_Strathspey.pdf', 10, 17946);
INSERT INTO 'danceurl' VALUES (4880, 'http://www.rscds-atlanta.org/petronella/201008.pdf', 10, 16052);
INSERT INTO 'danceurl' VALUES (4881, 'http://www.rscdsleeds.org.uk/Newsletter/RSCDS%20Newsletter%2031.pdf', 10, 13756);
INSERT INTO 'danceurl' VALUES (4826, 'http://eddywest.nz/ivyleaf.html', 10, 11360);
INSERT INTO 'danceurl' VALUES (4848, 'http://eddywest.nz/whgscot.html', 10, 15538);
INSERT INTO 'danceurl' VALUES (4840, 'https://8x32.e-cribs.org/index.php/a/the-road-to-scurdie-ness', 10, 15412);
INSERT INTO 'danceurl' VALUES (4879, 'http://www.rscds-swws.org/news/stories/PlethoraPinatas.htm', 10, 16025);
INSERT INTO 'danceurl' VALUES (4878, 'http://hh2f2ns.wixsite.com/frederick-scd/dances-g', 10, 16018);
INSERT INTO 'danceurl' VALUES (4877, 'http://hh2f2ns.wixsite.com/frederick-scd/dances-w', 10, 16017);
INSERT INTO 'danceurl' VALUES (4842, 'https://8x32.e-cribs.org/index.php/a/janice', 10, 15444);
INSERT INTO 'danceurl' VALUES (4841, 'https://8x32.e-cribs.org/index.php/a/the-battle-of-trafalgar', 10, 15430);
INSERT INTO 'danceurl' VALUES (4821, 'https://8x32.e-cribs.org/index.php/a/swirling-leaves', 10, 15231);
INSERT INTO 'danceurl' VALUES (4817, 'https://8x32.e-cribs.org/index.php/a/minister-on-the-mississippi', 10, 14987);
INSERT INTO 'danceurl' VALUES (4818, 'https://8x32.e-cribs.org/index.php/a/maggie-and-caitlin', 10, 14993);
INSERT INTO 'danceurl' VALUES (4832, 'http://www.members.westnet.com.au/trevanne/rscdswa/dances/Emmett''s_Chase.pdf', 15, 14363);
INSERT INTO 'danceurl' VALUES (3933, 'https://dances.e-cribs.org/Zytglogge.pdf', 10, 4799);
INSERT INTO 'danceurl' VALUES (4830, 'https://sites.google.com/site/thefollyofrogues/cusrc-reelwiki/miss-ella-catherine-hughes', 10, 15333);
INSERT INTO 'danceurl' VALUES (4829, 'https://suedan.com/dances/instructions/twistoffate.html', 10, 15332);
INSERT INTO 'danceurl' VALUES (4256, 'http://www.macrudi.de/resources/dances/carnival.pdf', 10, 10494);
INSERT INTO 'danceurl' VALUES (4068, 'http://www.macrudi.de/resources/dances/teapots.pdf', 10, 8724);
INSERT INTO 'danceurl' VALUES (4136, 'http://www.macrudi.de/resources/dances/tripdrew.pdf', 10, 9446);
INSERT INTO 'danceurl' VALUES (4882, 'http://www.minicrib.org.uk/Publications/BHS%209%20for%202015.pdf', 10, 16117);
INSERT INTO 'danceurl' VALUES (4883, 'http://www.minicrib.org.uk/Publications/BHS%209%20for%202015.pdf', 10, 16118);
INSERT INTO 'danceurl' VALUES (4884, 'http://www.minicrib.org.uk/Publications/BHS%209%20for%202015.pdf', 10, 16119);
INSERT INTO 'danceurl' VALUES (4885, 'http://www.minicrib.org.uk/Publications/BHS%209%20for%202015.pdf', 10, 16120);
INSERT INTO 'danceurl' VALUES (4886, 'http://www.minicrib.org.uk/Publications/BHS%209%20for%202015.pdf', 10, 16121);
INSERT INTO 'danceurl' VALUES (4887, 'http://www.minicrib.org.uk/Publications/BHS%209%20for%202015.pdf', 10, 16122);
INSERT INTO 'danceurl' VALUES (4888, 'http://www.minicrib.org.uk/Publications/BHS%209%20for%202015.pdf', 10, 16123);
INSERT INTO 'danceurl' VALUES (4889, 'http://www.minicrib.org.uk/Publications/BHS%209%20for%202015.pdf', 10, 16124);
INSERT INTO 'danceurl' VALUES (4890, 'http://www.minicrib.org.uk/Publications/BHS%209%20for%202015.pdf', 10, 16125);
INSERT INTO 'danceurl' VALUES (4891, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/st-magnus-quadrille.html', 10, 16158);
INSERT INTO 'danceurl' VALUES (4892, 'http://www.bstk.hu/flowers-of-ildiko/', 10, 16176);
INSERT INTO 'danceurl' VALUES (4893, 'http://www.bstk.hu/metro4/', 10, 16177);
INSERT INTO 'danceurl' VALUES (4894, 'http://camberleyreelclub.org.uk/Frames.htm', 10, 16182);
INSERT INTO 'danceurl' VALUES (4895, 'http://www.strathspey.org/lists/strathspey%40strathspey.org/t/17883/', 10, 9114);
INSERT INTO 'danceurl' VALUES (4896, 'http://www.rscds-seattle.org/ftworden/The%20RossKay%20Strathspey%20-Ft%20Worden%202009.pdf', 10, 14672);
INSERT INTO 'danceurl' VALUES (4898, 'http://www.scottishcountrydance.net/2014/12/sturts-desert-rose.html', 10, 6367);
INSERT INTO 'danceurl' VALUES (4899, 'http://www.scottishcountrydance.net/2014/12/the-quiet-achiever.html', 10, 5440);
INSERT INTO 'danceurl' VALUES (4900, 'http://www.scottishcountrydance.net/2014/12/mrs-henrys-bonnet.html', 10, 7469);
INSERT INTO 'danceurl' VALUES (4901, 'http://www.scottishcountrydance.net/2014/12/mairis-divorce.html', 10, 9911);
INSERT INTO 'danceurl' VALUES (4902, 'http://www.scottishcountrydance.net/2014/12/londons-turning.html', 10, 16257);
INSERT INTO 'danceurl' VALUES (4903, 'http://www.scottishcountrydance.net/2014/12/eighteen-years-on.html', 10, 16258);
INSERT INTO 'danceurl' VALUES (4904, 'http://www.scottishcountrydance.net/2014/12/courtney-jane.html', 10, 14394);
INSERT INTO 'danceurl' VALUES (4905, 'http://www.scottishcountrydance.net/2014/12/the-copthorne-steamie.html', 10, 16259);
INSERT INTO 'danceurl' VALUES (4915, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16365);
INSERT INTO 'danceurl' VALUES (4916, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16366);
INSERT INTO 'danceurl' VALUES (4917, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16367);
INSERT INTO 'danceurl' VALUES (4918, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16368);
INSERT INTO 'danceurl' VALUES (4919, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 11659);
INSERT INTO 'danceurl' VALUES (4920, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16369);
INSERT INTO 'danceurl' VALUES (4921, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16371);
INSERT INTO 'danceurl' VALUES (4922, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16370);
INSERT INTO 'danceurl' VALUES (4923, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16372);
INSERT INTO 'danceurl' VALUES (4924, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16373);
INSERT INTO 'danceurl' VALUES (4925, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16374);
INSERT INTO 'danceurl' VALUES (4926, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16375);
INSERT INTO 'danceurl' VALUES (4927, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16376);
INSERT INTO 'danceurl' VALUES (4928, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16377);
INSERT INTO 'danceurl' VALUES (4929, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16378);
INSERT INTO 'danceurl' VALUES (4930, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16379);
INSERT INTO 'danceurl' VALUES (4868, 'http://bridportscottishdancers.org.uk/pages/braiding/BramleyHouseStrathspey.pdf', 10, 15652);
INSERT INTO 'danceurl' VALUES (4872, 'https://www.rscdslondon.org.uk/wp-content/uploads/2013/09/120410Reel280.pdf#page=5', 10, 15460);
INSERT INTO 'danceurl' VALUES (4858, 'https://suepetyt.e-cribs.org/Thistle_Dubh.pdf', 10, 15574);
INSERT INTO 'danceurl' VALUES (4390, 'https://suepetyt.e-cribs.org/Sparks_Fly.pdf', 10, 11891);
INSERT INTO 'danceurl' VALUES (4860, 'https://suepetyt.e-cribs.org/Dora_Connolly''s_Jig.pdf', 10, 15579);
INSERT INTO 'danceurl' VALUES (4859, 'https://suepetyt.e-cribs.org/The_Barrie_Alexander_Strathspey.pdf', 10, 15576);
INSERT INTO 'danceurl' VALUES (4861, 'https://suepetyt.e-cribs.org/Hunter_House_Mill.pdf', 10, 15583);
INSERT INTO 'danceurl' VALUES (4931, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16380);
INSERT INTO 'danceurl' VALUES (4932, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16381);
INSERT INTO 'danceurl' VALUES (4933, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16382);
INSERT INTO 'danceurl' VALUES (4934, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16383);
INSERT INTO 'danceurl' VALUES (4935, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16384);
INSERT INTO 'danceurl' VALUES (4937, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16386);
INSERT INTO 'danceurl' VALUES (4938, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 16387);
INSERT INTO 'danceurl' VALUES (4939, 'http://www.minicrib.org.uk/Publications/Keppie_John/H5.pdf', 10, 16388);
INSERT INTO 'danceurl' VALUES (4940, 'http://www.minicrib.org.uk/Publications/Keppie_John/H5.pdf', 10, 16389);
INSERT INTO 'danceurl' VALUES (4941, 'http://www.minicrib.org.uk/Publications/Keppie_John/H5.pdf', 10, 16390);
INSERT INTO 'danceurl' VALUES (4942, 'http://www.minicrib.org.uk/Publications/Keppie_John/H5.pdf', 10, 16391);
INSERT INTO 'danceurl' VALUES (4943, 'http://www.minicrib.org.uk/Publications/Keppie_John/H5.pdf', 10, 16392);
INSERT INTO 'danceurl' VALUES (4944, 'http://www.minicrib.org.uk/Publications/Keppie_John/H5.pdf', 10, 16393);
INSERT INTO 'danceurl' VALUES (4945, 'http://www.minicrib.org.uk/Publications/Keppie_John/H5.pdf', 10, 16394);
INSERT INTO 'danceurl' VALUES (4946, 'http://www.minicrib.org.uk/Publications/Keppie_John/H5.pdf', 10, 16395);
INSERT INTO 'danceurl' VALUES (4947, 'http://www.minicrib.org.uk/Publications/Keppie_John/H5.pdf', 10, 16396);
INSERT INTO 'danceurl' VALUES (4948, 'http://www.minicrib.org.uk/Publications/Keppie_John/H5.pdf', 10, 16397);
INSERT INTO 'danceurl' VALUES (4949, 'http://www.minicrib.org.uk/Publications/Keppie_John/H5.pdf', 10, 16398);
INSERT INTO 'danceurl' VALUES (4950, 'http://www.minicrib.org.uk/Publications/Keppie_John/H5.pdf', 10, 16399);
INSERT INTO 'danceurl' VALUES (4951, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16400);
INSERT INTO 'danceurl' VALUES (4952, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16401);
INSERT INTO 'danceurl' VALUES (4953, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16402);
INSERT INTO 'danceurl' VALUES (4954, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16403);
INSERT INTO 'danceurl' VALUES (4955, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16404);
INSERT INTO 'danceurl' VALUES (4956, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16405);
INSERT INTO 'danceurl' VALUES (4957, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16406);
INSERT INTO 'danceurl' VALUES (4958, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16407);
INSERT INTO 'danceurl' VALUES (4959, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16408);
INSERT INTO 'danceurl' VALUES (4960, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16409);
INSERT INTO 'danceurl' VALUES (4907, 'https://suedan.com/dances/instructions/afternoonnap.html', 10, 16289);
INSERT INTO 'danceurl' VALUES (4908, 'https://suedan.com/dances/instructions/alainasbusstop.html', 10, 16290);
INSERT INTO 'danceurl' VALUES (4909, 'https://suedan.com/dances/instructions/awayandbackagain.html', 10, 16291);
INSERT INTO 'danceurl' VALUES (4910, 'https://suedan.com/dances/instructions/bagoshells.html', 10, 16292);
INSERT INTO 'danceurl' VALUES (4912, 'https://suedan.com/dances/instructions/banffcritter.html', 10, 16294);
INSERT INTO 'danceurl' VALUES (4911, 'https://suedan.com/dances/instructions/bicyclechain.html', 10, 16293);
INSERT INTO 'danceurl' VALUES (4913, 'https://suedan.com/dances/instructions/catnipmice.html', 10, 16295);
INSERT INTO 'danceurl' VALUES (4897, 'https://suedan.com/dances/instructions/knotcross.html', 10, 16223);
INSERT INTO 'danceurl' VALUES (4962, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16411);
INSERT INTO 'danceurl' VALUES (4963, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16412);
INSERT INTO 'danceurl' VALUES (4964, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16413);
INSERT INTO 'danceurl' VALUES (4965, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16415);
INSERT INTO 'danceurl' VALUES (4966, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 16416);
INSERT INTO 'danceurl' VALUES (4968, 'https://footnotes5.wordpress.com/', 10, 16551);
INSERT INTO 'danceurl' VALUES (4970, 'https://footnotes5.wordpress.com/', 10, 16553);
INSERT INTO 'danceurl' VALUES (4971, 'https://footnotes5.wordpress.com/', 10, 16554);
INSERT INTO 'danceurl' VALUES (4972, 'https://footnotes5.wordpress.com/', 10, 16555);
INSERT INTO 'danceurl' VALUES (4967, 'https://docs.wixstatic.com/ugd/613b84_7c6df491a38046ce87b9994ee7806800.pdf', 10, 16459);
INSERT INTO 'danceurl' VALUES (4974, 'http://moirastacey.com/', 10, 16557);
INSERT INTO 'danceurl' VALUES (4975, 'http://moirastacey.com/', 10, 16558);
INSERT INTO 'danceurl' VALUES (4976, 'http://moirastacey.com/', 10, 16559);
INSERT INTO 'danceurl' VALUES (4977, 'https://www.rscds.org/article/stv-appeal', 10, 16222);
INSERT INTO 'danceurl' VALUES (4980, 'http://www.dublin-scd.com/dublinsdelights', 10, 16700);
INSERT INTO 'danceurl' VALUES (4981, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Jig/5Muckle%20Beck.pdf', 10, 16701);
INSERT INTO 'danceurl' VALUES (4982, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Jig/5Light%20as%20Thistledown.pdf', 10, 16702);
INSERT INTO 'danceurl' VALUES (4983, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Jig/5Supping%20Honey.pdf', 10, 16703);
INSERT INTO 'danceurl' VALUES (4984, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Jig/5Fionas%20Fancy.pdf', 10, 16704);
INSERT INTO 'danceurl' VALUES (4985, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Jig/5Pandoras%20Box.pdf', 10, 16705);
INSERT INTO 'danceurl' VALUES (4986, 'http://www.dublin-scd.com/mrsmcginleysstrathspey', 10, 16706);
INSERT INTO 'danceurl' VALUES (4987, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Jig/5mayfly.pdf', 10, 16707);
INSERT INTO 'danceurl' VALUES (4988, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Jig/5Blue%20Bell-%20Bottoms.pdf', 10, 16708);
INSERT INTO 'danceurl' VALUES (4989, 'http://www.dublin-scd.com/johngibsonsjig', 10, 16709);
INSERT INTO 'danceurl' VALUES (4990, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Jig/5Reel%20for%20Five.pdf', 10, 16710);
INSERT INTO 'danceurl' VALUES (4991, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Reel/5Groombridge%20Waiter.pdf', 10, 16711);
INSERT INTO 'danceurl' VALUES (4992, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Reel/5Reel%20of%20Emperors%20egg.pdf', 10, 16712);
INSERT INTO 'danceurl' VALUES (4993, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Reel/5Roeder%20Rant.pdf', 10, 16713);
INSERT INTO 'danceurl' VALUES (4994, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Reel/5echoes%20of%20Baudy.pdf', 10, 16714);
INSERT INTO 'danceurl' VALUES (4995, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Reel/5Bidborough%20Ridge.pdf', 10, 16715);
INSERT INTO 'danceurl' VALUES (4996, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-Reel/5Henneker%20Reel.pdf', 10, 16716);
INSERT INTO 'danceurl' VALUES (4997, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-%20Strathspey/5strathspey%20Sandwich.pdf', 10, 16717);
INSERT INTO 'danceurl' VALUES (4998, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-%20Strathspey/5Bayham%20Abbey.pdf', 10, 16718);
INSERT INTO 'danceurl' VALUES (4999, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-%20Strathspey/5Memories%20of%20Marian.pdf', 10, 16719);
INSERT INTO 'danceurl' VALUES (5000, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-%20Strathspey/5High%20Five.pdf', 10, 16720);
INSERT INTO 'danceurl' VALUES (5001, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-%20Strathspey/5Fleure%20de%20Lise.pdf', 10, 16721);
INSERT INTO 'danceurl' VALUES (5002, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-%20Strathspey/5Lucy%20Serenas%20Strathspey.pdf', 10, 16722);
INSERT INTO 'danceurl' VALUES (5003, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Diamond%20Set%20-%20Strathspey/5Land%20of%20Dreams.pdf', 10, 16723);
INSERT INTO 'danceurl' VALUES (5004, 'http://www.dublin-scd.com/dances/converys-of-clonskeagh.pdf', 10, 16734);
INSERT INTO 'danceurl' VALUES (5005, 'http://eddywest.nz/Raindancers.html', 10, 16736);
INSERT INTO 'danceurl' VALUES (5006, 'http://eddywest.nz/jubilee.html', 10, 16737);
INSERT INTO 'danceurl' VALUES (5007, 'https://docs.google.com/document/d/1QYq5GplZgULf8DLpAe3IrSeXzMYv8wKPAdw0fPPzBjU/edit', 10, 16825);
INSERT INTO 'danceurl' VALUES (5274, 'http://www.scotchmist.ca/', 10, 18047);
INSERT INTO 'danceurl' VALUES (5009, 'http://www.dublin-scd.com/aliceandmalcolmsgoldenwedding', 10, 14557);
INSERT INTO 'danceurl' VALUES (5010, 'http://www.dublin-scd.com/andrewcarnegie', 10, 9974);
INSERT INTO 'danceurl' VALUES (5011, 'http://www.dublin-scd.com/blavenstrathspey', 10, 16839);
INSERT INTO 'danceurl' VALUES (5012, 'http://www.dublin-scd.com/campbellsofcrannagh', 10, 14392);
INSERT INTO 'danceurl' VALUES (5013, 'http://www.dublin-scd.com/dublinsfarewelltotheboodes', 10, 12076);
INSERT INTO 'danceurl' VALUES (5014, 'http://www.aurorascot.org.uk/about/10th-anniversary-book', 10, 2484);
INSERT INTO 'danceurl' VALUES (5015, 'http://www.dublin-scd.com/elephantsstampede', 10, 2484);
INSERT INTO 'danceurl' VALUES (5016, 'http://www.dublin-scd.com/florriesfancy', 10, 14387);
INSERT INTO 'danceurl' VALUES (5017, 'http://www.dublin-scd.com/40yearstogether', 10, 16183);
INSERT INTO 'danceurl' VALUES (5018, 'http://www.dublin-scd.com/hazelssalutetotheseventies', 10, 16804);
INSERT INTO 'danceurl' VALUES (5019, 'http://www.dublin-scd.com/rosaliesbirthdayreel', 10, 16840);
INSERT INTO 'danceurl' VALUES (5021, 'http://www.scottishdance.net/dances/', 10, 16838);
INSERT INTO 'danceurl' VALUES (5023, 'http://my.strathspey.org/u/anselm/dances/oneofthebest/', 10, 16773);
INSERT INTO 'danceurl' VALUES (5025, 'http://eddywest.nz/Celtwed.html', 10, 11949);
INSERT INTO 'danceurl' VALUES (5026, 'http://eddywest.nz/kamok.html', 10, 12669);
INSERT INTO 'danceurl' VALUES (5027, 'http://eddywest.nz/katjenjig.html', 10, 3405);
INSERT INTO 'danceurl' VALUES (5029, 'http://eddywest.nz/MrsThew.html', 10, 11363);
INSERT INTO 'danceurl' VALUES (5030, 'http://eddywest.nz/onegoodturn.html', 10, 15681);
INSERT INTO 'danceurl' VALUES (5032, 'http://eddywest.nz/Robroy.html', 10, 5625);
INSERT INTO 'danceurl' VALUES (5033, 'http://eddywest.nz/WaipuDom%20v2.html', 10, 15682);
INSERT INTO 'danceurl' VALUES (5035, 'https://my.strathspey.org/u/murrough/GorgeousGordons.pdf', 10, 16884);
INSERT INTO 'danceurl' VALUES (5037, 'https://my.strathspey.org/u/murrough/Pentamime.pdf', 10, 16886);
INSERT INTO 'danceurl' VALUES (5039, 'http://my.strathspey.org/u/murrough/GreatGable.pdf', 10, 16888);
INSERT INTO 'danceurl' VALUES (5339, 'https://tunes.e-cribs.org/Ray_and_Kay_Harris.pdf', 10, 15107);
INSERT INTO 'danceurl' VALUES (5041, 'http://my.strathspey.org/u/murrough/RealGem.pdf', 10, 16890);
INSERT INTO 'danceurl' VALUES (5042, 'http://www.minicrib.org.uk/bardill-prince.html', 10, 15607);
INSERT INTO 'danceurl' VALUES (5036, 'https://my.strathspey.org/u/murrough/Ompredena.pdf', 10, 16885);
INSERT INTO 'danceurl' VALUES (5028, 'https://dances.e-cribs.org/Mr_Pye_s_Steak_and_Kidney_Pie.pdf', 10, 15680);
INSERT INTO 'danceurl' VALUES (5421, 'https://dublinscdclub.files.wordpress.com/2015/10/40-years-together1.pdf', 10, 16183);
INSERT INTO 'danceurl' VALUES (5034, 'https://dances.e-cribs.org/The_Waipu_Wanderers.pdf', 10, 15683);
INSERT INTO 'danceurl' VALUES (4969, 'https://footnotes5.wordpress.com/fairfield/', 10, 16552);
INSERT INTO 'danceurl' VALUES (5020, 'https://www.dropbox.com/s/80623owv42cmi8j/Its_Reel_Life_dancedata.pdf?dl=0', 10, 14719);
INSERT INTO 'danceurl' VALUES (5043, 'http://www.rscdsleeds.org.uk/files/Drewry/SCN_0015.jpg', 10, 6644);
INSERT INTO 'danceurl' VALUES (5044, 'http://www.timdoodle.com/scd/AustinQuicksilver.html', 10, 16910);
INSERT INTO 'danceurl' VALUES (5060, 'http://www.thesundayclass.org.uk/MARJAS%20BUNS.html', 10, 16927);
INSERT INTO 'danceurl' VALUES (5061, 'http://www.thesundayclass.org.uk/EAST%20NEUK%20STORM.html', 10, 16929);
INSERT INTO 'danceurl' VALUES (5062, 'http://www.thesundayclass.org.uk/PIRONGIA.html', 10, 16930);
INSERT INTO 'danceurl' VALUES (5064, 'http://macrudi.de/resources/dances/toogled.pdf', 10, 16932);
INSERT INTO 'danceurl' VALUES (5065, 'http://www.thesundayclass.org.uk/LACING%20O%20THE%20GHILLIES.html', 10, 16933);
INSERT INTO 'danceurl' VALUES (5068, 'http://www.scottishdance.net/dances/Book/SnodsEdge.pdf', 10, 16936);
INSERT INTO 'danceurl' VALUES (5072, 'http://www.bracknellreelclub.org.uk/douglas/rodney2.html', 10, 12620);
INSERT INTO 'danceurl' VALUES (5074, 'http://nethybridge.com/wp-content/uploads/2015/02/Rhubarb-Reel-MINICRIB.pdf', 10, 15843);
INSERT INTO 'danceurl' VALUES (5075, 'http://nethybridge.com/wp-content/uploads/2014/10/Rhubarb-Reel-instructions.pdf', 10, 15843);
INSERT INTO 'danceurl' VALUES (5079, 'https://my.strathspey.org/u/murrough/CreakyFloorboards.pdf', 10, 17021);
INSERT INTO 'danceurl' VALUES (5080, 'https://my.strathspey.org/u/murrough/LargeHadronCollider.pdf', 10, 17022);
INSERT INTO 'danceurl' VALUES (5081, 'https://my.strathspey.org/u/murrough/MastersOfArt.pdf', 10, 17023);
INSERT INTO 'danceurl' VALUES (5054, 'https://sites.google.com/site/thefollyofrogues/cusrc-reelwiki/hellbender', 10, 16920);
INSERT INTO 'danceurl' VALUES (5038, 'https://my.strathspey.org/u/murrough/QuarriesProcession.pdf', 10, 16887);
INSERT INTO 'danceurl' VALUES (5099, 'https://www.scottishdance.net/dances/Book/ATripToLorient.pdf', 10, 13316);
INSERT INTO 'danceurl' VALUES (5100, 'http://www.janetelizabeth.org.uk/scottishdance/dances/calais-sunshine.pdf', 10, 17388);
INSERT INTO 'danceurl' VALUES (5101, 'http://www.rscdsleeds.org.uk/files/Drewry/Stepways.jpg', 10, 17390);
INSERT INTO 'danceurl' VALUES (5102, 'http://www.lulu.com/shop/rscds-international-branch/world-wide-weavings/ebook/product-22219057.html', 10, 16465);
INSERT INTO 'danceurl' VALUES (5103, 'http://portlandscottishdancers.org/dances.html', 10, 15315);
INSERT INTO 'danceurl' VALUES (5104, 'http://portlandscottishdancers.org/dances.html', 10, 15316);
INSERT INTO 'danceurl' VALUES (5106, 'http://portlandscottishdancers.org/dances.html', 10, 15318);
INSERT INTO 'danceurl' VALUES (5107, 'http://portlandscottishdancers.org/dances.html', 10, 15319);
INSERT INTO 'danceurl' VALUES (5108, 'http://portlandscottishdancers.org/dances.html', 10, 15320);
INSERT INTO 'danceurl' VALUES (5109, 'http://portlandscottishdancers.org/dances.html', 10, 15321);
INSERT INTO 'danceurl' VALUES (5110, 'http://portlandscottishdancers.org/dances.html', 10, 15322);
INSERT INTO 'danceurl' VALUES (5111, 'http://portlandscottishdancers.org/dances.html', 10, 15323);
INSERT INTO 'danceurl' VALUES (5112, 'http://portlandscottishdancers.org/dances.html', 10, 15324);
INSERT INTO 'danceurl' VALUES (5113, 'http://portlandscottishdancers.org/dances.html', 10, 15325);
INSERT INTO 'danceurl' VALUES (5024, 'https://rscds-twincities.org/dance/the-lost-40/', 10, 16869);
INSERT INTO 'danceurl' VALUES (5022, 'https://www.genevascdc.com/EN/LC_ADTSTY.shtml', 10, 16857);
INSERT INTO 'danceurl' VALUES (5114, 'http://portlandscottishdancers.org/dances.html', 10, 15326);
INSERT INTO 'danceurl' VALUES (5115, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/puggy.html', 10, 17418);
INSERT INTO 'danceurl' VALUES (5116, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/puggy-2.html', 10, 17418);
INSERT INTO 'danceurl' VALUES (5117, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/chaperons.html', 10, 17413);
INSERT INTO 'danceurl' VALUES (5118, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/coopers-crown.html', 10, 17393);
INSERT INTO 'danceurl' VALUES (5119, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/dark-island.html', 10, 17415);
INSERT INTO 'danceurl' VALUES (5120, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/st-georges-cross.html', 10, 17420);
INSERT INTO 'danceurl' VALUES (5121, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/pop-goes-the-weasel.html', 10, 17417);
INSERT INTO 'danceurl' VALUES (5275, 'http://www.scotchmist.ca/', 10, 18049);
INSERT INTO 'danceurl' VALUES (5066, 'https://web.archive.org/web/20200206061225/http://www.scottishdance.de/go-west.html', 10, 16934);
INSERT INTO 'danceurl' VALUES (5122, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/mary-macnivens-sash-pin.html', 10, 17411);
INSERT INTO 'danceurl' VALUES (5082, 'https://my.strathspey.org/u/murrough/SmoulderingTeapots.pdf', 10, 17024);
INSERT INTO 'danceurl' VALUES (5204, 'http://www.macrudi.de/resources/dances/afterhours.pdf', 10, 9447);
INSERT INTO 'danceurl' VALUES (5055, 'https://sites.google.com/site/thefollyofrogues/cusrc-reelwiki/mayflower-jig', 10, 16921);
INSERT INTO 'danceurl' VALUES (5057, 'https://sites.google.com/site/thefollyofrogues/cusrc-reelwiki/st-vincents-close', 10, 16923);
INSERT INTO 'danceurl' VALUES (5058, 'https://sites.google.com/site/thefollyofrogues/cusrc-reelwiki/welcome-to-cambridge', 10, 16924);
INSERT INTO 'danceurl' VALUES (5063, 'https://sites.google.com/site/thefollyofrogues/cusrc-reelwiki/the-world-turned-upside-down', 10, 16931);
INSERT INTO 'danceurl' VALUES (5046, 'https://suedan.com/dances/instructions/celticghost.html', 10, 16911);
INSERT INTO 'danceurl' VALUES (5048, 'https://suedan.com/dances/instructions/doubleduty2.html', 10, 16913);
INSERT INTO 'danceurl' VALUES (5049, 'https://suedan.com/dances/instructions/lakelouise.html', 10, 16914);
INSERT INTO 'danceurl' VALUES (5050, 'https://suedan.com/dances/instructions/pieceocake.html', 10, 16915);
INSERT INTO 'danceurl' VALUES (5051, 'https://suedan.com/dances/instructions/stalbans.html', 10, 16916);
INSERT INTO 'danceurl' VALUES (5045, 'https://suedan.com/dances/instructions/yinyang.html', 10, 16917);
INSERT INTO 'danceurl' VALUES (5084, 'https://harwellscdc.mno.org.uk/wp-content/uploads/2018/08/HCS-1948-1998-Harwell-Caledonian-Society.pdf', 10, 17042);
INSERT INTO 'danceurl' VALUES (5085, 'https://harwellscdc.mno.org.uk/wp-content/uploads/2018/08/HCS-1948-1998-Tea-Time.pdf', 10, 17043);
INSERT INTO 'danceurl' VALUES (5086, 'https://harwellscdc.mno.org.uk/wp-content/uploads/2018/08/HCS-1948-1998-Rimes-Close.pdf', 10, 17044);
INSERT INTO 'danceurl' VALUES (5088, 'https://harwellscdc.mno.org.uk/wp-content/uploads/2018/08/HCS-1948-1998-The-Half-Century.pdf', 10, 17046);
INSERT INTO 'danceurl' VALUES (5078, 'https://dances.e-cribs.org/Powdered_Sugar.pdf', 10, 17018);
INSERT INTO 'danceurl' VALUES (5076, 'https://dances.e-cribs.org/The_Irish_Bride.pdf', 10, 13354);
INSERT INTO 'danceurl' VALUES (5077, 'https://dances.e-cribs.org/Bulliondale.pdf', 10, 17017);
INSERT INTO 'danceurl' VALUES (5073, 'https://dances.e-cribs.org/Ezekiel_s_Wheel.pdf', 10, 15098);
INSERT INTO 'danceurl' VALUES (5123, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/john-campbells-kilt-pin.html', 10, 17412);
INSERT INTO 'danceurl' VALUES (5124, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/st-pirans-cross.html', 10, 17421);
INSERT INTO 'danceurl' VALUES (5125, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/trefoil-badge.html', 10, 17422);
INSERT INTO 'danceurl' VALUES (5126, 'http://www.scottish-country-dancing-dictionary.com/dance-crib/unsullied-saltire.html', 10, 17424);
INSERT INTO 'danceurl' VALUES (5135, 'http://genevascdc.com/EN/LC_ARMA.shtml', 10, 17616);
INSERT INTO 'danceurl' VALUES (5136, 'http://genevascdc.com/EN/LC_GG.shtml', 10, 17617);
INSERT INTO 'danceurl' VALUES (5137, 'http://media.wix.com/ugd/613b84_772abbf395484f94a3fabbce68dc6fdf.pdf', 10, 17626);
INSERT INTO 'danceurl' VALUES (5138, 'http://www.bstk.hu/book/', 10, 7300);
INSERT INTO 'danceurl' VALUES (5139, 'http://www.bstk.hu/book/', 10, 14474);
INSERT INTO 'danceurl' VALUES (5140, 'http://www.bstk.hu/book/', 10, 7301);
INSERT INTO 'danceurl' VALUES (5141, 'http://www.bstk.hu/book/', 10, 7304);
INSERT INTO 'danceurl' VALUES (5142, 'http://www.bstk.hu/book/', 10, 7311);
INSERT INTO 'danceurl' VALUES (5143, 'http://www.bstk.hu/book/', 10, 7312);
INSERT INTO 'danceurl' VALUES (5144, 'http://www.bstk.hu/book/', 10, 7313);
INSERT INTO 'danceurl' VALUES (5146, 'http://www.bstk.hu/book/', 10, 14477);
INSERT INTO 'danceurl' VALUES (5147, 'http://www.bstk.hu/book/', 10, 7297);
INSERT INTO 'danceurl' VALUES (5148, 'http://www.minicrib.org.uk/Publications/Pitlochry%20Celebration.pdf', 10, 5289);
INSERT INTO 'danceurl' VALUES (5149, 'http://www.minicrib.org.uk/Publications/Birlin''%20Sporrans.pdf', 10, 12869);
INSERT INTO 'danceurl' VALUES (5150, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/ForEwa.pdf', 10, 17633);
INSERT INTO 'danceurl' VALUES (5151, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Twists%20&%20Turns%20BP15.pdf', 10, 17633);
INSERT INTO 'danceurl' VALUES (5152, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Shimmying%20Bee.pdf', 10, 17634);
INSERT INTO 'danceurl' VALUES (5153, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Twists%20&%20Turns%20BP15.pdf', 10, 17634);
INSERT INTO 'danceurl' VALUES (5154, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Dark-eyed.pdf', 10, 17635);
INSERT INTO 'danceurl' VALUES (5155, 'http://www.minicrib.org.uk/Publications/Bardill-Prince/Twists%20&%20Turns%20BP15.pdf', 10, 17635);
INSERT INTO 'danceurl' VALUES (5158, 'http://www.dublin-scd.com/hiphiphooray', 10, 17662);
INSERT INTO 'danceurl' VALUES (5159, 'http://www.dublin-scd.com/helensfortiethflourish', 10, 17661);
INSERT INTO 'danceurl' VALUES (5161, 'http://www.strathspey.org/lists/strathspey%40strathspey.org/t/40434/#m40434', 10, 8855);
INSERT INTO 'danceurl' VALUES (5163, 'http://www.scottishdance.net/dances/Book/InScottishSpirit.pdf', 10, 11570);
INSERT INTO 'danceurl' VALUES (5164, 'http://www.rscdsleeds.org.uk/Newsletter/RSCDS%20Newsletter29.pdf', 10, 10624);
INSERT INTO 'danceurl' VALUES (5165, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17737);
INSERT INTO 'danceurl' VALUES (5166, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17648);
INSERT INTO 'danceurl' VALUES (5167, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17738);
INSERT INTO 'danceurl' VALUES (5168, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17649);
INSERT INTO 'danceurl' VALUES (5169, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17650);
INSERT INTO 'danceurl' VALUES (5170, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17654);
INSERT INTO 'danceurl' VALUES (5171, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17739);
INSERT INTO 'danceurl' VALUES (5172, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 7802);
INSERT INTO 'danceurl' VALUES (5173, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17651);
INSERT INTO 'danceurl' VALUES (5174, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17655);
INSERT INTO 'danceurl' VALUES (5175, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17740);
INSERT INTO 'danceurl' VALUES (5059, 'https://suepetyt.e-cribs.org/Marian''s_Reel.pdf', 10, 16925);
INSERT INTO 'danceurl' VALUES (5132, 'https://suepetyt.e-cribs.org/Lack_O''_Men.pdf', 10, 3566);
INSERT INTO 'danceurl' VALUES (5129, 'https://suepetyt.e-cribs.org/40_Merks.pdf', 10, 12210);
INSERT INTO 'danceurl' VALUES (5133, 'https://suepetyt.e-cribs.org/Let''s_Celebrate.pdf', 10, 12302);
INSERT INTO 'danceurl' VALUES (4158, 'https://suepetyt.e-cribs.org/Half_and_Half.pdf', 10, 9529);
INSERT INTO 'danceurl' VALUES (5131, 'https://suepetyt.e-cribs.org/Evelyn''s_Surprise.pdf', 10, 14397);
INSERT INTO 'danceurl' VALUES (5162, 'https://www.rscdsparis.fr/dances/MadamePipeau.pdf', 10, 17706);
INSERT INTO 'danceurl' VALUES (5176, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17652);
INSERT INTO 'danceurl' VALUES (5177, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17653);
INSERT INTO 'danceurl' VALUES (5178, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17741);
INSERT INTO 'danceurl' VALUES (5179, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17742);
INSERT INTO 'danceurl' VALUES (5180, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 10, 17743);
INSERT INTO 'danceurl' VALUES (5181, 'https://my.strathspey.org/u/murrough/AlfiesTeam.pdf', 10, 17753);
INSERT INTO 'danceurl' VALUES (5182, 'https://my.strathspey.org/u/murrough/AshleyAndHerHusbands.pdf', 10, 17754);
INSERT INTO 'danceurl' VALUES (5183, 'https://my.strathspey.org/u/murrough/EveningPrimrose.pdf', 10, 17755);
INSERT INTO 'danceurl' VALUES (5184, 'https://my.strathspey.org/u/murrough/JonathansWheels.pdf', 10, 17756);
INSERT INTO 'danceurl' VALUES (5185, 'https://my.strathspey.org/u/murrough/KyleCastle.pdf', 10, 17757);
INSERT INTO 'danceurl' VALUES (5186, 'https://my.strathspey.org/u/murrough/SimonesSerendipitousMeeting.pdf', 10, 17758);
INSERT INTO 'danceurl' VALUES (5187, 'https://my.strathspey.org/u/murrough/TreasureOfKennington.pdf', 10, 17759);
INSERT INTO 'danceurl' VALUES (5189, 'http://rscds-sf.org/resources/dances/Diamonds%20Are%20Forever%20Dancing.pdf', 10, 17760);
INSERT INTO 'danceurl' VALUES (5190, 'http://rscds-sf.org/resources/dances/A%20%20Dance%20%20for%20%20Des.pdf', 10, 17764);
INSERT INTO 'danceurl' VALUES (5191, 'http://macrudi.de/resources/dances/charliewelcome.pdf', 10, 9450);
INSERT INTO 'danceurl' VALUES (5195, 'http://www.scottishweekend.org/The%20Registrar.pdf', 10, 17150);
INSERT INTO 'danceurl' VALUES (5196, 'http://thesundayclass.org.uk/NAMES%20BOND.html', 10, 17903);
INSERT INTO 'danceurl' VALUES (5197, 'https://my.strathspey.org/u/murrough/HomemadeJam.pdf', 10, 17918);
INSERT INTO 'danceurl' VALUES (5198, 'https://my.strathspey.org/u/murrough/BrackenOnBroughtonMoor.pdf', 10, 17919);
INSERT INTO 'danceurl' VALUES (5199, 'http://www.bstk.hu/dances/the-real-wedding-reel/', 10, 17948);
INSERT INTO 'danceurl' VALUES (5200, 'http://www.macrudi.de/resources/dances/nonetrick.pdf', 10, 9449);
INSERT INTO 'danceurl' VALUES (5201, 'http://www.macrudi.de/resources/dances/december.pdf', 10, 9451);
INSERT INTO 'danceurl' VALUES (5202, 'http://www.macrudi.de/resources/dances/thursday.pdf', 10, 9452);
INSERT INTO 'danceurl' VALUES (5203, 'http://macrudi.de/resources/dances/cranshucks.pdf', 10, 9448);
INSERT INTO 'danceurl' VALUES (5127, 'https://suedan.com/george/lucy.html', 10, 9740);
INSERT INTO 'danceurl' VALUES (5156, 'http://www.minicrib.org.uk/Publications/Lagavulin.pdf', 10, 15685);
INSERT INTO 'danceurl' VALUES (5194, 'https://suedan.com/dances/instructions/42yearsandout.html', 10, 17884);
INSERT INTO 'danceurl' VALUES (5193, 'https://suedan.com/dances/instructions/greenmountainmemories.html', 10, 17883);
INSERT INTO 'danceurl' VALUES (5145, 'http://www.bstk.hu/dances/be-my-partner', 10, 14476);
INSERT INTO 'danceurl' VALUES (5128, 'https://www.rscds.org/sites/default/files/pudsey_bear.pdf', 10, 17462);
INSERT INTO 'danceurl' VALUES (5205, 'http://macrudi.de/resources/dances/Red_Squirrel.pdf', 10, 14381);
INSERT INTO 'danceurl' VALUES (5206, 'http://macrudi.de/resources/dances/charlrun.pdf', 10, 9445);
INSERT INTO 'danceurl' VALUES (5207, 'http://macrudi.de/resources/dances/daphjig.pdf', 10, 8725);
INSERT INTO 'danceurl' VALUES (5208, 'http://macrudi.de/resources/dances/hansglueck.pdf', 10, 13088);
INSERT INTO 'danceurl' VALUES (5209, 'http://macrudi.de/resources/dances/gelijig.pdf', 10, 13087);
INSERT INTO 'danceurl' VALUES (5210, 'http://macrudi.de/resources/dances/lady.pdf', 10, 9443);
INSERT INTO 'danceurl' VALUES (5211, 'http://macrudi.de/resources/dances/plainpurl.pdf', 10, 13089);
INSERT INTO 'danceurl' VALUES (5212, 'http://macrudi.de/resources/dances/reelchris.pdf', 10, 11708);
INSERT INTO 'danceurl' VALUES (5213, 'http://macrudi.de/resources/dances/swirlwaters.pdf', 10, 9444);
INSERT INTO 'danceurl' VALUES (5214, 'http://macrudi.de/resources/dances/tempt.pdf', 10, 9442);
INSERT INTO 'danceurl' VALUES (5215, 'http://macrudi.de/resources/dances/warden.pdf', 10, 12897);
INSERT INTO 'danceurl' VALUES (5216, 'http://www.scottishdance.net/dances/Book/MerchistonCastleJig.pdf', 10, 11797);
INSERT INTO 'danceurl' VALUES (5218, 'http://www.scottishdance.net/ceilidh/dances.html#CumberlandSquareEight', 10, 1479);
INSERT INTO 'danceurl' VALUES (5223, 'http://www.scd-chemnitz.de/7-scd-weekend-chemnitz/', 10, 17694);
INSERT INTO 'danceurl' VALUES (5224, 'https://www.dropbox.com/s/l761uh2g6mguypy/Oldenburg%20dance%20book.pdf', 10, 14973);
INSERT INTO 'danceurl' VALUES (5225, 'https://8x32.e-cribs.org/index.php/a/200-king-street-north', 10, 13823);
INSERT INTO 'danceurl' VALUES (5226, 'https://8x32.e-cribs.org/index.php/a/agnes-blackadder-fire-alarm', 10, 15055);
INSERT INTO 'danceurl' VALUES (5227, 'https://8x32.e-cribs.org/index.php/a/all-in', 10, 10845);
INSERT INTO 'danceurl' VALUES (5228, 'https://8x32.e-cribs.org/index.php/a/vefa-s-strathspey', 10, 16571);
INSERT INTO 'danceurl' VALUES (5229, 'https://my.strathspey.org/u/murrough/StrollerInHades.pdf', 10, 18044);
INSERT INTO 'danceurl' VALUES (5230, 'https://8x32.e-cribs.org/index.php/a/rin-wuid', 10, 18043);
INSERT INTO 'danceurl' VALUES (5231, 'https://8x32.e-cribs.org/index.php/a/music-melts-upon-the-evening', 10, 18042);
INSERT INTO 'danceurl' VALUES (5232, 'https://8x32.e-cribs.org/index.php/a/last-set-in-the-hall', 10, 15684);
INSERT INTO 'danceurl' VALUES (5233, 'https://8x32.e-cribs.org/index.php/a/malcolm-s-shoes', 10, 15686);
INSERT INTO 'danceurl' VALUES (5234, 'https://8x32.e-cribs.org/index.php/a/lagavulin', 10, 15685);
INSERT INTO 'danceurl' VALUES (5235, 'http://my.strathspey.org/u/keithrose/Battle_of_Trafalgar_-_6x40_H.pdf', 10, 15430);
INSERT INTO 'danceurl' VALUES (5236, 'https://8x32.e-cribs.org/index.php/a/it-s-my-pleasure', 10, 15230);
INSERT INTO 'danceurl' VALUES (4804, 'https://8x32.e-cribs.org/index.php/a/who-am-i', 10, 14986);
INSERT INTO 'danceurl' VALUES (5237, 'https://8x32.e-cribs.org/index.php/a/turn-turn-turn', 10, 15229);
INSERT INTO 'danceurl' VALUES (4596, 'https://8x32.e-cribs.org/index.php/a/anna-s-homecoming', 10, 13578);
INSERT INTO 'danceurl' VALUES (5238, 'https://8x32.e-cribs.org/index.php/a/ladies-of-schiehallion', 10, 12999);
INSERT INTO 'danceurl' VALUES (5239, 'https://8x32.e-cribs.org/index.php/a/barbara-s-strathspey', 10, 13149);
INSERT INTO 'danceurl' VALUES (5240, 'https://my.strathspey.org/u/murrough/DAVID.pdf', 10, 18053);
INSERT INTO 'danceurl' VALUES (5241, 'https://8x32.e-cribs.org/index.php/a/jean', 10, 14344);
INSERT INTO 'danceurl' VALUES (4666, 'https://8x32.e-cribs.org/index.php/a/gordon-of-straloch', 10, 14360);
INSERT INTO 'danceurl' VALUES (4805, 'https://8x32.e-cribs.org/index.php/a/heathery-breeze', 10, 14988);
INSERT INTO 'danceurl' VALUES (5242, 'https://my.strathspey.org/dd/dance/10784/#cribs', 10, 10784);
INSERT INTO 'danceurl' VALUES (5243, 'https://8x32.e-cribs.org/index.php/a/see-you-in-arran', 10, 13313);
INSERT INTO 'danceurl' VALUES (5244, 'https://8x32.e-cribs.org/index.php/a/dancing-on-water', 10, 13306);
INSERT INTO 'danceurl' VALUES (5245, 'http://www.anselms.net/SCD/dances/strobel-muehle.pdf', 10, 18054);
INSERT INTO 'danceurl' VALUES (5246, 'http://www.zscdc.ch/downloads/eng/waters_of_jona.pdf', 10, 18055);
INSERT INTO 'danceurl' VALUES (5247, 'https://8x32.e-cribs.org/index.php/a/de-il-amang-the-gaylors', 10, 14343);
INSERT INTO 'danceurl' VALUES (5248, 'https://8x32.e-cribs.org/index.php/a/trip-to-fanwood', 10, 13745);
INSERT INTO 'danceurl' VALUES (5250, 'https://8x32.e-cribs.org/index.php/a/molly-maclay-of-kilfinnan', 10, 13815);
INSERT INTO 'danceurl' VALUES (5251, 'https://8x32.e-cribs.org/index.php/a/quaternary-knot', 10, 13818);
INSERT INTO 'danceurl' VALUES (5252, 'https://8x32.e-cribs.org/index.php/a/gude-ale-keeps-the-heart-aboon', 10, 13811);
INSERT INTO 'danceurl' VALUES (5253, 'https://8x32.e-cribs.org/index.php/a/mally-s-meek-mally-sweet', 10, 13814);
INSERT INTO 'danceurl' VALUES (5219, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/mcewan.pdf', 10, 4257);
INSERT INTO 'danceurl' VALUES (5220, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/sheena.pdf', 10, 6030);
INSERT INTO 'danceurl' VALUES (5217, 'https://dances.e-cribs.org/Georges_s_Strathspey.pdf', 10, 14598);
INSERT INTO 'danceurl' VALUES (5192, 'http://suepetyt.e-cribs.org/Dumfries_welcomes_ribble_valley.pdf', 10, 17572);
INSERT INTO 'danceurl' VALUES (5254, 'https://8x32.e-cribs.org/index.php/a/silver-heather', 10, 14428);
INSERT INTO 'danceurl' VALUES (5255, 'https://8x32.e-cribs.org/index.php/a/groundhog-day', 10, 14989);
INSERT INTO 'danceurl' VALUES (5256, 'https://8x32.e-cribs.org/index.php/a/the-red-squirrel', 10, 14381);
INSERT INTO 'danceurl' VALUES (5257, 'https://8x32.e-cribs.org/index.php/a/emmett-s-chase', 10, 14363);
INSERT INTO 'danceurl' VALUES (5249, 'https://8x32.e-cribs.org/index.php/a/blethering-ghillie', 10, 13806);
INSERT INTO 'danceurl' VALUES (5267, 'http://scottishweekend.org/LintonWhipman.pdf', 10, 18074);
INSERT INTO 'danceurl' VALUES (5269, 'http://www.scottishdance.net/dances/Book/DancingDustbins.pdf', 10, 18109);
INSERT INTO 'danceurl' VALUES (5270, 'http://www.scottishdance.net/dances/Book/StrathspeyForAPerfectDay.pdf', 10, 18117);
INSERT INTO 'danceurl' VALUES (5271, 'http://www.scottishdance.net/dances/Book/TheEriskayJig.pdf', 10, 13573);
INSERT INTO 'danceurl' VALUES (5272, 'http://www.scottishdance.net/dances/Book/ThePrestonfieldReel.pdf', 10, 18119);
INSERT INTO 'danceurl' VALUES (5273, 'http://www.scottishdance.net/dances/Book/TheSixthOfNovember.pdf', 10, 18120);
INSERT INTO 'danceurl' VALUES (5277, 'https://sites.google.com/site/thefollyofrogues/kalan-i-manul', 10, 17789);
INSERT INTO 'danceurl' VALUES (5278, 'https://www.eecis.udel.edu/~harvey/sleepwalking.pdf', 10, 10286);
INSERT INTO 'danceurl' VALUES (5279, 'http://my.strathspey.org/u/anselm/dances/nevskiyprospekt/', 10, 16072);
INSERT INTO 'danceurl' VALUES (5280, 'https://my.strathspey.org/u/murrough/ZealOfTheJoyousScots.pdf', 10, 18238);
INSERT INTO 'danceurl' VALUES (5263, 'http://www.members.westnet.com.au/trevanne/rscdswa/dances/The%20Lion%20Gate.pdf', 15, 15304);
INSERT INTO 'danceurl' VALUES (5260, 'http://www.members.westnet.com.au/trevanne/rscdswa/dances/A_Special_Occasion.pdf', 15, 15306);
INSERT INTO 'danceurl' VALUES (5258, 'http://www.members.westnet.com.au/trevanne/rscdswa/dances/Far_North_Queensland.pdf', 15, 15307);
INSERT INTO 'danceurl' VALUES (5262, 'http://www.members.westnet.com.au/trevanne/rscdswa/dances/Mays_100.pdf', 15, 15308);
INSERT INTO 'danceurl' VALUES (5264, 'http://www.members.westnet.com.au/trevanne/rscdswa/dances/The_Anne_Archdeacon_Reel.pdf', 15, 15309);
INSERT INTO 'danceurl' VALUES (5261, 'http://www.members.westnet.com.au/trevanne/rscdswa/dances/AudreyandPeters_Jubilee.pdf', 15, 14356);
INSERT INTO 'danceurl' VALUES (5265, 'http://www.members.westnet.com.au/trevanne/rscdswa/dances/The_Torridon_Cross.pdf', 15, 15310);
INSERT INTO 'danceurl' VALUES (5266, 'http://www.members.westnet.com.au/trevanne/rscdswa/dances/The_Two_Gray_Cats.pdf', 15, 15311);
INSERT INTO 'danceurl' VALUES (5259, 'http://www.members.westnet.com.au/trevanne/rscdswa/dances/A_Highlander_in_Glasgow.pdf', 15, 15312);
INSERT INTO 'danceurl' VALUES (5282, 'https://my.strathspey.org/u/murrough/StrangenessAndCharm.pdf', 10, 18239);
INSERT INTO 'danceurl' VALUES (5345, 'https://tunes.e-cribs.org/Accomplished.pdf', 10, 15102);
INSERT INTO 'danceurl' VALUES (5393, 'https://tunes.e-cribs.org/Misty_Mountain_Reel.pdf', 10, 13933);
INSERT INTO 'danceurl' VALUES (5349, 'https://tunes.e-cribs.org/Rosenberg_Hill.pdf', 10, 18276);
INSERT INTO 'danceurl' VALUES (5290, 'https://tunes.e-cribs.org/35_Years_and_counting.pdf', 10, 13896);
INSERT INTO 'danceurl' VALUES (5346, 'https://tunes.e-cribs.org/Airs_in_July.pdf', 10, 15122);
INSERT INTO 'danceurl' VALUES (5347, 'https://tunes.e-cribs.org/All_together_now.pdf', 10, 18004);
INSERT INTO 'danceurl' VALUES (5410, 'https://tunes.e-cribs.org/An_Te_Liath.pdf', 10, 13908);
INSERT INTO 'danceurl' VALUES (5350, 'https://tunes.e-cribs.org/Andrew_s_Serenade.pdf', 10, 17998);
INSERT INTO 'danceurl' VALUES (5351, 'https://tunes.e-cribs.org/Anniversary_Jig.pdf', 10, 13916);
INSERT INTO 'danceurl' VALUES (5352, 'https://tunes.e-cribs.org/An_Autumn_Song.pdf', 10, 13907);
INSERT INTO 'danceurl' VALUES (5353, 'https://tunes.e-cribs.org/Betty_s_Bay_Reel.pdf', 10, 15103);
INSERT INTO 'danceurl' VALUES (5355, 'https://tunes.e-cribs.org/Beanntan_an_Dragoin.pdf', 10, 13927);
INSERT INTO 'danceurl' VALUES (5287, 'https://tunes.e-cribs.org/Wheel_of_fortune.pdf', 10, 11048);
INSERT INTO 'danceurl' VALUES (5330, 'https://tunes.e-cribs.org/The_Thistle_Protea.pdf', 10, 17711);
INSERT INTO 'danceurl' VALUES (5356, 'https://tunes.e-cribs.org/Strathspey_in_Cyberspace.pdf', 10, 14525);
INSERT INTO 'danceurl' VALUES (5357, 'http://www.strathspey.org/libDances/sspbook.pdf', 10, 14524);
INSERT INTO 'danceurl' VALUES (5354, 'https://tunes.e-cribs.org/Blooms_a_Twirling.pdf', 10, 15116);
INSERT INTO 'danceurl' VALUES (5341, 'https://tunes.e-cribs.org/Rainbow_Nation.pdf', 10, 13923);
INSERT INTO 'danceurl' VALUES (5340, 'https://tunes.e-cribs.org/Rainy_Days.pdf', 10, 18011);
INSERT INTO 'danceurl' VALUES (5328, 'https://tunes.e-cribs.org/To_Life.pdf', 10, 13914);
INSERT INTO 'danceurl' VALUES (5335, 'https://tunes.e-cribs.org/A_Scottish_Fantasy.pdf', 10, 13921);
INSERT INTO 'danceurl' VALUES (5336, 'https://tunes.e-cribs.org/Running_home.pdf', 10, 18014);
INSERT INTO 'danceurl' VALUES (5322, 'https://tunes.e-cribs.org/Winter.pdf', 10, 15099);
INSERT INTO 'danceurl' VALUES (5358, 'https://tunes.e-cribs.org/Inspiration.pdf', 10, 15123);
INSERT INTO 'danceurl' VALUES (5326, 'https://tunes.e-cribs.org/Touching_the_heart.pdf', 10, 13912);
INSERT INTO 'danceurl' VALUES (5327, 'https://tunes.e-cribs.org/A_Toast_to_Tobie.pdf', 10, 13929);
INSERT INTO 'danceurl' VALUES (5359, 'https://tunes.e-cribs.org/Blow_the_South-Easter.pdf', 10, 16775);
INSERT INTO 'danceurl' VALUES (5360, 'https://tunes.e-cribs.org/The_Bridal_Jig.pdf', 10, 15111);
INSERT INTO 'danceurl' VALUES (5361, 'https://tunes.e-cribs.org/Christof_s_Jig.pdf', 10, 17944);
INSERT INTO 'danceurl' VALUES (5362, 'https://tunes.e-cribs.org/City_of_Christchurch.pdf', 10, 13679);
INSERT INTO 'danceurl' VALUES (5363, 'https://tunes.e-cribs.org/Hope.pdf', 10, 13679);
INSERT INTO 'danceurl' VALUES (5364, 'https://tunes.e-cribs.org/Cooks_Dauth_s_Strathspey.pdf', 10, 13925);
INSERT INTO 'danceurl' VALUES (5365, 'https://tunes.e-cribs.org/Crowns_and_Diamonds.pdf', 10, 15120);
INSERT INTO 'danceurl' VALUES (5366, 'https://tunes.e-cribs.org/Draoideachd_Mhuriel.pdf', 10, 13922);
INSERT INTO 'danceurl' VALUES (5367, 'https://tunes.e-cribs.org/Driving_home.pdf', 10, 13918);
INSERT INTO 'danceurl' VALUES (5368, 'https://tunes.e-cribs.org/Election_Day.pdf', 10, 13915);
INSERT INTO 'danceurl' VALUES (5369, 'https://tunes.e-cribs.org/The_Examiners_Jig.pdf', 10, 13913);
INSERT INTO 'danceurl' VALUES (5370, 'https://tunes.e-cribs.org/Fiddler_s_fare.pdf', 10, 13906);
INSERT INTO 'danceurl' VALUES (5371, 'https://tunes.e-cribs.org/Friends_for_Reel.pdf', 10, 13909);
INSERT INTO 'danceurl' VALUES (5372, 'https://tunes.e-cribs.org/Five.pdf', 10, 18006);
INSERT INTO 'danceurl' VALUES (5373, 'https://tunes.e-cribs.org/The_Forbidden_Forest.pdf', 10, 18013);
INSERT INTO 'danceurl' VALUES (5374, 'https://tunes.e-cribs.org/Gallivanting_Guineafowl.pdf', 10, 17941);
INSERT INTO 'danceurl' VALUES (5375, 'https://tunes.e-cribs.org/Gratitude.pdf', 10, 17947);
INSERT INTO 'danceurl' VALUES (5376, 'https://tunes.e-cribs.org/Helen_and_Jean.pdf', 10, 15110);
INSERT INTO 'danceurl' VALUES (5377, 'https://tunes.e-cribs.org/I_ll_be_your_shadow.pdf', 10, 15121);
INSERT INTO 'danceurl' VALUES (5378, 'https://tunes.e-cribs.org/Jan_s_Choice.pdf', 10, 18015);
INSERT INTO 'danceurl' VALUES (5379, 'https://tunes.e-cribs.org/Key_Confusion.pdf', 10, 17997);
INSERT INTO 'danceurl' VALUES (5380, 'https://tunes.e-cribs.org/Miss_Terry_Lynne_Harris.pdf', 10, 17997);
INSERT INTO 'danceurl' VALUES (5381, 'https://tunes.e-cribs.org/Sunny_Seas.pdf', 10, 17943);
INSERT INTO 'danceurl' VALUES (5382, 'https://tunes.e-cribs.org/Longing.pdf', 10, 14365);
INSERT INTO 'danceurl' VALUES (5383, 'https://tunes.e-cribs.org/Leapfrog.pdf', 10, 15119);
INSERT INTO 'danceurl' VALUES (5384, 'https://tunes.e-cribs.org/Lives_Entwining.pdf', 10, 18002);
INSERT INTO 'danceurl' VALUES (5385, 'https://tunes.e-cribs.org/The_Ladies_Ebony_and_Ivory.pdf', 10, 15112);
INSERT INTO 'danceurl' VALUES (5386, 'https://tunes.e-cribs.org/Letting_Go.pdf', 10, 15104);
INSERT INTO 'danceurl' VALUES (5387, 'https://tunes.e-cribs.org/Liebet_s_Snake_Dance.pdf', 10, 15105);
INSERT INTO 'danceurl' VALUES (5388, 'https://tunes.e-cribs.org/Love_and_Sunbeams.pdf', 10, 13917);
INSERT INTO 'danceurl' VALUES (5389, 'https://tunes.e-cribs.org/Lyn_s_Hornpipe.pdf', 10, 13926);
INSERT INTO 'danceurl' VALUES (5390, 'https://tunes.e-cribs.org/Malcolm_Brown_of_Dunnington.pdf', 10, 13911);
INSERT INTO 'danceurl' VALUES (5391, 'https://tunes.e-cribs.org/Master_Duncan_Nelson.pdf', 10, 15115);
INSERT INTO 'danceurl' VALUES (5392, 'https://tunes.e-cribs.org/Memories.pdf', 10, 18003);
INSERT INTO 'danceurl' VALUES (5394, 'https://tunes.e-cribs.org/Mrs_Margo_Monteith.pdf', 10, 13919);
INSERT INTO 'danceurl' VALUES (5395, 'https://tunes.e-cribs.org/My_Heart_is_in_the_South.pdf', 10, 18001);
INSERT INTO 'danceurl' VALUES (5396, 'https://tunes.e-cribs.org/Nineteen_Years.pdf', 10, 16525);
INSERT INTO 'danceurl' VALUES (5397, 'https://tunes.e-cribs.org/Where_the_Mountains_Meet_the_Sea.pdf', 10, 18012);
INSERT INTO 'danceurl' VALUES (5398, 'https://tunes.e-cribs.org/The_Stubborn_Composer.pdf', 10, 18000);
INSERT INTO 'danceurl' VALUES (5399, 'https://tunes.e-cribs.org/Stormy_Skies.pdf', 10, 18005);
INSERT INTO 'danceurl' VALUES (5400, 'https://tunes.e-cribs.org/Reel_Collaboration.pdf', 10, 17999);
INSERT INTO 'danceurl' VALUES (5031, 'https://dances.e-cribs.org/Peter_s_Farewell.pdf', 10, 5234);
INSERT INTO 'danceurl' VALUES (5401, 'https://tunes.e-cribs.org/The_Party_Tree.pdf', 10, 18008);
INSERT INTO 'danceurl' VALUES (5402, 'https://tunes.e-cribs.org/Opposites_Attract.pdf', 10, 15113);
INSERT INTO 'danceurl' VALUES (5404, 'https://tunes.e-cribs.org/Of_meetings_and_partings.pdf', 10, 14366);
INSERT INTO 'danceurl' VALUES (5405, 'https://tunes.e-cribs.org/Of_Jack_and_Jill.pdf', 10, 18010);
INSERT INTO 'danceurl' VALUES (5344, 'https://tunes.e-cribs.org/wj/From_a_dream.pdf', 10, 18277);
INSERT INTO 'danceurl' VALUES (5406, 'https://tunes.e-cribs.org/Of_Butterflies_and_Rainbows.pdf', 10, 15118);
INSERT INTO 'danceurl' VALUES (5407, 'https://tunes.e-cribs.org/No_Sitting_on_the_Fence_(F_Major).pdf', 10, 15622);
INSERT INTO 'danceurl' VALUES (5408, 'https://tunes.e-cribs.org/Niel_van_der_Watt_s_Strathspey.pdf', 10, 15108);
INSERT INTO 'danceurl' VALUES (5409, 'https://tunes.e-cribs.org/Whirling_Wind.pdf', 10, 16776);
INSERT INTO 'danceurl' VALUES (5412, 'https://my.strathspey.org/u/murrough/FideleDeLausanne.pdf', 10, 18288);
INSERT INTO 'danceurl' VALUES (5413, 'https://my.strathspey.org/u/murrough/other/SurbitonFrolic.pdf', 10, 18309);
INSERT INTO 'danceurl' VALUES (5414, 'https://my.strathspey.org/u/murrough/CircuitOfSedbergh.pdf', 10, 18335);
INSERT INTO 'danceurl' VALUES (5415, 'https://tunes.e-cribs.org/When_Harry_Wed_Meghan.pdf', 10, 18341);
INSERT INTO 'danceurl' VALUES (5416, 'https://dances.e-cribs.org/Summerfield_Lass.pdf', 10, 18351);
INSERT INTO 'danceurl' VALUES (5342, 'https://suedan.com/dances/instructions/glasgowlassie.html', 10, 18274);
INSERT INTO 'danceurl' VALUES (5411, 'https://my.strathspey.org/u/murrough/TorqueBack.pdf', 10, 18287);
INSERT INTO 'danceurl' VALUES (5429, 'https://drive.google.com/file/d/0B9R_Fl585MrbaGRMcVFuWmREcFU/view', 10, 15306);
INSERT INTO 'danceurl' VALUES (5430, 'https://drive.google.com/file/d/0B9R_Fl585Mrbdk8ycGtCVnNRSlE/view', 10, 15307);
INSERT INTO 'danceurl' VALUES (5431, 'https://drive.google.com/file/d/0B9R_Fl585MrbWkhOMnRpam1ReFU/view', 10, 15308);
INSERT INTO 'danceurl' VALUES (5432, 'https://drive.google.com/file/d/0B9R_Fl585MrbZ2YzeTdtN1A2VEU/view', 10, 15309);
INSERT INTO 'danceurl' VALUES (5433, 'https://drive.google.com/file/d/0B9R_Fl585MrbM0k1YTdqRnQ4YVE/view', 12, 14356);
INSERT INTO 'danceurl' VALUES (5434, 'https://drive.google.com/file/d/0B9R_Fl585MrbYTFjZTJYVE95NG8/view', 10, 15310);
INSERT INTO 'danceurl' VALUES (5435, 'https://drive.google.com/file/d/0B9R_Fl585MrbVlExZ2JnTU1uZEk/view', 10, 15311);
INSERT INTO 'danceurl' VALUES (5436, 'https://drive.google.com/file/d/0B9R_Fl585MrbUktaTUdac2N0TGM/view', 10, 15312);
INSERT INTO 'danceurl' VALUES (4725, 'http://www.strathspey.org/lists/strathspey%40strathspey.org/t/55165/', 10, 14642);
INSERT INTO 'danceurl' VALUES (4275, 'https://dances.e-cribs.org/Fear_An_Taigh.pdf', 10, 10824);
INSERT INTO 'danceurl' VALUES (4354, 'https://dances.e-cribs.org/Maid_from_Morningside.pdf', 10, 11555);
INSERT INTO 'danceurl' VALUES (5439, 'https://dances.e-cribs.org/14_12.pdf', 10, 9812);
INSERT INTO 'danceurl' VALUES (5440, 'https://dances.e-cribs.org/Greetings_from_Lipica.pdf', 10, 9679);
INSERT INTO 'danceurl' VALUES (5441, 'https://dances.e-cribs.org/Down_the_Primrose_Path.pdf', 10, 10284);
INSERT INTO 'danceurl' VALUES (5442, 'https://dances.e-cribs.org/Join_the_Dance.pdf', 10, 8922);
INSERT INTO 'danceurl' VALUES (4566, 'http://www.waverleyscottishsociety.com/GradStrath.pdf', 10, 13231);
INSERT INTO 'danceurl' VALUES (5445, 'http://www.waverleyscottishsociety.com/BrokenRiverReel.pdf', 10, 13230);
INSERT INTO 'danceurl' VALUES (5446, 'http://www.waverleyscottishsociety.com/DoubleForty.pdf', 10, 14765);
INSERT INTO 'danceurl' VALUES (5052, 'https://sites.google.com/site/thefollyofrogues/cusrc-reelwiki/cherry-blossom-season', 10, 16918);
INSERT INTO 'danceurl' VALUES (5053, 'https://sites.google.com/site/thefollyofrogues/cusrc-reelwiki/do-not-apologise', 10, 16919);
INSERT INTO 'danceurl' VALUES (5056, 'https://sites.google.com/site/thefollyofrogues/cusrc-reelwiki/smoke-and-mirrors', 10, 16922);
INSERT INTO 'danceurl' VALUES (5450, 'http://www.scottishdance.net/dances/Book/BruntsfieldLinks.pdf', 10, 15577);
INSERT INTO 'danceurl' VALUES (5451, 'https://tunes.e-cribs.org/Yellowing_Leaves.pdf', 10, 18555);
INSERT INTO 'danceurl' VALUES (5452, 'http://www.rscds-wirral.org.uk/dances.html', 10, 18567);
INSERT INTO 'danceurl' VALUES (5453, 'http://www.minicrib.org.uk/Publications/AlanCottle/MILLENNIUM_WEDDING.pdf', 10, 18572);
INSERT INTO 'danceurl' VALUES (5454, 'http://www.minicrib.org.uk/Publications/AlanCottle/JIGGLES.pdf', 10, 18573);
INSERT INTO 'danceurl' VALUES (5455, 'http://www.minicrib.org.uk/Publications/The%20Treasured%20Cove.pdf', 10, 18092);
INSERT INTO 'danceurl' VALUES (5460, 'http://www.minicrib.org.uk/Publications/The%20Golden%20Hills%20of%20Glen%20Orrin%20with%20Music.pdf', 10, 18588);
INSERT INTO 'danceurl' VALUES (5461, 'https://harwellscdc.mno.org.uk/wp-content/uploads/2018/09/AllRightBob.pdf', 10, 18624);
INSERT INTO 'danceurl' VALUES (5462, 'https://harwellscdc.mno.org.uk/wp-content/uploads/2018/09/AllRightBob.pdf', 10, 18623);
INSERT INTO 'danceurl' VALUES (5463, 'https://my.strathspey.org/u/murrough/BrokenSymmetry.pdf', 10, 18659);
INSERT INTO 'danceurl' VALUES (5464, 'https://my.strathspey.org/u/murrough/AshleyInWonderland.pdf', 10, 18662);
INSERT INTO 'danceurl' VALUES (5465, 'https://my.strathspey.org/u/murrough/NimbleFlowerOfNyon.pdf', 10, 18660);
INSERT INTO 'danceurl' VALUES (5466, 'https://my.strathspey.org/u/murrough/InThisStyle.pdf', 10, 18661);
INSERT INTO 'danceurl' VALUES (5467, 'https://suedan.com/dances/instructions/wanderingeggplant.html', 10, 18574);
INSERT INTO 'danceurl' VALUES (4190, 'https://suedan.com/silk_and_thistle/quark.html', 10, 10050);
INSERT INTO 'danceurl' VALUES (5468, 'https://suedan.com/silk_and_thistle/diligentdevisor.html', 10, 12058);
INSERT INTO 'danceurl' VALUES (5469, 'https://suedan.com/silk_and_thistle/suecomesroundagain.html', 10, 12060);
INSERT INTO 'danceurl' VALUES (5470, 'https://suedan.com/george/sandt.html', 10, 9741);
INSERT INTO 'danceurl' VALUES (5472, 'https://suedan.com/george/dpath.html', 10, 9743);
INSERT INTO 'danceurl' VALUES (5473, 'https://suedan.com/george/ring.html', 10, 10013);
INSERT INTO 'danceurl' VALUES (5474, 'https://suedan.com/dances/instructions/5feistywomenandmichael.html', 10, 18672);
INSERT INTO 'danceurl' VALUES (5475, 'https://suedan.com/dances/instructions/9pinbowling.html', 10, 18673);
INSERT INTO 'danceurl' VALUES (4906, 'https://suedan.com/dances/instructions/afteralltheseyears.html', 10, 16288);
INSERT INTO 'danceurl' VALUES (5476, 'https://suedan.com/dances/instructions/albertaarts.html', 10, 18674);
INSERT INTO 'danceurl' VALUES (5477, 'https://suedan.com/dances/instructions/alltogetheragain.html', 10, 18675);
INSERT INTO 'danceurl' VALUES (5478, 'https://suedan.com/dances/instructions/anaugustday.html', 10, 18676);
INSERT INTO 'danceurl' VALUES (4509, 'https://suedan.com/dances/instructions/annawest.html', 10, 13152);
INSERT INTO 'danceurl' VALUES (5338, 'https://tunes.e-cribs.org/wj/Red_Disa_Reel2021.pdf', 10, 15124);
INSERT INTO 'danceurl' VALUES (5444, 'https://drive.google.com/file/d/1M3OIcFDtzuWRhIUaSqZJtDtADh1URZ-W/view', 10, 14122);
INSERT INTO 'danceurl' VALUES (5447, 'https://drive.google.com/file/d/1v9PkfnlA4op7q0RYA_tLbEHVysBCgIYO/view', 10, 14118);
INSERT INTO 'danceurl' VALUES (5479, 'https://suedan.com/dances/instructions/anotherrantday.html', 10, 18677);
INSERT INTO 'danceurl' VALUES (5480, 'https://suedan.com/dances/instructions/appmadness.html', 10, 18678);
INSERT INTO 'danceurl' VALUES (5481, 'https://suedan.com/dances/instructions/arboreallace.html', 10, 18679);
INSERT INTO 'danceurl' VALUES (5482, 'https://suedan.com/dances/instructions/asynchronicity.html', 10, 18680);
INSERT INTO 'danceurl' VALUES (5483, 'https://suedan.com/dances/instructions/backtrack.html', 10, 18681);
INSERT INTO 'danceurl' VALUES (5484, 'https://suedan.com/dances/instructions/bangersmash.html', 10, 14562);
INSERT INTO 'danceurl' VALUES (5485, 'https://suedan.com/dances/instructions/belleball.html', 10, 15609);
INSERT INTO 'danceurl' VALUES (4217, 'https://suedan.com/dances/instructions/bendinriver.html', 10, 10253);
INSERT INTO 'danceurl' VALUES (5486, 'https://suedan.com/dances/instructions/bizzybeereel.html', 10, 18682);
INSERT INTO 'danceurl' VALUES (5487, 'https://suedan.com/dances/instructions/bloodmoon.html', 10, 18683);
INSERT INTO 'danceurl' VALUES (5488, 'https://suedan.com/dances/instructions/bonniesreel.html', 10, 18684);
INSERT INTO 'danceurl' VALUES (5489, 'https://suedan.com/dances/instructions/bornebreeze.html', 10, 18685);
INSERT INTO 'danceurl' VALUES (5490, 'https://suedan.com/dances/instructions/breakersontheshore.html', 10, 18686);
INSERT INTO 'danceurl' VALUES (5491, 'https://suedan.com/dances/instructions/brecksvillebeckons.html', 10, 18687);
INSERT INTO 'danceurl' VALUES (5492, 'https://suedan.com/dances/instructions/briggslaw.html', 10, 18688);
INSERT INTO 'danceurl' VALUES (5493, 'https://suedan.com/dances/instructions/brokensleep.html', 10, 18689);
INSERT INTO 'danceurl' VALUES (5494, 'https://suedan.com/dances/instructions/brokensymmetry.html', 10, 18690);
INSERT INTO 'danceurl' VALUES (5495, 'https://suedan.com/dances/instructions/bubbleuplake.html', 10, 18691);
INSERT INTO 'danceurl' VALUES (5496, 'https://suedan.com/dances/instructions/butterflyeffect.html', 10, 18692);
INSERT INTO 'danceurl' VALUES (5497, 'https://suedan.com/dances/instructions/caesarsfolly.html', 10, 18693);
INSERT INTO 'danceurl' VALUES (5498, 'https://suedan.com/dances/instructions/candles.html', 10, 18694);
INSERT INTO 'danceurl' VALUES (5499, 'https://suedan.com/dances/instructions/candycane.html', 10, 18695);
INSERT INTO 'danceurl' VALUES (5500, 'https://suedan.com/dances/instructions/canfieldconnection.html', 10, 18698);
INSERT INTO 'danceurl' VALUES (5501, 'https://suedan.com/dances/instructions/cardtrick.html', 10, 18699);
INSERT INTO 'danceurl' VALUES (5502, 'https://suedan.com/dances/instructions/carouselcanter.html', 10, 18700);
INSERT INTO 'danceurl' VALUES (5503, 'https://suedan.com/dances/instructions/carpenterswheel.html', 10, 18701);
INSERT INTO 'danceurl' VALUES (5504, 'https://suedan.com/dances/instructions/catplay.html', 10, 18702);
INSERT INTO 'danceurl' VALUES (5505, 'https://suedan.com/dances/instructions/catwhowasntthere.html', 10, 18703);
INSERT INTO 'danceurl' VALUES (5506, 'https://suedan.com/dances/instructions/celtictwist.html', 10, 18704);
INSERT INTO 'danceurl' VALUES (5507, 'https://suedan.com/dances/instructions/cementmixer.html', 10, 18705);
INSERT INTO 'danceurl' VALUES (5508, 'https://suedan.com/dances/instructions/chainlink.html', 10, 18706);
INSERT INTO 'danceurl' VALUES (5509, 'https://suedan.com/dances/instructions/charliesjig.html', 10, 18707);
INSERT INTO 'danceurl' VALUES (5510, 'https://suedan.com/dances/instructions/chasingreddot.html', 10, 18708);
INSERT INTO 'danceurl' VALUES (5471, 'https://suedan.com/george/maryh.html', 10, 9742);
INSERT INTO 'danceurl' VALUES (5458, 'https://suedan.com/dances/instructions/pickleinthemiddle.html', 10, 18584);
INSERT INTO 'danceurl' VALUES (5457, 'https://suedan.com/dances/instructions/quiltersquest.html', 10, 18583);
INSERT INTO 'danceurl' VALUES (5459, 'https://suedan.com/dances/instructions/westandwithfrance.html', 10, 18585);
INSERT INTO 'danceurl' VALUES (5456, 'https://suedan.com/dances/instructions/matrixmedley.html', 10, 18582);
INSERT INTO 'danceurl' VALUES (5443, 'https://dances.e-cribs.org/Miri_s_Wedding.pdf', 10, 12929);
INSERT INTO 'danceurl' VALUES (5511, 'https://suedan.com/dances/instructions/chicagosilver.html', 10, 12054);
INSERT INTO 'danceurl' VALUES (5512, 'https://suedan.com/dances/instructions/chickadeesatthefeeder.html', 10, 18709);
INSERT INTO 'danceurl' VALUES (5514, 'https://suedan.com/dances/instructions/christmascandy.html', 10, 18711);
INSERT INTO 'danceurl' VALUES (5515, 'https://suedan.com/dances/instructions/cinnamonswirl.html', 10, 12174);
INSERT INTO 'danceurl' VALUES (5516, 'https://suedan.com/dances/instructions/circlingglobe.html', 10, 18712);
INSERT INTO 'danceurl' VALUES (4522, 'https://suedan.com/dances/instructions/clarasreel.html', 10, 13165);
INSERT INTO 'danceurl' VALUES (5517, 'https://suedan.com/dances/instructions/cloakofinvisibility.html', 10, 18713);
INSERT INTO 'danceurl' VALUES (5449, 'https://suedan.com/dances/instructions/cloudcover.html', 10, 18507);
INSERT INTO 'danceurl' VALUES (5518, 'https://suedan.com/dances/instructions/comfortandjoy.html', 10, 18714);
INSERT INTO 'danceurl' VALUES (5519, 'https://suedan.com/dances/instructions/corinthiancolumns.html', 10, 18715);
INSERT INTO 'danceurl' VALUES (5047, 'https://suedan.com/dances/instructions/coveredbyautumnleaves.html', 10, 16912);
INSERT INTO 'danceurl' VALUES (5520, 'https://suedan.com/dances/instructions/crisscross.html', 10, 18716);
INSERT INTO 'danceurl' VALUES (5521, 'https://suedan.com/dances/instructions/crossandtwist.html', 10, 18717);
INSERT INTO 'danceurl' VALUES (5522, 'https://suedan.com/dances/instructions/crossingdeadlydesert.html', 10, 18718);
INSERT INTO 'danceurl' VALUES (5523, 'https://suedan.com/dances/instructions/crossingtheline.html', 10, 18719);
INSERT INTO 'danceurl' VALUES (5524, 'https://suedan.com/dances/instructions/curlycat.html', 10, 18722);
INSERT INTO 'danceurl' VALUES (5525, 'https://suedan.com/dances/instructions/daffodils.html', 10, 12392);
INSERT INTO 'danceurl' VALUES (5526, 'https://suedan.com/dances/instructions/danceprogram.html', 10, 12182);
INSERT INTO 'danceurl' VALUES (5527, 'https://suedan.com/dances/instructions/dancinginmyhead.html', 10, 18723);
INSERT INTO 'danceurl' VALUES (5528, 'https://suedan.com/dances/instructions/dansjig.html', 10, 18724);
INSERT INTO 'danceurl' VALUES (5529, 'https://suedan.com/dances/instructions/darkisrising.html', 10, 18725);
INSERT INTO 'danceurl' VALUES (5530, 'https://suedan.com/dances/instructions/darksideofmoon.html', 10, 18726);
INSERT INTO 'danceurl' VALUES (5531, 'https://suedan.com/dances/instructions/dasherdancer.html', 10, 18727);
INSERT INTO 'danceurl' VALUES (5532, 'https://suedan.com/dances/instructions/dayofthedead.html', 10, 18728);
INSERT INTO 'danceurl' VALUES (5533, 'https://suedan.com/dances/instructions/deathstar.html', 10, 18729);
INSERT INTO 'danceurl' VALUES (5534, 'https://suedan.com/dances/instructions/deerinheadlights.html', 10, 18730);
INSERT INTO 'danceurl' VALUES (4318, 'https://suedan.com/dances/instructions/delllane.html', 10, 11466);
INSERT INTO 'danceurl' VALUES (5535, 'https://suedan.com/dances/instructions/diamondback.html', 10, 18731);
INSERT INTO 'danceurl' VALUES (5536, 'https://suedan.com/dances/instructions/diamondsonblackvelvet.html', 10, 18732);
INSERT INTO 'danceurl' VALUES (5537, 'https://suedan.com/dances/instructions/dipsydoodle.html', 10, 18733);
INSERT INTO 'danceurl' VALUES (5538, 'https://suedan.com/dances/instructions/disappearingcat.html', 10, 18734);
INSERT INTO 'danceurl' VALUES (5539, 'https://suedan.com/dances/instructions/discoball.html', 10, 18735);
INSERT INTO 'danceurl' VALUES (5540, 'https://suedan.com/dances/instructions/dolphinplay.html', 10, 12188);
INSERT INTO 'danceurl' VALUES (5541, 'https://suedan.com/dances/instructions/doublecross.html', 10, 18736);
INSERT INTO 'danceurl' VALUES (5542, 'https://suedan.com/dances/instructions/doubleferriswheel.html', 10, 18737);
INSERT INTO 'danceurl' VALUES (5543, 'https://suedan.com/dances/instructions/doublehelix.html', 10, 18738);
INSERT INTO 'danceurl' VALUES (5544, 'https://suedan.com/dances/instructions/doubleknitting.html', 10, 18739);
INSERT INTO 'danceurl' VALUES (5545, 'https://suedan.com/dances/instructions/doublenickel.html', 10, 12190);
INSERT INTO 'danceurl' VALUES (5546, 'https://suedan.com/dances/instructions/doubletime.html', 10, 12191);
INSERT INTO 'danceurl' VALUES (5547, 'https://suedan.com/dances/instructions/dougs7-0reel.html', 10, 18740);
INSERT INTO 'danceurl' VALUES (5548, 'https://suedan.com/dances/instructions/dupageriver.html', 10, 18741);
INSERT INTO 'danceurl' VALUES (5549, 'https://suedan.com/dances/instructions/durhambound.html', 10, 12200);
INSERT INTO 'danceurl' VALUES (5550, 'https://suedan.com/dances/instructions/eighteensix.html', 10, 18742);
INSERT INTO 'danceurl' VALUES (5551, 'https://suedan.com/dances/instructions/emilygrace.html', 10, 18743);
INSERT INTO 'danceurl' VALUES (5552, 'https://suedan.com/dances/instructions/emilysfireworks.html', 10, 18744);
INSERT INTO 'danceurl' VALUES (5553, 'https://suedan.com/dances/instructions/endtoend.html', 10, 18745);
INSERT INTO 'danceurl' VALUES (5554, 'https://suedan.com/dances/instructions/faithfulfeline.html', 10, 18746);
INSERT INTO 'danceurl' VALUES (5555, 'https://suedan.com/dances/instructions/fanwoodfrolic.html', 10, 18747);
INSERT INTO 'danceurl' VALUES (5556, 'https://suedan.com/dances/instructions/fiddlemeister.html', 10, 18748);
INSERT INTO 'danceurl' VALUES (5557, 'https://suedan.com/dances/instructions/fifthhelix.html', 10, 18749);
INSERT INTO 'danceurl' VALUES (5558, 'https://suedan.com/dances/instructions/fireflyflirt.html', 10, 18750);
INSERT INTO 'danceurl' VALUES (5559, 'https://suedan.com/dances/instructions/first100years.html', 10, 18751);
INSERT INTO 'danceurl' VALUES (5560, 'https://suedan.com/dances/instructions/flamingocroquet.html', 10, 18752);
INSERT INTO 'danceurl' VALUES (5561, 'https://suedan.com/dances/instructions/flashesofgold.html', 10, 18753);
INSERT INTO 'danceurl' VALUES (5562, 'https://suedan.com/dances/instructions/flashlight.html', 10, 18754);
INSERT INTO 'danceurl' VALUES (5563, 'https://suedan.com/dances/instructions/flibbertigibbet.html', 10, 18755);
INSERT INTO 'danceurl' VALUES (5564, 'https://suedan.com/dances/instructions/flightoffancy.html', 10, 18756);
INSERT INTO 'danceurl' VALUES (5565, 'https://suedan.com/dances/instructions/flipflop.html', 10, 18757);
INSERT INTO 'danceurl' VALUES (5566, 'https://suedan.com/dances/instructions/flirtydancer.html', 10, 12306);
INSERT INTO 'danceurl' VALUES (5567, 'https://suedan.com/dances/instructions/flume.html', 10, 18758);
INSERT INTO 'danceurl' VALUES (5568, 'https://suedan.com/dances/instructions/flyingblueangels.html', 10, 18759);
INSERT INTO 'danceurl' VALUES (5569, 'https://suedan.com/dances/instructions/flythew.html', 10, 18760);
INSERT INTO 'danceurl' VALUES (5570, 'https://suedan.com/dances/instructions/folderol.html', 10, 12303);
INSERT INTO 'danceurl' VALUES (5571, 'https://suedan.com/dances/instructions/followleader.html', 10, 18761);
INSERT INTO 'danceurl' VALUES (5572, 'https://suedan.com/dances/instructions/followyellowbrickroad.html', 10, 18762);
INSERT INTO 'danceurl' VALUES (5573, 'https://suedan.com/dances/instructions/followyourdream.html', 10, 18763);
INSERT INTO 'danceurl' VALUES (5574, 'https://suedan.com/dances/instructions/freedomrant.html', 10, 18764);
INSERT INTO 'danceurl' VALUES (5575, 'https://suedan.com/dances/instructions/frenchroundabout.html', 10, 18765);
INSERT INTO 'danceurl' VALUES (5576, 'https://suedan.com/dances/instructions/fridaynight.html', 10, 12068);
INSERT INTO 'danceurl' VALUES (5577, 'https://suedan.com/dances/instructions/friskyfeet.html', 10, 18766);
INSERT INTO 'danceurl' VALUES (5578, 'https://suedan.com/dances/instructions/frozenfalls.html', 10, 18767);
INSERT INTO 'danceurl' VALUES (5579, 'https://suedan.com/dances/instructions/furpile.html', 10, 18768);
INSERT INTO 'danceurl' VALUES (5580, 'https://suedan.com/dances/instructions/gearshift.html', 10, 18769);
INSERT INTO 'danceurl' VALUES (5581, 'https://suedan.com/dances/instructions/geneseeriver.html', 10, 18770);
INSERT INTO 'danceurl' VALUES (5582, 'https://suedan.com/dances/instructions/georgewhitehorne.html', 10, 18771);
INSERT INTO 'danceurl' VALUES (5583, 'https://suedan.com/dances/instructions/ghostandmaryjo.html', 10, 18772);
INSERT INTO 'danceurl' VALUES (5584, 'https://suedan.com/dances/instructions/giftwrapped.html', 10, 18773);
INSERT INTO 'danceurl' VALUES (5585, 'https://suedan.com/dances/instructions/glassscroll.html', 10, 18774);
INSERT INTO 'danceurl' VALUES (5586, 'https://suedan.com/dances/instructions/glenirisinn.html', 10, 18775);
INSERT INTO 'danceurl' VALUES (5587, 'https://suedan.com/dances/instructions/gocubsgo.html', 10, 18776);
INSERT INTO 'danceurl' VALUES (5588, 'https://suedan.com/dances/instructions/goldenrain.html', 10, 18777);
INSERT INTO 'danceurl' VALUES (5589, 'https://suedan.com/dances/instructions/goldring.html', 10, 18778);
INSERT INTO 'danceurl' VALUES (5590, 'https://suedan.com/dances/instructions/goleft.html', 10, 18779);
INSERT INTO 'danceurl' VALUES (5591, 'https://suedan.com/dances/instructions/gordionknot.html', 10, 18780);
INSERT INTO 'danceurl' VALUES (5592, 'https://suedan.com/dances/instructions/gregsplace.html', 10, 12261);
INSERT INTO 'danceurl' VALUES (5593, 'https://suedan.com/dances/instructions/gypsy.html', 10, 18781);
INSERT INTO 'danceurl' VALUES (5594, 'https://suedan.com/dances/instructions/hangingfromrafters.html', 10, 18782);
INSERT INTO 'danceurl' VALUES (5595, 'https://suedan.com/dances/instructions/happyharrison.html', 10, 18783);
INSERT INTO 'danceurl' VALUES (5596, 'https://suedan.com/dances/instructions/happyheart.html', 10, 12266);
INSERT INTO 'danceurl' VALUES (5597, 'https://suedan.com/dances/instructions/harringtonsfeather.html', 10, 18784);
INSERT INTO 'danceurl' VALUES (5598, 'https://suedan.com/dances/instructions/hauntedhouse.html', 10, 18785);
INSERT INTO 'danceurl' VALUES (5599, 'https://suedan.com/dances/instructions/hawkontherail.html', 10, 18786);
INSERT INTO 'danceurl' VALUES (4555, 'https://suedan.com/dances/instructions/highlandgypsy.html', 10, 13198);
INSERT INTO 'danceurl' VALUES (5600, 'https://suedan.com/dances/instructions/hogwartsexpress.html', 10, 18788);
INSERT INTO 'danceurl' VALUES (5601, 'https://suedan.com/dances/instructions/honorthelady.html', 10, 18789);
INSERT INTO 'danceurl' VALUES (5602, 'https://suedan.com/dances/instructions/hornofplenty.html', 10, 18790);
INSERT INTO 'danceurl' VALUES (5603, 'https://suedan.com/dances/instructions/howtoteachahuman.html', 10, 18377);
INSERT INTO 'danceurl' VALUES (5604, 'https://suedan.com/dances/instructions/inquisitivepaws.html', 10, 18792);
INSERT INTO 'danceurl' VALUES (5605, 'https://suedan.com/dances/instructions/interlockingwheels.html', 10, 18793);
INSERT INTO 'danceurl' VALUES (5606, 'https://suedan.com/dances/instructions/intheborealforest.html', 10, 18794);
INSERT INTO 'danceurl' VALUES (5607, 'https://suedan.com/dances/instructions/itsabouttiming.html', 10, 18795);
INSERT INTO 'danceurl' VALUES (5608, 'https://suedan.com/dances/instructions/itsjustanumber.html', 10, 18796);
INSERT INTO 'danceurl' VALUES (5609, 'https://suedan.com/dances/instructions/jackpumpkinhead.html', 10, 18797);
INSERT INTO 'danceurl' VALUES (5610, 'https://suedan.com/dances/instructions/jensenjig.html', 10, 12284);
INSERT INTO 'danceurl' VALUES (5611, 'https://suedan.com/dances/instructions/jigandhollar.html', 10, 18798);
INSERT INTO 'danceurl' VALUES (5612, 'https://suedan.com/dances/instructions/johnbarleycorn.html', 10, 18799);
INSERT INTO 'danceurl' VALUES (5613, 'https://suedan.com/dances/instructions/justalittlerant.html', 10, 18800);
INSERT INTO 'danceurl' VALUES (5614, 'https://suedan.com/dances/instructions/justascrazyasitlooked.html', 10, 18801);
INSERT INTO 'danceurl' VALUES (5615, 'https://suedan.com/dances/instructions/kiltflip.html', 10, 18802);
INSERT INTO 'danceurl' VALUES (5616, 'https://suedan.com/dances/instructions/kittycornered.html', 10, 18803);
INSERT INTO 'danceurl' VALUES (5617, 'https://suedan.com/dances/instructions/kittyrae.html', 10, 12295);
INSERT INTO 'danceurl' VALUES (5619, 'https://suedan.com/dances/instructions/knotwork.html', 10, 12297);
INSERT INTO 'danceurl' VALUES (5620, 'https://suedan.com/dances/instructions/kumihimo.html', 10, 16941);
INSERT INTO 'danceurl' VALUES (5621, 'https://suedan.com/dances/instructions/laceacrossthesky.html', 10, 18805);
INSERT INTO 'danceurl' VALUES (5622, 'https://suedan.com/dances/instructions/lacedthreads.html', 10, 18807);
INSERT INTO 'danceurl' VALUES (5624, 'https://suedan.com/dances/instructions/ladyfromwales.html', 10, 18809);
INSERT INTO 'danceurl' VALUES (5625, 'https://suedan.com/dances/instructions/ladygwen.html', 10, 12298);
INSERT INTO 'danceurl' VALUES (5626, 'https://suedan.com/dances/instructions/ladyhannah.html', 10, 18810);
INSERT INTO 'danceurl' VALUES (5627, 'https://suedan.com/dances/instructions/ladymairisdream.html', 10, 18811);
INSERT INTO 'danceurl' VALUES (5628, 'https://suedan.com/dances/instructions/ladyoftheelves.html', 10, 18812);
INSERT INTO 'danceurl' VALUES (4803, 'https://suedan.com/dances/instructions/lavender.html', 10, 14955);
INSERT INTO 'danceurl' VALUES (5629, 'https://suedan.com/dances/instructions/leftofcenter.html', 10, 14592);
INSERT INTO 'danceurl' VALUES (5630, 'https://suedan.com/dances/instructions/lentenrose.html', 10, 18813);
INSERT INTO 'danceurl' VALUES (5623, 'https://suedan.com/dances/instructions/ladiesofcertainage.html', 10, 18808);
INSERT INTO 'danceurl' VALUES (5631, 'https://suedan.com/dances/instructions/lightandshade.html', 10, 18814);
INSERT INTO 'danceurl' VALUES (5632, 'https://suedan.com/dances/instructions/lightninginabottle.html', 10, 18815);
INSERT INTO 'danceurl' VALUES (5633, 'https://suedan.com/dances/instructions/lindastriptobeloit.html', 10, 18816);
INSERT INTO 'danceurl' VALUES (5634, 'https://suedan.com/dances/instructions/littleh.html', 10, 18817);
INSERT INTO 'danceurl' VALUES (5635, 'https://suedan.com/dances/instructions/livelongandprosper.html', 10, 18818);
INSERT INTO 'danceurl' VALUES (5636, 'https://suedan.com/dances/instructions/lokisreel.html', 10, 18819);
INSERT INTO 'danceurl' VALUES (5637, 'https://suedan.com/dances/instructions/lorainmoraine.html', 10, 18820);
INSERT INTO 'danceurl' VALUES (4211, 'https://suedan.com/dances/instructions/lovelyhall.html', 10, 10247);
INSERT INTO 'danceurl' VALUES (5638, 'https://suedan.com/dances/instructions/lovemist.html', 10, 18821);
INSERT INTO 'danceurl' VALUES (5639, 'https://suedan.com/dances/instructions/lynnsrequest.html', 10, 18822);
INSERT INTO 'danceurl' VALUES (5640, 'https://suedan.com/dances/instructions/macrame.html', 10, 18823);
INSERT INTO 'danceurl' VALUES (5641, 'https://suedan.com/dances/instructions/madysidea.html', 10, 18824);
INSERT INTO 'danceurl' VALUES (5642, 'https://suedan.com/dances/instructions/mairisdoubledate.html', 10, 18825);
INSERT INTO 'danceurl' VALUES (5643, 'https://suedan.com/dances/instructions/maureencalling.html', 10, 12310);
INSERT INTO 'danceurl' VALUES (5644, 'https://suedan.com/dances/instructions/merrylittlejig.html', 10, 18826);
INSERT INTO 'danceurl' VALUES (5645, 'https://suedan.com/dances/instructions/midnightcrazies.html', 10, 18827);
INSERT INTO 'danceurl' VALUES (5646, 'https://suedan.com/dances/instructions/midwesternlinks.html', 10, 18828);
INSERT INTO 'danceurl' VALUES (5647, 'https://suedan.com/dances/instructions/mikesrequest.html', 10, 18829);
INSERT INTO 'danceurl' VALUES (5648, 'https://suedan.com/dances/instructions/misscreamcoral.html', 10, 18830);
INSERT INTO 'danceurl' VALUES (5649, 'https://suedan.com/dances/instructions/misspriss.html', 10, 18375);
INSERT INTO 'danceurl' VALUES (5650, 'https://suedan.com/dances/instructions/monkeywrench.html', 10, 12325);
INSERT INTO 'danceurl' VALUES (5651, 'https://suedan.com/dances/instructions/montyslittlebrother.html', 10, 18831);
INSERT INTO 'danceurl' VALUES (5652, 'https://suedan.com/dances/instructions/motorcyclelady.html', 10, 12328);
INSERT INTO 'danceurl' VALUES (5653, 'https://suedan.com/dances/instructions/movingtarget.html', 10, 18832);
INSERT INTO 'danceurl' VALUES (5654, 'https://suedan.com/dances/instructions/mrgilberthasarrived.html', 10, 18833);
INSERT INTO 'danceurl' VALUES (5655, 'https://suedan.com/dances/instructions/mrsnormabriggs.html', 10, 18834);
INSERT INTO 'danceurl' VALUES (5656, 'https://suedan.com/dances/instructions/musicspheres.html', 10, 18835);
INSERT INTO 'danceurl' VALUES (5657, 'https://suedan.com/dances/instructions/mybonnybeau.html', 10, 18836);
INSERT INTO 'danceurl' VALUES (5008, 'https://suedan.com/dances/instructions/narcissisity.html', 10, 16829);
INSERT INTO 'danceurl' VALUES (5658, 'https://suedan.com/dances/instructions/needykneader.html', 10, 18837);
INSERT INTO 'danceurl' VALUES (5659, 'https://suedan.com/dances/instructions/newrose.html', 10, 18838);
INSERT INTO 'danceurl' VALUES (5660, 'https://suedan.com/dances/instructions/niddynoddy.html', 10, 18839);
INSERT INTO 'danceurl' VALUES (5661, 'https://suedan.com/dances/instructions/notimetorest.html', 10, 18840);
INSERT INTO 'danceurl' VALUES (5662, 'https://suedan.com/dances/instructions/nyu.html', 10, 18841);
INSERT INTO 'danceurl' VALUES (5663, 'https://suedan.com/dances/instructions/offtheaxum.html', 10, 18842);
INSERT INTO 'danceurl' VALUES (5664, 'https://suedan.com/dances/instructions/offtooregon.html', 10, 18843);
INSERT INTO 'danceurl' VALUES (5665, 'https://suedan.com/dances/instructions/offtovareel.html', 10, 18844);
INSERT INTO 'danceurl' VALUES (5666, 'https://suedan.com/dances/instructions/orderedchaos.html', 10, 18845);
INSERT INTO 'danceurl' VALUES (5667, 'https://suedan.com/dances/instructions/ourpurrbear.html', 10, 18846);
INSERT INTO 'danceurl' VALUES (5668, 'https://suedan.com/dances/instructions/panama.html', 10, 18847);
INSERT INTO 'danceurl' VALUES (5669, 'https://suedan.com/dances/instructions/parchmentscroll.html', 10, 18848);
INSERT INTO 'danceurl' VALUES (5670, 'https://suedan.com/dances/instructions/parquet.html', 10, 18849);
INSERT INTO 'danceurl' VALUES (5671, 'https://suedan.com/dances/instructions/passingfancy.html', 10, 18850);
INSERT INTO 'danceurl' VALUES (5672, 'https://suedan.com/dances/instructions/physicistsfolly.html', 10, 13822);
INSERT INTO 'danceurl' VALUES (4314, 'https://suedan.com/dances/instructions/polychrome.html', 10, 11462);
INSERT INTO 'danceurl' VALUES (5673, 'https://suedan.com/dances/instructions/portagebridge.html', 10, 18856);
INSERT INTO 'danceurl' VALUES (5674, 'https://suedan.com/dances/instructions/puffinbilly.html', 10, 18857);
INSERT INTO 'danceurl' VALUES (5675, 'https://suedan.com/dances/instructions/puppeteer.html', 10, 18858);
INSERT INTO 'danceurl' VALUES (5676, 'https://suedan.com/dances/instructions/pussyfootin.html', 10, 18859);
INSERT INTO 'danceurl' VALUES (5678, 'https://suedan.com/dances/instructions/raccoonbabies.html', 10, 18861);
INSERT INTO 'danceurl' VALUES (5679, 'https://suedan.com/dances/instructions/randomwalk.html', 10, 18862);
INSERT INTO 'danceurl' VALUES (5680, 'https://suedan.com/dances/instructions/redrover.html', 10, 18863);
INSERT INTO 'danceurl' VALUES (5681, 'https://suedan.com/dances/instructions/reflectionreel.html', 10, 18864);
INSERT INTO 'danceurl' VALUES (5682, 'https://suedan.com/dances/instructions/regencyfaire.html', 10, 18865);
INSERT INTO 'danceurl' VALUES (5683, 'https://suedan.com/dances/instructions/ridingwave.html', 10, 18866);
INSERT INTO 'danceurl' VALUES (5684, 'https://suedan.com/dances/instructions/ripplesonpond.html', 10, 18867);
INSERT INTO 'danceurl' VALUES (5685, 'https://suedan.com/dances/instructions/robinsrowdyreel.html', 10, 18868);
INSERT INTO 'danceurl' VALUES (5686, 'https://suedan.com/dances/instructions/rockyriverice.html', 10, 18869);
INSERT INTO 'danceurl' VALUES (5687, 'https://suedan.com/dances/instructions/rockyriverreel.html', 10, 18870);
INSERT INTO 'danceurl' VALUES (5688, 'https://suedan.com/dances/instructions/rollercoasterride.html', 10, 18871);
INSERT INTO 'danceurl' VALUES (5689, 'https://suedan.com/dances/instructions/rosesharon.html', 10, 18872);
INSERT INTO 'danceurl' VALUES (5690, 'https://suedan.com/dances/instructions/rushhourtrain.html', 10, 18873);
INSERT INTO 'danceurl' VALUES (5691, 'https://suedan.com/dances/instructions/salmagundi.html', 10, 18874);
INSERT INTO 'danceurl' VALUES (5692, 'https://suedan.com/dances/instructions/sandsoftime.html', 10, 12385);
INSERT INTO 'danceurl' VALUES (5693, 'https://suedan.com/dances/instructions/sassycat.html', 10, 12386);
INSERT INTO 'danceurl' VALUES (5695, 'https://suedan.com/dances/instructions/sfsurprise.html', 10, 12059);
INSERT INTO 'danceurl' VALUES (5696, 'https://suedan.com/dances/instructions/shawshank.html', 10, 18876);
INSERT INTO 'danceurl' VALUES (4516, 'https://suedan.com/dances/instructions/sherlocksmom.html', 10, 13159);
INSERT INTO 'danceurl' VALUES (5697, 'https://suedan.com/dances/instructions/shesnoagentleman.html', 10, 18877);
INSERT INTO 'danceurl' VALUES (5698, 'https://suedan.com/dances/instructions/silverearrings.html', 10, 18878);
INSERT INTO 'danceurl' VALUES (5699, 'https://suedan.com/dances/instructions/silveronthetree.html', 10, 18879);
INSERT INTO 'danceurl' VALUES (5700, 'https://suedan.com/dances/instructions/simplesimon.html', 10, 18880);
INSERT INTO 'danceurl' VALUES (5701, 'https://suedan.com/dances/instructions/singaporefling.html', 10, 18881);
INSERT INTO 'danceurl' VALUES (5702, 'https://suedan.com/dances/instructions/sixtysix.html', 10, 18882);
INSERT INTO 'danceurl' VALUES (5703, 'https://suedan.com/dances/instructions/slopoke.html', 10, 18884);
INSERT INTO 'danceurl' VALUES (5704, 'https://suedan.com/dances/instructions/smoketrack.html', 10, 18885);
INSERT INTO 'danceurl' VALUES (5705, 'https://suedan.com/dances/instructions/snowscene.html', 10, 18886);
INSERT INTO 'danceurl' VALUES (5706, 'https://suedan.com/dances/instructions/soldiersbed.html', 10, 18887);
INSERT INTO 'danceurl' VALUES (5707, 'https://suedan.com/dances/instructions/solidgranite.html', 10, 18888);
INSERT INTO 'danceurl' VALUES (5708, 'https://suedan.com/dances/instructions/someoneinatree.html', 10, 18889);
INSERT INTO 'danceurl' VALUES (5709, 'https://suedan.com/dances/instructions/speedracer.html', 10, 18890);
INSERT INTO 'danceurl' VALUES (5710, 'https://suedan.com/dances/instructions/spiderweb.html', 10, 18891);
INSERT INTO 'danceurl' VALUES (5711, 'https://suedan.com/dances/instructions/spincycle.html', 10, 18892);
INSERT INTO 'danceurl' VALUES (5712, 'https://suedan.com/dances/instructions/spiralgalaxies.html', 10, 12391);
INSERT INTO 'danceurl' VALUES (5713, 'https://suedan.com/dances/instructions/splitpeasoup.html', 10, 18893);
INSERT INTO 'danceurl' VALUES (5714, 'https://suedan.com/dances/instructions/spoolknitting.html', 10, 18894);
INSERT INTO 'danceurl' VALUES (5715, 'https://suedan.com/dances/instructions/squarechaos.html', 10, 18895);
INSERT INTO 'danceurl' VALUES (5716, 'https://suedan.com/dances/instructions/squareday.html', 10, 18896);
INSERT INTO 'danceurl' VALUES (5717, 'https://suedan.com/dances/instructions/squareknot.html', 10, 18897);
INSERT INTO 'danceurl' VALUES (4342, 'https://suedan.com/dances/instructions/squashblossom.html', 10, 11501);
INSERT INTO 'danceurl' VALUES (5718, 'https://suedan.com/dances/instructions/stephaniesbigday.html', 10, 18898);
INSERT INTO 'danceurl' VALUES (5719, 'https://suedan.com/dances/instructions/stlouiscanyon.html', 10, 18899);
INSERT INTO 'danceurl' VALUES (5720, 'https://suedan.com/dances/instructions/strathspey10.html', 10, 18900);
INSERT INTO 'danceurl' VALUES (5721, 'https://suedan.com/dances/instructions/sudoku.html', 10, 18901);
INSERT INTO 'danceurl' VALUES (5722, 'https://suedan.com/dances/instructions/suesfantasy.html', 10, 18902);
INSERT INTO 'danceurl' VALUES (5723, 'https://suedan.com/dances/instructions/sugaronsnow.html', 10, 12396);
INSERT INTO 'danceurl' VALUES (5724, 'https://suedan.com/dances/instructions/sweetember.html', 10, 18903);
INSERT INTO 'danceurl' VALUES (5725, 'https://suedan.com/dances/instructions/sweetviolets.html', 10, 18904);
INSERT INTO 'danceurl' VALUES (5726, 'https://suedan.com/dances/instructions/takingturns.html', 10, 18905);
INSERT INTO 'danceurl' VALUES (5727, 'https://suedan.com/dances/instructions/tasteofpast.html', 10, 18906);
INSERT INTO 'danceurl' VALUES (5728, 'https://suedan.com/dances/instructions/thebugwhocametodance.html', 10, 18907);
INSERT INTO 'danceurl' VALUES (5729, 'https://suedan.com/dances/instructions/thegardenersbane.html', 10, 18908);
INSERT INTO 'danceurl' VALUES (5730, 'https://suedan.com/dances/instructions/thenorthernisles.html', 10, 18909);
INSERT INTO 'danceurl' VALUES (5731, 'https://suedan.com/dances/instructions/thepiratequeen.html', 10, 18910);
INSERT INTO 'danceurl' VALUES (5732, 'https://suedan.com/dances/instructions/thereandbackagain.html', 10, 18911);
INSERT INTO 'danceurl' VALUES (5733, 'https://suedan.com/dances/instructions/therearenoaurorasonvenus.html', 10, 18912);
INSERT INTO 'danceurl' VALUES (5734, 'https://suedan.com/dances/instructions/threelittlebandits.html', 10, 18913);
INSERT INTO 'danceurl' VALUES (5735, 'https://suedan.com/dances/instructions/throughthelookingglass.html', 10, 18914);
INSERT INTO 'danceurl' VALUES (5736, 'https://suedan.com/dances/instructions/timingiseverything.html', 10, 18915);
INSERT INTO 'danceurl' VALUES (5737, 'https://suedan.com/dances/instructions/tinydancer.html', 10, 18568);
INSERT INTO 'danceurl' VALUES (5738, 'https://suedan.com/dances/instructions/tinyspaces.html', 10, 18916);
INSERT INTO 'danceurl' VALUES (5739, 'https://suedan.com/dances/instructions/toastytootsies.html', 10, 18917);
INSERT INTO 'danceurl' VALUES (5740, 'https://suedan.com/dances/instructions/toboldlygo.html', 10, 18918);
INSERT INTO 'danceurl' VALUES (5741, 'https://suedan.com/dances/instructions/topcat.html', 10, 18919);
INSERT INTO 'danceurl' VALUES (5742, 'https://suedan.com/dances/instructions/topspin.html', 10, 18920);
INSERT INTO 'danceurl' VALUES (5743, 'https://suedan.com/dances/instructions/tourneesquare.html', 10, 12409);
INSERT INTO 'danceurl' VALUES (5744, 'https://suedan.com/dances/instructions/transitvenus.html', 10, 18921);
INSERT INTO 'danceurl' VALUES (5745, 'https://suedan.com/dances/instructions/triquetra.html', 10, 12413);
INSERT INTO 'danceurl' VALUES (5677, 'https://suedan.com/dances/instructions/quickjig.html', 10, 18860);
INSERT INTO 'danceurl' VALUES (5746, 'https://suedan.com/dances/instructions/triskel.html', 10, 12414);
INSERT INTO 'danceurl' VALUES (5748, 'https://suedan.com/dances/instructions/tumbleweed.html', 10, 18922);
INSERT INTO 'danceurl' VALUES (5749, 'https://suedan.com/dances/instructions/tunnellight.html', 10, 18923);
INSERT INTO 'danceurl' VALUES (5750, 'https://suedan.com/dances/instructions/turnaboutisfairplay.html', 10, 18924);
INSERT INTO 'danceurl' VALUES (5751, 'https://suedan.com/dances/instructions/turningtide.html', 10, 18925);
INSERT INTO 'danceurl' VALUES (5752, 'https://suedan.com/dances/instructions/twiddlybits.html', 10, 12415);
INSERT INTO 'danceurl' VALUES (4540, 'https://suedan.com/dances/instructions/twohearts.html', 10, 13183);
INSERT INTO 'danceurl' VALUES (5753, 'https://suedan.com/dances/instructions/ultimatebrief.html', 10, 18926);
INSERT INTO 'danceurl' VALUES (5754, 'https://suedan.com/dances/instructions/uncleisaac.html', 10, 18927);
INSERT INTO 'danceurl' VALUES (5755, 'https://suedan.com/dances/instructions/unintendedconsequences.html', 10, 18928);
INSERT INTO 'danceurl' VALUES (5756, 'https://suedan.com/dances/instructions/velcrokitty.html', 10, 18929);
INSERT INTO 'danceurl' VALUES (5757, 'https://suedan.com/dances/instructions/weaklink.html', 10, 18930);
INSERT INTO 'danceurl' VALUES (5758, 'https://suedan.com/dances/instructions/wheelsinwheels.html', 10, 18931);
INSERT INTO 'danceurl' VALUES (5759, 'https://suedan.com/dances/instructions/whengiantsfell.html', 10, 18932);
INSERT INTO 'danceurl' VALUES (5760, 'https://suedan.com/dances/instructions/wherestheknife.html', 10, 18933);
INSERT INTO 'danceurl' VALUES (5761, 'https://suedan.com/dances/instructions/whitepearlspeaks.html', 10, 18934);
INSERT INTO 'danceurl' VALUES (5762, 'https://suedan.com/dances/instructions/whitetornado.html', 10, 18376);
INSERT INTO 'danceurl' VALUES (5763, 'https://suedan.com/dances/instructions/whynot.html', 10, 18935);
INSERT INTO 'danceurl' VALUES (5764, 'https://suedan.com/dances/instructions/wingsatlantic.html', 10, 18936);
INSERT INTO 'danceurl' VALUES (5765, 'https://suedan.com/dances/instructions/winterlace.html', 10, 18937);
INSERT INTO 'danceurl' VALUES (5766, 'https://suedan.com/dances/instructions/wintersolstice.html', 10, 18938);
INSERT INTO 'danceurl' VALUES (5767, 'https://suedan.com/dances/instructions/wogglebug.html', 10, 18570);
INSERT INTO 'danceurl' VALUES (4329, 'https://suedan.com/dances/instructions/chickencoop.html', 10, 11488);
INSERT INTO 'danceurl' VALUES (5513, 'https://suedan.com/dances/instructions/afteronly5minutes.html', 10, 18710);
INSERT INTO 'danceurl' VALUES (5694, 'https://suedan.com/dances/instructions/ammolite.html', 10, 18875);
INSERT INTO 'danceurl' VALUES (5769, 'https://suedan.com/dances/instructions/babyc-mcd.html', 10, 18939);
INSERT INTO 'danceurl' VALUES (5770, 'https://suedan.com/dances/instructions/anygoodtune.html', 10, 18940);
INSERT INTO 'danceurl' VALUES (5087, 'https://harwellscdc.mno.org.uk/wp-content/uploads/2018/08/HCS-1948-1998-The-Hole-in-One.pdf', 10, 17045);
INSERT INTO 'danceurl' VALUES (5773, 'https://harwellscdc.mno.org.uk/wp-content/uploads/2018/08/HoopEhtEinniw.pdf', 10, 19039);
INSERT INTO 'danceurl' VALUES (5774, 'http://www.rscds-swws.org/news/stories/InfamousElGuapo.pdf', 10, 19041);
INSERT INTO 'danceurl' VALUES (5775, 'https://8x32.e-cribs.org/index.php/a/start-your-engines', 10, 14991);
INSERT INTO 'danceurl' VALUES (5776, 'http://www.strathspey.org/lists/strathspey@strathspey.org/m/29888/', 10, 10387);
INSERT INTO 'danceurl' VALUES (5777, 'http://www.strathspey.org/lists/strathspey@strathspey.org/m/25046/', 10, 10565);
INSERT INTO 'danceurl' VALUES (5778, 'http://scdk.de/WestCoastDelight.pdf', 10, 12451);
INSERT INTO 'danceurl' VALUES (5779, 'https://www.dropbox.com/s/aipc90jzu94wsax/Magic%20Moment%2C%20A%20-%204x32R.pdf?dl=0', 10, 19055);
INSERT INTO 'danceurl' VALUES (5780, 'http://www.rscds-swws.org/news/stories/InfamousElGuapo.htm', 10, 19041);
INSERT INTO 'danceurl' VALUES (5782, 'https://my.strathspey.org/u/murrough/Gallivanting.pdf', 10, 19125);
INSERT INTO 'danceurl' VALUES (5783, 'https://my.strathspey.org/u/murrough/ReflectionsOnWoodhallLoch.pdf', 10, 19126);
INSERT INTO 'danceurl' VALUES (5784, 'https://my.strathspey.org/u/murrough/WhirlwindAffairs.pdf', 10, 19127);
INSERT INTO 'danceurl' VALUES (4183, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/gypsy-dreams.html', 10, 9862);
INSERT INTO 'danceurl' VALUES (5785, 'http://www.bridportscottishdancers.org.uk/dances/breton/our_breton_friends.pdf', 10, 15655);
INSERT INTO 'danceurl' VALUES (5772, 'https://www.rscds-sf.org/resources/dances/Jezebel''s%20Jig.pdf', 10, 19035);
INSERT INTO 'danceurl' VALUES (4040, 'http://www.anselms.net/SCD/dances/frankfurt-fancy.pdf', 10, 7738);
INSERT INTO 'danceurl' VALUES (5786, 'https://suedan.com/dances/instructions/traveljenny.html', 10, 19143);
INSERT INTO 'danceurl' VALUES (5787, 'https://suedan.com/dances/instructions/27thofoctober.html', 10, 19144);
INSERT INTO 'danceurl' VALUES (5788, 'https://www.math.uci.edu/~asilverb/scd/audreyzetazoo.html', 10, 19172);
INSERT INTO 'danceurl' VALUES (5789, 'https://www.math.uci.edu/~asilverb/scd/ceilidhdance.html', 10, 19173);
INSERT INTO 'danceurl' VALUES (5790, 'https://www.math.uci.edu/~asilverb/scd/ringlein.html', 10, 19175);
INSERT INTO 'danceurl' VALUES (5791, 'https://www.math.uci.edu/~asilverb/scd/artinring.html', 10, 19176);
INSERT INTO 'danceurl' VALUES (5792, 'https://www.math.uci.edu/~asilverb/scd/ring.html', 10, 19174);
INSERT INTO 'danceurl' VALUES (5793, 'https://dances.e-cribs.org/The_Maypole_Medley.pdf', 10, 8627);
INSERT INTO 'danceurl' VALUES (5794, 'https://dances.e-cribs.org/Burning_Hearts.pdf', 10, 8629);
INSERT INTO 'danceurl' VALUES (5795, 'https://dances.e-cribs.org/The_Haggis_Hunt.pdf', 10, 9558);
INSERT INTO 'danceurl' VALUES (5796, 'https://dances.e-cribs.org/Romance_in_Ireland.pdf', 10, 8628);
INSERT INTO 'danceurl' VALUES (5798, 'https://dances.e-cribs.org/Irish_Romance.pdf', 10, 6131);
INSERT INTO 'danceurl' VALUES (5799, 'http://moirastacey.com/wp-content/uploads/2018/04/By-the-Way.pdf', 10, 14155);
INSERT INTO 'danceurl' VALUES (5800, 'https://dances.e-cribs.org/Perle_and_Ed.pdf', 10, 4335);
INSERT INTO 'danceurl' VALUES (5803, 'https://dances.e-cribs.org/Lindberg_Lilt,_The.pdf', 10, 8631);
INSERT INTO 'danceurl' VALUES (5805, 'https://dances.e-cribs.org/Sweet_Sixteen.pdf', 10, 8634);
INSERT INTO 'danceurl' VALUES (5806, 'https://dances.e-cribs.org/Truly_Yours.pdf', 10, 8632);
INSERT INTO 'danceurl' VALUES (5808, 'https://dances.e-cribs.org/Where_the_Grass_is_Greener.pdf', 10, 8636);
INSERT INTO 'danceurl' VALUES (5809, 'https://www.rscds-sf.org/resources/dances/Of%20Quakes%20and%20Quaichs%20final.pdf', 10, 19205);
INSERT INTO 'danceurl' VALUES (5810, 'https://docs.google.com/document/d/1XAAHkjCWuu7bOBI9tIIqGzCa44a1bPe8VI-c_sIwkaA', 10, 12014);
INSERT INTO 'danceurl' VALUES (5811, 'https://www.dropbox.com/s/ggxhp3471e9wndz/Paranoid_Jig.pdf?dl=0', 10, 19177);
INSERT INTO 'danceurl' VALUES (5812, 'https://www.dropbox.com/s/gz9jq9gtdjglf83/A%20Rose%20for%20the%20Cobbler.pdf?dl=0', 10, 17775);
INSERT INTO 'danceurl' VALUES (5813, 'https://www.dropbox.com/s/a77pqvfs5iub3w1/A_Dancers_Brainwave.pdf?dl=0', 10, 17777);
INSERT INTO 'danceurl' VALUES (5815, 'https://www.dropbox.com/s/njj663pfkys2y3l/Chasing_Butterflies.pdf?dl=0', 10, 17779);
INSERT INTO 'danceurl' VALUES (5817, 'https://www.dropbox.com/s/ol3lz0038zprcct/Dinner_for_One.pdf?dl=0', 10, 16828);
INSERT INTO 'danceurl' VALUES (5819, 'https://www.dropbox.com/s/q75a23cbj108asf/Flowers_and_Fields.pdf?dl=0', 10, 17772);
INSERT INTO 'danceurl' VALUES (5820, 'https://www.dropbox.com/s/g9rkvwmw1ojr6fj/Passion_Meets_profession.pdf?dl=0', 10, 17778);
INSERT INTO 'danceurl' VALUES (5814, 'https://www.dropbox.com/s/h76qpn2quocv9ev/A_Toast_to_Meike_dancedata.pdf?dl=0', 10, 16161);
INSERT INTO 'danceurl' VALUES (5818, 'https://www.dropbox.com/s/pcoxufh7d30xs5n/En_Tournee_Avec_Iris_dancedata.pdf?dl=0', 10, 17770);
INSERT INTO 'danceurl' VALUES (5804, 'https://dances.e-cribs.org/The_Lindberg_Strathspey.pdf', 10, 8637);
INSERT INTO 'danceurl' VALUES (5807, 'https://dances.e-cribs.org/A_Valentine_for_Vanessa.pdf', 10, 8635);
INSERT INTO 'danceurl' VALUES (5797, 'https://dances.e-cribs.org/Fermat_s_Bicycle_or_August_in_Erlangen.pdf', 10, 8630);
INSERT INTO 'danceurl' VALUES (5801, 'https://dances.e-cribs.org/Gabriel_s_Trumpet.pdf', 10, 8633);
INSERT INTO 'danceurl' VALUES (5802, 'https://dances.e-cribs.org/Helen_s_Shortbread.pdf', 10, 7704);
INSERT INTO 'danceurl' VALUES (5821, 'https://www.dropbox.com/s/b09z1835rnhsdcg/Spring_Fever.pdf?dl=0', 10, 17780);
INSERT INTO 'danceurl' VALUES (5822, 'https://www.dropbox.com/s/dgvrdruh3fein2g/The_Reel_Thing.pdf?dl=0', 10, 17782);
INSERT INTO 'danceurl' VALUES (5823, 'https://www.dropbox.com/s/bgl543ax4flxjqv/The_Reunion_Jig.pdf?dl=0', 10, 17776);
INSERT INTO 'danceurl' VALUES (5824, 'https://www.dropbox.com/s/9r94zvvkxr68gcc/The_Weasels_Nest.pdf?dl=0', 10, 18384);
INSERT INTO 'danceurl' VALUES (5825, 'https://www.dropbox.com/s/31dvmkzb1yc93dj/Wild%20Hedda%20Reel.pdf?dl=0', 10, 18263);
INSERT INTO 'danceurl' VALUES (5826, 'https://www.dropbox.com/s/ccrkymwew5z7he2/You%20are%20not%20alone.pdf?dl=0', 10, 19240);
INSERT INTO 'danceurl' VALUES (5827, 'https://www.dropbox.com/s/em9gb4sfag3qbd5/Potters_Pairs.pdf?dl=0', 10, 16190);
INSERT INTO 'danceurl' VALUES (5816, 'https://www.dropbox.com/s/uta42rwhydlh1la/Claudias_Barn_Dance_dancedata.pdf?dl=0', 10, 18560);
INSERT INTO 'danceurl' VALUES (5828, 'http://www.nicolascott.dance/dances.html', 10, 19273);
INSERT INTO 'danceurl' VALUES (5829, 'http://www.kafoozalum.co.uk/images/Expo.jpg', 10, 2023);
INSERT INTO 'danceurl' VALUES (5830, 'https://www.dropbox.com/s/rmsmwrrsqyu6eod/Fast%20and%20Furious.pdf?dl=0', 10, 19279);
INSERT INTO 'danceurl' VALUES (5832, 'https://dances.e-cribs.org/One_Humanity.pdf', 10, 19306);
INSERT INTO 'danceurl' VALUES (5833, 'http://my.strathspey.org/u/murrough/HolywoodProduction.pdf', 10, 19310);
INSERT INTO 'danceurl' VALUES (5834, 'http://my.strathspey.org/u/murrough/WorldWideWeb.pdf', 10, 19309);
INSERT INTO 'danceurl' VALUES (5835, 'https://my.strathspey.org/u/murrough/Enigma.pdf', 10, 19356);
INSERT INTO 'danceurl' VALUES (5836, 'https://my.strathspey.org/u/murrough/XylemAndPhloem.pdf', 10, 19357);
INSERT INTO 'danceurl' VALUES (5837, 'https://my.strathspey.org/u/murrough/DavidMinor.pdf', 10, 19361);
INSERT INTO 'danceurl' VALUES (5838, 'http://www.rscds-norwich.org.uk/rscds50annivdances.html', 10, 13739);
INSERT INTO 'danceurl' VALUES (5839, 'https://docs.google.com/document/d/1ngv2e5EALgL-ExTFfHqUoS_zgefgFHZNs2l14XpTxBk/edit', 10, 19366);
INSERT INTO 'danceurl' VALUES (5840, 'http://bstk.hu/dances/two-hornpipes/', 10, 19378);
INSERT INTO 'danceurl' VALUES (5841, 'http://www.bstk.hu/dances/happy-to-see-you/', 10, 19228);
INSERT INTO 'danceurl' VALUES (5842, 'http://www.bstk.hu/dances/scottish-roulette', 10, 16460);
INSERT INTO 'danceurl' VALUES (5843, 'http://www.bstk.hu/dances/the-three-e-s', 10, 16461);
INSERT INTO 'danceurl' VALUES (5844, 'https://dances.e-cribs.org/The_Silver_Link.pdf', 10, 11827);
INSERT INTO 'danceurl' VALUES (5845, 'https://dances.e-cribs.org/Well_Met_in_Paris.pdf', 10, 11830);
INSERT INTO 'danceurl' VALUES (5846, 'https://dances.e-cribs.org/Eight_of_Diamonds.pdf', 10, 12204);
INSERT INTO 'danceurl' VALUES (5847, 'https://dances.e-cribs.org/The_Four_Poster.pdf', 10, 17550);
INSERT INTO 'danceurl' VALUES (5848, 'https://dances.e-cribs.org/The_Four_Winds.pdf', 10, 17551);
INSERT INTO 'danceurl' VALUES (5849, 'https://dances.e-cribs.org/Four_in_Hand.pdf', 10, 17552);
INSERT INTO 'danceurl' VALUES (5850, 'https://dances.e-cribs.org/Gypsy_Dreams.pdf', 10, 9862);
INSERT INTO 'danceurl' VALUES (5851, 'https://suedan.com/dances/instructions/theunfortunateacronym.html', 10, 19398);
INSERT INTO 'danceurl' VALUES (5852, 'https://suedan.com/dances/instructions/ladymcgowansnightmare.html', 10, 19399);
INSERT INTO 'danceurl' VALUES (5853, 'https://suedan.com/dances/instructions/agilejacks.html', 10, 19400);
INSERT INTO 'danceurl' VALUES (5854, 'https://suedan.com/dances/instructions/flashinglights.html', 10, 19401);
INSERT INTO 'danceurl' VALUES (5855, 'https://suedan.com/dances/instructions/verticalbasking.html', 10, 19403);
INSERT INTO 'danceurl' VALUES (5856, 'https://suedan.com/dances/instructions/everythingbyhalves.html', 10, 19404);
INSERT INTO 'danceurl' VALUES (5857, 'https://suedan.com/dances/instructions/thelostprincessofoz.html', 10, 19405);
INSERT INTO 'danceurl' VALUES (5858, 'https://suedan.com/dances/instructions/orangeslices.html', 10, 19406);
INSERT INTO 'danceurl' VALUES (5859, 'https://suedan.com/dances/instructions/rainbowdragon.html', 10, 19407);
INSERT INTO 'danceurl' VALUES (5860, 'https://suedan.com/dances/instructions/tunabandit.html', 10, 19408);
INSERT INTO 'danceurl' VALUES (5861, 'https://my.strathspey.org/u/murrough/SoaringAndSwooping.pdf', 10, 19358);
INSERT INTO 'danceurl' VALUES (5862, 'https://my.strathspey.org/u/murrough/GoodbyeFromHim.pdf', 10, 19431);
INSERT INTO 'danceurl' VALUES (5863, 'https://my.strathspey.org/u/murrough/GreatPermianMassExtinction.pdf', 10, 19430);
INSERT INTO 'danceurl' VALUES (5864, 'https://my.strathspey.org/u/murrough/BetweenTwoLakes.pdf', 10, 19429);
INSERT INTO 'danceurl' VALUES (5865, 'https://suedan.com/dances/instructions/whilethebabysleeps.html', 10, 19432);
INSERT INTO 'danceurl' VALUES (5831, 'http://www.aurorascot.org.uk/events/ball2019/1865-2', 10, 19288);
INSERT INTO 'danceurl' VALUES (5866, 'https://suedan.com/dances/instructions/walkingwithfire.html', 10, 19433);
INSERT INTO 'danceurl' VALUES (5867, 'https://suedan.com/dances/instructions/bolillos.html', 10, 19434);
INSERT INTO 'danceurl' VALUES (5868, 'https://suedan.com/dances/instructions/measuredsleep.html', 10, 19435);
INSERT INTO 'danceurl' VALUES (5869, 'https://suedan.com/dances/instructions/crazy8s.html', 10, 19436);
INSERT INTO 'danceurl' VALUES (5870, 'https://suedan.com/dances/instructions/needlelace.html', 10, 19437);
INSERT INTO 'danceurl' VALUES (5871, 'https://suedan.com/dances/instructions/eveningstar.html', 10, 19438);
INSERT INTO 'danceurl' VALUES (5872, 'https://suedan.com/dances/instructions/halfstitch.html', 10, 19439);
INSERT INTO 'danceurl' VALUES (5873, 'https://suedan.com/dances/instructions/katieswedding.html', 10, 19440);
INSERT INTO 'danceurl' VALUES (5874, 'https://suedan.com/dances/instructions/riverroadroundabouts.html', 10, 19441);
INSERT INTO 'danceurl' VALUES (5875, 'https://suedan.com/dances/instructions/orilliasown.html', 10, 19442);
INSERT INTO 'danceurl' VALUES (5876, 'https://suedan.com/dances/instructions/danceofthegoldenflashes.html', 10, 19443);
INSERT INTO 'danceurl' VALUES (5877, 'https://suedan.com/dances/instructions/milkweeddancer.html', 10, 19444);
INSERT INTO 'danceurl' VALUES (5878, 'https://suedan.com/dances/instructions/northofscotland.html', 10, 19445);
INSERT INTO 'danceurl' VALUES (5879, 'https://suedan.com/dances/instructions/basketweavebraid.html', 10, 19446);
INSERT INTO 'danceurl' VALUES (5880, 'https://suedan.com/dances/instructions/milaneselace.html', 10, 19447);
INSERT INTO 'danceurl' VALUES (5881, 'https://suedan.com/dances/instructions/followthemouse.html', 10, 19448);
INSERT INTO 'danceurl' VALUES (5882, 'https://suedan.com/dances/instructions/flightsofgold.html', 10, 19449);
INSERT INTO 'danceurl' VALUES (5883, 'https://suedan.com/dances/instructions/twilightatnoon.html', 10, 19450);
INSERT INTO 'danceurl' VALUES (5884, 'https://suedan.com/dances/instructions/jewelonthewing.html', 10, 19451);
INSERT INTO 'danceurl' VALUES (5885, 'https://suedan.com/dances/instructions/thecircleissmall.html', 10, 19452);
INSERT INTO 'danceurl' VALUES (5887, 'https://suedan.com/dances/instructions/naturesconfetti.html', 10, 19454);
INSERT INTO 'danceurl' VALUES (5888, 'https://suedan.com/dances/instructions/mollysring.html', 10, 19455);
INSERT INTO 'danceurl' VALUES (5889, 'https://suedan.com/dances/instructions/platinum.html', 10, 19456);
INSERT INTO 'danceurl' VALUES (5890, 'https://suedan.com/dances/instructions/chainreaction.html', 10, 19457);
INSERT INTO 'danceurl' VALUES (5891, 'https://suedan.com/dances/instructions/chocolatechipdoubletriangles.html', 10, 19458);
INSERT INTO 'danceurl' VALUES (5892, 'https://suedan.com/dances/instructions/50yearsafan.html', 10, 19459);
INSERT INTO 'danceurl' VALUES (5893, 'https://suedan.com/dances/instructions/circleofsteel.html', 10, 19460);
INSERT INTO 'danceurl' VALUES (5894, 'https://suedan.com/dances/instructions/tenwords.html', 10, 19461);
INSERT INTO 'danceurl' VALUES (5895, 'https://suedan.com/dances/instructions/dashingthroughthesnow.html', 10, 19462);
INSERT INTO 'danceurl' VALUES (5896, 'https://suedan.com/dances/instructions/christmasstars.html', 10, 19463);
INSERT INTO 'danceurl' VALUES (5897, 'https://suedan.com/dances/instructions/walkingonair.html', 10, 19402);
INSERT INTO 'danceurl' VALUES (5898, 'https://suedan.com/dances/instructions/20yearsatfermi.html', 10, 18671);
INSERT INTO 'danceurl' VALUES (5899, 'https://suedan.com/dances/instructions/herdingcats.html', 10, 18787);
INSERT INTO 'danceurl' VALUES (5900, 'https://suedan.com/dances/instructions/slinky.html', 10, 18883);
INSERT INTO 'danceurl' VALUES (5901, 'https://suedan.com/dances/instructions/carefreehighway.html', 10, 18273);
INSERT INTO 'danceurl' VALUES (5902, 'https://www.scottishdance.net/dances/Book/CelticSteps.pdf', 10, 13574);
INSERT INTO 'danceurl' VALUES (5903, 'http://www.strathspey.org/lists/strathspey%40strathspey.org/m/12353/', 10, 19473);
INSERT INTO 'danceurl' VALUES (5904, 'http://www.valleyofthemoon.org/pdfs/QuintReel.pdf', 10, 12375);
INSERT INTO 'danceurl' VALUES (5905, 'http://www.matsmelin.com/wp-content/uploads/2011/05/St-Magnus-Reel.pdf', 10, 12394);
INSERT INTO 'danceurl' VALUES (5906, 'https://www.youtube.com/watch?v=gYPl1yxzAAc', 10, 19502);
INSERT INTO 'danceurl' VALUES (5907, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/book5.pdf', 10, 19503);
INSERT INTO 'danceurl' VALUES (5908, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/book5.pdf', 10, 19504);
INSERT INTO 'danceurl' VALUES (5909, 'http://www.wellingtonscd.org.nz/wp-content/uploads/2018/12/Sophies-Sand-Castle.doc', 10, 19507);
INSERT INTO 'danceurl' VALUES (5910, 'https://www.johnsonvillescd.org.nz/wp-content/uploads/2018/05/For-All-the-Days-of-Dance.jpg', 10, 19508);
INSERT INTO 'danceurl' VALUES (5911, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/book5.pdf', 10, 19509);
INSERT INTO 'danceurl' VALUES (5953, 'https://www.scd-germany.de/de/schottentanzen-in-deutschland/publikationen/publikationen.html?download=30&token=6f4922f45568161a8cdf4ad2299f6d23#tab30', 10, 19725);
INSERT INTO 'danceurl' VALUES (5954, 'https://www.scd-germany.de/de/schottentanzen-in-deutschland/publikationen/publikationen.html?download=30&token=1f0e3dad99908345f7439f8ffabdffc4#tab30', 10, 19726);
INSERT INTO 'danceurl' VALUES (5955, 'https://www.scd-germany.de/de/schottentanzen-in-deutschland/publikationen/publikationen.html?download=30&token=98f13708210194c475687be6106a3b84#tab30', 10, 19727);
INSERT INTO 'danceurl' VALUES (5956, 'http://my.strathspey.org/u/murrough/PartyAtTheFrenchHouse.pdf', 10, 19701);
INSERT INTO 'danceurl' VALUES (5918, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=30&token=70efdf2ec9b086079795c442636b55fb#tab30', 10, 19546);
INSERT INTO 'danceurl' VALUES (5917, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=30&token=c51ce410c124a10e0db5e4b97fc2af39#tab30', 10, 19547);
INSERT INTO 'danceurl' VALUES (5920, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=30&token=9bf31c7ff062936a96d3c8bd1f8f2ff3#tab30', 10, 18097);
INSERT INTO 'danceurl' VALUES (5921, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=30&token=c74d97b01eae257e44aa9d5bade97baf#tab30', 10, 19545);
INSERT INTO 'danceurl' VALUES (5919, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=30&token=aab3238922bcc25a6f606eb525ffdc56', 10, 18310);
INSERT INTO 'danceurl' VALUES (5923, 'https://my.strathspey.org/u/murrough/VariationsOnATheme.pdf', 10, 19563);
INSERT INTO 'danceurl' VALUES (5924, 'https://my.strathspey.org/u/murrough/CosiFanTutte.pdf', 10, 19562);
INSERT INTO 'danceurl' VALUES (5925, 'https://my.strathspey.org/u/murrough/BirlingDervishes.pdf', 10, 19561);
INSERT INTO 'danceurl' VALUES (5926, 'https://my.strathspey.org/u/murrough/BeTrueToYourself.pdf', 10, 19560);
INSERT INTO 'danceurl' VALUES (5927, 'http://www.minicrib.org.uk/Publications/Ms.%20Dean''s%20Fancy.pdf', 10, 19567);
INSERT INTO 'danceurl' VALUES (5928, 'http://my.strathspey.org/u/murrough/Parallelogram.pdf', 10, 19581);
INSERT INTO 'danceurl' VALUES (5929, 'http://my.strathspey.org/u/murrough/Neighbourliness.pdf', 10, 19582);
INSERT INTO 'danceurl' VALUES (5930, 'http://www.rscds-wirral.org.uk/dances.html', 10, 18565);
INSERT INTO 'danceurl' VALUES (5931, 'http://www.rscds-wirral.org.uk/dances.html', 10, 18562);
INSERT INTO 'danceurl' VALUES (5932, 'http://www.rscds-wirral.org.uk/dances.html', 10, 18564);
INSERT INTO 'danceurl' VALUES (5933, 'http://www.rscds-wirral.org.uk/dances.html', 10, 18561);
INSERT INTO 'danceurl' VALUES (5934, 'http://www.rscds-wirral.org.uk/dances.html', 10, 18563);
INSERT INTO 'danceurl' VALUES (5935, 'http://www.rscds-wirral.org.uk/dances.html', 10, 18566);
INSERT INTO 'danceurl' VALUES (5936, 'http://www.rscds-wirral.org.uk/dances.html', 10, 16769);
INSERT INTO 'danceurl' VALUES (5937, 'http://my.strathspey.org/u/murrough/BenignPresence.pdf', 10, 19635);
INSERT INTO 'danceurl' VALUES (5938, 'https://rscds.org.au/attachments/SNIB_Apr2019.pdf#10', 10, 19641);
INSERT INTO 'danceurl' VALUES (5939, 'http://scda.us/wp-content/uploads/2018/03/2018-Bluebonnet-Ball-Flier.doc', 10, 19642);
INSERT INTO 'danceurl' VALUES (5940, 'http://scda.us/wp-content/uploads/2018/03/2018-Bluebonnet-Ball-Flier.doc', 10, 18721);
INSERT INTO 'danceurl' VALUES (5941, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-090-April-May-1966.pdf', 10, 19661);
INSERT INTO 'danceurl' VALUES (5942, 'http://my.strathspey.org/u/murrough/GravitationalWaves.pdf', 10, 19665);
INSERT INTO 'danceurl' VALUES (5943, 'https://suedan.com/dances/instructions/mccaigstower.html', 10, 19684);
INSERT INTO 'danceurl' VALUES (5944, 'https://suedan.com/dances/instructions/isleman.html', 10, 19682);
INSERT INTO 'danceurl' VALUES (5946, 'https://sites.google.com/site/thefollyofrogues/cusrc-reelwiki/iron-horse-reel', 10, 19693);
INSERT INTO 'danceurl' VALUES (5947, 'http://www.dancescottishsd.org/wp-content/uploads/2019/04/Another-Trip-round-the-sun.pdf', 10, 19258);
INSERT INTO 'danceurl' VALUES (5948, 'http://www.dancescottishsd.org/wp-content/uploads/2016/10/The-Wandering-Thistle.pdf', 10, 19719);
INSERT INTO 'danceurl' VALUES (5949, 'http://www.dancescottishsd.org/wp-content/uploads/2016/10/The-Balboa-Park-Rant.pdf', 10, 19721);
INSERT INTO 'danceurl' VALUES (5950, 'http://www.dancescottishsd.org/wp-content/uploads/2016/10/Jaunty-Jeanne.pdf', 10, 19722);
INSERT INTO 'danceurl' VALUES (5951, 'http://www.dancescottishsd.org/wp-content/uploads/2016/10/Kellys-Journey.pdf', 10, 19723);
INSERT INTO 'danceurl' VALUES (5952, 'http://www.dancescottishsd.org/wp-content/uploads/2016/10/Midsummer-Moon.pdf', 10, 19724);
INSERT INTO 'danceurl' VALUES (5957, 'https://tac-rscds.org/images/stories/Drewry/Leaflets/Leaflet_-_Auld_Luckie.pdf', 10, 303);
INSERT INTO 'danceurl' VALUES (5995, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 2815);
INSERT INTO 'danceurl' VALUES (5987, 'https://suepetyt.e-cribs.org/Pudsey''s_Reel.pdf', 10, 19852);
INSERT INTO 'danceurl' VALUES (5958, 'https://tunes.e-cribs.org/A_Reel_for_Iris.pdf', 10, 19365);
INSERT INTO 'danceurl' VALUES (5961, 'https://99f1369a-0c74-45f9-886a-c695a89fc4c9.filesusr.com/ugd/bde46d_814278acee7f41ec8c05149cd140b68b.pdf', 10, 19769);
INSERT INTO 'danceurl' VALUES (5962, 'https://ruhrball.files.wordpress.com/2019/09/the-tesla-coil.pdf', 10, 19777);
INSERT INTO 'danceurl' VALUES (5963, 'https://ruhrball.files.wordpress.com/2016/05/strathspey-for-ewe.pdf', 10, 19780);
INSERT INTO 'danceurl' VALUES (5964, 'https://ruhrball.files.wordpress.com/2016/05/birthday-bee.pdf', 10, 19779);
INSERT INTO 'danceurl' VALUES (5965, 'https://ruhrball.files.wordpress.com/2016/05/books-and-maps.pdf', 10, 15056);
INSERT INTO 'danceurl' VALUES (5966, 'http://viscds.ca/2009Marchnews.pdf', 10, 1127);
INSERT INTO 'danceurl' VALUES (5967, 'https://rscds-sf.org/resources/dances/A.%20J.''s%20Jig%20(Andrew%20Clyde%20birthday%20dance).2.pdf', 10, 19795);
INSERT INTO 'danceurl' VALUES (5968, 'https://rscds-sf.org/resources/dances/Still%20and%20Always.pdf', 10, 19794);
INSERT INTO 'danceurl' VALUES (5969, 'https://rscds-sf.org/resources/dances/Wright%20Back%20Home%20final.pdf', 10, 19793);
INSERT INTO 'danceurl' VALUES (5970, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/eileen-rumble-mbe.html', 10, 19616);
INSERT INTO 'danceurl' VALUES (5971, 'https://www.anselms.net/pdf/scd-dances/nevskiyprospekt.pdf', 10, 16072);
INSERT INTO 'danceurl' VALUES (4594, 'https://my.strathspey.org/u/anselm/dances/fireworksreel/', 10, 13544);
INSERT INTO 'danceurl' VALUES (5972, 'https://www.genevascdc.com/EN/LC_GD.shtml', 10, 19687);
INSERT INTO 'danceurl' VALUES (4261, 'http://web.archive.org/web/20041216100736/http://www.opendoor.com/heatherandrose/dances_brookeandchris.html#piper', 10, 10505);
INSERT INTO 'danceurl' VALUES (4833, 'http://web.archive.org/web/20041216100736/http://www.opendoor.com/heatherandrose/dances_brookeandchris.html#gypsy', 10, 10504);
INSERT INTO 'danceurl' VALUES (5973, 'https://www.strathspey.org/lists/strathspey%40strathspey.org/m/37563/', 10, 11477);
INSERT INTO 'danceurl' VALUES (5974, 'http://bridportscottishdancers.org.uk/pages/braiding/welcometobridport.pdf', 10, 15633);
INSERT INTO 'danceurl' VALUES (5975, 'http://bridportscottishdancers.org.uk/pages/braiding/stmichaelsjig.pdf', 10, 15632);
INSERT INTO 'danceurl' VALUES (5976, 'http://bridportscottishdancers.org.uk/pages/braiding/ropemakers.pdf', 10, 11181);
INSERT INTO 'danceurl' VALUES (5977, 'http://bridportscottishdancers.org.uk/pages/braiding/sourlemon.htm?LMCL=FEZZCP', 10, 15634);
INSERT INTO 'danceurl' VALUES (5979, 'http://bridportscottishdancers.org.uk/pages/braiding/patriciasmakeup.pdf', 10, 15636);
INSERT INTO 'danceurl' VALUES (5980, 'http://bridportscottishdancers.org.uk/pages/braiding/bridportreelof7.pdf', 10, 15637);
INSERT INTO 'danceurl' VALUES (5981, 'http://bridportscottishdancers.org.uk/pages/braiding/sarahswedding.pdf', 10, 15638);
INSERT INTO 'danceurl' VALUES (5982, 'http://bridportscottishdancers.org.uk/pages/braiding/Sylvie.pdf', 10, 15651);
INSERT INTO 'danceurl' VALUES (5983, 'http://bridportscottishdancers.org.uk/pages/braiding/playingthefield.pdf', 10, 15653);
INSERT INTO 'danceurl' VALUES (5984, 'http://bridportscottishdancers.org.uk/pages/braiding/Bus%20Pass.pdf', 10, 15654);
INSERT INTO 'danceurl' VALUES (5985, 'http://bridportscottishdancers.org.uk/dances/Dance%20-%20%27Lannion%20Link%27.pdf', 10, 11183);
INSERT INTO 'danceurl' VALUES (5986, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/smiling-lila.html', 10, 19118);
INSERT INTO 'danceurl' VALUES (5040, 'http://my.strathspey.org/u/murrough/OttersInKenickBurn.pdf', 10, 16889);
INSERT INTO 'danceurl' VALUES (5988, 'https://my.strathspey.org/u/murrough/TowerOfLondon.pdf', 10, 19856);
INSERT INTO 'danceurl' VALUES (5990, 'https://links.e-cribs.org/WhetherlyBook1', 10, 572);
INSERT INTO 'danceurl' VALUES (5978, 'http://bridportscottishdancers.org.uk/pages/braiding/Dance%20for%20Ann%202b.pdf', 10, 15635);
INSERT INTO 'danceurl' VALUES (5960, 'https://dances.e-cribs.org/A_Reel_for_Iris_Teaching_Notes.pdf', 10, 19365);
INSERT INTO 'danceurl' VALUES (5996, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 4098);
INSERT INTO 'danceurl' VALUES (5997, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 3400);
INSERT INTO 'danceurl' VALUES (5989, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 6910);
INSERT INTO 'danceurl' VALUES (5991, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 956);
INSERT INTO 'danceurl' VALUES (5992, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 4199);
INSERT INTO 'danceurl' VALUES (5993, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 1504);
INSERT INTO 'danceurl' VALUES (5994, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 1584);
INSERT INTO 'danceurl' VALUES (5998, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 5013);
INSERT INTO 'danceurl' VALUES (5999, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 5676);
INSERT INTO 'danceurl' VALUES (6000, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 3026);
INSERT INTO 'danceurl' VALUES (6001, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 5044);
INSERT INTO 'danceurl' VALUES (6002, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 3896);
INSERT INTO 'danceurl' VALUES (5959, 'https://dances.e-cribs.org/A_Reel_for_Iris.pdf', 10, 19365);
INSERT INTO 'danceurl' VALUES (4867, 'http://bridportscottishdancers.org.uk/pages/braiding/foxonhill.pdf', 10, 15631);
INSERT INTO 'danceurl' VALUES (6003, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 432);
INSERT INTO 'danceurl' VALUES (6004, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677', 10, 5041);
INSERT INTO 'danceurl' VALUES (6005, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/russian-fly.html', 10, 19890);
INSERT INTO 'danceurl' VALUES (6006, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/scottish-midge.html', 10, 19891);
INSERT INTO 'danceurl' VALUES (6007, 'https://dances.e-cribs.org/Wee_Bairn''s_Noo_Awa,_The.pdf', 10, 7551);
INSERT INTO 'danceurl' VALUES (6008, 'https://dances.e-cribs.org/Merry_Widow,_The.pdf', 10, 8141);
INSERT INTO 'danceurl' VALUES (6009, 'https://dances.e-cribs.org/Skaters''_Strathspey.pdf', 10, 8814);
INSERT INTO 'danceurl' VALUES (6010, 'https://dances.e-cribs.org/Like_the_Morningstar.pdf', 10, 8170);
INSERT INTO 'danceurl' VALUES (6011, 'https://dances.e-cribs.org/Crickets_by_Moonlight.pdf', 10, 8169);
INSERT INTO 'danceurl' VALUES (6012, 'https://dances.e-cribs.org/Midsummer_Night.pdf', 10, 8168);
INSERT INTO 'danceurl' VALUES (6013, 'https://dances.e-cribs.org/Bouncing_Braids.pdf', 10, 8167);
INSERT INTO 'danceurl' VALUES (5448, 'https://www.rscds.it/welcome.php', 10, 18508);
INSERT INTO 'danceurl' VALUES (6014, 'https://my.strathspey.org/u/murrough/FamigliaGraziani.pdf', 10, 19956);
INSERT INTO 'danceurl' VALUES (4106, 'https://www.rscds-sf.org/resources/dances/seite_an_seite.html', 10, 9125);
INSERT INTO 'danceurl' VALUES (6015, 'http://ramshaw.info/dances/DoublyTriumphant.pdf', 10, 9508);
INSERT INTO 'danceurl' VALUES (6016, 'https://my.strathspey.org/u/murrough/AllShallBeWell.pdf', 10, 19960);
INSERT INTO 'danceurl' VALUES (6017, 'http://www.dancescottish.ca/leaflet-dances_files/Ladies%20of%20a%20Certain%20Age%20-%208s32.pdf', 20, 18808);
INSERT INTO 'danceurl' VALUES (6018, 'http://www.dancescottish.ca/leaflet-dances_files/Romance%20in%20St%20Andrews.pdf', 10, 19972);
INSERT INTO 'danceurl' VALUES (6020, 'http://www.dancescottish.ca/leaflet-dances_files/Wee%20Reely%20Progressed%20-%204s32.pdf', 10, 18806);
INSERT INTO 'danceurl' VALUES (6021, 'http://www.dancescottish.ca/leaflet-dances_files/Hillcrest%E2%80%99s%20Ruby%20Gem%20-%204s32.pdf', 10, 16842);
INSERT INTO 'danceurl' VALUES (6022, 'http://www.dancescottish.ca/leaflet-dances_files/The%20Toronto%20Volunteers%20-%208r32.pdf', 10, 17577);
INSERT INTO 'danceurl' VALUES (6023, 'http://www.dancescottish.ca/leaflet-dances_files/Sir%20Barry%20Pipes%20-%203r32.pdf', 10, 15951);
INSERT INTO 'danceurl' VALUES (6024, 'http://www.dancescottish.ca/leaflet-dances_files/The%20Award%20of%20Excellence%20-%203r32.pdf', 10, 19973);
INSERT INTO 'danceurl' VALUES (6019, 'http://www.dancescottish.ca/leaflet-dances_files/Lilibet%27s%20Strathspey%20-%204s32.pdf', 10, 15435);
INSERT INTO 'danceurl' VALUES (6025, 'http://www.dancescottish.ca/leaflet-dances_files/Brochan%20Lom%20%28Macfarlane%29%20-%208s32.pdf', 10, 824);
INSERT INTO 'danceurl' VALUES (6026, 'http://www.dancescottish.ca/leaflet-dances_files/The%20Peat%20Road%20-%208r32.pdf', 10, 17321);
INSERT INTO 'danceurl' VALUES (6028, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/magic-roundabout-2.html', 10, 19980);
INSERT INTO 'danceurl' VALUES (6029, 'http://www.minicrib.org.uk/Publications/A%20Jig%20For%20Julian.pdf', 10, 19984);
INSERT INTO 'danceurl' VALUES (6030, 'https://my.strathspey.org/u/murrough/WinterInWasdale.pdf', 10, 20000);
INSERT INTO 'danceurl' VALUES (6032, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/lonesome-reel.html', 10, 20030);
INSERT INTO 'danceurl' VALUES (6033, 'https://www.scd-germany.de/de/schottentanzen-in-deutschland/publikationen/publikationen.html?download=30&token=34173cb38f07f89ddbebc2ac9128303f#tab30', 10, 20034);
INSERT INTO 'danceurl' VALUES (6034, 'https://www.scd-germany.de/de/schottentanzen-in-deutschland/publikationen/publikationen.html?download=30&token=c16a5320fa475530d9583c34fd356ef5#tab30', 10, 20033);
INSERT INTO 'danceurl' VALUES (6035, 'https://www.scd-germany.de/de/schottentanzen-in-deutschland/publikationen/publikationen.html?download=30&token=6364d3f0f495b6ab9dcf8d3b5c6e0b01#tab30', 10, 20032);
INSERT INTO 'danceurl' VALUES (6036, 'https://www.scd-germany.de/de/schottentanzen-in-deutschland/publikationen/publikationen.html?download=30&token=8e296a067a37563370ded05f5a3bf3ec#tab30', 10, 15891);
INSERT INTO 'danceurl' VALUES (6037, 'https://www.scd-germany.de/de/schottentanzen-in-deutschland/publikationen/publikationen.html?download=30&token=1ff1de774005f8da13f42943881c655f#tab30', 10, 18392);
INSERT INTO 'danceurl' VALUES (6038, 'https://www.scd-germany.de/de/schottentanzen-in-deutschland/publikationen/publikationen.html?download=30&token=37693cfc748049e45d87b8c7d8b9aacd#tab30', 10, 13643);
INSERT INTO 'danceurl' VALUES (6039, 'https://www.scd-germany.de/de/schottentanzen-in-deutschland/publikationen/publikationen.html?download=30&token=b6d767d2f8ed5d21a44b0e5886680cb9#tab30', 10, 13306);
INSERT INTO 'danceurl' VALUES (6040, 'https://www.scd-germany.de/de/schottentanzen-in-deutschland/publikationen/publikationen.html?download=30&token=3c59dc048e8850243be8079a5c74d079#tab30', 10, 13313);
INSERT INTO 'danceurl' VALUES (6041, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/onesome-reel.html', 10, 20039);
INSERT INTO 'danceurl' VALUES (6042, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/sir-andy-murray-of-dunblane.html', 10, 20045);
INSERT INTO 'danceurl' VALUES (6031, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=30&token=c81e728d9d4c2f636f067f89cc14862c#tab30', 10, 20028);
INSERT INTO 'danceurl' VALUES (6043, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/isolated-weasel.html', 10, 20050);
INSERT INTO 'danceurl' VALUES (4851, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/midnight-jig.html', 10, 15568);
INSERT INTO 'danceurl' VALUES (6044, 'http://www.freiburg-scottish-country-dancers.de/freiburgdances/The_Freiburg_SCDs_Frolic.pdf', 10, 20054);
INSERT INTO 'danceurl' VALUES (6045, 'http://users.tpg.com.au/juliasm/Scottish-Dance/Let%27s%20Get%20This%20Sorted.pdf', 10, 20056);
INSERT INTO 'danceurl' VALUES (6046, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/2d.pdf', 10, 6826);
INSERT INTO 'danceurl' VALUES (6047, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/ball.pdf', 10, 46);
INSERT INTO 'danceurl' VALUES (6048, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/airie.pdf', 10, 56);
INSERT INTO 'danceurl' VALUES (6049, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/alister.pdf', 10, 91);
INSERT INTO 'danceurl' VALUES (6050, 'https://www.rscdslondon.org.uk/sdata/dances/farewell/nisbet.pdf', 10, 155);
INSERT INTO 'danceurl' VALUES (6051, 'https://www.rscdslondon.org.uk/sdata/dances/green_lochan/arran.pdf', 10, 241);
INSERT INTO 'danceurl' VALUES (6052, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/auchencairn.pdf', 10, 276);
INSERT INTO 'danceurl' VALUES (6053, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/robin_gray.pdf', 10, 306);
INSERT INTO 'danceurl' VALUES (6054, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/australian.pdf', 10, 312);
INSERT INTO 'danceurl' VALUES (6055, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/fair.pdf', 10, 323);
INSERT INTO 'danceurl' VALUES (6056, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/whigs.pdf', 10, 324);
INSERT INTO 'danceurl' VALUES (6057, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/balmaclellan.pdf', 10, 371);
INSERT INTO 'danceurl' VALUES (6058, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/spey.pdf', 10, 394);
INSERT INTO 'danceurl' VALUES (6059, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/bannockburn.pdf', 10, 399);
INSERT INTO 'danceurl' VALUES (6060, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/bateau.pdf', 10, 7608);
INSERT INTO 'danceurl' VALUES (6061, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/seeing.pdf', 10, 431);
INSERT INTO 'danceurl' VALUES (6062, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/belfast.pdf', 10, 453);
INSERT INTO 'danceurl' VALUES (6063, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/belle.pdf', 10, 463);
INSERT INTO 'danceurl' VALUES (6064, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/black.pdf', 10, 498);
INSERT INTO 'danceurl' VALUES (6065, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/birkie.pdf', 10, 519);
INSERT INTO 'danceurl' VALUES (6066, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/mountain.pdf', 10, 549);
INSERT INTO 'danceurl' VALUES (6067, 'https://www.rscdslondon.org.uk/sdata/dances/bonspiel/walnut.pdf', 10, 557);
INSERT INTO 'danceurl' VALUES (6068, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/blervie.pdf', 10, 570);
INSERT INTO 'danceurl' VALUES (6069, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/blithe.pdf', 10, 576);
INSERT INTO 'danceurl' VALUES (6070, 'https://www.rscdslondon.org.uk/sdata/dances/green_lochan/bonny_mally.pdf', 10, 665);
INSERT INTO 'danceurl' VALUES (6071, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/cairncross.pdf', 10, 919);
INSERT INTO 'danceurl' VALUES (6072, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/campbeltown.pdf', 10, 985);
INSERT INTO 'danceurl' VALUES (6073, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/catch.pdf', 10, 1086);
INSERT INTO 'danceurl' VALUES (6074, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/kate.pdf', 10, 1322);
INSERT INTO 'danceurl' VALUES (6075, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/donna.pdf', 10, 1681);
INSERT INTO 'danceurl' VALUES (6076, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/whaler.pdf', 10, 1838);
INSERT INTO 'danceurl' VALUES (6077, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/fiona.pdf', 10, 2180);
INSERT INTO 'danceurl' VALUES (3795, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/earlstoun.pdf', 10, 1891);
INSERT INTO 'danceurl' VALUES (6078, 'https://www.rscdslondon.org.uk/sdata/dances/fankle.pdf', 10, 2069);
INSERT INTO 'danceurl' VALUES (6079, 'https://www.rscdslondon.org.uk/sdata/dances/farewell/farewell.pdf', 10, 2079);
INSERT INTO 'danceurl' VALUES (6080, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/findhorn.pdf', 10, 2170);
INSERT INTO 'danceurl' VALUES (6081, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/fair.pdf', 10, 2363);
INSERT INTO 'danceurl' VALUES (3816, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/geneva.pdf', 10, 2431);
INSERT INTO 'danceurl' VALUES (6082, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/johnny_cope.pdf', 10, 2886);
INSERT INTO 'danceurl' VALUES (3831, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/halfway.pdf', 10, 2730);
INSERT INTO 'danceurl' VALUES (6083, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/arran.pdf', 10, 3147);
INSERT INTO 'danceurl' VALUES (6084, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/ironbung.pdf', 10, 3136);
INSERT INTO 'danceurl' VALUES (6085, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/illabo_reel.pdf', 10, 3066);
INSERT INTO 'danceurl' VALUES (6086, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/illabo_rant.pdf', 10, 3065);
INSERT INTO 'danceurl' VALUES (3863, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/anderson.pdf', 10, 3314);
INSERT INTO 'danceurl' VALUES (3866, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/badenyon.pdf', 10, 3325);
INSERT INTO 'danceurl' VALUES (6087, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/johnnie.pdf', 10, 3337);
INSERT INTO 'danceurl' VALUES (6088, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/kishmul.pdf', 10, 3524);
INSERT INTO 'danceurl' VALUES (6089, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/lassies.pdf', 10, 3732);
INSERT INTO 'danceurl' VALUES (3887, 'https://www.rscdslondon.org.uk/sdata/dances/glasgow_assembly/ceilidh.pdf', 10, 3786);
INSERT INTO 'danceurl' VALUES (6090, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/lightning.pdf', 10, 3805);
INSERT INTO 'danceurl' VALUES (6091, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/lobster.pdf', 10, 3854);
INSERT INTO 'danceurl' VALUES (6092, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/paddock.pdf', 10, 3916);
INSERT INTO 'danceurl' VALUES (3902, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/loyne.pdf', 10, 3979);
INSERT INTO 'danceurl' VALUES (6093, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/macdonald.pdf', 10, 4018);
INSERT INTO 'danceurl' VALUES (3914, 'https://www.rscdslondon.org.uk/sdata/dances/glendarroch/millquarter.pdf', 10, 4401);
INSERT INTO 'danceurl' VALUES (3926, 'https://www.rscdslondon.org.uk/sdata/dances/farewell/montreal.pdf', 10, 4642);
INSERT INTO 'danceurl' VALUES (3940, 'https://www.rscdslondon.org.uk/sdata/dances/song_tunes/tocher.pdf', 10, 4873);
INSERT INTO 'danceurl' VALUES (6094, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/new_scotland.pdf', 10, 4930);
INSERT INTO 'danceurl' VALUES (6095, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/postie.pdf', 10, 5330);
INSERT INTO 'danceurl' VALUES (6096, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/dundee.pdf', 10, 5609);
INSERT INTO 'danceurl' VALUES (3960, 'https://www.rscdslondon.org.uk/sdata/dances/hunter/kitchen.pdf', 10, 5720);
INSERT INTO 'danceurl' VALUES (6097, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/roy.pdf', 10, 5732);
INSERT INTO 'danceurl' VALUES (6098, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/barn.pdf', 10, 5951);
INSERT INTO 'danceurl' VALUES (6099, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/man.pdf', 10, 5961);
INSERT INTO 'danceurl' VALUES (6100, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/bobbins.pdf', 10, 6048);
INSERT INTO 'danceurl' VALUES (6101, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/kettle.pdf', 10, 6103);
INSERT INTO 'danceurl' VALUES (6102, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/spinning.pdf', 10, 6245);
INSERT INTO 'danceurl' VALUES (3963, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/columban.pdf', 10, 5819);
INSERT INTO 'danceurl' VALUES (6103, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/stealing.pdf', 10, 6294);
INSERT INTO 'danceurl' VALUES (6104, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/stirling.pdf', 10, 6309);
INSERT INTO 'danceurl' VALUES (6105, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/tae_lassies.pdf', 10, 6434);
INSERT INTO 'danceurl' VALUES (3994, 'https://www.rscdslondon.org.uk/sdata/dances/green_lochan/threesome.pdf', 10, 6583);
INSERT INTO 'danceurl' VALUES (6106, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/tinker.pdf', 10, 6612);
INSERT INTO 'danceurl' VALUES (6107, 'https://www.rscdslondon.org.uk/sdata/dances/sheila/arches.pdf', 10, 6838);
INSERT INTO 'danceurl' VALUES (6108, 'https://www.rscdslondon.org.uk/sdata/dances/uppies.pdf', 10, 6853);
INSERT INTO 'danceurl' VALUES (6109, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/joyce.pdf', 10, 6902);
INSERT INTO 'danceurl' VALUES (6110, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/welcome.pdf', 10, 7030);
INSERT INTO 'danceurl' VALUES (6111, 'https://www.rscdslondon.org.uk/sdata/dances/ormskirk/noddin.pdf', 10, 6967);
INSERT INTO 'danceurl' VALUES (6112, 'http://www.aurorascot.org.uk/events/ball2019/1865-2', 10, 19290);
INSERT INTO 'danceurl' VALUES (6113, 'https://dances.e-cribs.org/Muir_s_Rambles.pdf', 10, 20068);
INSERT INTO 'danceurl' VALUES (4639, 'https://8x32.e-cribs.org/index.php/a/the-physicist-s-folly', 10, 13822);
INSERT INTO 'danceurl' VALUES (6114, 'http://www.johnsonvillescd.org.nz/wp-content/uploads/2016/12/A-Trip-to-Pukerangi-1992-2.pdf', 10, 20076);
INSERT INTO 'danceurl' VALUES (6115, 'https://www.johnsonvillescd.org.nz/2016/12/11/a-trip-to-pukerangi/', 20, 20076);
INSERT INTO 'danceurl' VALUES (6116, 'https://rscds-twincities.org/dance/dance-thirty/', 10, 10410);
INSERT INTO 'danceurl' VALUES (6117, 'https://rscds-twincities.org/dance/the-beaten-path/', 10, 10409);
INSERT INTO 'danceurl' VALUES (6118, 'http://www.timdoodle.com/scd/LeavesOfAutumn.html', 10, 13289);
INSERT INTO 'danceurl' VALUES (6119, 'http://www.timdoodle.com/scd/AustinCelebration.html', 10, 13284);
INSERT INTO 'danceurl' VALUES (6120, 'http://www.timdoodle.com/scd/Crofter.html', 10, 13285);
INSERT INTO 'danceurl' VALUES (6121, 'http://www.timdoodle.com/scd/FiresideLounge.html', 10, 13286);
INSERT INTO 'danceurl' VALUES (6122, 'http://www.timdoodle.com/scd/GingerReel.html', 10, 13287);
INSERT INTO 'danceurl' VALUES (6123, 'http://www.timdoodle.com/scd/GyreAndReel.html', 10, 13288);
INSERT INTO 'danceurl' VALUES (6124, 'http://www.timdoodle.com/scd/MidsummerDances.html', 10, 13290);
INSERT INTO 'danceurl' VALUES (6125, 'http://www.timdoodle.com/scd/MidsummerDances.html', 10, 13291);
INSERT INTO 'danceurl' VALUES (6126, 'http://www.timdoodle.com/scd/StJeromesReel.html', 10, 13292);
INSERT INTO 'danceurl' VALUES (5781, 'http://www.timdoodle.com/scd/TorfsDelight.html', 10, 13296);
INSERT INTO 'danceurl' VALUES (6127, 'http://www.timdoodle.com/scd/ToughRowToHoe.html', 10, 13295);
INSERT INTO 'danceurl' VALUES (6128, 'http://www.timdoodle.com/scd/WaterlooSilver.html', 10, 13297);
INSERT INTO 'danceurl' VALUES (6129, 'http://www.timdoodle.com/scd/WaterlooStrathspey.html', 10, 13298);
INSERT INTO 'danceurl' VALUES (6130, 'https://my.strathspey.org/u/murrough/Helvellyn.pdf', 10, 20089);
INSERT INTO 'danceurl' VALUES (6131, 'https://my.strathspey.org/u/murrough/ItsAllTurnedOutPerfectly.pdf', 10, 20090);
INSERT INTO 'danceurl' VALUES (6133, 'https://tac-rscds.org/images/stories/Drewry/Leaflets/Leaflet_-_The_Blue_Toon.pdf', 10, 597);
INSERT INTO 'danceurl' VALUES (6135, 'https://www.dropbox.com/s/x0ifjn335lvs6pr/Arlette%27s%20Fancy%20-%203x32J.pdf?dl=0', 10, 20143);
INSERT INTO 'danceurl' VALUES (6136, 'https://rscds-twincities.org/dance/the-flowers-of-shakopee/', 10, 10413);
INSERT INTO 'danceurl' VALUES (6137, 'https://rscds-twincities.org/dance/destination-unknown/', 10, 10411);
INSERT INTO 'danceurl' VALUES (6138, 'https://rscds-twincities.org/dance/bills-reel/', 10, 513);
INSERT INTO 'danceurl' VALUES (6139, 'https://docs.google.com/viewer?pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxzY2RmaXNoaG9la3xneDoyOGJmMDMyMjdhMDg0OThj', 10, 16800);
INSERT INTO 'danceurl' VALUES (6140, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxzY2RmaXNoaG9la3xneDo3NzNiMWVjMzZlNGQxNGUz', 10, 18006);
INSERT INTO 'danceurl' VALUES (6141, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxzY2RmaXNoaG9la3xneDo0NDkwZWFmYzlkZTI2YjIz', 10, 14365);
INSERT INTO 'danceurl' VALUES (6142, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxzY2RmaXNoaG9la3xneDo3ODYwNTUyNjQzOTI4ZTVl', 10, 17386);
INSERT INTO 'danceurl' VALUES (6143, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxzY2RmaXNoaG9la3xneDo5ZmUxNGQzYjEwMjFhNzI', 10, 19942);
INSERT INTO 'danceurl' VALUES (6144, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxzY2RmaXNoaG9la3xneDo2YzdkMDQwMjlhMjI0MzI0', 10, 13679);
INSERT INTO 'danceurl' VALUES (6145, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxzY2RmaXNoaG9la3xneDoyNWU4MTYwZWMzYjZkODhk', 10, 16775);
INSERT INTO 'danceurl' VALUES (6146, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxzY2RmaXNoaG9la3xneDo3NmZhODE5YjRkNTI2ZGQz', 10, 17769);
INSERT INTO 'danceurl' VALUES (6147, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxzY2RmaXNoaG9la3xneDpmOWQxM2RkYzRhNzQ3MDM', 10, 20198);
INSERT INTO 'danceurl' VALUES (6148, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxzY2RmaXNoaG9la3xneDoxNzc0YjljMzUwNzczZTM0', 10, 18535);
INSERT INTO 'danceurl' VALUES (6149, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxzY2RmaXNoaG9la3xneDo1MTk5N2VlOTAxMWZjNWU4', 10, 16774);
INSERT INTO 'danceurl' VALUES (6150, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxzY2RmaXNoaG9la3xneDozYmEzZmE0NDdjNWM0MWZl', 10, 20199);
INSERT INTO 'danceurl' VALUES (6151, 'https://tac-rscds.org/images/stories/Drewry/Leaflets/Leaflet_-_The_Bob_OFootdee.pdf', 10, 609);
INSERT INTO 'danceurl' VALUES (6153, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-030-December-1966.pdf#page=8', 10, 839);
INSERT INTO 'danceurl' VALUES (6154, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-030-December-1966.pdf#page=8', 10, 5221);
INSERT INTO 'danceurl' VALUES (6155, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-030-December-1966.pdf#page=8', 10, 6489);
INSERT INTO 'danceurl' VALUES (6156, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-030-December-1966.pdf#page=8', 10, 5492);
INSERT INTO 'danceurl' VALUES (6157, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-030-December-1966.pdf#page=9', 10, 5372);
INSERT INTO 'danceurl' VALUES (6158, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-030-December-1966.pdf#page=9', 10, 3558);
INSERT INTO 'danceurl' VALUES (6159, 'http://www.dancescottish.ca/leaflets_files/Ginette%20d%27He%CC%81nonville.pdf', 10, 20080);
INSERT INTO 'danceurl' VALUES (6160, 'https://dublinscdclub.files.wordpress.com/2018/12/voulez-vous-danser.pdf', 10, 20210);
INSERT INTO 'danceurl' VALUES (6161, 'https://dublinscdclub.files.wordpress.com/2019/12/mischief-mastered.pdf', 10, 20211);
INSERT INTO 'danceurl' VALUES (6162, 'https://dublinscdclub.files.wordpress.com/2018/12/Dublins-Dancing-Fiddler.pdf', 10, 20212);
INSERT INTO 'danceurl' VALUES (6163, 'https://dublinscdclub.files.wordpress.com/2018/08/florries-fancy.pdf', 10, 14387);
INSERT INTO 'danceurl' VALUES (6164, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-016-January-1964.pdf', 10, 712);
INSERT INTO 'danceurl' VALUES (6165, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-018-April-1964.pdf', 10, 6355);
INSERT INTO 'danceurl' VALUES (6166, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-020-November-1964.pdf#page=2', 10, 411);
INSERT INTO 'danceurl' VALUES (6167, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-004-February-1962.pdf', 10, 3816);
INSERT INTO 'danceurl' VALUES (6168, 'https://www.rscdslondon.org.uk/wp-content/uploads/2019/10/Reel-310-The-Sailors-Hornpipe-Book-Extract.pdf', 10, 8747);
INSERT INTO 'danceurl' VALUES (6169, 'https://www.rscdslondon.org.uk/wp-content/uploads/2020/10/Reel-313-Electronic.pdf#page=11', 10, 20219);
INSERT INTO 'danceurl' VALUES (6170, 'https://www.rscdslondon.org.uk/wp-content/uploads/2019/08/Reel-308-electronic.pdf#page=13', 10, 19247);
INSERT INTO 'danceurl' VALUES (6172, 'https://dances.e-cribs.org/Dance_for_Susana_Teaching_Notes_2015.pdf', 10, 19180);
INSERT INTO 'danceurl' VALUES (6173, 'http://web.archive.org/web/20020202231353/http://www.geocities.com/dancingduff/dance1.html', 10, 9688);
INSERT INTO 'danceurl' VALUES (6174, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-014-November-1963.pdf', 10, 3568);
INSERT INTO 'danceurl' VALUES (6175, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-012-March-1963.pdf', 10, 4041);
INSERT INTO 'danceurl' VALUES (6176, 'http://minicrib.org.uk/Publications/A%20Reel%20for%20Iris.pdf', 10, 19365);
INSERT INTO 'danceurl' VALUES (6177, 'https://dances.e-cribs.org/Rose_of_Dunure_Teaching_Notes_2007.pdf', 10, 13613);
INSERT INTO 'danceurl' VALUES (6179, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-035-February-1968.pdf#page=3', 10, 4738);
INSERT INTO 'danceurl' VALUES (6180, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-037-October-1968.pdf#page=3', 10, 2413);
INSERT INTO 'danceurl' VALUES (6181, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-039-February-1969.pdf#page=4', 10, 677);
INSERT INTO 'danceurl' VALUES (6182, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-041-October-1969.pdf#page=2', 10, 737);
INSERT INTO 'danceurl' VALUES (6183, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-042-December-1969.pdf#page=2', 10, 6535);
INSERT INTO 'danceurl' VALUES (6184, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-045-October-1970.pdf#page=2', 10, 3109);
INSERT INTO 'danceurl' VALUES (6185, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-054-December-1972.pdf#page=2', 10, 4317);
INSERT INTO 'danceurl' VALUES (6186, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/sound-of-harris-ferry.html', 10, 20232);
INSERT INTO 'danceurl' VALUES (6187, 'https://dances.e-cribs.org/Riffle_Volunteers.pdf', 10, 5573);
INSERT INTO 'danceurl' VALUES (4185, 'http://scottishweekend.org/dances/whistler.htm', 10, 9904);
INSERT INTO 'danceurl' VALUES (6189, 'http://www.strathspey.org/lists/strathspey@strathspey.org/m/11827/', 10, 2786);
INSERT INTO 'danceurl' VALUES (6190, 'https://www.strathspey.org/lists/strathspey%40strathspey.org/t/21545/', 10, 9535);
INSERT INTO 'danceurl' VALUES (6191, 'https://www.tac-rscds.org/~tacrscds/images/stories/2017-SE-UBC/2017-DANCES/G-Coull-Ceilidh-Dances.pdf#page=4', 10, 20288);
INSERT INTO 'danceurl' VALUES (6192, 'https://www.tac-rscds.org/~tacrscds/images/stories/2017-SE-UBC/2017-DANCES/G-Coull-Ceilidh-Dances.pdf#page=6', 10, 16879);
INSERT INTO 'danceurl' VALUES (6193, 'https://www.tac-rscds.org/~tacrscds/images/stories/2017-SE-UBC/2017-DANCES/G-Coull-Ceilidh-Dances.pdf#page=5', 10, 20289);
INSERT INTO 'danceurl' VALUES (6194, 'http://btckstorage.blob.core.windows.net/site12681/Archive/Misses%20Reid''s%20dance.pdf', 10, 20295);
INSERT INTO 'danceurl' VALUES (6195, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-040-May-1969.pdf#page=3', 10, 6783);
INSERT INTO 'danceurl' VALUES (6244, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-209-September-November-1994.pdf#page=10', 10, 5307);
INSERT INTO 'danceurl' VALUES (6197, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-164-May-July-1983.pdf#page=3', 10, 5932);
INSERT INTO 'danceurl' VALUES (6245, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-230-December-1999-February-2000.pdf#page=2', 10, 9350);
INSERT INTO 'danceurl' VALUES (6199, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-134-December-1975-January-1976.pdf#page=2', 10, 5868);
INSERT INTO 'danceurl' VALUES (6200, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-106-December-1968-January-1969.pdf#page=3', 10, 3264);
INSERT INTO 'danceurl' VALUES (6201, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/04/Reel-242-December-2002-February-2003.pdf#page=9', 10, 11192);
INSERT INTO 'danceurl' VALUES (6202, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/04/Reel-242-December-2002-February-2003.pdf#page=9', 10, 11191);
INSERT INTO 'danceurl' VALUES (6203, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/04/Reel-246-December-2003-February-2004.pdf#page=7', 10, 10893);
INSERT INTO 'danceurl' VALUES (6204, 'https://www.rscdslondon.org.uk/wp-content/uploads/2019/02/Reel-306-electronic.pdf#page=13', 10, 18356);
INSERT INTO 'danceurl' VALUES (6205, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-182-November-1987-January-1988.pdf#page=3', 10, 6870);
INSERT INTO 'danceurl' VALUES (6206, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-184-May-July-1988.pdf#page=3', 10, 795);
INSERT INTO 'danceurl' VALUES (6207, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-185-August-October-1988.pdf#page=3', 10, 5026);
INSERT INTO 'danceurl' VALUES (6208, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-189-August-October-1989.pdf#page=4', 10, 1544);
INSERT INTO 'danceurl' VALUES (6209, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/02/Reel-016-January-February-1954.pdf#page=5', 10, 550);
INSERT INTO 'danceurl' VALUES (6210, 'https://tunes.e-cribs.org/sm/A_Ten_Year_Reel.pdf', 10, 19192);
INSERT INTO 'danceurl' VALUES (6211, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/02/Reel-018-May-1954.pdf#page=3', 10, 2223);
INSERT INTO 'danceurl' VALUES (6212, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/02/Reel-019-June-August-1954.pdf#page=3', 10, 7120);
INSERT INTO 'danceurl' VALUES (6213, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-100-December-1967-January-1968.pdf#page=1', 20, 3909);
INSERT INTO 'danceurl' VALUES (6214, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-107-February-April-1969.pdf#page=3', 10, 3551);
INSERT INTO 'danceurl' VALUES (6215, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-108-May-July-1969.pdf#page=3', 10, 4373);
INSERT INTO 'danceurl' VALUES (6216, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-109-August-October-1969.pdf#page=3', 10, 3662);
INSERT INTO 'danceurl' VALUES (6217, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-110-November-1969-January-1970.pdf#page=5', 20, 6464);
INSERT INTO 'danceurl' VALUES (6218, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-133-August-November-1975.pdf#page=4', 10, 445);
INSERT INTO 'danceurl' VALUES (6219, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-136-May-July-1976.pdf#page=2', 10, 2535);
INSERT INTO 'danceurl' VALUES (6220, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-137-August-October-1976.pdf#page=5', 10, 4552);
INSERT INTO 'danceurl' VALUES (6221, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-138-December-1976-January-1977.pdf#page=3', 10, 1639);
INSERT INTO 'danceurl' VALUES (6222, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-141-August-October-1977.pdf#page=3', 10, 77);
INSERT INTO 'danceurl' VALUES (6223, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-145-August-October-1978.pdf#page=3', 10, 3705);
INSERT INTO 'danceurl' VALUES (6224, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-146-November-1978-January-1979.pdf#page=3', 10, 1625);
INSERT INTO 'danceurl' VALUES (6225, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-147-February-April-1979.pdf#page=2', 10, 7020);
INSERT INTO 'danceurl' VALUES (6226, 'https://tunes.e-cribs.org/sm/A_Jig_With_Alexandra.pdf', 10, 20326);
INSERT INTO 'danceurl' VALUES (6227, 'https://tunes.e-cribs.org/sm/C''est_Pour_Vous.pdf', 10, 20327);
INSERT INTO 'danceurl' VALUES (6228, 'https://tunes.e-cribs.org/sm/Just_Give_Me_a_Kiss.pdf', 10, 20323);
INSERT INTO 'danceurl' VALUES (6229, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/02/Reel-016-January-February-1954.pdf#page=5', 10, 5385);
INSERT INTO 'danceurl' VALUES (6230, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/02/Reel-018-May-1954.pdf#page=3', 10, 16959);
INSERT INTO 'danceurl' VALUES (6231, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-150-November-1979-January-1980.pdf#page=5', 10, 3366);
INSERT INTO 'danceurl' VALUES (6232, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-150-November-1979-January-1980.pdf#page=5', 10, 2588);
INSERT INTO 'danceurl' VALUES (6233, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-152-May-July-1980.pdf#page=3', 10, 68);
INSERT INTO 'danceurl' VALUES (6234, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-159-February-April-1982.pdf#page=2', 10, 893);
INSERT INTO 'danceurl' VALUES (6235, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-165-August-October-1983.pdf#page=7', 10, 4878);
INSERT INTO 'danceurl' VALUES (6236, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-166-November-1983-January-1984.pdf#page=3', 10, 4337);
INSERT INTO 'danceurl' VALUES (6237, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-171-February-April-1985.pdf#page=5', 10, 4211);
INSERT INTO 'danceurl' VALUES (6238, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-175-February-April-1986.pdf#page=2', 10, 1300);
INSERT INTO 'danceurl' VALUES (6239, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-178-November-1986-January-1987.pdf#page=2', 10, 218);
INSERT INTO 'danceurl' VALUES (6240, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-180-May-July-1987.pdf#page=3', 10, 4047);
INSERT INTO 'danceurl' VALUES (6241, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-191-February-April-1990.pdf#page=6', 10, 964);
INSERT INTO 'danceurl' VALUES (6242, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-196-May-July-1991.pdf#page=4', 10, 3106);
INSERT INTO 'danceurl' VALUES (6243, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-205-September-November-1993.pdf#page=6', 10, 7980);
INSERT INTO 'danceurl' VALUES (6246, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-231-February-April-2000.pdf#page=4', 10, 9472);
INSERT INTO 'danceurl' VALUES (6247, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/04/Reel-238-December-2001-February-2002.pdf#page=6', 10, 1533);
INSERT INTO 'danceurl' VALUES (6248, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/04/Reel-238-December-2001-February-2002.pdf#page=10', 10, 10169);
INSERT INTO 'danceurl' VALUES (6249, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/04/Reel-238-December-2001-February-2002.pdf#page=10', 10, 10086);
INSERT INTO 'danceurl' VALUES (6250, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/04/Reel-239-February-May-2002.pdf#page=5', 10, 10368);
INSERT INTO 'danceurl' VALUES (6251, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/04/Reel-239-February-May-2002.pdf#page=5', 10, 11257);
INSERT INTO 'danceurl' VALUES (6252, 'https://tunes.e-cribs.org/sm/Thoughts_Of_Romance.pdf', 10, 20331);
INSERT INTO 'danceurl' VALUES (6253, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/11/Reel-305-electronic.pdf#page=13', 10, 18553);
INSERT INTO 'danceurl' VALUES (6254, 'https://www.rscdslondon.org.uk/wp-content/uploads/2017/11/Reel-301-electronic.pdf#page=11', 10, 18023);
INSERT INTO 'danceurl' VALUES (6255, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-302-Electronic.pdf#page=11', 10, 20218);
INSERT INTO 'danceurl' VALUES (6256, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-010-January-1963.pdf', 11, 5325);
INSERT INTO 'danceurl' VALUES (6257, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-012-March-1963.pdf', 10, 5325);
INSERT INTO 'danceurl' VALUES (6258, 'https://tunes.e-cribs.org/sm/Cramond_Island.pdf', 10, 20325);
INSERT INTO 'danceurl' VALUES (6259, 'https://tunes.e-cribs.org/sm/Les_Ghillies_A_Crampons.pdf', 10, 20329);
INSERT INTO 'danceurl' VALUES (6260, 'https://tunes.e-cribs.org/sm/Joie_De_Rire.pdf', 10, 20333);
INSERT INTO 'danceurl' VALUES (6261, 'https://tunes.e-cribs.org/sm/The_Snow_Wave.pdf', 10, 20332);
INSERT INTO 'danceurl' VALUES (6262, 'https://tunes.e-cribs.org/sm/Don''t_Worry.pdf', 10, 20330);
INSERT INTO 'danceurl' VALUES (6263, 'https://www.rscdslondon.org.uk/wp-content/uploads/2020/02/Reel-310-electronic.pdf#page=13', 10, 19604);
INSERT INTO 'danceurl' VALUES (6264, 'https://www.rscdslondon.org.uk/wp-content/uploads/2020/08/Reel-312-electronic.pdf#page=11', 10, 20002);
INSERT INTO 'danceurl' VALUES (6171, 'https://www.rscdslondon.org.uk/wp-content/uploads/2020/10/Reel-313-Electronic.pdf#page=15', 11, 20220);
INSERT INTO 'danceurl' VALUES (6265, 'http://www.rscdslondon.org.uk/rdata/R313Mirror.pdf', 10, 20220);
INSERT INTO 'danceurl' VALUES (6266, 'https://recordings.e-cribs.org/Meaudre_Reel_(R8x32).mp3', 10, 19194);
INSERT INTO 'danceurl' VALUES (6267, 'https://tunes.e-cribs.org/wj/Full_Circle.pdf', 10, 20335);
INSERT INTO 'danceurl' VALUES (6268, 'https://tunes.e-cribs.org/sm/Meaudre_Reel.pdf', 10, 19194);
INSERT INTO 'danceurl' VALUES (6269, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/06-Three-Traditional-Scottish-Dances-6th-Set.pdf#page=3', 10, 441);
INSERT INTO 'danceurl' VALUES (6270, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/06-Three-Traditional-Scottish-Dances-6th-Set.pdf#page=5', 10, 5749);
INSERT INTO 'danceurl' VALUES (6271, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/06-Three-Traditional-Scottish-Dances-6th-Set.pdf#page=7', 10, 3428);
INSERT INTO 'danceurl' VALUES (6272, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/02-Four-Traditional-Scottish-Dances-2nd-Set.pdf#page=2', 10, 633);
INSERT INTO 'danceurl' VALUES (6273, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/02-Four-Traditional-Scottish-Dances-2nd-Set.pdf#page=4', 10, 5128);
INSERT INTO 'danceurl' VALUES (6274, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/02-Four-Traditional-Scottish-Dances-2nd-Set.pdf#page=5', 10, 805);
INSERT INTO 'danceurl' VALUES (6275, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/02-Four-Traditional-Scottish-Dances-2nd-Set.pdf#page=6', 10, 4271);
INSERT INTO 'danceurl' VALUES (6276, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/05-Four-Traditional-Scottish-Dances-5th-Set.pdf#page=2', 10, 742);
INSERT INTO 'danceurl' VALUES (6277, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/05-Four-Traditional-Scottish-Dances-5th-Set.pdf#page=4', 10, 5799);
INSERT INTO 'danceurl' VALUES (6278, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/05-Four-Traditional-Scottish-Dances-5th-Set.pdf#page=6', 10, 4680);
INSERT INTO 'danceurl' VALUES (6279, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/05-Four-Traditional-Scottish-Dances-5th-Set.pdf#page=8', 10, 5807);
INSERT INTO 'danceurl' VALUES (6280, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/03-Three-Traditional-Scottish-Dances-3rd-Set.pdf#page=2', 10, 1789);
INSERT INTO 'danceurl' VALUES (6281, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/03-Three-Traditional-Scottish-Dances-3rd-Set.pdf#page=5', 10, 1881);
INSERT INTO 'danceurl' VALUES (6282, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/03-Three-Traditional-Scottish-Dances-3rd-Set.pdf#page=9', 10, 3225);
INSERT INTO 'danceurl' VALUES (6283, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/01-Scottish-Country-Dance-Book-of-Four-Set-Dances-1st-Set.pdf#page=2', 10, 2846);
INSERT INTO 'danceurl' VALUES (6284, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/01-Scottish-Country-Dance-Book-of-Four-Set-Dances-1st-Set.pdf#page=4', 10, 4014);
INSERT INTO 'danceurl' VALUES (6285, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/01-Scottish-Country-Dance-Book-of-Four-Set-Dances-1st-Set.pdf#page=6', 10, 5707);
INSERT INTO 'danceurl' VALUES (6286, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/01-Scottish-Country-Dance-Book-of-Four-Set-Dances-1st-Set.pdf#page=8', 10, 6037);
INSERT INTO 'danceurl' VALUES (6287, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/04-Three-Traditional-Scottish-Dances-4th-Set.pdf#page=3', 10, 4043);
INSERT INTO 'danceurl' VALUES (6288, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/04-Three-Traditional-Scottish-Dances-4th-Set.pdf#page=5', 10, 3651);
INSERT INTO 'danceurl' VALUES (6289, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/04-Three-Traditional-Scottish-Dances-4th-Set.pdf#page=7', 10, 3680);
INSERT INTO 'danceurl' VALUES (6290, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/07-Three-Traditional-Scottish-Dances-7th-Set.pdf#page=3', 10, 4044);
INSERT INTO 'danceurl' VALUES (6291, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/07-Three-Traditional-Scottish-Dances-7th-Set.pdf#page=5', 10, 5699);
INSERT INTO 'danceurl' VALUES (6292, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/07-Three-Traditional-Scottish-Dances-7th-Set.pdf#page=7', 10, 3883);
INSERT INTO 'danceurl' VALUES (6293, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/08-Two-Traditional-Scottish-Dances-8th-Set-1.pdf#page=3', 10, 4283);
INSERT INTO 'danceurl' VALUES (6294, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/08-Two-Traditional-Scottish-Dances-8th-Set-1.pdf#page=4', 10, 6616);
INSERT INTO 'danceurl' VALUES (6295, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/08-Two-Traditional-Scottish-Dances-8th-Set-1.pdf#page=6', 10, 2353);
INSERT INTO 'danceurl' VALUES (6296, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/08-Two-Traditional-Scottish-Dances-8th-Set-1.pdf#page=8', 10, 4282);
INSERT INTO 'danceurl' VALUES (6297, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/09-Two-Traditional-Scottish-Dances-9th-Set-1.pdf#page=2', 10, 3777);
INSERT INTO 'danceurl' VALUES (6298, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/09-Two-Traditional-Scottish-Dances-9th-Set-1.pdf#page=4', 10, 4474);
INSERT INTO 'danceurl' VALUES (6299, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/09-Two-Traditional-Scottish-Dances-9th-Set-1.pdf#page=6', 10, 6091);
INSERT INTO 'danceurl' VALUES (6300, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/L01-The-Broadswords-of-Lochiel.pdf', 10, 823);
INSERT INTO 'danceurl' VALUES (6301, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-033-November-1967.pdf#page=4', 10, 823);
INSERT INTO 'danceurl' VALUES (6302, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/L04-The-Huntly-Reel.pdf', 10, 3030);
INSERT INTO 'danceurl' VALUES (6303, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/L03-The-Deeside-Lilt.pdf', 10, 1607);
INSERT INTO 'danceurl' VALUES (6304, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/L05-The-Jacobite-Sword-Dance.pdf', 10, 3189);
INSERT INTO 'danceurl' VALUES (6305, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/L06-Lady-Louisa-MacDonald-of-Sleat.pdf', 10, 3614);
INSERT INTO 'danceurl' VALUES (6306, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/L07-MacLeod-of-Lewis-1.pdf', 10, 4045);
INSERT INTO 'danceurl' VALUES (6307, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/L08-McKenzie-of-Seaforth.pdf', 10, 15781);
INSERT INTO 'danceurl' VALUES (6308, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/L08-McKenzie-of-Seaforth.pdf', 10, 20209);
INSERT INTO 'danceurl' VALUES (6309, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/L11-The-Rose-of-Benbecula-1.pdf', 10, 14313);
INSERT INTO 'danceurl' VALUES (6310, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-024-May-1965.pdf#page=2', 20, 6188);
INSERT INTO 'danceurl' VALUES (6311, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-008-November-1962.pdf', 10, 2686);
INSERT INTO 'danceurl' VALUES (6312, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-029-October-1966.pdf#page=3', 10, 4436);
INSERT INTO 'danceurl' VALUES (6313, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-034-December-1967.pdf#page=3', 10, 164);
INSERT INTO 'danceurl' VALUES (6314, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-031-February-1967.pdf#page=2', 10, 153);
INSERT INTO 'danceurl' VALUES (6315, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-026-December-1965.pdf#page=4', 10, 3552);
INSERT INTO 'danceurl' VALUES (6316, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-002-December-1961.pdf', 20, 1747);
INSERT INTO 'danceurl' VALUES (6317, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-025-October-1965.pdf#page=3', 10, 2675);
INSERT INTO 'danceurl' VALUES (6318, 'http://www.folkdance.com/LDNotations/SparklingSixty2008LD.pdf', 10, 20041);
INSERT INTO 'danceurl' VALUES (6319, 'https://tac-rscds.org/~tacrscds/images/stories/Drewry/Leaflets/Leaflet_-_By_Candlelight.pdf', 10, 991);
INSERT INTO 'danceurl' VALUES (6320, 'https://hh2f2ns.wixsite.com/frederick-scd/dances-d', 10, 17574);
INSERT INTO 'danceurl' VALUES (6321, 'https://tac-rscds.org/images/stories/Drewry/Leaflets/Leaflet_-_Abegweit.pdf', 10, 10);
INSERT INTO 'danceurl' VALUES (6322, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/T09-Maid-of-Islay.pdf', 10, 14308);
INSERT INTO 'danceurl' VALUES (6323, 'https://music.rscdsparis.fr/files/TheTranslator.pdf', 10, 20314);
INSERT INTO 'danceurl' VALUES (6324, 'https://music.rscdsparis.fr/files/TheGoldenSunOfEarlySpring.pdf', 10, 20310);
INSERT INTO 'danceurl' VALUES (6325, 'https://music.rscdsparis.fr/files/Pleiades.pdf', 10, 20311);
INSERT INTO 'danceurl' VALUES (6326, 'https://music.rscdsparis.fr/files/StopWorryingAndHaveFun.pdf', 10, 20312);
INSERT INTO 'danceurl' VALUES (6327, 'https://music.rscdsparis.fr/files/HoldenTogether.pdf', 10, 20313);
INSERT INTO 'danceurl' VALUES (6328, 'https://music.rscdsparis.fr/files/LoveIsInTheAir.pdf', 10, 18383);
INSERT INTO 'danceurl' VALUES (6329, 'https://music.rscdsparis.fr/files/DanieleLandrieau.pdf', 10, 20321);
INSERT INTO 'danceurl' VALUES (6374, 'https://dances.e-cribs.org/The_Swelterin''_Strathspey.pdf', 10, 9122);
INSERT INTO 'danceurl' VALUES (6332, 'https://tunes.e-cribs.org/wj/March_Madness.pdf', 10, 19975);
INSERT INTO 'danceurl' VALUES (6331, 'https://tunes.e-cribs.org/wj/Ho!_Tom_Bombadil.pdf', 10, 19975);
INSERT INTO 'danceurl' VALUES (6330, 'https://recordings.e-cribs.org/Ho!_Tom_Bombadil.mp3', 10, 19975);
INSERT INTO 'danceurl' VALUES (6334, 'https://www.strathspey.org/lists/strathspey%40strathspey.org/t/11237/#m11237', 10, 3232);
INSERT INTO 'danceurl' VALUES (6335, 'https://rscds-delft.nl/anne-miek.html#06', 10, 20368);
INSERT INTO 'danceurl' VALUES (6336, 'https://rscds-delft.nl/anne-miek.html#05', 10, 20367);
INSERT INTO 'danceurl' VALUES (6337, 'https://rscds-delft.nl/anne-miek.html#04', 10, 20366);
INSERT INTO 'danceurl' VALUES (6338, 'https://rscds-delft.nl/anne-miek.html#13', 10, 10003);
INSERT INTO 'danceurl' VALUES (6339, 'https://drive.google.com/file/d/1lV3QSQl9DO-Y5tVPSM5F4pEswTAk4_Z1/view', 10, 20391);
INSERT INTO 'danceurl' VALUES (6340, 'https://drive.google.com/file/d/0B6ezj9waJDcVaE0zLVJ4Z1J1X2M/view', 10, 12629);
INSERT INTO 'danceurl' VALUES (6341, 'https://rscds-delft.nl/anne-miek.html#01', 10, 20363);
INSERT INTO 'danceurl' VALUES (6342, 'https://rscds-delft.nl/anne-miek.html#03', 10, 20365);
INSERT INTO 'danceurl' VALUES (6343, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=30&token=3416a75f4cea9109507cacd8e2f2aefc#tab30', 10, 20394);
INSERT INTO 'danceurl' VALUES (6344, 'https://www.genevascdc.com/EN/LC_TFL.shtml', 10, 18046);
INSERT INTO 'danceurl' VALUES (6345, 'https://www.genevascdc.com/EN/OD_SMC.shtml', 10, 13867);
INSERT INTO 'danceurl' VALUES (6346, 'https://www.matsmelin.com/wp-content/uploads/2019/08/1988-Melin-Russian-Fling-Reel.pdf', 10, 5776);
INSERT INTO 'danceurl' VALUES (6347, 'https://www.matsmelin.com/wp-content/uploads/2011/05/Hogmanay-Strathspey.pdf', 10, 12274);
INSERT INTO 'danceurl' VALUES (6348, 'https://www.matsmelin.com/wp-content/uploads/2011/05/Gairie-Burn.pdf', 10, 12252);
INSERT INTO 'danceurl' VALUES (6349, 'https://www.matsmelin.com/wp-content/uploads/2011/05/QuintReel.pdf', 10, 12375);
INSERT INTO 'danceurl' VALUES (6350, 'https://www.matsmelin.com/wp-content/uploads/2019/08/Stockholm-Ceilidh-J40-M-Melin.pdf', 10, 19501);
INSERT INTO 'danceurl' VALUES (6351, 'https://www.matsmelin.com/wp-content/uploads/2019/08/2017-Melin-The-Drummer-and-the-Dancer-R32-3.pdf', 10, 19497);
INSERT INTO 'danceurl' VALUES (6352, 'https://web.archive.org/web/20010304162309/http://www.main.org/austinscd/dances/Blumentritt-001.html', 10, 10022);
INSERT INTO 'danceurl' VALUES (6353, 'https://suepetyt.e-cribs.org/The_Day_of_Dance.pdf', 10, 17571);
INSERT INTO 'danceurl' VALUES (5130, 'https://suepetyt.e-cribs.org/60_and_still_going.pdf', 10, 14600);
INSERT INTO 'danceurl' VALUES (6354, 'https://suepetyt.e-cribs.org/Queen_of_the_Seas.pdf', 10, 17573);
INSERT INTO 'danceurl' VALUES (6355, 'https://dances.e-cribs.org/Arthur''s_Reel.pdf', 10, 20422);
INSERT INTO 'danceurl' VALUES (6356, 'http://users.tpg.com.au/juliasm/Scottish-Dance/Arthur%27s%20Reel.pdf', 10, 20422);
INSERT INTO 'danceurl' VALUES (6358, 'http://users.tpg.com.au/juliasm/Scottish-Dance/Portarlington%20Beckons.pdf', 10, 20423);
INSERT INTO 'danceurl' VALUES (6359, 'http://users.tpg.com.au/juliasm/Scottish-Dance/Bavarian%20Double.pdf', 10, 20424);
INSERT INTO 'danceurl' VALUES (6360, 'https://dances.e-cribs.org/Portarlington_Beckons.pdf', 10, 20423);
INSERT INTO 'danceurl' VALUES (6361, 'https://dances.e-cribs.org/Bavarian_Double.pdf', 10, 20424);
INSERT INTO 'danceurl' VALUES (6362, 'https://dances.e-cribs.org/Let''s_Get_This_Sorted.pdf', 10, 20056);
INSERT INTO 'danceurl' VALUES (6364, 'https://dances.e-cribs.org/Miss_Adele''s_Delight.pdf', 10, 10512);
INSERT INTO 'danceurl' VALUES (6365, 'https://dances.e-cribs.org/A_Dance_for_All_the_McKays.pdf', 10, 10513);
INSERT INTO 'danceurl' VALUES (6366, 'https://dances.e-cribs.org/Mrs_Elspeth_Sinclair''s_Strathspey.pdf', 10, 9343);
INSERT INTO 'danceurl' VALUES (6367, 'https://dances.e-cribs.org/Up_the_Pond.pdf', 10, 7558);
INSERT INTO 'danceurl' VALUES (6368, 'https://dances.e-cribs.org/A_Trip_to_the_Trossachs.pdf', 10, 9046);
INSERT INTO 'danceurl' VALUES (6369, 'https://dances.e-cribs.org/A_Trip_to_Newfoundland.pdf', 10, 7557);
INSERT INTO 'danceurl' VALUES (6370, 'https://dances.e-cribs.org/The_Three_Rivers_Reel.pdf', 10, 10514);
INSERT INTO 'danceurl' VALUES (6371, 'https://dances.e-cribs.org/The_Richmond_Two_Steps.pdf', 10, 10803);
INSERT INTO 'danceurl' VALUES (6372, 'https://dances.e-cribs.org/On_the_Wallaby_Track.pdf', 10, 10802);
INSERT INTO 'danceurl' VALUES (6373, 'https://dances.e-cribs.org/The_Avalon_Waltz.pdf', 10, 10804);
INSERT INTO 'danceurl' VALUES (6375, 'https://dances.e-cribs.org/Love''s_Knot_Forgotten.pdf', 10, 9776);
INSERT INTO 'danceurl' VALUES (6376, 'https://ousds.web.ox.ac.uk/ousds-dances', 10, 19573);
INSERT INTO 'danceurl' VALUES (6377, 'https://ousds.web.ox.ac.uk/ousds-dances', 10, 14723);
INSERT INTO 'danceurl' VALUES (6378, 'https://ousds.web.ox.ac.uk/ousds-dances', 10, 19574);
INSERT INTO 'danceurl' VALUES (6379, 'https://dances.e-cribs.org/Clare''s_Dance.pdf', 10, 12809);
INSERT INTO 'danceurl' VALUES (6380, 'https://dances.e-cribs.org/The_Tree_Fern.pdf', 10, 10977);
INSERT INTO 'danceurl' VALUES (6381, 'https://dances.e-cribs.org/The_Falkirk_Lass.pdf', 10, 10459);
INSERT INTO 'danceurl' VALUES (6382, 'https://dances.e-cribs.org/The_Salmonfield_Poacher.pdf', 10, 8970);
INSERT INTO 'danceurl' VALUES (6383, 'https://rscds-delft.nl/anne-miek.html', 10, 20369);
INSERT INTO 'danceurl' VALUES (6384, 'https://dances.e-cribs.org/Nimbus_2002.pdf', 10, 11969);
INSERT INTO 'danceurl' VALUES (6385, 'https://dances.e-cribs.org/The_Silver_Thistle_Ball.pdf', 10, 11970);
INSERT INTO 'danceurl' VALUES (6386, 'https://dances.e-cribs.org/Iona.pdf', 10, 8567);
INSERT INTO 'danceurl' VALUES (6387, 'https://dances.e-cribs.org/Haggarty''s_Brig.pdf', 10, 10458);
INSERT INTO 'danceurl' VALUES (6388, 'https://dances.e-cribs.org/Foggy_River_Reel.pdf', 10, 9802);
INSERT INTO 'danceurl' VALUES (6389, 'https://dances.e-cribs.org/A_Dance_for_Forty.pdf', 10, 10978);
INSERT INTO 'danceurl' VALUES (6390, 'https://dances.e-cribs.org/Aberdeen_Hunt.pdf', 10, 14013);
INSERT INTO 'danceurl' VALUES (6391, 'https://dances.e-cribs.org/Catching_Fireflies.pdf', 10, 11968);
INSERT INTO 'danceurl' VALUES (6392, 'https://dances.e-cribs.org/The_Bonnie_Hoose_o''_Airlee.pdf', 10, 684);
INSERT INTO 'danceurl' VALUES (6393, 'https://www.eecis.udel.edu/~harvey/PreparationReel.pdf', 10, 12894);
INSERT INTO 'danceurl' VALUES (6394, 'https://www.eecis.udel.edu/~harvey/PreparationReel.html', 11, 12894);
INSERT INTO 'danceurl' VALUES (6395, 'https://www.eecis.udel.edu/~harvey/puffins-reel.pdf', 10, 10285);
INSERT INTO 'danceurl' VALUES (6396, 'https://www.eecis.udel.edu/~harvey/ValleyOverTheHill32R3C.pdf', 10, 17265);
INSERT INTO 'danceurl' VALUES (6397, 'http://www.dancescottish.ca/leaflets_files/The%20Corona%20Borealis%20Reel.pdf', 10, 20207);
INSERT INTO 'danceurl' VALUES (6398, 'http://www.dancescottish.ca/leaflets_files/Dancing%20Not%20In%20The%20Park%20-%204-cpl%20reel%20or%20strathspey.pdf', 10, 19974);
INSERT INTO 'danceurl' VALUES (6399, 'http://www.dancescottish.ca/leaflets_files/Moran%20Taing%20-%2048-bar%20strathspey.pdf', 10, 4658);
INSERT INTO 'danceurl' VALUES (6400, 'http://www.dancescottish.ca/leaflets_files/The%20Hurrier%20You%20Go%20The%20Behinder%20You%20Get.pdf', 10, 3036);
INSERT INTO 'danceurl' VALUES (6401, 'http://www.dancescottish.ca/leaflets_files/St%20Andrews%20Links%20-%203s40.pdf', 10, 11107);
INSERT INTO 'danceurl' VALUES (6402, 'http://www.dancescottish.ca/leaflets_files/Bonavista.pdf', 10, 10456);
INSERT INTO 'danceurl' VALUES (6403, 'http://www.dancescottish.ca/leaflets_files/Ice%20Crystals%20-%208s32.pdf', 10, 3063);
INSERT INTO 'danceurl' VALUES (6404, 'http://www.dancescottish.ca/leaflets_files/A%20Marriage%20Made%20in%20Dancing%20-%208s32.pdf', 10, 15768);
INSERT INTO 'danceurl' VALUES (6405, 'http://www.dancescottish.ca/leaflets_files/Amhuinnsuidhe%20Castle%20-%208s32.pdf', 10, 15438);
INSERT INTO 'danceurl' VALUES (6406, 'http://www.dancescottish.ca/leaflets_files/The%20Countess%20of%20Dunmore%27s%20Reel%20-%208r32.pdf', 10, 16537);
INSERT INTO 'danceurl' VALUES (6407, 'http://www.dancescottish.ca/leaflets_files/The%20Scholars%20Bus%20-%208j32.pdf', 10, 18696);
INSERT INTO 'danceurl' VALUES (6408, 'http://www.dancescottish.ca/leaflets_files/Farewell%20to%20Benbecula%20-%203s32.pdf', 10, 19119);
INSERT INTO 'danceurl' VALUES (6409, 'http://www.dancescottish.ca/leaflets_files/The%20Erindale%20Jig%20-%208j32.pdf', 10, 19010);
INSERT INTO 'danceurl' VALUES (6410, 'http://www.dancescottish.ca/leaflets_files/A%20Trip%20to%20Crinan.pdf', 10, 15437);
INSERT INTO 'danceurl' VALUES (6411, 'http://www.dancescottish.ca/leaflets_files/Father%20To%20Son%20-%208r32.pdf', 10, 15443);
INSERT INTO 'danceurl' VALUES (6412, 'http://www.dancescottish.ca/leaflets_files/St%20Kilda%20Jig%20-%208j32.pdf', 10, 19122);
INSERT INTO 'danceurl' VALUES (6413, 'http://www.dancescottish.ca/leaflets_files/Smiling%20Lila%20-%208r32.pdf', 10, 19118);
INSERT INTO 'danceurl' VALUES (6414, 'http://www.dancescottish.ca/leaflets_files/Michelle%20Depledge%20of%20Preston%20-%208s32.pdf', 10, 13592);
INSERT INTO 'danceurl' VALUES (6415, 'http://www.dancescottish.ca/leaflets_files/Tam%20O%27Shanter.pdf', 10, 11709);
INSERT INTO 'danceurl' VALUES (6417, 'http://www.dancescottish.ca/A-Bouquet-for-May.pdf', 10, 20455);
INSERT INTO 'danceurl' VALUES (6418, 'https://www.rscds-sf.org/resources/dances/State%20of%20Grace.pdf', 10, 15566);
INSERT INTO 'danceurl' VALUES (5771, 'https://www.rscds-sf.org/resources/dances/Pilot''s%20Delight.pdf', 10, 19034);
INSERT INTO 'danceurl' VALUES (6419, 'https://www.rscds-sf.org/resources/dances/Basic%20Knitting.pdf', 10, 14329);
INSERT INTO 'danceurl' VALUES (6420, 'https://www.rscds-sf.org/resources/dances/MagicOfMerrill.1.pdf', 10, 13357);
INSERT INTO 'danceurl' VALUES (6421, 'http://ramshaw.info/dances/MagicOfMerrill.pdf', 10, 13357);
INSERT INTO 'danceurl' VALUES (6422, 'https://www.rscds-sf.org/resources/dances/The%20Barefoot%20Lad.htm', 10, 17763);
INSERT INTO 'danceurl' VALUES (6423, 'https://www.rscds-sf.org/resources/dances/Margaret%20Mitchell''s%20Rant%20revised.pdf', 10, 15697);
INSERT INTO 'danceurl' VALUES (6424, 'https://www.rscds-sf.org/resources/dances/Susie''s%20Latest%20Promotion.pdf', 10, 17765);
INSERT INTO 'danceurl' VALUES (6425, 'https://www.rscds-sf.org/resources/dances/Something%20Blue%20leaflet-3.pdf', 10, 17762);
INSERT INTO 'danceurl' VALUES (6426, 'https://www.rscds-sf.org/resources/dances/Together%20for%20Forty%20Years.1.pdf', 10, 19132);
INSERT INTO 'danceurl' VALUES (6427, 'http://www.londonhighlandclub.co.uk/DanceCribs/Bob%20Gilmour.pdf', 10, 605);
INSERT INTO 'danceurl' VALUES (6428, 'http://www.londonhighlandclub.co.uk/DanceCribs/Farewell%20to%20Fetter%20Lane.pdf', 10, 3906);
INSERT INTO 'danceurl' VALUES (6429, 'http://www.londonhighlandclub.co.uk/DanceCribs/Farewell%20to%20Paternoster%20Square.pdf', 10, 2093);
INSERT INTO 'danceurl' VALUES (6430, 'http://www.londonhighlandclub.co.uk/DanceCribs/The%20Dance%20of%20Diamonds.pdf', 10, 1521);
INSERT INTO 'danceurl' VALUES (6431, 'https://my.strathspey.org/u/murrough/ChasePursuedByABear.pdf', 10, 20562);
INSERT INTO 'danceurl' VALUES (6432, 'https://www.turnverein-maxglan.at/ovarian-cancer-appeal-for-scottish-country-dancers/', 10, 20563);
INSERT INTO 'danceurl' VALUES (6433, 'https://my.strathspey.org/u/murrough/other/StMarksStrathspey.pdf', 10, 20561);
INSERT INTO 'danceurl' VALUES (6434, 'http://www.scottishdance.net/dances/Book/BobGrantOfEdinburgh.pdf', 10, 20579);
INSERT INTO 'danceurl' VALUES (6435, 'http://www.staffordscottishdancing.danceorg.uk/dance-cribs/', 10, 15594);
INSERT INTO 'danceurl' VALUES (6436, 'http://www.staffordscottishdancing.danceorg.uk/dance-cribs/', 10, 15597);
INSERT INTO 'danceurl' VALUES (6437, 'http://www.staffordscottishdancing.danceorg.uk/dance-cribs/', 10, 13752);
INSERT INTO 'danceurl' VALUES (6438, 'http://www.staffordscottishdancing.danceorg.uk/dance-cribs/', 10, 16865);
INSERT INTO 'danceurl' VALUES (6439, 'http://www.staffordscottishdancing.danceorg.uk/dance-cribs/', 10, 20623);
INSERT INTO 'danceurl' VALUES (6440, 'http://www.staffordscottishdancing.danceorg.uk/dance-cribs/', 10, 8648);
INSERT INTO 'danceurl' VALUES (6441, 'http://www.staffordscottishdancing.danceorg.uk/dance-cribs/', 10, 15418);
INSERT INTO 'danceurl' VALUES (6442, 'http://www.staffordscottishdancing.danceorg.uk/dance-cribs/', 10, 8650);
INSERT INTO 'danceurl' VALUES (6443, 'https://drive.google.com/file/d/1DtHAKgqkfqFvHe62JDUt5gV5RZ2DZ2fC/view', 10, 15712);
INSERT INTO 'danceurl' VALUES (6444, 'https://sites.google.com/site/ipscdg/commemorative-book-of-dances', 10, 15712);
INSERT INTO 'danceurl' VALUES (6445, 'https://bit.ly/2QD8YF2', 10, 20664);
INSERT INTO 'danceurl' VALUES (6446, 'https://my.strathspey.org/u/murrough/BlueSkyYellowSun.pdf', 10, 20674);
INSERT INTO 'danceurl' VALUES (6447, 'https://suedan.com/dances/instructions/twoheartsentwined.html', 10, 20704);
INSERT INTO 'danceurl' VALUES (6448, 'https://www.turnverein-maxglan.at/reginas-dances/', 10, 20709);
INSERT INTO 'danceurl' VALUES (6449, 'https://www.turnverein-maxglan.at/reginas-dances/', 10, 20717);
INSERT INTO 'danceurl' VALUES (6450, 'https://www.turnverein-maxglan.at/reginas-dances/', 10, 20710);
INSERT INTO 'danceurl' VALUES (6451, 'https://www.turnverein-maxglan.at/reginas-dances/', 10, 20711);
INSERT INTO 'danceurl' VALUES (6452, 'https://www.turnverein-maxglan.at/reginas-dances/', 10, 20712);
INSERT INTO 'danceurl' VALUES (6453, 'https://www.turnverein-maxglan.at/reginas-dances/', 10, 20713);
INSERT INTO 'danceurl' VALUES (6454, 'https://www.turnverein-maxglan.at/reginas-dances/', 10, 20714);
INSERT INTO 'danceurl' VALUES (6455, 'https://www.turnverein-maxglan.at/reginas-dances/', 10, 20715);
INSERT INTO 'danceurl' VALUES (6456, 'https://www.turnverein-maxglan.at/reginas-dances/', 10, 20716);
INSERT INTO 'danceurl' VALUES (6457, 'https://dances.e-cribs.org/The_100th_English_Weekend_reloaded.pdf', 10, 18037);
INSERT INTO 'danceurl' VALUES (6458, 'https://dances.e-cribs.org/Chemnitz_Loopings.pdf', 10, 18038);
INSERT INTO 'danceurl' VALUES (6459, 'https://my.strathspey.org/u/murrough/EmergingFromLochDown.pdf', 10, 20718);
INSERT INTO 'danceurl' VALUES (6460, 'http://www.rscds-swws.org/news/stories/MyLittleButtercup.pdf', 10, 20722);
INSERT INTO 'danceurl' VALUES (6461, 'http://www.rscds-swws.org/news/stories/WeCanSew.pdf', 10, 20723);
INSERT INTO 'danceurl' VALUES (6462, 'http://www.rscds-swws.org/news/stories/PacificNorthwestPicnic.pdf', 10, 20724);
INSERT INTO 'danceurl' VALUES (6463, 'http://www.rscds-swws.org/news/stories/TakeAmigosClothes.pdf', 10, 20725);
INSERT INTO 'danceurl' VALUES (6464, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/du3a-ur30.html', 10, 20772);
INSERT INTO 'danceurl' VALUES (6465, 'https://my.strathspey.org/u/murrough/Atheist.pdf', 10, 20871);
INSERT INTO 'danceurl' VALUES (6466, 'https://my.strathspey.org/u/murrough/CliffsOfMoher.pdf', 10, 20872);
INSERT INTO 'danceurl' VALUES (6467, 'https://my.strathspey.org/u/murrough/SightlinesFromChernex.pdf', 10, 20873);
INSERT INTO 'danceurl' VALUES (6468, 'http://www.patshaw.info/Dance%20Notations/Levi%20Jackson%20Rag.pdf', 10, 20889);
INSERT INTO 'danceurl' VALUES (6469, 'https://dances.e-cribs.org/Miss_Amy_Andrews.pdf', 10, 20896);
INSERT INTO 'danceurl' VALUES (6470, 'https://suedan.com/dances/instructions/goldensplendor.html', 10, 20925);
INSERT INTO 'danceurl' VALUES (6472, 'https://suedan.com/dances/instructions/highmaintenance.html', 10, 20924);
INSERT INTO 'danceurl' VALUES (6473, 'https://suedan.com/dances/instructions/circleoflife.html', 10, 20926);
INSERT INTO 'danceurl' VALUES (6474, 'https://suedan.com/dances/instructions/trotteratplay.html', 10, 20927);
INSERT INTO 'danceurl' VALUES (6475, 'https://suedan.com/dances/instructions/beesareback.html', 10, 20928);
INSERT INTO 'danceurl' VALUES (6476, 'https://suedan.com/dances/instructions/sharedtradition.html', 10, 20929);
INSERT INTO 'danceurl' VALUES (6477, 'https://my.strathspey.org/u/anselm/dances/ladyofthedance/', 10, 10563);
INSERT INTO 'danceurl' VALUES (6478, 'https://my.strathspey.org/u/murrough/XMarksTheScot.pdf', 10, 20959);
INSERT INTO 'danceurl' VALUES (6479, 'https://my.strathspey.org/u/murrough/SplendourInTheGrass.pdf', 10, 20864);
INSERT INTO 'danceurl' VALUES (6480, 'https://scd.niols.fr/dance/drawn-in.pdf', 10, 20314);
INSERT INTO 'danceurl' VALUES (6481, 'https://scd.niols.fr/tune/forty-bars-of-cloud.pdf', 10, 19198);
INSERT INTO 'danceurl' VALUES (6482, 'https://scd.niols.fr/tune/forty-bars-of-cloud.pdf', 10, 19197);
INSERT INTO 'danceurl' VALUES (6483, 'https://scd.niols.fr/dance/two-blue-clouds-in-the-grey-sky.pdf', 10, 19197);
INSERT INTO 'danceurl' VALUES (6484, 'https://scd.niols.fr/dance/the-mall-in-st-james-s-park.html', 10, 20991);
INSERT INTO 'danceurl' VALUES (6485, 'https://scd.niols.fr/tune/the-mall-in-st-james-s-park.html', 10, 20991);
INSERT INTO 'danceurl' VALUES (6486, 'https://scd.niols.fr/dance/the-reel-of-the-51st-confusion.html', 10, 20993);
INSERT INTO 'danceurl' VALUES (6487, 'https://scd.niols.fr/tune/the-sober-piper.html', 10, 20993);
INSERT INTO 'danceurl' VALUES (6488, 'https://scd.niols.fr/dance/praha-matka-mest.html', 10, 20992);
INSERT INTO 'danceurl' VALUES (6489, 'https://scd.niols.fr/dance/the-waves.html', 10, 20994);
INSERT INTO 'danceurl' VALUES (5768, 'https://suedan.com/dances/instructions/wookieewalk.html', 10, 18569);
INSERT INTO 'danceurl' VALUES (6490, 'https://my.strathspey.org/u/murrough/BackToSquareOne.pdf', 10, 20998);
INSERT INTO 'danceurl' VALUES (6491, 'https://my.strathspey.org/u/murrough/ShimmeringFlamingos.pdf', 10, 20999);
INSERT INTO 'danceurl' VALUES (6492, 'https://my.strathspey.org/u/murrough/GenerousTunesmith.pdf', 10, 21001);
INSERT INTO 'danceurl' VALUES (6493, 'https://my.strathspey.org/u/murrough/EditorEmeritus.pdf', 10, 21000);
INSERT INTO 'danceurl' VALUES (6494, 'https://my.strathspey.org/u/murrough/NurseDent.pdf', 10, 21002);
INSERT INTO 'danceurl' VALUES (6495, 'https://suedan.com/dances/instructions/corinnescaper.html', 10, 19910);
INSERT INTO 'danceurl' VALUES (6496, 'https://suedan.com/dances/instructions/grandpasqueezebox.html', 10, 19690);
INSERT INTO 'danceurl' VALUES (6497, 'https://suedan.com/dances/instructions/ajigforthenewyear.html', 10, 20618);
INSERT INTO 'danceurl' VALUES (6498, 'https://suedan.com/dances/instructions/the18thofnovember.html', 10, 19905);
INSERT INTO 'danceurl' VALUES (6499, 'https://suedan.com/dances/instructions/superbluebloodmoon.html', 10, 21004);
INSERT INTO 'danceurl' VALUES (6500, 'https://suedan.com/dances/instructions/itsanewworld.html', 10, 21003);
INSERT INTO 'danceurl' VALUES (6501, 'https://suedan.com/dances/instructions/firstrobinofspring.html', 10, 21005);
INSERT INTO 'danceurl' VALUES (6502, 'https://suedan.com/dances/instructions/itsworthbelievin.html', 10, 21006);
INSERT INTO 'danceurl' VALUES (6503, 'https://suedan.com/dances/instructions/shadowdoubleknitting.html', 10, 21007);
INSERT INTO 'danceurl' VALUES (6504, 'https://suedan.com/dances/instructions/beehappy.html', 10, 21008);
INSERT INTO 'danceurl' VALUES (6505, 'https://suedan.com/dances/instructions/twistedtriangle.html', 10, 21009);
INSERT INTO 'danceurl' VALUES (6506, 'https://suedan.com/dances/instructions/tonisbigday.html', 10, 21011);
INSERT INTO 'danceurl' VALUES (6507, 'https://suedan.com/dances/instructions/loopdeloop.html', 10, 21012);
INSERT INTO 'danceurl' VALUES (6508, 'https://suedan.com/dances/instructions/cantdependonlove.html', 10, 21013);
INSERT INTO 'danceurl' VALUES (6509, 'https://suedan.com/dances/instructions/cottonjenny.html', 10, 21014);
INSERT INTO 'danceurl' VALUES (6510, 'https://suedan.com/dances/instructions/albertabound.html', 10, 21015);
INSERT INTO 'danceurl' VALUES (6511, 'https://suedan.com/dances/instructions/justkeepdancing.html', 10, 21016);
INSERT INTO 'danceurl' VALUES (6512, 'https://suedan.com/dances/instructions/chocolatebabka.html', 10, 21017);
INSERT INTO 'danceurl' VALUES (6513, 'https://suedan.com/dances/instructions/tuxedocat.html', 10, 21018);
INSERT INTO 'danceurl' VALUES (6514, 'https://suedan.com/dances/instructions/gogoround.html', 10, 21019);
INSERT INTO 'danceurl' VALUES (6515, 'https://suedan.com/dances/instructions/ghostsofcapehorn.html', 10, 21020);
INSERT INTO 'danceurl' VALUES (6516, 'https://suedan.com/dances/instructions/farfalle.html', 10, 21021);
INSERT INTO 'danceurl' VALUES (6517, 'https://suedan.com/dances/instructions/roseground.html', 10, 21032);
INSERT INTO 'danceurl' VALUES (6518, 'https://suedan.com/dances/instructions/monarchduet.html', 10, 21031);
INSERT INTO 'danceurl' VALUES (6519, 'https://suedan.com/dances/instructions/spinnenspinnenspinnen.html', 10, 21033);
INSERT INTO 'danceurl' VALUES (6520, 'https://suedan.com/dances/instructions/helenandmalcolmbrown.html', 10, 21034);
INSERT INTO 'danceurl' VALUES (6521, 'https://suedan.com/dances/instructions/cycles.html', 10, 21035);
INSERT INTO 'danceurl' VALUES (6522, 'https://suedan.com/dances/instructions/catchherifyoucan.html', 10, 21036);
INSERT INTO 'danceurl' VALUES (6523, 'https://suedan.com/dances/instructions/ridethewind.html', 10, 21037);
INSERT INTO 'danceurl' VALUES (6524, 'https://suedan.com/dances/instructions/nomekingsbelt.html', 10, 21038);
INSERT INTO 'danceurl' VALUES (6525, 'https://suedan.com/dances/instructions/buckinghamfountain.html', 10, 21039);
INSERT INTO 'danceurl' VALUES (6526, 'https://suedan.com/dances/instructions/diagonalduet.html', 10, 21040);
INSERT INTO 'danceurl' VALUES (6527, 'https://suedan.com/dances/instructions/justkeepturning.html', 10, 21041);
INSERT INTO 'danceurl' VALUES (6528, 'https://suedan.com/dances/instructions/awalkaroundtheblock.html', 10, 21042);
INSERT INTO 'danceurl' VALUES (6529, 'https://suedan.com/dances/instructions/23-7.html', 10, 21043);
INSERT INTO 'danceurl' VALUES (6530, 'https://suedan.com/dances/instructions/whitecity.html', 10, 21044);
INSERT INTO 'danceurl' VALUES (6531, 'https://suedan.com/dances/instructions/farewellfaithfuloak.html', 10, 21045);
INSERT INTO 'danceurl' VALUES (6532, 'https://suedan.com/dances/instructions/dreamstreetrose.html', 10, 21046);
INSERT INTO 'danceurl' VALUES (6533, 'https://suedan.com/dances/instructions/nwtmountie.html', 10, 21047);
INSERT INTO 'danceurl' VALUES (6534, 'https://suedan.com/dances/instructions/highlandscrambler.html', 10, 21048);
INSERT INTO 'danceurl' VALUES (6535, 'https://suedan.com/dances/instructions/tortiesarealwayssweet.html', 10, 21049);
INSERT INTO 'danceurl' VALUES (6536, 'https://suedan.com/dances/instructions/longerdays.html', 10, 21050);
INSERT INTO 'danceurl' VALUES (6537, 'https://suedan.com/dances/instructions/firstnight.html', 10, 21051);
INSERT INTO 'danceurl' VALUES (6538, 'https://suedan.com/dances/instructions/timetodanceagain.html', 10, 21052);
INSERT INTO 'danceurl' VALUES (6539, 'https://suedan.com/dances/instructions/returntodelawarevalley.html', 10, 21053);
INSERT INTO 'danceurl' VALUES (6540, 'https://suedan.com/dances/instructions/ice-cold-ice.html', 10, 21054);
INSERT INTO 'danceurl' VALUES (6541, 'https://suedan.com/dances/instructions/savorthefigure.html', 10, 21055);
INSERT INTO 'danceurl' VALUES (6542, 'https://suedan.com/dances/instructions/jerseyboy.html', 10, 21056);
INSERT INTO 'danceurl' VALUES (6543, 'https://suedan.com/dances/instructions/celticwheel.html', 10, 21058);
INSERT INTO 'danceurl' VALUES (6544, 'https://suedan.com/dances/instructions/aprilsnowagain.html', 10, 21060);
INSERT INTO 'danceurl' VALUES (6545, 'https://suedan.com/dances/instructions/toomuchrain.html', 10, 21063);
INSERT INTO 'danceurl' VALUES (6546, 'https://suedan.com/dances/instructions/foxinthesun.html', 10, 21064);
INSERT INTO 'danceurl' VALUES (6547, 'https://suedan.com/dances/instructions/fourdaughters.html', 10, 21059);
INSERT INTO 'danceurl' VALUES (6548, 'https://suedan.com/dances/instructions/oldfriends.html', 10, 21061);
INSERT INTO 'danceurl' VALUES (6549, 'https://suedan.com/dances/instructions/somethingdifferent.html', 10, 21062);
INSERT INTO 'danceurl' VALUES (6550, 'https://suedan.com/dances/instructions/screamofthecat.html', 10, 21057);
INSERT INTO 'danceurl' VALUES (6551, 'https://suedan.com/dances/instructions/fourcornersromp.html', 10, 21065);
INSERT INTO 'danceurl' VALUES (6552, 'https://suedan.com/dances/instructions/aprilsnow.html', 10, 21010);
INSERT INTO 'danceurl' VALUES (6553, 'https://suedan.com/dances/instructions/orangeandblackbeauty.html', 10, 21022);
INSERT INTO 'danceurl' VALUES (6554, 'https://suedan.com/dances/instructions/dipndive.html', 10, 21066);
INSERT INTO 'danceurl' VALUES (6555, 'https://suedan.com/dances/instructions/remnantsofbarry.html', 10, 21067);
INSERT INTO 'danceurl' VALUES (6556, 'https://suedan.com/dances/instructions/spirit.html', 10, 21068);
INSERT INTO 'danceurl' VALUES (6557, 'https://suedan.com/dances/instructions/hesleptonmyheart.html', 10, 21070);
INSERT INTO 'danceurl' VALUES (6558, 'https://suedan.com/dances/instructions/adopt.html', 10, 21071);
INSERT INTO 'danceurl' VALUES (6559, 'https://suedan.com/dances/instructions/chainedtogether.html', 10, 21072);
INSERT INTO 'danceurl' VALUES (6560, 'https://suedan.com/dances/instructions/tartanweave.html', 10, 21073);
INSERT INTO 'danceurl' VALUES (6561, 'https://suedan.com/dances/instructions/merryandbright.html', 10, 21074);
INSERT INTO 'danceurl' VALUES (6562, 'https://suedan.com/dances/instructions/softpretzels.html', 10, 21075);
INSERT INTO 'danceurl' VALUES (6563, 'https://suedan.com/dances/instructions/iainsinspiration.html', 10, 21076);
INSERT INTO 'danceurl' VALUES (6564, 'https://suedan.com/dances/instructions/bookends.html', 10, 21077);
INSERT INTO 'danceurl' VALUES (6565, 'https://suedan.com/dances/instructions/lastfarewell.html', 10, 21078);
INSERT INTO 'danceurl' VALUES (6566, 'https://suedan.com/dances/instructions/knotsandcrosses.html', 10, 21079);
INSERT INTO 'danceurl' VALUES (6567, 'https://suedan.com/dances/instructions/newbeginnings.html', 10, 21080);
INSERT INTO 'danceurl' VALUES (6568, 'https://suedan.com/dances/instructions/albany.html', 10, 21081);
INSERT INTO 'danceurl' VALUES (6569, 'https://suedan.com/dances/instructions/jackmeetsgeorge.html', 10, 21082);
INSERT INTO 'danceurl' VALUES (6570, 'https://suedan.com/dances/instructions/bourrelmadness.html', 10, 21083);
INSERT INTO 'danceurl' VALUES (6571, 'https://suedan.com/dances/instructions/73istheperfectnumber.html', 10, 21084);
INSERT INTO 'danceurl' VALUES (6572, 'https://suedan.com/dances/instructions/barrysbirthdaybourrel.html', 10, 21085);
INSERT INTO 'danceurl' VALUES (6573, 'https://suedan.com/dances/instructions/twinkletoes.html', 10, 21086);
INSERT INTO 'danceurl' VALUES (6574, 'https://suedan.com/dances/instructions/justalittlejig.html', 10, 21087);
INSERT INTO 'danceurl' VALUES (6575, 'https://suedan.com/dances/instructions/chainchainchain.html', 10, 21088);
INSERT INTO 'danceurl' VALUES (6576, 'https://suedan.com/dances/instructions/tinklingjade.html', 10, 21090);
INSERT INTO 'danceurl' VALUES (6577, 'https://suedan.com/dances/instructions/canadianroots.html', 10, 21091);
INSERT INTO 'danceurl' VALUES (6578, 'https://suedan.com/dances/instructions/penelope.html', 10, 21092);
INSERT INTO 'danceurl' VALUES (6579, 'https://suedan.com/dances/instructions/cheekychipmunk.html', 10, 21093);
INSERT INTO 'danceurl' VALUES (6580, 'https://suedan.com/dances/instructions/getready.html', 10, 21094);
INSERT INTO 'danceurl' VALUES (6581, 'https://suedan.com/dances/instructions/tunesofglory.html', 10, 21069);
INSERT INTO 'danceurl' VALUES (6582, 'https://suedan.com/dances/instructions/germanfigure.html', 10, 21089);
INSERT INTO 'danceurl' VALUES (6583, 'https://scd.niols.fr/dance/a-wee-journey.pdf', 10, 20990);
INSERT INTO 'danceurl' VALUES (6584, 'https://scd.niols.fr/dance/et-voila.pdf', 10, 21104);
INSERT INTO 'danceurl' VALUES (6585, 'https://scd.niols.fr/dance/in-strathspey-time-george-please.pdf', 10, 21105);
INSERT INTO 'danceurl' VALUES (6586, 'https://scd.niols.fr/dance/spot-on.pdf', 10, 21106);
INSERT INTO 'danceurl' VALUES (6587, 'https://scd.niols.fr/dance/the-terrific-twelve.pdf', 10, 21107);
INSERT INTO 'danceurl' VALUES (6588, 'https://scd.niols.fr/dance/units-2-and-3.pdf', 10, 21108);
INSERT INTO 'danceurl' VALUES (6589, 'https://scd.niols.fr/dance/sunday-early-in-the-morning.pdf', 10, 20996);
INSERT INTO 'danceurl' VALUES (6590, 'http://www.scottishdance.net/dances/Book/AQuakerMeeting.pdf', 10, 11722);
INSERT INTO 'danceurl' VALUES (6591, 'https://tunes.e-cribs.org/wj/All_the_King_s_Horses.pdf', 10, 20929);
INSERT INTO 'danceurl' VALUES (6592, 'https://tunes.e-cribs.org/wj/And_when_it_rains.pdf', 10, 20674);
INSERT INTO 'danceurl' VALUES (6594, 'https://tunes.e-cribs.org/wj/Birders_Hornpipe_The.pdf', 10, 21120);
INSERT INTO 'danceurl' VALUES (6595, 'https://tunes.e-cribs.org/wj/Bitter_Sweet.pdf', 10, 21127);
INSERT INTO 'danceurl' VALUES (6597, 'https://tunes.e-cribs.org/wj/Brandied_Cherries.pdf', 10, 21135);
INSERT INTO 'danceurl' VALUES (6598, 'https://tunes.e-cribs.org/wj/02_02_2020.pdf', 10, 19639);
INSERT INTO 'danceurl' VALUES (6599, 'https://tunes.e-cribs.org/wj/Brave_Ladies.pdf', 10, 21130);
INSERT INTO 'danceurl' VALUES (6600, 'https://tunes.e-cribs.org/wj/By_the_C_Hornpipe.pdf', 10, 21134);
INSERT INTO 'danceurl' VALUES (6601, 'https://my.strathspey.org/dd/dance/21138/', 10, 21138);
INSERT INTO 'danceurl' VALUES (6643, 'https://sprott.physics.wisc.edu/mecds/ScotBook/CascadeReel.html', 10, 21209);
INSERT INTO 'danceurl' VALUES (6602, 'https://tunes.e-cribs.org/wj/Departures.pdf', 10, 21135);
INSERT INTO 'danceurl' VALUES (5343, 'https://tunes.e-cribs.org/wj/Dragons_in_Flight.pdf', 10, 18275);
INSERT INTO 'danceurl' VALUES (6603, 'https://my.strathspey.org/u/murrough/HouseKeysOfLisbon.pdf', 10, 21149);
INSERT INTO 'danceurl' VALUES (6604, 'https://my.strathspey.org/u/murrough/HuttonsUnconformity.pdf', 10, 21150);
INSERT INTO 'danceurl' VALUES (6605, 'https://my.strathspey.org/u/murrough/IncursionOfWeasels.pdf', 10, 21151);
INSERT INTO 'danceurl' VALUES (6606, 'https://drive.google.com/file/d/1rZlBhBfLduGg6vo0qmaLa3Zr6IhsxNam/view', 10, 21153);
INSERT INTO 'danceurl' VALUES (6607, 'https://www.folkverein-chemnitz.de/scd/Chemnitz_Loopings.pdf', 10, 18038);
INSERT INTO 'danceurl' VALUES (6608, 'https://www.rscds-sf.org/newsletters/pdf/2022.11.1.pdf', 10, 21162);
INSERT INTO 'danceurl' VALUES (6609, 'https://www.rscds-sf.org/newsletters/pdf/2021.11.pdf', 10, 21163);
INSERT INTO 'danceurl' VALUES (6610, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=30&token=f7177163c833dff4b38fc8d2872f1ec6#tab30', 10, 21167);
INSERT INTO 'danceurl' VALUES (6611, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=30&token=6c8349cc7260ae62e3b1396831a8398f#tab30', 10, 21169);
INSERT INTO 'danceurl' VALUES (6612, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=30&token=d9d4f495e875a2e075a1a4a6e1b9770f#tab30', 10, 21170);
INSERT INTO 'danceurl' VALUES (6613, 'http://www.minicrib.org.uk/Publications/AlanCottle/ST_ANDREWS''_CASTLE.pdf', 10, 12902);
INSERT INTO 'danceurl' VALUES (6614, 'https://www.rscds.org/sites/default/files/two_new_dances_commemorating_the_stone_mountain_games.pdf', 10, 20956);
INSERT INTO 'danceurl' VALUES (6615, 'https://www.rscds.org/sites/default/files/two_new_dances_commemorating_the_stone_mountain_games.pdf', 10, 21185);
INSERT INTO 'danceurl' VALUES (6616, 'https://www.richmondcaledonian.co.uk/images/8-8.pdf', 10, 21189);
INSERT INTO 'danceurl' VALUES (6617, 'https://my.strathspey.org/u/murrough/SummerSuperstars.pdf', 10, 21191);
INSERT INTO 'danceurl' VALUES (6618, 'https://asdnwordpresscom.files.wordpress.com/2018/02/the-peter-ellis-waltz.pdf', 10, 21196);
INSERT INTO 'danceurl' VALUES (6619, 'https://www.bushtraditions.org/dancefest/images/Peter%20Ellis%20Waltz.pdf', 10, 21196);
INSERT INTO 'danceurl' VALUES (6620, 'https://suedan.com/dances/instructions/offaxis.html', 10, 21197);
INSERT INTO 'danceurl' VALUES (6134, 'https://dances.e-cribs.org/1st_February.pdf', 10, 20141);
INSERT INTO 'danceurl' VALUES (6621, 'https://www.rscdslondon.org.uk/wp-content/uploads/2020/02/Reel-310-electronic.pdf', 10, 20662);
INSERT INTO 'danceurl' VALUES (6622, 'https://web.archive.org/web/20200206060936/http://scottishdance.de/turn-haend.html', 10, 16935);
INSERT INTO 'danceurl' VALUES (6623, 'https://web.archive.org/web/20040205161836/http://anja-roeben.de/YksiKaksiKolme.htm', 10, 9809);
INSERT INTO 'danceurl' VALUES (6624, 'https://web.archive.org/web/20040205161717/http://anja-roeben.de/VerlGirl.htm', 10, 11563);
INSERT INTO 'danceurl' VALUES (6625, 'http://www.rscdsleeds.org.uk/files/Drewry/SCN_0044.jpg', 10, 727);
INSERT INTO 'danceurl' VALUES (6626, 'https://suedan.com/dances/instructions/thanksgivingkindness.html', 10, 21200);
INSERT INTO 'danceurl' VALUES (6627, 'https://suedan.com/dances/instructions/familiestogether.html', 10, 21201);
INSERT INTO 'danceurl' VALUES (6628, 'https://suedan.com/dances/instructions/promen-all.html', 10, 21202);
INSERT INTO 'danceurl' VALUES (6629, 'https://suedan.com/dances/instructions/squirrelinapumpkin.html', 10, 21203);
INSERT INTO 'danceurl' VALUES (6630, 'https://sprott.physics.wisc.edu/mecds/ScotBook/LockandDam.html', 10, 21205);
INSERT INTO 'danceurl' VALUES (6631, 'https://sprott.physics.wisc.edu/mecds/ScotBook/StPatrick.html', 10, 21206);
INSERT INTO 'danceurl' VALUES (6632, 'https://suedan.com/dances/instructions/thelonggoodbye.html', 10, 21204);
INSERT INTO 'danceurl' VALUES (6633, 'https://sprott.physics.wisc.edu/mecds/ScotBook/BricksofMadison.html', 10, 9663);
INSERT INTO 'danceurl' VALUES (6634, 'https://sprott.physics.wisc.edu/mecds/ScotBook/PassingPlace.html', 10, 9909);
INSERT INTO 'danceurl' VALUES (6635, 'https://sprott.physics.wisc.edu/mecds/ScotBook/Squirrel.html', 10, 9832);
INSERT INTO 'danceurl' VALUES (6636, 'https://sprott.physics.wisc.edu/mecds/ScotBook/ConstantCompanions.html', 10, 11511);
INSERT INTO 'danceurl' VALUES (6637, 'https://sprott.physics.wisc.edu/mecds/ScotBook/Janus.html', 10, 9831);
INSERT INTO 'danceurl' VALUES (6638, 'https://sprott.physics.wisc.edu/mecds/ScotBook/DancingRibbons.html', 10, 9830);
INSERT INTO 'danceurl' VALUES (6639, 'https://sprott.physics.wisc.edu/mecds/ScotBook/IanGaylor.html', 10, 8864);
INSERT INTO 'danceurl' VALUES (6640, 'https://sprott.physics.wisc.edu/mecds/ScotBook/RoyalDivorce.html', 10, 12241);
INSERT INTO 'danceurl' VALUES (6641, 'https://sprott.physics.wisc.edu/mecds/ScotBook/NormasFancy.html', 10, 9772);
INSERT INTO 'danceurl' VALUES (6642, 'https://sprott.physics.wisc.edu/mecds/ScotBook/MadisonSquare.html', 10, 9668);
INSERT INTO 'danceurl' VALUES (6644, 'https://sprott.physics.wisc.edu/mecds/ScotBook/KenoraReel.html', 10, 21210);
INSERT INTO 'danceurl' VALUES (6645, 'https://sprott.physics.wisc.edu/mecds/ScotBook/NormasGarden.html', 10, 21211);
INSERT INTO 'danceurl' VALUES (6646, 'https://my.strathspey.org/u/murrough/MusicalChairs.pdf', 10, 21213);
INSERT INTO 'danceurl' VALUES (6647, 'https://dances.e-cribs.org/Broadway.pdf', 10, 13771);
INSERT INTO 'danceurl' VALUES (6648, 'http://www.bstk.hu/dances/111100/', 10, 21215);
INSERT INTO 'danceurl' VALUES (6649, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-033-November-1967.pdf#page=2', 10, 4271);
INSERT INTO 'danceurl' VALUES (6650, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/andromeda.html', 10, 19623);
INSERT INTO 'danceurl' VALUES (6651, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/artillery-port.html', 10, 12754);
INSERT INTO 'danceurl' VALUES (6652, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/baiglieburn.html', 10, 10910);
INSERT INTO 'danceurl' VALUES (6653, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/bannockburn.html', 10, 12007);
INSERT INTO 'danceurl' VALUES (6654, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/bill-jacobs-jig.html', 10, 12747);
INSERT INTO 'danceurl' VALUES (6655, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/braveheart-2.html', 10, 12005);
INSERT INTO 'danceurl' VALUES (6656, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/brides-favourite.html', 10, 790);
INSERT INTO 'danceurl' VALUES (6657, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/candy-floss.html', 10, 12753);
INSERT INTO 'danceurl' VALUES (6658, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/christine-millers-reel.html', 10, 10903);
INSERT INTO 'danceurl' VALUES (6659, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/coldingham-sands.html', 10, 10909);
INSERT INTO 'danceurl' VALUES (6660, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/cuddy-alang.html', 10, 12757);
INSERT INTO 'danceurl' VALUES (6661, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/dance-of-the-red-moon.html', 10, 12755);
INSERT INTO 'danceurl' VALUES (6662, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/dianne-murdochs-promenade.html', 10, 10880);
INSERT INTO 'danceurl' VALUES (6663, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/eyemouth-harbour-reel.html', 10, 10908);
INSERT INTO 'danceurl' VALUES (6664, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/fairfield-bridge.html', 10, 10883);
INSERT INTO 'danceurl' VALUES (6665, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/farewell-to-hugh.html', 10, 20203);
INSERT INTO 'danceurl' VALUES (6666, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/glenys-pearces-strathspey.html', 10, 12749);
INSERT INTO 'danceurl' VALUES (6667, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/howard-mcnallys-favourite.html', 10, 10906);
INSERT INTO 'danceurl' VALUES (6668, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/jennifer-mcfarlanes-wedding.html', 10, 19577);
INSERT INTO 'danceurl' VALUES (6669, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/kerfuffle.html', 10, 20234);
INSERT INTO 'danceurl' VALUES (6670, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/lochiel-strathspey.html', 10, 10905);
INSERT INTO 'danceurl' VALUES (6671, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/lochiels-farewell-to-tony-szeto.html', 10, 12750);
INSERT INTO 'danceurl' VALUES (6672, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/may-johnstons-reel.html', 10, 10881);
INSERT INTO 'danceurl' VALUES (6673, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/milky-way.html', 10, 20001);
INSERT INTO 'danceurl' VALUES (6674, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/miss-mary-grays-fancy.html', 10, 12751);
INSERT INTO 'danceurl' VALUES (6675, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/mrs-nona-craig.html', 10, 10882);
INSERT INTO 'danceurl' VALUES (6676, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/new-plymouth-strathspey.html', 10, 12756);
INSERT INTO 'danceurl' VALUES (6677, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/nina-foulkes-reel.html', 10, 10884);
INSERT INTO 'danceurl' VALUES (6678, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/odd-couple.html', 10, 12758);
INSERT INTO 'danceurl' VALUES (6679, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/olivers-fifth.html', 10, 10904);
INSERT INTO 'danceurl' VALUES (6680, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/robert-the-bruce.html', 10, 12004);
INSERT INTO 'danceurl' VALUES (6681, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/rose-jacobs-reel.html', 10, 11703);
INSERT INTO 'danceurl' VALUES (6682, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/simon-barbours-rant.html', 10, 12752);
INSERT INTO 'danceurl' VALUES (6683, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/st-abbs-head-reel.html', 10, 10907);
INSERT INTO 'danceurl' VALUES (6684, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/stirling-castle-2.html', 10, 12006);
INSERT INTO 'danceurl' VALUES (6685, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/wedding-ring-2.html', 10, 12748);
INSERT INTO 'danceurl' VALUES (6686, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/win-thompsons-chase.html', 10, 10879);
INSERT INTO 'danceurl' VALUES (6687, 'https://dances.e-cribs.org/The_Jacaranda_Tree.pdf', 10, 3174);
INSERT INTO 'danceurl' VALUES (6688, 'https://archive.rscds.org/uploads/r/royal-scottish-country-dance-society-archive/f/e/8/fe80dd07aec191b2b01ae284dd85dd8c5ab42431bbdd92de1faeee0cc340f874/877-001opt.pdf', 10, 21228);
INSERT INTO 'danceurl' VALUES (6689, 'https://archive.rscds.org/uploads/r/royal-scottish-country-dance-society-archive/f/e/8/fe80dd07aec191b2b01ae284dd85dd8c5ab42431bbdd92de1faeee0cc340f874/877-001opt.pdf', 10, 21229);
INSERT INTO 'danceurl' VALUES (6690, 'https://archive.rscds.org/uploads/r/royal-scottish-country-dance-society-archive/f/e/8/fe80dd07aec191b2b01ae284dd85dd8c5ab42431bbdd92de1faeee0cc340f874/877-001opt.pdf', 10, 21230);
INSERT INTO 'danceurl' VALUES (6691, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/thelmas-jig.html', 10, 21278);
INSERT INTO 'danceurl' VALUES (6692, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/T02-Bronach.pdf', 10, 21281);
INSERT INTO 'danceurl' VALUES (6693, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/T01-Bonnie-Prince-Charlie.pdf', 10, 21280);
INSERT INTO 'danceurl' VALUES (6694, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/T03-The-Cameronian-Rant.pdf', 10, 21282);
INSERT INTO 'danceurl' VALUES (6695, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/05/T04-The-Dirk-Dance.pdf', 10, 21283);
INSERT INTO 'danceurl' VALUES (6696, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/T05-Double-Sword-Dance.pdf', 10, 21284);
INSERT INTO 'danceurl' VALUES (6697, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/T06-Flowers-of-Edinburgh.pdf', 10, 14303);
INSERT INTO 'danceurl' VALUES (6698, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/T07-The-Glengarry-Waltz.pdf', 10, 21285);
INSERT INTO 'danceurl' VALUES (6699, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/T08-Lewis-Bridal-Dance.pdf', 10, 21286);
INSERT INTO 'danceurl' VALUES (6700, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/T10-The-Meeting-of-the-Waters.pdf', 10, 21287);
INSERT INTO 'danceurl' VALUES (6701, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/T11-The-Portree-Lassies.pdf', 10, 21288);
INSERT INTO 'danceurl' VALUES (6702, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/T12-The-Sailors-Knot.pdf', 10, 21289);
INSERT INTO 'danceurl' VALUES (6703, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/T13-The-Sword-Dance-of-Culloden.pdf', 10, 21290);
INSERT INTO 'danceurl' VALUES (6704, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/T14-Waltz-Cotillion.pdf', 10, 21291);
INSERT INTO 'danceurl' VALUES (6705, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/T15-A-Weaving-Lilt.pdf', 10, 21292);
INSERT INTO 'danceurl' VALUES (6706, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/T16-Whirlygig.pdf', 10, 21293);
INSERT INTO 'danceurl' VALUES (6707, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/L02-The-Caller-Herrin.pdf', 10, 21294);
INSERT INTO 'danceurl' VALUES (6708, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/L09-A-Salute-to-Mac-Nab.pdf', 10, 21295);
INSERT INTO 'danceurl' VALUES (6709, 'http://www.matsmelin.com/wp-content/uploads/2011/05/Shapinsay-Polka.pdf', 10, 21296);
INSERT INTO 'danceurl' VALUES (6710, 'http://www.matsmelin.com/wp-content/uploads/2011/05/Queen-Mary-Two-Step.pdf', 10, 21297);
INSERT INTO 'danceurl' VALUES (6711, 'https://www.matsmelin.com/wp-content/uploads/2019/09/Loch-Aineort-Two-Step_Melin_2019.pdf', 10, 21299);
INSERT INTO 'danceurl' VALUES (6712, 'http://keith-wood.name/myDancesScottish.html#TheCurseOfScotland', 10, 21305);
INSERT INTO 'danceurl' VALUES (6713, 'http://keith-wood.name/myDancesScottish.html#FunfBavarianFive', 10, 21306);
INSERT INTO 'danceurl' VALUES (6714, 'http://keith-wood.name/myDancesScottish.html#GoldenPinwheels', 10, 21307);
INSERT INTO 'danceurl' VALUES (6715, 'http://keith-wood.name/myDancesScottish.html#IsleOfSkye', 10, 21308);
INSERT INTO 'danceurl' VALUES (6716, 'http://keith-wood.name/myDancesScottish.html#Joyous', 10, 21309);
INSERT INTO 'danceurl' VALUES (6717, 'http://keith-wood.name/myDancesScottish.html#Reunions', 10, 21310);
INSERT INTO 'danceurl' VALUES (6718, 'http://keith-wood.name/myDancesScottish.html#StAndrewsCross', 10, 21311);
INSERT INTO 'danceurl' VALUES (6719, 'http://keith-wood.name/myDancesScottish.html#AllTheRiversRun', 10, 21301);
INSERT INTO 'danceurl' VALUES (6720, 'http://keith-wood.name/myDancesScottish.html#AroundTheRuggedRock', 10, 21302);
INSERT INTO 'danceurl' VALUES (6721, 'http://keith-wood.name/myDancesScottish.html#AwayToWoodford', 10, 21303);
INSERT INTO 'danceurl' VALUES (6722, 'http://keith-wood.name/myDancesScottish.html#Claddagh', 10, 21304);
INSERT INTO 'danceurl' VALUES (6723, 'http://www.scottishdance.net/dances/Book/BruntsfieldMondays.pdf', 10, 18110);
INSERT INTO 'danceurl' VALUES (6724, 'http://www.scottishdance.net/dances/Book/CherryBlossom.pdf', 10, 8926);
INSERT INTO 'danceurl' VALUES (6725, 'http://www.scottishdance.net/dances/Book/HolyCorner.pdf', 10, 18112);
INSERT INTO 'danceurl' VALUES (4284, 'https://8x32.e-cribs.org/index.php/a/inside-oot-fish-eater', 20, 11365);
INSERT INTO 'danceurl' VALUES (6726, 'http://www.scottishdance.net/dances/Book/TheInsideOotFishEater.pdf', 10, 11365);
INSERT INTO 'danceurl' VALUES (6727, 'http://www.scottishdance.net/dances/Book/InvitedGuests.pdf', 10, 18113);
INSERT INTO 'danceurl' VALUES (6728, 'http://www.scottishdance.net/dances/Book/MorinoVII.pdf', 10, 18115);
INSERT INTO 'danceurl' VALUES (6729, 'http://www.scottishdance.net/dances/Book/NewScotlandGold.pdf', 10, 18116);
INSERT INTO 'danceurl' VALUES (6730, 'http://www.scottishdance.net/dances/Book/PuffinJohn.pdf', 10, 21156);
INSERT INTO 'danceurl' VALUES (6731, 'http://www.scottishdance.net/dances/Book/AQuakerMixup.pdf', 10, 11723);
INSERT INTO 'danceurl' VALUES (6732, 'http://www.scottishdance.net/dances/Kaleidoscope.pdf', 10, 18114);
INSERT INTO 'danceurl' VALUES (6733, 'http://www.scottishdance.net/dances/Book/SkagitsInStockbridge.pdf', 10, 11267);
INSERT INTO 'danceurl' VALUES (6734, 'http://www.scottishdance.net/dances/Book/ACanonbieCeilidh.pdf', 10, 8104);
INSERT INTO 'danceurl' VALUES (6735, 'http://www.scottishdance.net/dances/Book/SaltAndSauce.pdf', 10, 18111);
INSERT INTO 'danceurl' VALUES (6736, 'https://www.scottish-country-dancing-dictionary.com/dance-crib/pat-houghtons-reel.htm', 10, 18367);
INSERT INTO 'danceurl' VALUES (6737, 'https://my.strathspey.org/u/murrough/DAndDSideCaledonians.pdf', 10, 21336);
INSERT INTO 'danceurl' VALUES (6738, 'https://www.scottishcountrydanceoftheday.com/daysoftheyear/maxwell''s-waves', 10, 19326);
INSERT INTO 'danceurl' VALUES (6739, 'https://rscdschicago.org/class-notes/1090-2/?fbclid=IwAR3odCXf2KUjSBZE_U9E7rkzIr_IhQ_c6ZYOfpne4rguNr0J2t6pj0QhmSE', 10, 21341);
INSERT INTO 'danceurl' VALUES (6740, 'https://craigellachie-band.co.uk/teacher-resources/new-dances-resource-catherine/', 10, 21350);
INSERT INTO 'danceurl' VALUES (6741, 'https://craigellachie-band.co.uk/teacher-resources/new-dances-resource-the-borrower/', 10, 18264);
INSERT INTO 'danceurl' VALUES (6742, 'https://craigellachie-band.co.uk/teacher-resources/golden-hill-fort/', 10, 21349);
INSERT INTO 'danceurl' VALUES (6743, 'https://craigellachie-band.co.uk/teacher-resources/new-dances-resource-lochinver/', 11, 19604);


--
INSERT INTO 'dancevideo' VALUES (4758, '2019-04-14 20:55:06.523572+00', '2019-04-14 22:06:04.102451+00', 1582, 9, 106, '', 'D', 'Very informal, very active, young and inspiring. 



Last dance of the evening :-) Recorded on the Saturday night during the RSCDS Lyon Spring WE 2019, 14th april 2019.', 1, 1, 'Y', 'SM9GHKQBI1Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4759, '2019-04-16 23:49:31.59468+00', '2019-04-16 23:50:23.223393+00', 14243, 2, 106, '', 'B', 'RSCDS Toronto January 2019', 1, 1, 'Y', 'rNOnonnJOsM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4760, '2019-04-16 23:57:34.951641+00', '2019-04-17 00:00:47.358215+00', 2498, 5, 106, '', 'D', 'RSCDS Toronto January 2019', 1, 1, 'Y', 'LOFf0xEc7QM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3841, '2018-10-01 22:07:52.745388+00', '2019-04-17 00:01:08.826267+00', 2498, 4, 1296, '', 'X', '"The Glasgow Highlanders" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'dSQBJrYtEYU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3397, '2018-01-18 20:59:54.160434+00', '2019-04-17 08:40:58.301999+00', 5207, 4, 954, '', 'A', '', 1, 1, 'Y', 'A-w64iobA9c', 0, 254, NULL);
INSERT INTO 'dancevideo' VALUES (4761, '2019-04-17 01:34:35.507326+00', '2019-04-17 08:43:20.646483+00', 4995, 1, 940, '', 'A', '', 1, 1, 'Y', 'A-w64iobA9c', 252, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4764, '2019-04-20 21:57:07.995033+00', '2019-04-22 08:43:26.114253+00', 9138, 1, 1645, '', 'B', '', 1, 1, 'Y', 'R4fet98oN-k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4769, '2019-04-20 22:42:58.066585+00', '2019-04-22 08:44:22.198524+00', 15022, 1, 1645, '', 'B', '', 1, 1, 'Y', 'eaQftXjzOq0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4762, '2019-04-20 21:43:10.665432+00', '2019-04-22 08:46:22.728701+00', 7375, 3, 1645, '', 'B', '', 1, 1, 'Y', 'be1EtBwdzXw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4766, '2019-04-20 22:21:59.242847+00', '2019-04-22 08:48:09.75106+00', 1465, 2, 1645, '', 'B', 'Generally good with one or two minor glitches, eg transition into reels at the start of the 3rd repeat.', 1, 1, 'Y', 'Zg5SqyFCjDc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4767, '2019-04-20 22:26:49.980767+00', '2019-04-22 08:49:15.188623+00', 17889, 1, 1645, '', 'B', '', 1, 1, 'Y', 'vGTYLYnhtzI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4763, '2019-04-20 21:51:13.132465+00', '2019-04-22 08:50:19.856733+00', 3033, 2, 1645, '', 'B', '', 1, 1, 'Y', 'kYNesW1yDqk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4770, '2019-04-20 22:49:48.251639+00', '2019-04-22 08:51:36.267743+00', 17151, 1, 1645, '', 'B', '', 1, 1, 'Y', 'CH03FQmO5O0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4768, '2019-04-20 22:35:48.143645+00', '2019-04-22 08:53:22.918361+00', 10684, 3, 1645, '', 'B', '', 1, 1, 'Y', 'JTfbmbN4hQc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4765, '2019-04-20 22:05:01.943635+00', '2019-04-22 08:54:15.276846+00', 7019, 2, 1645, '', 'B', '', 1, 1, 'Y', 'djqwZwjh4VA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4771, '2019-04-27 23:39:52.43925+00', '2019-04-28 08:59:11.445843+00', 19177, 1, 513, '', 'B', '', 1, 1, 'Y', 'XV4bJtkVJEs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4773, '2019-05-02 08:52:05.788012+00', '2019-05-02 08:52:20.675491+00', 9478, 1, 1645, '', 'D', 'From an animal themed party.', 1, 1, 'Y', 'j5TG2iKH48A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4774, '2019-05-02 16:47:43.514181+00', '2019-05-02 20:06:26.780808+00', 18272, 4, 1580, '', 'A', '', 1, 1, 'Y', 'qQ-Kfh3HaCg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4775, '2019-05-02 18:32:00.87709+00', '2019-05-02 20:10:33.549501+00', 3589, 1, 3277, '', 'A', '', 1, 1, 'Y', 'o7RDjnLvy1g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4772, '2019-05-01 23:24:31.839283+00', '2019-05-02 20:12:03.189454+00', 1834, 1, 106, '', 'C', 'This video shows a variant of the Dundee Reel as described in the Border Book.  The "RHA" of bars 9-12 is replaced by 6 hands round to the L, and "Lead down and up" in [17-24] is replced by "slip down and up".  Also most of the steps are closer to walking.', 1, 1, 'Y', 'q_V1TBaBHZ0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4776, '2019-05-02 18:33:57.331621+00', '2019-05-02 20:24:44.58335+00', 4511, 4, 3277, '', 'A', '', 1, 1, 'Y', 'K5P1aqX0s7M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4778, '2019-05-03 12:34:33.606102+00', '2019-05-03 12:34:33.606102+00', 19272, 1, 2254, 'dd/dance/video/upload/DAVIDs-Warm_Welcome-20190502-WA0000.mp4', 'C', 'This is a demonstration by members of Bracknell Reel Club of which David was a member.', 0, 0, 'I', '', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4777, '2019-05-03 08:40:43.957166+00', '2019-05-03 18:50:41.081867+00', 10872, 1, 1645, '', 'B', 'The best repeat from an almost complete video whose other repeats have a few mishaps here and there.', 1, 1, 'Y', 'Oh2xV7K9Sfc', 81, 115, NULL);
INSERT INTO 'dancevideo' VALUES (4779, '2019-05-03 22:56:49.496448+00', '2019-05-04 06:39:31.629992+00', 19272, 2, 2254, '', 'C', 'This is a demonstration by members of Bracknell Reel Club of which David was a member.', 1, 1, 'Y', 'O8mcLZgtXmc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4780, '2019-05-04 06:38:53.177236+00', '2019-05-04 06:39:59.06122+00', 6152, 5, 202, '', 'C', '', 1, 1, 'Y', 'aQkTik4oZvA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4783, '2019-05-04 15:41:14.381194+00', '2019-05-04 20:57:50.053263+00', 8809, 1, 513, '', 'C', 'Danced just 4 times through, once to the bottom.', 1, 1, 'Y', '2g-VNP14ShM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4782, '2019-05-04 13:18:38.204101+00', '2019-05-04 21:00:24.034577+00', 10887, 1, 27683, '', 'B', 'NB: although the dance was originally devised for 2C in a 4C set, here it is performed in a 2C set, so after the first time through there is a new top couple for the second time through (with the former top couple dancing as the second one).

The musicality of some dancers should be improved, and one should pay attention to completing the steps at the end, but the video gives good impression of the dance choreography and the transitions between the formations and steps.', 1, 1, 'Y', 'V5f8gKApUE4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4781, '2019-05-04 10:04:43.06516+00', '2019-05-04 21:09:33.494681+00', 7124, 3, 274, '', 'B', 'Budapest, 2019,  4x', 1, 1, 'Y', 'Na_QSd8g9ak', 8, 162, NULL);
INSERT INTO 'dancevideo' VALUES (4785, '2019-05-06 06:48:30.701174+00', '2019-05-06 19:25:39.638898+00', 8152, 1, 961, '', 'D', '', 1, 1, 'Y', 'ugtunsx40BI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4784, '2019-05-06 06:25:58.752564+00', '2019-05-06 19:26:08.146744+00', 12071, 1, 961, '', 'D', 'Music changes from traditional to pop (e.g. 500 miles) halfway through.', 1, 1, 'Y', 'TmTO0wUO-IM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4786, '2019-05-07 21:54:43.82903+00', '2019-05-07 22:41:46.500774+00', 6010, 4, 2586, '', 'B', '', 1, 1, 'Y', 'MFJwXcYL_9k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4788, '2019-05-10 12:05:24.128244+00', '2019-05-10 17:47:43.207163+00', 11375, 3, 2847, '', 'A', '', 1, 1, 'Y', 'YT12tp27yAg', 283, 430, NULL);
INSERT INTO 'dancevideo' VALUES (4787, '2019-05-10 11:59:05.13517+00', '2019-05-10 17:51:51.690769+00', 5734, 2, 2847, '', 'A', '', 1, 1, 'Y', '_SFWgUfd5WA', 12, 165, NULL);
INSERT INTO 'dancevideo' VALUES (4789, '2019-05-11 13:42:24.730848+00', '2019-05-12 10:19:47.498764+00', 17024, 1, 1645, '', 'B', 'The first repeat has a wrong shoulder pass between the two "teapots".', 1, 1, 'Y', 'E6FqxtdJI70', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4792, '2019-05-12 07:37:32.896665+00', '2019-05-12 10:25:56.611374+00', 5667, 4, 2821, '', 'A', 'Rose of Glamis [2x(32S/32R)], performed by Nottingham RSCDS at the ASCDS Festival on 11 May 2019

', 1, 1, 'Y', 'rKwCTwAMXe0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4790, '2019-05-11 23:16:39.556811+00', '2019-05-12 10:27:07.176809+00', 19309, 1, 1645, '', 'C', '', 1, 1, 'Y', 'wl94Yb8KBug', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4795, '2019-05-13 23:31:37.980506+00', '2019-05-13 23:32:05.803426+00', 7239, 2, 106, '', 'C', 'Ruhrball, 30 Jan 2018', 1, 1, 'Y', 'gzDxewNIgL8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4793, '2019-05-12 11:15:11.681315+00', '2019-05-13 10:16:38.165257+00', 18226, 1, 1645, '', 'C', 'Starts well with a few recovered mishaps towards the end.', 1, 1, 'Y', 'pHP-B5t4H1I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4791, '2019-05-12 07:32:35.246932+00', '2019-05-13 22:40:59.899104+00', 2170, 1, 2821, '', 'A', 'Findhorn Medley (32J/32S/32R), performed by the Waltham Scottish Country Dance Group at the ASCDS Festival on 11 May 2019



NB the last 8 bars of the reel section in this performance differs from the version of the dance summarised in the MiniCrib (which follows the original instructions). See the Extra info for the dance for the details.', 1, 1, 'Y', 'gEY6QNUjkVc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4803, '2019-05-16 20:16:41.080151+00', '2019-05-17 09:14:14.186084+00', 4293, 2, 274, '', 'A', 'First part of a longer demonstration (from an old video). The ending of the second repeat is adapted to lead into the next dance.', 1, 1, 'Y', 'NrhtBxJtgw0', 24, 79, NULL);
INSERT INTO 'dancevideo' VALUES (4799, '2019-05-16 19:32:18.981891+00', '2019-05-17 16:45:51.558226+00', 19063, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'JNmOWemYxcw', 0, 158, NULL);
INSERT INTO 'dancevideo' VALUES (4797, '2019-05-16 19:14:21.146577+00', '2019-05-17 16:49:13.164702+00', 19084, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'fomk1LAGYag', 0, 132, NULL);
INSERT INTO 'dancevideo' VALUES (4798, '2019-05-16 19:19:53.922355+00', '2019-05-17 16:51:34.415116+00', 19076, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'BwfBo5qk36Q', 0, 72, NULL);
INSERT INTO 'dancevideo' VALUES (4796, '2019-05-16 19:09:15.293067+00', '2019-05-17 16:54:20.19165+00', 19082, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'vuBY2ygS4ds', 0, 72, NULL);
INSERT INTO 'dancevideo' VALUES (4801, '2019-05-16 19:40:47.058694+00', '2019-05-17 16:55:25.133307+00', 19061, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'qMiiKwZofvM', 0, 134, NULL);
INSERT INTO 'dancevideo' VALUES (4800, '2019-05-16 19:35:54.377136+00', '2019-05-17 16:56:12.09296+00', 19062, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'cs3qQvUMMpA', 0, 72, NULL);
INSERT INTO 'dancevideo' VALUES (4804, '2019-05-17 11:12:03.171529+00', '2019-05-17 16:50:38.624587+00', 19077, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'Bc-ybNSTVdE', 0, 135, NULL);
INSERT INTO 'dancevideo' VALUES (4822, '2019-06-04 18:24:52.984306+00', '2019-06-04 18:49:51.109534+00', 19361, 1, 1645, '', 'B', 'This is a three couple version of an originally five couple dance (<<ddd:DAVID>>) fading out the recording after three times through...', 1, 1, 'Y', '-y9nBD0wjz8', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4807, '2019-05-17 11:38:53.016952+00', '2019-05-17 16:47:09.539702+00', 19079, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'j3znAWttOCc', 0, 130, NULL);
INSERT INTO 'dancevideo' VALUES (4806, '2019-05-17 11:32:38.547234+00', '2019-05-17 16:52:27.649676+00', 19078, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'zc2hsaiAaxY', 0, 72, NULL);
INSERT INTO 'dancevideo' VALUES (4809, '2019-05-19 13:59:27.022886+00', '2019-05-19 17:44:37.937904+00', 13638, 1, 274, '', 'C', 'Budapest Scottish Dance Club - Siófok 2019

', 1, 1, 'Y', 'bqqENqgidVE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4808, '2019-05-19 01:41:37.089133+00', '2019-05-19 17:54:07.664481+00', 6535, 2, 2609, '', 'C', 'Some lines are a little late in coming in and some dancers lose their place but danced with good teamwork (and mostly energy and flight) and gets better as the dancers relax. Videoed from excellent angle in good lighting but closest side of the set is partly out of frame. NZ Summer School Hogmanay 2015/16, band: Reel of Seven.', 1, 1, 'Y', 'yTQPhKt9AaU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2275, '2015-11-28 22:11:23.665095+00', '2019-05-21 18:36:30.584003+00', 245, 1, 160, '', 'A', 'The demonstration team here turn right hands on bars 31-32 instead of petronella. The extra info for the <<ddd:Arthur''s Seat|dance>> has links to discussions on this issue.', 1, 1, 'Y', 'tfQZ3CfJLmk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4812, '2019-05-21 18:13:20.697975+00', '2019-05-21 18:37:51.888643+00', 245, 2, 1645, '', 'B', 'Lively performance at a youth ball which starts very well with some extra decorations and a few problems in the later repeats.', 1, 1, 'Y', 'MXw8shaPne8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4813, '2019-05-22 15:13:30.269167+00', '2019-05-22 22:22:49.059197+00', 13787, 1, 274, '', 'B', 'Budapest Scottish Dance Club; Siófok, 2019', 1, 1, 'Y', '2u4X8C_r9QA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4810, '2019-05-20 14:46:38.356058+00', '2019-05-23 20:39:43.541446+00', 9425, 1, 2220, '', 'C', 'This is the most brilliant dance I know and when it turned out that several people at Pinewoods 2017 had not done it we took over a pavilion and did it (twice through).  The recording is of the original tunes by Janet Kurnick performed by Patti Cobb and James MacQueen.', 1, 1, 'Y', 'uZBHS4YNpwc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4814, '2019-05-24 08:58:59.608809+00', '2019-05-24 20:40:45.117367+00', 14469, 1, 1645, '', 'C', '', 1, 1, 'Y', 'D_GxVVNiSUg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4815, '2019-05-24 21:03:51.223767+00', '2019-05-24 21:36:00.986725+00', 19358, 1, 1645, '', 'B', 'Just once through in a three couple set.', 1, 1, 'Y', 'kvyXt08pnfs', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4816, '2019-05-24 21:10:03.071771+00', '2019-05-24 21:37:30.087776+00', 19356, 1, 1645, '', 'B', '', 1, 1, 'Y', 'mC3SdJwjh3o', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4817, '2019-05-24 21:31:16.759118+00', '2019-05-24 21:38:42.95706+00', 19310, 1, 1645, '', 'B', '', 1, 1, 'Y', 'hSWMdaL64JU', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4818, '2019-05-24 21:35:33.201864+00', '2019-05-24 21:39:57.191355+00', 19357, 1, 1645, '', 'B', '', 1, 1, 'Y', 'OCkG7k7FeR8', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4819, '2019-05-30 22:18:36.946789+00', '2019-05-31 13:41:41.340353+00', 280, 3, 3086, '', 'A', '', 1, 1, 'Y', 'F4U7k8I3F1M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4088, '2018-11-01 19:54:18.802664+00', '2019-06-01 15:40:50.976977+00', 16526, 2, 2824, '', 'C', 'Some good dancing but also many mishaps. According to the deviser''s full instructions, hands should not been joined during the reels.', 1, 1, 'Y', 'A6qamrR1K_s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4820, '2019-06-03 08:24:43.204644+00', '2019-06-04 14:29:21.809751+00', 9087, 3, 513, '', 'C', '', 1, 1, 'Y', 'NDkz2uQo5fs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4821, '2019-06-03 09:42:43.266887+00', '2019-06-04 14:33:30.931656+00', 6798, 3, 513, '', 'C', '', 1, 1, 'Y', '-5qbL_ShP_g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4823, '2019-06-04 21:51:55.302336+00', '2019-06-04 22:09:06.076096+00', 335, 1, 1645, '', 'B', 'Part of a demonstration medley. Twice through in two back to back 2-couple sets.', 1, 1, 'Y', 'oxwXlXegR4c', 100, 168, NULL);
INSERT INTO 'dancevideo' VALUES (4830, '2019-06-08 00:40:03.933679+00', '2019-06-08 00:40:03.933679+00', 17896, 4, 1296, '', 'X', '''And For the Young Ones'' is a 32 bar jig for 4 couples.', 1, 1, 'Y', 'bUXGOALGi_U', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4824, '2019-06-04 23:27:17.005286+00', '2019-06-05 07:17:33.044785+00', 19378, 1, 274, '', 'A', 'Farewell Ceilidh, Budapest, 2015.



An exuberant performance of a dance with unusual phrasing inspired by music from Pirates of the Caribbean. The dancing starts around 1:30 into the video after a little introductory pirate drama. The deviser and his wife start as 1st couple (though there are substitutions of couples each repeat during the performance).', 1, 1, 'Y', '0_3-dV56y3g', 66, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4825, '2019-06-05 13:59:57.442034+00', '2019-06-05 22:10:40.571699+00', 15646, 2, 513, '', 'C', '', 1, 1, 'Y', 'p_ufKxUMcis', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4826, '2019-06-05 14:05:17.787019+00', '2019-06-05 22:17:59.962358+00', 15644, 3, 513, '', 'C', 'Video starts about four bars into the dance (missing 1c & 3c advance and retire).

', 1, 1, 'Y', 'ylKdEAQaAB8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4827, '2019-06-05 14:08:54.973767+00', '2019-06-06 22:52:15.235043+00', 15038, 1, 513, '', 'C', '', 1, 1, 'Y', 'zSah0Q8Qvsk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4832, '2019-06-08 00:40:03.995204+00', '2019-06-08 00:40:03.995204+00', 1777, 4, 1296, '', 'X', '''The Duchess Tree'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'OYhaUUyTJrg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4829, '2019-06-06 23:41:13.545635+00', '2019-06-07 18:31:58.990294+00', 19393, 1, 1645, '', 'A', 'The video starts at bar 2. NB the title of the dance on the video differs from the final one.', 1, 1, 'Y', 'Lkz3bRtQaZI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4834, '2019-06-08 00:40:04.061939+00', '2019-06-08 00:40:04.061939+00', 5860, 10, 1296, '', 'X', '''The Saltire Society Reel'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'yBHAnVd61jY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4836, '2019-06-09 11:38:50.500039+00', '2019-06-09 14:26:39.634425+00', 8956, 3, 1645, '', 'C', '', 1, 1, 'Y', 'eG6h5Rhf5qA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4835, '2019-06-08 13:46:19.685518+00', '2019-06-08 13:49:11.332964+00', 3580, 6, 1645, '', 'B', 'Twice through demonstration with two back to back three couple sets (1st couples in the centre).', 1, 1, 'Y', 'Q4u1YSdy76k', 11, 82, NULL);
INSERT INTO 'dancevideo' VALUES (4838, '2019-06-09 11:50:54.54463+00', '2019-06-09 14:25:55.470462+00', 8956, 5, 1645, '', 'B', 'Very good dancing, but constant cutting between different views makes it harder to follow the dance.', 1, 1, 'Y', 'TZwoEzWZ0Rk', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4837, '2019-06-09 11:43:36.333759+00', '2019-06-09 14:30:01.350486+00', 8956, 4, 1645, '', 'B', 'Starts four bars into the dance. A clear view, though some hesitations and confusions build up towards the end and constant clapping is a bit distracting.', 1, 1, 'Y', '8u8c3SJsQqM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4839, '2019-06-09 11:59:18.122542+00', '2019-06-09 14:33:26.197189+00', 8956, 6, 1645, '', 'B', 'Good view of demonstration quality dancing though to rather unorthodox music.', 1, 1, 'Y', 'logowphzvaQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4191, '2018-12-23 12:34:15.997809+00', '2019-06-09 21:48:24.791812+00', 19126, 1, 1645, '', 'B', 'Choreographically fine but 3rd & 2nd women should dance towards each other to face in and then turn away at the end of bar 4 (a reflected pattern). In the first repeat 2nd woman (white top) does this and in the 2nd repeat the new 3rd woman (dark blue top) also does this as intended.', 1, 1, 'Y', '1o4DQNgel1A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4840, '2019-06-09 23:20:30.61292+00', '2019-06-09 23:41:27.319286+00', 19393, 2, 4804, '', 'C', 'The video starts at bar 2



NB: The dancers here make a left shoulder pass on bar 28 while they should have passed right shoulder (last bar of the reels, middle positions)

', 1, 1, 'Y', 'j9Q2dXTBWEI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4841, '2019-06-10 19:58:17.648123+00', '2019-06-10 21:03:13.380937+00', 19273, 1, 81, '', 'D', 'Once through only.  ', 1, 1, 'Y', '5oe-XkvFpZ4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4833, '2019-06-08 00:40:04.020108+00', '2019-06-11 00:40:03.542124+00', 4784, 3, 1296, '', 'Z', '''Mrs Macpherson of Inveran'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', '_6ICH_svKpw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (629, '2012-12-17 14:18:59.080808+00', '2019-06-10 22:53:17.53548+00', 4803, 2, 1296, '', 'A', 'RSCDS Edinburgh - Firth Team win the Mixed Section at the Newcastle Festival with the Reel, "Mrs Stewart of Fasnacloich" [R8x32 - RSCDS Leaflet Book]. Music played by Andrew Nolan', 1, 1, 'Y', 'DtJXZT-2wa4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4842, '2019-06-11 00:40:03.554455+00', '2019-06-11 00:40:03.554455+00', 4784, 4, 1296, '', 'X', '''Mrs Macpherson of Inveran'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'TYadPH7Os7w', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4831, '2019-06-08 00:40:03.970158+00', '2019-06-11 00:40:03.59667+00', 1544, 5, 1296, '', 'Z', '''The Dancing Master'' is a 96 bar jig for 4 couples.', 1, 1, 'Y', 'uzJNo_sl9ws', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4843, '2019-06-11 00:40:03.614595+00', '2019-06-11 00:40:03.614595+00', 1544, 6, 1296, '', 'X', '''The Dancing Master'' is a 96 bar jig for 4 couples.', 1, 1, 'Y', 'ZRWmXpCyypk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4844, '2019-06-11 12:02:34.579034+00', '2019-06-11 20:20:46.84182+00', 17957, 2, 513, '', 'C', 'Video starts at bar 5. There are a few problems at the start of the next repeat. The adjoining set, seen on the 3rd repeat starting at 1:17 is the best.', 1, 1, 'Y', 'YLmvvqX8s4U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4846, '2019-06-12 08:06:46.03068+00', '2019-06-12 19:43:48.244718+00', 16526, 3, 513, '', 'C', '', 1, 1, 'Y', 'PUnxqLRdiZ0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4848, '2019-06-15 19:38:48.689276+00', '2019-06-16 09:14:52.634048+00', 17268, 1, 1645, '', 'C', '', 1, 1, 'Y', '-Eh5rNsNbZI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4851, '2019-06-15 21:01:08.939462+00', '2019-06-16 09:16:10.919826+00', 3119, 5, 1645, '', 'C', 'This decorative video starts about 1 bar into the dance with lots of extra claps & twirls and the common substitution of a chase instead of a circle at the end.', 1, 1, 'Y', 'hgKR27j3-_s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4847, '2019-06-15 19:35:00.871141+00', '2019-06-16 09:17:27.637516+00', 8674, 1, 1645, '', 'C', 'The video starts about 2 bars into the dance.', 1, 1, 'Y', 'uY5P_4L_z4c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4811, '2019-05-21 09:43:52.422362+00', '2021-01-31 11:33:51.432998+00', 2801, 1, 28165, '', 'B', '', 1, 1, 'Y', 'yl_RiTjBibw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4864, '2019-07-01 08:54:32.761575+00', '2019-07-01 21:54:57.827253+00', 13574, 1, 513, '', 'C', 'There is a little confusion going into the reels in the final square set sequence.', 1, 1, 'Y', 'dGcxj4KTRoQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4850, '2019-06-15 20:46:40.704839+00', '2019-06-16 09:20:41.956435+00', 9170, 1, 1645, '', 'C', 'Several of the repeats have a little confusion at the start of the hands across.', 1, 1, 'Y', 'fhrMx0DcFBk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4849, '2019-06-15 19:49:06.466963+00', '2019-06-16 20:23:26.204788+00', 18353, 1, 1645, '', 'B', 'Generally good dancing - though here all dancers clap and turn RH in bars 21-24 whereas the instructions have only 1st couple turning.', 1, 1, 'Y', 'Pm17CCFNasw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2434, '2016-03-27 01:27:02.159985+00', '2019-06-17 08:19:11.292035+00', 358, 6, 106, '', 'B', 'The Atlanta Branch of the Royal Scottish Country Dance Society performing the Reel of the 51st Highland Division and the Balgeddie Reel at the 2012 Stone Mountain Highland Games', 1, 1, 'Y', 'FBwUbS1gd24', 318, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4853, '2019-06-20 20:43:33.02287+00', '2019-06-21 21:30:59.080962+00', 3659, 7, 1645, '', 'C', 'Starts very well, then one or two missed turns and hesitations later on.', 1, 1, 'Y', '12Dp4HV2XX8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4863, '2019-07-01 08:29:26.814025+00', '2019-07-01 22:01:13.071427+00', 11797, 1, 513, '', 'C', '', 1, 1, 'Y', 'LbkOSUSTL18', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4852, '2019-06-20 20:34:18.360989+00', '2019-06-21 21:34:19.029431+00', 13309, 2, 1645, '', 'B', '', 1, 1, 'Y', 'JTMk1S3pijA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4854, '2019-06-28 00:40:03.24635+00', '2019-06-28 00:40:03.24635+00', 1207, 2, 1296, '', 'X', '''Ciamar a Tha (How Are You?)'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'Wgp5df9AA_c', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4855, '2019-06-28 00:40:03.275994+00', '2019-06-28 00:40:03.275994+00', 11393, 2, 1296, '', 'X', '''The Double Diamond Strathspey'' is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'qGm53vY_8Po', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4856, '2019-06-28 00:40:03.308715+00', '2019-06-28 00:40:03.308715+00', 3637, 5, 1296, '', 'X', '''Lady Susan Stewart''s Reel'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'LuiDlar8cPs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4857, '2019-06-28 00:40:03.345374+00', '2019-06-28 00:40:03.345374+00', 16523, 3, 1296, '', 'X', '''Orpington Caledonians'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'LLqfz5eQylM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4858, '2019-06-28 00:40:03.371882+00', '2019-06-28 00:40:03.371882+00', 10497, 2, 1296, '', 'X', '''Tweedbridge Court'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'w29yTSC1Z1U', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4859, '2019-06-29 16:08:32.767821+00', '2019-06-29 23:06:12.863541+00', 19431, 1, 1645, '', 'B', 'In the 3rd repeat the hello-goodbye chase (bars 17-24) has a small, quickly recovered, variation in which corners are being set to.', 1, 1, 'Y', '73dy-zlK0NU', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4860, '2019-06-29 16:17:26.119351+00', '2019-06-29 23:06:29.078157+00', 19429, 1, 1645, '', 'B', 'The phrasing of the "through the mirror" rondels of bars 25-32 is better in the bottom half of the set for the first two repeats (with arches on bar 4 of the figure).', 1, 1, 'Y', '3FUwuafrBl0', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4861, '2019-06-29 16:42:31.946156+00', '2019-06-29 23:06:55.375262+00', 19430, 1, 1645, '', 'B', 'There is one wrong shoulder pass in bars 9-12 of the 4th repeat. Ideally on bar 40 the women should slip into place rather than turn in.', 1, 1, 'Y', 'QStbW666a_M', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4866, '2019-07-01 09:09:14.955463+00', '2019-07-02 16:08:37.812483+00', 18117, 1, 513, '', 'C', '', 1, 1, 'Y', 'vJRPdv_fSuk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4875, '2019-07-03 05:34:41.331472+00', '2019-07-03 05:35:26.561615+00', 12508, 3, 202, '', 'C', '', 1, 1, 'Y', 'wCeCKIR6gx8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4873, '2019-07-01 10:25:05.335706+00', '2019-07-03 05:38:11.868479+00', 13547, 2, 513, '', 'C', '', 1, 1, 'Y', 'BZ-cOQPQCQ0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4865, '2019-07-01 09:01:36.780078+00', '2019-07-03 05:39:05.956564+00', 1330, 3, 513, '', 'C', '', 1, 1, 'Y', 'D4JigdPqkjw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4871, '2019-07-01 09:36:57.05129+00', '2019-07-03 05:39:33.525029+00', 1582, 10, 513, '', 'D', '', 1, 1, 'Y', 'pKddRChPvZk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4872, '2019-07-01 10:20:22.959801+00', '2019-07-03 05:40:11.665095+00', 16525, 5, 513, '', 'B', '', 1, 1, 'Y', '1DW2dZBzuZ8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4874, '2019-07-01 10:33:34.567851+00', '2019-07-03 05:42:01.050628+00', 9926, 1, 513, '', 'C', '', 1, 1, 'Y', 'etg_oBp5rdI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4867, '2019-07-01 09:15:03.662572+00', '2019-07-03 05:42:38.831521+00', 10395, 1, 513, '', 'C', '', 1, 1, 'Y', '5eKNQEOPbQI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4869, '2019-07-01 09:30:26.527442+00', '2019-07-03 05:43:08.870601+00', 6419, 1, 513, '', 'C', '', 1, 1, 'Y', 'M8v7NfX1sLk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4870, '2019-07-01 09:32:50.253466+00', '2019-07-03 05:43:30.470694+00', 6419, 2, 513, '', 'C', '', 1, 1, 'Y', 'UWN2b0iuZNE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4876, '2019-07-03 05:45:37.982322+00', '2019-07-03 05:45:54.265287+00', 522, 3, 202, '', 'C', '', 1, 1, 'Y', 'aaBTS6lRBWI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4877, '2019-07-03 05:51:01.271325+00', '2019-07-03 05:51:39.953731+00', 4444, 2, 202, '', 'D', '', 1, 1, 'Y', 'IvgO6j31reo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4868, '2019-07-01 09:18:58.272879+00', '2019-07-03 08:02:11.10419+00', 8094, 2, 513, '', 'C', 'Once each couple.', 1, 1, 'Y', 'C2KIr7BKyKQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4878, '2019-07-05 00:40:03.554766+00', '2019-07-05 00:40:03.554766+00', 942, 1, 1296, '', 'X', '''Calgary''s First Hundred'' is a 40 bar reel for 3 couples.', 1, 1, 'Y', 'kq5y_Xkfto8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4879, '2019-07-05 00:40:03.621347+00', '2019-07-05 00:40:03.621347+00', 15277, 1, 1296, '', 'X', '''Dr Quarrie''s Birthday'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '9W_zDP3iWaU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4880, '2019-07-05 00:40:03.654901+00', '2019-07-05 00:40:03.654901+00', 15406, 2, 1296, '', 'X', '''Out of Thin Air'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'QZ28ywoXw_A', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4881, '2019-07-05 00:40:03.683938+00', '2019-07-05 00:40:03.683938+00', 9000, 1, 1296, '', 'X', '''The Packhorse Rant'' is a 32 bar reel for 2 couples.', 1, 1, 'Y', 'EMfTnR6hLFw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4882, '2019-07-05 00:40:03.706338+00', '2019-07-05 00:40:03.706338+00', 18410, 3, 1296, '', 'X', '''Ysobel Stewart of Fish Hoek'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'lJ7eEynWJ2E', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4887, '2019-07-10 08:39:01.786368+00', '2019-07-10 09:27:39.58208+00', 14386, 2, 513, '', 'C', '', 1, 1, 'Y', 'SvHHyybr3-s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4885, '2019-07-08 12:06:42.868232+00', '2019-07-08 17:21:50.836564+00', 8770, 1, 2824, '', 'A', 'Twice through; part of a longer display. In this demonstation the orientation of the set is changed between the two repeats of the dance.', 1, 1, 'Y', 'wcUehpFpr44', 84, 158, NULL);
INSERT INTO 'dancevideo' VALUES (4886, '2019-07-08 12:14:13.276344+00', '2019-07-08 17:51:31.534051+00', 18233, 1, 2824, '', 'C', '', 1, 1, 'Y', 'GKUXa6Xz3JU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4883, '2019-07-08 11:40:53.799407+00', '2019-07-08 18:54:20.198101+00', 14543, 2, 2824, '', 'C', 'Paris Spring Fling 2019', 1, 1, 'Y', 'XKVw0TIOHwc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4888, '2019-07-13 00:40:03.186948+00', '2019-07-13 00:40:03.186948+00', 16536, 4, 1296, '', 'X', '''MacDonald of Keppoch'' is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'wgjbMcsVZJ8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4884, '2019-07-08 11:43:29.398688+00', '2019-07-08 18:58:54.231367+00', 18379, 1, 2824, '', 'B', 'Paris Spring Fling 2019.



Successive views of three sets: the first one is the best.

', 1, 1, 'Y', 'BH8YwXpbAEg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4889, '2019-07-13 00:40:03.217417+00', '2019-07-13 00:40:03.217417+00', 7465, 3, 1296, '', 'X', '''More Bees A-Dancing'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'ppefugB99d8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4890, '2019-07-13 00:40:03.240817+00', '2019-07-13 00:40:03.240817+00', 13299, 2, 1296, '', 'X', '''The Music and the Dance'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'octtdbU_R3M', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4891, '2019-07-14 09:16:52.809118+00', '2019-07-14 21:29:35.945465+00', 93, 1, 1957, '', 'B', 'Danced by Berkhamsted Strathspey and Reel Club, at a Monday General Class with Carole Stoker (Mary''s daughter) as First Woman.



Three times through.', 1, 1, 'Y', 'a1yZYYNEGSk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1370, '2013-08-18 10:56:00.893026+00', '2019-07-16 16:47:46.052683+00', 14741, 1, 1296, '', 'A', 'Part of a longer display. Two 3C sets joined bottom to bottom. Once through, the final bars modified to link to the rest of the display (for example 1st couple here end on opposite sides instead of their own sides at the end of the corners pass and turn).', 1, 1, 'Y', 'AMVhkllL1Co', 322, 385, NULL);
INSERT INTO 'dancevideo' VALUES (4893, '2019-07-17 20:36:56.398963+00', '2019-07-17 22:12:55.693973+00', 1405, 2, 1645, '', 'B', '', 1, 1, 'Y', '34HEEjj0b2g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4894, '2019-07-17 20:50:04.02915+00', '2019-07-17 22:14:52.986273+00', 12219, 2, 1645, '', 'B', '', 1, 1, 'Y', 'oLqmOF3HNKU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4895, '2019-07-17 21:25:52.476804+00', '2019-07-17 22:14:02.672581+00', 1634, 1, 1645, '', 'B', 'The corners in this video mostly keep setting for the whole of the last 8 bars which is not specified in the cribs.', 1, 1, 'Y', 'Tx4kaY-9R34', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4898, '2019-07-17 21:54:24.431826+00', '2019-07-17 22:09:42.419983+00', 56, 2, 1645, '', 'B', '', 1, 1, 'Y', 'J6HXaQx8O8o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4892, '2019-07-17 20:30:25.7315+00', '2019-07-17 22:10:43.811828+00', 9774, 1, 1645, '', 'B', 'Some hesitations especially in the hello-goodbye setting but still a clear display of the dance.', 1, 1, 'Y', 'OjzaUvkWjcc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4897, '2019-07-17 21:50:12.677197+00', '2019-07-17 22:12:15.296384+00', 816, 3, 1645, '', 'B', 'Although its not dem quality dancing this is a much clearer performance of the dance than video 1.', 1, 1, 'Y', '2_H4n8qcnFg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4896, '2019-07-17 21:39:05.915644+00', '2019-07-17 22:15:48.984807+00', 11529, 1, 1645, '', 'B', '', 1, 1, 'Y', 'xt_1z99C4S4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4913, '2019-07-27 17:29:28.022385+00', '2019-07-28 11:32:53.438622+00', 3957, 2, 1645, '', 'B', 'Once each couple. The last part of a longer costumed display with the 4th repeat modified to include all four couples and dance off.', 1, 1, 'Y', '082vJUeYRmw', 1370, 1514, NULL);
INSERT INTO 'dancevideo' VALUES (5019, '2019-09-02 17:57:58.058557+00', '2019-09-02 18:04:35.321979+00', 19603, 1, 1645, '', 'A', '', 1, 1, 'Y', 'Mn10k0J168E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5017, '2019-09-02 17:49:42.437271+00', '2019-09-02 18:04:42.972832+00', 15816, 1, 1645, '', 'A', '', 1, 1, 'Y', 'U11Ceywn1jU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5010, '2019-09-02 11:00:49.265237+00', '2019-09-02 18:04:50.650315+00', 19594, 1, 1645, '', 'A', '', 1, 1, 'Y', 'pX2rQss4d-s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4900, '2019-07-18 09:24:47.110468+00', '2019-07-18 09:26:57.718632+00', 7061, 6, 1645, '', 'B', 'Twice through excerpt from a longer demonstration with the end of the second repeat modified in preparation for the following dance.', 1, 1, 'Y', 'MlAvnfrvlgY', 42, 114, NULL);
INSERT INTO 'dancevideo' VALUES (4899, '2019-07-18 09:23:23.513927+00', '2019-07-18 09:31:49.523502+00', 4365, 4, 1645, '', 'B', 'Twice through excerpt from a longer demo (winner of the RSCDS 2018 virtual festival).', 1, 1, 'Y', 'MlAvnfrvlgY', 240, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4914, '2019-07-27 17:37:36.136142+00', '2019-07-28 11:33:28.075176+00', 3957, 3, 1645, '', 'C', '', 1, 1, 'Y', 'gvePDFy7Wwk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4904, '2019-07-18 18:13:26.600588+00', '2019-07-19 09:10:11.596665+00', 11198, 2, 1645, '', 'B', '', 1, 1, 'Y', 'LdRYJS8Gc3k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4905, '2019-07-18 18:21:53.938443+00', '2019-07-19 09:12:18.977253+00', 1546, 1, 1645, '', 'B', '', 1, 1, 'Y', 'cNtDGku_5zM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4902, '2019-07-18 17:53:08.49564+00', '2019-07-19 09:12:45.164349+00', 9787, 1, 1645, '', 'B', '', 1, 1, 'Y', '-gz83zmr_Qo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4903, '2019-07-18 18:02:32.781143+00', '2019-07-19 09:13:16.881158+00', 5256, 1, 1645, '', 'B', '2nd and 3rd couples here give hands on bar 3 when crossing out into the 3/4 double figures of eight. This is not explicitly mentioned in the instructions which simply have "cross".', 1, 1, 'Y', 'gdzQNghEzkI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4906, '2019-07-19 09:35:27.164782+00', '2019-07-19 09:37:22.32735+00', 15021, 1, 1645, '', 'B', '', 1, 1, 'Y', 'L9cXgVs6EzA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4917, '2019-07-29 08:38:04.145595+00', '2019-07-29 08:38:40.764189+00', 5794, 8, 202, '', 'D', '', 1, 1, 'Y', 'kFn-uR9mOZI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4907, '2019-07-22 06:50:46.441791+00', '2019-07-22 07:26:19.805476+00', 12890, 2, 202, '', 'C', '', 1, 1, 'Y', 'uXbUoE1-fYk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1149, '2013-08-18 10:55:19.137057+00', '2019-07-22 09:16:51.825152+00', 2317, 2, 1296, '', 'A', 'A fine demonstration of this dance as highland dance with highland steps only. Not SCD', 1, 1, 'Y', 'VIR2yX11TVE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1148, '2013-08-18 10:55:19.088252+00', '2019-07-22 09:18:21.170732+00', 2317, 1, 1296, '', 'A', 'This is an demonstration level performance of this dance as a highland dance, using highland steps only. It is not SCD.', 1, 1, 'Y', 'Be59_bdC-6w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1150, '2013-08-18 10:55:19.179435+00', '2019-07-22 09:19:04.604568+00', 2317, 3, 1296, '', 'C', 'A demo, using SCD steps with many highland elements. Combined with Reel of Tulloch.', 1, 1, 'Y', '_b5J1UQqZaQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4908, '2019-07-23 09:25:22.577074+00', '2019-07-23 09:28:10.750241+00', 19476, 1, 1645, '', 'B', '', 1, 1, 'Y', 'NmEjCpMuzko', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4909, '2019-07-23 19:01:41.359346+00', '2019-07-23 19:02:07.338923+00', 5032, 1, 202, '', 'C', '', 1, 1, 'Y', 'fx86dLam4ao', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4910, '2019-07-23 19:07:22.799676+00', '2019-07-23 19:07:47.503822+00', 9110, 6, 202, '', 'C', '', 1, 1, 'Y', 'dpO-LTZVEdg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4911, '2019-07-27 16:54:05.128913+00', '2019-07-28 11:24:34.924757+00', 2281, 1, 1645, '', 'B', 'Once each couple. Part of a longer costumed display.', 1, 1, 'Y', '082vJUeYRmw', 1014, 1218, NULL);
INSERT INTO 'dancevideo' VALUES (4918, '2019-07-29 08:43:30.327272+00', '2019-07-29 08:44:41.965848+00', 18409, 3, 202, '', 'D', '', 1, 1, 'Y', 'uB4Rirl_XB8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4915, '2019-07-27 17:59:30.943874+00', '2019-07-28 11:26:13.116493+00', 19502, 1, 1645, '', 'C', '', 1, 1, 'Y', 'nfr0rIk3_nY', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4916, '2019-07-27 18:03:22.982371+00', '2019-07-28 11:27:41.635236+00', 19502, 2, 1645, '', 'B', 'This selection starts after the first repeat (the beginning of which is missing from the video).', 1, 1, 'Y', 'gYPl1yxzAAc', 29, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4912, '2019-07-27 17:17:47.455525+00', '2019-07-28 11:29:34.039428+00', 3945, 1, 1645, '', 'B', 'This video, part of a longer display, shows just the last 64 bars of this 288 bar dance (bars 9-72 of the 3rd figure).', 1, 1, 'Y', '082vJUeYRmw', 1244, 1322, NULL);
INSERT INTO 'dancevideo' VALUES (4923, '2019-07-29 14:58:52.156445+00', '2019-07-30 00:36:14.551609+00', 19507, 1, 1645, '', 'C', 'Both 1st & 2nd and 3rd & 4th couples start together.

', 1, 1, 'Y', 'qcSw_a-xbcY', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4919, '2019-07-29 08:48:40.245461+00', '2019-07-29 08:49:20.131671+00', 1480, 4, 202, '', 'D', '', 1, 1, 'Y', 'zsxgoUZ-51s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4920, '2019-07-29 09:59:04.285236+00', '2019-07-29 10:18:14.499352+00', 4871, 1, 1645, '', 'C', 'Last time through at a social dance.', 1, 1, 'Y', 'OgOjB7wAE0g', 255, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4927, '2019-07-29 17:46:41.910407+00', '2019-07-29 20:14:22.653145+00', 6287, 5, 2824, '', 'C', '', 1, 1, 'Y', 'gfcm5JVld68', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4925, '2019-07-29 17:37:55.545383+00', '2019-07-29 20:19:30.860066+00', 7061, 7, 2824, '', 'D', '', 1, 1, 'Y', 'lzbFFt3vAUg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4921, '2019-07-29 14:06:03.290606+00', '2019-07-29 20:23:31.446664+00', 4334, 2, 1645, '', 'C', '', 1, 1, 'Y', 'ARcSNty01JE', 49, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4922, '2019-07-29 14:18:29.915667+00', '2019-07-29 20:24:12.892433+00', 4196, 2, 1645, '', 'D', 'Two repeats with a constant view of one set, after that camera moves around.', 1, 1, 'Y', '9Nz4-odsQvQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4924, '2019-07-29 15:15:01.595997+00', '2019-07-29 20:25:08.233634+00', 2209, 1, 1645, '', 'C', 'The deviser is dancing as 3rd man.', 1, 1, 'Y', 'xtPiyppyKiA', 36, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4926, '2019-07-29 17:43:54.373522+00', '2019-07-29 20:30:59.513936+00', 769, 6, 2824, '', 'C', '', 1, 1, 'Y', '6JyBUiaXF-o', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4928, '2019-07-30 12:24:57.626195+00', '2019-07-30 12:26:20.681979+00', 15406, 3, 202, '', 'B', '', 1, 1, 'Y', 'sKckf6fwwwg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4931, '2019-07-31 16:08:38.159435+00', '2019-07-31 20:58:38.465549+00', 7637, 3, 29817, '', 'B', '', 1, 1, 'Y', 'xzZzIpaCPmE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4929, '2019-07-31 15:58:17.245824+00', '2019-07-31 21:00:55.96445+00', 16898, 1, 29817, '', 'B', '', 1, 1, 'Y', 'n7C1FO5C8E8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4932, '2019-07-31 16:11:28.080292+00', '2019-07-31 21:04:52.78182+00', 12895, 1, 29817, '', 'B', '', 1, 1, 'Y', 'yHelQqYtNF4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4933, '2019-07-31 16:24:19.920476+00', '2019-08-01 05:23:10.634828+00', 16901, 1, 29817, '', 'B', '', 1, 1, 'Y', 'VCGC9YKX-ZQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4934, '2019-07-31 16:29:02.445825+00', '2019-08-01 05:23:30.052503+00', 16902, 1, 29817, '', 'B', '', 1, 1, 'Y', 'WdgTXzdgRjI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4930, '2019-07-31 16:05:36.513029+00', '2019-08-01 05:23:57.853915+00', 16900, 1, 29817, '', 'B', '', 1, 1, 'Y', 'C9WS8E64e-8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4935, '2019-08-01 05:22:07.419567+00', '2019-08-01 05:24:27.405035+00', 18508, 1, 202, '', 'A', '', 1, 1, 'Y', 'zd4EK_5mZkc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4936, '2019-08-03 07:32:30.536972+00', '2019-08-03 08:48:11.949376+00', 17137, 4, 274, '', 'A', 'RSCDS Summer School 2019 - w3 - 190801 - Younger Hall - Country Dem



Twice through as part of a longer demonstration. The ending of this round the room dance has been slightly adapted for a longwise set and for the transition into the next dance.', 1, 1, 'Y', 'ehvo0YHwS5U', 86, 163, NULL);
INSERT INTO 'dancevideo' VALUES (4939, '2019-08-03 07:40:43.948066+00', '2019-08-03 08:43:02.438225+00', 822, 2, 274, '', 'A', 'RSCDS Summer School 2019 - w3 - 190801 - Younger Hall - Country Dem', 1, 1, 'Y', 'ehvo0YHwS5U', 419, 496, NULL);
INSERT INTO 'dancevideo' VALUES (4938, '2019-08-03 07:39:06.276935+00', '2019-08-03 09:07:23.451284+00', 14534, 4, 274, '', 'A', 'RSCDS Summer School 2019 - w3 - 190801 - Younger Hall - Country Dem



Three times through as part of a longer display. The first and third repeats are modified so that 3rd and 4th couples also dance the first 8 bars which would normally only involve 1st and 2nd couples.', 1, 1, 'Y', 'ehvo0YHwS5U', 234, 419, NULL);
INSERT INTO 'dancevideo' VALUES (3312, '2017-11-13 15:58:33.137295+00', '2019-08-04 15:30:17.561486+00', 2807, 3, 106, '', 'A', 'A bit confusing: 2C dance in a 3C set, 3 times through, 2c+3c starting.



Spring School 2015, Nizhny Novgorod.   Presentation by the "Silver Tassie" school team..', 1, 1, 'Y', '3pQPJRyTgrU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4937, '2019-08-03 07:35:30.615329+00', '2019-08-03 09:00:13.742414+00', 2267, 10, 274, '', 'A', 'RSCDS Summer School 2019 - w3 - 190801 - Younger Hall - Country Dem



Twice through. Part of a longer demonstration display.', 1, 1, 'Y', 'ehvo0YHwS5U', 163, 235, NULL);
INSERT INTO 'dancevideo' VALUES (4941, '2019-08-07 09:57:24.750223+00', '2019-08-07 16:45:33.025353+00', 1816, 1, 2824, '', 'B', '', 1, 1, 'Y', 'OvXPKbSwhC8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4942, '2019-08-07 10:00:26.749471+00', '2019-08-07 16:52:06.522685+00', 8970, 1, 2824, '', 'B', '', 1, 1, 'Y', 'Xm1_Ay57aFU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4943, '2019-08-07 10:02:37.758566+00', '2019-08-07 16:57:16.389358+00', 15600, 1, 2824, '', 'B', '', 1, 1, 'Y', '__S1Cay63_M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4940, '2019-08-07 09:54:39.891108+00', '2019-08-08 19:06:12.798875+00', 16754, 1, 2824, '', 'B', '', 1, 1, 'Y', 'Oph5eCFzLv8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4945, '2019-08-11 17:18:57.120251+00', '2019-08-11 20:04:14.134843+00', 15656, 1, 2213, '', 'B', 'Twice through only', 1, 1, 'Y', 'CseusVUZmN8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4944, '2019-08-11 07:46:50.704944+00', '2019-08-11 20:00:29.080308+00', 5637, 7, 2709, '', 'C', 'The camera moves away from the nearest set for the last 8 bars or so.', 1, 1, 'Y', 'P4NC6Kb3ZZg', 17, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4946, '2019-08-12 16:10:18.491172+00', '2019-08-12 18:53:38.369442+00', 19409, 1, 24698, '', 'A', '', 1, 1, 'Y', 'ldzCErfQwtQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4948, '2019-08-14 07:53:15.96983+00', '2019-08-14 08:54:26.77644+00', 18310, 1, 13151, '', 'A', 'Recorded at the Angelbachtal Highlandgames 2018. Video taken by Steffi Hahn. Danced by the SchlobDancers, Heidelberg, Germany. Dancers: Volha Bryl, Margaret Hamilton, Annette Mast, Vivian Colbert, Ingrid Goshegger, Viktor Lehmann.', 1, 1, 'Y', 'XUjM-UVquAs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4949, '2019-08-14 07:59:19.951557+00', '2019-08-14 08:59:17.215826+00', 18097, 1, 13151, '', 'A', 'Recorded at Kuckucksnest, Schlüchtern, November 2017. Dancers: Angelika Schmidkonz, Volha Bryl, Anika Lange, Viktor Lehmann (devisor), Markus Daub, Ralf Bolte. Video taken by Martina Müller-Franz.', 1, 1, 'Y', 'E9CWEm8eXHc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4965, '2019-08-14 20:00:10.075825+00', '2019-08-14 20:00:22.580637+00', 753, 2, 202, '', 'D', '', 1, 1, 'Y', 's3U3Qu1Ll9M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5009, '2019-09-02 06:36:40.149511+00', '2019-09-07 17:26:28.349332+00', 2203, 7, 202, '', 'C', 'Some little extra "decorations" and spare couples switch in after each repeat.', 1, 1, 'Y', 'YZO5dS6qNQY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4951, '2019-08-14 11:37:33.916173+00', '2019-08-14 16:48:54.835736+00', 19545, 1, 13151, '', 'A', 'Recorded at Summer School 2017, Old Dining Room, University of St Andrews. Dancers: Fiona Carroll, Fiona Mackie, Liz Douglas, Maria Elena Bonacini, Malcolm Taylor Hansen, Kristian Vestli, Markus Daub, Viktor Lehmann (devisor). Video taken by Rachel Shankland.



Once through.', 1, 1, 'Y', '6gmw7HFeT-g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4950, '2019-08-14 11:34:28.231049+00', '2019-08-14 16:51:19.285399+00', 19547, 1, 13151, '', 'A', 'Recorded at Summer School 2019 at the Old Dining Room, University of St Andrews. Dancers: Liz Douglas, Ilona Brown, Fiona Scothern, John Throburn, Kai Hugtenburg, Viktor Lehmann (devisor). Video recorded by Adam Brady. ', 1, 1, 'Y', 'zjG6h9yFQ40', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4952, '2019-08-14 12:14:10.350423+00', '2019-08-14 16:56:51.416284+00', 19546, 1, 13151, '', 'C', 'Recorded during November Course 2017 @ Kuckucksnest, Schlüchtern, Germany. Dancers: Volha Bryl, Anika Lange, Angelika Schmidkonz, Ralf Bolte, Markus Daub, Viktor Lehmann (devisor). By mistake, the choice of music wasn''t correct (a reel of wrong length was put on instead of a jig). Check description for minor choreography errors.', 1, 1, 'Y', '6XvgjPPwdDU', 0, 116, NULL);
INSERT INTO 'dancevideo' VALUES (4953, '2019-08-14 19:36:01.670193+00', '2019-08-14 19:36:24.589692+00', 17142, 2, 202, '', 'D', '', 1, 1, 'Y', 'kRTsFFg5K6U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4954, '2019-08-14 19:37:55.197134+00', '2019-08-14 19:38:27.776161+00', 4827, 6, 202, '', 'D', '', 1, 1, 'Y', 'VTXWf5d6JVY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4955, '2019-08-14 19:40:49.9526+00', '2019-08-14 19:41:57.25094+00', 6380, 3, 202, '', 'D', '', 1, 1, 'Y', 'cz3uAAB3QRc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4956, '2019-08-14 19:42:42.440525+00', '2019-08-14 19:43:17.655885+00', 4968, 3, 202, '', 'D', '', 1, 1, 'Y', '8AyHMeRbwaQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4957, '2019-08-14 19:44:02.990175+00', '2019-08-14 19:44:19.154683+00', 10663, 7, 202, '', 'D', '', 1, 1, 'Y', 'a5StyfE8yEY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4958, '2019-08-14 19:45:34.789348+00', '2019-08-14 19:46:48.621134+00', 10787, 10, 202, '', 'D', '', 1, 1, 'Y', 'db_H7WGzl1w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4959, '2019-08-14 19:46:28.999818+00', '2019-08-14 19:47:03.46713+00', 4106, 5, 202, '', 'D', '', 1, 1, 'Y', '9rpxzD0QLkc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4960, '2019-08-14 19:47:51.014615+00', '2019-08-14 19:48:17.218267+00', 373, 4, 202, '', 'D', '', 1, 1, 'Y', 'vVg-jxuXvfA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4961, '2019-08-14 19:54:13.483519+00', '2019-08-14 19:54:27.849871+00', 1792, 10, 202, '', 'D', '', 1, 1, 'Y', 'x4QGvStPVGs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4962, '2019-08-14 19:55:36.120401+00', '2019-08-14 19:55:51.176969+00', 17460, 7, 202, '', 'D', '', 1, 1, 'Y', 'glFn-6-Or2A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4963, '2019-08-14 19:56:51.133446+00', '2019-08-14 19:57:05.590855+00', 17133, 6, 202, '', 'D', '', 1, 1, 'Y', 'X4OE6XKS-Ms', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4964, '2019-08-14 19:58:45.779716+00', '2019-08-14 19:58:58.105942+00', 12792, 5, 202, '', 'D', '', 1, 1, 'Y', 'ZH3j5kVbDPQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4966, '2019-08-14 20:01:25.96128+00', '2019-08-14 20:01:39.874578+00', 5713, 6, 202, '', 'D', '', 1, 1, 'Y', 'ektK6a-fPpg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4967, '2019-08-14 20:06:25.883375+00', '2019-08-14 20:06:50.230711+00', 4935, 2, 202, '', 'D', '', 1, 1, 'Y', '6s3YtDdDW8s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4968, '2019-08-14 20:07:36.257701+00', '2019-08-14 20:08:06.638773+00', 18272, 5, 202, '', 'D', '', 1, 1, 'Y', '_Y9adA2X1Xs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4979, '2019-08-17 09:14:24.770592+00', '2019-08-17 20:16:33.707062+00', 11369, 4, 2824, '', 'D', '', 1, 1, 'Y', 'Na6uixg1atI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4970, '2019-08-15 09:10:53.133009+00', '2019-08-15 09:18:32.370107+00', 1376, 1, 202, '', 'D', '', 1, 1, 'Y', 'skH8ny8nl28', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4971, '2019-08-15 16:50:02.415727+00', '2019-08-16 08:44:28.943935+00', 51, 1, 106, '', 'D', 'From a Medley of the dances at a RuhrBall.  Video starts 2 bars late; once through only.  Good dancers in a social setting.', 1, 1, 'Y', 'BHeqK8SmPkQ', 4, 67, NULL);
INSERT INTO 'dancevideo' VALUES (4982, '2019-08-19 20:44:55.399349+00', '2019-08-19 20:45:31.66796+00', 13629, 4, 202, '', 'D', '', 1, 1, 'Y', '2B1TyAuaz-k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4973, '2019-08-16 08:35:59.557548+00', '2019-08-16 09:47:49.582657+00', 19517, 1, 197, '', 'A', 'Performed at Week 4 Ceilidh, Summer School 2019 (twice through)', 1, 1, 'Y', 'IFAlCWTYfEk', 402, 482, NULL);
INSERT INTO 'dancevideo' VALUES (4972, '2019-08-16 08:29:09.852107+00', '2019-08-16 09:55:41.454475+00', 19514, 1, 197, '', 'A', 'Performed at Week 4 Ceilidh, Summer School 2019 (twice through)', 1, 1, 'Y', 'IFAlCWTYfEk', 211, 342, NULL);
INSERT INTO 'dancevideo' VALUES (4978, '2019-08-17 09:12:12.125362+00', '2019-08-17 19:44:24.452963+00', 773, 1, 2824, '', 'D', '', 1, 1, 'Y', 'ChJ2xPxEyM0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4974, '2019-08-17 08:58:49.406902+00', '2019-08-17 19:49:28.636007+00', 7037, 4, 2824, '', 'C', '', 1, 1, 'Y', 'HDeOB0i44Jw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4980, '2019-08-17 09:17:56.172888+00', '2019-08-17 19:52:32.803867+00', 8203, 5, 2824, '', 'D', '', 1, 1, 'Y', 'ng52i1Xq9No', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4976, '2019-08-17 09:02:19.122484+00', '2019-08-17 20:01:01.57008+00', 11773, 3, 2824, '', 'C', '', 1, 1, 'Y', 'bEMToJy4iNw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4977, '2019-08-17 09:06:07.960715+00', '2019-08-17 20:05:02.418337+00', 16535, 5, 2824, '', 'D', '', 1, 1, 'Y', '3uP7OZnph_w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4975, '2019-08-17 09:00:02.624675+00', '2019-08-17 20:10:13.692668+00', 3558, 1, 2824, '', 'D', '', 1, 1, 'Y', '-IdO0hm_kW4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4983, '2019-08-19 20:53:08.350912+00', '2019-08-19 20:54:06.525034+00', 2267, 11, 202, '', 'D', '', 1, 1, 'Y', 'qZp02Nx6O0s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4987, '2019-08-22 07:19:59.347803+00', '2019-08-24 05:24:55.134613+00', 1461, 1, 13151, '', 'A', 'St Andrews Summer School 2019 Week 4 Country Dem Team

Dancers: Emma Orgeret, Liz Douglas, Violaine Eysseric, Yurika Okumura, Robert Leonard, Arthur Baum, Kai Hugtenburg, Viktor Lehmann. Dem Training: Anne Robertson. Musician: Don Bartlett', 1, 1, 'Y', 'DzlPrDlHmqA', 0, 94, NULL);
INSERT INTO 'dancevideo' VALUES (4985, '2019-08-22 07:15:24.407461+00', '2019-08-24 05:25:41.540541+00', 3830, 1, 13151, '', 'A', 'St Andrews Summer School 2019 Week 4 Country Dem Team

Dancers: Emma Orgeret, Liz Douglas, Violaine Eysseric, Yurika Okumura, Robert Leonard, Arthur Baum, Kai Hugtenburg, Viktor Lehmann. Dem Training: Anne Robertson. Musician: Don Bartlett', 1, 1, 'Y', 'DzlPrDlHmqA', 283, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4986, '2019-08-22 07:18:33.834149+00', '2019-08-24 05:26:09.550052+00', 19079, 2, 13151, '', 'A', 'St Andrews Summer School 2019 Week 4 Country Dem Team

Dancers: Emma Orgeret, Liz Douglas, Violaine Eysseric, Yurika Okumura, Robert Leonard, Arthur Baum, Kai Hugtenburg, Viktor Lehmann. Dem Training: Anne Robertson. Musician: Don Bartlett', 1, 1, 'Y', 'DzlPrDlHmqA', 94, 283, NULL);
INSERT INTO 'dancevideo' VALUES (4988, '2019-08-24 05:21:44.094151+00', '2019-08-24 05:26:29.964055+00', 16524, 7, 202, '', 'D', '', 1, 1, 'Y', 'Wc_r6QgqHJ0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4989, '2019-08-24 06:21:45.543502+00', '2019-08-24 06:22:03.639066+00', 2394, 5, 202, '', 'D', '', 1, 1, 'Y', 'DgLFdZI6BOk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4990, '2019-08-24 06:29:40.746824+00', '2019-08-24 06:30:05.290907+00', 6734, 5, 202, '', 'D', '', 1, 1, 'Y', 'q88GDH-3JcI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4991, '2019-08-24 06:36:44.209843+00', '2019-08-24 06:37:16.343028+00', 2030, 4, 202, '', 'D', '', 1, 1, 'Y', 'SoH2J55Owjc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4992, '2019-08-24 06:39:17.778788+00', '2019-08-24 06:40:09.701072+00', 4155, 7, 202, '', 'D', '', 1, 1, 'Y', '3iIHC7NsWPI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4993, '2019-08-24 06:41:44.378942+00', '2019-08-24 06:42:23.204031+00', 7147, 7, 202, '', 'D', '', 1, 1, 'Y', 'sc1sSCOOFUk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4995, '2019-08-26 21:17:32.193249+00', '2019-08-26 21:18:05.225799+00', 3326, 7, 202, '', 'D', '', 1, 1, 'Y', 'i4cbFwoj_RM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4994, '2019-08-26 21:14:49.291394+00', '2019-08-26 21:19:40.773667+00', 340, 4, 202, '', 'D', '', 1, 1, 'Y', 'f_mPEhILJLc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4997, '2019-08-28 10:26:39.921066+00', '2019-08-28 10:33:11.09466+00', 1285, 2, 1645, '', 'C', '', 1, 1, 'Y', 'rhzmx9zgOvM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4996, '2019-08-28 10:19:43.082114+00', '2019-08-28 10:33:18.568893+00', 3506, 2, 1645, '', 'B', 'Clear view. The promenades, unusually finishing in the centre, seem to end a little early.', 1, 1, 'Y', 'RcuLuw2rs0I', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4999, '2019-08-28 15:55:56.50181+00', '2019-08-28 18:10:11.254532+00', 19561, 1, 1645, '', 'B', 'There is one wrong shoulder pass in the reels (3rd repeat).', 1, 1, 'Y', 'fQXSwkulKVY', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5001, '2019-08-28 16:07:55.833572+00', '2019-08-28 20:16:52.722835+00', 19563, 1, 1645, '', 'B', 'Some hesitations, unlinked hands while setting and late entry into hands across, but choreographically correct.', 1, 1, 'Y', 'PJery-HNAEY', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4998, '2019-08-28 15:48:04.071494+00', '2019-08-28 18:09:45.176788+00', 19562, 1, 1645, '', 'B', 'There are a few hesitations and variations in ending the final reels, but otherwise good.', 1, 1, 'Y', '5-J7IMGBw9Q', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5000, '2019-08-28 16:03:28.179064+00', '2019-08-28 20:10:48.935079+00', 19560, 1, 1645, '', 'B', 'This video shows the original version. The now preferred version ends with a standard diamond poussette on the last repeat so the final 1st and 3rd couples end facing their new partners.', 1, 1, 'Y', 'KWOOiGPy6ew', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5002, '2019-08-28 16:19:08.254405+00', '2019-08-28 20:17:55.954861+00', 17757, 2, 1645, '', 'B', 'Choreographically correct - albeit with some hesitations and a litle raggedness in the extended espagnole of bars 1-8.', 1, 1, 'Y', 'pdZa7nNqEq8', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5004, '2019-09-01 16:38:04.452583+00', '2019-09-02 06:37:30.072086+00', 6964, 6, 2824, '', 'D', '', 1, 1, 'Y', 'eptZ3rZJ_pY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5007, '2019-09-02 00:04:25.068717+00', '2019-09-02 06:38:30.253641+00', 7941, 1, 513, '', 'C', '', 1, 1, 'Y', 'lAhqqodg-S8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5008, '2019-09-02 00:06:48.138562+00', '2019-09-02 06:39:36.51951+00', 4563, 2, 513, '', 'C', '', 1, 1, 'Y', 'KFFm-UNs0_4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5006, '2019-09-02 00:03:16.026996+00', '2019-09-02 06:40:34.495916+00', 859, 1, 513, '', 'C', '', 1, 1, 'Y', 'xEGZuaX01Vc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5005, '2019-09-01 16:41:29.599434+00', '2019-09-02 06:43:18.825412+00', 822, 3, 2824, '', 'D', '', 1, 1, 'Y', 'na5AytIEcaA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5003, '2019-09-01 16:32:22.214449+00', '2019-09-02 06:46:51.840325+00', 1677, 3, 2824, '', 'A', '', 1, 1, 'Y', 'u5lMQPJraUI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5011, '2019-09-02 11:04:58.21969+00', '2019-09-02 18:04:57.632369+00', 19595, 1, 1645, '', 'A', '', 1, 1, 'Y', 'uGzAwXkaPMc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5016, '2019-09-02 17:38:42.380142+00', '2019-09-02 21:47:31.406973+00', 19266, 1, 2220, '', 'A', 'Performed by the Berkeley Adult Social Team for Adjudication at the 2019 Highland Games in Pleasanton California', 1, 1, 'Y', 'jHsEt5TWhOI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5015, '2019-09-02 17:36:55.820429+00', '2019-09-02 21:49:56.683198+00', 17312, 2, 2220, '', 'B', 'Performed by the Berkeley Adult Social Team for adjudication at the 2019 Highland Games in Pleasanton CA', 1, 1, 'Y', 'FY2xe4r4izw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5014, '2019-09-02 17:33:36.939342+00', '2019-09-02 21:52:35.887352+00', 4548, 2, 2220, '', 'B', 'Performed by the Berkeley Social Adjudication set at the 2019 Highland Games in Pleasanton CA', 1, 1, 'Y', 'gKw9ansO5vk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5020, '2019-09-02 20:45:08.834012+00', '2019-09-02 21:56:14.610386+00', 8150, 1, 21468, '', 'B', 'Good for illustrating this dance - for which the instructions in "A Guide to Scottish Country Dancing" aren''t that clear. However the audio track is very faint.', 1, 1, 'Y', 'bdSvLV-EgSA', 0, 85, NULL);
INSERT INTO 'dancevideo' VALUES (5030, '2019-09-03 22:33:11.271523+00', '2019-09-03 22:33:30.075191+00', 19623, 1, 106, '', 'C', '', 1, 1, 'Y', 'F61FIqQS68E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5024, '2019-09-03 00:40:03.215277+00', '2019-09-03 00:40:03.215277+00', 340, 5, 1296, '', 'X', '''Back to the Fireside'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'NBMXRsR4DFc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5026, '2019-09-03 00:40:03.265317+00', '2019-09-03 00:40:03.265317+00', 3678, 2, 1296, '', 'X', '''The Lammermuir Hills'' is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'GJtoCGa4RsE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5027, '2019-09-03 00:40:03.290099+00', '2019-09-03 00:40:03.290099+00', 5035, 1, 1296, '', 'X', '''Officer and a Gentleman, An'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'dt9dvx2RJls', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5023, '2019-09-03 00:04:51.669682+00', '2019-09-03 07:39:56.000428+00', 2353, 5, 1645, '', 'B', 'View of one set after another, generally good dancing.', 1, 1, 'Y', '-f_vOqCEN_k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5029, '2019-09-03 21:08:54.039069+00', '2019-09-03 21:09:11.628919+00', 19617, 1, 106, '', 'C', 'Old time dance at the Canberra Colonial Ball held by the Monaro Folk Society on 6th September 2014 at the Albert Hall.  



Music provided by the ''Heritage Ensemble'', called by Don Richmond.', 1, 1, 'Y', '7GoCT4ouSZE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5031, '2019-09-03 23:49:07.063519+00', '2019-09-03 23:55:00.449207+00', 13583, 1, 106, '', 'A', '', 1, 1, 'Y', 'PHZ4jYpmgNE', 283, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5028, '2019-09-03 08:44:15.193979+00', '2019-09-04 19:01:39.444797+00', 6386, 5, 1645, '', 'A', '', 1, 1, 'Y', 'h9Bto-g4hwA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5033, '2019-09-04 21:19:47.071379+00', '2019-09-04 22:53:53.886745+00', 289, 1, 1645, '', 'D', 'Quite a few errors, especially at the start, but gets better towards the end and the last repeat is good.', 1, 1, 'Y', '2BcZK9ekSeE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5034, '2019-09-04 22:06:54.485216+00', '2019-09-04 22:54:01.70516+00', 189, 1, 1645, '', 'C', 'Some shepherding of beginners but generally clear.', 1, 1, 'Y', 'e4RKMxFVw4A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5035, '2019-09-05 10:05:49.026934+00', '2019-09-05 19:38:27.026295+00', 13780, 1, 1645, '', 'D', 'This clip starts with the dancing. The beginning of the video has an intro by the MC and deviser.', 1, 1, 'Y', 'jlWlKSkbynw', 47, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5040, '2019-09-05 19:08:01.646268+00', '2019-09-05 19:39:58.613512+00', 19631, 1, 1645, '', 'A', '', 1, 1, 'Y', 'MA_4Khu1TLU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5038, '2019-09-05 17:27:01.052129+00', '2019-09-05 19:40:09.535089+00', 19629, 1, 1645, '', 'A', 'Twice through. First part of a demonstration medley (followed by <<ddd:Jack''s Jig# 19630>>).', 1, 1, 'Y', 'BCn4Ymh-2e4', 0, 124, NULL);
INSERT INTO 'dancevideo' VALUES (5039, '2019-09-05 17:27:29.414119+00', '2019-09-05 19:40:15.695069+00', 19630, 1, 1645, '', 'A', 'Twice through. Second part of a demonstration medley (following <<ddd:Jack''s Strathspey# 19629>>).', 1, 1, 'Y', 'BCn4Ymh-2e4', 124, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5043, '2019-09-06 17:51:41.373599+00', '2019-09-06 17:54:18.413762+00', 6161, 2, 1645, '', 'B', '', 1, 1, 'Y', 'XlV0I_whGrA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5052, '2019-09-06 21:09:15.017166+00', '2019-09-07 10:32:24.187609+00', 14717, 1, 1645, '', 'C', '', 1, 1, 'Y', '6j6dNoDM-f4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5048, '2019-09-06 20:38:17.978994+00', '2019-09-07 10:33:12.011451+00', 877, 3, 1645, '', 'C', 'A good first repeat but a few false starts later on.', 1, 1, 'Y', 'ALBKJW3RFjY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5049, '2019-09-06 20:45:55.014839+00', '2019-09-07 10:33:57.102605+00', 1202, 1, 1645, '', 'C', 'This dance is 32 bars strathspey and 32 bar reel. Here the set uses a track with 2x32 strathspey and 2x32 reel.', 1, 1, 'Y', 'zWj0L2fhE4A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5045, '2019-09-06 20:05:41.241023+00', '2019-09-07 10:34:57.539482+00', 17979, 2, 1645, '', 'B', 'Video starts at the end of bar 1.', 1, 1, 'Y', 'P6mW9A0u8zs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5050, '2019-09-06 20:56:18.994364+00', '2019-09-07 10:37:26.759445+00', 3711, 1, 1645, '', 'B', 'Danced in a three couple set (the former 1st couple step down on bars 9-10 of the next repeat after the circle).', 1, 1, 'Y', 'nvht7NkG_mY', 11, 332, NULL);
INSERT INTO 'dancevideo' VALUES (5051, '2019-09-06 21:04:57.052953+00', '2019-09-07 10:37:35.145703+00', 8151, 2, 1645, '', 'C', 'Fairly clear, though some dancers are doing variations.', 1, 1, 'Y', 'xvgS5jiyfN4', 11, 248, NULL);
INSERT INTO 'dancevideo' VALUES (5044, '2019-09-06 19:28:40.49195+00', '2019-09-07 10:37:44.577294+00', 4204, 1, 1645, '', 'B', '', 1, 1, 'Y', 'oErxgmwE6II', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5042, '2019-09-05 22:47:24.765615+00', '2019-09-07 10:48:12.95627+00', 12538, 2, 1645, '', 'B', '', 1, 1, 'Y', 'HDfFb2LIM94', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5041, '2019-09-05 19:33:49.327716+00', '2019-09-07 10:50:15.264766+00', 10339, 1, 1645, '', 'C', 'Once through plus the strathspey again. The video starts fractionally late.', 1, 1, 'Y', 'K56vBdTNkg4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5053, '2019-09-06 21:21:49.391074+00', '2019-09-07 10:54:33.945332+00', 18410, 4, 1645, '', 'C', 'Danced in three couple sets. Starts reasonably well but  there are a variety of mishaps in later repeats and constantly flickering video.', 1, 1, 'Y', 'FM9zOVmVHKU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5059, '2019-09-06 23:17:38.450369+00', '2019-09-07 10:31:53.327786+00', 109, 5, 1645, '', 'A', '', 1, 1, 'Y', 'lfh2uK5vBYQ', 15, 202, NULL);
INSERT INTO 'dancevideo' VALUES (5057, '2019-09-06 22:04:41.722476+00', '2019-09-07 10:33:31.13071+00', 7637, 4, 1645, '', 'D', 'NB this is a variation with four trios in a square instead of the expected three trios in a triangle and is marked as "Informal" for that reason.', 1, 1, 'Y', 'hpWScVlYetA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5060, '2019-09-06 23:23:45.349207+00', '2019-09-07 10:34:15.24718+00', 8086, 2, 1645, '', 'A', 'Three times through. In this competition demonstration, the first 1st couple start from 2nd place.

Russian Festival of Scottish Country Dancing in Kazan, May 2017.', 1, 1, 'Y', 'lfh2uK5vBYQ', 208, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5046, '2019-09-06 20:14:38.074561+00', '2019-09-07 10:36:29.35989+00', 3642, 1, 1645, '', 'C', 'Danced in a three couple set (the former 1st couple casting off at the end).', 1, 1, 'Y', 'SQz3-_xCuo8', 11, 116, NULL);
INSERT INTO 'dancevideo' VALUES (5058, '2019-09-06 22:26:22.05586+00', '2019-09-07 10:36:39.01711+00', 3680, 2, 1645, '', 'A', '', 1, 1, 'Y', 'WLNseL-6O1E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5056, '2019-09-06 21:52:24.94188+00', '2019-09-07 10:39:42.679068+00', 17988, 1, 1645, '', 'B', '', 1, 1, 'Y', 'ENWzgdBp9a8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5047, '2019-09-06 20:30:24.476424+00', '2019-09-07 10:53:11.097144+00', 10255, 1, 1645, '', 'D', 'During the first repeat the set struggles a bit to keep up with a fast track. This is exacerbated in bars 25-32 by them trying to follow the petronella turns with extra setting steps which are not in the instructions and therefore they do not have time for the final left hand turns. Thereafter it gets increasingly chaotic. With instructions and diagram to hand you may get the general idea of whats supposed to happen. They are at least having fun.', 1, 1, 'Y', '62FP7lLjenY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5055, '2019-09-06 21:40:57.392888+00', '2019-09-07 10:53:19.628621+00', 7085, 2, 1645, '', 'B', '', 1, 1, 'Y', 'rtrb-yvP6yY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5054, '2019-09-06 21:25:27.022883+00', '2019-09-07 10:55:17.616344+00', 18410, 5, 1645, '', 'A', 'Twice through.', 1, 1, 'Y', '0cn1qzEp2Q8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5061, '2019-09-07 17:00:07.89169+00', '2019-09-07 21:58:02.882206+00', 14239, 2, 1645, '', 'C', 'Once through.', 1, 1, 'Y', '0dodM7GInhQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5062, '2019-09-07 17:10:35.146954+00', '2019-09-07 22:10:15.202579+00', 12428, 4, 1645, '', 'B', '', 1, 1, 'Y', 'MpQlBR0bq0U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5063, '2019-09-07 23:05:05.981245+00', '2019-09-07 23:14:32.827415+00', 13473, 1, 1645, '', 'C', '', 1, 1, 'Y', 'vd6is53lfdQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5064, '2019-09-07 23:56:46.209182+00', '2019-09-07 23:57:09.788542+00', 1426, 2, 106, '', 'C', '', 1, 1, 'Y', 'HEWjvHGJtdI', 17, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5065, '2019-09-08 10:13:22.837261+00', '2019-09-08 10:17:12.88673+00', 19582, 1, 1645, '', 'B', '', 1, 1, 'Y', 'L88XNHoo6KQ', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5066, '2019-09-08 10:14:04.831412+00', '2019-09-08 10:19:37.686482+00', 19581, 1, 1645, '', 'B', '', 1, 1, 'Y', '0Jx02zAO9zM', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5070, '2019-09-11 19:37:41.561051+00', '2019-09-13 21:06:40.819227+00', 16854, 1, 1645, '', 'A', '', 1, 1, 'Y', 'oVo7kz1lyB8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5091, '2019-09-13 19:04:32.528994+00', '2019-09-13 21:06:50.468655+00', 19643, 1, 1645, '', 'X', '', 1, 1, 'Y', 'QwDe3U0mGoo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5036, '2019-09-05 11:00:28.371548+00', '2022-06-08 23:03:49.11611+00', 16461, 3, 1645, '', 'Z', 'A bit less than twice through, starting at bar 9.



Was Reasonable, now unavailable.', 1, 1, 'Y', 'RU3cfvbRhyg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5089, '2019-09-12 19:06:59.636509+00', '2019-09-13 20:25:33.954463+00', 38, 1, 1645, '', 'B', 'After two repeats the demonstration team switch in/out two couples and change the orientation of the set.', 1, 1, 'Y', '1J_CM8YPLkA', 1323, 1475, NULL);
INSERT INTO 'dancevideo' VALUES (5068, '2019-09-11 18:58:23.379947+00', '2019-09-13 20:35:01.278618+00', 629, 1, 1645, '', 'A', 'Twice through: the last part of a longer demonstration.', 1, 1, 'Y', 'MlcW-_VZvTc', 228, 305, NULL);
INSERT INTO 'dancevideo' VALUES (5081, '2019-09-12 17:37:05.19963+00', '2019-09-13 20:26:59.919867+00', 15220, 1, 1645, '', 'D', '', 1, 1, 'Y', 'lhmyfGopPgc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5072, '2019-09-11 19:55:43.090512+00', '2019-09-13 20:28:17.119576+00', 12608, 1, 1645, '', 'D', 'Danced three times in a three couple set with a workaround between repeats so the pattern of hands across at the start is not very clear.', 1, 1, 'Y', 'fTG9FVUGvng', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5083, '2019-09-12 17:55:12.292686+00', '2019-09-13 20:30:10.173087+00', 328, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', '1J_CM8YPLkA', 230, 364, NULL);
INSERT INTO 'dancevideo' VALUES (5084, '2019-09-12 18:02:43.847903+00', '2019-09-13 20:33:33.191907+00', 556, 1, 1645, '', 'B', 'Three times through.', 1, 1, 'Y', '1J_CM8YPLkA', 400, 513, NULL);
INSERT INTO 'dancevideo' VALUES (5090, '2019-09-12 19:19:34.010587+00', '2019-09-13 20:38:14.248901+00', 975, 2, 1645, '', 'B', 'The last part of a demonstration medley by a six couple team. The second repeat of this four couple dance is adapted to swap in the standing couples at the ends.', 1, 1, 'Y', '1J_CM8YPLkA', 1512, 1422, NULL);
INSERT INTO 'dancevideo' VALUES (5067, '2019-09-11 18:52:38.803155+00', '2019-09-13 20:39:41.9489+00', 1114, 1, 1645, '', 'A', 'Twice through (part of a longer demo) with the last four bars of the second repeat adapted for the next dance.', 1, 1, 'Y', 'MlcW-_VZvTc', 33, 105, NULL);
INSERT INTO 'dancevideo' VALUES (5087, '2019-09-12 18:54:53.35881+00', '2019-09-13 20:42:37.451382+00', 2039, 2, 1645, '', 'B', '', 1, 1, 'Y', '1J_CM8YPLkA', 871, 1037, NULL);
INSERT INTO 'dancevideo' VALUES (5085, '2019-09-12 18:11:42.658482+00', '2019-09-13 20:45:22.009411+00', 12446, 1, 1645, '', 'B', 'Danced in three two couple sets (at least initially).', 1, 1, 'Y', '1J_CM8YPLkA', 548, 696, NULL);
INSERT INTO 'dancevideo' VALUES (5092, '2019-09-13 19:10:20.715685+00', '2019-09-13 20:45:30.650726+00', 19642, 1, 1645, '', 'X', '', 1, 1, 'Y', 'T0CizHNW3ag', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5093, '2019-09-13 19:11:26.554638+00', '2019-09-13 20:45:38.945598+00', 19642, 2, 1645, '', 'A', 'Danced once each couple in a three couple set.', 1, 1, 'Y', 'GXo-TiSKDsg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5080, '2019-09-11 20:52:23.137098+00', '2019-09-13 20:49:57.479693+00', 5443, 1, 1645, '', 'A', '', 1, 1, 'Y', 'H2OkGr90zTc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5079, '2019-09-11 20:47:15.653087+00', '2019-09-13 20:51:22.506346+00', 13624, 1, 1645, '', 'C', '', 1, 1, 'Y', '2M-Vj95VWRg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5077, '2019-09-11 20:30:07.769017+00', '2019-09-13 20:52:51.692691+00', 5741, 1, 1645, '', 'D', '', 1, 1, 'Y', 'yJxtfW7V41c', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5076, '2019-09-11 20:21:27.994151+00', '2019-09-13 20:54:09.53939+00', 5936, 2, 1645, '', 'B', '', 1, 1, 'Y', 'hNgd9ckT_zY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5075, '2019-09-11 20:20:40.873639+00', '2019-09-13 20:55:10.953329+00', 5936, 1, 1645, '', 'C', '', 1, 1, 'Y', 'cDCtDzWBKbs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5071, '2019-09-11 19:49:44.93007+00', '2019-09-13 20:59:43.89171+00', 6627, 1, 1645, '', 'D', 'Its hard to make out the dance as the camera is a bit too close.', 1, 1, 'Y', 'cFBP_uTHytU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5082, '2019-09-12 17:47:22.37935+00', '2019-09-13 20:56:54.793907+00', 6219, 1, 1645, '', 'B', 'Three times, once each couple, in two three couple sets with the end adapted so 1st couple finish in 3rd place.', 1, 1, 'Y', '1J_CM8YPLkA', 66, 177, NULL);
INSERT INTO 'dancevideo' VALUES (5074, '2019-09-11 20:13:50.285678+00', '2019-09-13 20:57:56.294791+00', 19223, 1, 1645, '', 'B', 'This clip shows a once each couple demonstration of the dance (before everyone joins in).', 1, 1, 'Y', 'dLzh1GA5CmQ', 0, 156, NULL);
INSERT INTO 'dancevideo' VALUES (5073, '2019-09-11 20:02:12.184951+00', '2019-09-13 20:58:50.717925+00', 12450, 1, 1645, '', 'C', 'This clip starts with the dancing. The beginning of the whole video has an explanation of the figures.', 1, 1, 'Y', 'VQ0nC7epZ10', 48, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5086, '2019-09-12 18:40:00.38675+00', '2019-09-13 21:02:00.894884+00', 5487, 1, 1645, '', 'B', 'Twice through. Good dancing, but the demonstration team here do Set and Rotate in bars 33-40 whereas the original instructions have: set, half right hands across, half turn and twirl away instead.', 1, 1, 'Y', '1J_CM8YPLkA', 741, 850, NULL);
INSERT INTO 'dancevideo' VALUES (5088, '2019-09-12 19:00:39.895219+00', '2019-09-13 21:05:52.645989+00', 6880, 1, 1645, '', 'B', 'This is a four couple dance, although 4th couple are only active for bars 29-32. Here it is danced in two back to back three couple sets with a modified version of the last 4 bars.', 1, 1, 'Y', '1J_CM8YPLkA', 1081, 1285, NULL);
INSERT INTO 'dancevideo' VALUES (5069, '2019-09-11 19:14:41.429687+00', '2019-09-13 21:07:47.588389+00', 18091, 1, 1645, '', 'A', 'Twice through.', 1, 1, 'Y', 'ZkmqSRJ-OzA', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5095, '2019-09-14 07:52:35.755259+00', '2019-09-14 20:05:03.466903+00', 29, 1, 1645, '', 'A', 'Part of a longer display. Once through (plus a bit to show the round the room progression).', 1, 1, 'Y', 'o1Tc9yQZcKM', 133, 172, NULL);
INSERT INTO 'dancevideo' VALUES (5094, '2019-09-14 07:43:04.173838+00', '2019-09-14 20:10:42.316401+00', 5569, 1, 1645, '', 'B', 'Danced one each couple with a few minor which-shoulder glitches.', 1, 1, 'Y', '082vJUeYRmw', 785, 968, NULL);
INSERT INTO 'dancevideo' VALUES (5098, '2019-09-14 08:23:22.547624+00', '2019-09-14 20:11:31.485361+00', 19285, 1, 1645, '', 'A', '', 1, 1, 'Y', 'cUtoxP9xACM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5096, '2019-09-14 08:09:56.416874+00', '2019-09-14 20:11:45.011446+00', 16752, 1, 1645, '', 'B', '', 1, 1, 'Y', 'IRq1QyUMsJg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5102, '2019-09-15 21:28:08.278161+00', '2019-09-16 19:20:01.524756+00', 12476, 1, 1645, '', 'A', 'First part of a longer demonstration (with some background noise).', 1, 1, 'Y', 'yU8rxUZW4yE', 478, 634, NULL);
INSERT INTO 'dancevideo' VALUES (5101, '2019-09-15 21:21:51.60506+00', '2019-09-16 19:21:11.146818+00', 4929, 1, 1645, '', 'A', 'Extract from a longer demonstration.', 1, 1, 'Y', 'yU8rxUZW4yE', 634, 738, NULL);
INSERT INTO 'dancevideo' VALUES (5103, '2019-09-15 21:43:23.27797+00', '2019-09-16 19:20:08.560779+00', 4728, 3, 1645, '', 'B', 'Once through extract from a longer demonstration.', 1, 1, 'Y', 'yU8rxUZW4yE', 1106, 1143, NULL);
INSERT INTO 'dancevideo' VALUES (5099, '2019-09-15 20:49:02.591282+00', '2019-09-16 19:19:25.128922+00', 10663, 8, 1645, '', 'B', 'Twice through (once per couple) extract from a longer demonstation.', 1, 1, 'Y', 'yU8rxUZW4yE', 0, 70, NULL);
INSERT INTO 'dancevideo' VALUES (5100, '2019-09-15 20:59:58.378793+00', '2019-09-16 19:22:23.138298+00', 6104, 3, 1645, '', 'A', 'Twice through extract from a longer demonstration. There is a small glitch in the video around bar 7 of the 2nd time where a couple of seconds are repeated.', 1, 1, 'Y', 'yU8rxUZW4yE', 70, 195, NULL);
INSERT INTO 'dancevideo' VALUES (5116, '2019-09-17 00:40:03.768243+00', '2019-09-17 00:40:03.768243+00', 16788, 1, 1296, '', 'X', '''The Bunting Bee'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'aw5wbN_sj-g', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5117, '2019-09-17 00:40:03.791061+00', '2019-09-17 00:40:03.791061+00', 13621, 3, 1296, '', 'X', '''Granville Market'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', '8DeTxyKjyYQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5126, '2019-09-17 20:30:32.60059+00', '2019-09-17 20:47:26.05522+00', 14629, 1, 1645, '', 'B', '', 1, 1, 'Y', 'eq9OYWk6NAM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5112, '2019-09-16 20:55:05.022034+00', '2019-09-17 20:47:34.96392+00', 12169, 1, 1645, '', 'B', '', 1, 1, 'Y', '5LXVJQF6JK4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5127, '2019-09-17 20:34:36.366284+00', '2019-09-17 20:47:41.209328+00', 13331, 1, 1645, '', 'B', '', 1, 1, 'Y', '0cuvjYom8o8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5123, '2019-09-17 20:17:15.995923+00', '2019-09-17 20:47:48.544471+00', 15443, 2, 1645, '', 'B', 'Very clear with helpfully coloured tee shirts.', 1, 1, 'Y', '0fd-vyktn_k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5111, '2019-09-16 20:50:33.408096+00', '2019-09-17 20:48:54.02126+00', 15270, 2, 1645, '', 'C', '', 1, 1, 'Y', 'WBmUb8SHLB0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5110, '2019-09-16 20:44:21.216813+00', '2019-09-17 20:49:25.135672+00', 16116, 1, 1645, '', 'B', '', 1, 1, 'Y', 'TbKBeJpLrq8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5124, '2019-09-17 20:22:07.697883+00', '2019-09-17 20:49:33.610124+00', 14977, 6, 1645, '', 'B', 'Three times through.', 1, 1, 'Y', 'LlAUcli_zd4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5109, '2019-09-16 20:39:57.417753+00', '2019-09-17 20:50:31.076352+00', 12124, 4, 1645, '', 'B', '', 1, 1, 'Y', 'kMc9UF3yro8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5107, '2019-09-16 20:28:21.336221+00', '2019-09-17 20:53:30.013831+00', 14216, 1, 1645, '', 'B', 'Mostly looks good, but there are a few little glitches here and there (shoulder passes in 1st reel, recovered hesitations in double figures of eight).', 1, 1, 'Y', 'GQIR-LCL8OI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5108, '2019-09-16 20:34:22.194426+00', '2019-09-17 21:07:48.526679+00', 11756, 1, 1645, '', 'B', '', 1, 1, 'Y', 'ebR_rVEPtps', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5115, '2019-09-16 21:30:13.346644+00', '2019-09-17 21:11:56.422962+00', 14218, 1, 1645, '', 'B', '', 1, 1, 'Y', '8uOuu2s0PK4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5128, '2019-09-17 20:40:28.87662+00', '2019-09-17 21:12:20.788432+00', 7923, 1, 1645, '', 'B', '', 1, 1, 'Y', 'JvhJ_ChheRM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5129, '2019-09-17 20:42:38.143269+00', '2019-09-17 21:12:59.598487+00', 14623, 1, 1645, '', 'B', '', 1, 1, 'Y', 'frnIEBN6Gto', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5125, '2019-09-17 20:27:25.153764+00', '2019-09-17 21:13:35.737792+00', 14630, 1, 1645, '', 'B', '', 1, 1, 'Y', 'JpqHhEg1Shk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5105, '2019-09-16 20:07:46.44974+00', '2019-09-17 21:14:35.007583+00', 8683, 2, 1645, '', 'C', 'Twice through. The 2nd repeat is sometimes too close up to see the whole dance.', 1, 1, 'Y', 'YFwkvtu90vY', 80, 160, NULL);
INSERT INTO 'dancevideo' VALUES (5114, '2019-09-16 21:26:04.56183+00', '2019-09-17 21:17:19.516815+00', 14217, 2, 1645, '', 'B', '', 1, 1, 'Y', 'XPE2QiloXaI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5113, '2019-09-16 21:13:55.399957+00', '2019-09-17 21:18:21.699532+00', 19658, 1, 1645, '', 'B', '', 1, 1, 'Y', 'tZU9qpNV7qc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5106, '2019-09-16 20:15:59.01112+00', '2019-09-17 21:19:24.034522+00', 16115, 1, 1645, '', 'B', '', 1, 1, 'Y', '6JF5kw5XyvA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5130, '2019-09-17 20:46:05.472565+00', '2019-09-17 21:20:12.234937+00', 14631, 1, 1645, '', 'B', '', 1, 1, 'Y', 'qNmtKfRmJV0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5104, '2019-09-16 20:00:34.726519+00', '2019-09-17 21:21:02.02026+00', 14811, 1, 1645, '', 'C', 'Twice through.', 1, 1, 'Y', 'YFwkvtu90vY', 0, 77, NULL);
INSERT INTO 'dancevideo' VALUES (5122, '2019-09-17 20:07:58.257301+00', '2019-09-17 21:22:03.134738+00', 7109, 5, 1645, '', 'B', '', 1, 1, 'Y', 'LawLBlZxHOQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5121, '2019-09-17 17:48:45.548819+00', '2019-09-17 21:24:59.628507+00', 13985, 1, 2220, '', 'B', '', 1, 1, 'Y', '0CCbKD65ntI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5119, '2019-09-17 00:40:03.849815+00', '2019-09-18 00:40:03.979621+00', 8072, 1, 1296, '', 'Z', '''Persuasion'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'DruexDwXMlU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5131, '2019-09-18 00:40:03.990759+00', '2019-09-18 00:40:03.990759+00', 8072, 2, 1296, '', 'X', '''Persuasion'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'pmAUxI7E884', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5120, '2019-09-17 00:40:03.882221+00', '2019-09-18 00:40:04.01879+00', 5889, 2, 1296, '', 'Z', '''Sandy O''er the Lea'' is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'fkG3q3N9-Xk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5132, '2019-09-18 00:40:04.032646+00', '2019-09-18 00:40:04.032646+00', 5889, 3, 1296, '', 'X', '''Sandy o''er the Lea'' is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'UwjG3niyLP0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5152, '2019-09-18 16:45:40.754008+00', '2019-09-18 20:53:02.156225+00', 929, 1, 1645, '', 'A', '', 1, 1, 'Y', 'LWoZ_jbkNSI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5138, '2019-09-18 13:45:00.82039+00', '2019-09-18 20:55:58.83562+00', 10786, 1, 1645, '', 'C', '', 1, 1, 'Y', 'X3NWSW9Irsc', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5137, '2019-09-18 13:19:32.286083+00', '2019-09-18 21:01:05.178336+00', 15058, 1, 1645, '', 'D', '', 1, 1, 'Y', 'T3tW2Z2JaqM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5143, '2019-09-18 15:12:35.451454+00', '2019-09-18 21:01:36.455162+00', 10498, 1, 1645, '', 'B', 'This clip shows once through. The demonstration continues with another repeat inverted at the other end of the set.', 1, 1, 'Y', 'AG3yIgO2GTo', 0, 50, NULL);
INSERT INTO 'dancevideo' VALUES (5134, '2019-09-18 12:46:01.860841+00', '2019-09-18 21:02:27.33716+00', 12793, 6, 1645, '', 'B', '', 1, 1, 'Y', 'L-tT4lJEjIg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5144, '2019-09-18 15:16:37.951288+00', '2019-09-18 21:02:49.972691+00', 13470, 1, 1645, '', 'B', 'Twice through (part of a longer demo).', 1, 1, 'Y', 'AG3yIgO2GTo', 98, 168, NULL);
INSERT INTO 'dancevideo' VALUES (5139, '2019-09-18 13:58:32.124256+00', '2019-09-18 21:03:23.38872+00', 16601, 1, 1645, '', 'D', 'Shows once in strathspey and twice in reel time.', 1, 1, 'Y', 'au5t6Gp897s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5147, '2019-09-18 15:41:05.934071+00', '2019-09-18 21:03:52.008711+00', 15023, 1, 1645, '', 'B', 'Once through.', 1, 1, 'Y', 'DJ1R4mAPe94', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5150, '2019-09-18 16:20:54.757655+00', '2019-09-18 21:04:33.776384+00', 3454, 1, 1645, '', 'C', '', 1, 1, 'Y', 'eELfh8dqTEs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5151, '2019-09-18 16:29:01.456111+00', '2019-09-18 21:07:03.271812+00', 9160, 2, 1645, '', 'C', '', 1, 1, 'Y', 'DZuYKLkHOwg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5140, '2019-09-18 14:05:25.389938+00', '2019-09-18 21:10:55.152545+00', 17232, 1, 1645, '', 'A', 'Four times through.', 1, 1, 'Y', 'nce6evLSaBQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5145, '2019-09-18 15:27:03.035286+00', '2019-09-18 21:10:46.931569+00', 13081, 1, 1645, '', 'B', 'Once through (the demo continues with a second repeat but all does not go quite as planned, so best just to watch the first one).', 1, 1, 'Y', 'AG3yIgO2GTo', 291, 342, NULL);
INSERT INTO 'dancevideo' VALUES (5148, '2019-09-18 16:04:05.460775+00', '2019-09-18 21:11:02.669267+00', 4398, 1, 1645, '', 'A', 'Side view of one repeat as part of a longer display. The end is adapted to move into the next dance.', 1, 1, 'Y', 'urmv5O-c4LY', 155, 218, NULL);
INSERT INTO 'dancevideo' VALUES (5149, '2019-09-18 16:08:58.604496+00', '2019-09-18 21:11:09.233908+00', 4398, 2, 1645, '', 'A', 'Top view of one repeat as part of a longer display with two back to back sets joined at 1st place. The end is adapted to move into the next dance.', 1, 1, 'Y', 'wcUehpFpr44', 158, 221, NULL);
INSERT INTO 'dancevideo' VALUES (5142, '2019-09-18 15:00:35.73751+00', '2019-09-18 21:11:31.142537+00', 13171, 1, 1645, '', 'C', 'Once through extract from a longer demo.', 1, 1, 'Y', 'SToSnDYbatE', 94, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5146, '2019-09-18 15:28:45.177603+00', '2019-09-18 21:12:28.934023+00', 6678, 1, 1645, '', 'B', 'This clip shows once through. The video continues with another repeat but inverted from the other end of the set.', 1, 1, 'Y', 'AG3yIgO2GTo', 168, 228, NULL);
INSERT INTO 'dancevideo' VALUES (5141, '2019-09-18 14:52:06.247131+00', '2019-09-18 21:15:16.075451+00', 16894, 1, 1645, '', 'C', 'Twice through, with the video starting during the first bar. The view looking up to the stage makes it hard to see the dance clearly.', 1, 1, 'Y', 'BLAyzHggkNk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5153, '2019-09-22 08:27:44.148474+00', '2019-09-22 08:29:13.290142+00', 223, 2, 202, '', 'D', '', 1, 1, 'Y', 'zVQKiUjikxw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5154, '2019-09-22 20:04:11.53846+00', '2019-09-23 08:57:29.35421+00', 12017, 1, 1645, '', 'B', 'Three times through demo in two three couple sets (joined in the centre in 3rd place). The nearest set is viewed from the top.', 1, 1, 'Y', 'iryOTzsAlWY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5156, '2019-09-22 20:37:29.64333+00', '2019-09-23 08:52:30.67689+00', 9839, 1, 1645, '', 'C', 'The nearest set on the right is better than the one on the left.', 1, 1, 'Y', 'UzqF4LPVaj8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5158, '2019-09-22 21:19:26.663566+00', '2019-09-23 08:53:17.701443+00', 338, 1, 1645, '', 'B', 'This clip shows the first repeat. The video continues but most of the following repeats have decorations and/or "variations".', 1, 1, 'Y', 'w9JcuPx434g', 10, 48, NULL);
INSERT INTO 'dancevideo' VALUES (5155, '2019-09-22 20:12:50.787215+00', '2019-09-23 08:55:19.961416+00', 12837, 1, 1645, '', 'C', 'This 5 couple dance is here being done in a 7 couple set. Good dancing, but its a slightly wobbly and distant view of only part of the whole set, so not always easy to understand whats going on.', 1, 1, 'Y', 'UZYstP8z34Y', 103, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5157, '2019-09-22 21:04:05.750366+00', '2019-09-23 08:58:05.664824+00', 6972, 5, 1645, '', 'C', 'One or two glitches in the left hand set in the 3rd repeat. The right hand set is a bit better.', 1, 1, 'Y', 'cnB0pF12k58', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5159, '2019-09-23 08:51:43.777233+00', '2019-09-23 08:58:51.729723+00', 19663, 1, 1645, '', 'B', '', 1, 1, 'Y', 'ZpSsWWL6lC0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5163, '2019-09-24 11:34:54.633754+00', '2019-09-24 16:37:13.139163+00', 9381, 2, 1645, '', 'B', 'Public demo with a little background noise.', 1, 1, 'Y', 'HHIC9ameqxs', 48, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5160, '2019-09-24 11:04:08.061625+00', '2019-09-24 16:39:36.20564+00', 11586, 1, 1645, '', 'C', 'Three times through, once each couple, in a three couple set with the last few bars adapted to get the 1st couple to the bottom. Part of a longer display.', 1, 1, 'Y', '6qVNTxx9QRw', 84, 192, NULL);
INSERT INTO 'dancevideo' VALUES (5164, '2019-09-24 20:10:23.514383+00', '2019-09-24 22:53:40.006611+00', 4948, 1, 1645, '', 'A', '', 1, 1, 'Y', 'kDOhlK4GaDM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5166, '2019-09-24 22:01:39.165434+00', '2019-09-24 22:53:57.918663+00', 12316, 1, 1645, '', 'B', '', 1, 1, 'Y', '1fCNLGfbrFg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5165, '2019-09-24 20:30:16.275493+00', '2019-09-24 22:55:13.309187+00', 18947, 1, 1645, '', 'A', '', 1, 1, 'Y', '0gfWLQNEWd0', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5167, '2019-09-24 22:17:52.305766+00', '2019-09-24 22:57:41.017761+00', 3390, 1, 1645, '', 'B', 'Danced four times in an adaptation for a three couple set: 1st couple here cast off to the bottom (instead of to 2nd place) at the end of the promenade. This clip starts with the dancing. The whole video begins with a walk through.', 1, 1, 'Y', 'hWVbUUlyyrA', 48, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5168, '2019-09-24 22:49:41.948228+00', '2019-09-24 22:57:54.038663+00', 19635, 1, 1645, '', 'B', '', 1, 1, 'Y', 'vK4X9cADScE', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5135, '2019-09-18 13:00:38.328241+00', '2019-12-14 16:37:41.213675+00', 10198, 1, 1645, '', 'B', 'Danced here in a five couple set. This clip shows the dance though the video starts with a demonstration of the corner partner figure (starting with 2nd corners).', 1, 1, 'Y', 'auXH4zscHGs', 32, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5136, '2019-09-18 13:08:04.876809+00', '2019-12-14 16:40:56.253172+00', 10199, 1, 1645, '', 'B', 'Here danced just twice through in a five couple set (though intended for seven). This clip shows the performance of the dance though the video starts with a demonstration of the corner partner figure (starting with 2nd corner).', 1, 1, 'Y', '1wT0uFCBebQ', 23, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6677, '2020-01-10 01:16:59.351568+00', '2020-01-16 17:26:53.878939+00', 8146, 5, 1296, '', '?', '', 1, 1, 'Y', 'Gz3pdlZhO30', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6676, '2020-01-10 01:16:59.339826+00', '2020-01-16 17:27:31.39828+00', 8146, 4, 1296, '', '?', '', 1, 1, 'Y', '1dcLn1K1gdI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5169, '2019-09-25 22:58:18.337247+00', '2019-09-25 22:58:32.652336+00', 18020, 1, 1645, '', 'D', 'Couples gradually start joining the floor and dancing this once the music has started and as the video progresses.', 1, 1, 'Y', '8KkoExPh9H4', 38, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5170, '2019-09-26 03:41:15.979365+00', '2019-09-26 10:54:31.53666+00', 11480, 1, 3159, '', 'C', '', 1, 1, 'Y', 'l67FVFTx5AY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5178, '2019-09-26 16:28:03.522643+00', '2019-09-26 17:23:04.807078+00', 12996, 1, 2220, '', 'C', 'The polite turn at the end of rights and lefts the second time is omitted -- Tim was explicit that it should be included, as it  is in the first time through.  The dance is intended as a 3 cpl dance in a 4 cpl set, but has been modified here to be a 3 couple set.', 1, 1, 'Y', 'G-tieo6B9zk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5182, '2019-09-26 21:47:16.18077+00', '2019-09-26 21:47:32.234015+00', 8069, 1, 106, '', 'B', 'Kelowna Scottish Country Dancers    May 2017  ', 1, 1, 'Y', 'MzV2QarHf0k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5186, '2019-10-01 00:40:04.4551+00', '2019-10-01 00:40:04.4551+00', 109, 6, 1296, '', 'X', '''Alltshellach'' is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'DRKa1wunswA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5187, '2019-10-01 00:40:04.485489+00', '2019-10-01 00:40:04.485489+00', 4491, 5, 1296, '', 'X', '''Miss Hadden''s Reel'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'WuD_euISFTs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5188, '2019-10-01 00:40:04.520823+00', '2019-10-01 00:40:04.520823+00', 7061, 8, 1296, '', 'X', '''The Westminster Reel'' is a 32 bar reel for 2 couples.', 1, 1, 'Y', 'iwkia_A6hgY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5184, '2019-09-27 21:26:50.186356+00', '2019-10-01 11:49:33.574987+00', 9106, 5, 1645, '', 'B', 'Once through.', 1, 1, 'Y', '6w3M0YBS45I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5183, '2019-09-27 21:22:14.392684+00', '2019-10-01 11:50:37.18097+00', 9082, 1, 1645, '', 'B', 'Twice though. Starts about two bars into the dance.', 1, 1, 'Y', 'thi6F5zNSDU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5180, '2019-09-26 17:59:24.325922+00', '2019-10-01 11:53:56.162131+00', 18552, 1, 1645, '', 'C', 'Twice through with John (the deviser) and Margaret McCallum as first couple. The choreography is clear but the audio track seems to get progressively less synchronised with the dancing.', 1, 1, 'Y', 'mjLZ0GJ-zkA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5179, '2019-09-26 17:49:42.674852+00', '2019-10-01 11:54:49.229012+00', 13113, 1, 1645, '', 'D', 'Reasonable dancing but the camera is moving around and cutting between sets so its hard to get a good overview of the dance from the video.', 1, 1, 'Y', 'fMM-6GTmNig', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5185, '2019-09-27 21:38:29.680984+00', '2019-10-01 11:57:32.651782+00', 19681, 1, 1645, '', 'B', 'Twice though, once per couple in a three couple set with 1st couple slipping to the bottom.', 1, 1, 'Y', 'jhOxxwJBewg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5181, '2019-09-26 18:07:47.768658+00', '2019-10-01 13:29:21.685706+00', 16610, 1, 1645, '', 'C', 'The deviser starts in 1st man''s position. The choreography is clear but the audio seems to get progressively out of synch.', 1, 1, 'Y', '23-rmXD6PCE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5189, '2019-10-03 20:22:42.110153+00', '2019-10-03 20:34:40.316067+00', 19308, 1, 1645, '', 'B', 'Occasionally out of view of the camera but still very clear with beaming smiles all round.', 1, 1, 'Y', 'uHguarxYV_k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5190, '2019-10-03 20:34:03.083908+00', '2019-10-03 20:34:50.6465+00', 19307, 1, 1645, '', 'B', 'Good, with one or two late or false starts. The camera is a bit too close to catch everything but its still pretty clear.', 1, 1, 'Y', '3_NOnayxUuI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5194, '2019-10-03 21:26:15.49262+00', '2019-10-05 10:02:46.400423+00', 7366, 1, 1645, '', 'B', 'Three times through.', 1, 1, 'Y', '_vbfqkuGDwo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5192, '2019-10-03 20:58:06.016539+00', '2019-10-05 10:10:50.608883+00', 15889, 1, 1645, '', 'C', 'The best two repeats from a longer video.', 1, 1, 'Y', 'mvpNZiX0zVs', 73, 140, NULL);
INSERT INTO 'dancevideo' VALUES (5195, '2019-10-03 21:49:03.200355+00', '2019-10-05 10:06:05.035962+00', 8047, 1, 1645, '', 'B', 'The first two repeats are excellent but a few mistakes creep in later on.', 1, 1, 'Y', 'XYAhDR0cBso', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5175, '2019-09-26 11:26:35.806428+00', '2019-10-16 03:41:32.311435+00', 1128, 5, 1645, '', 'B', 'Once through clip from a longer demo with the final promenade adapted to lead into the next dance.', 1, 1, 'Y', '0uQiDKdwJMs', 57, 113, NULL);
INSERT INTO 'dancevideo' VALUES (5197, '2019-10-03 22:09:03.850361+00', '2019-10-05 10:06:16.933214+00', 19609, 1, 1645, '', 'B', 'Once through in one 3 couple set, then another twice through in two 3 couple sets.', 1, 1, 'Y', 'mvEKFpkKPmY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5191, '2019-10-03 20:43:25.169587+00', '2019-10-05 09:58:53.487438+00', 8039, 1, 1645, '', 'C', '', 1, 1, 'Y', '_Wn5ZToubqE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5196, '2019-10-03 22:02:27.744476+00', '2019-10-05 10:00:18.18866+00', 10650, 3, 1645, '', 'C', 'Starts and ends well, but some mishaps in a couple of the repeats in between.', 1, 1, 'Y', 'cZWbva0XhEk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5193, '2019-10-03 21:10:50.306322+00', '2019-10-05 10:01:51.152239+00', 10692, 1, 1645, '', 'B', 'This clip has four repeats (earlier in the video the camera is moving around). The very experienced dancers here are  doing the variation with mirror reels of three on the sides in bars 9-16 instead of the default figures of 8 on the sides for 1st couple alone.', 1, 1, 'Y', 'kbKAA0EV6Nw', 132, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5198, '2019-10-03 22:35:48.882361+00', '2019-10-05 10:09:02.781473+00', 15072, 1, 1645, '', 'B', 'Fine, with one little crossing error in the last few bars of the last repeat.', 1, 1, 'Y', 'NpjwudcXrns', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5225, '2019-10-08 21:02:22.301102+00', '2019-10-09 22:21:15.970792+00', 18093, 1, 1645, '', 'B', '', 1, 1, 'Y', 'z8zq3GVJMUI', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5216, '2019-10-06 14:53:51.463884+00', '2019-10-06 18:42:36.67213+00', 10774, 1, 2636, '', 'B', '', 1, 1, 'Y', 'xiZhRE2dN8k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5199, '2019-10-05 10:27:00.212046+00', '2019-10-06 18:43:40.567511+00', 12897, 1, 1645, '', 'C', 'The first two and last repeats work well, the central four repeats have some mistakes in the "cross and rotate" figure.', 1, 1, 'Y', '3WvQmw9YGRs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5201, '2019-10-05 11:27:19.506872+00', '2019-10-06 18:44:37.798099+00', 8111, 1, 1645, '', 'A', 'Twice through as part of a longer demo - both times in two 2 couple sets.



The end of the 2nd repeat is adapted to lead into the next dance: all four couples turn both hands, one and a half in the right hand set, instead of just the 1st couple in each set.', 1, 1, 'Y', '1Q8wxnW-3p4', 628, 756, NULL);
INSERT INTO 'dancevideo' VALUES (5200, '2019-10-05 11:00:55.386771+00', '2019-10-06 18:46:00.446491+00', 13938, 1, 1645, '', 'C', '', 1, 1, 'Y', 'Xx4-64VZiOU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5215, '2019-10-05 20:12:27.457239+00', '2019-10-06 18:46:31.647752+00', 16053, 1, 1645, '', 'B', '', 1, 1, 'Y', '1SOcRyO6t5c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5214, '2019-10-05 20:06:38.555137+00', '2019-10-06 18:47:29.43726+00', 1852, 1, 1645, '', 'B', 'This clip shows the dancing (some of which is out of view). This on-location video starts with a walkthrough.', 1, 1, 'Y', '-j3oJDn9tcE', 101, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5212, '2019-10-05 19:47:44.145221+00', '2019-10-06 18:47:38.942195+00', 5459, 1, 1645, '', 'A', '', 1, 1, 'Y', '6YvyGZGerI4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5202, '2019-10-05 11:34:50.015555+00', '2019-10-06 18:49:51.412247+00', 10695, 2, 1645, '', 'A', 'Twice through as part of a longer demo, here in two back to back 2 couple sets joined at 2nd place.', 1, 1, 'Y', '1Q8wxnW-3p4', 756, 831, NULL);
INSERT INTO 'dancevideo' VALUES (5211, '2019-10-05 18:58:37.239232+00', '2019-10-06 18:51:02.860344+00', 19602, 1, 1645, '', 'B', 'This video first shows a demonstration of the "Keppoch" formation, then from 0:28 the dance is done once in one 3 couple set. This is followed from 1:06 by the full three times through in three  sets.', 1, 1, 'Y', 'ohbOCKbT9F0', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5208, '2019-10-05 13:28:50.48226+00', '2019-10-06 18:51:21.941922+00', 10905, 1, 1645, '', 'D', '', 1, 1, 'Y', 'oOFZi9Zkz2A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5209, '2019-10-05 17:16:42.133109+00', '2019-10-06 18:52:05.864383+00', 4048, 1, 1645, '', 'B', '', 1, 1, 'Y', 'ta7BpiMjAOw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5210, '2019-10-05 17:26:20.316979+00', '2019-10-06 18:52:37.188624+00', 5260, 3, 1645, '', 'B', '', 1, 1, 'Y', '5lIl7J97ZxU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5207, '2019-10-05 13:04:36.2809+00', '2019-10-06 18:53:11.944057+00', 15062, 1, 1645, '', 'C', 'Starts very well but a few wrong shoulder mishaps in the last two repeats.', 1, 1, 'Y', 'PEAahxerVbc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5203, '2019-10-05 11:47:02.75043+00', '2019-10-06 18:54:14.044097+00', 19555, 1, 1645, '', 'B', 'Twice through in a 3 couple set as part of a longer demo. The dance is adapted with a 3 couple poussette at the end instead of a 2 couple poussette. Here 2nd and 3rd couples add polite turns after the half rights and lefts of bars 5-8 whereas the crib suggests they should not.', 1, 1, 'Y', '1Q8wxnW-3p4', 1016, 1091, NULL);
INSERT INTO 'dancevideo' VALUES (5206, '2019-10-05 12:49:12.307432+00', '2019-10-06 18:54:43.509887+00', 6116, 1, 1645, '', 'A', 'Once through as part of a longer Newcastle demo. The dance is slightly adapted:  

- on bars 1-8 both 1st and 3rd couples are dancing instead of just 1st couple;  

- after the hands across figures of bars 17-24 the orientation of the set is rotated 90 degrees.', 1, 1, 'Y', 'ukQgBPv9Nb0', 242, 304, NULL);
INSERT INTO 'dancevideo' VALUES (5205, '2019-10-05 12:38:52.348542+00', '2019-10-06 18:55:02.996973+00', 6153, 1, 1645, '', 'B', 'First part of a Newcastle display. Excellent dancing and a lot of fun, but all the umbrellas make the choreography a little hard to follow! The end is also adapted to lead into the next dance. Its all a bit too (delightfully) distracting to be of much use in learning the dance.', 1, 1, 'Y', 'ukQgBPv9Nb0', 19, 162, NULL);
INSERT INTO 'dancevideo' VALUES (5204, '2019-10-05 11:56:41.349664+00', '2019-10-06 18:55:26.551171+00', 14053, 1, 1645, '', 'A', 'Twice through, once per couple, in a 3 couple set as part of a longer demo.', 1, 1, 'Y', '1Q8wxnW-3p4', 1091, 1217, NULL);
INSERT INTO 'dancevideo' VALUES (5217, '2019-10-06 19:46:15.970726+00', '2019-10-06 19:55:06.549665+00', 14401, 3, 1645, '', 'A', 'Twice through.', 1, 1, 'Y', 'iCaWaZINbi8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (92, '2012-05-06 13:38:41.364893+00', '2012-05-06 13:39:49.71598+00', 4239, 1, 1, '', 'B', '', 1, 1, 'Y', '6MNcyHFlxUI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5173, '2019-09-26 11:13:46.955366+00', '2022-02-24 17:16:22.986949+00', 10198, 2, 1645, '', 'B', 'Leicester RSCDS at the 2019 ASCDS festival. Once through clip from a longer display. Danced in a five couple set (instead of seven). View from the side.', 1, 1, 'Y', '5cq7_TKdne8', 122, 182, NULL);
INSERT INTO 'dancevideo' VALUES (5218, '2019-10-06 19:53:13.010279+00', '2019-10-06 19:55:28.97435+00', 14401, 4, 1645, '', 'B', 'Generally good dancing with quite a few extra twirls though with rather few 1st couples dancing a long way down in bars 1-4 as the instructions encourage them to do.', 1, 1, 'Y', 'ivArGukAdcc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5226, '2019-10-08 21:08:53.720968+00', '2019-10-09 22:27:19.650662+00', 18100, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'olRkfGd-1Pc', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5220, '2019-10-08 19:54:59.682279+00', '2019-10-09 22:17:26.968968+00', 17745, 1, 1645, '', 'B', 'Twice through showing two different sets.', 1, 1, 'Y', '6fv66mWZgjk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5227, '2019-10-08 21:13:13.738429+00', '2019-10-09 22:16:55.927897+00', 18095, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'fLB7IKodoWI', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5230, '2019-10-08 21:24:43.466709+00', '2019-10-09 22:18:55.593629+00', 18101, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'vIEWv5D8raA', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5231, '2019-10-08 21:28:02.839977+00', '2019-10-09 22:19:44.821651+00', 18098, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'Zwnyvdg_mig', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5223, '2019-10-08 20:36:17.157958+00', '2019-10-09 22:22:35.044372+00', 8170, 1, 1645, '', 'C', 'This clip shows three times through (the full video starts part way through the first repeat).', 1, 1, 'Y', '1qldXQxkBcI', 13, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5224, '2019-10-08 20:36:45.56673+00', '2019-10-09 22:22:09.767721+00', 8170, 2, 1645, '', 'B', '', 1, 1, 'Y', 'bz1LvviXqvo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5222, '2019-10-08 20:15:32.660802+00', '2019-10-09 22:23:08.878477+00', 14340, 1, 1645, '', 'D', 'Three times through in a 3 couple set with 1st couple slipping to the bottom each time. The half reels in bars 9-12 and 21-24 should be left shoulder but are here danced right shoulder both times. This means 1st couple dance round 1st corner position twice in a row instead of just for the first half diagonal reel. They are having fun, but its not a good example to follow.', 1, 1, 'Y', 'nCL9keOU_bA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5221, '2019-10-08 20:01:28.266879+00', '2019-10-09 22:23:17.520533+00', 4358, 2, 1645, '', 'B', 'Three times through by different couples in two sets.', 1, 1, 'Y', 'E-bhOWlr2r4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5228, '2019-10-08 21:16:50.054677+00', '2019-10-09 22:28:39.700892+00', 18094, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', '1R3c7qd7L54', 9, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5219, '2019-10-08 19:45:49.631172+00', '2019-10-09 22:25:35.843527+00', 5141, 1, 1645, '', 'B', 'Clear demonstration with close ups of some beautiful footwork in the setting sections. The instructions suggest men have hands on partners waists for the reels of bars 97-108 which are here done without hands.', 1, 1, 'Y', 'KH2fiUcbwxM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5232, '2019-10-08 21:34:54.5423+00', '2019-10-09 22:26:23.023458+00', 12449, 1, 1645, '', 'B', '', 1, 1, 'Y', '2BNN5IaZtHI', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5233, '2019-10-08 21:41:25.488459+00', '2019-10-09 22:28:13.669603+00', 18092, 1, 1645, '', 'B', '', 1, 1, 'Y', '4U3n7OIqnOk', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5236, '2019-10-10 18:11:52.855815+00', '2019-10-11 09:59:03.931624+00', 10892, 1, 1645, '', 'C', 'One or two hesitations but the coloured shirts make the choreography clear. At the end of the video there is an explanation about the origin of the dance.', 1, 1, 'Y', 'iF4Cz0H1Q6Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5235, '2019-10-10 17:54:43.003566+00', '2019-10-11 09:35:34.646717+00', 2110, 4, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'gvc0HmGescs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5234, '2019-10-10 17:50:57.736342+00', '2019-10-11 09:50:41.533225+00', 5643, 1, 1645, '', 'D', 'Some couples are just crossing at the end instead of turning one and a half times.', 1, 1, 'Y', 'u_UTBhRYsYE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5213, '2019-10-05 19:48:06.819092+00', '2019-10-06 18:49:08.297348+00', 1881, 1, 1645, '', 'B', '', 1, 1, 'Y', 'Y6LkqDU67yI', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5238, '2019-10-10 18:41:18.188506+00', '2019-10-11 09:53:27.784339+00', 7260, 2, 1645, '', 'A', 'Excellent dancing but from low down so not such a good view. Twice through, but in the second repeat the reels of four across the set are adapted to cross between the two sets.', 1, 1, 'Y', 'YMPMY3rMuPU', 267, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5251, '2019-10-10 22:26:31.015921+00', '2019-10-10 22:26:48.636402+00', 19692, 1, 106, '', 'B', 'Kitchener-Waterloo And Blair Scottish Country Dancers, 2018', 1, 1, 'Y', 'i2BshnwFE44', 42, 112, NULL);
INSERT INTO 'dancevideo' VALUES (5248, '2019-10-10 21:42:03.724499+00', '2019-10-11 09:29:15.162603+00', 10071, 3, 1645, '', 'B', 'The 100th video made by this group which consistently produces choreographically very clear demonstrations of dances that lack good videos.', 1, 1, 'Y', 'WH_Z0CReFYg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5242, '2019-10-10 19:27:04.782257+00', '2019-10-11 09:31:01.398311+00', 19141, 1, 1645, '', 'C', '', 1, 1, 'Y', '5w7Gz7WMVO8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5237, '2019-10-10 18:26:28.630613+00', '2019-10-11 09:32:01.046884+00', 11240, 1, 1645, '', 'A', 'This clip shows the dance once through. The video continues with a second repeat but the end of that one is adapted to lead into the next dance in a demonstration medley.', 1, 1, 'Y', 'YMPMY3rMuPU', 60, 98, NULL);
INSERT INTO 'dancevideo' VALUES (5240, '2019-10-10 19:05:28.833822+00', '2019-10-11 09:33:02.328472+00', 18442, 1, 1645, '', 'C', 'This clip shows the dance. The video starts with an introduction about the deviser Francis Walduck.', 1, 1, 'Y', '4OXuxdhS0a8', 150, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5250, '2019-10-10 22:14:28.998557+00', '2019-10-11 09:33:52.99631+00', 19691, 1, 1645, '', 'B', '', 1, 1, 'Y', '8JjRNRXvBos', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5244, '2019-10-10 20:57:14.018076+00', '2019-10-11 09:34:46.331352+00', 17105, 1, 1645, '', 'B', '', 1, 1, 'Y', 'CR57JFJkIwc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5245, '2019-10-10 21:05:52.238833+00', '2019-10-11 09:36:07.948955+00', 15586, 2, 1645, '', 'B', '', 1, 1, 'Y', 'tekCYzUTc7k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5249, '2019-10-10 21:51:31.22467+00', '2019-10-11 09:36:33.016309+00', 19281, 1, 1645, '', 'B', '', 1, 1, 'Y', 'GeXEUn_hLyk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5243, '2019-10-10 19:41:33.284057+00', '2019-10-11 09:37:04.335729+00', 15068, 1, 1645, '', 'C', 'Two repeats from a longer video.', 1, 1, 'Y', 'yH9-VYcgnQY', 71, 142, NULL);
INSERT INTO 'dancevideo' VALUES (5254, '2019-10-11 18:42:26.469612+00', '2019-10-11 21:21:26.383738+00', 19622, 1, 1645, '', 'B', '', 1, 1, 'Y', 'u1cNMUCP9rk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5246, '2019-10-10 21:13:19.059329+00', '2019-10-11 09:43:55.472771+00', 5389, 2, 1645, '', 'B', 'The 1st couples here slip to the bottom after two repeats as usual, although the deviser suggested they should repeat the reels of bars 1-8 a 3rd time. See the <<https://my.strathspey.org/dd/dance/5389/#extrainfo|extra info>> for the dance.', 1, 1, 'Y', '9gad-7ydkJE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5247, '2019-10-10 21:22:37.356479+00', '2019-10-11 09:44:15.024852+00', 11919, 1, 1645, '', 'B', '', 1, 1, 'Y', 'KhARL1fKJyw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5256, '2019-10-11 18:51:23.521026+00', '2019-10-11 21:21:32.717842+00', 11749, 1, 1645, '', 'B', '', 1, 1, 'Y', '64P8P9RvkHA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5253, '2019-10-11 18:38:14.721162+00', '2019-10-11 21:21:46.707282+00', 19475, 1, 1645, '', 'B', '', 1, 1, 'Y', '_8RkbgaY9qk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5239, '2019-10-10 18:51:01.16377+00', '2019-10-11 09:49:45.3516+00', 6037, 6, 1645, '', 'B', 'Excellent dancing. However the dancers closest to the camera are doing an adaptation for four dancers instead of three. The two pairs at each end are dancing reflected footwork in the setting parts (as are the lines of three behind them). A very impressive demonstration which is faithful to the spirit but not the letter of the original.', 1, 1, 'Y', 'YMPMY3rMuPU', 133, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5252, '2019-10-11 17:54:48.047605+00', '2019-10-11 17:55:15.51065+00', 18177, 1, 1645, '', 'B', '', 1, 1, 'Y', '1HM-sjuPREA', 44, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5258, '2019-10-11 20:18:29.8395+00', '2019-10-12 12:23:46.444131+00', 1931, 9, 1645, '', 'D', 'Not useful for learning the dance, but an impressive display at what is claimed to be the largest ever demonstration of SCD involving 960 dancers (120 sets) at the 1993 Toronto International Festival Tattoo.', 1, 1, 'Y', 'O96XWcNCRIc', 613, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5260, '2019-10-11 20:52:13.324038+00', '2019-10-11 21:21:57.226348+00', 19693, 1, 1645, '', 'A', 'Twice though (followed by the next dance in a demonstation medley).', 1, 1, 'Y', '17UxOxtRtRM', 30, 105, NULL);
INSERT INTO 'dancevideo' VALUES (5259, '2019-10-11 20:23:43.672453+00', '2019-10-11 21:22:09.383813+00', 4044, 1, 1645, '', 'A', '', 1, 1, 'Y', 'GGbeAUrPh6Y', 226, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5255, '2019-10-11 18:44:57.170928+00', '2019-10-11 21:22:15.966022+00', 5178, 1, 1645, '', 'B', '', 1, 1, 'Y', 'pQRtzxjAzT0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5257, '2019-10-11 18:56:41.917017+00', '2019-10-11 21:22:25.523542+00', 6484, 4, 1645, '', 'B', '', 1, 1, 'Y', '9WIyWDKha6s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5261, '2019-10-11 21:20:57.919987+00', '2019-10-11 21:23:22.969245+00', 16018, 2, 1645, '', 'C', 'Twice though, one time for each of two sets being coached through the dance. Various hesitations and corrections but still a reasonable impression.', 1, 1, 'V', '77191573', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5264, '2019-10-11 22:20:13.691868+00', '2019-10-12 12:24:15.71891+00', 354, 1, 1645, '', 'A', '', 1, 1, 'Y', 'eVxI5xmFe3Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5263, '2019-10-11 22:10:59.430042+00', '2019-10-12 12:24:36.655526+00', 10456, 1, 1645, '', 'C', 'The dancers here are turning 3/4 left hand in the middle of the celtic reels of bars 9-24 instead of the usual left shoulder pass.', 1, 1, 'Y', '_GPyKXI7auE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5262, '2019-10-11 21:58:59.747128+00', '2019-10-12 12:25:14.440985+00', 9204, 1, 1645, '', 'C', 'Good dancers having fun at a ball adding lots of extra twirls (and the odd collision).', 1, 1, 'Y', 'wUpf1LfYW9c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (91, '2012-05-06 13:36:08.715452+00', '2012-05-06 13:40:19.89141+00', 4641, 1, 1, '', 'D', '', 1, 1, 'Y', '11-ZfPa4Xr8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5265, '2019-10-11 22:48:26.12774+00', '2019-10-11 22:53:54.843055+00', 15498, 1, 106, '', 'B', 'Middle part of a longer display.  Twice through, all 4 couples starting. The final 4 bars are modified to link to the following dance of the display.', 1, 1, 'Y', 'i2BshnwFE44', 113, 234, NULL);
INSERT INTO 'dancevideo' VALUES (5266, '2019-10-11 23:37:58.946564+00', '2019-10-11 23:38:57.792937+00', 1544, 7, 106, '', 'B', 'Final part of a longer display', 1, 1, 'Y', 'i2BshnwFE44', 234, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5270, '2019-10-12 13:48:51.877543+00', '2019-10-14 20:01:41.867409+00', 13817, 1, 1645, '', 'B', 'Twice through (part of a longer demo).', 1, 1, 'Y', 'vTIhwxHeDs0', 167, 291, NULL);
INSERT INTO 'dancevideo' VALUES (5279, '2019-10-14 09:23:38.670622+00', '2019-10-14 09:25:30.801668+00', 19697, 1, 1645, '', 'B', '', 1, 1, 'Y', 'jlWRUpewEUk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5280, '2019-10-14 11:03:51.730515+00', '2019-10-14 11:04:58.773566+00', 19698, 1, 1645, '', 'B', '', 1, 1, 'Y', 'Y1y__gXNeLM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5278, '2019-10-13 22:34:01.418648+00', '2019-10-14 20:00:01.669643+00', 2443, 1, 1645, '', 'C', 'Twice through. The video starts around bar 5 (missing the first cross and cast).', 1, 1, 'Y', 'wxy3-jknL2I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5277, '2019-10-13 20:35:44.186443+00', '2019-10-14 20:00:39.767632+00', 13680, 1, 1645, '', 'B', '', 1, 1, 'Y', '7Pz4V8-FSus', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5274, '2019-10-13 18:19:08.752012+00', '2019-10-14 20:01:09.772026+00', 15404, 1, 1645, '', 'C', 'Four times, from two different angles. The dancing couples often take hands crossing down for the first two bars which is not specified in the instructions.', 1, 1, 'Y', 'h4MWHCdWNBs', 0, 203, NULL);
INSERT INTO 'dancevideo' VALUES (5269, '2019-10-12 13:42:47.421981+00', '2019-10-14 20:02:33.052673+00', 12720, 1, 1645, '', 'B', 'Twice through as the last part of a longer demo.', 1, 1, 'Y', 'vTIhwxHeDs0', 291, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5272, '2019-10-12 14:08:24.279182+00', '2019-10-14 20:03:38.038666+00', 18611, 1, 1645, '', 'B', 'Danced once in a single set, then three times more in three sets (the furthest one centred between the nearer two).', 1, 1, 'Y', '2RhKWQCtWt8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5276, '2019-10-13 19:46:47.221235+00', '2019-10-14 20:04:36.814528+00', 19118, 2, 1645, '', 'C', '', 1, 1, 'Y', 'Cw98MYvVqBQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5268, '2019-10-12 13:35:07.538796+00', '2019-10-14 20:05:01.624043+00', 19694, 1, 1645, '', 'X', '', 1, 1, 'Y', 'sOJx0hy05E8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5267, '2019-10-12 13:23:22.559986+00', '2019-10-14 20:06:02.181902+00', 8525, 1, 1645, '', 'B', 'Twice through - one corrected near mistake in the reels 2nd time through.', 1, 1, 'Y', 'Oa9AN3C8SRA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5275, '2019-10-13 18:27:42.902954+00', '2019-10-14 20:06:58.059699+00', 12534, 1, 1645, '', 'C', 'Once through.', 1, 1, 'Y', 'plIwXFmlR1c', 0, 42, NULL);
INSERT INTO 'dancevideo' VALUES (5271, '2019-10-12 13:54:51.765387+00', '2019-10-14 20:07:49.839042+00', 13820, 1, 1645, '', 'B', 'Danced twice though in a 3 couple set as part of a longer demo.', 1, 1, 'Y', 'vTIhwxHeDs0', 95, 167, NULL);
INSERT INTO 'dancevideo' VALUES (5273, '2019-10-12 16:04:54.651365+00', '2019-10-14 20:08:56.434074+00', 15226, 1, 1645, '', 'B', 'About seven times through - until they realise they have made a progression error earlier (in the diagonal reel of the 6th repeat around 3:00).', 1, 1, 'Y', 'iXcY5qV5DKE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5285, '2019-10-16 03:39:58.037561+00', '2019-10-16 03:45:49.366735+00', 19699, 1, 202, '', 'C', '', 1, 1, 'Y', '5VCJM_yYl-k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5283, '2019-10-15 22:02:17.097952+00', '2019-10-16 22:16:06.736146+00', 15138, 1, 1645, '', 'C', 'Twice through. Good dancing, but the whole set is rarely in view at once.', 1, 1, 'Y', 'ozvPOBSF5I8', 41, 159, NULL);
INSERT INTO 'dancevideo' VALUES (5282, '2019-10-15 21:50:48.724221+00', '2019-10-16 22:19:36.922077+00', 18022, 1, 1645, '', 'B', 'Good, but rather dark and distant video, so a little hard to make out. Four times through.', 1, 1, 'Y', '7RBn_8ojVfI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5287, '2019-10-16 10:35:49.637234+00', '2019-10-16 22:13:10.614599+00', 17142, 3, 1645, '', 'B', 'Twice through, once per couple, in two 3 couple sets as part of a longer demonstration medley.', 1, 1, 'Y', 'i8_BnpHAaIo', 47, 122, NULL);
INSERT INTO 'dancevideo' VALUES (5286, '2019-10-16 10:30:53.515551+00', '2019-10-16 22:14:04.357915+00', 2235, 1, 1645, '', 'B', 'Once through as part of a longer demonstration.', 1, 1, 'Y', 'i8_BnpHAaIo', 122, 183, NULL);
INSERT INTO 'dancevideo' VALUES (5284, '2019-10-15 22:09:37.193422+00', '2019-10-16 22:14:49.115738+00', 17266, 1, 1645, '', 'C', 'Danced in a 5 couple set. Choreographically clear though some dancers are just walking.', 1, 1, 'Y', 'y71zCKpcVdU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5288, '2019-10-17 08:28:26.253176+00', '2019-10-17 08:28:53.234585+00', 6957, 3, 202, '', 'D', '', 1, 1, 'Y', 'GpN0qfvuHaE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5289, '2019-10-17 08:31:24.944745+00', '2019-10-17 08:31:52.086004+00', 13689, 2, 202, '', 'D', '', 1, 1, 'Y', 'Ub2E_IJs0YE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5290, '2019-10-17 08:33:46.571235+00', '2019-10-17 08:34:35.312327+00', 13589, 6, 202, '', 'D', '', 1, 1, 'Y', 'AZLzRnhJVCg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (182, '2012-09-09 13:53:58.816431+00', '2019-10-17 14:24:07.894949+00', 1480, 2, 1041, '', 'C', 'Note that W2 [closest to men’s side in line of 4] incorrectly turns inward (LS-back) at bottom; all should turn RS-back)

', 1, 1, 'Y', 'QhJQG6hvKc0', 272, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5291, '2019-10-19 23:40:52.780604+00', '2019-10-20 08:18:46.534631+00', 2934, 2, 3637, '', 'C', 'Attendees at the Silver State Scottish Dancer''s Truckee (California ) Workshop & Dance, 25 June 2016 enjoying dancing to music by Thistle Glen. The whole video starts in the midst of "set to and turn corners". This clip starts at 0.20secs with a new repetition.  Video is by Rachel Pusey', 1, 1, 'Y', 'OhF3DiUgZt8', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5292, '2019-10-21 18:17:52.53657+00', '2019-10-21 18:19:42.240522+00', 5525, 20, 202, '', 'B', '', 1, 1, 'Y', 'K03PXySIzqg', 0, 274, NULL);
INSERT INTO 'dancevideo' VALUES (5304, '2019-10-24 16:40:00.345241+00', '2019-10-24 16:57:29.388126+00', 19712, 1, 1645, '', 'A', '', 1, 1, 'Y', 'bqIQC308DQw', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5293, '2019-10-21 20:28:58.574727+00', '2019-10-21 21:50:12.865386+00', 5687, 1, 106, '', 'D', 'Open air dancing in the sun under the walls of Roslin Castle.  Long line of sets, some poorly lit.  Videoed from a lower position, and panning from set to set.  Quite some inexperienced dancers, often missing the L shoulder pass on bar 24.   Not very useful for learning the dance.  8 times through.', 1, 1, 'Y', 'ABn9FZCX1aw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5294, '2019-10-22 00:40:03.59526+00', '2019-10-22 00:40:03.664737+00', 13961, 1, 1296, '', 'Z', '''The Clement Street Reel'' is a 32 bar reel for 2 couples.', 1, 1, 'Y', 'ikUA6umUmNE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5296, '2019-10-22 00:40:03.683609+00', '2019-10-22 00:40:03.683609+00', 13961, 2, 1296, '', 'X', '''Maids in the Mirror'' is a 32 bar reel for 2 couples.', 1, 1, 'Y', 'UThXmmvoQi8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5297, '2019-10-22 00:40:03.729486+00', '2019-10-22 00:40:03.729486+00', 9701, 2, 1296, '', 'X', '''Miss Jane Muirhead of Dunsmuir'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '-I_WwwPrPuI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5299, '2019-10-22 00:40:03.781573+00', '2019-10-22 00:40:03.781573+00', 6489, 1, 1296, '', 'X', '''Tayport Beauty'' is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'gCRSgzcAhFU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5295, '2019-10-22 00:40:03.638544+00', '2019-10-23 00:40:03.986257+00', 16086, 1, 1296, '', 'Z', '''The Fiddler''s Wife'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'wByPt2SmK08', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4221, '2019-01-09 15:51:32.83233+00', '2019-10-23 16:08:33.476094+00', 11524, 1, 513, '', 'C', 'John Drewry''s instructions for bars 17-24 say 1st couple dance up crossing over to second place on own side to dance reels of three on the sides with 2nd and 3rd couples. 2nd couple dance in and down and 3rd couple dance down and out to enter the reels. In this demonstration 3rd couple are dancing out and up each time for this reel.', 1, 1, 'Y', 'V67zBRPkwoo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5319, '2019-10-30 22:18:24.984249+00', '2019-11-01 21:46:43.883085+00', 5099, 1, 1645, '', 'C', '', 1, 1, 'Y', 'g0hfeG27Hh4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6679, '2020-01-10 01:16:59.445504+00', '2020-01-11 14:49:20.011836+00', 7554, 7, 1296, '', 'D', '', 1, 1, 'Y', 'zNY-eCKET-c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6681, '2020-01-10 01:16:59.594435+00', '2020-01-16 14:38:05.715997+00', 5093, 3, 1296, '', 'C', '', 1, 1, 'Y', 'QN-O8QivU28', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5298, '2019-10-22 00:40:03.752105+00', '2019-10-23 18:12:22.640557+00', 10703, 2, 1296, '', 'X', '''Pint o'' Ale is Fain'' is a 32 bar jig for 3 couples.



This video shows the basic version with figures of 8 on the sides for 1st couple alone (instead of reels of three).', 1, 1, 'Y', 'ot7-Y8_Bhts', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5301, '2019-10-24 02:09:53.839896+00', '2019-10-24 02:10:30.651825+00', 16566, 4, 202, '', 'A', '', 1, 1, 'Y', 'eJX1daPtkoc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5305, '2019-10-24 16:55:35.293963+00', '2019-10-24 16:58:30.691906+00', 19717, 1, 1645, '', 'A', '', 1, 1, 'Y', 'LHLWM5pw99M', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5302, '2019-10-24 16:10:37.996318+00', '2019-10-24 16:23:51.570053+00', 458, 2, 1645, '', 'A', 'Performance of the Reel section.', 1, 1, 'Y', '6mNIN8H_3Oo', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5303, '2019-10-24 16:21:26.529444+00', '2019-10-24 16:24:08.096849+00', 458, 3, 1645, '', 'A', 'Performance of the Strathspey section of the dance.', 1, 1, 'Y', '1egtQeLmD3A', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5306, '2019-10-25 09:29:29.041385+00', '2019-10-28 09:29:25.234523+00', 19258, 1, 197, '', 'A', 'Video by Dance Scottish San Diego', 1, 1, 'Y', 'pTMvWXWNBuE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5310, '2019-10-28 13:04:52.673454+00', '2019-10-28 14:33:47.175019+00', 19725, 1, 13151, '', 'A', '"Paco''s Wiggle Waggle Walk", a 8×32 Reel, devised by Viktor Lehmann. Music thanks to Suzan MacFadyen. Dancers: Ilona Brown, Alasdair Brown, Maria Terradas, Scott Smith, Fiona Scothern, Niall Bootland. Thanks to Debra McAlees for recording @ Glasgow, 23 Oct 2019.', 1, 1, 'Y', 'OS3_FuDyBo8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (96, '2012-06-11 00:12:50.512172+00', '2012-06-11 05:41:52.283701+00', 413, 1, 961, '', 'B', '', 1, 1, 'Y', 'nur7PAeO8jw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (164, '2012-09-06 17:13:58.446592+00', '2012-09-06 17:14:24.023165+00', 3435, 2, 106, '', 'D', 'RSCDS Seattle branch Social Dance Feb 2012', 1, 1, 'Y', 'x97jg6zAhAo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5312, '2019-10-29 11:44:48.817363+00', '2019-10-29 18:32:43.253674+00', 16730, 1, 1645, '', 'A', 'Once through extract from a longer demo. The circle and back of bars 33-40 is here adapted, to circle one way and cross over, in order to lead into the next dance. So only bars 1-32 are as per the instructions.', 1, 1, 'Y', 'kgqdeIP0oK8', 421, 469, NULL);
INSERT INTO 'dancevideo' VALUES (5308, '2019-10-28 12:42:55.974668+00', '2019-10-28 14:35:25.28882+00', 1603, 1, 1645, '', 'D', 'Set being coached through the dance at a ceilidh.', 1, 1, 'Y', 'mqI455lXlk8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5309, '2019-10-28 12:53:05.229642+00', '2019-10-28 14:36:20.81543+00', 6916, 1, 1645, '', 'A', 'Demo with explanatory voice over. Six times through.', 1, 1, 'Y', 'duHP3hDsuUc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5313, '2019-10-29 18:47:43.431687+00', '2019-10-29 18:53:46.49611+00', 19701, 1, 1645, '', 'B', '', 1, 1, 'Y', '3COhIoHN7lU', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5311, '2019-10-29 11:20:21.87148+00', '2019-10-29 18:27:21.945189+00', 16728, 2, 1645, '', 'A', 'Twice through extract from a longer demo.', 1, 1, 'Y', 'kgqdeIP0oK8', 133, 210, NULL);
INSERT INTO 'dancevideo' VALUES (5314, '2019-10-29 18:53:25.447613+00', '2019-10-29 18:54:00.969887+00', 19665, 1, 1645, '', 'B', '', 1, 1, 'Y', 'QHG2OTkDbKQ', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (218, '2012-09-11 21:31:13.991488+00', '2012-09-13 00:42:57.344861+00', 4106, 2, 1041, '', 'D', '', 1, 1, 'Y', 'K0nOe9MPd7g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3449, '2018-02-25 21:26:08.52324+00', '2018-02-26 12:24:23.852271+00', 15642, 1, 3086, '', 'A', '', 1, 1, 'Y', 'QrQObASp7ZQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (219, '2012-09-11 21:32:30.405238+00', '2012-09-13 07:29:44.983729+00', 4155, 1, 1041, '', 'B', '', 1, 1, 'Y', 'QsVuv8-FGlI', 82, 0, NULL);
INSERT INTO 'dancevideo' VALUES (257, '2012-09-13 01:20:51.604473+00', '2012-09-13 01:22:44.986821+00', 1492, 2, 106, '', 'B', '', 1, 1, 'Y', 'D1SSC614VMA', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (140, '2012-08-20 07:35:30.822972+00', '2012-08-20 21:10:13.015858+00', 13619, 1, 513, '', 'C', '', 1, 1, 'Y', 'NV6lJhERXKk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (36, '2012-02-13 11:33:17.802415+00', '2019-06-10 22:49:46.476246+00', 4803, 1, 513, '', 'A', 'Newcastle Festival 2012: Ladies (RSCDS Edinburgh)', 1, 1, 'Y', 'VGgQX54IdI8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (24, '2012-02-03 18:15:40.567348+00', '2012-02-07 11:23:36.799137+00', 794, 1, 513, '', 'A', '', 1, 1, 'Y', 'MtXyw-_7rUQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (27, '2012-02-03 18:21:58.10352+00', '2012-02-07 11:24:08.350759+00', 1501, 1, 513, '', 'A', '', 1, 1, 'Y', 'RBIzZwqRcRw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (21, '2012-01-31 11:32:46.228835+00', '2012-01-31 11:33:48.340771+00', 5525, 1, 1, '', 'D', 'This video shows a 5-couple adaptation of the dance (1st and 3rd couple starting at the same time, not the original 5-couple set version) as used for a FSCDC display on 25 August 2007. Recorded by Tobias Hünger.', 1, 1, 'Y', '5DJXsfi_7ZM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (22, '2012-01-31 11:49:44.30858+00', '2012-01-31 11:50:13.983792+00', 13588, 1, 1, '', 'A', 'London Branch demonstration team at the 2011 Newcastle Festival.', 1, 1, 'Y', 'iZiXHPffCGE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (28, '2012-02-03 18:29:15.680033+00', '2012-02-07 11:24:45.063763+00', 3623, 1, 513, '', 'A', '', 1, 1, 'Y', 'q7_OgD4G_ZM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (30, '2012-02-03 18:32:18.818495+00', '2012-02-07 11:25:09.097299+00', 13588, 3, 513, '', 'A', '', 1, 1, 'Y', '3xJ-otGswqs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (49, '2012-02-14 22:18:24.39772+00', '2012-02-15 10:53:11.604368+00', 159, 1, 513, '', 'A', '', 1, 1, 'Y', 'XKejeD9nG7k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (42, '2012-02-13 20:32:59.072578+00', '2012-02-15 10:54:43.884845+00', 340, 1, 513, '', 'A', '', 1, 1, 'Y', 'xkMcVZqUgic', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (33, '2012-02-08 14:59:09.22199+00', '2012-02-15 10:55:44.588525+00', 9422, 1, 513, '', 'B', '', 1, 1, 'Y', 'EVvGxHznUYs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (48, '2012-02-14 08:02:32.995474+00', '2012-02-15 10:59:50.328839+00', 1223, 1, 513, '', 'A', '', 1, 1, 'Y', 'S6rfj_QvK28', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (44, '2012-02-14 07:26:36.479583+00', '2012-02-15 11:00:22.491218+00', 2136, 1, 513, '', 'A', '', 1, 1, 'Y', '6X54AosC0SU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (43, '2012-02-14 07:19:47.272892+00', '2012-02-15 11:00:38.315883+00', 2562, 1, 513, '', 'A', '', 1, 1, 'Y', 'wG9Ths1f9Y4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (35, '2012-02-08 15:05:59.704975+00', '2012-02-15 11:00:49.785987+00', 12663, 1, 513, '', 'B', '', 1, 1, 'Y', 'bVAE-SoYeCI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (38, '2012-02-13 12:27:18.763136+00', '2012-02-15 11:03:12.801038+00', 13500, 1, 513, '', 'A', '', 1, 1, 'Y', 'Gu3QhTzzRGg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (40, '2012-02-13 17:08:42.568129+00', '2012-02-15 11:03:30.100474+00', 14241, 1, 513, '', 'B', '', 1, 1, 'Y', 'BChEesiaLK0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (34, '2012-02-08 15:02:27.068711+00', '2012-02-15 11:05:21.872501+00', 12302, 1, 513, '', 'B', '', 1, 1, 'Y', 'sqgeiqFq0J8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (39, '2012-02-13 12:33:17.949327+00', '2012-02-15 11:06:47.097211+00', 5667, 1, 513, '', 'A', '', 1, 1, 'Y', 'OsN7m1MsOKI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (47, '2012-02-14 07:44:43.179438+00', '2012-02-15 11:07:44.361841+00', 5860, 2, 513, '', 'A', '', 1, 1, 'Y', 'fhxiY0SyOF8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (46, '2012-02-14 07:40:45.644853+00', '2012-02-15 11:08:32.901201+00', 6271, 1, 513, '', 'A', '', 1, 1, 'Y', 'IXhT7j9nB8U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (45, '2012-02-14 07:28:41.354813+00', '2012-02-15 11:09:38.43713+00', 6349, 1, 513, '', 'A', '', 1, 1, 'Y', 'yjw1mOOJiYI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (41, '2012-02-13 17:53:40.770624+00', '2012-02-15 11:10:18.791951+00', 7242, 1, 513, '', 'A', '', 1, 1, 'Y', 'dy2aGQVgx6c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (31, '2012-02-03 18:33:20.523377+00', '2012-02-16 14:54:51.097637+00', 13149, 1, 513, '', 'A', '', 1, 1, 'Y', '3xJ-otGswqs', 220, 0, NULL);
INSERT INTO 'dancevideo' VALUES (29, '2012-02-03 18:30:17.977318+00', '2012-02-16 14:56:07.217461+00', 794, 2, 513, '', 'A', '', 1, 1, 'Y', 'q7_OgD4G_ZM', 190, 0, NULL);
INSERT INTO 'dancevideo' VALUES (25, '2012-02-03 18:17:44.802458+00', '2012-02-16 14:58:02.008666+00', 13588, 2, 513, '', 'A', '', 1, 1, 'Y', 'MtXyw-_7rUQ', 258, 0, NULL);
INSERT INTO 'dancevideo' VALUES (26, '2012-02-03 18:20:07.372952+00', '2012-02-16 14:59:20.77096+00', 5860, 1, 513, '', 'A', '', 1, 1, 'Y', 'RBIzZwqRcRw', 264, 0, NULL);
INSERT INTO 'dancevideo' VALUES (56, '2012-02-26 18:47:23.025261+00', '2012-11-12 21:00:57.622802+00', 7286, 1, 1, '', 'A', '', 1, 1, 'Y', 'nNr0eC_eA-0', 52, 0, NULL);
INSERT INTO 'dancevideo' VALUES (76, '2012-03-25 11:39:29.068367+00', '2012-03-25 11:40:06.256036+00', 5330, 1, 1, '', 'C', 'Introduces The Broom of Bon Accord as 4th man.', 1, 1, 'Y', '8jIadq4M6xk', 68, 0, NULL);
INSERT INTO 'dancevideo' VALUES (75, '2012-03-14 17:51:59.179695+00', '2012-05-02 18:16:51.237218+00', 9406, 1, 513, '', 'B', '', 1, 1, 'Y', '5VU-NHBsTkQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (162, '2012-09-06 15:21:42.204818+00', '2012-09-06 15:26:31.435891+00', 5749, 1, 106, '', 'A', 'SCD dem - Summer School 2011 week 2, second dance', 1, 1, 'Y', 'WEXkt1GG1zg', 214, 0, NULL);
INSERT INTO 'dancevideo' VALUES (154, '2012-09-04 08:23:15.481448+00', '2013-02-13 23:26:29.34922+00', 14535, 1, 106, '', 'A', 'Demo at Summer School 2012 week 4', 1, 1, 'Y', 't29gjE7RWwU', 41, 117, NULL);
INSERT INTO 'dancevideo' VALUES (156, '2012-09-04 20:52:04.997233+00', '2012-09-04 20:53:11.116829+00', 4796, 2, 106, '', 'A', 'Country Demo, Summer School 2012 week 2', 1, 1, 'Y', 'yLdpG4b1Llw', 171, 0, NULL);
INSERT INTO 'dancevideo' VALUES (136, '2012-08-19 19:20:27.671184+00', '2012-08-19 22:00:01.52127+00', 14432, 1, 513, '', 'A', '', 1, 1, 'Y', 'Zh9uXICmKq8', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (235, '2012-09-12 06:39:41.160134+00', '2012-09-18 19:32:13.231103+00', 5982, 1, 1041, '', 'C', '', 1, 1, 'Y', '5AotF21zp68', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5322, '2019-10-31 07:50:33.085907+00', '2019-11-01 21:42:47.123748+00', 9385, 2, 1645, '', 'A', 'Once through excerpt from a longer demo.', 1, 1, 'Y', 'JmcelyNN1yU', 657, 721, NULL);
INSERT INTO 'dancevideo' VALUES (5323, '2019-10-31 07:54:02.712445+00', '2019-11-01 21:44:27.249222+00', 8850, 1, 1645, '', 'A', 'Twice through as part of a longer demo.', 1, 1, 'Y', 'JmcelyNN1yU', 720, 794, NULL);
INSERT INTO 'dancevideo' VALUES (5318, '2019-10-30 22:02:11.00679+00', '2019-11-01 21:47:07.35689+00', 5448, 1, 1645, '', 'C', '', 1, 1, 'Y', 'FjBFPytR82g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5321, '2019-10-30 22:52:19.031598+00', '2019-11-01 21:46:18.056642+00', 9096, 1, 1645, '', 'A', 'Twice through as part of a longer demo. This 4 couple set dance is here adapted for 6 couples.', 1, 1, 'Y', 'JmcelyNN1yU', 277, 350, NULL);
INSERT INTO 'dancevideo' VALUES (5316, '2019-10-30 21:23:19.296993+00', '2019-11-01 21:47:41.168716+00', 6712, 11, 1645, '', 'B', '', 1, 1, 'Y', 'M49akvnWwV0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5307, '2019-10-25 10:22:24.299965+00', '2021-03-28 12:27:03.257767+00', 19723, 1, 197, '', 'B', 'Video by Dance Scottish San Diego', 1, 1, 'Y', 'pGMgMlLa1qE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6682, '2020-01-10 01:19:25.238524+00', '2020-01-11 14:41:15.091661+00', 13082, 2, 1296, '', 'A', '', 1, 1, 'Y', 'wJFRWgn6TUQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6684, '2020-01-10 01:19:26.310714+00', '2020-01-15 23:49:33.749724+00', 17136, 4, 1296, '', 'D', '', 1, 1, 'Y', 'kXycUVsnHis', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (143, '2012-08-23 16:24:59.280201+00', '2021-11-19 15:01:25.251384+00', 14543, 1, 106, '', 'A', 'This video was made before the dance was revised. It shows the original version of the last 8 bars. Since 2017 these are now changed to have the half circle first, then all cross RH at the end.', 1, 1, 'Y', 'bgDBmoDbaZ8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (250, '2012-09-12 19:57:50.870428+00', '2012-09-13 00:36:13.739765+00', 7061, 1, 1041, '', 'B', '', 1, 1, 'Y', 'vwFwn9YCwgk', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (77, '2012-04-04 15:55:53.242421+00', '2017-01-30 19:57:43.668146+00', 3776, 1, 513, '', 'B', '', 1, 1, 'Y', 'ifcMgPgetc0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3500, '2018-04-03 16:57:40.058544+00', '2018-04-03 18:18:52.745101+00', 18232, 1, 1957, '', 'A', 'Once through only', 1, 1, 'Y', 'XoIzmcOvPys', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (99, '2012-06-11 00:19:31.320036+00', '2012-06-11 08:10:50.885606+00', 887, 2, 961, '', 'A', 'found via http://www.scottish-country-dancing-dictionary.com/scottish-dancing-youtube-videos.html.



"Butterscotch and Honey" is danced once through, and ends at 0.59.  The demonstration continues with the "Double Diamond Strathspey" by Roy Goldring, danced twice through, and finishes with "Butterscotch and Honey" danced once through, starting at 2.55', 1, 1, 'Y', 'FjbvrFKETk4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3448, '2018-02-21 00:14:54.806117+00', '2018-02-21 00:20:39.246163+00', 2600, 5, 106, '', 'A', 'Newcastle Festival 2018 - Ladies - International Team ', 1, 1, 'Y', 'iRBzt3SmWVE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (88, '2012-05-04 13:04:30.16471+00', '2012-05-04 13:05:45.961414+00', 594, 2, 106, '', 'C', '', 1, 1, 'Y', '4knCwlGgQXE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (90, '2012-05-06 12:41:52.988561+00', '2012-05-06 12:43:36.353438+00', 1087, 2, 1, '', 'D', '', 1, 1, 'Y', 'x_bNZwvNRPo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (89, '2012-05-06 12:38:48.311184+00', '2012-05-06 12:43:54.077714+00', 1087, 1, 1, '', 'B', 'This video uses the original music suggested by the dance author. The choreography is OK but there are some glitches in the phrasing.', 1, 1, 'Y', 'UuZUTfmGCbs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (100, '2012-06-11 00:23:03.807275+00', '2012-06-11 07:47:21.251745+00', 1473, 1, 961, '', 'A', 'A beautiful set, despite the mediocre video quality. 



discovered via http://www.scottish-country-dancing-dictionary.com/scottish-dancing-youtube-videos.html', 1, 1, 'Y', '2j_RbcqSKV4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (98, '2012-06-11 00:17:58.342107+00', '2012-06-11 21:32:13.93085+00', 769, 1, 961, '', 'C', 'One dancer obviously does not know the dance, and there is a tutor ''on stage'' directing him. Everyone else is good in the figures, but the footwork is mediocre.



video found via http://www.scottish-country-dancing-dictionary.com/scottish-dancing-youtube-videos.html', 1, 1, 'Y', 'XsRWuxGOcT0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (105, '2012-07-16 08:24:27.255263+00', '2012-07-16 21:02:16.239273+00', 3422, 1, 513, '', 'B', '', 1, 1, 'Y', 'g0oMxOHLeXQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (106, '2012-07-16 08:26:49.175537+00', '2012-07-16 21:05:26.409089+00', 12793, 1, 513, '', 'C', '', 1, 1, 'Y', 'X3Ekblh_f20', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (107, '2012-07-16 08:28:47.48292+00', '2012-07-16 21:07:05.972747+00', 12793, 2, 513, '', 'B', '', 1, 1, 'Y', 'o2Lv_PunxAM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (108, '2012-07-17 13:05:32.34861+00', '2012-07-17 21:44:48.093835+00', 12983, 1, 513, '', 'C', 'This video shows the earlier version of this dance, where for [17-24] 1C dances a figure of 8 round the end couple.  In 2011 Edwin Werner revised the dance to make these Reels of 3 across (1M down, 1W up).  Note that at the end [on 24] 1C passes partner R shoulder to face 3rd corner; in the video many couples pass L shoulder.', 1, 1, 'Y', 'lpkgBnK93dI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (126, '2012-07-23 09:31:39.888907+00', '2012-07-23 09:35:16.044808+00', 3338, 1, 1041, '', 'A', '', 1, 1, 'Y', 'pfMCbRtH9Ak', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (117, '2012-07-22 18:03:03.123018+00', '2012-08-08 20:01:27.997985+00', 7283, 1, 1041, '', 'C', '', 1, 1, 'Y', '0JXNV8UP3fQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (112, '2012-07-22 14:26:54.100394+00', '2012-08-11 16:31:58.80255+00', 7055, 1, 1041, '', 'C', 'Danced by an amateur demonstration team in a 5-couple set, with deviations from the normal progression, and a few errors.  This is a part of a demonstration of several dances chained together.', 1, 1, 'Y', 'Km78vxftLgg', 139, 0, NULL);
INSERT INTO 'dancevideo' VALUES (115, '2012-07-22 16:20:38.666379+00', '2012-08-11 21:05:31.306593+00', 5860, 3, 1041, '', 'A', '', 1, 1, 'Y', '5_tU57X5088', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (120, '2012-07-22 19:03:00.851755+00', '2012-08-11 21:55:46.321692+00', 2498, 1, 1041, '', 'A', 'This is part of a demonstration of many linked dances, adapted for the occasion.  The set is a "broadwise set": up/down is at right angles to the length of the set.  The dancing is of demonstation quality.', 1, 1, 'Y', 'OlT6md-1FlY', 77, 0, NULL);
INSERT INTO 'dancevideo' VALUES (125, '2012-07-22 20:12:17.050085+00', '2012-08-11 22:11:14.47248+00', 5964, 1, 1041, '', 'A', 'This is the final part of a demonstration; three sets placed in a triangle dance this dance simultaneously.', 1, 1, 'Y', 'dhJDGoPcWH8', 139, 0, NULL);
INSERT INTO 'dancevideo' VALUES (124, '2012-07-22 20:04:02.771028+00', '2012-08-11 22:19:57.610932+00', 10920, 1, 1041, '', 'B', 'This is the first dance of a demonstration consisting of a number of linked dances.  It is followed by Wicked Willie.', 1, 1, 'Y', 'a1X2CRUX5Qc', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (122, '2012-07-22 19:36:28.101179+00', '2012-08-11 22:25:02.210148+00', 5497, 2, 1041, '', 'B', 'Danced by an all male set.', 1, 1, 'Y', '8Sx6X65izDs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (114, '2012-07-22 16:10:21.869445+00', '2012-08-11 22:31:36.503447+00', 4805, 1, 1041, '', 'D', '', 1, 1, 'Y', 'A6KGozKy41A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (121, '2012-07-22 19:09:30.966313+00', '2012-08-11 22:58:54.391734+00', 13581, 1, 1041, '', 'A', 'Demonstration in Younger Hall, Summer School 2009, Thursday of week 1', 1, 1, 'Y', 'sWIHdHrVREM', 350, 0, NULL);
INSERT INTO 'dancevideo' VALUES (129, '2012-08-13 22:23:07.570052+00', '2012-08-13 22:47:36.33811+00', 11617, 1, 106, '', 'B', 'This dance was written by ian Boyd; the video erroneously attributes it to Romaine Butterfield.', 1, 1, 'Y', 'yCkZt47ay54', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (130, '2012-08-17 20:01:49.875874+00', '2012-08-17 20:34:53.142314+00', 13438, 1, 82, '', 'B', 'There are no significant errors in the choreography, but the performance is in a 3-couple set, and does not use the suggested tune.  ', 1, 1, 'Y', '6T0khmyqI_k', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (195, '2012-09-09 15:43:10.868564+00', '2012-09-09 22:11:08.561994+00', 11280, 1, 1041, '', 'D', '', 1, 1, 'Y', 'Q3y7zAckjRA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (109, '2012-07-17 13:06:20.285647+00', '2012-09-10 19:45:50.943056+00', 11896, 1, 513, '', 'C', '', 1, 1, 'Y', 'Z5Nnp3b1oCM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (110, '2012-07-17 13:06:58.497898+00', '2012-09-10 19:49:21.387104+00', 13706, 1, 513, '', 'C', '', 1, 1, 'Y', '2cOdO_ThiTs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (131, '2012-08-19 16:00:17.302256+00', '2012-08-19 16:30:53.119411+00', 8956, 1, 513, '', 'C', 'The first time through the set shown goes well; the second time through the set (another one) has problems.', 1, 1, 'Y', '9gqxdG-aUs0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (160, '2012-09-06 14:56:42.151419+00', '2012-09-06 14:58:35.73314+00', 2267, 1, 106, '', 'B', 'RSCDS Edinburgh Branch Ball May 2010 ', 1, 1, 'Y', 'SCT0XTOIm6g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (132, '2012-08-19 18:46:46.435163+00', '2012-08-19 20:08:27.136399+00', 1480, 1, 513, '', 'C', '', 1, 1, 'Y', 'x-mWGH5FdIw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (133, '2012-08-19 18:49:17.482055+00', '2012-08-19 20:10:09.141789+00', 12426, 1, 513, '', 'C', '', 1, 1, 'Y', 'fBYsgWN2sTE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (134, '2012-08-19 18:52:05.498448+00', '2012-08-19 20:32:25.048135+00', 6420, 1, 513, '', 'C', '', 1, 1, 'Y', 'OEaDvbK84IU', 25, 0, NULL);
INSERT INTO 'dancevideo' VALUES (123, '2012-07-22 19:44:12.159619+00', '2012-12-25 23:29:05.514277+00', 2437, 1, 1041, '', 'C', '', 1, 1, 'Y', '5FEEo69tYvk', 0, 128, NULL);
INSERT INTO 'dancevideo' VALUES (103, '2012-06-30 23:16:24.919988+00', '2012-12-25 16:06:27.691554+00', 5525, 2, 106, '', 'A', 'Twice through in a 3C set.', 1, 1, 'Y', 'G1CMN-PTYWw', 241, 0, NULL);
INSERT INTO 'dancevideo' VALUES (111, '2012-07-22 14:18:11.066129+00', '2012-12-25 17:58:17.060065+00', 3759, 1, 1041, '', 'A', '', 1, 1, 'Y', 'Z4GkIWVn4M0', 100, 233, NULL);
INSERT INTO 'dancevideo' VALUES (101, '2012-06-11 21:55:05.188228+00', '2012-12-31 12:37:06.261657+00', 4411, 1, 106, '', 'A', 'Demonstration at Summer School 2008, week 1.', 1, 1, 'Y', 'kJZJLlJvnaQ', 0, 200, NULL);
INSERT INTO 'dancevideo' VALUES (137, '2012-08-19 19:51:26.492151+00', '2012-08-19 21:10:30.328214+00', 14542, 1, 106, '', 'A', 'Video made by Martina Müller-Franz in Younger Hall on 11 august 2012 at the end of the 4th week of Summer School.', 1, 1, 'Y', 'YuDTotOCGis', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (139, '2012-08-20 07:32:47.996821+00', '2012-08-20 20:28:04.108837+00', 14418, 1, 513, '', 'D', '', 1, 1, 'Y', 'UJiBVh75dSU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (127, '2012-07-26 11:28:57.975925+00', '2019-02-18 18:36:21.225465+00', 6205, 1, 513, '', 'B', 'The instructions say 1st lady, 3rd lady and 3rd man should pull right shoulders back to face up/down after the half turn of bars 15-16 which is omitted from this performance.', 1, 1, 'Y', '1Ij8qywxPF4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (260, '2012-09-13 16:23:12.744469+00', '2012-09-13 16:25:11.868826+00', 4646, 2, 106, '', 'A', 'St Andrews University Celtic Society dancing Monymusk at the Newcastle RSCDS Festival, Feb 2009', 1, 1, 'Y', 'fezb4WwPYPo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (229, '2012-09-11 21:53:16.372264+00', '2012-09-13 16:26:50.893117+00', 5462, 1, 1041, '', 'X', '', 1, 1, 'Y', 'l687Zy7mQy8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (263, '2012-09-18 10:42:27.325687+00', '2012-09-18 10:57:52.442093+00', 54, 1, 513, '', 'C', '', 1, 1, 'Y', 'FXlg9pNFiGE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (147, '2012-08-25 21:21:10.608705+00', '2012-08-25 21:37:22.45241+00', 14242, 1, 106, '', 'D', 'From the web; shows how the dance can look in a non-RSCDS environment.



The Kandahar reel was written by two officers of The Black Watch, 3rd Battalion The Royal Regiment of Scotland to mark the Battalion''s operational tour in Afghanistan. Soldiers of The Black Watch made frequent use of Chinook Helicopters with their signature double rotor blades and they were often supported by American Army Black Hawk helicopters with a single rotor. The dance reproduces the use of these workhorses of the sky upon which the Army relies in Afghanistan.  The rotors go 1 1/2 times round, to symbolize the "150% commitment" expected.



The reel is danced to Mr Jamie Forrester''s Kandahar Reel or the Auld Reekie Band''s Speed the Plough.', 1, 1, 'Y', 'JdYfsT45FDs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (148, '2012-08-27 07:56:08.740139+00', '2012-08-27 09:00:53.405525+00', 5529, 1, 513, '', 'D', 'This video was taken during RSCDS Summer School 2012 and shows the dance in a social situation.', 1, 1, 'Y', 'XLw_1OXsfSo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (150, '2012-08-27 18:48:05.333529+00', '2012-08-27 18:50:07.095888+00', 3541, 1, 106, '', 'C', '', 1, 1, 'Y', 'P7k9n1pX1Og', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (149, '2012-08-27 12:15:59.155063+00', '2012-08-27 19:36:45.334614+00', 1607, 1, 513, '', 'A', '', 1, 1, 'Y', '-YQhINjI_0U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (157, '2012-09-04 21:09:52.159869+00', '2012-09-04 21:14:45.751338+00', 1647, 1, 106, '', 'B', 'Country Demo, Summer School 2012 week 2', 1, 1, 'Y', 'yLdpG4b1Llw', 285, 0, NULL);
INSERT INTO 'dancevideo' VALUES (152, '2012-09-04 07:45:14.406121+00', '2012-09-04 07:49:06.73834+00', 4796, 1, 106, '', 'A', 'Demo at Summer School 2012, week 2', 1, 1, 'Y', 'rTYMGDs5Q-M', 94, 0, NULL);
INSERT INTO 'dancevideo' VALUES (158, '2012-09-06 06:12:46.837458+00', '2012-09-06 06:14:20.465885+00', 12542, 1, 1, '', 'B', 'Patty Lindsay <<sspey:63083|says>>:



> Its the 2011 Pittsburgh ball (part of their 2011 workshop).   The venue is

> the George Washington Hotel in Washington, PA, a lovely setting and a great

> event.  The musicians are the Music Makars,  with Elissa Hock-Wimmer on

> piano.

', 1, 1, 'Y', 'JjdTNbUPt6k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (119, '2012-07-22 18:52:26.51469+00', '2022-11-06 18:15:57.072266+00', 11769, 2, 1041, '', 'A', '', 1, 1, 'Y', 'aho1kBA6uiw', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (183, '2012-09-09 14:34:06.722647+00', '2012-09-09 14:34:32.140566+00', 8630, 1, 1, '', 'C', 'Published by Loretta Holz.', 1, 1, 'V', '40613152', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (175, '2012-09-09 13:03:58.55714+00', '2012-09-09 21:01:54.899956+00', 888, 1, 1041, '', 'C', '', 1, 1, 'Y', '1u05kODrQGU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (176, '2012-09-09 13:31:44.410223+00', '2012-09-09 21:03:49.33723+00', 1087, 3, 1041, '', 'B', '', 1, 1, 'Y', 'rY2O4xAkXLk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (177, '2012-09-09 13:35:48.158775+00', '2012-09-09 21:07:04.933051+00', 895, 1, 1041, '', 'C', '', 1, 1, 'Y', '7QC4EAQZ8Pc', 146, 0, NULL);
INSERT INTO 'dancevideo' VALUES (181, '2012-09-09 13:49:52.834278+00', '2012-09-09 21:24:05.421652+00', 10007, 1, 1041, '', 'C', '', 1, 1, 'Y', 'Y6l7kjyvZx4', 215, 0, NULL);
INSERT INTO 'dancevideo' VALUES (184, '2012-09-09 15:05:51.441915+00', '2012-09-09 21:30:05.9596+00', 11872, 1, 1041, '', 'C', '', 1, 1, 'Y', 'LBCTDmi6Xt4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (188, '2012-09-09 15:24:06.9089+00', '2012-09-09 21:45:15.196044+00', 9084, 1, 1041, '', 'B', 'Video starts halfway the first round.', 1, 1, 'Y', '1bDNqExpEH8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (189, '2012-09-09 15:28:58.578769+00', '2012-09-09 21:50:12.129023+00', 11393, 1, 1041, '', 'A', '', 1, 1, 'Y', 'FjbvrFKETk4', 60, 0, NULL);
INSERT INTO 'dancevideo' VALUES (190, '2012-09-09 15:31:35.953198+00', '2012-09-09 21:53:49.62589+00', 10433, 1, 1041, '', 'B', '', 1, 1, 'Y', 'fs5RhA7zyWE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (191, '2012-09-09 15:33:22.046124+00', '2012-09-09 21:56:44.112654+00', 12983, 2, 1041, '', 'B', '', 1, 1, 'Y', 'W2JJpN4CL5s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (151, '2012-08-28 06:06:20.202075+00', '2012-09-09 22:21:53.074992+00', 3678, 1, 106, '', 'B', '', 1, 1, 'Y', 'Z-4mGnrpdKI', 111, 0, NULL);
INSERT INTO 'dancevideo' VALUES (161, '2012-09-06 15:09:19.867622+00', '2012-09-09 22:28:47.911001+00', 11374, 1, 106, '', 'A', 'SCD dem - Summer School 2011 week 2', 1, 1, 'Y', 'WEXkt1GG1zg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (169, '2012-09-09 12:27:53.450874+00', '2012-09-09 22:44:25.013382+00', 12426, 2, 1041, '', 'A', '', 1, 1, 'Y', 'CZGPC1guhW0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (170, '2012-09-09 12:33:02.69331+00', '2012-09-09 22:47:51.241906+00', 549, 1, 1041, '', 'B', '', 1, 1, 'Y', 'NijqXp5wh78', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (172, '2012-09-09 12:54:37.312229+00', '2012-09-09 22:52:01.159219+00', 11188, 1, 1041, '', 'A', '', 1, 1, 'Y', 'e7pgFsgiEuY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (185, '2012-09-09 15:07:47.305167+00', '2012-09-10 06:38:41.603042+00', 1543, 1, 1041, '', 'C', '', 1, 1, 'Y', 'DixbcQsaT-M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (192, '2012-09-09 15:36:06.333714+00', '2012-09-10 07:23:18.224996+00', 1792, 1, 1041, '', 'B', '', 1, 1, 'Y', 'QXYkC_y-NwM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (186, '2012-09-09 15:09:52.592703+00', '2012-09-10 07:28:20.52757+00', 1544, 1, 1041, '', 'A', '', 1, 1, 'Y', 'Yfog5CEj-ac', 306, 0, NULL);
INSERT INTO 'dancevideo' VALUES (200, '2012-09-09 15:57:59.35705+00', '2012-09-09 20:25:43.799129+00', 2616, 1, 1041, '', 'B', '', 1, 1, 'Y', '6XdzNEOi9x8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (202, '2012-09-09 19:58:50.902584+00', '2012-09-09 20:31:50.923953+00', 3057, 1, 1041, '', 'C', 'This video shows the popular version with the second promenade going anticlockwise.', 1, 1, 'Y', 'uPEtzzN5jVM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (203, '2012-09-09 20:00:46.824346+00', '2012-09-09 20:34:50.612005+00', 9836, 1, 1041, '', 'A', '', 1, 1, 'Y', 'bWP0SFECCwg', 320, 0, NULL);
INSERT INTO 'dancevideo' VALUES (206, '2012-09-09 20:07:44.194199+00', '2012-09-09 20:39:45.182621+00', 3310, 1, 1041, '', 'C', '', 1, 1, 'Y', 'xRdBS9kWWHw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (207, '2012-09-09 20:09:04.779479+00', '2012-09-09 20:47:05.928546+00', 3323, 1, 1041, '', 'A', '', 1, 1, 'Y', 'GOjd6oMFeEM', 140, 0, NULL);
INSERT INTO 'dancevideo' VALUES (209, '2012-09-09 20:18:04.925677+00', '2012-09-09 20:57:41.05548+00', 3365, 1, 1041, '', 'C', '', 1, 1, 'Y', 'BoH3hIw8Kj4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (179, '2012-09-09 13:41:36.945078+00', '2012-09-09 21:15:06.528673+00', 10787, 1, 1041, '', 'C', 'The previous 1:50 minutes involve the trainings session prior to the dancing', 1, 1, 'Y', '7zkHKNgBXTU', 110, 0, NULL);
INSERT INTO 'dancevideo' VALUES (187, '2012-09-09 15:12:28.548927+00', '2012-09-09 21:42:40.329716+00', 1647, 1, 1041, '', 'B', 'There is a bit of <<ddd:Petronella>> in the middle of the performance.', 1, 1, 'Y', 'sSvY6LLAM38', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (194, '2012-09-09 15:41:12.235216+00', '2012-09-09 22:05:36.496013+00', 2030, 1, 1041, '', 'B', '', 1, 1, 'Y', 'jbKWlv2VktE', 230, 0, NULL);
INSERT INTO 'dancevideo' VALUES (196, '2012-09-09 15:48:00.622844+00', '2012-09-09 22:14:55.806741+00', 2203, 1, 1041, '', 'D', '', 1, 1, 'Y', 'L6vUeNf2wqU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (211, '2012-09-09 22:20:26.241363+00', '2012-09-09 22:22:55.071238+00', 12539, 1, 106, '', 'C', '', 1, 1, 'V', '37865912', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (213, '2012-09-10 06:20:14.964495+00', '2012-09-10 06:20:35.296266+00', 314, 4, 1, '', 'B', '', 1, 1, 'Y', '-2SEEseSn_k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (208, '2012-09-09 20:11:35.35196+00', '2012-12-25 17:19:23.309564+00', 3326, 1, 1041, '', 'A', '', 1, 1, 'Y', 'O7hRuGzTrL4', 0, 167, NULL);
INSERT INTO 'dancevideo' VALUES (166, '2012-09-09 12:12:21.277232+00', '2013-02-07 02:59:25.115625+00', 12801, 1, 1041, '', 'B', 'Part of a longer demo.  Once through, and the last bars were modified to link to the next dance', 1, 1, 'Y', 'WWW1YaHN8BQ', 453, 514, NULL);
INSERT INTO 'dancevideo' VALUES (153, '2012-09-04 08:15:49.809779+00', '2013-02-13 23:12:10.986867+00', 14533, 1, 106, '', 'A', 'Demo at RSCDS Summer School 2012 - week 2



The Castle of May is danced twice through; it is followed by Mrs Milne of Kinneff (see there, or play on).', 1, 1, 'Y', 'rTYMGDs5Q-M', 21, 94, NULL);
INSERT INTO 'dancevideo' VALUES (214, '2012-09-10 06:26:08.320923+00', '2012-09-10 06:27:03.657525+00', 743, 1, 1, '', 'B', '', 1, 1, 'Y', 'KWTfpql8Dmg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (197, '2012-09-09 15:50:06.790219+00', '2012-09-10 07:27:03.660695+00', 12941, 1, 1041, '', 'D', '', 1, 1, 'Y', 'M5vlzoL-gbU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (201, '2012-09-09 19:29:50.720643+00', '2012-09-10 07:32:18.314872+00', 2924, 2, 1041, '', 'B', '', 1, 1, 'Y', 'QZITJttK_Vc', 113, 0, NULL);
INSERT INTO 'dancevideo' VALUES (210, '2012-09-09 20:19:15.160267+00', '2012-09-10 07:36:06.771315+00', 3365, 2, 1041, '', 'X', '', 1, 1, 'Y', 'At-ksYHI77U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (220, '2012-09-11 21:35:52.677891+00', '2012-09-11 21:47:07.266566+00', 9638, 1, 1041, '', 'D', '', 1, 1, 'Y', 'pbp3KC__Uuo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (243, '2012-09-12 14:00:01.59319+00', '2012-09-13 00:28:32.657783+00', 6995, 1, 1041, '', 'B', '', 1, 1, 'Y', 'olG9idagzmo', 128, 0, NULL);
INSERT INTO 'dancevideo' VALUES (167, '2012-09-09 12:23:16.706936+00', '2013-09-07 13:09:38.358536+00', 314, 2, 1041, '', 'B', '', 1, 1, 'Y', 'yM-uVG7vVbs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (216, '2012-09-11 21:25:11.050973+00', '2013-12-11 23:11:07.903609+00', 3980, 1, 1041, '', 'D', 'Once through, starts a few bars late.  Clips from a social dance event.', 1, 1, 'Y', 'I54v12AgPZk', 212, 248, NULL);
INSERT INTO 'dancevideo' VALUES (193, '2012-09-09 15:37:59.421125+00', '2014-01-04 09:31:45.684747+00', 9107, 1, 1041, '', 'C', 'Only once through; low viewpoint.', 1, 1, 'Y', 'zgPAmQO7tRM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (178, '2012-09-09 13:36:17.897647+00', '2014-11-04 23:16:02.490043+00', 895, 2, 1041, '', 'C', '', 1, 1, 'Y', 'QhJQG6hvKc0', 75, 111, NULL);
INSERT INTO 'dancevideo' VALUES (228, '2012-09-11 21:52:29.298237+00', '2012-09-13 00:30:10.487385+00', 5407, 1, 1041, '', 'A', '', 1, 1, 'Y', 'IqEVkMpGoI4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (221, '2012-09-11 21:36:23.486353+00', '2012-09-13 00:15:55.793149+00', 9638, 2, 1041, '', 'D', '', 1, 1, 'Y', 'fozMnqxLor8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (223, '2012-09-11 21:41:23.256322+00', '2012-09-13 00:52:23.309628+00', 4844, 1, 1041, '', 'A', '', 1, 1, 'Y', 'FpOHod_Kc3Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (225, '2012-09-11 21:47:42.266407+00', '2012-09-13 00:24:22.345061+00', 5209, 1, 1041, '', 'B', '', 1, 1, 'Y', 'k9xFOoHofg4', 29, 0, NULL);
INSERT INTO 'dancevideo' VALUES (255, '2012-09-13 00:53:14.879488+00', '2012-09-13 00:54:38.352179+00', 4411, 2, 106, '', 'B', '', 1, 1, 'Y', 'FpOHod_Kc3Y', 75, 0, NULL);
INSERT INTO 'dancevideo' VALUES (180, '2012-09-09 13:44:42.163003+00', '2017-08-28 21:31:43.839591+00', 1330, 1, 1041, '', 'C', 'Note: the instructions tell 2c to step up on [9-10].  In the video they step up on [1-2]', 1, 1, 'Y', '6Ms2sahcXAo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (222, '2012-09-11 21:38:20.759606+00', '2012-09-13 07:32:42.218054+00', 4784, 1, 1041, '', 'D', '', 1, 1, 'Y', 'Muq5sjFYXJA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (246, '2012-09-12 14:03:59.70777+00', '2012-09-13 07:26:02.671099+00', 909, 1, 1041, '', 'D', '', 1, 1, 'Y', '-rMuv4cbVBg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (215, '2012-09-11 21:23:27.156933+00', '2012-09-13 07:27:32.199634+00', 3786, 1, 1041, '', 'B', '', 1, 1, 'Y', 'd3eaihomrcg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (224, '2012-09-11 21:45:15.340847+00', '2012-09-13 07:34:13.545863+00', 12796, 1, 1041, '', 'B', '', 1, 1, 'Y', 'a1X2CRUX5Qc', 380, 0, NULL);
INSERT INTO 'dancevideo' VALUES (264, '2012-09-18 10:45:29.686111+00', '2012-09-18 12:32:17.377618+00', 9528, 1, 513, '', 'C', '', 1, 1, 'Y', 'z-2oO_oUelQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (262, '2012-09-18 10:34:09.892421+00', '2012-09-18 12:38:28.629078+00', 4032, 1, 513, '', 'C', '', 1, 1, 'Y', '2ydtMR1HVFI', 9, 0, NULL);
INSERT INTO 'dancevideo' VALUES (265, '2012-09-18 10:47:32.96331+00', '2012-09-18 12:43:08.785435+00', 5330, 2, 513, '', 'C', '', 1, 1, 'Y', 'SsM8LAvSSw0', 29, 0, NULL);
INSERT INTO 'dancevideo' VALUES (244, '2012-09-12 14:01:24.184304+00', '2012-09-18 19:15:21.357688+00', 7105, 1, 1041, '', 'A', '', 1, 1, 'Y', 'JGJpd8zUrEA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (256, '2012-09-13 00:58:07.420478+00', '2012-09-18 19:28:47.742536+00', 7147, 2, 106, '', 'A', '', 1, 1, 'Y', 'FpOHod_Kc3Y', 202, 0, NULL);
INSERT INTO 'dancevideo' VALUES (227, '2012-09-11 21:50:39.198672+00', '2012-09-18 19:43:33.812946+00', 5296, 1, 1041, '', 'D', '', 1, 1, 'Y', 'xsDqAQTer-E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (245, '2012-09-12 14:02:28.816561+00', '2012-09-18 19:38:13.111311+00', 11772, 1, 1041, '', 'C', '', 1, 1, 'Y', 'rrzxO_MUVW0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (266, '2012-09-18 10:55:14.119974+00', '2012-09-18 19:45:47.260854+00', 5552, 1, 513, '', 'C', '', 1, 1, 'Y', '7PEGyq9pJoY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (241, '2012-09-12 06:54:33.280354+00', '2012-09-18 19:55:26.919282+00', 7282, 1, 1041, '', 'D', '', 1, 1, 'Y', 'siuzDoNwdao', 21, 0, NULL);
INSERT INTO 'dancevideo' VALUES (231, '2012-09-11 21:57:48.245336+00', '2012-09-18 20:02:34.14826+00', 5555, 1, 1041, '', 'A', '', 1, 1, 'Y', 'GPU_u1yzcTg', 283, 0, NULL);
INSERT INTO 'dancevideo' VALUES (238, '2012-09-12 06:45:04.932188+00', '2012-09-18 21:19:05.497885+00', 5802, 2, 1041, '', 'C', '', 1, 1, 'Y', 'taJ2kHBZ-Z4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (236, '2012-09-12 06:41:49.92548+00', '2012-09-18 21:24:49.862159+00', 6104, 1, 1041, '', 'C', '', 1, 1, 'Y', 'ReuGjv0SZfU', 38, 0, NULL);
INSERT INTO 'dancevideo' VALUES (268, '2012-09-18 14:51:38.329798+00', '2012-09-18 21:28:48.579716+00', 1982, 1, 513, '', 'D', '', 1, 1, 'Y', 'dl82LVuvy7s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (234, '2012-09-12 06:37:34.428402+00', '2012-09-18 21:48:55.45077+00', 5915, 1, 1041, '', 'A', '', 1, 1, 'Y', 'U7BPfF6j5Mo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (247, '2012-09-12 19:17:03.837578+00', '2012-09-18 21:56:03.967001+00', 7204, 1, 1041, '', 'A', '', 1, 1, 'Y', 'OqbWAyGrUVI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (239, '2012-09-12 06:49:12.153916+00', '2012-09-18 21:53:41.581426+00', 6287, 1, 1041, '', 'C', '', 1, 1, 'Y', 'wvsJTA7VHwg', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (232, '2012-09-11 21:59:32.766447+00', '2012-09-18 22:36:20.084809+00', 5637, 2, 1041, '', 'B', '', 1, 1, 'Y', 'bwv-XApNsr4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (269, '2012-09-18 15:00:55.600817+00', '2012-09-18 22:38:24.479818+00', 12839, 1, 513, '', 'D', '', 1, 1, 'Y', 'ew4D9mi-y-s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (356, '2012-11-24 03:21:20.69432+00', '2012-11-24 23:48:09.779109+00', 5713, 1, 961, '', 'B', 'The audience''s cheering does settle down later in the video. The camera zooms in and out a little during the dance, but captures everything important.', 1, 1, 'Y', '7PQGOq0jedw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (230, '2012-09-11 21:55:24.9096+00', '2012-09-18 19:24:57.983211+00', 5529, 2, 1041, '', 'C', 'The dancing is good, bu the progression is abnormal. This dance is danced "once and to the bottom".  For that the dancing couple moves to 4pl (and 3c+4c step up) on bars 23-24.  That rather spoils the link between the figures on bar 24.', 1, 1, 'Y', '5byCvG6lTd8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (297, '2012-10-16 14:27:23.932799+00', '2012-10-16 22:09:32.841688+00', 8726, 1, 513, '', 'D', '', 1, 1, 'Y', 'q2ZnmKdNvlE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (301, '2012-10-16 18:36:09.630117+00', '2012-10-16 22:14:25.56924+00', 13581, 2, 513, '', 'D', '', 1, 1, 'Y', 'MmJVc0CNYEY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (314, '2012-10-17 11:34:30.322564+00', '2012-10-17 20:36:40.968434+00', 1884, 1, 513, '', 'C', '', 1, 1, 'Y', 'Q6FVG0NODtM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (275, '2012-09-21 22:12:49.54105+00', '2012-09-21 22:16:51.688724+00', 4239, 2, 106, '', 'B', '', 1, 1, 'Y', '73s-7ErcgvE', 165, 0, NULL);
INSERT INTO 'dancevideo' VALUES (276, '2012-09-21 22:45:15.495279+00', '2012-09-21 22:46:16.398917+00', 11188, 2, 106, '', 'B', '', 1, 1, 'Y', '73s-7ErcgvE', 99, 0, NULL);
INSERT INTO 'dancevideo' VALUES (302, '2012-10-16 18:39:58.977845+00', '2012-10-16 22:20:49.432297+00', 12792, 2, 513, '', 'D', '', 1, 1, 'Y', 'if8c4ojZREw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (277, '2012-09-21 23:13:34.081505+00', '2012-09-21 23:21:45.92116+00', 1931, 1, 106, '', 'C', 'Good dancers, but making a lot of fun movements.', 1, 1, 'Y', 'fEhsYBdjeKs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (294, '2012-10-16 13:34:39.725135+00', '2012-10-16 22:30:47.200914+00', 9836, 2, 513, '', 'A', 'RSCDS Summer School 2006

Country Dance Demonstration in week 4', 1, 1, 'Y', 'M7Ez9ELo3BU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (278, '2012-09-21 23:27:50.839126+00', '2012-09-21 23:31:38.277292+00', 4015, 2, 106, '', 'C', '', 1, 1, 'Y', '9_1DXMMS_EY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (279, '2012-09-24 07:31:25.687722+00', '2012-09-24 10:59:10.646546+00', 9203, 1, 513, '', 'C', '', 1, 1, 'Y', '0u65XayzH0k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (298, '2012-10-16 15:06:05.112786+00', '2012-10-16 22:37:07.862372+00', 109, 1, 513, '', 'A', '', 1, 1, 'Y', 'TROCNEKbw_U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (296, '2012-10-16 14:17:51.717189+00', '2012-10-16 22:40:24.581171+00', 2360, 1, 513, '', 'B', '', 1, 1, 'Y', 'AbnbYnTgzm8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (280, '2012-09-24 07:32:26.844172+00', '2012-09-24 21:03:32.464321+00', 12279, 1, 513, '', 'D', '', 1, 1, 'Y', 'affjGFIuxhg', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (284, '2012-10-01 07:43:10.314681+00', '2012-10-01 22:28:23.297353+00', 2604, 1, 513, '', 'D', '', 1, 1, 'Y', 'loqEExprpjI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (300, '2012-10-16 15:26:24.088316+00', '2012-10-16 23:10:07.072664+00', 13314, 1, 513, '', 'B', '', 1, 1, 'Y', '4-2PTW-K25M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (283, '2012-10-01 07:41:35.325546+00', '2012-10-01 22:33:42.085093+00', 12680, 1, 513, '', 'D', '', 1, 1, 'Y', 'WMvwWj2nKSg', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (285, '2012-10-01 07:44:45.527574+00', '2012-10-01 22:39:58.00724+00', 8932, 1, 513, '', 'D', '', 1, 1, 'Y', '00JqSerWjQw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (289, '2012-10-04 07:23:39.938069+00', '2012-10-10 22:47:37.853445+00', 11893, 1, 513, '', 'C', '', 1, 1, 'Y', 'PuLgSA76GsI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (292, '2012-10-14 10:32:54.170991+00', '2012-10-14 23:05:22.847397+00', 3834, 1, 274, '', 'C', 'Scottish Dance House for beginners, 2011, Budapest, Hungary', 1, 1, 'Y', 'G6jg35nCUKk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (293, '2012-10-14 10:34:39.702989+00', '2012-10-15 01:00:16.413733+00', 7286, 2, 274, '', 'B', '', 1, 1, 'Y', 'qzQhG3jdbpk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (274, '2012-09-19 07:54:21.48847+00', '2013-12-28 23:47:36.692362+00', 13579, 2, 513, '', 'A', '', 1, 1, 'Y', 'Tbhp10EE-tE', 23, 0, NULL);
INSERT INTO 'dancevideo' VALUES (272, '2012-09-19 07:50:14.053252+00', '2014-08-23 20:25:08.187243+00', 5330, 3, 513, '', 'A', 'Twice through; by RSCDS Vancouver Demonstration Team.', 1, 1, 'Y', 'JVYYCx7snk4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (291, '2012-10-14 10:24:30.263869+00', '2012-10-15 01:04:38.814414+00', 14477, 1, 274, '', 'C', 'This dance was devised for dancers who dance in wheelchairs, so as to enrich their repertoire. More info: www.bstk.hu/rolling/

', 1, 1, 'Y', 'EdLya7T1I-8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (295, '2012-10-16 13:36:41.987707+00', '2012-10-16 22:08:24.442995+00', 12794, 1, 513, '', 'A', 'RSCDS Summer School 2006 in St Andrews/Scotland

Country Dance Demonstration week 4', 1, 1, 'Y', 'BUlOlIufqU4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (305, '2012-10-17 08:29:48.166589+00', '2012-10-17 08:55:21.485207+00', 4411, 3, 513, '', 'A', '', 1, 1, 'Y', 'BtmuJFy-MQA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (304, '2012-10-17 08:13:06.385629+00', '2012-10-17 09:01:20.030941+00', 2616, 2, 513, '', 'C', '', 1, 1, 'Y', 'W4Y2Mv2C370', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (307, '2012-10-17 08:54:00.81476+00', '2012-10-17 09:06:13.012064+00', 14484, 2, 513, '', 'C', '', 1, 1, 'Y', 'kOENf-lyJHc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (311, '2012-10-17 11:04:32.553323+00', '2012-10-17 20:58:29.540112+00', 10535, 2, 513, '', 'A', '', 1, 1, 'Y', 'oHzrHoQGM_s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (306, '2012-10-17 08:30:37.164453+00', '2012-10-17 09:11:33.606159+00', 11190, 1, 513, '', 'A', '', 1, 1, 'Y', 'BOpbKbMoX3A', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (313, '2012-10-17 11:14:27.426745+00', '2012-10-17 21:06:22.418238+00', 8684, 1, 513, '', 'C', '', 1, 1, 'Y', '1ZQCeqrgmnE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (308, '2012-10-17 09:23:57.892229+00', '2012-10-17 20:19:22.839265+00', 7061, 2, 513, '', 'C', '', 1, 1, 'Y', 'Q7-iMiAxD6g', 18, 0, NULL);
INSERT INTO 'dancevideo' VALUES (316, '2012-10-17 14:43:00.94712+00', '2012-10-17 20:29:04.961897+00', 5915, 2, 513, '', 'C', '', 1, 1, 'Y', 'XM0iMD9y2lE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (312, '2012-10-17 11:10:13.090081+00', '2012-10-17 21:56:54.945872+00', 10381, 1, 513, '', 'A', '', 1, 1, 'Y', 'VfuATfbSxjY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (322, '2012-10-22 15:17:46.151531+00', '2012-10-22 20:47:23.498141+00', 14243, 1, 513, '', 'A', '', 1, 1, 'Y', 'yX5qsojGJhY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (310, '2012-10-17 10:15:04.086542+00', '2017-12-17 16:10:07.089218+00', 5885, 2, 513, '', 'B', '', 1, 1, 'Y', 'JiuwEJFa0I4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (282, '2012-09-30 17:17:33.768652+00', '2016-01-01 14:02:10.762835+00', 4354, 1, 106, '', 'B', 'This video, by Dunedin Dancers, of Edinburgh, and recorded on 29/07/2011, shows left shoulder passes in bars 13-16 and 29-32 where John Drewry specified right shoulder passes.', 1, 1, 'Y', 'cluM_GrG4oc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (273, '2012-09-19 07:52:20.453061+00', '2017-02-28 15:43:27.785357+00', 13316, 1, 513, '', 'A', 'The RSCDS Vancouver Branch Demonstration Team perform at the 2009 Burns Supper', 1, 1, 'Y', '2oHqBdqwjwc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (406, '2012-12-17 14:17:47.229113+00', '2012-12-20 11:43:51.31768+00', 549, 3, 1296, '', 'C', '', 1, 1, 'Y', 'yXhwc_P6I9o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (375, '2012-12-17 14:17:19.605381+00', '2012-12-20 11:51:29.935365+00', 7339, 1, 1296, '', 'B', '', 1, 1, 'Y', 'mevFKwaYWnU', 80, 237, NULL);
INSERT INTO 'dancevideo' VALUES (233, '2012-09-11 22:06:52.003607+00', '2017-12-17 21:39:44.907862+00', 5885, 1, 1041, '', 'B', 'From the evening programme at a Weekend School of Scottish Country Dance in Lyon, France in January 2009. The first couple are Sophie Rickebusch and Antoine Rousseau, and the live music is by James Gray (piano) and Keith Smith (fiddle).', 1, 1, 'Y', 'qk_0DaIdzoo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (315, '2012-10-17 13:06:18.976512+00', '2012-10-17 22:28:46.786005+00', 8091, 1, 513, '', 'B', '', 1, 1, 'Y', 'RtlZ9sPPxVk', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (320, '2012-10-18 12:45:16.867237+00', '2012-10-18 15:08:12.673841+00', 10663, 1, 513, '', 'C', '', 1, 1, 'Y', 'oRqzcldDfLM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (324, '2012-10-22 15:24:35.429014+00', '2012-10-22 20:34:55.028066+00', 3057, 2, 513, '', 'A', '', 1, 1, 'Y', 'KdyeA5qdWBk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (323, '2012-10-22 15:22:29.801812+00', '2012-10-22 20:43:45.830077+00', 4046, 1, 513, '', 'B', '', 1, 1, 'Y', 'uhNizsB-208', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (325, '2012-10-29 10:06:06.429635+00', '2012-10-29 20:35:50.805898+00', 12428, 2, 513, '', 'C', '', 1, 1, 'Y', 'zuXU53qhC4A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (299, '2012-10-16 15:07:39.548771+00', '2021-03-02 12:00:36.639904+00', 4407, 1, 513, '', 'B', '', 1, 1, 'Y', 'JCPmLTpDe90', 9, 0, NULL);
INSERT INTO 'dancevideo' VALUES (327, '2012-11-07 08:30:38.977624+00', '2012-11-07 11:40:54.809135+00', 159, 2, 513, '', 'C', '', 1, 1, 'Y', '_vwy28eV7Qc', 39, 0, NULL);
INSERT INTO 'dancevideo' VALUES (329, '2012-11-07 09:50:17.693426+00', '2012-11-07 12:13:18.523164+00', 14532, 1, 513, '', 'C', 'Only once through; big hall viewed from too far.', 1, 1, 'Y', 'pMNgAaDfJZM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (328, '2012-11-07 09:06:31.397302+00', '2012-11-07 11:34:34.646705+00', 4359, 1, 513, '', 'C', '', 1, 1, 'Y', 'Lt2_OGWaG_U', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (331, '2012-11-12 15:52:23.794202+00', '2012-11-12 20:54:40.700551+00', 674, 2, 513, '', 'C', '', 1, 1, 'Y', 'hLnx5PZpcOI', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (332, '2012-11-12 15:54:01.764857+00', '2012-11-12 20:33:08.839213+00', 445, 1, 513, '', 'B', '', 1, 1, 'Y', 'LxgXzHYlqp8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (330, '2012-11-12 13:15:54.285956+00', '2012-11-13 06:52:43.987514+00', 7286, 3, 513, '', 'A', '', 1, 1, 'Y', '-KA0sw8V7W4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (345, '2012-11-20 09:12:10.309229+00', '2012-11-24 23:45:12.457443+00', 6947, 2, 513, '', 'C', '', 1, 1, 'Y', 'MoVhXANPibg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (340, '2012-11-18 15:22:26.036482+00', '2012-11-24 23:57:06.375764+00', 1533, 1, 513, '', 'B', '', 1, 1, 'Y', 'SioOnhgVlts', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (341, '2012-11-18 15:24:28.814117+00', '2012-11-28 09:16:02.487322+00', 10769, 1, 513, '', 'B', '', 1, 1, 'Y', 'WHDmEsWqP6U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (342, '2012-11-18 15:37:13.667746+00', '2012-11-28 09:16:55.06761+00', 2598, 1, 513, '', 'C', '', 1, 1, 'Y', 'arEGWeZIui4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (354, '2012-11-24 03:05:11.523696+00', '2012-11-24 21:21:24.735334+00', 462, 1, 961, '', 'B', 'The sound may be slightly out of sync, and the quality of the video is rather low.

Found via http://www.scottish-country-dancing-dictionary.com/dance-crib/belle-of-bon-accord.html', 1, 1, 'Y', 'AYphljNx_bk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (348, '2012-11-20 09:15:09.134545+00', '2012-11-24 21:38:18.009045+00', 2600, 1, 513, '', 'B', '', 1, 1, 'Y', 'GsMUSYMEiuE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (355, '2012-11-24 03:11:30.120237+00', '2012-11-24 22:59:01.876559+00', 6010, 1, 961, '', 'B', '', 1, 1, 'Y', 'lzrLNS9XNIM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (346, '2012-11-20 09:13:15.833032+00', '2012-11-24 23:15:08.946497+00', 3033, 1, 513, '', 'C', '', 1, 1, 'Y', 'hXLew7UP6Lg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (350, '2012-11-20 09:16:46.660864+00', '2012-11-24 23:23:41.990215+00', 7045, 1, 513, '', 'C', '', 1, 1, 'Y', 'JodPJjksJys', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (344, '2012-11-20 09:11:12.548405+00', '2012-11-24 23:39:24.606455+00', 6947, 1, 513, '', 'C', '', 1, 1, 'Y', 'n8tDYmqA3TE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (349, '2012-11-20 09:15:58.954556+00', '2012-11-28 09:16:16.989168+00', 1992, 1, 513, '', 'C', '', 1, 1, 'Y', 'ivMNpWFjDOU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (582, '2012-12-17 14:18:41.99329+00', '2012-12-25 17:53:50.821716+00', 3759, 2, 1296, '', 'B', 'Once through only.', 1, 1, 'Y', 'wxjyNzIYdPo', 98, 160, NULL);
INSERT INTO 'dancevideo' VALUES (454, '2012-12-17 14:17:59.832475+00', '2012-12-18 12:27:31.781963+00', 1473, 3, 1296, '', 'A', '', 1, 1, 'Y', 'c94Pb0HuY4Y', 0, 262, NULL);
INSERT INTO 'dancevideo' VALUES (363, '2012-12-08 18:53:49.046673+00', '2012-12-08 18:54:19.929196+00', 5330, 5, 106, '', 'D', 'Fun dance: the fourth man is replaced by a broom.  The arches are made such that the broom always passes under.  ', 1, 1, 'Y', 'osGv7Ev63zk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (347, '2012-11-20 09:14:05.313439+00', '2012-11-28 09:17:26.817831+00', 7878, 1, 513, '', 'C', '', 1, 1, 'Y', 'CERkSVJzDds', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (358, '2012-11-29 00:54:29.796436+00', '2012-11-29 06:11:56.111466+00', 3941, 1, 57, '', 'B', 'The dance instructions (Collins book, p. 220) for bars 9-16 say "Pas de Basque | Coupé ; repeat".  In this video the set dances "Coupé | Pas de Basque ; repeat". 



For bars 33-40 the instructions tell 2nd couple not to move on bars 35-36, but to step up together with 3rd and 4th couples on 39-40.  In this video 2c steps up on [35-36]', 1, 1, 'Y', 'IJNAmUzMSNE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (364, '2012-12-09 09:55:27.389748+00', '2012-12-09 10:13:42.078096+00', 3119, 1, 106, '', 'B', 'At New Scotland Country Dance Society''s Summer Dance 2011



At the end the outside couples dance a 3/4 chase.  This is a common variant in social dancing; it should be 3/4 Hands Round, much more difficult.  The clapping and extra twirls are not "official".', 1, 1, 'Y', '12hJQg46T04', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (334, '2012-11-12 20:39:16.418939+00', '2012-12-18 12:41:13.583903+00', 5330, 4, 106, '', 'D', '', 1, 1, 'Y', 'LpcwdPGR1Hg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (439, '2012-12-17 14:17:56.596555+00', '2012-12-26 00:47:01.098748+00', 1223, 4, 1296, '', 'C', 'Once through only.', 1, 1, 'Y', 'qaAjz1SgQ1I', 202, 237, NULL);
INSERT INTO 'dancevideo' VALUES (441, '2012-12-17 14:17:56.844461+00', '2012-12-21 00:46:54.178739+00', 1280, 1, 1296, '', 'B', '', 1, 1, 'Y', 'Z1J1hbZKdao', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (97, '2012-06-11 00:14:44.616079+00', '2012-11-29 23:08:40.213453+00', 584, 1, 961, '', 'B', 'discovered via http://www.scottish-country-dancing-dictionary.com/scottish-dancing-youtube-videos.html



In this video the dance has been modified.  On bars 1-8, 1C+2C and 3C+4C set and link {4} followed by RHA {4}. Both the crib and diagrams say "all set {2}, RHA at top and bottom {4}, 1C and 4C cast to middle as 2C+3C step to the ends {2}".  Regards, Amy', 1, 1, 'Y', '0IlUNVdgt24', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (360, '2012-12-01 12:54:22.158276+00', '2012-12-01 23:45:27.819584+00', 7286, 4, 513, '', 'A', 'Danced by the Budapest Skót Tánc Klub   <www.bstk.hu>', 1, 1, 'Y', 'pk-htk9tWoM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (361, '2012-12-03 21:42:11.445092+00', '2012-12-07 12:51:34.371393+00', 1829, 1, 1111, '', 'B', 'Incorrect music.  Bars 1-2 not danced as written.  For the last 16 bars top two couples should be standing.  But competently done otherwise.', 1, 1, 'Y', 'TvZ01v3HVWE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (357, '2012-11-26 09:44:13.502532+00', '2012-12-07 14:31:12.829317+00', 12674, 1, 513, '', 'B', 'Chiswick SCDC, November 2012', 1, 1, 'Y', 'cPp_ywaJWMQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (367, '2012-12-17 08:35:09.493483+00', '2012-12-17 08:35:34.980887+00', 6756, 1, 1, '', 'A', '', 1, 1, 'Y', 'w2uG1vyedDs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (437, '2012-12-17 14:17:56.519657+00', '2012-12-18 12:26:34.050569+00', 1223, 2, 1296, '', 'B', '', 1, 1, 'Y', 'Ky2KZdEV60Y', 0, 56, NULL);
INSERT INTO 'dancevideo' VALUES (370, '2012-12-17 14:13:21.580861+00', '2012-12-18 11:41:20.282104+00', 9631, 1, 1296, '', 'B', '', 1, 1, 'Y', 'ZwQk668FN_s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (335, '2012-11-13 19:31:16.349621+00', '2018-02-25 23:02:12.088546+00', 13576, 1, 562, '', 'B', 'This video was recorded at the Kukucksnest, Schluechtern, Germany.', 1, 1, 'Y', 'BF39EwnqnkQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (333, '2012-11-12 15:56:41.062221+00', '2013-10-04 22:00:40.182881+00', 2822, 1, 513, '', 'D', '', 1, 1, 'Y', 'AhvzS9fWC8s', 29, 0, NULL);
INSERT INTO 'dancevideo' VALUES (395, '2012-12-17 14:17:35.969413+00', '2012-12-19 12:36:10.857819+00', 445, 2, 1296, '', 'C', '', 1, 1, 'Y', 'ql3z20tWH8k', 62, 0, NULL);
INSERT INTO 'dancevideo' VALUES (432, '2012-12-17 14:17:54.658104+00', '2012-12-18 12:24:38.457667+00', 1163, 1, 1296, '', 'A', '', 1, 1, 'Y', 'fUICpEO1_ao', 270, 417, NULL);
INSERT INTO 'dancevideo' VALUES (390, '2012-12-17 14:17:31.19291+00', '2012-12-18 12:44:48.348813+00', 13149, 3, 1296, '', 'A', '', 1, 1, 'Y', 'fUICpEO1_ao', 11, 266, NULL);
INSERT INTO 'dancevideo' VALUES (398, '2012-12-17 14:17:36.165115+00', '2012-12-19 13:25:24.357263+00', 445, 5, 1296, '', 'C', '', 1, 1, 'Y', '4ArA3BXBOng', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (371, '2012-12-17 14:17:18.715551+00', '2012-12-19 13:15:30.373698+00', 54, 2, 1296, '', 'C', '', 1, 1, 'Y', 'IIpe1EKg5cw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (418, '2012-12-17 14:17:52.079426+00', '2013-02-08 11:57:55.726183+00', 848, 1, 1296, '', 'B', '', 1, 1, 'Y', '0IRzp_-qgJA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (321, '2012-10-22 15:16:19.395499+00', '2017-06-04 15:39:05.735854+00', 14244, 1, 513, '', 'A', 'A 3x40 Reel by Richard Bennett, from the book Katannuta, danced by the Salt Spring Scottish Country Dance Club', 1, 1, 'Y', '1FekkeVLmYw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (326, '2012-11-06 14:00:00.100374+00', '2018-09-07 15:30:20.954877+00', 652, 1, 513, '', 'C', '', 1, 1, 'Y', 'xfLkbBuoDSE', 90, 0, NULL);
INSERT INTO 'dancevideo' VALUES (368, '2012-12-17 10:48:10.929962+00', '2012-12-19 18:35:33.413478+00', 2125, 1, 1041, '', 'B', '', 1, 1, 'Y', 'LInbapMWkeo', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (394, '2012-12-17 14:17:34.443722+00', '2012-12-19 13:26:27.201651+00', 428, 1, 1296, '', 'B', '', 1, 1, 'Y', 'QFIpdgGycOQ', 0, 214, NULL);
INSERT INTO 'dancevideo' VALUES (408, '2012-12-17 14:17:48.784338+00', '2012-12-19 13:30:39.604319+00', 584, 2, 1296, '', 'C', '', 1, 1, 'Y', 'PaNQh2K5Q4s', 1, 138, NULL);
INSERT INTO 'dancevideo' VALUES (405, '2012-12-17 14:17:47.181586+00', '2012-12-19 13:34:38.350445+00', 549, 2, 1296, '', 'C', '', 1, 1, 'Y', '4ZIHN0LBisU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (391, '2012-12-17 14:17:31.197334+00', '2012-12-19 22:56:38.514431+00', 13149, 4, 1296, '', 'B', '', 1, 1, 'Y', 'Q8Pn4Q2PcMg', 0, 120, NULL);
INSERT INTO 'dancevideo' VALUES (399, '2012-12-17 14:17:37.497158+00', '2012-12-20 11:39:50.505564+00', 12426, 3, 1296, '', 'C', 'This video uses reel-time music even though the dance is actually a jig.', 1, 1, 'Y', 'dEEktMQNZxo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (396, '2012-12-17 14:17:36.056859+00', '2012-12-20 11:31:33.510248+00', 445, 3, 1296, '', 'B', '', 1, 1, 'Y', '42_8iujkR3Y', 204, 272, NULL);
INSERT INTO 'dancevideo' VALUES (400, '2012-12-17 14:17:37.588861+00', '2012-12-20 11:36:50.809867+00', 12426, 4, 1296, '', 'D', '', 1, 1, 'Y', 'TgoUOEqjQ4A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (387, '2012-12-17 14:17:24.074081+00', '2012-12-20 23:46:46.291788+00', 314, 5, 1296, '', 'B', 'Once through only', 1, 1, 'Y', 'YI-6NqMxJyY', 71, 138, NULL);
INSERT INTO 'dancevideo' VALUES (377, '2012-12-17 14:17:21.025861+00', '2012-12-25 21:41:01.397154+00', 12665, 1, 1296, '', 'B', 'Twice through only', 1, 1, 'Y', '3Sofq6x3GtU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (388, '2012-12-17 14:17:27.533193+00', '2012-12-25 23:24:39.917555+00', 358, 1, 1296, '', 'D', '', 1, 1, 'Y', '5FEEo69tYvk', 127, 226, NULL);
INSERT INTO 'dancevideo' VALUES (378, '2012-12-17 14:17:21.188792+00', '2012-12-25 21:40:21.298047+00', 12665, 2, 1296, '', 'C', '', 1, 1, 'Y', '3q_rUH0l2Kc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (379, '2012-12-17 14:17:21.220256+00', '2012-12-25 21:44:29.074088+00', 12665, 3, 1296, '', 'C', '', 1, 1, 'Y', 'TYa0zyummZI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (380, '2012-12-17 14:17:21.244408+00', '2012-12-25 21:53:43.640619+00', 12665, 4, 1296, '', 'C', '', 1, 1, 'Y', 'CCE3p7TmKTI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (431, '2012-12-17 14:17:54.496655+00', '2013-02-09 22:44:13.146835+00', 12085, 1, 1296, '', 'B', '3 times through.', 1, 1, 'Y', '9M4LDoK1hds', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (404, '2012-12-17 14:17:47.00993+00', '2012-12-25 23:41:47.771061+00', 542, 1, 1296, '', 'B', '', 1, 1, 'Y', 'Z06fWvyYv2U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (410, '2012-12-17 14:17:49.212667+00', '2012-12-26 00:00:28.584202+00', 633, 2, 1296, '', 'B', '', 1, 1, 'Y', 'Zo0RJFEelO0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (411, '2012-12-17 14:17:49.241911+00', '2012-12-26 00:02:59.136914+00', 633, 3, 1296, '', 'C', '', 1, 1, 'Y', '80twvZmbp70', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (412, '2012-12-17 14:17:49.434863+00', '2012-12-26 00:05:35.241156+00', 713, 1, 1296, '', 'D', '', 1, 1, 'Y', '7hHOTFbNezU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (415, '2012-12-17 14:17:51.136807+00', '2012-12-26 00:12:27.94462+00', 795, 1, 1296, '', 'A', 'Once through, in two 3C sets joined bottom to bottom.', 1, 1, 'Y', 'NnnFfJUXyGc', 236, 301, NULL);
INSERT INTO 'dancevideo' VALUES (416, '2012-12-17 14:17:51.248689+00', '2012-12-26 00:17:28.323052+00', 11188, 3, 1296, '', 'B', '', 1, 1, 'Y', 'XqsivGyBGL0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (420, '2012-12-17 14:17:52.328383+00', '2012-12-26 00:27:55.851818+00', 887, 3, 1296, '', 'B', '', 1, 1, 'Y', '4wHcNOR5Qrs', 3, 238, NULL);
INSERT INTO 'dancevideo' VALUES (438, '2012-12-17 14:17:56.572481+00', '2012-12-26 00:43:14.918148+00', 1223, 3, 1296, '', 'D', 'The whole video is a tribute to Derek Haynes.  The dance itself starts at 0:46.', 1, 1, 'Y', 'CMpOYg_-pK8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (429, '2012-12-17 14:17:53.591505+00', '2012-12-26 00:37:18.125517+00', 11375, 1, 1296, '', 'B', '', 1, 1, 'Y', '81Uj-DIzwDw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (424, '2012-12-17 14:17:53.057829+00', '2012-12-28 16:00:06.352457+00', 7553, 2, 1296, '', 'D', '', 1, 1, 'Y', 'MSEBdX4d0QM', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (434, '2012-12-17 14:17:54.786721+00', '2013-01-04 10:58:25.074426+00', 1176, 1, 1296, '', 'C', '', 1, 1, 'Y', '7X0jsnU7wrQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (430, '2012-12-17 14:17:54.125322+00', '2013-01-01 11:26:07.005712+00', 10071, 1, 1296, '', 'D', '', 1, 1, 'Y', 'vFzMej0ytow', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (372, '2012-12-17 14:17:19.048632+00', '2013-01-16 01:47:34.022059+00', 7421, 1, 1296, '', 'B', 'once through only', 1, 1, 'Y', 'lkX1a4pACts', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (381, '2012-12-17 14:17:21.462179+00', '2013-01-23 00:48:38.366058+00', 13079, 1, 1296, '', 'C', 'Horizontal view.  Once through only.', 1, 1, 'Y', '6YBrd2Aeujo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (541, '2012-12-17 14:18:30.137105+00', '2013-02-09 21:36:21.879971+00', 12769, 1, 1296, '', 'A', '', 1, 1, 'Y', 'ZdIebd_vQ_E', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (383, '2012-12-17 14:17:21.610705+00', '2013-01-24 23:45:48.804531+00', 188, 1, 1296, '', 'D', 'Good view from above.  Useful for teaching.  First time through removed as a mistake was made.', 1, 1, 'Y', 'MGybP0a3ebs', 36, 0, NULL);
INSERT INTO 'dancevideo' VALUES (374, '2012-12-17 14:17:19.489262+00', '2013-02-07 02:54:44.63877+00', 12801, 2, 1296, '', 'B', 'Part of longer demo.  Once through', 1, 1, 'Y', 'a1X2CRUX5Qc', 434, 496, NULL);
INSERT INTO 'dancevideo' VALUES (491, '2012-12-17 14:18:12.322733+00', '2012-12-20 23:54:24.099415+00', 12793, 3, 1296, '', 'B', 'Part of a longer display; only once through.', 1, 1, 'Y', 'YI-6NqMxJyY', 137, 172, NULL);
INSERT INTO 'dancevideo' VALUES (423, '2012-12-17 14:17:53.04525+00', '2023-01-31 21:58:41.126547+00', 7553, 1, 1296, '', 'B', 'This video teaches the dance which is then danced from 1:36.', 1, 1, 'Y', 'mc0yO39IRKg', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (520, '2012-12-17 14:18:24.882159+00', '2012-12-19 13:48:12.350659+00', 2437, 2, 1296, '', 'A', '', 1, 1, 'Y', 'Yfog5CEj-ac', 208, 272, NULL);
INSERT INTO 'dancevideo' VALUES (510, '2012-12-17 14:18:21.881924+00', '2012-12-20 22:29:51.52767+00', 2267, 3, 1296, '', 'B', '', 1, 1, 'Y', 'M3y93SFGCoY', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (445, '2012-12-17 14:17:57.482137+00', '2012-12-20 11:54:44.096383+00', 1348, 1, 1296, '', 'D', '', 1, 1, 'Y', 'QdKNoVuRxe8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (477, '2012-12-17 14:18:06.566529+00', '2012-12-20 12:00:07.33376+00', 1782, 1, 1296, '', 'B', '', 1, 1, 'Y', 'vfsKEehlNL0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (478, '2012-12-17 14:18:06.701727+00', '2012-12-20 12:01:55.762017+00', 1786, 1, 1296, '', 'A', '', 1, 1, 'Y', 'o_OpMH-Mka4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (389, '2012-12-17 14:17:31.129217+00', '2013-07-06 12:50:11.588537+00', 13149, 2, 1296, '', 'A', '', 1, 1, 'Y', 'hZH5dkf4IrU', 244, 517, NULL);
INSERT INTO 'dancevideo' VALUES (462, '2012-12-17 14:18:03.350418+00', '2013-12-30 20:45:59.15241+00', 1544, 2, 1296, '', 'A', '', 1, 1, 'Y', 'Ky2KZdEV60Y', 84, 150, NULL);
INSERT INTO 'dancevideo' VALUES (479, '2012-12-17 14:18:06.713181+00', '2012-12-20 12:04:34.010475+00', 1786, 2, 1296, '', 'C', '', 1, 1, 'Y', 'fLKrxxlylmE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (521, '2012-12-17 14:18:24.960633+00', '2012-12-20 23:31:55.107316+00', 2437, 3, 1296, '', 'B', 'Second part of a longer display in a 3C set; once through only.', 1, 1, 'Y', 'Hk6NM5vjGzM', 75, 136, NULL);
INSERT INTO 'dancevideo' VALUES (461, '2012-12-17 14:18:02.902544+00', '2013-01-04 11:04:38.761884+00', 1543, 2, 1296, '', 'B', '', 1, 1, 'Y', 'OAgex6kwzLA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (472, '2012-12-17 14:18:06.112354+00', '2012-12-21 00:16:59.941359+00', 9084, 4, 1296, '', 'B', 'Twice through only; final finish modified to link to the next dance.', 1, 1, 'Y', 'wZpLQupGccY', 0, 73, NULL);
INSERT INTO 'dancevideo' VALUES (475, '2012-12-17 14:18:06.268584+00', '2012-12-21 16:47:26.712264+00', 10433, 3, 1296, '', 'A', '', 1, 1, 'Y', 'WAPRVoqaEec', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (466, '2012-12-17 14:18:04.768987+00', '2012-12-21 00:33:21.125098+00', 1582, 2, 1296, '', 'D', '', 1, 1, 'Y', 'VHE9SqYv66k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (473, '2012-12-17 14:18:06.128636+00', '2012-12-21 00:39:31.987261+00', 9084, 5, 1296, '', 'C', '', 1, 1, 'Y', 'xOnHXu60EcE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (471, '2012-12-17 14:18:06.095965+00', '2012-12-21 00:42:41.501062+00', 9084, 3, 1296, '', 'C', '', 1, 1, 'Y', 'IP6h-Ysmoms', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (474, '2012-12-17 14:18:06.248657+00', '2012-12-21 16:40:30.238698+00', 10433, 2, 1296, '', 'B', 'Starts on bar 10.  ', 1, 1, 'Y', 'Ks4qrXP2KC0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (476, '2012-12-17 14:18:06.298017+00', '2012-12-21 16:52:08.346123+00', 10433, 4, 1296, '', 'B', '', 1, 1, 'Y', 'WWW1YaHN8BQ', 201, 389, NULL);
INSERT INTO 'dancevideo' VALUES (519, '2012-12-17 14:18:24.162487+00', '2012-12-26 11:24:09.403711+00', 7546, 2, 1296, '', 'D', '', 1, 1, 'Y', 'lCwbGrJfh84', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (480, '2012-12-17 14:18:07.113416+00', '2012-12-28 20:52:32.701535+00', 1792, 2, 1296, '', 'D', '', 1, 1, 'Y', 'rZvxDw77rFQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (456, '2012-12-17 14:18:00.34928+00', '2012-12-27 16:13:12.550032+00', 1478, 2, 1296, '', 'C', '', 1, 1, 'Y', 'Q70GBT9-w8s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (450, '2012-12-17 14:17:58.541952+00', '2012-12-27 16:23:53.767397+00', 9083, 1, 1296, '', 'D', '', 1, 1, 'Y', 'uce2dIC4XQc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3570, '2018-06-11 21:58:10.928753+00', '2018-06-11 22:01:07.86444+00', 7283, 5, 1645, '', 'A', '', 1, 1, 'Y', 'r8z2mnNFBbM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (449, '2012-12-17 14:17:58.048951+00', '2012-12-28 21:05:54.028975+00', 9157, 2, 1296, '', 'C', '', 1, 1, 'Y', 'EKV0fBPbCXQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (448, '2012-12-17 14:17:58.032865+00', '2012-12-28 21:11:58.337725+00', 9157, 1, 1296, '', 'C', 'Six times "once and to the bottom" in a 3C set.', 1, 1, 'Y', 'wjZb_mJegA4', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (524, '2012-12-17 14:18:27.878196+00', '2012-12-29 00:15:09.64799+00', 2506, 1, 1296, '', 'B', '', 1, 1, 'Y', 'wxjyNzIYdPo', 65, 99, NULL);
INSERT INTO 'dancevideo' VALUES (503, '2012-12-17 14:18:16.55806+00', '2012-12-29 00:19:28.395817+00', 2129, 2, 1296, '', 'D', 'This variation replaces the chain on bars 17-24 with a promenade.', 1, 1, 'Y', 'YvSXocSBZOw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (502, '2012-12-17 14:18:16.008824+00', '2012-12-29 00:23:49.048606+00', 2129, 1, 1296, '', 'D', 'This version replaces the chain on bars 17-24 with a promenade.', 1, 1, 'Y', '6YRBOAucdlY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (487, '2012-12-17 14:18:08.705165+00', '2012-12-31 13:25:44.5179+00', 1884, 2, 1296, '', 'C', 'Once through completely, second time through broken off.', 1, 1, 'Y', 'uMWILFKz6Zk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (509, '2012-12-17 14:18:21.869733+00', '2012-12-29 00:29:46.632221+00', 2267, 2, 1296, '', 'B', '', 1, 1, 'Y', 'fZ4Xcp38WAU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (447, '2012-12-17 14:17:57.874043+00', '2012-12-30 00:05:50.801656+00', 9420, 1, 1296, '', 'B', '', 1, 1, 'Y', 'nQB0SuymjMo', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (505, '2012-12-17 14:18:16.792221+00', '2013-01-20 21:12:18.854426+00', 13385, 1, 1296, '', 'A', 'Summer School 2008, week 1, last dance of the demo.  Once through only.  Bars 17-24 modified (one couple A&R each time, instead of all); at the end the dancers leave the hall.', 1, 1, 'Y', 'kJZJLlJvnaQ', 362, 402, NULL);
INSERT INTO 'dancevideo' VALUES (484, '2012-12-17 14:18:07.661387+00', '2013-01-04 11:08:57.45807+00', 1838, 1, 1296, '', 'D', '', 1, 1, 'Y', 'p_VSJKwsfAE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (442, '2012-12-17 14:17:57.004531+00', '2013-01-23 01:37:54.477527+00', 10600, 1, 1296, '', 'D', '', 1, 1, 'Y', '8AKx1V_Pl9c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (444, '2012-12-17 14:17:57.265058+00', '2013-01-23 01:40:58.798939+00', 1315, 1, 1296, '', 'C', '', 1, 1, 'Y', 'Z-NMzcqGV98', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (460, '2012-12-17 14:18:02.728655+00', '2013-01-23 02:11:08.960798+00', 10051, 1, 1296, '', 'A', '', 1, 1, 'Y', 'vnnMUhJ8w0s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (486, '2012-12-17 14:18:08.602873+00', '2013-01-23 15:35:13.258009+00', 5693, 1, 1296, '', 'D', '4 times through.  Side view.  Shows the figures well, but no precision.', 1, 1, 'Y', 'WLFRodORojM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (522, '2012-12-17 14:18:25.63013+00', '2019-09-07 17:34:03.88315+00', 2453, 1, 1296, '', 'B', '', 1, 1, 'Y', '09f7-_leb90', 0, 71, NULL);
INSERT INTO 'dancevideo' VALUES (463, '2012-12-17 14:18:03.448581+00', '2013-01-23 15:30:12.527197+00', 1544, 3, 1296, '', 'C', 'Side view.  Once through only.  Unsuitable for learning or teaching.', 1, 1, 'Y', 'LiIDYlogbME', 19, 134, NULL);
INSERT INTO 'dancevideo' VALUES (489, '2012-12-17 14:18:12.220593+00', '2013-01-23 15:48:53.733063+00', 1931, 3, 1296, '', 'D', 'Good view, but little "zest" in the dancing.', 1, 1, 'Y', 'eCTZdMp7a3w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (523, '2012-12-17 14:18:26.556636+00', '2013-01-23 22:53:26.292365+00', 2501, 1, 1296, '', 'A', 'Summer school demo. Taken from floor level, but easy to follow.  ', 1, 1, 'Y', 'gZ8aFcKxnjY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (513, '2012-12-17 14:18:22.098637+00', '2013-01-25 17:47:39.794696+00', 2332, 1, 1296, '', 'D', 'A bit dark, taken from the floor.  Can be followed fairly well.  Speed and flourish.', 1, 1, 'Y', 'ILZ8J12lEnc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (526, '2012-12-17 14:18:28.12647+00', '2013-01-25 18:01:13.628152+00', 250, 1, 1296, '', 'D', 'Angled view from above.  Figures clear, but not so well danced. ', 1, 1, 'Y', 'kwu5e49odzs', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (529, '2012-12-17 14:18:28.376192+00', '2013-01-25 19:53:34.491247+00', 2562, 3, 1296, '', 'D', 'View from above.  Crowded dance floor, sets not clearly separated.  Difficult to follow.', 1, 1, 'Y', 'hqZ2WFZNFgw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (451, '2012-12-17 14:17:59.315445+00', '2013-02-07 03:48:08.649657+00', 7662, 1, 1296, '', 'B', 'Part of a longer demo.  Once through only.', 1, 1, 'Y', 'YI-6NqMxJyY', 334, 402, NULL);
INSERT INTO 'dancevideo' VALUES (507, '2012-12-17 14:18:20.744098+00', '2013-02-08 11:47:01.699542+00', 2203, 3, 1296, '', 'C', '', 1, 1, 'Y', 'mu2NSLaNBgU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (571, '2012-12-17 14:18:38.363655+00', '2013-01-05 13:58:17.103712+00', 3594, 1, 1296, '', 'D', 'Danced in a 3C set.', 1, 1, 'Y', '40TYPynkR7Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (531, '2012-12-17 14:18:28.603057+00', '2012-12-18 12:34:18.04934+00', 2616, 3, 1296, '', 'A', '', 1, 1, 'Y', 'fy0ndDxhQ0w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (551, '2012-12-17 14:18:33.689977+00', '2012-12-18 12:36:34.985825+00', 3108, 1, 1296, '', 'A', '', 1, 1, 'Y', 'Yfog5CEj-ac', 414, 488, NULL);
INSERT INTO 'dancevideo' VALUES (561, '2012-12-17 14:18:35.778336+00', '2012-12-18 12:37:51.143884+00', 3338, 2, 1296, '', 'A', '', 1, 1, 'Y', '8wlxjZ1p6oQ', 311, 500, NULL);
INSERT INTO 'dancevideo' VALUES (544, '2012-12-17 14:18:30.653598+00', '2012-12-20 22:15:27.258269+00', 2979, 2, 1296, '', 'B', 'Danced three times through in a 3C set.', 1, 1, 'Y', 'ej7OMKKBMDU', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (553, '2012-12-17 14:18:34.177412+00', '2012-12-20 00:17:09.960351+00', 3172, 3, 1296, '', 'C', '', 1, 1, 'Y', 'W_1DDIEJoRk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (590, '2012-12-17 14:18:46.287048+00', '2013-01-04 11:35:41.319356+00', 3941, 3, 1296, '', 'D', 'The lines across on [9-16] face out, instead of both facing the top.', 1, 1, 'Y', 'OGNSNrDhrrM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (617, '2012-12-17 14:18:56.643574+00', '2012-12-20 00:24:34.209056+00', 4477, 2, 1296, '', 'A', '', 1, 1, 'Y', 'PyDEu91bXOU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (598, '2012-12-17 14:18:50.342432+00', '2012-12-20 00:33:23.781459+00', 4086, 3, 1296, '', 'A', '', 1, 1, 'Y', 'c94Pb0HuY4Y', 264, 443, NULL);
INSERT INTO 'dancevideo' VALUES (554, '2012-12-17 14:18:34.185318+00', '2012-12-20 17:48:41.369575+00', 3172, 4, 1296, '', 'D', '', 1, 1, 'Y', 'wG1KAxT7m5c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (555, '2012-12-17 14:18:34.190002+00', '2012-12-20 17:52:29.60644+00', 3172, 5, 1296, '', 'D', '', 1, 1, 'Y', 'bFfLzuuZVos', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (557, '2012-12-17 14:18:34.359697+00', '2012-12-26 11:43:27.277951+00', 12542, 4, 1296, '', 'B', '', 1, 1, 'Y', '11_DpYndyY0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (603, '2012-12-17 14:18:54.505591+00', '2012-12-21 16:33:00.213162+00', 4239, 3, 1296, '', 'D', 'Twice through only.', 1, 1, 'Y', '7j4ALZKSgJk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (457, '2012-12-17 14:18:01.212608+00', '2014-08-25 21:29:53.095064+00', 1479, 1, 1296, '', 'D', 'Once through only.  Very informal, Ceilidh style, mostly walking', 1, 1, 'Y', 'TO90D4oHYSA', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (565, '2012-12-17 14:18:37.530642+00', '2012-12-25 17:47:27.221747+00', 3326, 2, 1296, '', 'D', '', 1, 1, 'Y', '3sNCfjUx-vw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (569, '2012-12-17 14:18:38.050783+00', '2012-12-25 20:46:52.195166+00', 3422, 2, 1296, '', 'B', '', 1, 1, 'Y', 'JCeiAU83ZCM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (548, '2012-12-17 14:18:31.937246+00', '2012-12-26 11:32:50.028872+00', 3057, 3, 1296, '', 'B', '', 1, 1, 'Y', 'ZWi2lhQD2uQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (577, '2012-12-17 14:18:38.82767+00', '2012-12-26 11:35:22.278132+00', 3659, 3, 1296, '', 'D', '', 1, 1, 'Y', 'k8SLBiQhE9c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (588, '2012-12-17 14:18:45.788691+00', '2012-12-26 11:39:59.698996+00', 3932, 1, 1296, '', 'D', '', 1, 1, 'Y', 'EZuZPiC1Y7U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (607, '2012-12-17 14:18:55.127637+00', '2013-02-08 12:20:29.801254+00', 4365, 1, 1296, '', 'B', '', 1, 1, 'Y', 'L8GpKXwy7Fw', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (556, '2012-12-17 14:18:34.275902+00', '2012-12-26 11:45:51.230013+00', 12542, 3, 1296, '', 'B', '', 1, 1, 'Y', 'QFIpdgGycOQ', 263, 450, NULL);
INSERT INTO 'dancevideo' VALUES (608, '2012-12-17 14:18:55.185546+00', '2012-12-26 11:53:55.254527+00', 4365, 2, 1296, '', 'C', 'In full twice through, third time through interrupted.', 1, 1, 'Y', 'Q81-01um67E', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (612, '2012-12-17 14:18:55.95365+00', '2012-12-26 12:03:04.133239+00', 4411, 4, 1296, '', 'B', 'once through only', 1, 1, 'Y', 'qaAjz1SgQ1I', 64, 127, NULL);
INSERT INTO 'dancevideo' VALUES (576, '2012-12-17 14:18:38.823119+00', '2012-12-27 16:39:35.128927+00', 3659, 2, 1296, '', 'D', '', 1, 1, 'Y', '0WoCF6A25wg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (613, '2012-12-17 14:18:55.971817+00', '2012-12-26 12:09:41.183122+00', 4411, 5, 1296, '', 'B', '', 1, 1, 'Y', 'X7qjZcNwE54', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (586, '2012-12-17 14:18:45.290238+00', '2012-12-27 22:29:20.095097+00', 3862, 1, 1296, '', 'C', '', 1, 1, 'Y', 'vmeSNqahtAo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (583, '2012-12-17 14:18:42.799253+00', '2013-01-27 14:56:27.081186+00', 3786, 2, 1296, '', 'C', 'Good slanted view from above.  4 times through.', 1, 1, 'Y', 'ui_shLyjB_M', 4, 150, NULL);
INSERT INTO 'dancevideo' VALUES (587, '2012-12-17 14:18:45.683948+00', '2012-12-27 23:11:55.146766+00', 9419, 1, 1296, '', 'B', '', 1, 1, 'Y', 'ISmb3rbVrHw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (578, '2012-12-17 14:18:38.920205+00', '2012-12-28 16:44:18.180146+00', 3690, 1, 1296, '', 'B', '', 1, 1, 'Y', 'WWW1YaHN8BQ', 0, 125, NULL);
INSERT INTO 'dancevideo' VALUES (562, '2012-12-17 14:18:36.888656+00', '2012-12-30 01:44:18.656767+00', 3336, 1, 1296, '', 'B', 'The jigtime Grand Chain is danced 2 steps per hand; the jigtime promenade goes round once R and once L.', 1, 1, 'Y', 'e89QkWZ9Zio', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (535, '2012-12-17 14:18:29.485312+00', '2012-12-29 00:33:17.309804+00', 9862, 1, 1296, '', 'A', '', 1, 1, 'Y', 'dhJDGoPcWH8', 0, 140, NULL);
INSERT INTO 'dancevideo' VALUES (605, '2012-12-17 14:18:54.760729+00', '2013-01-29 23:01:23.525144+00', 4333, 1, 1296, '', 'C', 'Clear and easy to follow.  4 times through.', 1, 1, 'Y', 'sGFF_vXhZzo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (543, '2012-12-17 14:18:30.625968+00', '2012-12-29 00:47:55.759729+00', 2979, 1, 1296, '', 'D', '', 1, 1, 'Y', 'CfDn33M2ZaQ', 168, 251, NULL);
INSERT INTO 'dancevideo' VALUES (542, '2012-12-17 14:18:30.3091+00', '2012-12-29 00:51:03.779971+00', 2910, 1, 1296, '', 'C', '', 1, 1, 'Y', 'jbKWlv2VktE', 0, 86, NULL);
INSERT INTO 'dancevideo' VALUES (539, '2012-12-17 14:18:29.962466+00', '2012-12-29 00:53:01.035189+00', 2807, 1, 1296, '', 'A', '', 1, 1, 'Y', 'T-Ndn9QoQ08', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (602, '2012-12-17 14:18:54.20042+00', '2012-12-29 00:58:10.0541+00', 9008, 1, 1296, '', 'D', '', 1, 1, 'Y', 'hqnGFRLxGkk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (564, '2012-12-17 14:18:37.342002+00', '2013-01-22 22:56:47.724795+00', 3339, 1, 1296, '', 'D', 'Twice through only.', 1, 1, 'Y', 'kgq4-0gii_8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (575, '2012-12-17 14:18:38.743012+00', '2013-01-22 22:18:49.20655+00', 3656, 1, 1296, '', 'C', 'Recorded at Kuckucksnest, Germany', 1, 1, 'Y', 'mbtbjOsj3to', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (574, '2012-12-17 14:18:38.65324+00', '2013-01-22 22:44:07.651585+00', 8571, 1, 1296, '', 'B', '', 1, 1, 'Y', 'FxjmJ7o2cc0', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (560, '2012-12-17 14:18:34.679673+00', '2013-01-22 23:04:15.180551+00', 8138, 1, 1296, '', 'C', '', 1, 1, 'Y', 'BMEmNVsXthw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (547, '2012-12-17 14:18:31.446192+00', '2013-01-22 23:24:37.941397+00', 9528, 2, 1296, '', 'B', '', 1, 1, 'Y', 'cHTnpbyU_l4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (532, '2012-12-17 14:18:28.717003+00', '2013-01-25 19:57:59.089448+00', 2644, 1, 1296, '', 'C', 'Once through.', 1, 1, 'Y', 'Ri4uRxaaR8Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (597, '2012-12-17 14:18:50.328333+00', '2013-02-08 12:16:01.390269+00', 4086, 2, 1296, '', 'A', '', 1, 1, 'Y', 'ay-DrdwJ9P4', 266, 449, NULL);
INSERT INTO 'dancevideo' VALUES (537, '2012-12-17 14:18:29.630598+00', '2013-01-25 20:12:06.784412+00', 2747, 1, 1296, '', 'D', 'Twice through.  High intensity, hyperactive, many "extras".  Good dancers.  Fun to see, but not to teach from.', 1, 1, 'Y', '_xtFuhEWorQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (592, '2012-12-17 14:18:46.875909+00', '2013-01-27 15:02:25.748666+00', 4014, 1, 1296, '', 'A', '', 1, 1, 'Y', 'FrbvVDN5Yhk', 0, 150, NULL);
INSERT INTO 'dancevideo' VALUES (536, '2012-12-17 14:18:29.489767+00', '2013-01-29 22:24:51.863713+00', 9862, 2, 1296, '', 'A', 'Once through.  Part of a longer demo.', 1, 1, 'Y', 'GH2yo_P_bV0', 203, 264, NULL);
INSERT INTO 'dancevideo' VALUES (606, '2012-12-17 14:18:54.979017+00', '2013-01-27 15:14:42.868194+00', 11892, 1, 1296, '', 'C', '', 1, 1, 'Y', '_ogkF-k1ny4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (610, '2012-12-17 14:18:55.298133+00', '2013-01-27 15:20:19.926058+00', 7543, 1, 1296, '', 'D', 'Summer School evening dance.  Busy hall; good view from above.', 1, 1, 'Y', 'L182A7vDbPk', 0, 280, NULL);
INSERT INTO 'dancevideo' VALUES (616, '2012-12-17 14:18:56.564655+00', '2013-01-27 15:31:46.96058+00', 12662, 1, 1296, '', 'B', 'Demo from the deviser''s own website.  Twice through.  Good for teaching.', 1, 1, 'Y', 'uyvHrs-D6Og', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (639, '2012-12-17 14:19:01.501436+00', '2013-02-08 12:24:04.312138+00', 4864, 2, 1296, '', 'A', '', 1, 1, 'Y', 'wqjiXCdEkCY', 270, 411, NULL);
INSERT INTO 'dancevideo' VALUES (676, '2012-12-17 14:19:07.66896+00', '2012-12-20 17:44:32.143876+00', 5330, 7, 1296, '', 'C', '', 1, 1, 'Y', 'YYPtg9sIseo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (690, '2012-12-17 14:19:13.693074+00', '2012-12-19 23:51:24.739857+00', 5529, 4, 1296, '', 'B', 'Danced once through only, all four couples dancing the final hands round and back.



The video continues with the Bees of Maggiknockater, the Immigrqnant Lass, and other dances.', 1, 1, 'Y', '42_8iujkR3Y', 160, 199, NULL);
INSERT INTO 'dancevideo' VALUES (660, '2012-12-17 14:19:03.410138+00', '2012-12-20 22:24:34.203783+00', 5239, 2, 1296, '', 'B', 'Demonstration, danced three times through in two 3C sets.  First time in standard version (1C only for bars 1-24).  Second time 2C joins in for bars 3-16.  Third time 2C+3C join in for bars 3-16, dancing the petronellas in tandem, and finishing with a a 3C poussette.', 1, 1, 'Y', 'BaYMGDpTYMM', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (651, '2012-12-17 14:19:02.530826+00', '2012-12-19 13:46:18.867079+00', 5006, 1, 1296, '', 'A', 'Danced in two contiguous 3-couple sets', 1, 1, 'Y', 'Yfog5CEj-ac', 107, 176, NULL);
INSERT INTO 'dancevideo' VALUES (645, '2012-12-17 14:19:02.305725+00', '2012-12-20 00:15:00.884691+00', 4968, 1, 1296, '', 'A', '', 1, 1, 'Y', 'ovIayeRHsnM', 267, 448, NULL);
INSERT INTO 'dancevideo' VALUES (649, '2012-12-17 14:19:02.435111+00', '2013-02-08 12:24:31.846287+00', 4998, 4, 1296, '', 'A', '', 1, 1, 'Y', 'a0Ur-hVHB-o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (640, '2012-12-17 14:19:01.771098+00', '2012-12-20 19:28:26.633574+00', 4890, 2, 1296, '', 'D', '', 1, 1, 'Y', '64jwvBuqiiA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (636, '2012-12-17 14:19:00.804674+00', '2012-12-20 22:42:08.987513+00', 4858, 1, 1296, '', 'B', 'Part of a longer display, in a 3C set.  Once through only.', 1, 1, 'Y', 'Hk6NM5vjGzM', 19, 75, NULL);
INSERT INTO 'dancevideo' VALUES (642, '2012-12-17 14:19:01.800004+00', '2012-12-20 17:54:52.00711+00', 4890, 4, 1296, '', 'D', '', 1, 1, 'Y', '4aIk2S6vNRc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (641, '2012-12-17 14:19:01.795504+00', '2012-12-20 19:30:53.793219+00', 4890, 3, 1296, '', 'D', '', 1, 1, 'Y', 'MJS5u5VfsTw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (624, '2012-12-17 14:18:58.034564+00', '2012-12-20 23:01:10.857895+00', 4641, 4, 1296, '', 'D', 'Danced 4 times "once and to the bottom" in a 4C set.', 1, 1, 'Y', 'pvW1ROlOjmk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (781, '2012-12-25 17:23:45.551688+00', '2012-12-25 17:24:41.964759+00', 5885, 5, 106, '', 'A', '', 1, 1, 'Y', 'O7hRuGzTrL4', 167, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1073, '2013-08-18 10:47:51.967641+00', '2013-11-18 01:28:54.63192+00', 8144, 1, 1296, '', 'B', '', 1, 1, 'Y', 'QtrwkCGy5y4', 2683, 2803, NULL);
INSERT INTO 'dancevideo' VALUES (659, '2012-12-17 14:19:03.383923+00', '2012-12-20 23:29:06.662982+00', 5239, 1, 1296, '', 'C', 'Danced 3 tines through in a 2C set.  First time 1C only for bars 1-24.  Second time 2C joins in for bars 3-16.  Third time all dance together using "Petronella in tandem".', 1, 1, 'Y', 'Jo7NU21GYpc', 14, 0, NULL);
INSERT INTO 'dancevideo' VALUES (622, '2012-12-17 14:18:57.974127+00', '2012-12-20 23:14:54.220034+00', 4641, 2, 1296, '', 'C', 'Danced 4 times through, "once ant tot he bottom".', 1, 1, 'Y', 'ejIAgU5xopE', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (689, '2012-12-17 14:19:13.68484+00', '2012-12-23 15:17:13.62313+00', 5529, 3, 1296, '', 'B', 'Twice through in a 3C set', 1, 1, 'Y', 'qaAjz1SgQ1I', 334, 403, NULL);
INSERT INTO 'dancevideo' VALUES (681, '2012-12-17 14:19:08.657688+00', '2013-02-08 11:51:42.305614+00', 5497, 3, 1296, '', 'A', '', 1, 1, 'Y', 'pdB63GNA1aQ', 316, 409, NULL);
INSERT INTO 'dancevideo' VALUES (655, '2012-12-17 14:19:02.833102+00', '2012-12-21 16:59:11.90762+00', 12796, 2, 1296, '', 'C', 'Once through only.', 1, 1, 'Y', 'WWW1YaHN8BQ', 400, 453, NULL);
INSERT INTO 'dancevideo' VALUES (621, '2012-12-17 14:18:57.288255+00', '2012-12-27 16:30:46.31248+00', 4561, 1, 1296, '', 'A', '', 1, 1, 'Y', 'TEFJZHfk1DM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (657, '2012-12-17 14:19:03.181811+00', '2012-12-26 09:55:47.279963+00', 13589, 1, 1296, '', 'A', '', 1, 1, 'Y', 'wqjiXCdEkCY', 0, 267, NULL);
INSERT INTO 'dancevideo' VALUES (684, '2012-12-17 14:19:12.595205+00', '2013-02-08 12:09:55.153274+00', 5519, 1, 1296, '', 'A', '', 1, 1, 'Y', 'zsVVGyztOHs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (623, '2012-12-17 14:18:58.029207+00', '2012-12-27 23:27:50.458399+00', 4641, 3, 1296, '', 'B', '', 1, 1, 'Y', 'N6fOB2e1lrE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (704, '2012-12-17 14:19:22.51332+00', '2014-05-07 21:41:10.85903+00', 5794, 1, 1296, '', 'B', 'On bars 5-6, 1st couple should cast round 1st corner, not turn them.', 1, 1, 'Y', 'kn3gY-uageI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (615, '2012-12-17 14:18:56.396553+00', '2014-06-10 21:33:28.438865+00', 4424, 1, 1296, '', 'B', '', 1, 1, 'Y', 'QsVuv8-FGlI', 0, 82, NULL);
INSERT INTO 'dancevideo' VALUES (618, '2012-12-17 14:18:56.831873+00', '2012-12-27 23:37:03.121379+00', 4491, 1, 1296, '', 'D', '', 1, 1, 'Y', 'O86Y559r8ao', 17, 0, NULL);
INSERT INTO 'dancevideo' VALUES (637, '2012-12-17 14:19:01.270834+00', '2012-12-27 23:56:22.227085+00', 9011, 1, 1296, '', 'B', '', 1, 1, 'Y', '_7_1L21u3UE', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (647, '2012-12-17 14:19:02.425781+00', '2013-02-08 12:06:49.183095+00', 4998, 2, 1296, '', 'B', '', 1, 1, 'Y', '8Df8A5K2Zkg', 202, 310, NULL);
INSERT INTO 'dancevideo' VALUES (654, '2012-12-17 14:19:02.73773+00', '2012-12-28 00:33:49.674984+00', 5040, 2, 1296, '', 'A', '', 1, 1, 'Y', 'w2uG1vyedDs', 286, 425, NULL);
INSERT INTO 'dancevideo' VALUES (650, '2012-12-17 14:19:02.440121+00', '2012-12-28 00:15:23.661984+00', 4998, 5, 1296, '', 'B', '', 1, 1, 'Y', '3moDqHSerwQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (703, '2012-12-17 14:19:22.429002+00', '2012-12-28 00:39:07.753144+00', 5755, 2, 1296, '', 'A', '', 1, 1, 'Y', 'ovIayeRHsnM', 0, 265, NULL);
INSERT INTO 'dancevideo' VALUES (687, '2012-12-17 14:19:13.489432+00', '2012-12-28 01:53:15.120071+00', 5525, 6, 1296, '', 'C', 'Twice through only.', 1, 1, 'Y', '42_8iujkR3Y', 20, 94, NULL);
INSERT INTO 'dancevideo' VALUES (675, '2012-12-17 14:19:07.610891+00', '2012-12-28 01:51:00.809784+00', 5330, 6, 1296, '', 'C', '', 1, 1, 'Y', '9stxFL8s_NM', 13, 0, NULL);
INSERT INTO 'dancevideo' VALUES (646, '2012-12-17 14:19:02.421088+00', '2013-02-08 12:04:02.971024+00', 4998, 1, 1296, '', 'C', '', 1, 1, 'Y', 'u42ukAqiu44', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (685, '2012-12-17 14:19:13.425291+00', '2012-12-28 01:57:52.290177+00', 5525, 4, 1296, '', 'A', '', 1, 1, 'Y', 'GOjd6oMFeEM', 57, 96, NULL);
INSERT INTO 'dancevideo' VALUES (686, '2012-12-17 14:19:13.484922+00', '2012-12-28 02:01:29.418448+00', 5525, 5, 1296, '', 'B', '', 1, 1, 'Y', 'mnFTMu85A2Q', 7, 107, NULL);
INSERT INTO 'dancevideo' VALUES (801, '2013-01-04 23:05:33.410626+00', '2013-01-04 23:05:49.343274+00', 9638, 4, 106, '', 'D', '', 1, 1, 'Y', 'VnAHB6_T670', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (678, '2012-12-17 14:19:08.285354+00', '2012-12-28 12:32:20.262959+00', 5407, 2, 1296, '', 'D', 'Meant as a demo, four times through (once and to the bottom); third time through goes badly wrong.', 1, 1, 'Y', 'j_CD4JkWPLM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (635, '2012-12-17 14:19:00.391838+00', '2012-12-28 16:50:38.331018+00', 4857, 1, 1296, '', 'A', '', 1, 1, 'Y', 'eA6mqpKQ1gI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (662, '2012-12-17 14:19:03.799335+00', '2012-12-28 16:55:53.928424+00', 5243, 1, 1296, '', 'B', '', 1, 1, 'Y', 'WWW1YaHN8BQ', 124, 196, NULL);
INSERT INTO 'dancevideo' VALUES (663, '2012-12-17 14:19:03.852024+00', '2012-12-28 16:57:41.07062+00', 5243, 2, 1296, '', 'B', '', 1, 1, 'Y', 'a1X2CRUX5Qc', 301, 373, NULL);
INSERT INTO 'dancevideo' VALUES (693, '2012-12-17 14:19:13.962906+00', '2012-12-30 00:50:04.854271+00', 5552, 2, 1296, '', 'C', 'Once through only', 1, 1, 'Y', 's-FMvgFHXKc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (630, '2012-12-17 14:18:59.214322+00', '2017-09-06 23:06:05.242265+00', 4805, 2, 1296, '', 'D', 'Only once through, 1C starting in second place.



RSCDS Seattle  Fort Worden Ball 9-10-2011 - ', 1, 1, 'Y', 'oXsR_exzm5g', 18, 0, NULL);
INSERT INTO 'dancevideo' VALUES (656, '2012-12-17 14:19:03.042151+00', '2012-12-28 17:08:50.66436+00', 5207, 1, 1296, '', 'A', '', 1, 1, 'Y', 'sWIHdHrVREM', 4, 295, NULL);
INSERT INTO 'dancevideo' VALUES (705, '2012-12-17 14:19:22.517547+00', '2012-12-30 01:22:08.585004+00', 5794, 2, 1296, '', 'D', '', 1, 1, 'Y', 'PZA_n7Q1IAs', 32, 0, NULL);
INSERT INTO 'dancevideo' VALUES (674, '2012-12-17 14:19:06.741159+00', '2013-01-04 16:35:14.095804+00', 5326, 1, 1296, '', 'A', '', 1, 1, 'Y', 'HoGtQaPeFqs', 66, 138, NULL);
INSERT INTO 'dancevideo' VALUES (682, '2012-12-17 14:19:08.753399+00', '2013-01-05 21:37:36.906111+00', 5499, 1, 1296, '', 'D', 'Once through only.', 1, 1, 'Y', '1M5W2QYz70M', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (701, '2012-12-17 14:19:21.655571+00', '2013-01-04 22:46:21.872653+00', 9110, 1, 1296, '', 'D', 'One thrugh completely, once truncated at the staert.', 1, 1, 'Y', 'CfDn33M2ZaQ', 16, 83, NULL);
INSERT INTO 'dancevideo' VALUES (699, '2012-12-17 14:19:21.160784+00', '2013-01-27 15:37:49.51122+00', 5671, 2, 1296, '', 'C', 'In a 3C set; 3 times through. Horizontal view; hard to follow the figures.', 1, 1, 'Y', '58N3wBnKu3Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (679, '2012-12-17 14:19:08.418585+00', '2013-01-05 21:52:17.390004+00', 5412, 1, 1296, '', 'B', '', 1, 1, 'Y', 'ZgGXh-IqiP0', 3, 203, NULL);
INSERT INTO 'dancevideo' VALUES (619, '2012-12-17 14:18:57.020848+00', '2013-01-27 20:21:42.19013+00', 9701, 1, 1296, '', 'D', 'Once through.  First 2 bars missing, 1 bar added at the end.  Good slanted view from above, but sets not easy to tell apart in the busy hall', 1, 1, 'Y', 'pA4yYPKxZVY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (644, '2012-12-17 14:19:02.19668+00', '2013-01-27 20:34:29.570321+00', 4933, 1, 1296, '', 'B', 'Hong Kong demo.', 1, 1, 'Y', 'gZbi6Wgke8E', 33, 182, NULL);
INSERT INTO 'dancevideo' VALUES (677, '2012-12-17 14:19:08.163208+00', '2013-01-27 21:35:50.232187+00', 12454, 2, 1296, '', 'C', 'Twice through.  The set forgets to join NH when setting on [27-28]', 1, 1, 'Y', '4cQ-vaS3Nsc', 208, 282, NULL);
INSERT INTO 'dancevideo' VALUES (697, '2012-12-17 14:19:16.193747+00', '2013-01-27 22:14:28.263354+00', 5637, 4, 1296, '', 'D', 'Busy hall with many sets, but one set is kept in view, on a slant from above.  Easy to follow.', 1, 1, 'Y', 's9lATLLb1sA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (695, '2012-12-17 14:19:15.004772+00', '2013-01-27 22:00:15.131674+00', 5621, 1, 1296, '', 'D', '6 x through in a 3C set, 1c steps down after each turn.', 1, 1, 'Y', '8iEFaztQ5Uk', 18, 231, NULL);
INSERT INTO 'dancevideo' VALUES (702, '2012-12-17 14:19:22.396824+00', '2013-01-27 22:22:06.432676+00', 5755, 1, 1296, '', 'A', '', 1, 1, 'Y', 'XX92H7naOPw', 0, 262, NULL);
INSERT INTO 'dancevideo' VALUES (680, '2012-12-17 14:19:08.551286+00', '2013-01-30 00:08:54.990199+00', 5460, 1, 1296, '', 'A', '', 1, 1, 'Y', 'olG9idagzmo', 214, 335, NULL);
INSERT INTO 'dancevideo' VALUES (661, '2012-12-17 14:19:03.414874+00', '2013-02-08 11:54:10.597237+00', 5239, 3, 1296, '', 'A', '', 1, 1, 'Y', 'mq5wwJbRX4w', 9, 270, NULL);
INSERT INTO 'dancevideo' VALUES (369, '2012-12-17 14:13:19.876971+00', '2012-12-18 11:34:19.428881+00', 6532, 1, 1296, '', 'B', '', 1, 1, 'Y', '0X4ySkxEk4c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (769, '2012-12-17 14:19:49.971897+00', '2013-02-15 01:30:38.480425+00', 7260, 1, 1296, '', 'D', 'This video of a class shows many fails, probably they are training for a demo.', 1, 1, 'Y', 'hHufUcucrCs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1704, '2014-06-25 09:39:06.105057+00', '2018-02-24 21:43:15.090781+00', 7090, 1, 513, '', 'C', 'Large Class.  Once through, with calling.



On the second half reel across, the first couple, in promhold, has the M on the left.  He should be on the Right.', 1, 1, 'Y', 'MCKZ7tPvlsY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (715, '2012-12-17 14:19:25.412484+00', '2012-12-25 18:03:25.290176+00', 6048, 1, 1296, '', 'B', 'Danced three times through in a 3C set, 1c casting to the bottom after their turn.', 1, 1, 'Y', '5sQyMClZNjU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (718, '2012-12-17 14:19:26.729183+00', '2012-12-25 18:08:59.637379+00', 6091, 1, 1296, '', 'A', 'Once through only.', 1, 1, 'Y', 'c6wSYqIqKWA', 0, 70, NULL);
INSERT INTO 'dancevideo' VALUES (3450, '2018-02-27 22:23:47.470353+00', '2018-02-27 22:25:43.742077+00', 4968, 2, 106, '', 'A', 'Second part of a demo by Edinburgh Scottish Dancers dancing at the Aberdeen Festival in 2017', 1, 1, 'Y', 'Ugp-dzm1Z5Q', 262, 0, NULL);
INSERT INTO 'dancevideo' VALUES (761, '2012-12-17 14:19:48.914112+00', '2012-12-28 00:48:43.502879+00', 7147, 3, 1296, '', 'C', 'Part of a longer demo; once through only.', 1, 1, 'Y', 'qaAjz1SgQ1I', 127, 160, NULL);
INSERT INTO 'dancevideo' VALUES (758, '2012-12-17 14:19:48.688533+00', '2012-12-28 01:43:08.556879+00', 7109, 1, 1296, '', 'C', '', 1, 1, 'Y', 'zv1wxtbAIS4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (767, '2012-12-17 14:19:49.520334+00', '2012-12-28 00:46:44.981738+00', 11772, 2, 1296, '', 'A', '', 1, 1, 'Y', '3xcyqc7RBy0', 6, 274, NULL);
INSERT INTO 'dancevideo' VALUES (759, '2012-12-17 14:19:48.693024+00', '2012-12-28 01:47:34.846511+00', 7109, 2, 1296, '', 'D', '', 1, 1, 'Y', 'wssuvmeuZQU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (713, '2012-12-17 14:19:24.628737+00', '2012-12-30 00:44:59.074164+00', 10920, 2, 1296, '', 'C', '', 1, 1, 'Y', 'axbcs-c9jSs', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (756, '2012-12-17 14:19:48.119353+00', '2012-12-28 02:05:04.066198+00', 7105, 2, 1296, '', 'C', '', 1, 1, 'Y', 'jbKWlv2VktE', 164, 230, NULL);
INSERT INTO 'dancevideo' VALUES (760, '2012-12-17 14:19:48.803671+00', '2012-12-28 16:31:38.563189+00', 7139, 1, 1296, '', 'B', '', 1, 1, 'Y', 'a1X2CRUX5Qc', 103, 174, NULL);
INSERT INTO 'dancevideo' VALUES (710, '2012-12-17 14:19:23.126833+00', '2012-12-29 22:42:17.178192+00', 5885, 4, 1296, '', 'D', 'Danced once through only', 1, 1, 'Y', '09f7-_leb90', 71, 0, NULL);
INSERT INTO 'dancevideo' VALUES (671, '2012-12-17 14:19:05.370149+00', '2014-06-07 16:16:19.581867+00', 5296, 3, 1296, '', 'D', 'First time through was cut because incomplete, 3 times left.', 1, 1, 'Y', 'VAN-Dgc14-4', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (719, '2012-12-17 14:19:26.74168+00', '2012-12-30 01:14:31.430112+00', 6091, 2, 1296, '', 'C', 'Danced in a 3C set, 1c dancing to the bottom and 3c stepping up on bars 31-32.  The steps are not true Strathspey steps.', 1, 1, 'Y', 'DMuvock-EAs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (725, '2012-12-17 14:19:31.270614+00', '2012-12-30 22:41:39.750631+00', 6287, 3, 1296, '', 'D', '', 1, 1, 'Y', 'XiKARNCCO_c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (726, '2012-12-17 14:19:32.170424+00', '2013-01-04 10:18:54.810794+00', 6349, 2, 1296, '', 'A', '', 1, 1, 'Y', 'khhIdoOS4Gg', 31, 95, NULL);
INSERT INTO 'dancevideo' VALUES (835, '2013-02-12 01:41:42.718003+00', '2013-02-12 01:46:45.132091+00', 6964, 2, 106, '', 'A', '', 1, 1, 'Y', '2pExEccDqd4', 82, 0, NULL);
INSERT INTO 'dancevideo' VALUES (745, '2012-12-17 14:19:43.167329+00', '2012-12-31 12:24:13.624009+00', 6748, 1, 1296, '', 'A', 'Once through only.  The preceding and following parts of the video start/finish part way through the dance. ', 1, 1, 'Y', 'LhNxtu6EHlw', 13, 45, NULL);
INSERT INTO 'dancevideo' VALUES (727, '2012-12-17 14:19:32.174737+00', '2013-01-04 10:14:38.253192+00', 6349, 3, 1296, '', 'A', 'twice through only.', 1, 1, 'Y', 'Hc_vHnWBopY', 23, 147, NULL);
INSERT INTO 'dancevideo' VALUES (729, '2012-12-17 14:19:34.003353+00', '2013-01-04 10:31:27.270412+00', 12792, 3, 1296, '', 'D', 'Danced in a 3C set, 6 times through.', 1, 1, 'Y', 'ueHSFGNhCBI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (714, '2012-12-17 14:19:25.218043+00', '2013-01-04 10:42:26.655417+00', 5980, 1, 1296, '', 'B', 'danced at Kuckucksnest', 1, 1, 'Y', '78CQwpba8DY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (728, '2012-12-17 14:19:32.82231+00', '2013-01-04 11:00:43.280351+00', 6359, 1, 1296, '', 'D', '', 1, 1, 'Y', 'li-d6bc_yks', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (752, '2012-12-17 14:19:45.798823+00', '2013-01-04 22:10:16.346914+00', 6915, 1, 1296, '', 'A', '', 1, 1, 'Y', 'AMVhkllL1Co', 179, 229, NULL);
INSERT INTO 'dancevideo' VALUES (740, '2012-12-17 14:19:39.767763+00', '2013-01-04 11:15:36.138685+00', 6712, 2, 1296, '', 'D', 'Video does not show the whole set; useless for instruction or even getting a general impression.  Poor technique.  ', 1, 1, 'Y', 'MdqISZ31rsI', 54, 0, NULL);
INSERT INTO 'dancevideo' VALUES (708, '2012-12-17 14:19:22.807517+00', '2013-01-04 16:17:30.431964+00', 5860, 6, 1296, '', 'A', '', 1, 1, 'Y', 'xt-AzpBCgMY', 294, 450, NULL);
INSERT INTO 'dancevideo' VALUES (706, '2012-12-17 14:19:22.788863+00', '2013-01-04 16:22:34.299595+00', 5860, 4, 1296, '', 'D', '', 1, 1, 'Y', 'FjGRcZQfp9M', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (707, '2012-12-17 14:19:22.803184+00', '2013-01-04 16:31:27.822759+00', 5860, 5, 1296, '', 'B', '', 1, 1, 'Y', '42_8iujkR3Y', 93, 161, NULL);
INSERT INTO 'dancevideo' VALUES (743, '2012-12-17 14:19:40.493786+00', '2013-01-04 22:05:12.844861+00', 6734, 2, 1296, '', 'A', '', 1, 1, 'Y', '3xcyqc7RBy0', 276, 459, NULL);
INSERT INTO 'dancevideo' VALUES (735, '2012-12-17 14:19:38.770685+00', '2013-01-06 00:42:10.14395+00', 6523, 1, 1296, '', 'A', '', 1, 1, 'Y', 'bWP0SFECCwg', 29, 300, NULL);
INSERT INTO 'dancevideo' VALUES (724, '2012-12-17 14:19:30.787855+00', '2013-01-04 22:28:06.199477+00', 11769, 3, 1296, '', 'A', '', 1, 1, 'Y', 'XX92H7naOPw', 268, 417, NULL);
INSERT INTO 'dancevideo' VALUES (711, '2012-12-17 14:19:23.527475+00', '2013-01-04 22:39:55.191867+00', 5904, 2, 1296, '', 'D', '', 1, 1, 'Y', '15HxF7lbDAQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (717, '2012-12-17 14:19:26.384649+00', '2013-02-06 07:21:04.292829+00', 6964, 1, 1296, '', 'D', 'First part cut as it was incomplete.  Only once through.  Full hall, sets difficult to tell apart.  Useless for teaching.', 1, 1, 'Y', 'CfDn33M2ZaQ', 103, 168, NULL);
INSERT INTO 'dancevideo' VALUES (723, '2012-12-17 14:19:30.505291+00', '2019-02-18 18:36:49.154501+00', 6205, 2, 1296, '', 'B', 'Twice through.  



The instructions say 1st lady, 3rd lady and 3rd man should pull right shoulders back to face up/down after the half turn of bars 15-16 which is omitted from this performance.', 1, 1, 'Y', '0sSFxNZTsYA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (763, '2012-12-17 14:19:49.016419+00', '2013-01-09 14:47:12.188255+00', 7152, 1, 1296, '', 'A', 'Twice through; the second time the final bars are modified to lead into the next dance of the demo.', 1, 1, 'Y', 'FW9QhC7Bi1g', 0, 72, NULL);
INSERT INTO 'dancevideo' VALUES (742, '2012-12-17 14:19:40.414334+00', '2013-01-14 10:29:04.49437+00', 6734, 1, 1296, '', 'A', 'Twice through; last bar truncated.', 1, 1, 'Y', 'rRivDKiyofQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (731, '2012-12-17 14:19:35.225105+00', '2013-01-14 11:02:24.961745+00', 6393, 1, 1296, '', 'B', 'This dance is a strathspey, but is here danced as a medley S + R', 1, 1, 'Y', 'G8mzOOdbMqY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (749, '2012-12-17 14:19:45.56926+00', '2013-01-27 22:38:29.899475+00', 8161, 1, 1296, '', 'A', '', 1, 1, 'Y', 'XUx2XUZIjmY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (734, '2012-12-17 14:19:38.683907+00', '2013-01-27 22:59:52.326807+00', 9417, 1, 1296, '', 'B', 'From the deviser''s own website', 1, 1, 'Y', 'MJL5zJmhq28', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (737, '2012-12-17 14:19:39.006118+00', '2013-01-27 23:02:12.155906+00', 9532, 1, 1296, '', 'B', 'From the deviser''s own website', 1, 1, 'Y', 'iU_9nUBOLKM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (757, '2012-12-17 14:19:48.533405+00', '2013-01-27 23:16:20.173988+00', 7104, 1, 1296, '', 'B', '', 1, 1, 'Y', 'dBtRa5PKhJM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (709, '2012-12-17 14:19:23.112319+00', '2013-02-08 11:50:19.359507+00', 5885, 3, 1296, '', 'A', '', 1, 1, 'Y', 'ay-DrdwJ9P4', 0, 265, NULL);
INSERT INTO 'dancevideo' VALUES (413, '2012-12-17 14:17:49.674008+00', '2012-12-18 12:23:49.222715+00', 743, 2, 1296, '', 'A', '', 1, 1, 'Y', 'GPU_u1yzcTg', 0, 283, NULL);
INSERT INTO 'dancevideo' VALUES (459, '2012-12-17 14:18:02.155178+00', '2012-12-18 12:29:07.690105+00', 1501, 2, 1296, '', 'A', '', 1, 1, 'Y', 'xt-AzpBCgMY', 0, 292, NULL);
INSERT INTO 'dancevideo' VALUES (198, '2012-09-09 15:54:02.119042+00', '2012-12-21 10:31:35.96008+00', 2428, 1, 1041, '', 'C', 'Final part of a display in a 5C set.  Danced twice through, 1c and 3c starting.', 1, 1, 'Y', 'mEy2f3E-t5M', 275, 0, NULL);
INSERT INTO 'dancevideo' VALUES (632, '2012-12-17 14:18:59.302698+00', '2012-12-27 23:24:11.065472+00', 4827, 2, 1296, '', 'A', 'Once through only (the preceding part of the video starts in the middle of the dance).  Finishes with a 3C Poussette, that ends in a different shape for the next dance of the demonstration.', 1, 1, 'Y', 'bymcjTD9FFI', 17, 0, NULL);
INSERT INTO 'dancevideo' VALUES (783, '2012-12-26 04:37:50.652235+00', '2012-12-26 10:11:41.372575+00', 5079, 1, 513, '', 'D', '', 1, 1, 'Y', 'QOdKYCOWIng', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (778, '2012-12-21 10:35:54.606989+00', '2012-12-21 10:51:27.836988+00', 10789, 1, 106, '', 'B', 'Second part of a display in a 5C set, danced twice through, 1c and 3c starting.', 1, 1, 'Y', 'mEy2f3E-t5M', 148, 275, NULL);
INSERT INTO 'dancevideo' VALUES (455, '2012-12-17 14:18:00.190512+00', '2012-12-27 16:10:04.272217+00', 1478, 1, 1296, '', 'D', 'This set dances down for 4 [17-20] and up for 4 [21-24], inste4ad of 6 for each, and so has 4 bars left over at the end; they stand still and clap to fill teh time.', 1, 1, 'Y', '-948rRvd2aI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (777, '2012-12-20 21:59:52.176834+00', '2012-12-21 10:58:27.508155+00', 11372, 1, 1041, '', 'B', 'First part of a longer display in a 5C set.  Danced twice, 1c+3c starting the first time, 2c+4c the second time. ', 1, 1, 'Y', 'mEy2f3E-t5M', 74, 149, NULL);
INSERT INTO 'dancevideo' VALUES (775, '2012-12-19 20:27:40.708208+00', '2012-12-23 15:21:52.091026+00', 4782, 2, 1041, '', 'C', 'Twice through.', 1, 1, 'Y', 'jbKWlv2VktE', 85, 161, NULL);
INSERT INTO 'dancevideo' VALUES (773, '2012-12-19 12:59:40.852616+00', '2012-12-19 13:02:11.016609+00', 9157, 1, 106, '', 'B', '', 1, 1, 'Y', 'QFIpdgGycOQ', 507, 0, NULL);
INSERT INTO 'dancevideo' VALUES (159, '2012-09-06 11:02:09.683152+00', '2012-12-19 13:02:52.572955+00', 12542, 2, 1, '', 'A', 'From YouTube:



> In September 2010, the Lisbon-Telheiras SCD group danced on three 

> consecutive weekends during the festival "Olhar Carnide". One of the 

> seven dances performed was "Jean Martin of Aberdeen", a dance written by 

> Muriel Johnstone and with music composed and played by her (together 

> with Keith Smith on violin). The team at each of the weekend 

> performances was slightly different, and this recording of "Jean Martin 

> of Aberdeen" is a compiliation [sic] from two of the performances of the

> dance. ', 1, 1, 'Y', 'WA37PEnBzZY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (366, '2012-12-14 14:25:56.349114+00', '2012-12-28 15:21:54.43281+00', 14528, 1, 1294, '', 'A', 'Part of a display medley. Mairi''s Hangover runs twice through. Entry into the next dance required that the second circle go round again rather than round and back, with lower two couples crossing at the end.', 1, 1, 'Y', 'NnnFfJUXyGc', 150, 237, NULL);
INSERT INTO 'dancevideo' VALUES (774, '2012-12-19 20:01:59.498409+00', '2012-12-19 23:38:40.064384+00', 5529, 6, 1041, '', 'C', 'If you continue playing the video after it stops, it shows the teaching and walk-through of this dance.  ', 1, 1, 'Y', 'jbKWlv2VktE', 346, 383, NULL);
INSERT INTO 'dancevideo' VALUES (885, '2013-02-18 23:03:57.367652+00', '2013-02-18 23:50:29.048222+00', 4106, 4, 106, '', 'A', '', 1, 1, 'Y', 'kb8Rw-sJqMo', 0, 82, NULL);
INSERT INTO 'dancevideo' VALUES (776, '2012-12-19 22:33:33.778667+00', '2012-12-20 00:05:20.81036+00', 14534, 2, 1041, '', 'A', 'After the stop, the video continues with the reel "the Royal Patron"', 1, 1, 'Y', 'mNto6b418EM', 40, 320, NULL);
INSERT INTO 'dancevideo' VALUES (397, '2012-12-17 14:17:36.092394+00', '2012-12-20 11:34:52.075604+00', 445, 4, 1296, '', 'C', 'This video is using reel-time music even though the dance is really a jig.', 1, 1, 'Y', 'e4tRQr7604w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (421, '2012-12-17 14:17:52.567368+00', '2012-12-20 11:47:01.235733+00', 905, 1, 1296, '', 'C', 'A complete turn of the dance starts at about 0:20.', 1, 1, 'Y', 'VXMcv0V912s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (446, '2012-12-17 14:17:57.504489+00', '2012-12-20 11:57:15.764528+00', 1348, 2, 1296, '', 'B', 'This is an interesting display variation of the dance involving three staggered and inverted sets.', 1, 1, 'Y', 'Dpk7hwkDt_w', 27, 103, NULL);
INSERT INTO 'dancevideo' VALUES (604, '2012-12-17 14:18:54.639793+00', '2012-12-20 22:48:58.045503+00', 4291, 1, 1296, '', 'B', 'Final part of a longer display, in a 3C set.  Once through only.', 1, 1, 'Y', 'Hk6NM5vjGzM', 135, 192, NULL);
INSERT INTO 'dancevideo' VALUES (506, '2012-12-17 14:18:20.65488+00', '2012-12-20 23:51:44.852564+00', 2203, 2, 1296, '', 'D', 'Late start of the video; only once through.', 1, 1, 'Y', 'f5o_YhniLcE', 0, 37, NULL);
INSERT INTO 'dancevideo' VALUES (780, '2012-12-25 13:54:46.042659+00', '2012-12-25 15:47:20.909024+00', 13472, 1, 513, '', 'C', '', 1, 1, 'Y', 'qmf0NPhZrDc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (470, '2012-12-17 14:18:06.077987+00', '2012-12-21 00:12:52.151759+00', 9084, 2, 1296, '', 'C', 'Three times through.  Errors (wrong shoulder) on each of the second reels of three.', 1, 1, 'Y', '1SE2oSfBCWw', 7, 106, NULL);
INSERT INTO 'dancevideo' VALUES (102, '2012-06-30 17:52:24.0944+00', '2012-12-25 16:02:39.585012+00', 5908, 1, 106, '', 'A', 'Second dance in a demonstration by the Corryvrechan SD Team at Kilkenny Castle.', 1, 1, 'Y', 'G1CMN-PTYWw', 149, 222, NULL);
INSERT INTO 'dancevideo' VALUES (467, '2012-12-17 14:18:04.79252+00', '2012-12-21 00:27:26.377157+00', 1582, 3, 1296, '', 'D', 'Video started too late, the start has been set at a new beginning.  4 times through.', 1, 1, 'Y', '2KlayqeO15A', 28, 0, NULL);
INSERT INTO 'dancevideo' VALUES (788, '2012-12-26 11:15:31.350235+00', '2012-12-26 11:19:07.07845+00', 7061, 4, 106, '', 'B', 'Once through only', 1, 1, 'Y', 'qaAjz1SgQ1I', 297, 333, NULL);
INSERT INTO 'dancevideo' VALUES (609, '2012-12-17 14:18:55.207706+00', '2012-12-26 12:00:46.974823+00', 4365, 3, 1296, '', 'B', 'twice through only', 1, 1, 'Y', 'pQEG9-XtV6w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (784, '2012-12-26 10:48:39.548398+00', '2012-12-27 23:30:00.121117+00', 4844, 2, 106, '', 'C', 'Once through only; part of a bigger demo.', 1, 1, 'Y', 'qaAjz1SgQ1I', 31, 65, NULL);
INSERT INTO 'dancevideo' VALUES (782, '2012-12-25 17:46:23.960817+00', '2012-12-28 12:22:25.447053+00', 3021, 1, 513, '', 'D', 'Recorded on the 22.12.2012 at the 20th Christmas Ball in Münster/Germany.', 1, 1, 'Y', 'Z1LfHaFO8jU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (787, '2012-12-26 11:08:39.960428+00', '2012-12-26 11:11:59.560883+00', 8302, 1, 106, '', 'C', 'Once through only', 1, 1, 'Y', 'qaAjz1SgQ1I', 237, 297, NULL);
INSERT INTO 'dancevideo' VALUES (481, '2012-12-17 14:18:07.13652+00', '2012-12-28 21:01:17.65293+00', 1792, 3, 1296, '', 'D', 'Danced at a very high speed (129 bpm), once and to the bottom in two 3C sets.  Intended to be a demo, but very poor accuracy of figures and phrasing due to the speed.', 1, 1, 'Y', 'EjV6DSkJ17w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (23, '2012-02-03 18:09:55.223743+00', '2012-12-30 00:54:45.94539+00', 4827, 1, 513, '', 'A', 'Once through only', 1, 1, 'Y', 'jnRt03GhWPI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (793, '2012-12-28 21:55:15.348163+00', '2012-12-28 22:00:47.25627+00', 4477, 3, 106, '', 'A', '', 1, 1, 'Y', '5eKqbvHD_Nw', 160, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1237, '2013-08-18 10:55:36.513354+00', '2013-12-30 21:54:22.69335+00', 3941, 4, 1296, '', 'C', '', 1, 1, 'Y', 'MOQPlprU8mA', 26, 198, NULL);
INSERT INTO 'dancevideo' VALUES (751, '2012-12-17 14:19:45.702992+00', '2018-10-03 22:20:49.11757+00', 6897, 1, 1296, '', 'X', '', 1, 1, 'Y', 'FSi39cXAAto', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (739, '2012-12-17 14:19:39.308173+00', '2019-01-28 20:52:43.168506+00', 7980, 1, 1296, '', 'A', 'Beautiful dancing but the choreography is heavily modified for this demonstration. Bars 1-16 for 1c+3c and 17-32 for 2c+4c are condensed into 16 bars with all couples dancing; bars 49-64, a repeat of 33-48, are skipped as are the last 8 bars. Great to watch but not so useful for learning the dance.', 1, 1, 'Y', 'Ky2KZdEV60Y', 261, 355, NULL);
INSERT INTO 'dancevideo' VALUES (843, '2013-02-12 22:26:20.608203+00', '2013-02-14 00:17:59.382766+00', 10433, 5, 106, '', 'C', '', 1, 1, 'Y', '6MuX5aGVU3g', 120, 0, NULL);
INSERT INTO 'dancevideo' VALUES (841, '2013-02-12 13:57:42.578486+00', '2013-02-14 01:13:24.013264+00', 7544, 1, 513, '', 'C', '', 1, 1, 'Y', 'K9epnPaoPQM', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (563, '2012-12-17 14:18:36.933896+00', '2012-12-30 01:54:56.926377+00', 3336, 2, 1296, '', 'C', 'The first 8 hands round and back is replaced by a bow/curtsey and a chase half round cclw.  The jigtime Grand Chain is danced 2 steps per hand; the jigtime promenade goes round once R and once L.', 1, 1, 'Y', 'GFs9VAm6G-U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (453, '2012-12-17 14:17:59.799921+00', '2012-12-31 05:30:40.380107+00', 1473, 2, 1296, '', 'A', 'Twice through only.



', 1, 1, 'Y', 'pdB63GNA1aQ', 186, 316, NULL);
INSERT INTO 'dancevideo' VALUES (795, '2012-12-31 12:40:10.070947+00', '2012-12-31 12:48:24.69036+00', 2039, 2, 106, '', 'A', 'Summer School 2008 week 1 demo.  3 times through.  The final bars are modified to link into the next dance of the demo.', 1, 1, 'Y', 'kJZJLlJvnaQ', 203, 362, NULL);
INSERT INTO 'dancevideo' VALUES (800, '2013-01-04 21:59:38.198424+00', '2013-01-04 22:00:00.871286+00', 11189, 6, 106, '', 'C', '', 1, 1, 'Y', 'S65KrUBsehY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (425, '2012-12-17 14:17:53.148277+00', '2013-01-01 09:35:24.570082+00', 8104, 1, 1296, '', 'B', 'Various versions of this dance exist.  This video, the final part of a longer demo, shows a 32-bar version, twice through; the men dancing the figure of 8 round the women the first time, the women dancing the figure the second time.  After the arches all couples set.  The music and the dancing are not precisely in sync.', 1, 1, 'Y', 'GH2yo_P_bV0', 277, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3451, '2018-02-27 22:28:36.910027+00', '2018-02-27 22:29:45.704223+00', 2725, 3, 106, '', 'A', 'First part of a demo by Edinburgh Scottish Dancers dancing at the Aberdeen Festival in 2017', 1, 1, 'Y', 'Ugp-dzm1Z5Q', 0, 261, NULL);
INSERT INTO 'dancevideo' VALUES (798, '2013-01-01 13:41:07.318393+00', '2013-01-01 14:04:12.949678+00', 14637, 1, 106, '', 'D', 'Dance found on Youtube - no other source known', 1, 1, 'Y', 'T9F7362yxjg', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (549, '2012-12-17 14:18:32.649931+00', '2013-01-01 23:40:53.575165+00', 7285, 2, 1296, '', 'C', 'Twice through in a demo set.', 1, 1, 'Y', '42_8iujkR3Y', 271, 342, NULL);
INSERT INTO 'dancevideo' VALUES (799, '2013-01-01 23:38:26.411056+00', '2013-01-01 23:41:42.87696+00', 7285, 3, 106, '', 'D', '', 1, 1, 'Y', 'cPITo-41giE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (251, '2012-09-12 20:31:48.4522+00', '2013-01-04 11:19:25.899218+00', 6712, 1, 1041, '', 'C', 'In costume.', 1, 1, 'Y', '8z4_Z-viDjI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (802, '2013-01-05 12:43:10.275138+00', '2013-01-05 13:49:45.635956+00', 480, 1, 274, '', 'D', 'Scottish Dance House / Budapest 2011.  Danced in a 3C set.', 1, 1, 'Y', '16FeX5aA1a4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (803, '2013-01-05 12:46:13.085878+00', '2013-01-05 13:55:21.594734+00', 3594, 3, 274, '', 'D', 'Scottish Dance House / Budapest 2011.  Once through only.', 1, 1, 'Y', 'nrXmU_Fc1pk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (807, '2013-01-05 12:57:21.309343+00', '2013-01-05 14:07:04.143585+00', 1582, 5, 274, '', 'B', 'Burns Supper / Budapest 2011.  Part of a longer demo.  Two 2 couple sets, joined at the bottom.  The "down the middle and up" make arches to pass each other.  

', 1, 1, 'Y', 'blhkTHy4Jto', 41, 109, NULL);
INSERT INTO 'dancevideo' VALUES (806, '2013-01-05 12:53:50.884968+00', '2013-01-05 14:14:34.24259+00', 584, 3, 274, '', 'B', 'Burns Supper / Budapest 2011.  Part of a longer demo.  Only once through.', 1, 1, 'Y', 'blhkTHy4Jto', 6, 42, NULL);
INSERT INTO 'dancevideo' VALUES (812, '2013-01-18 10:54:43.410788+00', '2013-01-18 22:18:59.128602+00', 445, 6, 106, '', 'B', 'Demo by costumed dancers.  ', 1, 1, 'Y', 'yJaR_TCbQG0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (747, '2012-12-17 14:19:43.594091+00', '2013-01-20 14:37:55.518752+00', 13445, 1, 1296, '', 'B', 'Recorded at Kuckucksnest, Germany.  Good view of the figures; suitable for learning the dance.  Third time through largely recorded in the mirror.', 1, 1, 'Y', 'lXKCOkoxWH0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (805, '2013-01-05 12:50:36.689517+00', '2013-01-05 14:20:51.122566+00', 2931, 1, 274, '', 'D', 'Scottish Dance House / Budapest 2010', 1, 1, 'Y', 'Fu2RafC0mF0', 5, 66, NULL);
INSERT INTO 'dancevideo' VALUES (808, '2013-01-05 13:09:08.318769+00', '2013-01-05 14:39:47.546771+00', 11731, 1, 274, '', 'D', 'Scottish Dance House / Budapest 2012', 1, 1, 'Y', 'Y60sgbbewLc', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (804, '2013-01-05 12:48:04.322784+00', '2013-01-05 14:43:59.506556+00', 2250, 1, 274, '', 'D', 'Scottish Dance House / Budapest 2010.  Once through only.', 1, 1, 'Y', 'KutlU48UJrw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (666, '2012-12-17 14:19:05.124531+00', '2013-10-15 21:02:34.732571+00', 11189, 2, 1296, '', 'B', 'Part of a longer demonstration. Final 8 bars modified for the link to the next dance.', 1, 1, 'Y', '99sAc66sUMw', 70, 167, NULL);
INSERT INTO 'dancevideo' VALUES (589, '2012-12-17 14:18:46.218808+00', '2019-10-05 12:42:09.567711+00', 3941, 2, 1296, '', 'A', 'Twice through only.  The lines across on [9-16] face out instead of both facing the top.', 1, 1, 'Y', 'mwCIjYu1wHo', 26, 114, NULL);
INSERT INTO 'dancevideo' VALUES (809, '2013-01-05 13:15:08.339384+00', '2013-01-05 14:46:49.002897+00', 2048, 1, 274, '', 'D', 'Scottish Dance House - Budapest 2010.  Once through; slightly truncated.', 1, 1, 'Y', 'Iavr1Pbi-7I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (683, '2012-12-17 14:19:11.306144+00', '2013-01-05 21:33:02.342074+00', 9102, 1, 1296, '', 'C', 'Part of a longer demo.  Once through only.  ', 1, 1, 'Y', 'YI-6NqMxJyY', 37, 71, NULL);
INSERT INTO 'dancevideo' VALUES (226, '2012-09-11 21:49:04.224186+00', '2013-01-07 13:01:53.30451+00', 11189, 1, 1041, '', 'B', 'In bars 57–64, the dancing couples dance round each other in promenade hold instead of doing rights and lefts as per the dance description (this is correct on bars 41-48).



At approximately 1:35, this segues into an abridged version of <<ddd:The Round Reel of Eight>>.', 1, 1, 'Y', '7Ek-_wuz_xk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (483, '2012-12-17 14:18:07.312372+00', '2013-01-23 13:55:22.732723+00', 11897, 1, 1296, '', 'B', 'Video from the deviser''s website', 1, 1, 'Y', 'nT6VfqGGDAs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (490, '2012-12-17 14:18:12.232245+00', '2013-01-23 15:39:14.003688+00', 1931, 4, 1296, '', 'D', 'Ragged dancing, images do not show the whole set.  Perhaps skip this video?', 1, 1, 'Y', 'cLTEU7OB8Yk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (497, '2012-12-17 14:18:14.718751+00', '2013-01-23 22:32:43.377422+00', 10459, 1, 1296, '', 'D', 'Good close-up images, but the camera keeps moving from set to set, or focussing on details, so this videois not usseful for explaining the dance to beginners.', 1, 1, 'Y', 'JShkGYSdn38', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (813, '2013-01-20 17:45:51.176136+00', '2013-01-20 20:59:36.588945+00', 674, 3, 106, '', 'C', 'Once through only, slightly clipped at start and end.  Side view, not for teaching.  Alternative music', 1, 1, 'Y', '1QrdlD11xlg', 170, 236, NULL);
INSERT INTO 'dancevideo' VALUES (550, '2012-12-17 14:18:33.534591+00', '2013-01-22 23:20:27.289411+00', 3105, 1, 1296, '', 'D', '', 1, 1, 'Y', 'QrcOvxFqkNo', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (811, '2013-01-17 23:54:02.523652+00', '2013-01-20 17:42:56.415122+00', 10920, 3, 1332, '', 'B', 'Once through only, slightly clipped at start and end; side view.  Not for teaching.  Original music.', 1, 1, 'Y', '1QrdlD11xlg', 137, 170, NULL);
INSERT INTO 'dancevideo' VALUES (838, '2013-02-12 11:37:24.508254+00', '2013-02-14 00:25:55.179139+00', 14437, 1, 513, '', 'D', 'Recorded at Kuckucksnest.', 1, 1, 'Y', 'qRvR_aM1S44', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (382, '2012-12-17 14:17:21.505043+00', '2013-01-23 00:45:06.674699+00', 13079, 2, 1296, '', 'C', 'Twice through; the preceding and following parts were arbitrarily cut off, and thus incomplete', 1, 1, 'Y', 'ZgY9hCG1V8Y', 33, 133, NULL);
INSERT INTO 'dancevideo' VALUES (393, '2012-12-17 14:17:31.612237+00', '2013-01-23 01:14:22.066096+00', 9422, 2, 1296, '', 'C', 'The turns on bars 13-16 should be RH.  This set uses LH; this could be caused by the fact that there are some cribs in circulation that contain that mistake.', 1, 1, 'Y', '7W_e7p5dMfw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (485, '2012-12-17 14:18:08.359088+00', '2013-02-08 11:58:34.345842+00', 1841, 1, 1296, '', 'A', 'Once through only.  In the final promenade tho dancers leave the hall.', 1, 1, 'Y', 'olG9idagzmo', 433, 465, NULL);
INSERT INTO 'dancevideo' VALUES (842, '2013-02-12 22:25:03.010616+00', '2013-02-14 00:21:43.796721+00', 12538, 1, 106, '', 'C', '', 1, 1, 'Y', '6MuX5aGVU3g', 0, 116, NULL);
INSERT INTO 'dancevideo' VALUES (515, '2012-12-17 14:18:22.834186+00', '2013-01-25 17:54:34.562631+00', 2388, 1, 1296, '', 'B', 'First two bars missing.  Twice through, as part of a longer demo.  Final 4 bars move to a different ending as needed for the demo.  Horizontal view.  ', 1, 1, 'Y', '99sAc66sUMw', 0, 70, NULL);
INSERT INTO 'dancevideo' VALUES (579, '2012-12-17 14:18:38.93388+00', '2013-01-25 20:20:44.349164+00', 3690, 2, 1296, '', 'B', 'Twice through.  Horizontal view.  Demo set.', 1, 1, 'Y', 'a1X2CRUX5Qc', 180, 302, NULL);
INSERT INTO 'dancevideo' VALUES (816, '2013-01-26 23:21:05.947007+00', '2013-01-27 00:03:05.699421+00', 1777, 1, 1330, '', 'B', 'The strathspey "The Duchess Tree" danced one time through by members of the Telheiras Scottish Country Dance group (Grupo de Dança Escocesa da ART) , just to give the idea of the dance.', 1, 1, 'Y', 'qwFiIgCzQU4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3571, '2018-06-11 22:17:19.932722+00', '2018-06-11 22:21:35.183095+00', 18366, 1, 1645, '', 'A', '', 1, 1, 'Y', 'Z7AofS-muD0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3581, '2018-06-19 21:12:48.573097+00', '2018-06-19 21:14:45.89077+00', 18362, 1, 1645, '', 'A', 'Twice through only.', 1, 1, 'Y', 'twK-I7fgtko', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3588, '2018-07-01 21:12:27.155813+00', '2018-07-01 21:31:16.709132+00', 369, 1, 2213, '', 'B', '4 times through only', 1, 1, 'Y', 'RB-DEtIawNs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3586, '2018-07-01 11:07:39.887242+00', '2018-07-01 11:28:15.208769+00', 18390, 1, 513, '', 'C', 'Dancing starts at 1:05 preceded by a full recap.', 1, 1, 'Y', 'Xk4EdG4QOQc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (817, '2013-01-26 23:24:32.583031+00', '2013-01-27 00:15:26.251845+00', 9104, 2, 1330, '', 'C', 'This short video shows a simple Scottish country dance from RSCDS Book 40, "Nice to See You". This dance is done "round the room" in lines of three facing each other (as in the dance, Dashing White Sergeant). After each repetition of the dance, the lines progress to meet the next line of three towards them. In the ballroom, there would be lots of lines of three all the way round the room. Here we only have 9 dancers involved, just to give the idea. ', 1, 1, 'Y', 'ErrhjnWYAsc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (552, '2012-12-17 14:18:34.006485+00', '2013-01-27 12:49:30.477476+00', 13323, 1, 1296, '', 'B', 'Danced at Kuckucksnest.  Good view, from slightly above the heads.', 1, 1, 'Y', 'zHHI-9oVnho', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (596, '2012-12-17 14:18:49.369154+00', '2013-01-27 15:09:01.408244+00', 4046, 2, 1296, '', 'B', 'Twice through.  The final 8 bars modified to link into the next dance of the demo.  Music and dancing are not precisely in sync.  ', 1, 1, 'Y', 'PXeuDvxUnpg', 1, 70, NULL);
INSERT INTO 'dancevideo' VALUES (855, '2013-02-14 15:40:20.484382+00', '2013-02-14 21:35:43.348087+00', 3045, 1, 274, '', 'A', 'Newcastle Festival 2013', 1, 1, 'Y', 'BhEjqWPGvhE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1343, '2013-08-18 10:55:55.709495+00', '2013-12-26 21:04:55.123218+00', 14535, 5, 1296, '', 'A', '', 1, 1, 'Y', 'xOfMGKl6Jxs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (698, '2012-12-17 14:19:21.146108+00', '2013-01-27 15:43:19.64485+00', 5671, 1, 1296, '', 'D', 'First two bars missing, two bars extra at the end.  Twice through. Good view slanted from above, but it''s a well-filled hall, and the sets are not well separated.', 1, 1, 'Y', 'uPidX72G0G0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (653, '2012-12-17 14:19:02.716071+00', '2013-01-27 20:39:18.109184+00', 5040, 1, 1296, '', 'D', 'Once only.  Good view from above, easy to follow though the hall is full.  ', 1, 1, 'Y', 'R54fn0QD2L4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (670, '2012-12-17 14:19:05.365165+00', '2013-01-27 21:04:45.486646+00', 5296, 2, 1296, '', 'C', 'One set.  Horizontal view, but clear to follow.  5 times through.  ', 1, 1, 'Y', 'EH3sUzfmO9M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (672, '2012-12-17 14:19:05.603633+00', '2013-01-27 21:24:43.261945+00', 13469, 1, 1296, '', 'D', 'Full ballroom.  View slightly from above.  First and second time through cut out as too much of the video showed only the musicians.  Fifth time useless for te same reason.  The camera moves around too much from set toset in the hall.  No good for teaching.', 1, 1, 'Y', '39ViyT1flVA', 119, 0, NULL);
INSERT INTO 'dancevideo' VALUES (309, '2012-10-17 10:11:31.916549+00', '2013-01-27 21:32:06.460009+00', 12454, 1, 513, '', 'A', 'Beautiful demo (Summer School) but video is far too dark.  Can someone make it lighter and reload it?', 1, 1, 'Y', '-140UDu1IFA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (696, '2012-12-17 14:19:16.122237+00', '2013-01-27 22:10:16.950393+00', 5637, 3, 1296, '', 'D', 'Hall with five sets. Once through.   Camera keeps shifting between sets.  Impossible to follow unless you know the dance.', 1, 1, 'Y', 'WCj8fkdCPqI', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (712, '2012-12-17 14:19:23.7041+00', '2013-01-27 22:29:45.950016+00', 5915, 3, 1296, '', 'A', 'Outdoors demo.  8 bars of set twice to P and birl added at the end as ornamental conclusion', 1, 1, 'Y', 'JgXgEtT8VLY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (746, '2012-12-17 14:19:43.392708+00', '2013-01-27 23:10:32.86817+00', 6791, 1, 1296, '', 'D', '4 x through, but the first 4 bars show only the musicians.  Clear slanting view from above, easy to follow.', 1, 1, 'Y', '-z-_hOeSRCw', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (770, '2012-12-17 14:19:50.717244+00', '2013-01-27 23:59:17.175371+00', 5480, 1, 1296, '', 'C', 'Starts one bar too late.  4 x though.  Good slanting view from above.  ', 1, 1, 'Y', 'Bl2uUaZ3j-8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (720, '2012-12-17 14:19:27.502482+00', '2013-01-28 00:28:57.46097+00', 9093, 1, 1296, '', 'D', 'First time through cut (incomplete).  End view of set; figures not clear.  Poor for teaching.', 1, 1, 'Y', '4zh5k31llYM', 32, 138, NULL);
INSERT INTO 'dancevideo' VALUES (818, '2013-01-28 20:47:17.810089+00', '2013-01-28 20:58:53.047048+00', 14689, 1, 106, '', 'B', '', 1, 1, 'Y', 'tCZBX5VJFJM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (819, '2013-01-28 20:47:56.474328+00', '2013-01-28 21:03:36.882838+00', 14688, 1, 106, '', 'B', 'There are some fade-overs, perfectly in rhythm, that show that this video must  have been assembled from shorter episodes.', 1, 1, 'Y', 'Q5RyjqXCTaA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (545, '2012-12-17 14:18:30.770447+00', '2013-01-30 00:05:18.240537+00', 9930, 1, 1296, '', 'B', 'End of a longer demo.  Twice through, but set turned 90 deg second time. Final 8 bars modified to let all dancers finish in a long line.', 1, 1, 'Y', 'BW8nFzeYpYo', 138, 209, NULL);
INSERT INTO 'dancevideo' VALUES (822, '2013-02-06 14:15:53.912986+00', '2013-02-06 14:42:37.733542+00', 11001, 1, 513, '', 'C', 'Recorded in Nunspeet, 3 feb 1013.', 1, 1, 'Y', 'D9-a7udab8k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (872, '2013-02-18 22:34:20.963518+00', '2013-02-18 23:46:01.616521+00', 2616, 5, 106, '', 'A', '', 1, 1, 'Y', '3tEbS_UJNcM', 0, 116, NULL);
INSERT INTO 'dancevideo' VALUES (815, '2013-01-25 16:04:43.379044+00', '2014-05-07 21:46:30.24835+00', 5794, 3, 106, '', 'C', 'The footwork is "informal".  The music is fast, the dancers have great flight.  On bars 5-6, 1st couple should cast round 1st corner, not turn them. ', 1, 1, 'Y', 'enum7zy75H4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (500, '2012-12-17 14:18:15.312804+00', '2014-10-20 20:18:48.566783+00', 2063, 2, 1296, '', 'B', 'Danced in a 3C set, 3 times.  Good view.  The last time through, 1st couple, birling for fun, end up at the opposite corner, but recover very gracefully.', 1, 1, 'Y', 'tF7_lLhG9Mo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (821, '2013-02-06 14:15:17.437277+00', '2013-02-06 14:45:11.068673+00', 1415, 1, 513, '', 'C', 'Recorded in Nunspeet, 3 feb 2013', 1, 1, 'Y', 'wKlLT-GQybE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (820, '2013-02-06 14:14:43.625688+00', '2013-02-06 14:48:34.396213+00', 7520, 1, 513, '', 'C', 'Recorded in Nunspeet, 3 feb 2013', 1, 1, 'Y', 'kw5uzcc6io4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (823, '2013-02-06 14:16:25.887985+00', '2013-02-06 14:50:50.036074+00', 5934, 1, 513, '', 'C', 'Recorded in Nunspeet, 3 feb 2013', 1, 1, 'Y', 'hPWaIYKZcTY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (419, '2012-12-17 14:17:52.22507+00', '2013-02-07 04:11:30.66928+00', 849, 1, 1296, '', 'C', 'Part of a longer demo.  Once only.  Beginning clipped.  Final bars modified.  It''s difficult to see the formatiions.', 1, 1, 'Y', 'YI-6NqMxJyY', 170, 205, NULL);
INSERT INTO 'dancevideo' VALUES (504, '2012-12-17 14:18:16.564133+00', '2013-02-08 12:01:07.960007+00', 2129, 3, 1296, '', 'C', 'Once through only; end of a longer display, final bars modified to make lineup.', 1, 1, 'Y', 'wxjyNzIYdPo', 159, 195, NULL);
INSERT INTO 'dancevideo' VALUES (825, '2013-02-11 22:36:18.68991+00', '2013-02-11 22:44:47.855891+00', 4555, 2, 106, '', 'A', '', 1, 1, 'Y', 'eTZtHVbCxxc', 0, 130, NULL);
INSERT INTO 'dancevideo' VALUES (828, '2013-02-11 23:14:44.589796+00', '2013-02-11 23:17:48.142356+00', 159, 3, 106, '', 'A', 'Twice through, final bars clipped', 1, 1, 'Y', 'UU68G_2pOg8', 87, 0, NULL);
INSERT INTO 'dancevideo' VALUES (826, '2013-02-11 23:05:47.063635+00', '2013-02-11 23:07:13.528863+00', 5209, 3, 106, '', 'A', '', 1, 1, 'Y', 'eTZtHVbCxxc', 131, 0, NULL);
INSERT INTO 'dancevideo' VALUES (827, '2013-02-11 23:11:17.186327+00', '2013-02-11 23:13:08.570296+00', 340, 2, 106, '', 'A', '', 1, 1, 'Y', 'UU68G_2pOg8', 5, 84, NULL);
INSERT INTO 'dancevideo' VALUES (829, '2013-02-11 23:20:53.227485+00', '2013-02-12 00:25:31.145466+00', 4511, 1, 106, '', 'A', '', 1, 1, 'Y', 'YJqAgDFYY7k', 6, 133, NULL);
INSERT INTO 'dancevideo' VALUES (830, '2013-02-12 00:28:59.31486+00', '2013-02-12 00:43:10.348336+00', 3577, 1, 106, '', 'A', '', 1, 1, 'Y', 'YJqAgDFYY7k', 133, 0, NULL);
INSERT INTO 'dancevideo' VALUES (832, '2013-02-12 00:49:56.791589+00', '2013-02-12 00:54:04.380706+00', 6701, 3, 106, '', 'A', '', 1, 1, 'Y', '5OpZhS7Mtro', 2, 79, NULL);
INSERT INTO 'dancevideo' VALUES (833, '2013-02-12 01:08:35.633046+00', '2013-02-12 01:11:41.533612+00', 2600, 2, 106, '', 'A', '', 1, 1, 'Y', '5OpZhS7Mtro', 78, 0, NULL);
INSERT INTO 'dancevideo' VALUES (834, '2013-02-12 01:41:09.279561+00', '2013-02-12 01:43:55.184386+00', 1280, 2, 106, '', 'A', '', 1, 1, 'Y', '2pExEccDqd4', 2, 80, NULL);
INSERT INTO 'dancevideo' VALUES (840, '2013-02-12 13:52:25.309926+00', '2013-02-14 01:03:06.672502+00', 5152, 1, 513, '', 'C', '', 1, 1, 'Y', 'uoku3Okkzko', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (32, '2012-02-07 11:16:40.727991+00', '2013-02-13 13:34:05.63975+00', 13582, 1, 1, '', 'D', '80th Anniversary, The RSCDS Summer School 2011, Week 1, 17 July to 24 July

Dances which take place on Saturday nights during summer school 

in St Andrews, Scotland - Younger Hall



Posted to YouTube by »MrFentsahm«.', 1, 1, 'Y', '7Ce7AcozrJI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (837, '2013-02-12 10:58:35.871527+00', '2013-02-13 16:41:40.843318+00', 14425, 1, 513, '', 'C', 'Recorded at Kuckucksnest', 1, 1, 'Y', '7ADp4FTkV54', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (867, '2013-02-15 09:52:57.542634+00', '2013-02-17 07:29:01.106572+00', 4106, 3, 106, '', 'A', '', 1, 1, 'Y', '9fgV7FCRxd4', 0, 96, NULL);
INSERT INTO 'dancevideo' VALUES (845, '2013-02-13 22:50:20.547305+00', '2013-02-13 23:01:20.122559+00', 14533, 3, 106, '', 'A', 'End of a display.  Twice through.', 1, 1, 'Y', 't29gjE7RWwU', 466, 543, NULL);
INSERT INTO 'dancevideo' VALUES (846, '2013-02-13 23:03:51.178766+00', '2013-02-13 23:40:16.113494+00', 14537, 1, 106, '', 'A', 'Summer School 2012 4th week display.  Twice through, final bars modified to link to next dance.', 1, 1, 'Y', 't29gjE7RWwU', 239, 466, NULL);
INSERT INTO 'dancevideo' VALUES (365, '2012-12-11 21:50:53.859024+00', '2013-02-13 23:52:38.119071+00', 14533, 2, 106, '', 'A', 'The Castle of Mey is danced twice through.  It is followed by Mrs Milne of Kinneff and The Diamond Jubilee.', 1, 1, 'Y', 'yLdpG4b1Llw', 10, 171, NULL);
INSERT INTO 'dancevideo' VALUES (848, '2013-02-14 00:02:43.761809+00', '2013-02-14 00:08:48.872673+00', 1647, 3, 106, '', 'A', 'Just close your eyes for a moment at the end of the second time through.', 1, 1, 'Y', 'rTYMGDs5Q-M', 208, 0, NULL);
INSERT INTO 'dancevideo' VALUES (844, '2013-02-13 16:55:49.278787+00', '2013-02-14 00:15:50.090234+00', 7204, 2, 106, '', 'A', 'Once through.', 1, 1, 'Y', 'BtI3cYhs1D8', 0, 61, NULL);
INSERT INTO 'dancevideo' VALUES (839, '2013-02-12 12:18:39.236657+00', '2013-02-14 00:32:58.820178+00', 780, 1, 513, '', 'C', 'Many mistakes in the beginning, much better towards the end', 1, 1, 'Y', '2GPrmI1lBJw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (849, '2013-02-14 15:32:37.30632+00', '2013-02-14 19:55:40.568728+00', 4555, 3, 274, '', 'A', 'Newcastle Festival 2013', 1, 1, 'Y', '9AQrFts146k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (850, '2013-02-14 15:33:43.821191+00', '2013-02-14 20:01:55.258911+00', 6539, 2, 274, '', 'A', 'Newcastle Festival 2013', 1, 1, 'Y', 'sBj4OQsOdEE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (851, '2013-02-14 15:34:44.447965+00', '2013-02-14 20:09:38.644564+00', 4155, 2, 274, '', 'A', 'Newcastle Festival 2013', 1, 1, 'Y', 'yRnbEKrmTXU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (852, '2013-02-14 15:35:39.095899+00', '2013-02-14 20:33:39.66981+00', 5209, 4, 274, '', 'A', 'Newcastle Festival 2013', 1, 1, 'Y', 'QXHwVvHghio', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (854, '2013-02-14 15:39:00.731301+00', '2013-02-14 20:37:23.20707+00', 14535, 3, 274, '', 'A', 'Newcastle Festival 2013', 1, 1, 'Y', 'VltSQ5fUik0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (858, '2013-02-14 15:42:31.97095+00', '2013-02-14 21:10:40.921633+00', 6539, 3, 274, '', 'A', 'Newcastle festival 2013', 1, 1, 'Y', '7z4JiSDMYH4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (860, '2013-02-14 15:44:03.434588+00', '2013-02-14 21:23:00.160417+00', 6349, 4, 274, '', 'A', 'Newcastle Festival 2013', 1, 1, 'Y', 'GE1ojpNlPxs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (857, '2013-02-14 15:41:40.654308+00', '2013-02-14 21:24:51.2773+00', 11770, 2, 274, '', 'A', 'Newcastle festival 2013', 1, 1, 'Y', 'z8VZBXaJHNc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (859, '2013-02-14 15:43:18.046453+00', '2013-02-14 21:38:20.188968+00', 2616, 4, 274, '', 'A', 'Newcastle Festival 2013', 1, 1, 'Y', 'WTnFyoLnf_U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (856, '2013-02-14 15:41:05.335641+00', '2013-02-14 21:45:27.142961+00', 4155, 3, 274, '', 'A', 'Newcastle festival 2013', 1, 1, 'Y', 'SEdOcuRhEdY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (861, '2013-02-14 15:48:25.040465+00', '2013-02-14 21:49:16.861329+00', 2158, 1, 274, '', 'A', 'Newcastle Festival 2013', 1, 1, 'Y', 'VZSliBxUsAQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (869, '2013-02-15 14:21:50.226692+00', '2013-02-15 14:27:16.263978+00', 3045, 2, 106, '', 'A', '', 1, 1, 'Y', 'HTeL6qwqEy8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (866, '2013-02-15 09:51:02.714644+00', '2013-02-16 09:43:45.509495+00', 10535, 3, 106, '', 'A', '', 1, 1, 'Y', 'BsOUcPHbp7U', 196, 0, NULL);
INSERT INTO 'dancevideo' VALUES (865, '2013-02-15 09:49:31.559181+00', '2013-02-16 09:45:08.09885+00', 2394, 1, 106, '', 'A', '', 1, 1, 'Y', 'BsOUcPHbp7U', 0, 196, NULL);
INSERT INTO 'dancevideo' VALUES (863, '2013-02-15 09:44:43.050161+00', '2013-02-16 09:47:29.528996+00', 3932, 2, 106, '', 'A', '', 1, 1, 'Y', 'gQxH-u1YLp0', 0, 137, NULL);
INSERT INTO 'dancevideo' VALUES (864, '2013-02-15 09:46:39.895266+00', '2013-02-16 09:49:29.784+00', 4404, 2, 106, '', 'A', '', 1, 1, 'Y', 'gQxH-u1YLp0', 140, 0, NULL);
INSERT INTO 'dancevideo' VALUES (868, '2013-02-15 09:54:20.847916+00', '2013-02-17 07:26:26.865069+00', 754, 1, 106, '', 'A', '', 1, 1, 'Y', '9fgV7FCRxd4', 99, 0, NULL);
INSERT INTO 'dancevideo' VALUES (881, '2013-02-18 22:56:01.092602+00', '2013-02-18 23:20:10.476485+00', 10663, 3, 106, '', 'A', '', 1, 1, 'Y', 'n9L5KLrT_LM', 0, 75, NULL);
INSERT INTO 'dancevideo' VALUES (878, '2013-02-18 22:49:16.980194+00', '2013-02-18 23:21:28.074145+00', 10663, 2, 106, '', 'A', '', 1, 1, 'Y', 'BtI3cYhs1D8', 68, 0, NULL);
INSERT INTO 'dancevideo' VALUES (882, '2013-02-18 22:57:16.405517+00', '2013-02-18 23:22:57.051564+00', 13149, 6, 106, '', 'A', '', 1, 1, 'Y', 'n9L5KLrT_LM', 76, 0, NULL);
INSERT INTO 'dancevideo' VALUES (887, '2013-02-18 23:08:54.073602+00', '2013-02-18 23:26:19.532833+00', 745, 1, 106, '', 'A', '', 1, 1, 'Y', 'RT3zUy_kXTE', 0, 67, NULL);
INSERT INTO 'dancevideo' VALUES (880, '2013-02-18 22:53:19.768289+00', '2013-02-18 23:29:46.09262+00', 6386, 1, 106, '', 'A', '', 1, 1, 'Y', '3mltV7w2I_k', 137, 0, NULL);
INSERT INTO 'dancevideo' VALUES (888, '2013-02-18 23:10:01.174147+00', '2013-02-18 23:33:30.149632+00', 11369, 1, 106, '', 'A', '', 1, 1, 'Y', 'RT3zUy_kXTE', 68, 0, NULL);
INSERT INTO 'dancevideo' VALUES (875, '2013-02-18 22:40:19.273608+00', '2013-02-18 23:34:49.541292+00', 14535, 4, 106, '', 'A', '', 1, 1, 'Y', '6r6ayfpoRg4', 141, 0, NULL);
INSERT INTO 'dancevideo' VALUES (886, '2013-02-18 23:05:32.786702+00', '2013-02-18 23:35:51.886772+00', 13589, 2, 106, '', 'A', '', 1, 1, 'Y', 'kb8Rw-sJqMo', 83, 0, NULL);
INSERT INTO 'dancevideo' VALUES (879, '2013-02-18 22:52:33.010169+00', '2013-02-18 23:37:52.524719+00', 4857, 2, 106, '', 'A', '', 1, 1, 'Y', '3mltV7w2I_k', 0, 136, NULL);
INSERT INTO 'dancevideo' VALUES (873, '2013-02-18 22:35:13.188479+00', '2013-02-18 23:42:35.737257+00', 2394, 2, 106, '', 'A', '', 1, 1, 'Y', '3tEbS_UJNcM', 118, 0, NULL);
INSERT INTO 'dancevideo' VALUES (870, '2013-02-18 22:28:19.532857+00', '2013-02-18 23:53:33.673113+00', 4126, 1, 106, '', 'A', '', 1, 1, 'Y', 'H-P9E56PHuc', 0, 143, NULL);
INSERT INTO 'dancevideo' VALUES (874, '2013-02-18 22:38:52.040793+00', '2013-02-18 23:56:23.884704+00', 4155, 4, 106, '', 'A', '', 1, 1, 'Y', '6r6ayfpoRg4', 0, 140, NULL);
INSERT INTO 'dancevideo' VALUES (893, '2013-03-01 01:41:17.462198+00', '2013-03-01 01:41:30.066916+00', 1931, 5, 106, '', 'X', '', 1, 1, 'Y', '_Av3tqGvmok', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (508, '2012-12-17 14:18:21.67565+00', '2013-02-24 21:38:54.936732+00', 2236, 1, 1296, '', 'C', 'Part of a longer demo; only twice through.  

On [5-8] and [13-16] the top couple should make a 3/4 turn and cast off to 5th place.  In three of the four occastions, the top couple in this video dances down omitting the turn.', 1, 1, 'Y', '4cQ-vaS3Nsc', 0, 80, NULL);
INSERT INTO 'dancevideo' VALUES (897, '2013-03-04 09:44:23.31334+00', '2013-03-04 23:40:12.397512+00', 981, 1, 513, '', 'D', 'Danced at the "Schiehallion SCD Group" ball in Roosendaal, Netherlands, on 3 march 2013.



The full video is longer, but only this last time through gives a clear view of the dance.  Note that for bars [17-24]; the arch should be made on [19], and the three other couples should start to dance down at the same time; this set is 2 bars late, and therefore starts the Allemande late.', 1, 1, 'Y', 'ghcNeptarL4', 110, 0, NULL);
INSERT INTO 'dancevideo' VALUES (894, '2013-03-02 16:15:07.527203+00', '2013-03-04 23:54:35.467937+00', 4998, 6, 274, '', 'A', 'Budapest Scottish Dance Club

Burns Supper, 2013, Budapest

', 1, 1, 'Y', 'yKfM7-em_LQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (673, '2012-12-17 14:19:05.711292+00', '2013-03-10 23:34:36.835167+00', 5308, 2, 1296, '', 'A', 'Part of a longer demo.  Once through only, in a 5+5 demonstration set, placed bottom to bottom.  The figures are difficult to follow.  At the end the dancing couples finish in 2pl and 4pl, omitting the final cast to 3pl/5pl.', 1, 1, 'Y', 'GOjd6oMFeEM', 326, 362, NULL);
INSERT INTO 'dancevideo' VALUES (901, '2013-03-15 08:24:31.716179+00', '2013-03-15 09:39:24.032173+00', 14738, 1, 513, '', 'C', '', 1, 1, 'Y', '6iRF8G0ZBgQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (318, '2012-10-17 14:59:57.711403+00', '2013-03-20 21:58:21.804055+00', 13847, 1, 513, '', 'A', '', 1, 1, 'Y', 'oHBrbA1UJEE', 13, 0, NULL);
INSERT INTO 'dancevideo' VALUES (904, '2013-03-28 13:31:02.998308+00', '2013-03-28 14:11:39.538842+00', 462, 2, 1022, '', 'A', 'Twice through;  last moves of dance changed to flow into next dance.', 1, 1, 'Y', '27em4ertfPQ', 102, 232, NULL);
INSERT INTO 'dancevideo' VALUES (918, '2013-04-16 22:28:25.152185+00', '2013-05-05 23:03:13.79053+00', 3300, 1, 1041, '', 'D', 'Danced at a Seattle RSCDS Christmas Ball on Mercer Island.', 1, 1, 'Y', 'bs1bODSiS1w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (911, '2013-04-07 12:38:04.494157+00', '2013-04-07 14:40:22.758991+00', 5904, 3, 274, '', 'B', 'Demo at Budapest, Burns Supper 2013;

Two 2 couple sets joined bottom to bottom.  :-)   Once through.  Bars 1-8 modified by adding arches.

', 1, 1, 'Y', 'JBY1UvyPTFM', 0, 71, NULL);
INSERT INTO 'dancevideo' VALUES (922, '2013-04-22 12:23:48.903809+00', '2013-05-05 23:08:22.86261+00', 2364, 1, 513, '', 'C', '', 1, 1, 'Y', 'UoOabOUGntw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3528, '2018-05-04 09:52:32.760643+00', '2018-05-05 10:56:32.030914+00', 16055, 1, 8724, '', 'C', 'Generally good, but things go a bit wrong in the 3rd repeat. The video starts about 1 bar into the dance.', 1, 1, 'Y', 'b76mi94s9hk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (896, '2013-03-03 10:19:22.774324+00', '2014-10-05 21:24:29.491529+00', 10419, 1, 274, '', 'C', 'Scottish Dance House for beginners, 2013, Budapest, Hungary.



According to the deviser, only 2c+1c dance the final circle, but this video shows a variant where 2c+1c+3c dance that circle. ', 1, 1, 'Y', 'PVi_kWmqL40', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (905, '2013-03-28 18:10:56.258539+00', '2014-07-29 14:47:35.007767+00', 4102, 3, 1022, '', 'C', 'As First Couple always passes Right Shoulder in the middle, they are dancing the variant nicknamed "Mairi''s Divorce", ', 1, 1, 'Y', 'RRpLfLurI5s', 0, 354, NULL);
INSERT INTO 'dancevideo' VALUES (910, '2013-04-07 12:36:36.305052+00', '2013-04-07 14:50:23.86195+00', 8348, 1, 274, '', 'B', 'Budapest, Burns Supper 2013.  Demo.  Once through.', 1, 1, 'Y', 'JBY1UvyPTFM', 71, 140, NULL);
INSERT INTO 'dancevideo' VALUES (909, '2013-04-07 12:31:26.379051+00', '2013-04-07 15:02:19.24641+00', 2119, 1, 274, '', 'D', 'Budapest, Dance House for beginners 2013.04.06.  Three times through.  ', 1, 1, 'Y', '63296_CVtw0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (984, '2013-08-06 17:57:52.13305+00', '2013-08-09 06:04:46.767471+00', 5209, 6, 106, '', 'A', 'Second video recording of the same demo.', 1, 1, 'Y', '89Cr9qh-ObE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (892, '2013-02-28 17:16:13.528008+00', '2015-08-28 21:23:08.637146+00', 1792, 9, 106, '', 'X', '', 1, 1, 'Y', 'hursShTjeI4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3502, '2018-04-09 07:01:26.398655+00', '2018-04-09 19:05:24.182513+00', 5198, 4, 2709, '', 'B', 'A single set dancing is of more value to those wishing to learn the dance. ', 1, 1, 'Y', 'UYaPzfxb0oM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (912, '2013-04-10 16:02:14.439257+00', '2013-04-10 22:18:29.932285+00', 3463, 1, 1041, '', 'C', 'Once through only.  Starts a few seconds late, and finishes a few seconds early.', 1, 1, 'Y', '5lA-xUnz1o4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (924, '2013-05-09 19:20:24.690516+00', '2013-05-09 19:23:58.790452+00', 3129, 2, 106, '', 'C', '', 1, 1, 'V', '40591726', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (919, '2013-04-22 09:03:45.55473+00', '2014-05-07 12:16:40.818323+00', 13587, 1, 513, '', 'D', '', 1, 1, 'Y', '_qMi0VqwrwY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (915, '2013-04-14 10:44:35.837847+00', '2013-04-14 21:12:41.844701+00', 6972, 1, 1041, '', 'A', 'Part of a longer display.  Once through only, filmed from rather far away.  ', 1, 1, 'Y', 'yRQzUTgH02M', 168, 204, NULL);
INSERT INTO 'dancevideo' VALUES (906, '2013-03-30 07:46:07.391651+00', '2014-06-09 09:13:40.825274+00', 9013, 1, 513, '', 'C', '', 1, 1, 'Y', '2OSdQOd6zuI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (204, '2012-09-09 20:02:29.973493+00', '2013-05-09 21:26:43.903153+00', 3129, 1, 1041, '', 'D', '', 1, 1, 'Y', 'e8J3F2D0Qw0', 0, 268, NULL);
INSERT INTO 'dancevideo' VALUES (931, '2013-05-18 01:39:55.684064+00', '2013-05-18 07:44:07.829143+00', 14427, 1, 513, '', 'B', '', 1, 1, 'Y', 'ehKOgCo3j7Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (928, '2013-05-13 23:23:21.218551+00', '2013-05-16 12:23:26.716484+00', 584, 4, 1022, '', 'A', 'Twice through with changes at end to flow into next dance.

Summer School dem, week 3, 2012.', 1, 1, 'Y', '27em4ertfPQ', 20, 100, NULL);
INSERT INTO 'dancevideo' VALUES (930, '2013-05-16 22:09:50.119478+00', '2013-05-16 22:19:34.562713+00', 5829, 1, 106, '', 'C', 'Especially first time through has rather many errors.', 1, 1, 'Y', 'hVrsz9H8xyQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (376, '2012-12-17 14:17:20.034504+00', '2013-05-16 22:36:48.807875+00', 153, 1, 1296, '', 'A', 'The figure danced for bar 57-64 differs from the usual form (see the crib and Minicrib).  The Men also set sometimes with high cuts instead of points.', 1, 1, 'Y', 'G1CMN-PTYWw', 0, 144, NULL);
INSERT INTO 'dancevideo' VALUES (932, '2013-05-18 06:24:25.299528+00', '2013-05-18 07:27:50.443825+00', 13709, 1, 513, '', 'D', '', 1, 1, 'Y', 'hyLhRmYhM-4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (933, '2013-05-18 12:51:02.441118+00', '2013-05-18 15:34:34.518937+00', 13270, 1, 1506, '', 'C', '', 1, 1, 'Y', 'Ue19AOjGu5s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (934, '2013-05-19 17:39:49.07755+00', '2013-05-19 19:50:49.420002+00', 89, 1, 1022, '', 'C', '', 1, 1, 'Y', 'XE1CL8WYV4I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (895, '2013-03-02 16:18:01.228553+00', '2022-09-19 19:46:25.236208+00', 6798, 1, 274, '', 'A', 'Budapest Scottish Dance Club

Burns Supper, 2013, Budapest

', 1, 1, 'Y', 'sGgOnK3-jqI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (898, '2013-03-05 20:54:51.413736+00', '2023-02-04 18:20:18.113937+00', 6577, 1, 106, '', 'Z', 'Was Social/Informal. Now Private on youtube.', 1, 1, 'Y', 'fKnsjoyAD08', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (936, '2013-05-19 20:18:59.354872+00', '2013-05-19 21:48:14.178188+00', 2349, 2, 1041, '', 'B', 'Danced in Egertorget in Oslo, 2nd May, 2012', 1, 1, 'Y', 'NAKaH7wOcVI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (937, '2013-05-19 20:36:42.196438+00', '2013-05-19 21:56:09.272603+00', 2353, 1, 1041, '', 'D', 'New Haven Highland Ball 2009.



The camera pans around too much; the dance is hard to follow.', 1, 1, 'Y', 'KPML9y92K-o', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (938, '2013-05-20 02:23:52.542978+00', '2013-05-20 12:56:01.68192+00', 13580, 1, 513, '', 'D', '4th International Branch Weekend, 19 may 2013, Killarney, Ireland.', 1, 1, 'Y', 'rDFMi8Tl000', 24, 0, NULL);
INSERT INTO 'dancevideo' VALUES (939, '2013-05-20 21:17:11.370944+00', '2013-05-21 00:10:32.93151+00', 10376, 1, 1041, '', 'D', '', 1, 1, 'Y', 'ZvChof549GE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (940, '2013-05-21 00:15:59.692449+00', '2013-05-21 00:25:29.454627+00', 12680, 2, 106, '', 'C', 'Vancouver Island SCDS, Christmas Dance 2012', 1, 1, 'Y', 'G-VdOPMvNRE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (941, '2013-05-21 00:24:32.321941+00', '2013-05-21 00:24:49.995407+00', 462, 3, 106, '', 'C', 'Vancouver Island SCDS, Christmas Dance 2012', 1, 1, 'Y', 'MAVRX217ZGE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (962, '2013-07-06 12:22:56.436385+00', '2013-07-06 12:23:23.353145+00', 3435, 3, 106, '', 'D', 'Roosendaal, Netherlands 2nd march 2013', 1, 1, 'Y', 'h4agmMxJZGY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (942, '2013-05-21 09:20:01.278073+00', '2013-05-23 09:38:39.03101+00', 12803, 1, 1041, '', 'B', 'The title in the video is in error; the dance is The Floosie in the Jacuzzi, with an s.', 1, 1, 'Y', 'WWW1YaHN8BQ', 514, 0, NULL);
INSERT INTO 'dancevideo' VALUES (944, '2013-05-23 19:55:08.570387+00', '2013-05-23 22:01:50.921529+00', 9564, 2, 274, '', 'B', 'Once through only.

Budapest Scottish Dance Weekend 2013

http://www.bstk.hu/bal2013/

Teacher: Eric Finley

', 1, 1, 'Y', 'NMfMSzFp-Wo', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (104, '2012-07-15 17:07:07.599075+00', '2013-07-06 12:45:53.8111+00', 13588, 4, 106, '', 'A', 'Summer School demo, 2010', 1, 1, 'Y', 'hZH5dkf4IrU', 10, 205, NULL);
INSERT INTO 'dancevideo' VALUES (3456, '2018-03-04 21:39:16.598581+00', '2018-03-05 14:00:35.796944+00', 17305, 1, 3129, '', 'A', '', 1, 1, 'Y', '6J7Sl-6KaRA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (946, '2013-06-02 16:19:32.855345+00', '2013-06-02 19:08:45.956884+00', 12177, 1, 513, '', 'A', 'Danced by Derek Haynes himself!', 1, 1, 'Y', 'YK9cxGJ__YQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (546, '2012-12-17 14:18:31.09618+00', '2013-06-06 13:32:48.055308+00', 8932, 2, 1296, '', 'C', 'At St. Andrews, Summer School 2012.  A good view from above; shows the figures well.  The dancers make a few errors in the figures, but the recovery is good. ', 1, 1, 'Y', 'SGyvefTmutw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (951, '2013-06-06 14:21:43.119183+00', '2013-06-06 14:23:53.409108+00', 754, 2, 106, '', 'C', 'Summer school, 22 july 2012.', 1, 1, 'Y', '1EysVbDBgds', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (949, '2013-06-06 14:06:41.279883+00', '2013-06-06 14:28:53.810823+00', 4827, 3, 106, '', 'C', 'Summer School, 22 july 2012', 1, 1, 'Y', 'Hv5UdpfC0K8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (950, '2013-06-06 14:15:52.278582+00', '2013-06-06 14:36:48.281089+00', 5885, 6, 106, '', 'C', 'A few errors of phrasing, but still gives a good impression of the dance.', 1, 1, 'Y', 'pcKavQVP8Kw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (955, '2013-06-07 19:47:37.937909+00', '2013-06-07 21:34:07.641347+00', 9110, 3, 1041, '', 'D', '', 1, 1, 'Y', 'acwRz-F2tjc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (954, '2013-06-07 19:38:02.1166+00', '2013-06-07 21:53:42.605125+00', 14393, 1, 1041, '', 'D', '', 1, 1, 'Y', 'BWle_8CEQLM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (953, '2013-06-07 19:35:20.126342+00', '2013-06-07 21:59:35.884494+00', 588, 1, 1041, '', 'D', '', 1, 1, 'Y', 'AVmACzwPPc8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (965, '2013-07-17 06:34:32.089031+00', '2013-07-17 08:06:02.450193+00', 8683, 2, 513, '', 'D', '', 1, 1, 'Y', 'QpSwrafIylw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (956, '2013-06-09 17:12:08.151897+00', '2013-06-09 19:19:28.885069+00', 5209, 5, 1, '', 'A', 'This video from the RSCDS Archive intersperses a performance of the dance with author Barry Skelton expounding on the history and inner workings of the dance as well as the selection of the music. The video contains a demonstration quality performance (twice through) from time 3:00 to 4:10, and again from 7:10 to 8:20.', 1, 1, 'Y', 'qIg2H6gew7Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (966, '2013-07-17 12:36:08.810152+00', '2013-07-17 14:52:47.175669+00', 14979, 1, 513, '', 'C', '', 1, 1, 'Y', '1-22PxoOPwk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (957, '2013-06-10 19:48:25.313169+00', '2013-06-10 20:15:44.800403+00', 5111, 1, 106, '', 'A', 'A long video with background information on this dance and the deviser. Good videos of the dance from 0:55 to 1:59, 2:42 to 3:45 and 4:09-5:13.', 1, 1, 'Y', 'mCz7g98eh3M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (958, '2013-06-24 20:36:56.944807+00', '2013-07-17 14:56:51.542162+00', 6532, 2, 1002, '', 'C', 'Some problems at the beginning of the reel part. At the end TR TL has beend replaced by two times TR for choreographic reasons.', 1, 1, 'Y', 'bwqAO51QILc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (961, '2013-07-03 14:58:46.000028+00', '2013-07-04 04:55:56.581253+00', 8956, 2, 1022, '', 'B', '', 1, 1, 'Y', 'K5_DWoMdE9k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (964, '2013-07-16 12:30:10.332379+00', '2013-07-20 15:38:26.572141+00', 3337, 1, 513, '', 'D', '', 1, 1, 'Y', 'JHfKOcZDv7Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (960, '2013-07-01 04:20:51.575408+00', '2013-07-20 20:35:34.177679+00', 8743, 1, 1240, '', 'C', '', 1, 1, 'Y', 'C_VSiNVIBVM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (970, '2013-07-26 13:58:02.868378+00', '2013-07-27 01:01:16.49631+00', 13577, 1, 513, '', 'A', '', 1, 1, 'Y', 'OFnob2kJgog', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (969, '2013-07-26 13:57:14.067264+00', '2013-07-27 01:05:34.47095+00', 14346, 1, 513, '', 'A', '', 1, 1, 'Y', 'O-TDZQ2rUbk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (972, '2013-07-30 05:40:38.409163+00', '2013-07-30 07:47:43.071142+00', 5093, 1, 513, '', 'A', '', 1, 1, 'Y', 'DEQtAzNAPcQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (973, '2013-07-30 21:16:08.87295+00', '2013-07-30 21:18:17.530892+00', 5407, 3, 106, '', 'D', 'Brussels ball, 2012, at "De Kam".', 1, 1, 'Y', 'tAHD_JL6Z9g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1034, '2013-08-18 00:52:07.941926+00', '2014-08-16 18:48:47.55135+00', 611, 1, 1296, '', 'C', '', 1, 1, 'Y', 'PIUDxIm1iRc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1241, '2013-08-18 10:55:37.135473+00', '2013-12-30 21:25:20.509039+00', 4046, 3, 1296, '', 'C', '', 1, 1, 'Y', '3Dj7CHw24sk', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1078, '2013-08-18 10:47:52.885683+00', '2013-10-15 19:36:53.446142+00', 1280, 3, 1296, '', 'D', '', 1, 1, 'Y', 'I54v12AgPZk', 0, 102, NULL);
INSERT INTO 'dancevideo' VALUES (943, '2013-05-23 19:50:33.702634+00', '2017-06-19 23:01:48.748209+00', 6267, 3, 274, '', 'B', 'Budapest Scottish Dance Weekend 2013 (23 may)

www.bstk.hu/bal2013

Teacher: Eric Finley

', 1, 1, 'Y', 'ftUHEV2w6EQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (959, '2013-06-25 19:11:46.55702+00', '2015-02-12 21:23:53.606427+00', 6532, 3, 1002, '', 'B', '', 1, 1, 'Y', 'Ay7ATFD99Oo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (979, '2013-08-06 14:20:17.994648+00', '2013-08-09 06:22:28.540075+00', 13730, 2, 513, '', 'A', '', 1, 1, 'Y', 'moiOb3sV-1c', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (983, '2013-08-06 16:27:54.1553+00', '2013-08-06 17:22:13.695693+00', 3996, 1, 106, '', 'A', 'Part of a longer display; only once through. International team, Newcastle Festival 2013

', 1, 1, 'Y', '-ZikRxCK5Bs', 65, 126, NULL);
INSERT INTO 'dancevideo' VALUES (95, '2012-06-11 00:11:22.920378+00', '2013-08-07 05:55:16.742268+00', 314, 1, 961, '', 'B', 'discovered via http://www.scottish-country-dancing-dictionary.com/scottish-dancing-youtube-videos.html



The video title says "Auftritt der Scottish Country Dancers Münster bei den Highland Games in Ochtrup 2009:  Galloping Carousel;  The Piper and the Penguin;  Autumn in Appin; Blooms of Bon Accord.  

This video is set to start at "Autumn in Appin, at 2:47.  It is danced twice through, finishing on 4:44.  ', 1, 1, 'Y', '99sAc66sUMw', 167, 0, NULL);
INSERT INTO 'dancevideo' VALUES (974, '2013-07-30 21:25:09.301385+00', '2014-07-29 20:12:38.931975+00', 13629, 1, 106, '', 'C', 'The video has a large bit in the middle showing only the band, but it does return to the dance floor later.



It was recorded on the 31.03.2012 during a social at "De Kam" in Wezembeek-Oppem near Brussels.

Music was provided by the "Inverrhine Scottish Dance Band".

', 1, 1, 'Y', 'zpJKtOcNPLw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (980, '2013-08-06 14:21:17.976467+00', '2013-08-09 06:12:48.327239+00', 11483, 1, 513, '', 'A', 'Summer School 2013 week 3.  Youth Dem.', 1, 1, 'Y', 'VPW3pCUsMUw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (982, '2013-08-06 14:27:58.169283+00', '2014-06-05 15:36:28.56229+00', 14977, 1, 513, '', 'A', 'Summer School 2013, week 3', 1, 1, 'Y', '8sMxXNxJM6E', 306, 0, NULL);
INSERT INTO 'dancevideo' VALUES (971, '2013-07-29 01:10:52.205807+00', '2013-08-11 00:34:05.765978+00', 14607, 1, 485, '', 'C', 'Very poor lighting; video much too dark.  Dancers hardly visible, can''t judge the quality.', 1, 1, 'Y', 'UEO7PqcwgBE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (988, '2013-08-16 19:32:33.613352+00', '2013-10-06 23:57:48.951616+00', 1128, 1, 1041, '', 'B', '', 1, 1, 'Y', 'xWQC2whdsxk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (986, '2013-08-14 13:23:17.185692+00', '2013-10-11 22:29:22.810653+00', 11284, 1, 1041, '', 'C', 'Once through. Two sets in a restricted hall with spectators; no view of the legs. Slow music.', 1, 1, 'Y', 'JR8OvZFdTRM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (990, '2013-08-16 20:32:38.187526+00', '2013-10-24 22:41:18.860996+00', 7811, 1, 1041, '', 'C', 'Nearly twice through.', 1, 1, 'Y', 'A85U9d5wAS8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (991, '2013-08-16 20:56:36.927558+00', '2013-11-18 01:39:49.999599+00', 5128, 1, 1041, '', 'A', 'Danced by the Summer School Dem Team ', 1, 1, 'Y', '27em4ertfPQ', 268, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1050, '2013-08-18 00:52:30.055996+00', '2014-10-23 21:54:36.901009+00', 796, 1, 1296, '', 'A', 'Excellent dancing except for one small passing error.', 1, 1, 'Y', 'pNmJ3WZ4n9U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1015, '2013-08-18 00:51:43.606076+00', '2013-09-20 22:45:17.529397+00', 410, 1, 1296, '', 'D', 'Part of a longer open-air video.', 1, 1, 'Y', 'RbtuVSIapLs', 84, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1245, '2013-08-18 10:55:37.554648+00', '2013-11-18 01:03:42.469375+00', 4092, 1, 1296, '', 'C', 'Beginners'' Class.', 1, 1, 'Y', 'ncNdG0H2A4E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1062, '2013-08-18 10:47:50.66472+00', '2013-08-29 00:39:15.558494+00', 1087, 4, 1296, '', 'B', 'Camera at  sporran level, good view, but not showing quite the whole set. ', 1, 1, 'Y', 'S_P3xGziou4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1044, '2013-08-18 00:52:22.206797+00', '2013-08-29 00:03:49.03117+00', 769, 2, 1296, '', 'D', 'Good View, looking slightly down, some heads cropped.  Shows one set in a big hall. 8 times through', 1, 1, 'Y', 'q-R6Qbq0-CE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1017, '2013-08-18 00:51:45.936203+00', '2013-08-28 23:54:30.186255+00', 413, 3, 1296, '', 'Z', 'REJECTED.  Only bars 49-88, once only.', 1, 1, 'Y', 'VNxs2WmJxQs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1018, '2013-08-18 00:51:47.094469+00', '2013-08-28 21:27:56.021897+00', 413, 4, 1296, '', 'C', 'View from the side, through railings. ', 1, 1, 'Y', 'Tlh_HarNCQ0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1056, '2013-08-18 10:47:49.208847+00', '2013-08-29 00:15:00.905885+00', 887, 5, 1296, '', 'D', 'View from very close; only part of the set is seen at any moment. Makes it difficult to follow the figures.

4 times through', 1, 1, 'Y', 'lFRnigsym7E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1061, '2013-08-18 10:47:50.25358+00', '2013-08-29 00:33:03.662423+00', 13581, 4, 1296, '', 'A', 'Camera at the bottom at sporran level, but giving a very good view of the movements. 8 times.', 1, 1, 'Y', 'BfKxp_mW6s4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (994, '2013-08-18 00:51:13.367655+00', '2013-09-20 11:54:42.638057+00', 9106, 1, 1296, '', 'C', 'Social dance, 4 sets, viewed from the bottom.  ', 1, 1, 'Y', 'kpB7JrlkuXE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1001, '2013-08-18 00:51:23.199916+00', '2013-09-20 13:49:11.758968+00', 116, 1, 1296, '', 'B', 'Part of a longer demo. Twice through in a 3C set, first time the video starts slightly late.', 1, 1, 'Y', '4BnkXp8xArc', 0, 101, NULL);
INSERT INTO 'dancevideo' VALUES (1005, '2013-08-18 00:51:30.545487+00', '2013-09-20 14:55:48.906045+00', 9838, 1, 1296, '', 'B', '', 1, 1, 'Y', 'ce35lQ6I7G8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1007, '2013-08-18 00:51:33.286106+00', '2013-09-20 21:49:05.313057+00', 11184, 1, 1296, '', 'A', '', 1, 1, 'Y', 'pnOwxP3BnCw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1004, '2013-08-18 00:51:29.012475+00', '2013-09-20 22:02:10.077414+00', 132, 2, 1296, '', 'C', 'Once through, first bars missing. Good view.', 1, 1, 'Y', 'zmiKdixkpxQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1003, '2013-08-18 00:51:27.893158+00', '2013-09-20 21:59:17.386328+00', 132, 1, 1296, '', 'A', 'Video starts a little too late; the first bars are missing. Part of a longer demo. Very fine dancing with great "flight".', 1, 1, 'Y', 'mlfnPUukdXg', 10, 119, NULL);
INSERT INTO 'dancevideo' VALUES (1009, '2013-08-18 00:51:36.139555+00', '2013-09-20 22:21:00.977286+00', 292, 1, 1296, '', 'C', 'Class situation, but good and stable view.', 1, 1, 'Y', 'OxnVRg48RWw', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1025, '2013-08-18 00:51:55.782183+00', '2013-09-20 23:02:42.02042+00', 441, 3, 1296, '', 'B', '', 1, 1, 'Y', 'finX4iWl6kU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1023, '2013-08-18 00:51:53.033786+00', '2013-09-20 23:06:11.022842+00', 441, 1, 1296, '', 'A', '', 1, 1, 'Y', 'mlfnPUukdXg', 118, 310, NULL);
INSERT INTO 'dancevideo' VALUES (1028, '2013-08-18 00:51:59.820595+00', '2013-09-20 23:20:39.766225+00', 462, 4, 1296, '', 'C', 'Mixed children/adult set', 1, 1, 'Y', 'DFdeBYb9vYQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1042, '2013-08-18 00:52:19.647208+00', '2013-09-20 23:33:23.477949+00', 745, 2, 1296, '', 'A', '', 1, 1, 'Y', '9QPveQgda60', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1031, '2013-08-18 00:52:04.083962+00', '2013-09-21 00:56:10.860187+00', 615, 1, 1296, '', 'D', '', 1, 1, 'Y', '5zgxUb_UFBg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1079, '2013-08-18 10:47:53.022153+00', '2013-09-21 19:30:55.235998+00', 1285, 1, 1296, '', 'C', 'Very low viewpoint.', 1, 1, 'Y', 'QtrwkCGy5y4', 1860, 2007, NULL);
INSERT INTO 'dancevideo' VALUES (1054, '2013-08-18 08:16:21.507534+00', '2013-09-25 13:20:53.061475+00', 14740, 1, 1296, '', 'B', 'Twice through. Taken from too far. Good dancing, with a very young 1st couple.', 1, 1, 'Y', 'yzmZaMmNKYo', 0, 110, NULL);
INSERT INTO 'dancevideo' VALUES (1032, '2013-08-18 00:52:05.564038+00', '2013-09-25 15:12:16.828212+00', 604, 1, 1296, '', 'B', '', 1, 1, 'Y', 'xGTvbhXELfk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1033, '2013-08-18 00:52:06.719639+00', '2013-09-25 15:07:57.708422+00', 604, 2, 1296, '', 'D', '', 1, 1, 'Y', 'bDg9FLobhns', 31, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1037, '2013-08-18 00:52:11.955817+00', '2013-10-06 20:26:47.312724+00', 699, 1, 1296, '', 'C', '', 1, 1, 'Y', '3-myNaC7BUk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1006, '2013-08-18 00:51:31.833218+00', '2013-10-07 06:05:54.883314+00', 12665, 5, 1296, '', 'B', 'Danced in a 4C set; 1c steps to 4pl at th the end.', 1, 1, 'Y', 'HM5Y-O_okMU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1041, '2013-08-18 00:52:17.69769+00', '2013-10-06 20:31:28.304646+00', 8142, 3, 1296, '', 'D', '', 1, 1, 'Y', 'YlDmZDi1cwQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1040, '2013-08-18 00:52:16.50841+00', '2013-10-06 20:32:59.965171+00', 8142, 2, 1296, '', 'A', '', 1, 1, 'Y', '0ngVLzm1FuI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1039, '2013-08-18 00:52:15.309132+00', '2013-10-06 20:36:14.085567+00', 8142, 1, 1296, '', 'A', 'Demo In slow motion', 1, 1, 'Y', 'B5XKK9R856U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1000, '2013-08-18 00:51:21.870048+00', '2013-10-06 23:25:22.938241+00', 105, 2, 1296, '', 'C', 'The animation video tells that 1c+2c  & 3c+4c dance RHA, LHA to start.  In this live video only 1c+2c dance this wheel.', 1, 1, 'Y', 'P-C_uFi2lc4', 1155, 1313, NULL);
INSERT INTO 'dancevideo' VALUES (1080, '2013-08-18 10:47:53.286122+00', '2013-10-14 00:15:18.286423+00', 8569, 1, 1296, '', 'A', 'View from a bit far. et of all women, making it hard to distinguish M and W dancers.', 1, 1, 'Y', 'DwEPzU5Wrh8', 0, 190, NULL);
INSERT INTO 'dancevideo' VALUES (1070, '2013-08-18 10:47:51.464908+00', '2013-10-14 18:08:25.246646+00', 10787, 3, 1296, '', 'D', 'Once through only. Social dance. Reasonable dancing, but not so easy to follow the figures', 1, 1, 'Y', 'ct_wWt1qhwM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (993, '2013-08-17 19:00:48.149983+00', '2013-12-26 01:41:07.855738+00', 6484, 2, 1041, '', 'C', 'In costumes.  With a "scarecrow" dancing round the set for fun.', 1, 1, 'Y', 'mTBXfIhvDgU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1076, '2013-08-18 10:47:52.432159+00', '2013-11-18 20:06:13.342825+00', 8653, 2, 1296, '', 'C', '', 1, 1, 'Y', '66ua162iKms', 83, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1030, '2013-08-18 00:52:02.640331+00', '2013-12-26 20:11:46.4055+00', 11108, 2, 1296, '', 'C', 'Once through; mediocre image.', 1, 1, 'Y', 'M2tVnHkDU5g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1012, '2013-08-18 00:51:39.921066+00', '2013-12-26 21:36:37.355907+00', 358, 2, 1296, '', 'C', '', 1, 1, 'Y', 'KaSuIlMtYbc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1013, '2013-08-18 00:51:41.071652+00', '2013-12-26 21:38:04.110603+00', 358, 3, 1296, '', 'D', '', 1, 1, 'Y', '1k8KD3z73Jo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1074, '2013-08-18 10:47:52.133486+00', '2013-12-29 00:30:48.505162+00', 13847, 2, 1296, '', 'C', '', 1, 1, 'Y', 'ivK4c94pp1g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1022, '2013-08-18 00:51:51.791356+00', '2013-12-29 01:42:33.492757+00', 428, 3, 1296, '', 'B', '1c goes to bottom after each turn; 4 times through.', 1, 1, 'Y', 'Zxsm-kn9xMM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1053, '2013-08-18 08:16:21.368072+00', '2013-12-29 01:38:48.250437+00', 877, 2, 1296, '', 'B', '', 1, 1, 'Y', 'Oufa30PgMH8', 26, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1014, '2013-08-18 00:51:42.358404+00', '2013-12-29 02:36:35.182926+00', 13149, 7, 1296, '', 'B', '', 1, 1, 'Y', 'fApSz2HnZok', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1068, '2013-08-18 10:47:50.981681+00', '2014-04-27 09:30:37.284672+00', 1100, 3, 1296, '', 'C', 'The figure of eight is danced incorrectly - the dancing couples should dance Right Shoulder around their first corner

', 1, 1, 'Y', 'xjFBIY6qP7E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1075, '2013-08-18 10:47:52.307291+00', '2013-12-30 20:42:50.655064+00', 1223, 6, 1296, '', 'B', 'Once through; part of a longer display', 1, 1, 'Y', 'rofhzgF24FU', 15, 55, NULL);
INSERT INTO 'dancevideo' VALUES (1127, '2013-08-18 10:48:00.439865+00', '2014-08-18 05:29:49.147536+00', 12793, 4, 1296, '', 'B', '', 1, 1, 'Y', 'tBRsJcLzq8w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1111, '2013-08-18 10:47:58.122793+00', '2013-10-24 00:03:47.903121+00', 11512, 1, 1296, '', 'A', 'Newcastle 2012', 1, 1, 'Y', '8wlxjZ1p6oQ', 15, 275, NULL);
INSERT INTO 'dancevideo' VALUES (1092, '2013-08-18 10:47:55.095057+00', '2013-08-28 21:06:39.07747+00', 1473, 8, 1296, '', 'A', 'Once through only.  Viewed from the side.  Tinny music.', 1, 1, 'Y', 'ZLZlzaoTj3U', 0, 61, NULL);
INSERT INTO 'dancevideo' VALUES (1103, '2013-08-18 10:47:56.697095+00', '2013-08-28 22:07:03.253024+00', 1582, 6, 1296, '', 'D', 'Good view from slightly above. 8 times through. One serious error. ', 1, 1, 'Y', 'S-LtnDtoJy0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1098, '2013-08-18 10:47:56.203847+00', '2013-08-28 21:52:28.0967+00', 1562, 1, 1296, '', 'C', 'Dancing starts at 0:15. View from slightly above. ', 1, 1, 'Y', 'g5Axpo-FHac', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1142, '2013-08-18 10:55:18.453126+00', '2013-08-28 22:15:31.397382+00', 2203, 6, 1296, '', 'B', 'Part of a larger demo. 3 times through.  Good view, from the side.', 1, 1, 'Y', 'S_6xmqAc9RE', 25, 140, NULL);
INSERT INTO 'dancevideo' VALUES (1160, '2013-08-18 10:55:20.515757+00', '2013-08-28 22:26:56.32875+00', 2428, 2, 1296, '', 'D', 'Nearly vertical view; excellent view of the figures. Poor lighting. Towards the end wider view of the hall. ', 1, 1, 'Y', '7Ac8zNb6HxI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1113, '2013-08-18 10:47:58.355558+00', '2013-09-20 00:24:57.791016+00', 10433, 7, 1296, '', 'B', 'On bars 31-32 and 87-88, this set makes 1 1/2 RH turn instead of 1/2 turn. Looks good.', 1, 1, 'Y', '08cc1OkPixg', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1114, '2013-08-18 10:47:58.381603+00', '2013-09-20 00:34:09.236886+00', 10433, 8, 1296, '', 'C', 'Some errors in the "twirls"before the reels.', 1, 1, 'Y', 'WzXTNy3jdmg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1083, '2013-08-18 10:47:53.772144+00', '2013-09-20 00:52:07.415935+00', 1348, 3, 1296, '', 'B', '', 1, 1, 'Y', 'REm-aj_zuD0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1084, '2013-08-18 10:47:53.79525+00', '2013-09-20 00:58:23.848719+00', 1348, 4, 1296, '', 'D', '', 1, 1, 'Y', 'qvRnVmp9qgw', 45, 324, NULL);
INSERT INTO 'dancevideo' VALUES (1091, '2013-08-18 10:47:55.04804+00', '2013-09-20 01:16:01.422657+00', 1473, 7, 1296, '', 'B', '', 1, 1, 'Y', 'CubkhjX9LAQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1090, '2013-08-18 10:47:55.023049+00', '2013-09-20 01:17:44.666565+00', 1473, 6, 1296, '', 'D', '', 1, 1, 'Y', '-y8tlcO4QrA', 0, 240, NULL);
INSERT INTO 'dancevideo' VALUES (1617, '2014-03-24 14:44:58.563852+00', '2014-03-24 16:39:49.891213+00', 3580, 2, 1022, '', 'C', '', 1, 1, 'Y', 'YoM7ip7qm80', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1029, '2013-08-18 00:52:01.208915+00', '2023-02-07 10:03:00.046281+00', 9340, 1, 1296, '', 'D', 'Good view, once through only.', 1, 1, 'Y', 'F8AOMRRDQq4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1135, '2013-08-18 10:48:01.523999+00', '2013-09-20 11:34:09.312015+00', 2034, 1, 1296, '', 'A', 'Three times through in a 3C set. Old style ladies'' clothing.', 1, 1, 'Y', 'Y58lwffxXqU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1136, '2013-08-18 10:48:01.552566+00', '2013-09-20 11:46:07.905517+00', 2034, 2, 1296, '', 'C', 'View from the bottom, not so good. Some weak dancers.', 1, 1, 'Y', 'K2_PoVzGAtY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1120, '2013-08-18 10:47:59.026628+00', '2013-09-25 22:34:48.635839+00', 1790, 2, 1296, '', 'A', '', 1, 1, 'Y', '5H0Qc63ysoA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1137, '2013-08-18 10:48:01.585107+00', '2013-09-20 11:40:22.013974+00', 2034, 3, 1296, '', 'D', 'Quite some muddles.', 1, 1, 'Y', 'DKDfrSaHZU4', 28, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1116, '2013-08-18 10:47:58.727969+00', '2013-10-15 20:27:15.022787+00', 1782, 2, 1296, '', 'C', 'Class dance, only first set clear to see. Some dancer only walk. Phrasing mediocre. Does show all the formations.', 1, 1, 'Y', 'SznEMyAOIow', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1571, '2014-02-18 04:34:57.976028+00', '2014-02-18 23:58:29.596084+00', 219, 1, 513, '', 'A', '', 1, 1, 'Y', 'vIRrRSeBX2w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1132, '2013-08-18 10:48:01.204915+00', '2013-10-24 00:46:08.435934+00', 8146, 2, 1296, '', 'Z', 'This is ballroom dancing. Neither steps nor music are SCD or anywhere near. ', 1, 1, 'Y', '8G8aw0hpV2o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1133, '2013-08-18 10:48:01.227337+00', '2013-10-24 00:49:36.006744+00', 8146, 3, 1296, '', 'Z', 'This is ballroom or perhaps ceilidh dancing. Neither steps nor music are SCD. ', 1, 1, 'Y', '9p5n6-roHlQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1151, '2013-08-18 10:55:19.226332+00', '2013-10-24 22:06:11.793331+00', 2317, 4, 1296, '', 'C', '', 1, 1, 'Y', 'gKyRUyrH9lU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1138, '2013-08-18 10:48:01.908563+00', '2013-10-24 22:28:27.477312+00', 14398, 1, 1296, '', 'B', 'Once through only.', 1, 1, 'Y', 'MGdBSSZayI0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1153, '2013-08-18 10:55:19.359717+00', '2013-10-24 23:30:06.788212+00', 7738, 1, 1296, '', 'A', '', 1, 1, 'Y', 'xoqZlzsfLDc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1134, '2013-08-18 10:48:01.339703+00', '2013-10-24 23:45:24.309619+00', 14397, 1, 1296, '', 'B', '', 1, 1, 'Y', 'ibdCJNGg-nc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1165, '2013-08-18 10:55:21.584816+00', '2013-11-18 02:03:02.220156+00', 10672, 1, 1296, '', 'B', 'View too low and too narrow, not easy to follow.', 1, 1, 'Y', '5SCoGrxpQfA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1102, '2013-08-18 10:47:56.475795+00', '2013-11-18 01:58:18.79269+00', 8514, 2, 1296, '', 'B', '', 1, 1, 'Y', 'cJlr-ZJRhMg', 3, 207, NULL);
INSERT INTO 'dancevideo' VALUES (1140, '2013-08-18 10:48:02.392906+00', '2013-11-18 02:58:07.504327+00', 9085, 2, 1296, '', 'C', 'The first time through starts a bit late, and is taken from too far.  Gets better later.', 1, 1, 'Y', 'yfrezqZEFDg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1139, '2013-08-18 10:48:02.23762+00', '2013-11-18 03:02:07.844291+00', 9085, 1, 1296, '', 'D', '', 1, 1, 'Y', 'nJ0LlJXtf6A', 70, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1109, '2013-08-18 10:47:57.472634+00', '2013-12-25 02:25:33.095836+00', 11893, 2, 1296, '', 'B', '', 1, 1, 'Y', 'hllbupTLJO8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1129, '2013-08-18 10:48:00.885419+00', '2013-12-06 00:17:40.628048+00', 1992, 2, 1296, '', 'A', '', 1, 1, 'Y', 'WpzKnSXpGT4', 81, 131, NULL);
INSERT INTO 'dancevideo' VALUES (1143, '2013-08-18 10:55:18.681428+00', '2013-12-26 01:06:24.195375+00', 12941, 2, 1296, '', 'C', '', 1, 1, 'Y', 'gclZeHdHhYQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1124, '2013-08-18 10:47:59.9108+00', '2013-12-26 01:09:45.501732+00', 1838, 2, 1296, '', 'C', 'Once through only.', 1, 1, 'Y', 'ffzK8aJouc0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1108, '2013-08-18 10:47:57.221506+00', '2013-12-26 20:27:40.219604+00', 1641, 3, 1296, '', 'D', 'Once through, ceilidh-like social', 1, 1, 'Y', 'PDGJA7qsyCs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1154, '2013-08-18 10:55:19.703684+00', '2013-12-26 01:26:40.436711+00', 2360, 2, 1296, '', 'B', 'Danced in a 3 couplse set, adding the extra progression by modifying the last 4 bars for each gender.', 1, 1, 'Y', 'sTDbHXyTP0c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1107, '2013-08-18 10:47:57.200004+00', '2013-12-26 20:30:05.973198+00', 1641, 2, 1296, '', 'D', 'Not all the set visible at the same time.  ', 1, 1, 'Y', 'iRQCFNCJnD0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3532, '2018-05-08 12:20:39.161554+00', '2018-05-16 10:17:28.889682+00', 10286, 1, 586, '', 'A', '', 1, 1, 'Y', 'zt52W96KX2k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1059, '2013-08-18 10:47:50.050085+00', '2017-03-16 22:10:49.113507+00', 998, 1, 1296, '', 'A', 'Very poor lighting but excellent dancing.  Twice through, only the first time through shows the dancing clearly.', 1, 1, 'Y', 'aiBbY7VXPdw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1035, '2013-08-18 00:52:09.191049+00', '2018-09-03 22:32:00.522947+00', 633, 4, 1296, '', 'A', '', 1, 1, 'Y', 'kpMrBV2b83c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1195, '2013-08-18 10:55:28.170258+00', '2018-10-02 08:56:13.164943+00', 3057, 5, 1296, '', 'X', '', 1, 1, 'Y', '2_C3ZS8qRVU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (1156, '2013-08-18 10:55:19.927489+00', '2013-12-28 01:38:21.167565+00', 695, 2, 1296, '', 'B', 'Danced three times through in a 3C set', 1, 1, 'Y', 'zrBQg6MYbks', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1082, '2013-08-18 10:47:53.567942+00', '2013-12-28 01:26:39.748421+00', 1315, 2, 1296, '', 'B', '', 1, 1, 'Y', 'EW4H3-yjyyc', 13, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1167, '2013-08-18 10:55:21.806709+00', '2013-12-29 02:26:24.363555+00', 2600, 4, 1296, '', 'A', '', 1, 1, 'Y', '9Zrqkdcslbo', 235, 570, NULL);
INSERT INTO 'dancevideo' VALUES (1166, '2013-08-18 10:55:21.777717+00', '2013-12-29 02:30:52.368197+00', 2600, 3, 1296, '', 'B', '', 1, 1, 'Y', 'tllzmGHokqw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1119, '2013-08-18 10:47:58.916989+00', '2013-12-29 13:34:11.967238+00', 1786, 3, 1296, '', 'D', 'Social at summer school 2013/4', 1, 1, 'Y', 'MN2i4FTmPUI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1159, '2013-08-18 10:55:20.409819+00', '2013-12-30 23:07:32.727811+00', 7546, 3, 1296, '', 'B', '', 1, 1, 'Y', '4QyoSIQocKI', 0, 170, NULL);
INSERT INTO 'dancevideo' VALUES (1126, '2013-08-18 10:48:00.350306+00', '2013-12-30 22:33:40.056565+00', 1931, 6, 1296, '', 'B', 'A shortened version of this dance ', 1, 1, 'Y', 'lf986fj4HUg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1112, '2013-08-18 10:47:58.309669+00', '2013-12-30 23:24:37.023889+00', 10433, 6, 1296, '', 'C', '', 1, 1, 'Y', '7LbRkwXyCB0', 201, 389, NULL);
INSERT INTO 'dancevideo' VALUES (1147, '2013-08-18 10:55:18.985966+00', '2013-12-30 23:13:18.029371+00', 2267, 6, 1296, '', 'C', '', 1, 1, 'Y', 'VnE2-y898Pk', 1, 180, NULL);
INSERT INTO 'dancevideo' VALUES (1097, '2013-08-18 10:47:56.012348+00', '2013-12-30 23:55:41.360155+00', 1544, 4, 1296, '', 'B', 'For more information listen to the introduction from time 0:00.', 1, 1, 'Y', 'YekGMBP1LHk', 96, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1104, '2013-08-18 10:47:56.731827+00', '2013-12-30 23:47:42.26383+00', 1582, 7, 1296, '', 'B', 'Once though.  The display continues with Hooper''s Jig and the Sailor', 1, 1, 'Y', 'QGVggcfG3y0', 0, 37, NULL);
INSERT INTO 'dancevideo' VALUES (1115, '2013-08-18 10:47:58.533945+00', '2013-12-30 23:59:23.473496+00', 12983, 3, 1296, '', 'B', 'The set dances the older version of this dance, where [17-24] are just Fig8 for 1c, and not reels across.', 1, 1, 'Y', 'v7K2D7Djqkk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1222, '2013-08-18 10:55:34.606886+00', '2013-10-23 10:22:45.068641+00', 3700, 1, 1296, '', 'B', 'One set, on a stage, low view from the side.', 1, 1, 'Y', 'a39Ja-aKLGc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1194, '2013-08-18 10:55:28.124321+00', '2013-12-30 22:18:58.971819+00', 3057, 4, 1296, '', 'A', '', 1, 1, 'Y', 'NXtM3MhMYrM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1176, '2013-08-18 10:55:23.712742+00', '2013-08-28 23:10:00.648784+00', 2846, 1, 1296, '', 'A', 'Video not yet checked against original description.', 1, 1, 'Y', 'jkVUXtLWn1I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1181, '2013-08-18 10:55:24.067955+00', '2013-10-08 22:56:30.280952+00', 2910, 2, 1296, '', 'D', '', 1, 1, 'Y', 'XOL0WdhAS0U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1184, '2013-08-18 10:55:24.366162+00', '2013-10-08 22:38:50.662223+00', 2925, 1, 1296, '', 'D', '', 1, 1, 'Y', 'g1sIPM1n8vI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1183, '2013-08-18 10:55:24.184833+00', '2013-10-08 22:53:15.438887+00', 8056, 1, 1296, '', 'B', '', 1, 1, 'Y', '-9vx9A_5okI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1182, '2013-08-18 10:55:24.089525+00', '2013-10-08 22:55:31.936033+00', 2910, 3, 1296, '', 'D', '', 1, 1, 'Y', 'DlSRJc5ZBMI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1186, '2013-08-18 10:55:24.729274+00', '2013-10-13 23:35:18.027349+00', 2956, 1, 1296, '', 'D', 'Just one bar short of once through. Good view.', 1, 1, 'Y', '0mSaNlQ_z2U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1187, '2013-08-18 10:55:25.30304+00', '2013-10-13 23:37:31.760073+00', 2956, 2, 1296, '', 'C', 'Once through only, slow dancing without enthusiasm. ', 1, 1, 'Y', 'jaSBp4EYp70', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1190, '2013-08-18 10:55:26.693276+00', '2013-10-14 00:26:48.220265+00', 7420, 1, 1296, '', 'D', 'Too much looking at the orchestra.', 1, 1, 'Y', 'EYd4vLdJJHY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1253, '2013-08-18 10:55:38.789423+00', '2013-10-15 19:31:24.159009+00', 4239, 4, 1296, '', 'A', 'Six times through. Excellent view.', 1, 1, 'Y', 'l4NVNzxuYkY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1169, '2013-08-18 10:55:22.041583+00', '2013-10-15 19:42:03.800795+00', 2616, 7, 1296, '', 'D', '', 1, 1, 'Y', 'Aw3lnV6RbpY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1209, '2013-08-18 10:55:32.590486+00', '2013-10-24 11:43:47.315782+00', 3509, 1, 1296, '', 'B', 'Poor lighting, and low view, but well danced.', 1, 1, 'Y', '-GFrPfupehI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1205, '2013-08-18 10:55:31.757382+00', '2013-10-24 13:12:04.12491+00', 12291, 1, 1296, '', 'B', '', 1, 1, 'Y', 'WYfgjNyWGS8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2972, '2017-04-10 16:04:21.355482+00', '2018-05-10 03:30:30.222671+00', 5262, 4, 160, '', 'A', '', 1, 1, 'Y', 'wizpNvandqk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1223, '2013-08-18 10:55:34.772605+00', '2013-10-24 21:20:37.366889+00', 3710, 1, 1296, '', 'D', 'Part of a longer demo, with 8 couples dancing a compound choreography based on this dance. Nice to look at, danced at demo level, but of no use for learning or following Largo bay', 1, 1, 'Y', 'GOjd6oMFeEM', 280, 326, NULL);
INSERT INTO 'dancevideo' VALUES (1207, '2013-08-18 10:55:32.31452+00', '2013-10-24 22:14:54.076717+00', 3472, 1, 1296, '', 'B', 'Demo, 3 times through in a 3 couple set. Clear and good, useful for learning from.', 1, 1, 'Y', '2dHZkRy5FkI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1216, '2013-08-18 10:55:33.139431+00', '2013-10-24 22:21:39.814867+00', 3580, 1, 1296, '', 'D', '', 1, 1, 'Y', 'EH0vx3JiXbc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1196, '2013-08-18 10:55:28.462904+00', '2013-10-24 23:51:13.795904+00', 7285, 4, 1296, '', 'B', '', 1, 1, 'Y', 'Qixa5ahytnI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1256, '2013-08-18 10:55:39.412128+00', '2013-10-29 00:45:52.895448+00', 4358, 1, 1296, '', 'C', '', 1, 1, 'Y', 'MeMoCooRmgw', 50, 395, NULL);
INSERT INTO 'dancevideo' VALUES (1236, '2013-08-18 10:55:36.388888+00', '2013-10-29 18:57:53.391209+00', 3933, 1, 1296, '', 'C', 'Part of a display, starts midway through.', 1, 1, 'Y', 'WmOXllT298g', 0, 63, NULL);
INSERT INTO 'dancevideo' VALUES (1157, '2013-08-18 10:55:20.175236+00', '2022-10-03 16:52:59.486973+00', 13585, 2, 1296, '', 'B', '', 1, 1, 'Y', 'i8Bx2AJWPqI', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1198, '2013-08-18 10:55:29.599941+00', '2013-11-18 02:05:56.663362+00', 3152, 1, 1296, '', 'C', 'View too close and too narrow; hard to follow', 1, 1, 'Y', 'w3A2eDpY974', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1244, '2013-08-18 10:55:37.325508+00', '2013-12-02 18:52:47.635374+00', 4008, 1, 1296, '', 'A', '3 times through; final bars modified to link into the following dance of the display.', 1, 1, 'Y', 'yBse3dxoL_k', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1212, '2013-08-18 10:55:32.922363+00', '2013-12-02 19:47:08.70867+00', 7554, 1, 1296, '', 'A', 'This is a slow and detailed walkthrough to teach the dance', 1, 1, 'Y', 'rpJtHGH_BO4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1213, '2013-08-18 10:55:32.947482+00', '2013-12-02 19:49:25.097902+00', 7554, 2, 1296, '', 'A', '', 1, 1, 'Y', 'gzNHG8aB7Gc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1214, '2013-08-18 10:55:32.992427+00', '2013-12-02 19:52:18.715492+00', 7554, 3, 1296, '', 'C', 'Victorian version', 1, 1, 'Y', '6ZOcalk4KH0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1215, '2013-08-18 10:55:33.01458+00', '2013-12-02 19:54:17.168613+00', 7554, 4, 1296, '', 'D', 'NSW version.', 1, 1, 'Y', 'lnlN6iLU2r0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1238, '2013-08-18 10:55:36.776413+00', '2013-12-11 22:49:36.755839+00', 3980, 3, 1296, '', 'D', 'Camera does keep foussed on a single set.', 1, 1, 'Y', 'aAe0YJnXK20', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1219, '2013-08-18 10:55:33.754668+00', '2013-12-14 03:06:16.52011+00', 3608, 2, 1296, '', 'A', '', 1, 1, 'Y', '6Fcu8HkHwAU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1191, '2013-08-18 10:55:26.840425+00', '2013-12-14 03:16:41.411578+00', 3021, 2, 1296, '', 'A', '', 1, 1, 'Y', 'D2qL97Yu4rc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1239, '2013-08-18 10:55:36.872023+00', '2013-12-18 23:36:45.177442+00', 4014, 2, 1296, '', 'A', '', 1, 1, 'Y', 'GXirBg0S4ag', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1199, '2013-08-18 10:55:30.684415+00', '2013-12-19 00:02:04.821658+00', 8138, 2, 1296, '', 'B', '', 1, 1, 'Y', 'hCDEsnfVXGA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1233, '2013-08-18 10:55:35.774735+00', '2013-12-19 00:12:11.723756+00', 3834, 3, 1296, '', 'D', '', 1, 1, 'Y', 'paH0HFTr_qo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1229, '2013-08-18 10:55:35.254369+00', '2013-12-19 00:05:30.944819+00', 3802, 2, 1296, '', 'D', '', 1, 1, 'Y', 'I54v12AgPZk', 249, 320, NULL);
INSERT INTO 'dancevideo' VALUES (1232, '2013-08-18 10:55:35.745607+00', '2013-12-19 00:10:01.725468+00', 3834, 2, 1296, '', 'D', 'Just once through; at a social', 1, 1, 'Y', 'oWxCUT9sS0s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1180, '2013-08-18 10:55:23.898435+00', '2013-12-19 00:41:09.415287+00', 13619, 2, 1296, '', 'D', 'Young dancers', 1, 1, 'Y', 'Jz_i3FqIfX8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1235, '2013-08-18 10:55:36.263189+00', '2013-12-25 02:16:03.427549+00', 3932, 4, 1296, '', 'A', '', 1, 1, 'Y', '4xeLmb-1XIY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1234, '2013-08-18 10:55:36.172337+00', '2013-12-25 02:18:39.246055+00', 3932, 3, 1296, '', 'A', '', 1, 1, 'Y', 'j5y1uvmA608', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1188, '2013-08-18 10:55:25.458697+00', '2013-12-25 13:56:13.701239+00', 13579, 3, 1296, '', 'A', '', 1, 1, 'Y', 'iBTTL8APcxE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1224, '2013-08-18 10:55:34.880771+00', '2013-12-26 01:02:51.475086+00', 7795, 2, 1296, '', 'C', '', 1, 1, 'Y', 'g9I6VopbYDQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1226, '2013-08-18 10:55:35.015135+00', '2013-12-26 21:07:53.357545+00', 3759, 4, 1296, '', 'B', '', 1, 1, 'Y', 'xPRe_laLJpQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1200, '2013-08-18 10:55:31.076845+00', '2013-12-26 20:07:39.462402+00', 3337, 2, 1296, '', 'B', 'Once through. Formal ballroom setting.  The dance is not SCD, but has the same figures as the SCD dance of the same name.', 1, 1, 'Y', '4rebJVnV1LM', 0, 47, NULL);
INSERT INTO 'dancevideo' VALUES (1227, '2013-08-18 10:55:35.051917+00', '2013-12-26 21:16:21.025247+00', 3759, 5, 1296, '', 'D', 'easonable dancing, but to muddled a view to be much use to explain the dance.', 1, 1, 'Y', 'Ie_2fubNOHc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1255, '2013-08-18 10:55:39.300757+00', '2013-12-29 01:55:21.072261+00', 4354, 2, 1296, '', 'C', '', 1, 1, 'Y', 'cIuNNdcpjR4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1240, '2013-08-18 10:55:37.035003+00', '2013-12-29 02:13:38.79985+00', 4032, 3, 1296, '', 'C', '', 1, 1, 'Y', 'tQeYdTDjd2g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1202, '2013-08-18 10:55:31.436102+00', '2013-12-29 02:15:33.778933+00', 7283, 3, 1296, '', 'D', '', 1, 1, 'Y', '0X-Zs4eqSYs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1203, '2013-08-18 10:55:31.607356+00', '2013-12-29 02:20:57.375039+00', 3365, 4, 1296, '', 'D', '', 1, 1, 'Y', 'EsoBxDoxtlU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1178, '2013-08-18 10:55:23.753234+00', '2013-12-29 13:41:34.316709+00', 2846, 3, 1296, '', 'B', '', 1, 1, 'Y', 'iZv7LVJxerg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1179, '2013-08-18 10:55:23.795367+00', '2013-12-29 13:49:40.341559+00', 2846, 4, 1296, '', 'B', '', 1, 1, 'Y', 'cK2jToOllNI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1242, '2013-08-18 10:55:37.179996+00', '2013-12-30 21:19:41.664826+00', 4046, 4, 1296, '', 'A', '', 1, 1, 'Y', 'L3m7q_eu95E', 269, 410, NULL);
INSERT INTO 'dancevideo' VALUES (1201, '2013-08-18 10:55:31.24503+00', '2013-12-30 22:05:16.946333+00', 3338, 3, 1296, '', 'C', 'Once through.', 1, 1, 'Y', '0B8C3LDoZM0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1228, '2013-08-18 10:55:35.15935+00', '2013-12-30 22:21:02.369203+00', 3786, 3, 1296, '', 'C', '', 1, 1, 'Y', 'rBR_eKS8iYs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1193, '2013-08-18 10:55:27.618125+00', '2013-12-30 22:23:37.935065+00', 8932, 3, 1296, '', 'D', '', 1, 1, 'Y', 'cfw-1WIheEI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1173, '2013-08-18 10:55:22.869364+00', '2013-12-30 22:29:50.267491+00', 9862, 3, 1296, '', 'C', '', 1, 1, 'Y', 'rFBUTNxL42c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1334, '2013-08-18 10:55:54.37201+00', '2013-10-15 22:39:24.763428+00', 5525, 11, 1296, '', 'B', 'Clear view. 3C set. Good for learning.', 1, 1, 'Y', 'Vo_mJUH6zoE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1286, '2013-08-18 10:55:43.952943+00', '2013-10-14 20:36:14.831285+00', 4808, 1, 1296, '', 'C', '', 1, 1, 'Y', 'T1F8V7ZyF5c', 485, 828, NULL);
INSERT INTO 'dancevideo' VALUES (1335, '2013-08-18 10:55:54.668458+00', '2013-09-25 10:21:52.877001+00', 5529, 7, 1296, '', 'B', 'On grass. ', 1, 1, 'Y', 'y049wdoMQn4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1267, '2013-08-18 10:55:41.37675+00', '2013-09-02 08:03:11.164038+00', 9638, 6, 1296, '', 'C', '', 1, 1, 'Y', 'PcuysZ-Gz84', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1336, '2013-08-18 10:55:54.728821+00', '2013-09-25 10:23:42.444072+00', 5529, 8, 1296, '', 'A', 'Twice through', 1, 1, 'Y', 'XWuNgTiQH1s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1319, '2013-08-18 10:55:50.666218+00', '2013-10-14 18:15:12.944783+00', 5308, 4, 1296, '', 'B', '', 1, 1, 'Y', 'S_6xmqAc9RE', 203, 310, NULL);
INSERT INTO 'dancevideo' VALUES (1318, '2013-08-18 10:55:50.579762+00', '2013-10-14 19:22:34.682401+00', 5308, 3, 1296, '', 'B', '', 1, 1, 'Y', 'aX0CflUKGwg', 165, 249, NULL);
INSERT INTO 'dancevideo' VALUES (1293, '2013-08-18 10:55:44.85448+00', '2013-10-15 19:51:13.376715+00', 10535, 4, 1296, '', 'C', '', 1, 1, 'Y', 'h8gh6WK6Hp8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1283, '2013-08-18 10:55:43.795391+00', '2013-10-15 20:37:02.313645+00', 4805, 4, 1296, '', 'D', 'Low view, from the bottom in a long set, once through, 1C dancing to the bottom at the end. Good dancing, but impossible to follow the figures.', 1, 1, 'Y', 'SUXdF63MoOw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1285, '2013-08-18 10:55:43.858073+00', '2013-10-15 20:44:47.688954+00', 4805, 6, 1296, '', 'C', 'Ballroom, good view from above. Figures easy to follow, in spite of some errors. ', 1, 1, 'Y', 'wtVJaNDdn8o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1315, '2013-08-18 10:55:50.244007+00', '2013-10-15 20:57:09.038063+00', 11189, 7, 1296, '', 'B', 'Dem set on stage, seen from the floor below. Figures can be followed. ', 1, 1, 'Y', 'xbblsREKbrI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1269, '2013-08-18 10:55:41.504718+00', '2013-10-15 21:07:27.491524+00', 4555, 6, 1296, '', 'A', '', 1, 1, 'Y', '9vMNoujq9fk', 9, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1268, '2013-08-18 10:55:41.468998+00', '2013-10-15 21:10:52.137515+00', 4555, 5, 1296, '', 'B', 'Very close to dem level. Excellent view from above.', 1, 1, 'Y', 'V8_NjUHS-a4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1332, '2013-08-18 10:55:54.301461+00', '2013-10-15 22:34:50.959678+00', 5525, 9, 1296, '', 'C', 'In ballroom, from bottom of the set, taken at shoulder height. ', 1, 1, 'Y', 'pfosO_sS0AA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1258, '2013-08-18 10:55:39.963047+00', '2013-10-24 23:20:47.553117+00', 14022, 1, 1296, '', 'B', '3 times through in a 3C set.', 1, 1, 'Y', 'LnFZT17Ikiw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1331, '2013-08-18 10:55:54.273014+00', '2013-10-15 22:39:58.002566+00', 5525, 8, 1296, '', 'C', '', 1, 1, 'Y', '2URKrQ9RcVk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1274, '2013-08-18 10:55:42.23577+00', '2013-10-24 23:44:57.117361+00', 12664, 1, 1296, '', 'B', '', 1, 1, 'Y', 'C2_JJY1dyxI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1281, '2013-08-18 10:55:43.101771+00', '2013-10-24 23:48:06.885952+00', 4741, 1, 1296, '', 'B', '', 1, 1, 'Y', '9G3oKrbOlxM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1257, '2013-08-18 10:55:39.704327+00', '2013-10-29 17:16:21.690279+00', 4356, 1, 1296, '', 'C', 'Twice through in a 3C set', 1, 1, 'Y', 'MQCyuP7rqvU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1288, '2013-08-18 10:55:44.196256+00', '2013-10-29 17:23:19.880046+00', 13299, 1, 1296, '', 'A', '', 1, 1, 'Y', 'MMX6YY96aHs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1280, '2013-08-18 10:55:42.838536+00', '2013-10-29 18:36:11.012661+00', 13464, 1, 1296, '', 'C', '', 1, 1, 'Y', 'hdHxoKB_LqM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1275, '2013-08-18 10:55:42.332724+00', '2013-11-18 00:05:32.624475+00', 11287, 1, 1296, '', 'B', '3 times through in a 3c set. Good view.', 1, 1, 'Y', 'LW4aYAkk4k8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1300, '2013-08-18 10:55:47.010911+00', '2013-10-29 22:30:23.891987+00', 12368, 1, 1296, '', 'B', '', 1, 1, 'Y', 'g48QUaP_I9w', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1308, '2013-08-18 10:55:49.471446+00', '2013-11-17 23:33:00.301668+00', 14634, 1, 1296, '', 'A', 'Low view, moderately easy to follow. 4 times through.', 1, 1, 'Y', '4PjUSocNG60', 24, 167, NULL);
INSERT INTO 'dancevideo' VALUES (1299, '2013-08-18 10:55:46.861474+00', '2013-11-18 00:15:19.340737+00', 14458, 1, 1296, '', 'B', 'Good view. 4 times through', 1, 1, 'Y', 'HQNwObZ935k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1270, '2013-08-18 10:55:41.686475+00', '2013-11-18 01:07:10.019345+00', 8734, 1, 1296, '', 'D', '', 1, 1, 'Y', 'Wtgwa0XCO6g', 120, 270, NULL);
INSERT INTO 'dancevideo' VALUES (1297, '2013-08-18 10:55:45.928639+00', '2013-11-18 01:10:32.932056+00', 14448, 1, 1296, '', 'B', 'Once through. Excellent view.', 1, 1, 'Y', '9dNJbfCXtGA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3482, '2018-03-23 03:04:10.6893+00', '2018-04-11 15:14:53.223962+00', 11078, 1, 160, '', 'A', 'Xiaowen Yu was incorrectly credited. My sincere apologies, Peter Price', 1, 1, 'Y', 'joKESxEZaCI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1298, '2013-08-18 10:55:46.345742+00', '2013-11-18 01:16:51.265627+00', 13082, 1, 1296, '', 'B', 'Once only.', 1, 1, 'Y', 'g6_ubChLhRE', 45, 220, NULL);
INSERT INTO 'dancevideo' VALUES (1323, '2013-08-18 10:55:51.356784+00', '2013-11-18 20:35:44.066913+00', 12893, 1, 1296, '', 'D', 'Twice through, poor lighting but good view from above.  The nearer set makes many mistakes. ', 1, 1, 'Y', 'wkR5QG-w3mo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1324, '2013-08-18 10:55:51.631638+00', '2013-11-18 22:42:03.713375+00', 14707, 1, 1296, '', 'A', '', 1, 1, 'Y', '42_8iujkR3Y', 388, 584, NULL);
INSERT INTO 'dancevideo' VALUES (1325, '2013-08-18 10:55:51.84672+00', '2013-11-24 02:28:02.502458+00', 5389, 1, 1296, '', 'C', '', 1, 1, 'Y', 'a3JUR07Vuug', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1326, '2013-08-18 10:55:52.192126+00', '2013-12-02 19:30:51.442624+00', 11370, 1, 1296, '', 'B', 'Nearly the whole dance is walked, not danced with  RSCDS steps.', 1, 1, 'Y', '6JukOWTb4a8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1327, '2013-08-18 10:55:52.464362+00', '2013-12-02 19:34:03.657401+00', 11370, 2, 1296, '', 'C', 'Youth group in Omsk', 1, 1, 'Y', 'RSjjjswVjeo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1292, '2013-08-18 10:55:44.685662+00', '2013-12-19 00:36:32.998875+00', 9011, 2, 1296, '', 'C', '', 1, 1, 'Y', '52ymLEDYrR8', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1341, '2013-08-18 10:55:55.524866+00', '2013-12-25 02:09:47.887227+00', 5637, 5, 1296, '', 'B', 'Once through; part of a longer display.', 1, 1, 'Y', 'IAkeKEYrB4Q', 146, 302, NULL);
INSERT INTO 'dancevideo' VALUES (1261, '2013-08-18 10:55:40.15208+00', '2013-12-25 02:28:11.492894+00', 4404, 4, 1296, '', 'A', '', 1, 1, 'Y', 'W-tG4ASvbP0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1260, '2013-08-18 10:55:40.108811+00', '2013-12-25 02:28:57.756089+00', 4404, 3, 1296, '', 'A', '', 1, 1, 'Y', 'RfxNHKKAMDA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1344, '2013-08-18 10:55:55.956419+00', '2013-12-26 00:50:42.607224+00', 5703, 2, 1296, '', 'C', 'The dancing improves as the dance goes on.', 1, 1, 'Y', 'Zsn9OrV4izw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1302, '2013-08-18 10:55:47.543248+00', '2013-12-26 01:15:01.341667+00', 5207, 2, 1296, '', 'A', '', 1, 1, 'Y', 'L3m7q_eu95E', 15, 269, NULL);
INSERT INTO 'dancevideo' VALUES (1301, '2013-08-18 10:55:47.316043+00', '2013-12-26 01:17:35.719747+00', 5198, 2, 1296, '', 'D', '', 1, 1, 'Y', 'Q9KuW4shEjI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1307, '2013-08-18 10:55:49.304106+00', '2013-12-26 01:28:25.14972+00', 5209, 10, 1296, '', 'C', '', 1, 1, 'Y', 'CUoj4oe1T5Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1305, '2013-08-18 10:55:49.197386+00', '2013-12-26 01:31:43.245267+00', 5209, 8, 1296, '', 'B', 'Once through only', 1, 1, 'Y', 'ZmfMRbUZlus', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1306, '2013-08-18 10:55:49.254079+00', '2013-12-26 01:33:46.690314+00', 5209, 9, 1296, '', 'B', '', 1, 1, 'Y', 'nmz49kwtB9E', 111, 375, NULL);
INSERT INTO 'dancevideo' VALUES (1271, '2013-08-18 10:55:41.810109+00', '2013-12-26 20:51:07.915533+00', 4565, 2, 1296, '', 'C', 'Once through; starts one bar late.', 1, 1, 'Y', 'A22E48eWtT0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1309, '2013-08-18 10:55:49.58718+00', '2013-12-26 21:26:26.397133+00', 5239, 4, 1296, '', 'C', '', 1, 1, 'Y', '-C_wmqCFr1A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1310, '2013-08-18 10:55:49.626861+00', '2013-12-26 21:24:15.246333+00', 5239, 5, 1296, '', 'C', '3 couples. Danced with minimal music, outside on a forest path.', 1, 1, 'Y', 'BSHT9bszIJg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1314, '2013-08-18 10:55:50.060515+00', '2013-12-28 01:16:28.965678+00', 5262, 3, 1296, '', 'C', '', 1, 1, 'Y', 'WSEWmloDLAs', 38, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1265, '2013-08-18 10:55:40.935023+00', '2013-12-29 01:59:03.240616+00', 4484, 3, 1296, '', 'D', '', 1, 1, 'Y', '3IqFqH1bkkk', 36, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1322, '2013-08-18 10:55:51.216022+00', '2013-12-29 02:32:59.461514+00', 5330, 10, 1296, '', 'C', '', 1, 1, 'Y', '3stc0bK-9xM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1321, '2013-08-18 10:55:50.947642+00', '2013-12-29 02:34:48.758214+00', 5330, 9, 1296, '', 'B', '', 1, 1, 'Y', 't6WLSoKqBhU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1277, '2013-08-18 10:55:42.620355+00', '2013-12-30 17:34:07.237859+00', 4646, 4, 1296, '', 'C', 'Once through only', 1, 1, 'Y', 'zvC95glbU3c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1278, '2013-08-18 10:55:42.642683+00', '2013-12-30 17:36:54.745796+00', 4646, 5, 1296, '', 'C', 'Class. Several sets', 1, 1, 'Y', 'YJEUyWnhRCU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1282, '2013-08-18 10:55:43.643297+00', '2013-12-30 17:42:08.174746+00', 4803, 3, 1296, '', 'C', 'once through only', 1, 1, 'Y', 'SI66U96ZSKE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1266, '2013-08-18 10:55:41.347705+00', '2013-12-30 21:12:54.212599+00', 9638, 5, 1296, '', 'B', '', 1, 1, 'Y', 'S_6xmqAc9RE', 615, 730, NULL);
INSERT INTO 'dancevideo' VALUES (1330, '2013-08-18 10:55:53.7354+00', '2013-12-30 21:43:21.861583+00', 12680, 3, 1296, '', 'B', '', 1, 1, 'Y', 'UVcyL0xP6t8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1346, '2013-08-18 10:55:56.143777+00', '2013-12-29 00:42:08.800113+00', 5713, 2, 1296, '', 'D', '', 1, 1, 'Y', 'p1teab9z7bE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1365, '2013-08-18 10:55:59.265006+00', '2014-08-18 05:37:20.984341+00', 6204, 1, 1296, '', 'X', '', 1, 1, 'Y', 'rp28GmRRmwE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1412, '2013-08-18 10:56:08.484956+00', '2013-12-29 13:58:33.458831+00', 7204, 3, 1296, '', 'A', '', 1, 1, 'Y', 'M7oJViZq7_o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1413, '2013-08-18 10:56:08.602891+00', '2014-08-18 05:41:01.08671+00', 10171, 1, 1296, '', 'B', '', 1, 1, 'Y', '09Wvz_Tddy8', 64, 177, NULL);
INSERT INTO 'dancevideo' VALUES (1349, '2013-08-18 10:55:56.496447+00', '2013-11-15 09:21:21.966447+00', 9110, 4, 1296, '', 'Z', '', 1, 1, 'Y', 'JrsBi3vgDmo', 0, 38, NULL);
INSERT INTO 'dancevideo' VALUES (1060, '2013-08-18 10:47:50.146775+00', '2013-08-29 00:25:09.435099+00', 7284, 2, 1296, '', 'D', 'Good view slanting down, at bottom, but alas the camera pans between the two sets.', 1, 1, 'Y', 'ufyZy-vwSR8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1329, '2013-08-18 10:55:53.265576+00', '2021-03-12 14:41:51.470044+00', 11894, 1, 1296, '', 'A', '', 1, 1, 'Y', 'lubASmlrQpU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1415, '2013-08-26 08:58:29.949066+00', '2013-11-08 00:43:26.597158+00', 15097, 1, 106, '', 'D', 'This video starts with a long explanation by Ian Brockbank, and the full teaching of the dance to the hall.  The  actual dance starts at 3:32 (212 seconds).', 1, 1, 'Y', 'axYtfnpAG_I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1010, '2013-08-18 00:51:37.367056+00', '2013-08-28 21:08:53.954143+00', 314, 6, 1296, '', 'A', 'Old recording (1991); music quality rather poor. View from the side. Twice through.', 1, 1, 'Y', 'NBv11jA1WiE', 135, 385, NULL);
INSERT INTO 'dancevideo' VALUES (1406, '2013-08-18 10:56:07.666112+00', '2013-09-24 23:41:36.358636+00', 7111, 2, 1296, '', 'C', '', 1, 1, 'Y', '_R3OEHxHBqk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1405, '2013-08-18 10:56:07.519657+00', '2013-09-24 23:44:05.373333+00', 7111, 1, 1296, '', 'C', '', 1, 1, 'Y', 'rPtfkrjAuNs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1380, '2013-08-18 10:56:03.143636+00', '2013-09-25 09:12:36.416981+00', 6712, 3, 1296, '', 'B', 'Four times through. First 6 bars missing.', 1, 1, 'Y', 'fgfJzlHlVX8', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1381, '2013-08-18 10:56:03.211542+00', '2013-09-25 09:16:04.126973+00', 6712, 4, 1296, '', 'Z', 'This is German folk dance, not SCD. The dance and some of the music is identical to SCD, but the steps are different.', 1, 1, 'Y', 'R9bGgzxDlJg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1377, '2013-08-18 10:56:02.587186+00', '2014-10-19 14:53:40.115403+00', 3252, 3, 1296, '', 'C', '', 1, 1, 'Y', '-uO21nFi0XI', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1356, '2013-08-18 10:55:57.802846+00', '2013-10-15 19:45:58.751139+00', 5904, 4, 1296, '', 'Z', 'IncompleteOnce through only, ant that incomplete, from bar 7 to 32', 1, 1, 'Y', '8rzhTqzsehs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1409, '2013-08-18 10:56:07.953477+00', '2013-10-15 20:19:29.998674+00', 7147, 6, 1296, '', 'C', 'View of ballroom from above, clear impression of the dance despite some errors.', 1, 1, 'Y', '3_YvTnKAwSM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1408, '2013-08-18 10:56:07.930947+00', '2013-10-15 20:21:55.617284+00', 7147, 5, 1296, '', 'D', 'In "Lawson Pub". Poor lighting.  Hard to follow.', 1, 1, 'Y', 'f06I06RJSzY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1386, '2013-08-18 10:56:03.849679+00', '2013-10-15 21:14:53.802123+00', 6748, 2, 1296, '', 'C', 'Open air demo. View from below the set', 1, 1, 'Y', '-TzE8ApUv60', 0, 108, NULL);
INSERT INTO 'dancevideo' VALUES (1366, '2013-08-18 10:55:59.512946+00', '2013-10-24 23:47:14.095576+00', 11891, 1, 1296, '', 'B', '', 1, 1, 'Y', '01rpCR2e0Jk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1392, '2013-08-18 10:56:04.483771+00', '2013-10-24 23:47:45.283157+00', 9533, 1, 1296, '', 'B', '', 1, 1, 'Y', 'R1B98wBLL-g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1368, '2013-08-18 10:56:00.392951+00', '2013-11-18 03:08:53.561956+00', 6380, 1, 1296, '', 'A', 'Once through', 1, 1, 'Y', 'NBv11jA1WiE', 0, 110, NULL);
INSERT INTO 'dancevideo' VALUES (1395, '2013-08-18 10:56:05.441346+00', '2013-11-18 20:16:14.217036+00', 6919, 1, 1296, '', 'C', 'First two bars missing. ', 1, 1, 'Y', '8LSAjOHa6-U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1354, '2013-08-18 10:55:57.355373+00', '2013-11-18 20:21:35.178372+00', 5889, 1, 1296, '', 'C', '', 1, 1, 'Y', 'zCSPrP5XH7o', 59, 336, NULL);
INSERT INTO 'dancevideo' VALUES (1393, '2013-08-18 10:56:04.832528+00', '2013-11-18 20:39:00.943598+00', 6860, 1, 1296, '', 'D', '', 1, 1, 'Y', '2N1puP2Qnzg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1402, '2013-08-18 10:56:06.36397+00', '2013-11-18 20:45:23.732529+00', 11629, 1, 1296, '', 'C', '', 1, 1, 'Y', 'OTLWHAEEYvs', 70, 367, NULL);
INSERT INTO 'dancevideo' VALUES (1398, '2013-08-18 10:56:05.857709+00', '2013-11-24 05:19:55.644151+00', 6957, 2, 1296, '', 'C', '', 1, 1, 'Y', 'UvulobdVBps', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1410, '2013-08-18 10:56:08.049735+00', '2013-12-01 08:29:06.601963+00', 7152, 2, 1296, '', 'B', 'Twice through.  End bars of second time through modified for joining to the next dance in the longer display', 1, 1, 'Y', 'osTJXCWRJQw', 20, 94, NULL);
INSERT INTO 'dancevideo' VALUES (1375, '2013-08-18 10:56:02.206426+00', '2013-12-13 16:56:36.71038+00', 6629, 1, 1296, '', 'A', '', 1, 1, 'Y', 'RU3oTnXatBA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1376, '2013-08-18 10:56:02.468968+00', '2013-12-17 20:54:16.063575+00', 3252, 2, 1296, '', 'D', '', 1, 1, 'Y', 'lTVSLh7_xKQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1350, '2013-08-18 10:55:56.852291+00', '2013-12-25 02:21:50.264789+00', 11369, 2, 1296, '', 'A', '', 1, 1, 'Y', 'gdpc6oz-8WE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1384, '2013-08-18 10:56:03.503091+00', '2013-12-25 02:32:17.980173+00', 13316, 3, 1296, '', 'A', '', 1, 1, 'Y', 'yRQzUTgH02M', 46, 170, NULL);
INSERT INTO 'dancevideo' VALUES (1359, '2013-08-18 10:55:58.443878+00', '2013-12-28 01:42:02.307977+00', 6048, 4, 1296, '', 'D', '', 1, 1, 'Y', 'cZYS42rZRFw', 29, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1400, '2013-08-18 10:56:06.063239+00', '2013-12-25 23:59:31.546107+00', 6972, 2, 1296, '', 'A', '', 1, 1, 'Y', 'TQGNGQ-hJOk', 239, 309, NULL);
INSERT INTO 'dancevideo' VALUES (1390, '2013-08-18 10:56:04.279677+00', '2013-12-26 00:28:02.684038+00', 6791, 2, 1296, '', 'B', '', 1, 1, 'Y', '-qCk6egivwE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1391, '2013-08-18 10:56:04.31987+00', '2013-12-26 00:30:13.098303+00', 6791, 3, 1296, '', 'C', '', 1, 1, 'Y', '-8ezduuyR1Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1387, '2013-08-18 10:56:04.018653+00', '2013-12-26 00:36:11.912131+00', 6756, 2, 1296, '', 'C', '', 1, 1, 'Y', 'rOO6QZb_gW0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1371, '2013-08-18 10:56:01.090351+00', '2013-12-26 00:41:47.228037+00', 6420, 2, 1296, '', 'C', 'Once through only', 1, 1, 'Y', 'j1D8KBECTNo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1367, '2013-08-18 10:55:59.896424+00', '2013-12-26 00:46:18.754274+00', 13615, 2, 1296, '', 'D', 'Once through only; late start', 1, 1, 'Y', 'uE-btXdXqAc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1353, '2013-08-18 10:55:57.237287+00', '2013-12-26 20:00:27.940841+00', 10381, 2, 1296, '', 'B', '', 1, 1, 'Y', 'l2lORf3p9jo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1360, '2013-08-18 10:55:58.466597+00', '2013-12-28 01:50:20.221542+00', 6048, 5, 1296, '', 'C', '', 1, 1, 'Y', 'AtoVxTVQC-o', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1361, '2013-08-18 10:55:58.512928+00', '2013-12-28 01:47:45.591247+00', 6048, 6, 1296, '', 'B', 'Danced 4 times through in a 4C set; at the end of their turn each dancing couple casts off to 4th place.', 1, 1, 'Y', 'FQ9NUurSUg4', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1362, '2013-08-18 10:55:58.533794+00', '2013-12-28 02:18:23.061224+00', 6048, 7, 1296, '', 'Z', 'Starts 2 bars late, just once through. Not worth keeping.', 1, 1, 'Y', 'QAAKj1EqTU0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1358, '2013-08-18 10:55:58.414264+00', '2013-12-28 02:23:02.103007+00', 6048, 3, 1296, '', 'C', 'Four times through; dancing couple cast to 4th place when thier turnends. Some serious errors.', 1, 1, 'Y', 'GRTkmxPvHu8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1404, '2013-08-18 10:56:06.622644+00', '2013-12-29 02:05:00.540706+00', 13730, 3, 1296, '', 'B', '', 1, 1, 'Y', '2G3JyAzWu7g', 0, 79, NULL);
INSERT INTO 'dancevideo' VALUES (1363, '2013-08-18 10:55:58.735341+00', '2013-12-29 02:39:37.213442+00', 6091, 3, 1296, '', 'C', '', 1, 1, 'Y', '5FEEo69tYvk', 225, 353, NULL);
INSERT INTO 'dancevideo' VALUES (1394, '2013-08-18 10:56:05.098836+00', '2013-12-30 17:48:54.401751+00', 6915, 3, 1296, '', 'C', '', 1, 1, 'Y', '0rDbZgEQoqw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1351, '2013-08-18 10:55:57.022298+00', '2013-12-30 17:23:29.863325+00', 5794, 4, 1296, '', 'C', 'Once through only', 1, 1, 'Y', 'Ij784mEtTnY', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1357, '2013-08-18 10:55:57.921796+00', '2013-12-30 21:40:55.42081+00', 5915, 4, 1296, '', 'B', '', 1, 1, 'Y', 'ZGFJljSWMh4', 25, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1411, '2013-08-18 10:56:08.242127+00', '2013-12-30 17:53:45.57425+00', 7180, 5, 1296, '', 'C', 'Hard to follow: Poor lighting, low viewpoint. ', 1, 1, 'Y', 'ba8673XmlTo', 58, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1168, '2013-08-18 10:55:21.919802+00', '2013-08-28 23:01:44.901524+00', 2604, 3, 1296, '', 'C', 'Good viw from slightly above, two sets, 8 times through', 1, 1, 'Y', 'grTbtHgXMIU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1177, '2013-08-18 10:55:23.729431+00', '2013-08-28 23:16:16.106975+00', 2846, 2, 1296, '', 'B', 'Low view, but easy to follow. ', 1, 1, 'Y', 'k45aSqAcYP0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3566, '2018-06-06 14:28:35.183653+00', '2018-06-06 14:36:13.561633+00', 10376, 4, 2824, '', 'A', '4 times through.

Newcastle Festival 2018, Newcastle RSCDS team', 1, 1, 'Y', '7sj1DTtIMqw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3558, '2018-06-06 14:06:02.994618+00', '2018-06-06 14:36:54.150877+00', 3108, 4, 2824, '', 'A', '4 times through.

Newcastle Festival 2018, Ladies Glasgow Youth team', 1, 1, 'Y', 'n55rI4l_7S0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1399, '2013-08-18 10:56:05.948891+00', '2019-02-01 00:26:07.049488+00', 6959, 1, 1296, '', 'D', 'This is a ceilidh dance, described in text inserted into the video.  As the camera battery died, only part of the dance was recorded.  The beginning of the dance is much like a "Grand March", later followed by "over and under".  This video seems unrelated to the dance "Waves of Tory" entered on SCDDB.



', 1, 1, 'Y', 'UT8xRaxB-Fg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1385, '2013-08-18 10:56:03.600645+00', '2018-10-02 08:58:06.810836+00', 6734, 3, 1296, '', 'X', '', 1, 1, 'Y', 'OpxikbJykw4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (1369, '2013-08-18 10:56:00.546288+00', '2019-01-14 17:16:36.873703+00', 6384, 1, 1296, '', 'B', 'The video starts around bar 9 of the dance.', 1, 1, 'Y', 't-U0Gry_otk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1019, '2013-08-18 00:51:48.195322+00', '2013-08-28 23:53:41.101306+00', 413, 5, 1296, '', 'Z', 'REJECTED. Only bars 9 to about 20; mediocre dancing', 1, 1, 'Y', '3sKliirWrGg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1106, '2013-08-18 10:47:57.158886+00', '2013-09-20 00:41:28.279346+00', 1641, 1, 1296, '', 'B', 'Danced well, but dressed not in "scottish" style but in "old style dance".', 1, 1, 'Y', '83yX_cTsp_Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1085, '2013-08-18 10:47:53.838302+00', '2013-09-20 01:05:10.011953+00', 1348, 5, 1296, '', 'C', 'Excellent dancing, but most of this demo uses two 2C sets joined at the bottoms, and dancing in mirror image to each other. The "down the middle and up" is modified by adding a RHA. That makes the video unsuited for learning the dance.', 1, 1, 'Y', 't5YaWPrI044', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1020, '2013-08-18 00:51:49.35288+00', '2013-08-28 23:55:32.135153+00', 413, 6, 1296, '', 'Z', 'REJECTED.  Bars 33-64 only; mediocre dancing.', 1, 1, 'Y', 'zvu64Fc4mnk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1045, '2013-08-18 00:52:23.363665+00', '2013-08-29 00:07:09.996898+00', 769, 3, 1296, '', 'D', 'Low view from the bottom; difficult to see the movements. Some errors.', 1, 1, 'Y', 'uYWsZWt1gK8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1055, '2013-08-18 10:47:49.149436+00', '2013-08-29 00:18:15.754065+00', 887, 4, 1296, '', 'D', 'Camera at sporran level, viewing set from quite far. Difficult to see the formations unless you know them.', 1, 1, 'Y', '467J7OwQqOk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1064, '2013-08-18 10:47:50.759613+00', '2013-08-29 00:48:56.459224+00', 1087, 6, 1296, '', 'C', 'Once only. Camera at sporran level, looking down the set.', 1, 1, 'Y', 'SA9fXP1Uo2Q', 76, 117, NULL);
INSERT INTO 'dancevideo' VALUES (1419, '2013-08-31 16:39:53.375213+00', '2013-08-31 19:31:17.079402+00', 10563, 1, 1111, '', 'C', 'Good viewpoint of the hall from oblique above, but seen from far off, showing several sets at a time; stays on one set each time through. Good for following the whole dance.  Good dancing, except for a few mistakes. No source given.', 1, 1, 'Y', 'J5nSeQC1fHQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (995, '2013-08-18 00:51:15.329883+00', '2013-09-20 15:01:56.649946+00', 11543, 1, 1296, '', 'D', 'Good slanting view from above on a hall of many sets, dancing rather chaotically.  It is hard to recognize the dance.', 1, 1, 'Y', 'UmZYqNuicZ4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1420, '2013-09-06 07:31:20.155663+00', '2013-09-07 14:07:26.386739+00', 498, 1, 274, '', 'D', 'Scottish Dance House for beginners, Budapest, 2010



The video is in error.  The Promenade is danced for bars 25-28, the Grand Chain for 29-32.  The Promenade should be from 25-32, the Grand Chain from 33-40.



Also, on 13-16 the Women should dance Left Shoulder round the Man and out, not dance backwards.', 1, 1, 'Y', 'YVOkPoe5oi8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1077, '2013-08-18 10:47:52.602561+00', '2013-09-21 19:47:17.688032+00', 1260, 1, 1296, '', 'A', 'Dancer dressed and dancing in "old style". 3C set, 3 times through.', 1, 1, 'Y', 'dnU_HJSl3i0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1002, '2013-08-18 00:51:25.532721+00', '2013-09-20 17:40:43.163739+00', 9711, 1, 1296, '', 'D', 'Dancers clothed in "Old Style".  Camera position and coverage very erratic, often showing only a small part of the 8C set. It is impossible to really follow the dance. The set deviates from the instructions on bar 5-6 and 13-14 by making lines across. Danced twice through, with the third time finishing in a muddled way.', 1, 1, 'Y', 'BIQjcHqL43A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1421, '2013-09-10 23:12:14.19133+00', '2013-09-13 22:54:55.138128+00', 15098, 1, 106, '', 'B', 'First video ever, 9 sept 2013, taken by the deviser in his local class', 1, 1, 'Y', 'rN_hcInneBs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1424, '2013-09-14 20:06:16.749044+00', '2013-09-15 00:32:36.517307+00', 4618, 1, 1041, '', 'B', '', 1, 1, 'Y', 'xPQ-zZa5DoE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1425, '2013-09-14 20:23:03.921412+00', '2013-09-15 06:38:54.557173+00', 14974, 1, 1041, '', 'A', '', 1, 1, 'Y', 'enAoyDt2mLY', 56, 0, NULL);
INSERT INTO 'dancevideo' VALUES (252, '2012-09-12 20:38:36.055624+00', '2013-09-15 23:05:15.323666+00', 3172, 2, 1041, '', 'B', 'Three-couple set; progression modified to (2,3,1) so it can be danced 3 times though', 1, 1, 'Y', 'u6cmyo_QB4g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1008, '2013-08-18 00:51:34.787927+00', '2013-09-20 22:12:20.107572+00', 11376, 1, 1296, '', 'B', 'All girl set. Video distorted in shape (narrowed, making the girls unnaturally slim). Well danced, but as one cannot see the difference between M and W it is hard to follow some aprts of the figures.', 1, 1, 'Y', 'QmrOC7m0imU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1011, '2013-08-18 00:51:38.619331+00', '2013-09-20 22:38:45.06283+00', 329, 1, 1296, '', 'C', 'Rehearsal of a children+adult dem team. Several errors, easy to follow.', 1, 1, 'Y', 'zEitvOUHyKE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1024, '2013-08-18 00:51:54.617103+00', '2013-09-20 22:57:22.498979+00', 441, 2, 1296, '', 'B', 'Video distorted (narrowed) giving unnatural proportions. Good dancing by a local non-demo group.', 1, 1, 'Y', 'tQOTn8hTREc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1026, '2013-08-18 00:51:57.187638+00', '2013-09-20 23:14:36.260727+00', 9022, 1, 1296, '', 'D', 'Video distorted (narrowed). Social class. Reasonable dancing, but it is a bit hard to follow the figures as the video is taken from knee height. ', 1, 1, 'Y', '-liR2aO6d_o', 123, 255, NULL);
INSERT INTO 'dancevideo' VALUES (1105, '2013-08-18 10:47:56.997555+00', '2013-09-21 19:37:23.815883+00', 9404, 1, 1296, '', 'D', 'Camera not steady on one set; quite some errors. Poorly suited for learning hte dance.', 1, 1, 'Y', 'y6U-WE3-HQo', 13, 0, NULL);
INSERT INTO 'dancevideo' VALUES (290, '2012-10-14 10:06:38.879287+00', '2013-09-22 19:19:59.968107+00', 14484, 1, 274, '', 'A', 'Scottish dance, hungarian music :-)  One error of shoulder (very well resolved) on last time through before the break.', 1, 1, 'Y', 'PQKk9cFPkZA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1426, '2013-09-24 15:26:56.936906+00', '2013-09-24 23:29:49.781453+00', 14484, 3, 274, '', 'B', '', 1, 1, 'Y', 'uuT-HZSefD8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1423, '2013-09-13 09:01:50.09467+00', '2013-09-24 23:35:57.535709+00', 3435, 4, 274, '', 'D', 'Scottish Dance House for beginners, Budapest, 2013

', 1, 1, 'Y', 'OelnOwxGIQ4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1422, '2013-09-13 08:56:15.871913+00', '2013-09-24 23:38:32.956992+00', 2924, 3, 274, '', 'D', 'Scottish Dance House for beginners, Budapest, 2103', 1, 1, 'Y', 'Plpjz2H8TYg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1427, '2013-09-25 08:44:51.606957+00', '2013-09-25 08:46:55.163745+00', 15148, 1, 106, '', 'B', 'Only once through', 1, 1, 'Y', 'kjhIGhPeoDE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1479, '2013-11-27 07:02:54.101928+00', '2013-11-27 07:06:00.040274+00', 15269, 1, 106, '', 'B', '', 1, 1, 'Y', 'KadV59GkJmE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1483, '2013-11-27 13:43:46.819796+00', '2013-11-27 13:45:56.787649+00', 15268, 2, 513, '', 'C', '', 1, 1, 'Y', 'pYUNjaST1_A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1429, '2013-09-25 09:54:17.422923+00', '2013-09-25 10:19:07.670814+00', 5529, 10, 274, '', 'B', 'St. Andrew''s Day Ceilidh, Budapest, 2012

Performed by the Budapest Scottish Dance Club

Three couple set. 1C & 3C change places on [31-32].

', 1, 1, 'Y', '9ZDUBdZz8lg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1416, '2013-08-30 13:27:00.598553+00', '2013-11-24 02:05:38.196023+00', 314, 7, 1022, '', 'A', '', 1, 1, 'Y', 'QGA_nTGhHwo', 0, 256, NULL);
INSERT INTO 'dancevideo' VALUES (1247, '2013-08-18 10:55:37.792147+00', '2014-07-29 14:54:45.76467+00', 4102, 5, 1296, '', 'B', 'Side view to stage. Twice through. FIrst couple passes RSh in the middle ("Mairi''s Divorce").', 1, 1, 'Y', 'LR7Pr6etqAs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1094, '2013-08-18 10:47:55.295652+00', '2014-08-25 21:31:07.432703+00', 1479, 2, 1296, '', 'Z', 'This video shows the ECD version, in a social setting, with deviations from the ECD instructions, and no hint of any SCD style or steps.  Eric Ferguson, 2013-09-13', 1, 1, 'Y', '_Qvg1GwwcyA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1435, '2013-10-04 21:52:57.947194+00', '2013-10-04 21:56:20.024678+00', 2822, 3, 106, '', 'C', 'On the video, the dance is incorrectly named "St.Andrews of Brampton.", but it is really "The Hazel Tree".', 1, 1, 'Y', 'P-YpF5H1AN0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1175, '2013-08-18 10:55:23.501385+00', '2013-10-04 21:59:14.791545+00', 2822, 2, 1296, '', 'D', 'Low point of view; following the formations is very difficult.', 1, 1, 'Y', 'T1F8V7ZyF5c', 225, 484, NULL);
INSERT INTO 'dancevideo' VALUES (1436, '2013-10-05 22:21:24.740069+00', '2013-10-05 22:25:55.423294+00', 9158, 1, 274, '', 'C', 'Scottish Dance House for Beginners, Budapest, 2013', 1, 1, 'Y', 'ThglquP9HRM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1437, '2013-10-05 22:36:41.471316+00', '2013-10-05 23:38:10.414991+00', 498, 2, 274, '', 'C', 'Scottish Dance House for beginners, Budapest, 2013



One mistake: on bar 13-16 the Women should dance Left Shoulder round the Man and out, not dance backwards :-(', 1, 1, 'Y', '11upTBKPQh0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3503, '2018-04-09 20:17:56.95124+00', '2018-04-09 23:20:30.609222+00', 9711, 4, 14113, '', 'B', 'Mistake at the end: 1st couple should turn both hands moving down, but here they turn right hand and then move down.', 1, 1, 'Y', 'WGWamPKxvIA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3572, '2018-06-11 22:18:03.893364+00', '2018-06-11 22:24:18.791333+00', 18368, 1, 1645, '', 'A', '', 1, 1, 'Y', 'GO1GCm_iYek', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3583, '2018-06-30 10:18:29.174417+00', '2018-06-30 19:52:04.482696+00', 14393, 3, 513, '', 'C', '', 1, 1, 'Y', '6otwoZioA3o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1491, '2013-12-03 15:32:22.966803+00', '2013-12-05 23:42:57.529977+00', 15271, 1, 513, '', 'C', '', 1, 1, 'Y', '9klo6mcgsNo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (998, '2013-08-18 00:51:18.968161+00', '2013-10-06 20:02:27.837117+00', 9631, 2, 1296, '', 'C', 'Horizontal view, figures not so easy to follow. Danced in a 4C set, but each time the new top starts, the old 1c moving to the bottom.', 1, 1, 'Y', 'w8JOnQFFvnw', 35, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1071, '2013-08-18 10:47:51.728856+00', '2013-10-06 23:46:17.825824+00', 14371, 2, 1296, '', 'D', 'The dance is taught in the preceding part of the video', 1, 1, 'Y', 'P-C_uFi2lc4', 2316, 2430, NULL);
INSERT INTO 'dancevideo' VALUES (1317, '2013-08-18 10:55:50.302172+00', '2013-10-15 21:03:51.166228+00', 11189, 9, 1296, '', 'D', '', 1, 1, 'Y', 'LW9o22-H7Eg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1171, '2013-08-18 10:55:22.367936+00', '2013-10-13 23:58:14.193085+00', 13621, 1, 1296, '', 'C', 'Demo at a fair. Poor point of view (too low), imprecise dancing. Just usable to learn the dance.', 1, 1, 'Y', 'QtrwkCGy5y4', 2489, 2645, NULL);
INSERT INTO 'dancevideo' VALUES (1432, '2013-10-03 06:22:39.201548+00', '2013-10-08 23:03:05.002728+00', 2820, 1, 513, '', 'A', 'RSCDS demo; once through only', 1, 1, 'Y', '_CsrFi2KdLQ', 0, 48, NULL);
INSERT INTO 'dancevideo' VALUES (1047, '2013-08-18 00:52:25.739788+00', '2013-10-08 23:18:48.596303+00', 10650, 1, 1296, '', 'D', 'The first half of the video mostly shows the band only, at the end some full turns through are shown, but hatrd to follow as the cameera pands around.', 1, 1, 'Y', 'T1F8V7ZyF5c', 829, 1006, NULL);
INSERT INTO 'dancevideo' VALUES (987, '2013-08-15 01:24:33.39846+00', '2013-10-09 12:59:21.01057+00', 975, 1, 985, '', 'A', 'Campbell of Duntroon - Canberra Scottish Country Dancers 2013', 1, 1, 'Y', 'lvcxDgCJXzk', 15, 159, NULL);
INSERT INTO 'dancevideo' VALUES (1679, '2014-06-03 22:59:39.746879+00', '2014-06-04 00:17:33.14216+00', 14527, 1, 1777, '', 'B', '', 1, 1, 'Y', 'Dvy2tvj_ng4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1231, '2013-08-18 10:55:35.6398+00', '2013-10-11 22:15:41.995934+00', 11284, 2, 1296, '', 'C', 'Twice through, with 1C moving to 3rd place on start of second turn.  Good dancing, but poor viewpoint, and the video is distorted (narrowed) making it look unnatural. Much background noise.', 1, 1, 'Y', '4BnkXp8xArc', 100, 225, NULL);
INSERT INTO 'dancevideo' VALUES (1328, '2013-08-18 10:55:52.903871+00', '2013-10-11 22:25:04.355811+00', 5497, 4, 1296, '', 'C', 'Three times through, with 1C moving to 3rd place on start of next turn. Good dancing, but poor viewpoint, and the video is distorted (narrowed) making it look unnatural. Much background noise.', 1, 1, 'Y', '4BnkXp8xArc', 225, 357, NULL);
INSERT INTO 'dancevideo' VALUES (1333, '2013-08-18 10:55:54.347939+00', '2013-10-15 22:31:35.015279+00', 5525, 10, 1296, '', 'C', 'Clear view from obove, figures easy to follow, but some dancers mainly walk', 1, 1, 'Y', '4sZ-S1HAjUY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1067, '2013-08-18 10:47:50.961698+00', '2013-10-13 22:47:33.695446+00', 1100, 2, 1296, '', 'D', 'Demo, danced in a 3C set. Poor viewpoint (too low). Systematic errors: 1M starts Lsh to 2cnr in the Figure of 8 and 1c makes a LH turn to face 1cnrs; at the end 1c makes RH turn to side instead of Petronella).  Not suitable for learning the dance.', 1, 1, 'Y', 'YKT3MX8iWo0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1066, '2013-08-18 10:47:50.902767+00', '2013-10-13 22:55:47.550766+00', 1100, 1, 1296, '', 'D', 'Open air demo on grass, in a 4C set.  Reasonable point of view. Systematic formation errors: in the figure of 8 1M starts Lsh to 2cnr.  The 1c meet below 3c, and do the "hello-goodbye" setting with 3c (moved up to 2pl) and 4c, and step to 4pl (4c up) after their turn. At the end 1c turns RH instead of dancing a petronella to the sidelines.  Unsuitable for learning the dance.', 1, 1, 'Y', 'dyZwNvgU4ZQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1442, '2013-10-14 15:20:37.320129+00', '2013-10-14 19:01:22.999025+00', 10787, 2, 1022, '', 'B', 'Once through only. Good, energetic dancing. Clear view.', 1, 1, 'Y', 'Z404XKHs0wY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1249, '2013-08-18 10:55:37.847361+00', '2013-10-15 20:00:45.497577+00', 4102, 7, 1296, '', 'Z', 'Social and chaotic; very poor lighting and very low point of view, only part of set visible.  Impossible to identify the dance by viewing this. Unfitted for this website. Eric', 1, 1, 'Y', 'pMzhqQR2lnA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1117, '2013-08-18 10:47:58.770229+00', '2013-10-15 20:30:46.921542+00', 1782, 3, 1296, '', 'D', 'Camera is at waist height, and pans around; impossible to follow any set.', 1, 1, 'Y', '7WqjoUzcfk8', 14, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1284, '2013-08-18 10:55:43.822922+00', '2013-10-15 20:41:23.596843+00', 4805, 5, 1296, '', 'D', 'Leg height viewpoint. Danced in 3C set with change of places on 31-32 (unnecessary, can be done on 1-2) . Some figures hard to follow.', 1, 1, 'Y', '-8gGPgzkZ0o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1445, '2013-10-18 23:04:47.949087+00', '2013-10-18 23:08:32.44585+00', 6130, 1, 106, '', 'D', '', 1, 1, 'Y', 'eF0JqwVB9q0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (631, '2012-12-17 14:18:59.224398+00', '2013-10-15 20:49:31.630173+00', 4805, 3, 1296, '', 'C', 'Ballroom, breast-hight view. First set well shown, easy to follow.', 1, 1, 'Y', 'tURamO4jG5g', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1316, '2013-08-18 10:55:50.281513+00', '2013-10-15 20:53:41.447995+00', 11189, 8, 1296, '', 'B', 'Dem set, on a stage viewed from lower floor. Figures can be followed.', 1, 1, 'Y', 'iplppSRSjJk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (668, '2012-12-17 14:19:05.197383+00', '2013-10-15 21:03:02.686503+00', 11189, 4, 1296, '', 'B', 'End of a longer demo.  Final 4 bars modified to take positions for the next dance.', 1, 1, 'Y', 'qayV7yhBWgY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1446, '2013-10-21 08:48:40.460092+00', '2013-10-21 14:34:11.110358+00', 1624, 1, 513, '', 'C', '', 1, 1, 'Y', 'N6XuDYjmfLs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1389, '2013-08-18 10:56:04.146381+00', '2013-10-23 23:36:48.968549+00', 6763, 2, 1296, '', 'D', 'Good view from above, but shoddy dacning makes it hard to recognise the reels.', 1, 1, 'Y', 'SVtY95NjXTU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1388, '2013-08-18 10:56:04.124756+00', '2013-10-23 23:49:07.737302+00', 6763, 1, 1296, '', 'B', 'Good dancing, but incomplete, starting on bar 9, once through only. The difficult entry on [1-2] is missing.

Remove this video when a complete one is available', 1, 1, 'Y', 'q-Z-SjQttXE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1598, '2014-03-19 16:08:46.034333+00', '2014-03-19 16:13:55.068059+00', 327, 1, 106, '', 'B', '', 1, 1, 'Y', 'qe_4lV3KLVg', 148, 276, NULL);
INSERT INTO 'dancevideo' VALUES (1279, '2013-08-18 10:55:42.741991+00', '2013-10-24 00:21:50.459356+00', 4662, 2, 1296, '', 'B', 'Once through only.  Clear view. Bars 33-48 have a modified progression to rearrange the dancers for the following dance in the demonstration.', 1, 1, 'Y', 'P1ZPnb-aYp8', 213, 307, NULL);
INSERT INTO 'dancevideo' VALUES (570, '2012-12-17 14:18:38.285091+00', '2013-11-26 02:33:44.417988+00', 3588, 1, 1296, '', 'D', 'On Youtube, this video of Lady Auckland''s Reel was given the erroneous name "Lady Auckley''s Reel". This cannot be corrected by SCDDB.', 1, 1, 'Y', '-A1n3iQdYIo', 0, 127, NULL);
INSERT INTO 'dancevideo' VALUES (1474, '2013-11-26 13:13:38.371934+00', '2013-12-07 00:59:10.032287+00', 14432, 2, 513, '', 'B', 'Very good view of the dance.', 1, 1, 'Y', 'lUeQdD0GSlE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1485, '2013-11-27 20:26:22.458429+00', '2013-11-28 02:35:46.942228+00', 1066, 2, 106, '', 'B', '', 1, 1, 'Y', 'dStZDTMDKNE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1456, '2013-11-08 23:12:54.674289+00', '2013-11-08 23:17:14.18078+00', 3561, 1, 106, '', 'C', 'This video gives a general impression of "La Russe", but differs in several respects:



1.  On [1-16] turning the corners and partner is done with a birling turn instead of BH turn.



2.  For [17-32] either 1c+3c or 2c+4c dance; this should be one couple only.  The Poussette [25-32]is missing, replaced by biring turns for 8 bars placed in [17-24].



3.  Arches have been added for [33-48]



4.  The big wheel [57-64] has been replaced by a promenade cclw once round.

', 1, 1, 'Y', '8ZyX6WJbfbw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1131, '2013-08-18 10:48:01.180356+00', '2013-10-24 00:47:20.328865+00', 8146, 1, 1296, '', 'Z', 'This is ballroom dancing. The steps are not SCD or anywhere near. ', 1, 1, 'Y', 'MU5lyqLwsN4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1457, '2013-11-09 00:01:56.372044+00', '2013-11-09 11:12:10.724883+00', 9110, 5, 1022, '', 'A', '', 1, 1, 'Y', '2Ia3jkFDVS8', 0, 71, NULL);
INSERT INTO 'dancevideo' VALUES (1208, '2013-08-18 10:55:32.46679+00', '2013-10-24 21:16:19.685782+00', 3506, 1, 1296, '', 'D', 'Bit of a longer demo. Danced by 8 couples, in a star, once through, using the figures of this dance in a composite choreography with a different ending. It is hardy possible to reconstitute the original dance from this demo, but it looks nice.', 1, 1, 'Y', '2a_WjxCOlzg', 53, 99, NULL);
INSERT INTO 'dancevideo' VALUES (3454, '2018-03-03 12:35:14.228183+00', '2018-03-05 23:49:56.242686+00', 1125, 2, 1645, '', 'B', 'All goes well for the first two figures (Theme, Following) but the last two trickier figures (Eight and a Half, Marsh Marigold) have a few glitches.

', 1, 1, 'Y', 'qlGk6Wm3bEM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3505, '2018-04-12 21:27:55.918873+00', '2018-04-12 21:36:55.036989+00', 18046, 2, 1645, '', 'C', 'Filmed at the Geneva spring dance in March 2018 with music by Nicol McLaren and Isobelle Hodgson.', 1, 1, 'Y', 'VX6Ludf-aeU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1145, '2013-08-18 10:55:18.86995+00', '2013-12-02 19:14:41.390445+00', 2260, 2, 1296, '', 'D', 'Youth class.  Instead of returning to 2nd place, the dancing couples stops in 4pl on bar 24', 1, 1, 'Y', 'S765CEDqveE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2281, '2015-12-08 16:09:30.122543+00', '2018-05-28 22:05:11.222957+00', 1743, 1, 1041, '', 'B', 'Danced at the Clarke Memorial Hall, Port Credit, Ontario, Canada. during the 2014 Teacher Workshop led by Jimmy Hill.  Video published on 6 dec. 2015', 1, 1, 'Y', 'AuvCM-Ujir4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3573, '2018-06-12 15:47:28.527441+00', '2018-06-12 16:18:56.15568+00', 18380, 1, 6572, '', 'B', '', 1, 1, 'Y', 'wxEFdNfdBP0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1254, '2013-08-18 10:55:39.140513+00', '2013-10-24 23:46:04.291545+00', 11895, 1, 1296, '', 'B', '', 1, 1, 'Y', 'GKbuAhRm2Ms', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1372, '2013-08-18 10:56:01.215957+00', '2013-10-24 23:58:25.812095+00', 7282, 2, 1296, '', 'A', 'Once through, part of a bigger display.  Beginning and ending slightly adapted.', 1, 1, 'Y', 'WpzKnSXpGT4', 309, 346, NULL);
INSERT INTO 'dancevideo' VALUES (1448, '2013-10-28 12:52:59.447969+00', '2013-10-28 16:06:03.785727+00', 9836, 3, 513, '', 'C', 'Once through, in an advanced class.', 1, 1, 'Y', 'ltUl8WmEVFc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1449, '2013-10-28 12:54:29.022484+00', '2013-10-28 22:55:37.231391+00', 4927, 1, 513, '', 'C', '', 1, 1, 'Y', 'hpnw3dM1zW0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1252, '2013-08-18 10:55:38.623696+00', '2013-10-29 18:16:19.97341+00', 4209, 1, 1296, '', 'A', 'Once through, preceded by and followed by Culla Bay in the full clip.', 1, 1, 'Y', 'ZLZlzaoTj3U', 60, 120, NULL);
INSERT INTO 'dancevideo' VALUES (1295, '2013-08-18 10:55:45.29593+00', '2013-11-17 23:39:31.002452+00', 4931, 1, 1296, '', 'D', 'Busy floor seen from above.', 1, 1, 'Y', 'oh9mJn3PPYY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1450, '2013-10-30 19:08:00.188432+00', '2013-10-30 22:21:21.740663+00', 535, 1, 1719, '', 'C', '', 1, 1, 'Y', '-fCb97NXpEo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1170, '2013-08-18 10:55:22.147834+00', '2021-04-07 20:26:45.715168+00', 2632, 1, 1296, '', 'Z', 'Poor lighting; low view; poor resolution, well danced.



Now marked private in youtube. Left as blocked in case it ever gets made public again.', 1, 1, 'Y', 'upR99JiTFQQ', 0, 118, NULL);
INSERT INTO 'dancevideo' VALUES (1451, '2013-11-02 07:50:41.997026+00', '2013-11-02 22:39:31.495403+00', 5493, 1, 513, '', 'C', 'The 1st few bars of the Begiing are missing.', 1, 1, 'Y', 'twgsvR0qz2g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1101, '2013-08-18 10:47:56.455029+00', '2014-03-08 17:53:29.183777+00', 8514, 1, 1296, '', 'B', '4 times through in a 4C set, top couple starting each time.', 1, 1, 'Y', '2d9SQPe7w6U', 9, 178, NULL);
INSERT INTO 'dancevideo' VALUES (1459, '2013-11-10 08:47:40.97696+00', '2013-11-10 13:09:25.085699+00', 10463, 2, 513, '', 'D', 'After first time through the dance is continued in darkness, using fluorescent arm bands (Halloween dance event).', 1, 1, 'Y', 'F-wIyXhpfuA', 18, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1458, '2013-11-10 08:44:05.278017+00', '2013-11-10 18:36:52.530737+00', 15056, 1, 513, '', 'D', '', 1, 1, 'Y', '237s919oe1w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1197, '2013-08-18 10:55:28.916395+00', '2013-11-10 21:09:18.696678+00', 3119, 2, 1296, '', 'A', 'Once through only, in Reel time. Part of a longer demo.  On [29-32] this set dances clw chase 3/4 round instead of Circle L 3/4.  The side couples drop away as the next time round starts, the reels mutating into a starting position for the next dance of the demo (Trip to Lorient).', 1, 1, 'Y', 'yRQzUTgH02M', 0, 47, NULL);
INSERT INTO 'dancevideo' VALUES (3504, '2018-04-12 21:25:10.437965+00', '2018-04-12 21:41:08.289598+00', 17918, 2, 1645, '', 'C', 'Filmed at the Geneva spring dance in March 2018 with music by Nicol McLaren and Isobelle Hodgson.

The video starts about 8 bars into the dance.', 1, 1, 'Y', '3EgMvTwsffE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1462, '2013-11-10 15:49:08.240794+00', '2013-11-10 21:31:41.529335+00', 5921, 1, 274, '', 'D', 'Scottish Dance House for beginners, Budapest, november 2013', 1, 1, 'Y', 'tlPD4xsmdZ8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1460, '2013-11-10 15:39:02.471094+00', '2013-11-10 21:40:17.791874+00', 498, 3, 274, '', 'D', 'Scottish Dance House for beginners, Budapest, november 2013', 1, 1, 'Y', '-eFjUdaoI0o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1463, '2013-11-18 00:32:43.082378+00', '2013-11-18 00:57:02.237352+00', 13589, 3, 106, '', 'C', 'This is a detailed video of teaching this dance to a class. It is NOT danced though completely.', 1, 1, 'Y', 'SvanOnk72yc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1379, '2013-08-18 10:56:02.875001+00', '2013-11-18 15:14:17.914613+00', 6687, 1, 1296, '', 'C', 'Well done for beginners level', 1, 1, 'Y', 'bjxNQJSyAMw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1454, '2013-11-06 12:59:48.201259+00', '2013-11-18 15:02:43.986849+00', 5065, 1, 1041, '', 'D', 'The camera often drifts off to the orchestra, only a few times can one see the whole dance once through. ', 1, 1, 'Y', 'wNJMANW8jvE', 40, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1452, '2013-11-03 08:12:32.552352+00', '2013-11-18 15:09:22.112268+00', 2585, 1, 513, '', 'C', 'Big hall, no clear focus on a good set. ', 1, 1, 'Y', '7zLjmTGabLM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1340, '2013-08-18 10:55:55.395696+00', '2013-11-18 15:19:06.446587+00', 5623, 1, 1296, '', 'D', 'Good video view, but the dancers make many mistakes; the last time through is best.', 1, 1, 'Y', 'K8zs0i7qvDo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1396, '2013-08-18 10:56:05.56794+00', '2013-11-18 21:57:00.463555+00', 8203, 1, 1296, '', 'Z', 'Does not show even once through; starts on bar 25 and ends next round on bar 23. Useless', 1, 1, 'Y', 'nO3svdeTHLg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1251, '2013-08-18 10:55:38.289905+00', '2013-11-18 22:08:31.051195+00', 9834, 1, 1296, '', 'D', 'several times through, very muddled.  At 1:32 the camera shifts to top set which dances much better. ', 1, 1, 'Y', 'P8XA3tWMgyk', 36, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1465, '2013-11-18 22:21:55.590894+00', '2013-11-18 22:32:16.450571+00', 5260, 2, 106, '', 'B', 'The same demo as in the other video, but from a better camera position.', 1, 1, 'Y', 'HVvmUTIdaJo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1312, '2013-08-18 10:55:49.845044+00', '2013-11-18 22:33:45.033965+00', 5260, 1, 1296, '', 'B', 'The other video of this same demonstration has a better camera position', 1, 1, 'Y', 'E7sYs6l9Ebs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1464, '2013-11-18 16:58:43.71248+00', '2013-11-18 23:32:49.330347+00', 13768, 1, 82, '', 'B', '', 1, 1, 'Y', 'V4qkoFkMnG0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1467, '2013-11-24 21:35:08.25193+00', '2013-11-25 15:25:25.186811+00', 15047, 1, 274, '', 'C', 'Budapest Birl - 23.11.2013', 1, 1, 'Y', 'dUO6Mfh9Kxc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1468, '2013-11-25 15:24:05.519666+00', '2013-11-25 16:50:13.566055+00', 7548, 1, 1751, '', 'D', '', 1, 1, 'Y', 'VWfn91gNAi8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1469, '2013-11-25 17:47:22.506833+00', '2013-11-25 17:48:42.439002+00', 6323, 1, 1, '', 'A', 'Demonstration at 1995 RSCDS Summer School in St Andrews. What happens during bars 9-16 is <<sspey-thread:64993|somewhat contentious>> but the interpretation shown here looks reasonable.  

Video by Malcolm Brown.', 1, 1, 'Y', 'c2rJt7LQnvI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1455, '2013-11-08 13:36:45.787895+00', '2014-01-22 10:41:32.404585+00', 2222, 1, 1041, '', 'B', 'The 1c set on bars 1-2 has been replaced by 1c Turn RH, probably to "make a better show". ', 1, 1, 'Y', 'pdkMrxy4SHM', 50, 390, NULL);
INSERT INTO 'dancevideo' VALUES (1152, '2013-08-18 10:55:19.263331+00', '2014-08-18 05:33:10.19437+00', 2317, 5, 1296, '', 'B', 'Good demo of this as a highland dance. Not SCD.', 1, 1, 'Y', 'ZHEl2p4aWCI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1476, '2013-11-26 17:30:38.710253+00', '2013-11-26 18:42:19.389712+00', 7935, 1, 106, '', 'B', '', 1, 1, 'Y', 'T7Qhzi3dPfM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1470, '2013-11-26 06:51:45.207708+00', '2013-11-26 18:51:22.732971+00', 15266, 1, 106, '', 'B', '', 1, 1, 'Y', 'FlUjPRd2Z10', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1477, '2013-11-26 19:16:32.800542+00', '2013-11-26 19:17:06.564253+00', 15267, 1, 106, '', 'B', '', 1, 1, 'Y', 'Yh97L3OVNxY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1478, '2013-11-26 19:26:14.427074+00', '2013-11-26 20:37:25.01453+00', 12107, 1, 106, '', 'B', '', 1, 1, 'Y', 'Go1ZEU3hFFU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1471, '2013-11-26 06:58:52.304548+00', '2013-11-27 04:17:09.229889+00', 2531, 1, 106, '', 'B', '', 1, 1, 'Y', 'EhQKWu4X_sQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1348, '2013-08-18 10:55:56.335105+00', '2013-11-29 04:52:44.387656+00', 5734, 1, 1296, '', 'B', 'In this video, first couple start and finish on opposite sides. 1C does not make the full turn after the Ladies'' Chain to enter the Poussette.  This option makes for a more natural transition from the hands across to the line across.  In the "Pilling" diagrams, 1c starts and finishes on own side.', 1, 1, 'Y', '7E9R-ppqWO0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1473, '2013-11-26 13:12:50.828514+00', '2013-11-29 05:47:31.533721+00', 223, 1, 513, '', 'C', 'In this video, 3c+4c also dance R&L for bars 25-32.', 1, 1, 'Y', 'z_C2hILLvgA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1502, '2013-12-09 17:20:12.671561+00', '2013-12-09 17:27:32.65677+00', 2042, 1, 106, '', 'D', '', 1, 1, 'Y', 'Pg8FPFrFtmY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1481, '2013-11-27 10:49:50.410526+00', '2013-11-29 05:57:50.172344+00', 5786, 1, 513, '', 'B', '', 1, 1, 'Y', 'EBDFjFD3mec', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1482, '2013-11-27 11:40:53.924776+00', '2013-11-29 07:41:50.15219+00', 9543, 1, 513, '', 'B', '', 1, 1, 'Y', 'Bbc7PO0thlY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1484, '2013-11-27 20:20:53.215382+00', '2013-11-29 07:51:13.7885+00', 15270, 1, 106, '', 'B', '', 1, 1, 'Y', 'HpqL5dhG7EM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1489, '2013-11-30 14:03:11.565183+00', '2013-12-01 08:25:38.831602+00', 7152, 3, 274, '', 'B', 'Two times only', 1, 1, 'Y', '4EZaTcQzUlI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1490, '2013-11-30 14:04:11.13087+00', '2013-12-02 04:19:35.936491+00', 12793, 5, 274, '', 'B', 'St.Andrew''s Day Ceilidh, Budapest, 2013', 1, 1, 'Y', 'xWCVwo-9Svk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1397, '2013-08-18 10:56:05.830007+00', '2013-12-02 19:03:54.212373+00', 6957, 1, 1296, '', 'D', 'Quite good dancing in a  full hall, but the camera pans too much to follow any single set long enough.', 1, 1, 'Y', 'DAUMBiH9MMY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1431, '2013-10-02 14:28:36.951997+00', '2013-12-02 19:25:41.396129+00', 5080, 1, 1649, '', 'B', '', 1, 1, 'Y', '3CnxVDNq7AE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1492, '2013-12-05 23:48:02.041481+00', '2013-12-05 23:48:58.145568+00', 14435, 1, 106, '', 'B', '', 1, 1, 'Y', 'nkYrQsW4al8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1494, '2013-12-06 00:31:09.546949+00', '2013-12-06 00:42:57.285639+00', 11112, 1, 106, '', 'C', 'Once thtrough only. Error on 25-32; both reels across should be Rsh.', 1, 1, 'Y', 'Oy7fzGctcg8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1495, '2013-12-06 00:45:57.635306+00', '2013-12-06 00:49:57.427961+00', 15242, 1, 106, '', 'C', '', 1, 1, 'Y', 'ycmWsF6_nHE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1493, '2013-12-06 00:21:18.837637+00', '2013-12-06 00:52:28.327597+00', 9015, 1, 106, '', 'B', '', 1, 1, 'Y', 'YPqzrwXZBAg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1496, '2013-12-06 01:11:55.402556+00', '2013-12-06 01:17:59.824399+00', 15273, 1, 106, '', 'C', '', 1, 1, 'Y', 'N8gP3LyXWKc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1497, '2013-12-07 17:52:12.575778+00', '2013-12-07 20:33:57.212533+00', 12890, 1, 513, '', 'C', '', 1, 1, 'Y', 'sQY5kbbEmhM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1294, '2013-08-18 10:55:45.114765+00', '2013-12-09 12:52:55.91923+00', 4928, 1, 1296, '', 'B', '8 times through, good dancing. However, all first couples are slow to dance up on [31-32], so that they are late for setting to the corners.  Note that the Manual recommends a phrasing that disagrees with the book 9 description.', 1, 1, 'Y', 'DRTYG77SrAg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1499, '2013-12-09 02:23:23.993172+00', '2013-12-09 16:28:35.021492+00', 10684, 1, 106, '', 'C', 'Seattle University Class', 1, 1, 'Y', 'p2DpEJHDSR0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1680, '2014-06-08 20:16:45.073086+00', '2014-06-08 22:28:33.12839+00', 10232, 1, 1041, '', 'B', '', 1, 1, 'Y', 'N4dtvlD7h08', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1503, '2013-12-11 08:30:03.407827+00', '2013-12-11 10:50:15.769293+00', 183, 1, 1041, '', 'C', 'Younger Hall social 2013. Twice through. Video starts two bars late, finishes one bar early.  In at least 1 set 1st couple turn left hands instead of right hands at bar 29-30', 1, 1, 'Y', 'iQO-aWU5ZY4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1211, '2013-08-18 10:55:32.792954+00', '2013-12-11 18:34:25.532324+00', 3541, 2, 1296, '', 'C', 'Video recorded at the Hessisches Volkstanzturnier 2008.  The formations are the same as in the SCD dance of this name, but a walking step is used.  The set is very small.', 1, 1, 'Y', 'wiV9S2mYsX4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1488, '2013-11-29 22:52:10.77472+00', '2013-12-13 11:27:39.133389+00', 7182, 1, 1777, '', 'D', 'Video unsharp; poor lighting, oblique view from above.  Two sets in a class setting.', 1, 1, 'Y', 'xWr-qJj1y8I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1218, '2013-08-18 10:55:33.61096+00', '2013-12-14 02:56:06.644831+00', 3607, 2, 1296, '', 'A', 'Danced in a 3C set, three times through.  In the progression [17-20] 1c casts to 3rd place (2c+3c step up)', 1, 1, 'Y', 'QtrwkCGy5y4', 1230, 1431, NULL);
INSERT INTO 'dancevideo' VALUES (1505, '2013-12-17 04:21:18.225437+00', '2013-12-17 06:21:02.75772+00', 11970, 1, 202, '', 'A', '', 1, 1, 'Y', 'SfSuWMu1Qbc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1506, '2013-12-17 10:12:13.840546+00', '2013-12-17 10:19:00.676081+00', 5384, 1, 1041, '', 'C', 'Taken from the floor, Younger Hall, 2013. Twice through. ', 1, 1, 'Y', 'bpalHeyn9dw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1504, '2013-12-13 08:56:44.998914+00', '2013-12-18 11:58:28.764867+00', 10469, 1, 274, '', 'B', 'Budapest Birl - 24.11.2013', 1, 1, 'Y', 'NDUy2z77eVg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1172, '2013-08-18 10:55:22.578507+00', '2013-12-19 00:21:03.344313+00', 13580, 2, 1296, '', 'C', 'Once through only.  On [13-16] the LHA is done with the same couple as the RHA in [9-12], instead of swapping the couples ', 1, 1, 'Y', 'OoeqDjOMDTo', 196, 227, NULL);
INSERT INTO 'dancevideo' VALUES (1545, '2014-01-04 00:47:10.91071+00', '2014-01-04 09:29:50.094075+00', 9107, 2, 562, '', 'C', 'New Haven Highland Ball 2013 - First dance of the night. Music by Parcel O'' Rogues', 1, 1, 'Y', 'YNkQ4JUEDEI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1514, '2013-12-20 07:41:43.241504+00', '2013-12-25 02:00:00.595547+00', 1989, 2, 106, '', 'B', 'Two sets, four times through.', 1, 1, 'Y', '4nnO89ML328', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1486, '2013-11-28 22:32:23.423094+00', '2013-12-25 23:16:48.390641+00', 15177, 1, 963, '', 'C', '', 1, 1, 'Y', 'tYynm3ByKhI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1512, '2013-12-20 07:37:57.773844+00', '2013-12-25 22:10:19.109355+00', 1486, 1, 106, '', 'D', 'Once trhoug, starting at bar 11, finishing next time through at bar 16', 1, 1, 'Y', 'aHLEEanBwx4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1475, '2013-11-26 17:26:54.486292+00', '2013-12-31 00:25:13.005697+00', 13466, 1, 513, '', 'B', '', 1, 1, 'Y', 'G-N6L047kJw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1542, '2014-01-01 15:03:28.663338+00', '2014-01-04 00:02:08.121144+00', 8051, 1, 106, '', 'D', 'Very poor lighting.  Social dance. The video spells the name wrong (Edive).', 1, 1, 'Y', 'gglYKCgyo6w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1548, '2014-01-06 08:04:24.85797+00', '2014-01-06 14:11:22.479889+00', 761, 1, 274, '', 'C', 'Scottish Dance House for beginners, Budapest, 2014', 1, 1, 'Y', 'JHGCGkwzk9s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1547, '2014-01-06 08:02:37.57231+00', '2014-01-06 14:07:47.918872+00', 15330, 1, 274, '', 'D', 'Scottish Dance House for beginners, Budapest, 2014', 1, 1, 'Y', 'uz3NKqeP0FQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1659, '2014-05-06 19:42:48.431454+00', '2014-06-18 13:12:51.620798+00', 14449, 1, 1041, '', 'B', '', 1, 1, 'Y', 'uGfmAM0e2Dk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1656, '2014-05-06 19:33:30.563152+00', '2014-06-20 08:59:06.438918+00', 2344, 2, 1041, '', 'C', '', 1, 1, 'Y', 'A41wVzhU7dY', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1521, '2013-12-23 08:59:48.517052+00', '2013-12-25 13:38:30.421212+00', 2125, 2, 513, '', 'D', 'I recorded the encore of the dance, so what you see here might differ to what the original description says. :-)   The dancers add many "variations" of their own invention.', 1, 1, 'Y', 'g-z0sF1Ui_w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1556, '2014-02-12 19:09:57.473766+00', '2014-02-12 21:58:10.076135+00', 794, 4, 274, '', 'A', 'Newcastle Festival 2014, International Team', 1, 1, 'Y', 'JkhYHDjTbrk', 23, 297, NULL);
INSERT INTO 'dancevideo' VALUES (1087, '2013-08-18 10:47:54.416725+00', '2013-12-29 00:38:35.647415+00', 10007, 2, 1296, '', 'D', 'Part of a compilation.  Starts at 2:20, goes to the end. Not the whole set is in view. Gives an idea of teh dance but not suitable for instruction.



Alas not available embedded.', 1, 1, 'Y', 'TvGKVCnzrkY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1538, '2013-12-25 17:43:10.719944+00', '2013-12-25 17:44:05.411761+00', 14023, 1, 106, '', 'A', '', 1, 1, 'Y', 'CHMUXNbgUxY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1158, '2013-08-18 10:55:20.297181+00', '2013-12-25 23:26:58.56498+00', 2409, 2, 1296, '', 'Z', 'REJECTED.  View taken from stomach level, showing only part of the set. Impossible to follow the dance unless you know it.', 1, 1, 'Y', 'baYncFzrrwg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1461, '2013-11-10 15:40:33.137232+00', '2013-12-25 23:49:34.796386+00', 8158, 2, 274, '', 'C', 'Scottish Dance House for beginners, Budapest, november 2013.  This set dances "Circle L and back" at the end, rather than "Circle L for 8 bars".', 1, 1, 'Y', 'F0oJ-D3YJ6M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1472, '2013-11-26 13:12:11.698402+00', '2013-12-25 23:54:47.120616+00', 11629, 2, 513, '', 'B', 'Danced in Kuckucksnest.', 1, 1, 'Y', 'fzDdLW4zqK0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1345, '2013-08-18 10:55:56.02124+00', '2013-12-26 00:53:36.808262+00', 5703, 3, 1296, '', 'C', 'Very tight set.', 1, 1, 'Y', 'ozVgCp5zUJE', 33, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1568, '2014-02-18 04:31:30.678654+00', '2014-02-18 23:41:14.182111+00', 6091, 5, 513, '', 'A', '', 1, 1, 'Y', 'W61J-XLoNcE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1291, '2013-08-18 10:55:44.591608+00', '2013-12-26 00:58:04.037622+00', 4858, 2, 1296, '', 'C', 'The set on the left dances better', 1, 1, 'Y', 'urF3lKkmuRI', 39, 202, NULL);
INSERT INTO 'dancevideo' VALUES (1093, '2013-08-18 10:47:55.187992+00', '2013-12-26 01:36:52.678896+00', 1478, 3, 1296, '', 'D', 'The two sets use quite different phrasing.', 1, 1, 'Y', 'ddXN2PwLG6U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1383, '2013-08-18 10:56:03.464683+00', '2013-12-26 20:59:03.742242+00', 13316, 2, 1296, '', 'A', 'Part of a longer display. Once through, final bars adapted for linking to the next dance.', 1, 1, 'Y', 'nbGanaws0t0', 0, 164, NULL);
INSERT INTO 'dancevideo' VALUES (1225, '2013-08-18 10:55:34.989628+00', '2013-12-26 21:12:30.58246+00', 3759, 3, 1296, '', 'Z', 'Danced in a 5C set. Video starts late.  Breaks off part way through next time. There are much better videos available; this one can be dropped for good.', 1, 1, 'Y', 'vMPaYSl1DLU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1311, '2013-08-18 10:55:49.668293+00', '2013-12-26 21:21:16.04056+00', 5239, 6, 1296, '', 'C', 'Social. The sets are dancing the "Star Petronella" where 2nd couple joins in the Petronella. ', 1, 1, 'Y', '1Ar6pSP5lII', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1155, '2013-08-18 10:55:19.74134+00', '2013-12-26 21:41:10.449422+00', 2360, 3, 1296, '', 'B', 'Good dancing, but sets not in view fully, and too many sets and too low viewpoint to see the formations properly.', 1, 1, 'Y', 'aX0CflUKGwg', 0, 108, NULL);
INSERT INTO 'dancevideo' VALUES (1522, '2013-12-23 09:02:35.400035+00', '2013-12-28 01:03:13.0488+00', 13709, 2, 513, '', 'D', '', 1, 1, 'Y', 'RJ2kS3EWkrc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1096, '2013-08-18 10:47:55.773349+00', '2013-12-28 01:34:33.74438+00', 11872, 2, 1296, '', 'C', 'Good dancing, but video often taken so close that the figures cannot be followed. This is the same demo as the other video from this event, which has better camera handling.', 1, 1, 'Y', 'IpfK6hpdbfA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1204, '2013-08-18 10:55:31.628719+00', '2013-12-29 02:19:24.759387+00', 3365, 5, 1296, '', 'D', '', 1, 1, 'Y', 'P6eGgOFE5Dw', 72, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1095, '2013-08-18 10:47:55.510949+00', '2013-12-29 21:55:33.624597+00', 1501, 3, 1296, '', 'Z', 'The camera regularly shifts to the musicians; there is hardly one time through to be seen in full.  Most frustrating. It makes no sense to keep showing this video now better ones are available.', 1, 1, 'Y', 'eyD9prcr6So', 67, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1352, '2013-08-18 10:55:57.060928+00', '2013-12-30 17:27:27.046615+00', 5794, 5, 1296, '', 'C', 'Twice through, first time a few bars missing at the start. Good viewpoint, but very poor lighting; some dancers hardly visible. ', 1, 1, 'Y', 'hGPMRbXPPrw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1036, '2013-08-18 00:52:10.770619+00', '2013-12-30 20:18:09.510766+00', 674, 4, 1296, '', 'C', 'Danced in very small sets in a full dance hall, making the figures hard to follow; good viewpoint, but mediocre lighting.  ', 1, 1, 'Y', 'AYCmbIJSnqI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1052, '2013-08-18 08:05:58.440491+00', '2013-12-30 20:25:32.120794+00', 11188, 5, 1296, '', 'C', 'OUSDS Social in Younger Hall, 2013.  Twice through shown. Narrow set spacing. Good viewpoint.', 1, 1, 'Y', '7ybucLB5Am4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1296, '2013-08-18 10:55:45.657193+00', '2013-12-30 21:35:16.813243+00', 4998, 7, 1296, '', 'A', '', 1, 1, 'Y', 'IIERkIwLj4g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1174, '2013-08-18 10:55:22.912986+00', '2013-12-30 22:27:42.555813+00', 9862, 4, 1296, '', 'A', '', 1, 1, 'Y', 'ld8Cvsi4L-Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (768, '2012-12-17 14:19:49.824231+00', '2013-12-31 00:06:51.857906+00', 7242, 2, 1296, '', 'A', 'Once through only, 2c of the set is the dancing couple.  Very clear view.  Part of a longer display.', 1, 1, 'Y', 'vANsSfNd_Kk', 81, 149, NULL);
INSERT INTO 'dancevideo' VALUES (1520, '2013-12-22 18:19:28.066064+00', '2014-04-28 22:38:50.867302+00', 15314, 1, 106, '', 'B', 'The deviser, Darrick Wong, gives background information from 0:40, with a quick recap starting at 1:07.





The dance itself starts at 2:31, and is danced 4 times through (of 8).  It is an older version of the current dance, where 1c turns 1 1/2 instead of 2 times on (11-14), and the arches on [15-16] are missing.  The Baratte is danced facing down, and there is only a (too) short turn to face 1st corners.', 1, 1, 'Y', 'jeVJVrqav-g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1544, '2014-01-03 23:28:54.644062+00', '2014-03-05 09:32:42.247013+00', 3418, 1, 562, '', 'B', 'Hogmanay in Wellington, New Zealand, December 31, 2013.  The MC was Betty Redfearn.', 1, 1, 'Y', 'dz0P4rFqAAE', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1543, '2014-01-03 22:48:32.368474+00', '2014-01-04 00:05:13.573413+00', 2428, 4, 1240, '', 'C', '', 1, 1, 'Y', 'M57luJO3rpc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1546, '2014-01-05 20:27:20.847597+00', '2014-01-05 22:03:33.460931+00', 14472, 1, 1193, '', 'B', '', 1, 1, 'Y', 'V9bAXKik9ow', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1665, '2014-05-07 12:27:01.673678+00', '2014-05-07 12:41:30.347081+00', 5407, 4, 106, '', 'A', '', 1, 1, 'Y', 'QGA_nTGhHwo', 281, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1668, '2014-05-13 18:12:00.790968+00', '2014-05-13 20:02:05.627104+00', 6037, 3, 1633, '', 'A', '', 1, 1, 'Y', 'Yu2Hv4n1zZE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1653, '2014-05-06 19:26:12.27506+00', '2014-05-13 20:05:22.626211+00', 6037, 1, 1041, '', 'A', '', 1, 1, 'Y', 'JaQT0d_EbxM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1667, '2014-05-13 18:09:23.879654+00', '2014-05-13 20:08:13.908332+00', 6037, 2, 1633, '', 'B', '', 1, 1, 'Y', 'z9NdeSdjaoI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1660, '2014-05-06 19:47:24.828164+00', '2014-06-18 10:53:06.51265+00', 14445, 1, 1041, '', 'B', '', 1, 1, 'Y', 'GcIX6U_quiE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1663, '2014-05-06 19:59:27.591394+00', '2014-06-18 11:00:53.385587+00', 14442, 1, 1041, '', 'B', '', 1, 1, 'Y', 'xu0SkWRvyv0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1654, '2014-05-06 19:29:49.82991+00', '2014-06-18 13:05:19.521513+00', 14443, 1, 1041, '', 'B', '', 1, 1, 'Y', 'rxb7pu6JJ8M', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1778, '2014-08-24 14:20:44.01299+00', '2014-08-24 14:24:48.295706+00', 4334, 1, 106, '', 'D', '', 1, 1, 'Y', 'TH3Gqh4WeV4', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1549, '2014-01-26 21:17:18.753204+00', '2014-01-26 22:34:47.624033+00', 9166, 1, 274, '', 'A', 'Burns Supper, Budapest, 2014.  Danced in two sets. joined bottom to bottom.', 1, 1, 'Y', 'd01Ixed7ueQ', 263, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1541, '2013-12-31 13:08:35.355669+00', '2014-02-05 07:48:17.447925+00', 6461, 1, 106, '', 'Z', 'This is a video of the dance being taught; no actual dancing. It contains no information that is not available in the dance description.  In addition the video has bad lighting and is fuzzy. ', 1, 1, 'Y', 'Y_k1asA5IHs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1539, '2013-12-30 23:01:45.131307+00', '2014-02-05 07:51:41.79027+00', 6461, 2, 106, '', 'D', 'This is a poorly recorded video, and the dancing is mediocre. The set goes wrong, and starts again on 1:12.  That failed part has been blocked here.  The video has the name "The Glens of Angus", but it is Drewry''s Tappie Toorie.  Another video from the same occasion shows this dance being taught.



The video was uploaded by "Heidi Afschar".  Her photograph can be found on http://rscds-losangeles.org/PDFs/GC_Mar12.pdf.  ', 1, 1, 'Y', '2B6csRZt_Pc', 71, 0, NULL);
INSERT INTO 'dancevideo' VALUES (155, '2012-09-04 10:26:57.309387+00', '2014-02-09 00:04:39.520918+00', 14536, 1, 106, '', 'A', 'Demo at Summer School 2012 - week 4.  Twice through. This is a dance for a 3C set.  On 2nd time through, the old 1c+4c also dance a 2c knot to change places. At the end, the final bars are modified to link to the next dance of the display, in a square set. ', 1, 1, 'Y', 't29gjE7RWwU', 117, 240, NULL);
INSERT INTO 'dancevideo' VALUES (1523, '2013-12-23 09:03:09.828546+00', '2019-10-23 18:10:53.392099+00', 10703, 1, 513, '', 'D', 'This video shows the advanced version with reels of three on the sides in bars 17-24 (instead of figures of 8 for 1st couple alone).', 1, 1, 'Y', 'hEDddmJ7ZnU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1558, '2014-02-12 19:11:37.698448+00', '2014-02-12 22:04:21.723304+00', 3108, 2, 274, '', 'A', 'Newcastle Festival 2014, International Team', 1, 1, 'Y', '57l8QxFVIzA', 0, 160, NULL);
INSERT INTO 'dancevideo' VALUES (1555, '2014-02-12 19:08:50.826302+00', '2014-02-12 22:09:52.041917+00', 11284, 3, 274, '', 'A', 'Newcastle Festival 2014, International Team', 1, 1, 'Y', 'si8wLA-5VgE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1563, '2014-02-18 04:23:29.721648+00', '2014-02-19 00:02:57.844318+00', 10787, 4, 513, '', 'A', '', 1, 1, 'Y', 'dc-aWPFgtsE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1553, '2014-02-12 19:07:11.863+00', '2014-02-12 22:16:26.771609+00', 5326, 2, 274, '', 'A', 'Newcastle Festival 2014, International Team', 1, 1, 'Y', 'jXLIltUp2Ms', 0, 160, NULL);
INSERT INTO 'dancevideo' VALUES (1567, '2014-02-18 04:30:03.584015+00', '2014-02-19 00:04:37.086578+00', 10787, 5, 513, '', 'A', '', 1, 1, 'Y', '_0O3E7wJE3w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1578, '2014-03-05 01:35:44.398655+00', '2014-03-05 01:45:08.642759+00', 12567, 1, 1733, '', 'D', 'Only once through.  The preceding part of the video is a detailed oral recap of the dance.', 1, 1, 'Y', 'LSR__Hpr7JM', 80, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1560, '2014-02-12 19:13:18.429144+00', '2014-02-12 22:23:02.48308+00', 4935, 1, 274, '', 'A', 'Newcastle Festival 2014, International Team', 1, 1, 'Y', 'NLvfrJac0CI', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1561, '2014-02-18 04:19:50.886382+00', '2014-02-19 00:07:52.905373+00', 1501, 4, 513, '', 'A', '', 1, 1, 'Y', 'bAZlz8jVAAc', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1559, '2014-02-12 19:12:34.134109+00', '2014-02-12 22:27:41.010758+00', 4720, 1, 274, '', 'A', 'Newcastle Festival 2014, International Team', 1, 1, 'Y', 'fdhbjZbntaw', 22, 285, NULL);
INSERT INTO 'dancevideo' VALUES (1554, '2014-02-12 19:08:07.988486+00', '2014-02-12 22:31:22.11148+00', 4404, 5, 274, '', 'A', 'Newcastle festival 2014, International team', 1, 1, 'Y', 'X5Aya4OhJ4o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1557, '2014-02-12 19:10:41.939207+00', '2014-02-12 22:35:05.982013+00', 5207, 3, 274, '', 'A', 'Newcastle Festival 2014, International Team', 1, 1, 'Y', 'KAj3gMl0lnw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1564, '2014-02-18 04:26:05.612812+00', '2014-02-18 23:43:46.41196+00', 6964, 3, 513, '', 'A', '', 1, 1, 'Y', 'TjA1ss0cFng', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1573, '2014-02-18 04:37:22.81242+00', '2014-02-18 23:45:39.406414+00', 14535, 6, 513, '', 'A', '', 1, 1, 'Y', 'fs7sQyyoHnc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1574, '2014-02-18 04:39:47.778464+00', '2014-02-18 23:46:32.559522+00', 5525, 12, 513, '', 'A', '', 1, 1, 'Y', 'UuTMz-d99Hg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1566, '2014-02-18 04:28:48.273053+00', '2014-02-18 23:48:02.918073+00', 5326, 3, 513, '', 'A', '', 1, 1, 'Y', 'Q3WjuCDvsTs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1570, '2014-02-18 04:33:59.767912+00', '2014-02-18 23:48:28.999092+00', 4646, 5, 513, '', 'A', '', 1, 1, 'Y', 'oC2jAZQifyk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1572, '2014-02-18 04:35:50.686081+00', '2014-02-18 23:52:53.528534+00', 2158, 3, 513, '', 'A', '', 1, 1, 'Y', 'XYWFhjcSLKk', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1569, '2014-02-18 04:32:35.009365+00', '2014-02-18 23:55:25.69046+00', 11543, 2, 513, '', 'A', '', 1, 1, 'Y', 'B34A3DpJTl0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1565, '2014-02-18 04:27:45.843412+00', '2014-02-18 23:56:58.642905+00', 13149, 8, 513, '', 'A', '', 1, 1, 'Y', 'sG46juREWcI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1581, '2014-03-05 06:31:43.830695+00', '2014-03-05 09:37:50.48924+00', 13586, 1, 1733, '', 'D', 'Labour Weekend school, Auckland, New Zealand, October 2013. 

In the first part of this video the dance is briefed by Esther Mackay.

', 1, 1, 'Y', '2Uzu6v4czEE', 124, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1645, '2014-05-05 19:24:14.785156+00', '2014-06-20 09:23:57.763763+00', 5330, 11, 1041, '', 'B', 'Educational video to help everyone to take the floor and participate in the commonwealth ceilidh on the 21st June 2014', 1, 1, 'V', '89897897', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1649, '2014-05-05 19:47:59.377673+00', '2014-06-20 09:28:03.548763+00', 1931, 7, 1041, '', 'B', 'Educational video to help everyone to take the floor and participate in the commonwealth ceilidh on the 21st June 2014', 1, 1, 'V', '89897874', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1779, '2014-08-24 14:31:01.005702+00', '2014-08-24 14:31:42.884204+00', 10593, 1, 106, '', 'D', '', 1, 1, 'Y', 'tYU-DxOupog', 9, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1585, '2014-03-05 09:49:08.269788+00', '2014-03-05 16:33:51.537682+00', 3503, 1, 106, '', 'D', 'In the first part of this video the MC gives a recap of the dance.



Johnsonville SCD Club hosted the New Dancers'' Celebration in Wellington, New Zealand this year. The dance was held at the Newlands Centennial hall and Lynne Scott and Associates provided the music. Jean Malcolm and Richard Hardie are the band''s other members. "The Kingston Flyer" was devised by Noeline O''Connor and takes its name from a well-known South Island tourist train. Our MC was Johnsonville club tutor Rod Downey. Oh, and please note the bunting around the hall - this was its first outing. Several of Johnsonville''s new members held a bunting bee, using donated tartan and plain fabric.', 1, 1, 'Y', 'ZB0kRVIVViw', 52, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1575, '2014-02-21 14:46:02.311585+00', '2014-02-22 23:07:21.224903+00', 9534, 1, 1041, '', 'A', 'Danced twice through in 3-couple sets, as final part of a longer display.  The closer (bottom) set dances "Widdershins", the further (top) set dances it in mirror image, i.e. clockwise.  In the old parlance, that direction is called "Deosil", and so the title the dem team uses for the dance is Deosil/Widdershins"', 1, 1, 'Y', 'NnnFfJUXyGc', 301, 378, NULL);
INSERT INTO 'dancevideo' VALUES (343, '2012-11-19 01:53:11.505418+00', '2014-03-01 11:46:27.358681+00', 14532, 2, 1240, '', 'A', 'Summer School 2012 week 1 Demonstration.', 1, 1, 'Y', 'mNto6b418EM', 326, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1683, '2014-06-09 02:24:20.005173+00', '2014-06-09 02:25:30.370963+00', 15395, 2, 106, '', 'B', '', 1, 1, 'Y', 'nsLTSSganMs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3457, '2018-03-07 15:01:15.069063+00', '2018-03-08 12:37:47.533715+00', 18246, 1, 2586, '', 'A', '', 1, 1, 'Y', 'cMm8GrIWmSA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3455, '2018-03-04 19:44:30.945325+00', '2018-03-05 23:54:26.251474+00', 13975, 1, 2220, '', 'B', 'The dance should end with the 1s pulling back right shoulder to swirl into place, optionally they may swirl round each other into place.  Note that the figure in bars 17-24 is quite long, it is based on the Thomas Wilson''s (no relation) 1811 description of the figure that morphed into what is now called Double Triangles.



The final swirl into place is omitted by the second couple dancing.  The optional long swirl into place is not performed.  

  

Recorded at the interval at the San Francisco monthly party March 3, 2018.', 1, 1, 'Y', 'qcI2OLzl2AU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1579, '2014-03-05 01:51:06.966125+00', '2014-03-05 08:10:04.448149+00', 10920, 4, 106, '', 'D', 'Lower Hutt, Wellington, New Zealand, February 2014. A dance in honour of Xiaowen Yu who was back home on a short visit - she is currently on a Fulbright scholarship in Chicago. Scott Meikle was briefed by Iain Boyd.', 1, 1, 'Y', 'JmyaWtec3cs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1584, '2014-03-05 06:38:53.309854+00', '2014-03-05 09:50:35.157984+00', 3065, 1, 1733, '', 'D', 'New Dancers'' Celebration dance, Newlands, Wellington, New Zealand, October 2013. The dance was briefed by Rod Downey.', 1, 1, 'Y', 'Rm2oTBTXgP0', 21, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1586, '2014-03-05 10:24:15.090101+00', '2014-03-05 10:26:43.222916+00', 3065, 2, 106, '', 'D', 'At the New Dancers'' Celebration in Wellington, New Zealand, October 2013', 1, 1, 'Y', 'Fyi_u6jGgzk', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1589, '2014-03-11 14:32:09.547393+00', '2014-03-22 23:48:09.628327+00', 5009, 1, 513, '', 'C', '', 1, 1, 'Y', '9RsvmfJQBZM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1588, '2014-03-11 14:28:37.431978+00', '2014-03-22 23:36:20.944193+00', 15041, 1, 513, '', 'D', '', 1, 1, 'Y', 'AiZ5wTmXZl4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1641, '2014-05-05 19:05:24.586788+00', '2014-05-06 23:29:13.729117+00', 1562, 4, 1041, '', 'B', 'Educational video to help everyone to take the floor and participate in the commonwealth ceilidh on the 21st June 2014', 1, 1, 'V', '89897872', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1655, '2014-05-06 19:31:30.337103+00', '2014-06-18 13:20:52.915227+00', 2781, 2, 1041, '', 'C', '', 1, 1, 'Y', 'ZpvjzbmKUm0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1658, '2014-05-06 19:40:46.525024+00', '2014-06-18 13:25:14.070649+00', 11200, 1, 1041, '', 'D', '', 1, 1, 'Y', 'yH_F5pk0hhs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1650, '2014-05-05 19:49:21.868535+00', '2014-06-20 09:25:53.265569+00', 7554, 5, 1041, '', 'C', 'Educational video to help everyone to take the floor and participate in the commonwealth ceilidh on the 21st June 2014', 1, 1, 'V', '89897898', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3509, '2018-04-16 08:13:14.499494+00', '2018-04-16 12:22:36.987639+00', 18077, 1, 513, '', 'C', '', 1, 1, 'Y', 'rbozoMmK7xQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3529, '2018-05-04 22:03:07.116697+00', '2018-05-12 20:20:23.799699+00', 18330, 1, 197, '', 'B', 'Videoed at Glasgow RSCDS Branch Dance held in memory of deviser Jimmy McMillan on 23 March 2018.  The video shows two repeats of the dance.



(In bars 13-16 1st couple in the first set turn RH instead of the expected LH).', 1, 1, 'Y', 'MUABxwDZDr4', 13, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1592, '2014-03-16 09:16:27.913876+00', '2014-03-17 13:23:51.304016+00', 15265, 1, 1041, '', 'C', '', 1, 1, 'Y', '4SsG-3jMNAM', 5, 81, NULL);
INSERT INTO 'dancevideo' VALUES (1599, '2014-03-19 22:24:21.696855+00', '2014-03-23 00:32:31.106718+00', 15378, 1, 197, '', 'B', '', 1, 1, 'Y', 'BsjesSCmLLc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1594, '2014-03-17 13:32:21.807957+00', '2014-03-17 13:35:33.942478+00', 3326, 3, 106, '', 'C', '', 1, 1, 'Y', '4SsG-3jMNAM', 205, 287, NULL);
INSERT INTO 'dancevideo' VALUES (1593, '2014-03-17 13:25:30.751868+00', '2014-03-17 13:36:14.551258+00', 4484, 4, 106, '', 'C', '', 1, 1, 'Y', '4SsG-3jMNAM', 80, 206, NULL);
INSERT INTO 'dancevideo' VALUES (1627, '2014-03-31 15:49:09.339151+00', '2014-03-31 16:36:18.375351+00', 15395, 1, 160, '', 'A', '', 1, 1, 'Y', 'jLvCmEOA3-0', 78, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1596, '2014-03-17 22:14:49.744376+00', '2014-03-17 22:24:40.973064+00', 5860, 7, 106, '', 'A', 'Newcastle 2010 International Team (White).  ', 1, 1, 'Y', 'msa0yu6iCio', 339, 487, NULL);
INSERT INTO 'dancevideo' VALUES (1624, '2014-03-26 13:02:38.887918+00', '2014-03-31 16:45:25.633259+00', 9107, 3, 1041, '', 'A', 'Twice through', 1, 1, 'Y', '9ljkDZGtPsk', 73, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1597, '2014-03-19 14:32:49.907197+00', '2014-03-19 16:03:40.6447+00', 5807, 1, 1041, '', 'A', 'Before the end of the first time through, the set is turned a quarter', 1, 1, 'Y', 'qe_4lV3KLVg', 34, 148, NULL);
INSERT INTO 'dancevideo' VALUES (1623, '2014-03-26 12:59:34.75526+00', '2014-04-01 05:48:02.403575+00', 9106, 2, 1041, '', 'A', 'Once only', 1, 1, 'Y', '9ljkDZGtPsk', 0, 74, NULL);
INSERT INTO 'dancevideo' VALUES (1652, '2014-05-06 19:23:09.166603+00', '2014-06-18 13:23:49.539535+00', 11202, 1, 1041, '', 'D', '', 1, 1, 'Y', 'DrESJYrLK3I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1595, '2014-03-17 16:17:43.838824+00', '2016-02-08 23:13:54.745163+00', 13582, 2, 1041, '', 'A', 'Newcastle 2010 International Team (White).   For bars 26-28, the set does not follow the instructions, which say that that the couples finish in the middle close to their partners, and set in lines of 3 at that distance.  See the "Extra Info" of this dance.', 1, 1, 'Y', 'msa0yu6iCio', 39, 305, NULL);
INSERT INTO 'dancevideo' VALUES (1628, '2014-04-01 12:47:23.99244+00', '2014-04-10 08:18:16.283832+00', 1060, 1, 1041, '', 'C', '', 1, 1, 'V', '50503472', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1620, '2014-03-26 12:16:02.778627+00', '2014-03-26 23:26:02.868254+00', 9559, 1, 1041, '', 'A', '4 times through, two bars missing at the end.', 1, 1, 'Y', '2B-uCzApW7g', 68, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1619, '2014-03-26 10:42:43.684415+00', '2014-03-26 23:29:51.296027+00', 9074, 1, 1041, '', 'A', 'Once through only', 1, 1, 'Y', '2B-uCzApW7g', 0, 68, NULL);
INSERT INTO 'dancevideo' VALUES (1626, '2014-03-29 06:11:36.112767+00', '2014-03-29 06:16:48.763594+00', 12309, 1, 106, '', 'B', 'Six times through', 1, 1, 'Y', 'bvE4ktoqKJQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1621, '2014-03-26 12:33:14.991985+00', '2014-03-31 00:25:25.11008+00', 6848, 2, 1041, '', 'A', 'Once through only', 1, 1, 'Y', 'QVSAklaUdTY', 0, 66, NULL);
INSERT INTO 'dancevideo' VALUES (1634, '2014-04-17 14:15:46.651519+00', '2014-04-17 19:56:41.760623+00', 9169, 4, 160, '', 'C', 'New Haven Highland Ball, March 1, 2014', 1, 1, 'Y', 'MjitDeqLEjw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1622, '2014-03-26 12:37:25.285039+00', '2014-03-31 00:31:28.051431+00', 3986, 2, 1041, '', 'A', '', 1, 1, 'Y', 'QVSAklaUdTY', 65, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1632, '2014-04-16 10:20:54.041019+00', '2014-04-16 20:56:45.135279+00', 15422, 1, 197, '', 'C', 'recorded on the 22.11.2008 during the November course at the "Kuckucksnest" 



Incorrectly described as R32', 1, 1, 'Y', 'Czk5yibK8VY', 36, 315, NULL);
INSERT INTO 'dancevideo' VALUES (1635, '2014-04-22 11:11:58.890025+00', '2014-04-22 19:56:02.031596+00', 10790, 1, 513, '', 'D', '', 1, 1, 'Y', 'Wu5ns_MqxEw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1636, '2014-04-22 11:12:36.393849+00', '2014-04-22 19:56:44.211273+00', 10790, 2, 513, '', 'D', '', 1, 1, 'Y', 'HVWZZksgcMI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1639, '2014-05-05 01:19:31.730002+00', '2014-06-18 13:27:07.3127+00', 4291, 2, 940, '', 'D', '', 1, 1, 'Y', 'RSnsu2Nt84Y', 0, 57, NULL);
INSERT INTO 'dancevideo' VALUES (1644, '2014-05-05 19:22:39.719938+00', '2014-06-20 09:16:44.985209+00', 7552, 1, 1041, '', 'B', 'Educational video to help everyone to take the floor and participate in the commonwealth ceilidh on the 21st June 2014', 1, 1, 'V', '89897896', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1646, '2014-05-05 19:38:52.664234+00', '2014-06-20 09:19:11.638611+00', 7553, 4, 1041, '', 'B', 'Educational video to help everyone to take the floor and participate in the commonwealth ceilidh on the 21st June 2014', 1, 1, 'V', '89897871', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1640, '2014-05-05 19:03:20.617662+00', '2014-06-20 09:20:54.94587+00', 7546, 4, 1041, '', 'B', 'Educational video to help everyone to take the floor and participate in the commonwealth ceilidh on the 21st June 2014', 1, 1, 'V', '89897876', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1647, '2014-05-05 19:40:23.865995+00', '2014-06-20 09:29:23.894635+00', 5525, 14, 1041, '', 'B', 'Educational video to help everyone to take the floor and participate in the commonwealth ceilidh on the 21st June 2014', 1, 1, 'V', '89897900', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1776, '2014-08-24 13:52:25.935057+00', '2014-08-24 13:55:29.712177+00', 4726, 1, 106, '', 'D', '', 1, 1, 'Y', 'X4SFPkjRJt4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1777, '2014-08-24 14:15:47.541454+00', '2014-08-24 14:18:25.361604+00', 13360, 1, 106, '', 'B', 'Once through only', 1, 1, 'Y', 'IR8OXfF8jnw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1671, '2014-05-17 17:07:46.861217+00', '2014-05-18 08:09:15.843217+00', 2250, 2, 1777, '', 'C', '', 1, 1, 'Y', 'wog7asyLylE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1672, '2014-05-17 17:10:07.504792+00', '2014-05-18 08:12:46.750881+00', 2250, 3, 1777, '', 'D', '', 1, 1, 'Y', 'DR8C8-9vvMM', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1674, '2014-05-21 23:06:52.163808+00', '2014-05-21 23:08:59.042807+00', 633, 5, 106, '', 'C', 'Outside Raglan Castle.  The video starts late.', 1, 1, 'Y', 'Eh7gLFzw9vU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (824, '2013-02-10 23:07:02.76663+00', '2014-06-20 07:40:01.846793+00', 1244, 1, 106, '', 'C', 'The formations Rights and Lefts [17-24] and Ladies Chain [25-32] have been switched around.  On [33-40] all turns are done with the wrong hand, so that the men face in when setting, and also the phrasing is poor  The demo goes twice through with a good view, the third time the camera pans around; the 4th time is cut off short.



This was recorded on Feb. 3rd, 2008, probably at a Festival Interceltique of Lorient, the dancers could be from Russia. It was uploaded to Youtube on Feb 6, 2008.', 1, 1, 'Y', 'UeAp5-Byi24', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1677, '2014-05-30 01:05:01.283467+00', '2014-05-30 01:14:28.606146+00', 7527, 3, 160, '', 'B', 'video taken by Theresa Forbes, RSCDS NJ Branch', 1, 1, 'Y', 'MK6Nl-9o_RI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1678, '2014-06-03 22:13:46.295066+00', '2014-06-03 23:35:24.528121+00', 2782, 1, 1777, '', 'C', '', 1, 1, 'Y', '6TFSaW5wams', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1631, '2014-04-16 08:43:50.330508+00', '2021-10-29 14:09:13.589783+00', 14604, 1, 106, '', 'Z', 'Video recorded at Kuckucksnest, Germany. Unfortunately now private.', 1, 1, 'Y', 'wUzIqiZVP6I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1688, '2014-06-09 15:34:48.478561+00', '2014-06-09 15:38:56.057001+00', 15459, 1, 106, '', 'C', '', 1, 1, 'Y', 'GCwLTbbbmOY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1689, '2014-06-09 15:38:28.164824+00', '2014-06-09 15:39:13.67728+00', 15459, 2, 106, '', 'A', 'Dem team.  First four bars missing', 1, 1, 'Y', 'Fsya0sOuKpM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1691, '2014-06-09 16:26:41.78307+00', '2014-06-09 16:26:57.171627+00', 15460, 1, 106, '', 'D', '', 1, 1, 'Y', '58ym0sy-M6I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1681, '2014-06-08 20:37:03.288697+00', '2014-06-09 16:43:45.143375+00', 9102, 2, 1041, '', 'C', '', 1, 1, 'Y', 'YfvpyEz76vw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1694, '2014-06-10 21:57:34.281841+00', '2014-06-10 22:00:34.076496+00', 2166, 1, 106, '', 'D', 'Our annual dance on August 24 2013 was most enjoyable, with fifteen of our new dancers there (more than the number of ''experienced'' club members), and visitors from several other Wellington clubs.  Pat Reesby,  Johnsonville SCD Club', 1, 1, 'Y', 'LcLhyyZ4jEg', 130, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1693, '2014-06-10 17:22:56.44599+00', '2014-06-10 22:06:17.074465+00', 4424, 3, 274, '', 'C', 'Two times through', 1, 1, 'Y', 'nD9FNI4ZPcg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1692, '2014-06-10 17:13:43.538088+00', '2014-06-18 11:03:23.073521+00', 14720, 1, 274, '', 'D', 'One times through', 1, 1, 'Y', '4glWG8OvnD4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1642, '2014-05-05 19:07:43.35159+00', '2014-06-18 11:08:07.505973+00', 8154, 1, 1041, '', 'D', 'Educational video to help everyone to take the floor and participate in the commonwealth ceilidh on the 21st June 2014', 1, 1, 'V', '89897904', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1657, '2014-05-06 19:34:51.483018+00', '2014-06-18 13:10:03.040399+00', 14456, 1, 1041, '', 'A', '', 1, 1, 'Y', 'bTfPfQc1mpo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1669, '2014-05-17 05:49:58.994763+00', '2014-06-18 13:17:22.23313+00', 1535, 1, 1733, '', 'C', 'Ngaio SCD Club annual dance, Wellington, New Zealand, May 10, 2014.', 1, 1, 'Y', 'OlyB0cV62lE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1696, '2014-06-20 08:24:04.336832+00', '2014-06-20 08:25:13.836389+00', 1244, 3, 106, '', 'A', 'Poor resolution video.', 1, 1, 'Y', '9Zrqkdcslbo', 10, 223, NULL);
INSERT INTO 'dancevideo' VALUES (1673, '2014-05-17 17:14:07.475346+00', '2014-06-20 09:09:07.778075+00', 1501, 5, 1777, '', 'D', 'Many sets in the hall.  Video keeps turning to the band. ', 1, 1, 'Y', 'eyD9prcr6So', 132, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1651, '2014-05-05 19:50:29.35281+00', '2014-06-20 09:17:55.858601+00', 6359, 2, 1041, '', 'B', 'Educational video to help everyone to take the floor and participate in the commonwealth ceilidh on the 21st June 2014', 1, 1, 'V', '89897917', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1682, '2014-06-09 01:02:35.123285+00', '2017-12-19 21:22:27.454115+00', 15457, 1, 106, '', 'B', 'Recorded at Chiswick SCDC 3/11/13. Newly-wed lawyers Helen and Ollie as first couple.



', 1, 1, 'Y', 'U8KpfNmpQ84', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1822, '2014-08-28 04:06:10.893356+00', '2014-08-28 04:10:45.011468+00', 13595, 1, 106, '', 'D', '', 1, 1, 'Y', 'DYd7Jtuzu0Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1700, '2014-06-20 11:49:23.853182+00', '2014-06-21 00:18:46.041742+00', 8335, 1, 197, '', 'C', 'Heather & Thistle Ball 2014, Colorado.

The video shows a full 32 bars, then breaks to show most of another 32 bars with a different set.', 1, 1, 'Y', 'necPWPWrK5s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1702, '2014-06-23 22:28:30.49964+00', '2014-06-23 22:33:20.490489+00', 9565, 1, 106, '', 'B', '', 1, 1, 'Y', 'S_6xmqAc9RE', 496, 616, NULL);
INSERT INTO 'dancevideo' VALUES (1444, '2013-10-14 19:28:28.378155+00', '2014-06-23 22:47:14.740099+00', 4246, 1, 106, '', 'B', 'Five couples Round the Room. Twice through.  Contrary to the instructions, the cross [7-8] is danced LH.



For this demo, the dance has been modified by keeping the couples together. In the original instructions, the Men stop the final promenade on bar 28, and the Women dance on, past one man and join the next as their new partner, to continue.



The dance ending of the second time through has also been modified, the dancers moving into the longwise set for the next demo.





The information for this dance has been derived from the video taken at Birmingham, Scottish dancing at Friday Folk New Year''s Eve Party 2012. See http://youtu.be/S_6xmqAc9RE, from 2:20 to 3.20



T', 1, 1, 'Y', 'S_6xmqAc9RE', 139, 204, NULL);
INSERT INTO 'dancevideo' VALUES (1705, '2014-06-25 09:40:31.831716+00', '2014-06-25 10:16:20.696167+00', 7090, 2, 513, '', 'C', 'Vienna, Branch 25th anniv.  June 2014.  8 x through.  Excellent view selection, keeping one single set in view for each time through. ', 1, 1, 'Y', 'PyX_8nHa0GA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1703, '2014-06-25 09:33:16.206887+00', '2014-06-25 12:18:48.017243+00', 8987, 1, 513, '', 'C', 'Full hall, 5 times through.  The dance is hard to follow at the beginning, but later on the set are well in view.

Vienna 25th anniversary, 2014', 1, 1, 'Y', 'KQHYcqmRe7g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1706, '2014-06-25 09:43:41.313648+00', '2014-06-25 13:55:33.594906+00', 904, 1, 513, '', 'C', '', 1, 1, 'Y', 'b6vcF5bdCf8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1313, '2013-08-18 10:55:49.963744+00', '2014-06-27 21:17:31.39886+00', 5262, 2, 1296, '', 'D', 'Caution: This is not the dance as written by John Bowie Dickson. It may be a misinterpretation or a deliberate variation, but it is not as written!', 1, 1, 'Y', 'vTgQ5QXQwak', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1707, '2014-07-07 22:01:37.676931+00', '2014-07-07 22:02:14.167988+00', 8165, 1, 1, '', 'C', 'Reasonable presentation of the dance with various small mistakes and weak phrasing.

The music stops in mid-turn.', 1, 1, 'Y', 'nzAZVp5Pa-A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1708, '2014-07-17 14:24:46.433261+00', '2014-07-23 16:32:43.325107+00', 15539, 1, 197, '', 'C', 'Very poor lighting; the dancers are hardly visible.', 1, 1, 'Y', 'CEAnRk6Y9mk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1709, '2014-07-17 20:32:20.367338+00', '2014-07-23 16:31:22.475536+00', 2976, 1, 197, '', 'B', 'Good viewpoinst but poor resolution.  Poor recording of the music.  

Watch the full video to see the coming on stage and leaving the stage.', 1, 1, 'Y', 'HEp2B3mkyqw', 28, 178, NULL);
INSERT INTO 'dancevideo' VALUES (1773, '2014-08-24 12:21:24.715842+00', '2014-08-24 12:24:49.181181+00', 10938, 1, 106, '', 'D', 'Regrettably the set most in view is quite confused.', 1, 1, 'Y', '-nl7EKW5y6M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1710, '2014-07-27 21:03:29.263659+00', '2014-07-27 21:04:26.518171+00', 6048, 8, 106, '', 'A', 'Scottish dancers performed for Happy Hoppers - April 20 2013



Published  6 jul. 2014

Shiftin Bobbins - Martin, Sally, Tom, Holly, John, Susan

http://www.rscds-swws.org/



Scottish dance friends had fun with Shiftin Bobbins music during a demo. Lead down the middle and up has the rare quality to cross 8-bar phrases. The spirit of the dance compelled us to respond with Hey! 



We closed the demo with a Square Dance tradition to thank the set for dancing.', 1, 1, 'Y', 'nMta1Z1pDZQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1711, '2014-07-29 15:07:35.203827+00', '2014-07-29 15:10:12.804336+00', 4102, 7, 106, '', 'B', 'The video calls the dance "Mairi''s Wedding", but 1c always passes R shoulder in the middle ("Mairi''s Divorce").  There is slight change to the figures, so that 1c ends in 3rd place, and then makes a turn and cast to reach 4th place when the next couple starts. 4 times through.', 1, 1, 'Y', 'LiIDYlogbME', 135, 315, NULL);
INSERT INTO 'dancevideo' VALUES (1712, '2014-07-29 15:21:02.649516+00', '2014-07-29 15:21:53.688112+00', 4102, 8, 106, '', 'C', 'This video is named s "Mairi''s Wedding", but is danced with Right Shoulder pass in the middle; i.e. it is the variant nicknamed "Mairi''s Divorce". Some couples add twirls.', 1, 1, 'Y', 'iE5JAulmqD0', 19, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1713, '2014-07-29 19:44:58.795611+00', '2014-07-29 19:47:18.153435+00', 13629, 2, 342, '', 'C', 'Taken at the RSCDS Vienna Branch 25th Jubilee Weekend - Welcome Dance on 6 June 2014.

Musicians: Muriel Johnstone and Keith Smith', 1, 1, 'Y', 'lYQtws0TH7E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1716, '2014-07-30 10:06:23.948178+00', '2014-07-30 23:31:55.713925+00', 13766, 1, 197, '', 'A', 'RSCDS Summer School 2014 Week 1 demo team

', 1, 1, 'Y', 'Lc1kupYhk_I', 0, 202, NULL);
INSERT INTO 'dancevideo' VALUES (1717, '2014-07-30 10:09:28.099054+00', '2014-07-30 23:32:59.741955+00', 5615, 1, 197, '', 'A', 'RSCDS Summer School 2014 Week 1', 1, 1, 'Y', 'Lc1kupYhk_I', 247, 369, NULL);
INSERT INTO 'dancevideo' VALUES (1719, '2014-08-07 17:12:57.221391+00', '2014-08-07 17:19:50.891742+00', 13163, 1, 513, '', 'A', '', 1, 1, 'Y', 'TRps-wKvKIs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1720, '2014-08-08 20:18:41.22787+00', '2014-08-10 07:53:02.023844+00', 5296, 4, 197, '', 'C', 'Danced at Bedford Scottish Dance Group Summer Ball, 17 May 2014 with the Silver Cross Band playing.', 1, 1, 'Y', 'cAxS5BjqYLo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1721, '2014-08-12 01:03:48.089679+00', '2014-08-12 19:50:30.951923+00', 3435, 5, 513, '', 'D', '', 1, 1, 'Y', 'Yr2L45khUvw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1722, '2014-08-12 01:04:35.842171+00', '2014-08-12 19:53:59.045014+00', 2495, 1, 513, '', 'C', '', 1, 1, 'Y', 'hRKJ1R9L3GQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1723, '2014-08-15 06:36:32.575257+00', '2014-08-18 03:55:20.599091+00', 753, 1, 513, '', 'C', '', 1, 1, 'Y', 'Pfbe3Hk5EpU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1724, '2014-08-15 06:37:40.292469+00', '2014-08-18 03:59:46.001407+00', 13544, 1, 513, '', 'A', '', 1, 1, 'Y', 'P_qxF8EyYQo', 60, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1725, '2014-08-15 06:38:38.287268+00', '2014-08-18 04:03:16.279735+00', 15402, 1, 513, '', 'A', '', 1, 1, 'Y', 'z1XzXm_AqoY', 52, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3459, '2018-03-08 16:38:16.496528+00', '2018-03-09 09:03:11.545012+00', 10376, 3, 596, '', 'X', '', 1, 1, 'Y', 'Yy8N59lpJP4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3506, '2018-04-16 07:49:10.701074+00', '2018-04-16 12:24:38.548774+00', 10938, 2, 513, '', 'C', '', 1, 1, 'Y', 'npuFMPvOkTU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1701, '2014-06-21 10:00:20.802332+00', '2018-09-03 22:31:31.827847+00', 633, 6, 1022, '', 'B', '', 1, 1, 'Y', 'd01Ixed7ueQ', 33, 138, NULL);
INSERT INTO 'dancevideo' VALUES (1726, '2014-08-16 22:58:36.41531+00', '2018-10-02 14:15:57.019078+00', 9103, 1, 106, '', 'X', '', 1, 1, 'Y', 'V6HEYZu-PBE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (1730, '2014-08-18 06:01:38.540285+00', '2018-10-01 14:22:09.411285+00', 9862, 5, 106, '', 'X', '', 1, 1, 'Y', 'ODby-tgPUts', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (1750, '2014-08-19 12:35:01.4164+00', '2014-08-20 13:09:44.790246+00', 15341, 1, 1330, '', 'B', 'As far as we know, the deviser Betty Mackenzie has not suggested any particular music for this dance. We therefore used Keith Smith and Muriel Johnstone''s lovely music for "In Campbell Country". The video shows the first 2 repetitions of the dance.', 1, 1, 'Y', '1QrdlD11xlg', 0, 138, NULL);
INSERT INTO 'dancevideo' VALUES (1752, '2014-08-23 08:38:27.993278+00', '2014-08-23 08:44:44.435031+00', 13052, 1, 106, '', 'C', 'Very pooor lighting.', 1, 1, 'Y', '7fk3UyKsIYo', 55, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1760, '2014-08-23 16:07:38.047992+00', '2014-08-23 16:16:43.769705+00', 301, 1, 106, '', 'A', '', 1, 1, 'Y', 't0F8YdrvaQg', 0, 258, NULL);
INSERT INTO 'dancevideo' VALUES (1753, '2014-08-23 08:46:50.938618+00', '2014-08-23 08:49:58.906179+00', 14975, 1, 106, '', 'B', '', 1, 1, 'Y', '8OGeX2knyg8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1758, '2014-08-23 15:44:50.342007+00', '2014-08-23 15:49:37.844707+00', 9381, 1, 106, '', 'A', '', 1, 1, 'Y', 'o70TbiLu_ro', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1755, '2014-08-23 10:58:09.319679+00', '2014-08-23 10:59:16.106778+00', 15574, 1, 106, '', 'B', '', 1, 1, 'Y', 'HMIbGxuz0t4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1759, '2014-08-23 15:57:25.578642+00', '2014-08-23 16:03:48.850629+00', 280, 1, 106, '', 'A', '', 1, 1, 'Y', 'XZHXixJK5O0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1756, '2014-08-23 11:13:54.48386+00', '2014-08-23 11:16:50.524926+00', 6885, 1, 106, '', 'B', '', 1, 1, 'Y', 'qW5iTEmebrY', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1757, '2014-08-23 11:22:49.507915+00', '2014-08-23 11:24:34.795677+00', 14568, 1, 106, '', 'B', '', 1, 1, 'Y', 'dBnH5tKwWDk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1761, '2014-08-23 16:20:50.306919+00', '2014-08-23 16:24:19.905103+00', 522, 1, 106, '', 'B', 'Only once through', 1, 1, 'Y', 'oXmAWL8Ixcg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (528, '2012-12-17 14:18:28.36985+00', '2014-08-23 16:37:24.050401+00', 2562, 2, 1296, '', 'A', 'Twice through.  View slightly from above, excellent for teaching.', 1, 1, 'Y', 'vANsSfNd_Kk', 0, 82, NULL);
INSERT INTO 'dancevideo' VALUES (1762, '2014-08-23 16:40:21.11371+00', '2014-08-23 16:44:18.289732+00', 742, 1, 106, '', 'A', 'This video only shows selected parts of the dance.  It starts on bar 57 (Chorus); some later bits are also skipped.



When a better video is found this one should be blocked.', 1, 1, 'Y', 'vANsSfNd_Kk', 149, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1827, '2014-08-28 04:47:52.580839+00', '2014-08-28 04:50:33.558892+00', 10327, 1, 106, '', 'D', '', 1, 1, 'Y', 'qD6BpyHrSAA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1763, '2014-08-23 18:57:33.871516+00', '2014-08-23 19:02:43.187351+00', 7520, 2, 106, '', 'D', 'Big hall; no continuous view of any set; hard to follow. ', 1, 1, 'Y', 'tsy3JIZnjHA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1764, '2014-08-23 19:11:23.947116+00', '2014-08-23 19:14:08.605553+00', 5812, 1, 106, '', 'A', '', 1, 1, 'Y', '0TbLSM6MApY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1765, '2014-08-23 20:06:47.825014+00', '2014-08-23 20:12:01.154422+00', 8524, 1, 106, '', 'B', '', 1, 1, 'Y', 'yAEHxkLcC4Q', 0, 119, NULL);
INSERT INTO 'dancevideo' VALUES (1769, '2014-08-24 09:06:57.055147+00', '2014-08-24 09:22:45.594102+00', 5872, 1, 106, '', 'C', '', 1, 1, 'Y', '0VtQD6qKczY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1772, '2014-08-24 12:06:50.812186+00', '2014-08-24 12:08:57.497318+00', 5463, 1, 106, '', 'D', '', 1, 1, 'Y', 'RIalF-h5AD0', 0, 345, NULL);
INSERT INTO 'dancevideo' VALUES (1775, '2014-08-24 13:36:45.065667+00', '2014-08-24 13:41:25.472482+00', 4195, 1, 106, '', 'D', '', 1, 1, 'Y', 'Dnm42Wcf8HA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1780, '2014-08-24 14:37:01.52864+00', '2014-08-24 14:42:14.890593+00', 3866, 1, 106, '', 'B', '', 1, 1, 'Y', '67As6dBxiBg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1791, '2014-08-25 05:27:07.269041+00', '2014-08-25 05:29:10.387481+00', 13687, 1, 106, '', 'D', '', 1, 1, 'Y', 'VrHYgCPTfLk', 47, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1781, '2014-08-24 19:43:51.394292+00', '2014-08-24 19:58:27.587971+00', 3636, 1, 106, '', 'B', '', 1, 1, 'Y', 'KHqN7ylItyA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1782, '2014-08-24 20:00:21.763676+00', '2014-08-24 20:05:58.160268+00', 12124, 1, 106, '', 'B', '', 1, 1, 'Y', 'lrFhbtueb14', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1783, '2014-08-24 20:10:24.11878+00', '2014-08-24 20:16:30.100689+00', 893, 1, 106, '', 'A', 'Part of a display, once through, end modified.', 1, 1, 'Y', 'Ky2KZdEV60Y', 150, 210, NULL);
INSERT INTO 'dancevideo' VALUES (1812, '2014-08-26 20:01:34.493235+00', '2014-08-26 20:01:50.566308+00', 15579, 1, 106, '', 'B', '', 1, 1, 'Y', 'zfOBgD-W-BA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1792, '2014-08-25 05:42:44.813956+00', '2014-08-25 05:46:18.067478+00', 11985, 1, 106, '', 'B', '', 1, 1, 'Y', 'JCf5a_-TkPk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1784, '2014-08-24 20:20:58.941495+00', '2014-08-24 20:23:18.883524+00', 7637, 1, 106, '', 'B', 'Part of a display. Once through.', 1, 1, 'Y', 'NJsCmAQ9mYE', 120, 184, NULL);
INSERT INTO 'dancevideo' VALUES (1793, '2014-08-25 05:53:24.030341+00', '2014-08-25 05:55:40.232431+00', 2809, 1, 106, '', 'B', '', 1, 1, 'Y', '8rfInn5A4XI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1851, '2014-09-27 09:35:31.917167+00', '2014-09-27 22:25:52.046873+00', 7284, 3, 1022, '', 'A', '', 1, 1, 'Y', 'XYjLQfc0Y_c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1852, '2014-09-28 00:10:12.519873+00', '2014-09-28 10:31:47.277935+00', 2312, 1, 513, '', 'C', '', 1, 1, 'Y', 'gyitOW45S8M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1853, '2014-09-28 10:21:58.436806+00', '2014-09-28 13:52:30.872779+00', 4102, 11, 106, '', 'C', '', 1, 1, 'V', '27901683', 0, 198, NULL);
INSERT INTO 'dancevideo' VALUES (3458, '2018-03-08 16:37:17.65455+00', '2018-03-09 09:01:30.579086+00', 15437, 2, 596, '', 'X', '', 1, 1, 'Y', 'br4q4BSC0n0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1859, '2014-10-07 23:36:59.689336+00', '2014-10-08 16:36:00.383947+00', 15657, 1, 197, '', 'A', 'Danced as a demonstration by dancers, including the deviser, Louise, from York at the last night ceilidh of a Scottish Dancing holiday to Conil de la Frontera, Spain in February 2014.', 1, 1, 'Y', 'g8HRQTJUlJo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1863, '2014-10-08 22:04:39.119519+00', '2014-10-08 22:05:32.611881+00', 14138, 2, 106, '', 'A', 'Part of a demo; once only', 1, 1, 'Y', 'fL4TH0lekBA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1864, '2014-10-08 22:15:49.432164+00', '2014-10-08 22:21:26.4684+00', 4102, 12, 106, '', 'C', 'At RSCDS AGM Perth 1-2 november 2013', 1, 1, 'Y', '-RTVG0kSz7E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1865, '2014-10-13 22:58:56.912783+00', '2014-10-14 07:32:14.270419+00', 7282, 3, 1022, '', 'B', 'Clear demonstration to learn from.', 1, 1, 'Y', 'v1Zo2lRz6ik', 82, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1866, '2014-10-14 21:53:39.270513+00', '2014-10-14 22:01:40.601983+00', 2494, 1, 106, '', 'B', '', 1, 1, 'Y', 'f50AE4GblCI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1507, '2013-12-17 16:24:13.857982+00', '2014-10-19 15:40:04.148535+00', 3252, 4, 1041, '', 'C', 'music too fast / some dancing out of step

', 1, 1, 'Y', 'L4xuJdS9gQk', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1867, '2014-10-20 09:27:34.160536+00', '2014-10-20 10:30:04.641374+00', 15413, 1, 513, '', 'C', '', 1, 1, 'Y', 'GseAMLlbxSE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1785, '2014-08-24 20:56:24.21015+00', '2014-08-24 21:00:06.226626+00', 1125, 1, 106, '', 'A', 'This is not so much a single dance as a recipe for producing thousands of millions of different dances in a highly prescriptive format of figures within the Celtic Brooch set, an unusual form of circular set for three couples; all the Ls perform the same movements at the same time and all the Mn similarly. Every 32-bar sequence contains the distinctive figure, The Theme, danced by the Ls in bars 1-12 and by the Mn in bars 17-28; while The Theme is being danced (by those whom the deviser, Hugh Foss, calls the "outsiders"), their partners (the "insiders") dance three complementary 4-bar figures (or, occasionally, one 12-bar figure) of which the deviser identifies 57 (and invites others to devise more). A Celtic Brooch dance is any six of these different 32-bar sequences in succession and so an immense variety of combinations is possible. Hugh Foss identifies three groups of six sequences as detailed in the separate dance instructions:

The Celtic Brooch (Elementary), The Celtic Brooch (Intermediate) and The Celtic Brooch (Advanced). He codifies and lists the 57 complementary figures. 



Note that this video is of a display consisting of only four sequences, codes 10Ax3, 43A, 21C and 30A+40A+30A followed by a choreographed exit. 



For more detail consult http://www.scottish-country-dancing-dictionary.com/dance-crib/celtic-brooch.html', 1, 1, 'Y', 'P5Md8qZPCo4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1786, '2014-08-24 21:03:31.245427+00', '2014-08-24 21:07:19.023094+00', 7362, 1, 106, '', 'B', '', 1, 1, 'Y', 'D3dBD6rEScQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1787, '2014-08-24 21:16:06.632932+00', '2014-08-24 21:18:24.244893+00', 13259, 1, 106, '', 'B', '', 1, 1, 'Y', 'QxiDbHDkYKc', 0, 70, NULL);
INSERT INTO 'dancevideo' VALUES (1788, '2014-08-24 22:21:29.732688+00', '2014-08-24 22:28:18.005583+00', 1616, 1, 106, '', 'C', 'Begins 5 bars late.  Spends some time viewing the band.  Better later on.', 1, 1, 'Y', 'pyofQQ2RWOM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1771, '2014-08-24 12:03:17.686127+00', '2014-09-10 22:30:37.628773+00', 5843, 1, 513, '', 'C', '', 1, 1, 'Y', 'xoBGZgXX6t0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1790, '2014-08-25 05:13:13.760535+00', '2014-08-25 05:20:34.103866+00', 13647, 1, 106, '', 'D', '', 1, 1, 'Y', '7yqwTw5b7R0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1813, '2014-08-26 20:34:34.624749+00', '2014-08-26 20:34:44.815086+00', 15580, 1, 106, '', 'A', '', 1, 1, 'Y', 'rqmmqfJEZb8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1794, '2014-08-25 06:02:54.907876+00', '2014-08-25 06:06:49.386254+00', 10822, 1, 106, '', 'A', '', 1, 1, 'Y', 'ifNGenCxbXI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1796, '2014-08-25 06:26:30.417931+00', '2014-08-25 06:30:30.809122+00', 8058, 1, 106, '', 'B', 'Part of a display.  Adapted for a 5C set, and using the RHA-LHA option for bars 5-8 and 13-16. Twice through.', 1, 1, 'Y', 'bvq2LF4Wc48', 0, 75, NULL);
INSERT INTO 'dancevideo' VALUES (1814, '2014-08-26 20:40:07.264827+00', '2014-08-26 20:54:23.63308+00', 15581, 1, 106, '', 'B', '', 1, 1, 'Y', 'SCyLDvMNAuY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1797, '2014-08-25 07:53:34.592424+00', '2014-08-25 07:54:49.725365+00', 3201, 1, 106, '', 'A', '', 1, 1, 'Y', 'Lh5gDfMNBUY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1798, '2014-08-25 11:29:32.023287+00', '2014-08-25 11:32:23.751725+00', 13618, 1, 106, '', 'C', '', 1, 1, 'Y', 'AMrKcni0ZkA', 9, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1799, '2014-08-26 12:08:20.553589+00', '2014-08-26 12:08:40.27906+00', 9561, 2, 106, '', 'A', '', 1, 1, 'Y', 'HoGtQaPeFqs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1830, '2014-08-28 15:08:59.254341+00', '2014-08-28 15:09:25.218436+00', 10327, 4, 106, '', 'D', '', 1, 1, 'Y', 'SZqk6BNBdZo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1805, '2014-08-26 15:50:25.821204+00', '2014-08-26 15:51:57.823503+00', 11523, 1, 106, '', 'D', '', 1, 1, 'Y', 'Z3eQh5Fe_Sg', 193, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1766, '2014-08-23 20:15:34.493383+00', '2021-10-09 20:32:45.678102+00', 4015, 5, 106, '', 'Z', 'Video now unavailable (was classified as good).', 1, 1, 'Y', 'yAEHxkLcC4Q', 122, 313, NULL);
INSERT INTO 'dancevideo' VALUES (1807, '2014-08-26 17:01:01.449647+00', '2014-08-26 17:02:37.778278+00', 15576, 1, 106, '', 'B', '', 1, 1, 'Y', 'bzeVt4AqSKg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1808, '2014-08-26 19:29:55.096723+00', '2014-08-26 19:30:08.688106+00', 15577, 1, 106, '', 'C', '', 1, 1, 'Y', 'Op0ioEkQydc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1815, '2014-08-26 21:02:49.387751+00', '2014-08-26 21:03:01.700882+00', 15582, 1, 106, '', 'C', '', 1, 1, 'Y', 'YvcC2v2iLBs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1809, '2014-08-26 19:37:47.333093+00', '2014-08-26 19:42:51.764707+00', 15578, 1, 106, '', 'A', '', 1, 1, 'Y', 'y1yuN8-mg-E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1811, '2014-08-26 19:49:54.834121+00', '2014-08-26 19:50:28.506032+00', 3326, 4, 106, '', 'C', '', 1, 1, 'Y', 'zei9hswwjJk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1810, '2014-08-26 19:38:16.976028+00', '2014-08-26 19:50:56.510818+00', 15578, 2, 106, '', 'A', 'DemoTeam RSCDS Winter School, 2013.   Clan McBédoin are most grateful to the group who rehearsed this Dance at the RSCDS Winter School 2013, for this first expert performance. ', 1, 1, 'Y', 'EFQzWk89pI8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1816, '2014-08-26 21:11:32.576933+00', '2014-08-26 21:11:43.317272+00', 15583, 1, 106, '', 'B', '', 1, 1, 'Y', 'ArS0RXhpmw8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1817, '2014-08-26 21:22:38.011645+00', '2014-08-26 21:24:05.110302+00', 15584, 1, 106, '', 'A', '', 1, 1, 'Y', 'QVsgJbtqYPk', 28, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1818, '2014-08-26 21:34:16.820875+00', '2014-08-26 21:34:27.49104+00', 15585, 1, 106, '', 'C', '', 1, 1, 'Y', 'kySh1gnfvG0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1826, '2014-08-28 04:09:26.985113+00', '2014-08-28 04:09:46.784306+00', 13595, 5, 106, '', 'D', '', 1, 1, 'Y', 'RzmxpV1QhSo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1819, '2014-08-26 21:52:08.457144+00', '2014-08-26 21:54:56.417653+00', 15586, 1, 106, '', 'C', '', 1, 1, 'Y', 'QnWf7-N7P_U', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3462, '2018-03-08 16:41:05.238661+00', '2018-03-09 09:04:20.410525+00', 11858, 1, 596, '', 'X', '', 1, 1, 'Y', 'B0nE5OdOEMA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1747, '2014-08-18 08:15:42.603738+00', '2018-10-03 22:15:17.683047+00', 12428, 3, 106, '', 'X', '', 1, 1, 'Y', 'rgTbHPfvEr0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (1748, '2014-08-18 14:01:36.672409+00', '2014-08-18 14:01:47.886758+00', 15565, 1, 106, '', 'X', '', 1, 1, 'Y', 'mSiGi4DpSh0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (1825, '2014-08-28 04:08:55.363546+00', '2014-08-28 04:10:02.65486+00', 13595, 4, 106, '', 'D', '', 1, 1, 'Y', 'E0eSGXWdeqA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1820, '2014-08-26 22:07:24.499461+00', '2014-08-26 22:12:28.973773+00', 15587, 1, 106, '', 'B', '', 1, 1, 'Y', 'VC1nJhTn7Ws', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1824, '2014-08-28 04:08:17.78093+00', '2014-08-28 04:10:13.224914+00', 13595, 3, 106, '', 'D', '', 1, 1, 'Y', 'AY7ee8s_qZo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1821, '2014-08-26 22:16:13.914308+00', '2014-08-26 22:17:25.516873+00', 15588, 1, 106, '', 'D', '', 1, 1, 'Y', 'ge379HXPIF8', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1828, '2014-08-28 14:07:34.390336+00', '2014-08-28 14:08:19.517673+00', 10327, 2, 106, '', 'D', '', 1, 1, 'Y', 'Dd1XJsyComw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1829, '2014-08-28 14:15:05.076584+00', '2014-08-28 14:15:35.528284+00', 10327, 3, 106, '', 'D', 'In this variant, bars 9-16 are Advance and Retire ; dance BtoB starting L shoulder.  Only 1c slips down at the end.', 1, 1, 'Y', 'a81yG8QwuCc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1831, '2014-09-03 21:04:49.893322+00', '2014-09-03 21:41:51.262289+00', 3441, 1, 1041, '', 'B', '', 1, 1, 'Y', 'fNX44hLn21w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1833, '2014-09-03 21:28:59.969226+00', '2014-09-04 09:16:55.278219+00', 15421, 2, 1041, '', 'B', '', 1, 1, 'Y', 'pqC09ed3jFE', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1835, '2014-09-08 09:44:40.724326+00', '2014-09-08 09:54:56.132867+00', 4102, 10, 274, '', 'A', 'Four times', 1, 1, 'Y', 'r7qyFX-EbCg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1832, '2014-09-03 21:28:26.008848+00', '2014-09-04 09:22:28.313782+00', 15421, 1, 1041, '', 'B', '', 1, 1, 'Y', 'x7KemGUSebU', 88, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1834, '2014-09-06 19:35:01.138183+00', '2014-09-06 19:35:30.418453+00', 5525, 14, 106, '', 'C', '', 1, 1, 'Y', '-aTECFCX9PU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1838, '2014-09-10 14:27:53.897638+00', '2014-09-10 15:39:12.056777+00', 15619, 1, 513, '', 'C', '', 1, 1, 'Y', 'u0MzHlpoJCQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1837, '2014-09-08 09:50:13.346828+00', '2014-09-10 22:18:36.258094+00', 2267, 6, 274, '', 'A', 'Two times', 1, 1, 'Y', '9pxSrd8QtOw', 138, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1806, '2014-08-26 16:25:33.102264+00', '2014-09-10 22:24:43.809527+00', 15575, 1, 106, '', 'A', '', 1, 1, 'Y', 'qiqTjOEJMgc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1839, '2014-09-13 13:08:21.846858+00', '2014-09-14 21:51:57.737439+00', 3791, 3, 1586, '', 'B', '3C set, 3 times through. Bars 28-32 modified awkwardly to get 1c to 3pl facing out.  The video gives the  impression of being distorted; expanded laterally. ', 1, 1, 'Y', 'zJdqoMC3S2E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1840, '2014-09-19 10:26:16.0275+00', '2014-09-19 10:36:28.690602+00', 3725, 1, 1022, '', 'C', '', 1, 1, 'Y', 'H4eL-zRuhjs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1842, '2014-09-22 14:32:51.178368+00', '2014-09-22 14:37:58.169497+00', 9760, 1, 106, '', 'C', '', 1, 1, 'Y', '06HF8XoDTuk', 26, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1845, '2014-09-22 14:52:42.900259+00', '2014-09-22 15:00:29.171184+00', 9770, 2, 106, '', 'C', '', 1, 1, 'Y', 'iggbdJa6xxM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1844, '2014-09-22 14:47:35.233298+00', '2014-09-22 14:58:35.998136+00', 9770, 1, 106, '', 'B', '', 1, 1, 'Y', 'qiFl-5TFeYI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1847, '2014-09-22 15:15:20.597988+00', '2014-09-22 15:22:10.698418+00', 9761, 1, 106, '', 'C', '', 1, 1, 'Y', 'ZV6ggOcT6-w', 40, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1854, '2014-09-28 16:33:02.879251+00', '2014-09-28 19:32:40.550698+00', 7313, 2, 274, '', 'B', 'Two times through, last bar missing.', 1, 1, 'Y', 'LWB88VFVuwM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1856, '2014-09-29 13:24:41.739931+00', '2014-09-29 13:41:24.071672+00', 7312, 1, 274, '', 'B', '', 1, 1, 'Y', 'xgyrf9MK5jc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1855, '2014-09-29 13:04:26.151634+00', '2014-09-29 13:44:28.837283+00', 7311, 1, 274, '', 'B', '', 1, 1, 'Y', 'VgRXca1AyqA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1857, '2014-10-01 12:29:38.673736+00', '2014-10-01 12:44:03.284943+00', 5062, 1, 81, '', 'A', 'An extract from the RSCDS pack ''Jigs and Reels''', 1, 1, 'Y', 'FJXpanKJUA0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1862, '2014-10-08 09:09:20.152625+00', '2014-10-08 09:19:27.714483+00', 6451, 1, 2213, '', 'B', '', 1, 1, 'Y', 'eyfDCcSbdBA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1860, '2014-10-08 08:53:51.27798+00', '2014-10-08 09:44:32.84836+00', 14688, 2, 2213, '', 'A', '', 1, 1, 'Y', 'Mlc3wxHxoSg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1861, '2014-10-08 09:05:33.281032+00', '2014-10-08 16:28:37.207152+00', 10298, 1, 2213, '', 'B', '', 1, 1, 'Y', 'wLTdBMUeWIk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1868, '2014-10-20 09:27:55.27674+00', '2014-10-20 10:31:32.248473+00', 15413, 2, 513, '', 'C', '', 1, 1, 'Y', 'SFKilTVqsa0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (499, '2012-12-17 14:18:15.243288+00', '2014-10-20 20:24:39.884164+00', 2063, 1, 1296, '', 'B', 'Part of a longer display.  View from floor level, but all formations are easy to follow, although top end is off screen during part of first time through.  Suitable for teaching.', 1, 1, 'Y', 'Q8Pn4Q2PcMg', 120, 195, NULL);
INSERT INTO 'dancevideo' VALUES (3463, '2018-03-08 16:41:58.036149+00', '2018-03-09 09:02:21.438942+00', 10232, 4, 596, '', 'X', '', 1, 1, 'Y', 'OBQWIgLcxGs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1869, '2014-10-21 19:50:55.897595+00', '2014-10-22 10:55:29.819439+00', 894, 2, 1041, '', 'C', 'Twice through only', 1, 1, 'Y', 'IZoIU1Fm7UQ', 46, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3531, '2018-05-08 12:18:13.193034+00', '2018-05-12 20:24:40.280459+00', 17265, 1, 586, '', 'A', '', 1, 1, 'Y', 'GPVs3NN4gtU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3510, '2018-04-16 08:30:18.123651+00', '2018-04-16 19:42:32.245193+00', 12466, 1, 513, '', 'D', 'The 1st two times through are looking ok.', 1, 1, 'Y', 'HyG9P2SW5sA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3534, '2018-05-16 01:31:22.470007+00', '2018-05-16 01:51:02.510176+00', 9109, 1, 2372, '', 'A', '', 1, 1, 'Y', 'iSZFCvaQf-M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1870, '2014-10-21 19:51:34.856216+00', '2014-10-27 20:39:19.180664+00', 894, 3, 1041, '', 'C', 'Slightly truncated at the beginning and end; once through.  The turn on [5-8] is done RH; it should be BH.', 1, 1, 'Y', 'ZSUyfM25hfw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1945, '2015-02-17 23:06:03.366385+00', '2015-02-21 00:38:47.828158+00', 5885, 7, 513, '', 'A', '', 1, 1, 'Y', 'NCwNaPmCT-I', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2164, '2015-09-10 16:43:45.282055+00', '2015-09-12 22:14:25.496545+00', 15402, 2, 513, '', 'A', '', 1, 1, 'Y', 'g41pWyeu7YU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1880, '2014-11-01 00:56:39.478502+00', '2014-11-01 00:56:50.387888+00', 10794, 1, 106, '', 'A', 'Scottish Flowers dancing "James Gray" at the 2014 Highland Gathering in Peine.', 1, 1, 'Y', '-du4h1uBnHM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1882, '2014-11-01 12:41:44.341361+00', '2014-11-02 11:39:01.743619+00', 10008, 1, 1041, '', 'C', '', 1, 1, 'Y', 'wAGh9EeVnU0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1881, '2014-11-01 12:10:17.65125+00', '2014-11-02 12:56:01.260998+00', 2110, 1, 1041, '', 'D', 'Begins on bar 11.', 1, 1, 'Y', 'uoT7Jhfox5E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3508, '2018-04-16 08:01:29.988082+00', '2020-03-24 15:18:15.640143+00', 17922, 2, 513, '', 'B', 'The video starts around bar 5 (with the deviser as 1st woman).', 1, 1, 'Y', 'LuqQ5kFH3j4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1883, '2014-11-03 16:25:54.710303+00', '2014-11-03 23:58:30.22113+00', 15429, 1, 1666, '', 'B', 'The dancing is good, and the dance is fully "called" during the video, but the camera position and the fraction of the set shown change so often and so suddenly that only experienced dancers can follow the dance.  Video unsuitable for teaching.', 1, 1, 'V', '89725499', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1884, '2014-11-05 07:46:43.996822+00', '2014-11-05 10:06:20.796008+00', 700, 1, 106, '', 'C', '', 1, 1, 'Y', '0NKzOnVZMUE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1885, '2014-11-09 23:26:49.532267+00', '2014-11-09 23:55:35.365454+00', 10008, 2, 2213, '', 'C', '', 1, 1, 'Y', 'z6OgMKB_Kes', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1886, '2014-11-09 23:34:57.565896+00', '2014-11-10 00:04:37.725843+00', 1405, 1, 2213, '', 'C', 'Towards the end of the dance, most couples finished the dance with a birl instead of turning with the right hand. 

There were one or two 5 couple sets in the Hall so Ian Muir kindly played the music 10 times through.  Therefore the first and second couples in the other sets got an extra turn. ', 1, 1, 'Y', 'Ls-ahILURkQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1888, '2014-11-11 01:16:38.89558+00', '2014-11-11 11:02:01.031912+00', 980, 1, 1, '', 'B', 'RSCDS Conference Weekend 2014.', 1, 1, 'Y', 'V-BWYhwgv_w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1887, '2014-11-11 01:15:59.796049+00', '2014-11-11 11:03:26.979195+00', 1280, 4, 1, '', 'C', 'RSCDS Conference Weekend 2014.', 1, 1, 'Y', 'kFFK0p4LEbQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1889, '2014-11-11 01:17:24.243567+00', '2014-11-11 11:05:52.939929+00', 2498, 2, 1, '', 'C', 'RSCDS Conference Weekend 2014.', 1, 1, 'Y', 'xVXxCSLfNfk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1896, '2014-11-27 11:30:48.146454+00', '2014-11-27 11:33:58.31999+00', 14548, 1, 1, '', 'B', '', 1, 1, 'Y', 'ljiqhX21y30', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1892, '2014-11-22 13:29:00.964748+00', '2014-11-27 11:34:28.233769+00', 6798, 2, 274, '', 'B', '', 1, 1, 'Y', 'UESdMzMYYWg', 66, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1894, '2014-11-25 09:06:44.240072+00', '2014-11-29 17:29:21.634769+00', 6532, 4, 2302, '', 'A', '', 1, 1, 'Y', 'Yy8eYKUnauQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1897, '2014-12-03 21:57:57.511897+00', '2014-12-05 02:44:57.029049+00', 56, 1, 106, '', 'D', 'Milton Keynes Ball in 2010 with George Meikle playing.



Some poor sections and incomplete parts of the video were clipped; only twice through (of 5) remains.', 1, 1, 'Y', 'KqpukUE8qSA', 62, 130, NULL);
INSERT INTO 'dancevideo' VALUES (1909, '2015-01-05 08:37:53.057107+00', '2015-01-05 13:53:56.07542+00', 2228, 1, 106, '', 'B', '', 1, 1, 'Y', 'OBahSJNSNP0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1908, '2015-01-04 22:41:08.176796+00', '2015-02-20 23:59:22.528449+00', 9636, 1, 2269, '', 'Z', 'Video starts at bar 9. and only once through.  Seen from the bottomof the set; the movements are hard to follow.  Has no value for dancers or teachers.  Eric.', 1, 1, 'Y', 'pHIyaSOLLlY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1906, '2015-01-03 21:47:45.661833+00', '2015-02-21 00:11:46.865114+00', 1615, 2, 1240, '', 'B', '', 1, 1, 'Y', 'e7DH3HvJMB0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1989, '2015-02-25 09:59:01.455546+00', '2015-02-27 21:03:43.837399+00', 6091, 6, 1041, '', 'B', 'This is a "teaching video", where the formations are briefed while being danced, and the bar numbers are shown on screen.', 1, 1, 'Y', 'GW0pPpqauOY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1903, '2015-01-03 21:22:27.405615+00', '2015-02-21 00:43:44.078106+00', 10920, 5, 1240, '', 'B', 'The end of the dance calls for one-and-a-half turns by fourth and first couples (at the bottom of the set), although birling is sometimes seen in social situations.', 1, 1, 'Y', 'dafexREB3IQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3466, '2018-03-08 16:44:25.822961+00', '2018-03-09 09:01:48.756731+00', 152, 1, 596, '', 'X', '', 1, 1, 'Y', 'rz-QJicKF5k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3464, '2018-03-08 16:42:49.307959+00', '2018-03-09 09:02:54.590522+00', 4444, 1, 596, '', 'X', '', 1, 1, 'Y', 'errmpibqFvE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1991, '2015-02-25 10:03:19.06129+00', '2015-02-26 14:58:09.982993+00', 13270, 2, 1041, '', 'B', '', 1, 1, 'Y', 'emv_m8TuyX4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1900, '2014-12-24 16:15:17.982972+00', '2015-02-26 15:08:33.48412+00', 2409, 3, 1056, '', 'B', '', 1, 1, 'Y', 'uuh6qs_vGEE', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1984, '2015-02-25 09:51:43.601109+00', '2015-02-26 15:14:54.858905+00', 4015, 7, 1041, '', 'B', '', 1, 1, 'Y', 'Kt2jhkXrryo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1893, '2014-11-23 13:11:40.886299+00', '2015-02-26 20:22:47.957216+00', 7124, 1, 274, '', 'D', 'Burns Night. Caledonian Pub, Budapest.  Very crowded; poor lighting; not useful for learning the dance.', 1, 1, 'Y', 'XksOXr37bII', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1904, '2015-01-03 21:27:01.233958+00', '2015-02-27 20:44:38.583141+00', 4102, 13, 1240, '', 'B', '', 1, 1, 'Y', '3ypcAbXEwtg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1905, '2015-01-03 21:35:42.639535+00', '2015-02-27 20:45:38.742152+00', 5209, 11, 1240, '', 'B', '', 1, 1, 'Y', '4V0zBCUXTLM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1990, '2015-02-25 10:01:32.607836+00', '2015-02-27 21:06:56.0715+00', 4046, 6, 1041, '', 'B', 'This is a "teaching video", where the formations are briefed while being danced, and the bar numbers are shown on screen.', 1, 1, 'Y', 'Z9d92zdoktE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1988, '2015-02-25 09:57:56.227167+00', '2015-02-27 21:07:53.596953+00', 5621, 3, 1041, '', 'B', 'This is a "teaching video", where the formations are briefed while being danced, and the bar numbers are shown on screen.', 1, 1, 'Y', 'BJS_RDLIvCM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1987, '2015-02-25 09:56:55.02005+00', '2015-02-27 21:10:23.755459+00', 7204, 4, 1041, '', 'B', 'This is a "teaching video", where the formations are briefed while being danced, and the bar numbers are shown on screen.', 1, 1, 'Y', '3aLDWToKIyQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1985, '2015-02-25 09:53:59.198944+00', '2015-02-27 21:27:18.172498+00', 5529, 12, 1041, '', 'B', 'This is a "teaching video", where the formations are briefed while being danced, and the bar numbers are shown on screen.', 1, 1, 'Y', '1gpmxe7PwRM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1907, '2015-01-04 22:19:36.115029+00', '2015-02-27 21:29:00.886869+00', 5982, 4, 2269, '', 'A', '', 1, 1, 'Y', 'k355TQE80Uw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1899, '2014-12-24 16:06:31.991529+00', '2015-02-27 22:24:03.299006+00', 5927, 1, 1056, '', 'B', '', 1, 1, 'Y', 'ioOutNOquW8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3467, '2018-03-08 16:45:35.837864+00', '2018-03-09 09:03:27.301666+00', 4662, 3, 596, '', 'X', '', 1, 1, 'Y', 'tjNTHRd-vqk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1890, '2014-11-19 15:50:05.383299+00', '2015-03-19 10:30:16.339609+00', 12669, 2, 81, '', 'C', '', 1, 1, 'V', '111086388', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3465, '2018-03-08 16:43:38.888616+00', '2018-03-09 09:03:41.29609+00', 5006, 2, 596, '', 'X', '', 1, 1, 'Y', 'O-CtWb3qlHo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3468, '2018-03-08 16:47:16.932672+00', '2018-03-09 09:03:56.150377+00', 10920, 9, 596, '', 'X', 'This is a correction. It should replace the Danciemaetion of Scott Meikle currently available.', 1, 1, 'Y', 'Jdf8WoL-Dtc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3460, '2018-03-08 16:39:11.230006+00', '2018-03-09 09:02:02.141657+00', 232, 1, 596, '', 'X', '', 1, 1, 'Y', '3Q1fyN2smA0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3511, '2018-04-17 00:40:03.1012+00', '2018-04-17 00:40:03.1012+00', 3418, 3, 1296, '', 'X', '"The Kelloholm Jig" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'aqahK0pOY3U', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (1914, '2015-02-02 14:02:12.286935+00', '2015-02-12 21:26:44.710791+00', 9711, 2, 106, '', 'C', 'This video shows a different version of this dance, it does not agree with the description of this entry.', 1, 1, 'Y', 'widr6oY2CUo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1843, '2014-09-22 14:39:37.40142+00', '2022-03-13 23:06:50.94224+00', 9768, 1, 106, '', 'B', '', 1, 1, 'Y', '4xoBTjAjTYo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1846, '2014-09-22 15:02:25.975546+00', '2022-03-14 00:21:47.045748+00', 9766, 1, 106, '', 'C', '', 1, 1, 'Y', 'BJP4RcwzgQo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3533, '2018-05-16 01:28:15.135236+00', '2018-05-16 01:48:46.02444+00', 11044, 1, 2372, '', 'A', '', 1, 1, 'Y', 'AUyFxVrlGOo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1949, '2015-02-21 21:52:46.794337+00', '2015-02-22 09:36:50.468204+00', 9636, 2, 1041, '', 'B', 'Incomplete: once through and the first half of the second time through.', 1, 1, 'Y', '60uojLsvxFU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3576, '2018-06-12 17:23:56.129891+00', '2018-06-12 17:35:24.869885+00', 18361, 1, 1645, '', 'A', '', 1, 1, 'Y', '-3pC0XfzEtQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3574, '2018-06-12 17:09:07.58356+00', '2018-06-12 17:37:33.007045+00', 18367, 1, 1645, '', 'A', '', 1, 1, 'Y', 'FFcBypDKsy8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1921, '2015-02-04 09:36:05.206338+00', '2015-02-18 23:06:27.007326+00', 312, 2, 1022, '', 'C', '', 1, 1, 'Y', '-abzVqP5YDE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1933, '2015-02-17 09:45:37.011704+00', '2015-02-21 00:08:03.345592+00', 15411, 1, 1675, '', 'A', '', 1, 1, 'Y', 'pht7uIhzo1M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1915, '2015-02-02 14:13:39.77643+00', '2015-02-21 00:44:56.930295+00', 9711, 3, 106, '', 'C', 'This video shows a version of this dance that differs from the description of this entry', 1, 1, 'Y', 'NIy_s52AlMQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1917, '2015-02-04 08:33:19.246819+00', '2015-02-21 00:52:39.487524+00', 8158, 3, 274, '', 'C', 'Bar 13-16 changed to 1/2 LHA...', 1, 1, 'Y', 'vk7rPZ9v--Y', 39, 139, NULL);
INSERT INTO 'dancevideo' VALUES (1922, '2015-02-06 16:30:38.530982+00', '2015-02-21 00:57:34.214706+00', 7795, 3, 2455, '', 'B', '', 1, 1, 'Y', '6HhM70lKQzk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1941, '2015-02-17 22:00:09.583312+00', '2015-02-21 01:03:17.20032+00', 9332, 1, 513, '', 'C', '', 1, 1, 'Y', '4Hj5myTWhIQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1939, '2015-02-17 21:28:28.852292+00', '2015-02-21 01:20:13.569315+00', 6964, 4, 1024, '', 'A', '', 1, 1, 'Y', 'FzaUyUbw0gU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3575, '2018-06-12 17:20:09.162621+00', '2018-06-12 17:39:35.296958+00', 18369, 1, 1645, '', 'A', '', 1, 1, 'Y', 'FgY0e76a3Xs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1953, '2015-02-22 10:30:02.806584+00', '2015-02-22 10:31:10.151992+00', 2242, 1, 106, '', 'C', '', 1, 1, 'Y', 'kGpiyWbBXbg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1955, '2015-02-22 22:35:20.982776+00', '2015-02-23 01:27:36.36859+00', 822, 1, 1041, '', 'A', '', 1, 1, 'Y', 'MUjCMqR_p4w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3577, '2018-06-12 23:32:41.287863+00', '2018-06-12 23:33:17.135686+00', 18383, 1, 106, '', 'A', '', 1, 1, 'Y', 'iJlGNKvIEPs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1967, '2015-02-24 20:36:44.582941+00', '2015-02-26 14:16:07.507734+00', 132, 3, 1041, '', 'A', '', 1, 1, 'Y', 'ijp9eUy7lQ8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1978, '2015-02-25 07:32:21.543625+00', '2015-02-26 14:21:03.290378+00', 1244, 5, 1041, '', 'B', '', 1, 1, 'Y', 'B7rAkbn_nJw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1964, '2015-02-24 20:20:20.439668+00', '2015-02-26 14:38:54.531705+00', 10792, 1, 1041, '', 'A', '', 1, 1, 'Y', 'fapi898pr1w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1959, '2015-02-24 19:32:19.758499+00', '2015-02-26 14:48:30.807986+00', 1280, 5, 1041, '', 'A', '', 1, 1, 'Y', 'KccljNRWrWI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1961, '2015-02-24 19:36:36.315197+00', '2015-02-26 14:58:34.906015+00', 1677, 2, 1041, '', 'A', '', 1, 1, 'Y', 'nHZAy47H0Hc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1968, '2015-02-24 20:38:55.031368+00', '2015-02-26 15:01:46.926126+00', 2267, 7, 1041, '', 'A', '', 1, 1, 'Y', 'FBwFrLatGxU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1982, '2015-02-25 07:37:33.227563+00', '2015-02-26 15:06:39.602243+00', 9107, 5, 1041, '', 'B', '', 1, 1, 'Y', 'JYh9Ikqcz78', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1966, '2015-02-24 20:34:09.255694+00', '2015-02-26 15:11:16.962522+00', 2661, 1, 1041, '', 'A', '', 1, 1, 'Y', 'dOw7GwElYGE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1965, '2015-02-24 20:28:41.781234+00', '2015-02-26 15:12:02.06614+00', 2916, 1, 1041, '', 'A', '', 1, 1, 'Y', '8V-anD25CYE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1960, '2015-02-24 19:33:27.866216+00', '2015-02-26 15:13:51.943042+00', 13588, 5, 1041, '', 'A', '', 1, 1, 'Y', 't3HMNyRCByo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1912, '2015-01-26 10:02:08.167711+00', '2015-02-26 20:15:21.897295+00', 7124, 2, 274, '', 'B', 'Sunday Brunch 2015, Budapest

', 1, 1, 'Y', 'z0WkuHGongo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1980, '2015-02-25 07:35:14.297688+00', '2015-02-27 21:25:46.50369+00', 5407, 6, 1041, '', 'B', 'This is a "teaching video", where the formations are briefed while being danced, and the bar numbers are shown on screen.', 1, 1, 'Y', 'pY9cfxYIk48', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1973, '2015-02-24 21:05:36.363865+00', '2015-02-27 21:31:30.568484+00', 5868, 1, 1041, '', 'B', '', 1, 1, 'Y', 'gilnhbslojU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1963, '2015-02-24 20:14:45.310268+00', '2015-02-27 21:33:20.545914+00', 1588, 1, 1041, '', 'A', '', 1, 1, 'Y', '7p7zt55yOOA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1962, '2015-02-24 19:49:38.806868+00', '2015-02-27 21:34:13.923511+00', 14688, 3, 1041, '', 'A', '', 1, 1, 'Y', '0j36urhOs-Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1958, '2015-02-24 19:29:04.700503+00', '2015-02-27 21:35:44.507252+00', 4857, 3, 1041, '', 'A', '', 1, 1, 'Y', 'KLxSBaEgaOQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1957, '2015-02-24 19:24:12.179397+00', '2015-02-27 21:36:15.829612+00', 15403, 1, 1041, '', 'A', '', 1, 1, 'Y', 'SWYEswEl7QI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1937, '2015-02-17 21:20:10.737083+00', '2015-02-27 22:05:23.433061+00', 10306, 1, 513, '', 'C', '', 1, 1, 'Y', 'fZlG88nw2qA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1943, '2015-02-17 22:18:33.223921+00', '2015-02-27 22:08:06.549923+00', 10306, 2, 513, '', 'C', '', 1, 1, 'Y', '-T6wDpzJnrI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1910, '2015-01-12 10:23:59.81053+00', '2015-02-27 22:25:28.493704+00', 4038, 1, 274, '', 'D', 'Budapest Dance House for Beginners, january 2015', 1, 1, 'Y', 'x13xesLBTbk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1918, '2015-02-04 08:36:13.27203+00', '2015-02-27 22:49:51.904865+00', 13307, 1, 274, '', 'B', 'Part of a demonstration medley', 1, 1, 'Y', 'vk7rPZ9v--Y', 140, 264, NULL);
INSERT INTO 'dancevideo' VALUES (1919, '2015-02-04 08:37:32.983742+00', '2015-02-27 22:52:23.084437+00', 7139, 2, 274, '', 'B', 'Part of a demonstration medley', 1, 1, 'Y', 'vk7rPZ9v--Y', 264, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1924, '2015-02-10 08:02:41.462252+00', '2015-03-02 12:43:27.604931+00', 13351, 1, 116, '', 'D', 'Danced on 31 January 2015 in The Hague, The Netherlands.', 1, 1, 'Y', 'Rlpf630Bn7I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1928, '2015-02-13 18:24:32.041971+00', '2015-03-02 13:03:38.278206+00', 1791, 3, 274, '', 'C', '', 1, 1, 'Y', 'GU8aINB0pJI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1927, '2015-02-13 18:23:17.818914+00', '2015-03-02 12:56:52.507081+00', 1791, 2, 274, '', 'B', '', 1, 1, 'Y', 'KOL-TwoMMGs', 50, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1926, '2015-02-13 18:21:25.367722+00', '2015-03-02 13:09:31.025615+00', 1791, 1, 274, '', 'B', '', 1, 1, 'Y', 'sQds3w8YM1I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1929, '2015-02-13 18:25:20.034441+00', '2015-03-02 13:06:13.652608+00', 1791, 4, 274, '', 'C', '', 1, 1, 'Y', 'Trt8yz1L73c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1969, '2015-02-24 20:50:57.568008+00', '2015-03-11 11:11:47.000653+00', 15311, 1, 1041, '', 'C', '', 1, 1, 'Y', 'aStVV4r70rE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1971, '2015-02-24 20:57:12.051479+00', '2015-03-11 11:16:01.087343+00', 12124, 2, 1041, '', 'C', '', 1, 1, 'Y', 'x4mkcktTtjs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1916, '2015-02-03 20:10:24.924855+00', '2015-03-11 11:50:25.621682+00', 14964, 1, 1022, '', 'C', '', 1, 1, 'Y', 'AcRMXich0Fg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1944, '2015-02-17 22:23:04.281143+00', '2015-03-11 11:54:12.931646+00', 9816, 1, 513, '', 'B', '', 1, 1, 'Y', 'VtKdkeHaNJY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1972, '2015-02-24 21:00:36.679348+00', '2015-03-11 12:02:11.595987+00', 5898, 1, 1041, '', 'C', '', 1, 1, 'Y', 'qk8_qVZ5XOU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1940, '2015-02-17 21:43:32.924186+00', '2015-03-11 13:25:08.602172+00', 1969, 1, 513, '', 'C', '', 1, 1, 'Y', 'VSfQlSxTZC0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1954, '2015-02-22 16:35:54.597918+00', '2015-03-11 13:43:18.930108+00', 7563, 1, 2213, '', 'B', '', 1, 1, 'Y', '7orBK4LMD1c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1947, '2015-02-21 01:43:59.351881+00', '2015-03-11 14:17:23.93122+00', 1176, 2, 562, '', 'A', '', 1, 1, 'Y', 'To2UcbbcY1A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1934, '2015-02-17 14:01:14.902899+00', '2015-03-11 14:56:40.710638+00', 10163, 1, 513, '', 'C', '', 1, 1, 'Y', 'A15TnKkcvck', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1950, '2015-02-21 22:00:58.807092+00', '2015-03-11 14:59:46.349252+00', 9896, 1, 1041, '', 'C', '', 1, 1, 'Y', 'WhDamMd0NuE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1911, '2015-01-25 18:09:45.577838+00', '2015-03-11 15:03:41.258911+00', 14382, 1, 274, '', 'B', 'Burns Supper 2015, Budapest.

Three times through

The last part of a domonstration medley

', 1, 1, 'Y', 'Pua0N0lAYoI', 229, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1976, '2015-02-24 21:28:17.168077+00', '2015-04-12 21:04:35.458657+00', 9224, 1, 1041, '', 'B', '', 1, 1, 'Y', '1_lqZKiIlVQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1981, '2015-02-25 07:36:29.918452+00', '2015-02-26 14:12:26.289401+00', 7284, 5, 1041, '', 'B', '', 1, 1, 'Y', 'MbLs2nJ4MrM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1942, '2015-02-17 22:13:13.772305+00', '2017-02-26 14:03:41.442927+00', 12907, 1, 513, '', 'Z', 'This video was made at Kuckucksnest, Schluechtern, Germany.



It shows a truncated, 40-bar, version of this 48-bar dance. Basically, bars 9-24 are replaced by parallel figures of 8 round 1c and 3c.  Changes are also made to the reels.  Consider this video as giving a general impression of the original dance, not as an example from which to learn.

', 1, 1, 'Y', 'zBLdTEx-Jgw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2011, '2015-02-25 13:07:11.37956+00', '2018-10-03 22:08:51.761477+00', 9086, 1, 1041, '', 'X', '', 1, 1, 'Y', 'jd0WYgj6AJo', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2038, '2015-03-15 15:35:13.944099+00', '2016-05-14 20:24:01.785626+00', 16160, 1, 197, '', 'B', 'Video by deviser, Martin McWilliam.  The dance is a Jig, but here danced to Reel music.  This is the original version of the dance, with a lead-change Fig8 on bars 1-8.', 1, 1, 'Y', 'cvbPsmpS6GM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3470, '2018-03-11 13:39:46.487205+00', '2018-03-16 18:08:39.011071+00', 18258, 1, 513, '', 'A', 'Once through presentation at a wedding celebration', 1, 1, 'Y', 'WohBjkwbUAg', 10, 89, NULL);
INSERT INTO 'dancevideo' VALUES (1992, '2015-02-25 10:04:46.840802+00', '2015-02-26 14:47:26.1057+00', 7180, 6, 1041, '', 'B', '', 1, 1, 'Y', 'sPV9mVs8onM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1983, '2015-02-25 09:50:30.170109+00', '2015-02-26 15:11:45.640915+00', 12542, 7, 1041, '', 'B', '', 1, 1, 'Y', 'QR3_iZqFDEo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3473, '2018-03-11 13:42:53.148967+00', '2018-03-16 18:14:00.670576+00', 18252, 1, 513, '', 'A', 'Once through presentation at a wedding celebration', 1, 1, 'Y', '0jCC2FzLK4A', 18, 110, NULL);
INSERT INTO 'dancevideo' VALUES (3476, '2018-03-11 13:46:24.844894+00', '2018-03-16 18:22:18.541554+00', 18256, 1, 513, '', 'A', 'Once through presentation at a wedding celebration', 1, 1, 'Y', 'W_RAM5qPk4s', 3, 96, NULL);
INSERT INTO 'dancevideo' VALUES (3471, '2018-03-11 13:41:04.636188+00', '2018-03-16 18:26:16.350396+00', 18251, 1, 513, '', 'A', 'Once through presentation at a wedding celebration', 1, 1, 'Y', 'Si1kHBQJAzY', 13, 60, NULL);
INSERT INTO 'dancevideo' VALUES (2109, '2015-07-03 19:27:09.426222+00', '2015-07-03 19:31:40.06937+00', 4805, 8, 106, '', 'D', 'London Spring Fling 2015', 1, 1, 'Y', 'cpfeUObClAU', 291, 572, NULL);
INSERT INTO 'dancevideo' VALUES (1930, '2015-02-13 21:33:36.757673+00', '2022-06-05 10:26:19.686256+00', 9853, 1, 1041, '', 'B', 'Telheiras SCD group, Lisbon 2014.', 1, 1, 'Y', 'H_9bDelw-D4', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2064, '2015-04-26 22:11:50.843276+00', '2015-04-26 22:12:08.97958+00', 15125, 1, 106, '', 'B', 'On Saturday, 21st September, 2013, the Telheiras Scottish Country Dance Group performed six country dances at the "Olhar Carnide" festival in Carnide, Lisbon. Three were old dances from the 18th and 19th centuries and three were modern dances. This was the third, a modern Scottish country dance devised by Avril Quarrie called Going Dutch. We used music by Bob McMurtry, "The Devil''s Quandry", downloadable from cdbaby', 1, 1, 'Y', 'Oq9IGq902Hw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2146, '2015-08-25 19:57:30.927548+00', '2015-09-12 22:17:43.927995+00', 16523, 1, 1041, '', 'B', '', 1, 1, 'Y', 'j01JSWf-FNw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1902, '2015-01-03 21:16:51.327853+00', '2015-02-27 20:57:38.948093+00', 2409, 4, 1240, '', 'D', 'The pipe tune used is not the Jigtime Polka, but the dance is in fact the Garry Strathspey, contrary to what someone states in one of the comments. It is danced by two all-female sets viewed from behind the ladies'' side. (You can tell it is behind the ladies'' side because first couple dances up the middle on bars 13-16). Some mistakes and false starts, but a good overall impression of the dance.



The sets are on stage in the back of the hall, viewed over the heads of the audience, and show only the heads and bodies.  It is well-nigh impossible to follow the dance, unless you know it well.  Useless for learning or teaching.', 1, 1, 'Y', '3qliJMKnxrs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1986, '2015-02-25 09:55:36.770869+00', '2015-02-27 21:13:02.836416+00', 2063, 3, 1041, '', 'B', 'This is a "teaching video", where the formations are briefed while being danced, and the bar numbers are shown on screen.', 1, 1, 'Y', 'JJo0tnIlTrM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1687, '2014-06-09 15:10:43.619801+00', '2015-02-27 21:18:47.484037+00', 11189, 10, 106, '', 'C', 'Once through, first bars missing.', 1, 1, 'Y', '8f1neqWAXMA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1993, '2015-02-25 10:07:47.210167+00', '2015-02-27 21:18:29.724898+00', 11189, 11, 1041, '', 'B', 'This is a "teaching video", where the formations are briefed while being danced, and the bar numbers are shown on screen.', 1, 1, 'Y', 'Vw_loz1Csgk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2018, '2015-02-26 18:38:14.110343+00', '2015-03-01 22:11:51.133096+00', 3336, 3, 2482, '', 'B', '', 1, 1, 'Y', 'BEY4M1DPNBg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2024, '2015-02-26 22:05:49.482232+00', '2015-02-27 21:41:51.428698+00', 10163, 2, 1041, '', 'B', '', 1, 1, 'Y', '6zjA8RRTP7k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2022, '2015-02-26 21:23:46.690597+00', '2015-02-27 21:45:12.710223+00', 10306, 3, 1041, '', 'C', '', 1, 1, 'Y', 'eADxAswcWds', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2019, '2015-02-26 18:39:21.849425+00', '2015-02-27 22:02:40.628594+00', 9817, 1, 2482, '', 'B', '', 1, 1, 'Y', '6TZAPlEfSHs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1895, '2014-11-26 23:22:44.844145+00', '2015-02-27 22:20:58.575474+00', 3637, 1, 1684, '', 'D', 'It''s Lady Susan Stewart''s Reel, indeed, although the title reads Stewert. 

RSCDS Sacramento branch November party. Posted by John Hamilton, Nov 2011.



Danced in a 3C set, 3 times through.', 1, 1, 'Y', '1jUUgYj8kcw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1936, '2015-02-17 21:12:28.392317+00', '2015-02-28 16:01:48.876755+00', 8635, 1, 513, '', 'C', 'Danced on 14 February 2015 in Schlüchtern-Vollmerz.', 1, 1, 'Y', '2Wx5gQFYSxk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2032, '2015-03-03 23:22:50.659694+00', '2015-03-03 23:24:41.333377+00', 16153, 1, 106, '', 'C', 'This video is the source from which this dance was entered into the database.', 1, 1, 'Y', '3MQ1bWITwjU', 19, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2030, '2015-03-02 01:38:00.036695+00', '2015-03-04 00:49:08.507413+00', 15248, 1, 160, '', 'A', 'Far set has issues with the birl on the last repeat.', 1, 1, 'Y', 'uGNKUSyn5-M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2035, '2015-03-08 22:27:22.309184+00', '2015-03-08 22:27:44.55599+00', 10102, 1, 106, '', 'D', 'Taken in Class at Fanwood.', 1, 1, 'V', '41677571', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2026, '2015-02-27 13:58:40.474579+00', '2015-04-22 14:21:15.247221+00', 1600, 1, 513, '', 'C', '', 1, 1, 'Y', '2SHiSluaPl8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2031, '2015-03-03 09:27:46.017504+00', '2015-03-11 11:30:02.41435+00', 2631, 1, 513, '', 'D', '', 1, 1, 'Y', 'sMisLYLGlKU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2027, '2015-02-28 16:58:37.045017+00', '2015-03-11 13:52:41.767786+00', 984, 1, 106, '', 'D', '', 1, 1, 'Y', 'xsJx8H_HOm4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2041, '2015-03-20 00:16:22.031308+00', '2015-03-20 00:16:37.221483+00', 16176, 1, 106, '', 'D', '', 1, 1, 'Y', '8ihojyChj9E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2037, '2015-03-15 10:13:14.926609+00', '2015-03-15 11:40:29.01327+00', 16161, 1, 197, '', 'B', 'Video by Martin McWilliam', 1, 1, 'Y', 'JhVqDhz_MqY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2044, '2015-03-25 23:18:30.195764+00', '2015-03-25 23:18:50.893848+00', 7055, 3, 106, '', 'C', '', 1, 1, 'Y', 'vUsWwktotak', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2140, '2015-08-18 13:11:59.556672+00', '2015-08-22 21:54:20.4315+00', 16524, 1, 513, '', 'A', '', 1, 1, 'Y', '0tjYT2IhEeQ', 0, 274, NULL);
INSERT INTO 'dancevideo' VALUES (2045, '2015-03-25 23:36:00.143765+00', '2015-03-25 23:36:33.827583+00', 10166, 2, 106, '', 'D', 'Video from a class learning the dance.', 1, 1, 'V', '85339909', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2046, '2015-03-25 23:49:27.727212+00', '2015-03-25 23:49:48.855086+00', 2250, 5, 106, '', 'A', 'This is of demonstration quality, but not in RSCDS style but as a historical re-enactment.', 1, 1, 'Y', 'FVIBYcnUepU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2047, '2015-03-26 01:42:30.785549+00', '2015-03-26 01:43:08.292996+00', 1582, 8, 106, '', 'D', '', 1, 1, 'Y', '72V_oQ9_Kk8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2049, '2015-03-26 23:41:56.903877+00', '2015-04-15 10:39:58.65958+00', 15281, 2, 1041, '', 'C', '', 1, 1, 'Y', 'lnPaRhj0WP0', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2048, '2015-03-26 23:41:06.613488+00', '2015-04-15 10:45:19.007706+00', 15281, 1, 1041, '', 'C', '', 1, 1, 'Y', 'Y7olB7M0TdU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2052, '2015-03-29 21:48:48.315382+00', '2015-04-15 10:49:58.203477+00', 7457, 2, 513, '', 'C', '', 1, 1, 'Y', 'jsj9qsrbSfg', 34, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2054, '2015-04-01 09:29:11.539263+00', '2015-04-01 12:18:18.629692+00', 13506, 2, 106, '', 'A', '', 1, 1, 'Y', 'NEG-4WRYV7E', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (37, '2012-02-13 12:25:10.120736+00', '2015-04-01 12:18:53.856068+00', 13506, 1, 513, '', 'A', 'This video mistakenly carries the title "Bow Fiddle Medley".', 1, 1, 'Y', 'DoDHlwDu8Mg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2055, '2015-04-01 13:10:49.296776+00', '2015-04-01 13:15:35.729572+00', 658, 1, 106, '', 'B', 'The second part repeats the dance in reel time.', 1, 1, 'Y', 'B6MUaoEL1lI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2057, '2015-04-07 06:57:03.156542+00', '2015-04-07 07:02:06.367485+00', 14568, 2, 106, '', 'B', '', 1, 1, 'Y', 'Y1jir7lTDO0', 18, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3535, '2018-05-16 01:32:06.312183+00', '2018-05-16 01:53:32.167139+00', 7465, 3, 2372, '', 'A', '', 1, 1, 'Y', '9JLvvLpUXC0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1770, '2014-08-24 09:25:19.509429+00', '2015-04-13 18:06:49.05985+00', 8576, 1, 106, '', 'B', 'The Santa Cruz Class of the Royal Scottish Country Dance Society-San Francisco Branch dances the Rose Garden Strathspey for the third and final time on day two of two of the Scottish Renaissance Fair at the Santa Cruz County Fairground in Watsonville, CA, June 16, 2013.



Starts with all couples dancing, instead of only 1c+2c.', 1, 1, 'Y', 'ACjyZfr4r74', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2066, '2015-04-26 22:22:12.377861+00', '2015-04-26 22:22:26.373181+00', 5713, 4, 106, '', 'B', 'On Saturday, 21st September, 2013, the Telheiras Scottish Country Dance Group performed six country dances at the "Olhar Carnide" festival in Carnide, Lisbon. Three were old dances from the 18th and 19th centuries and three were modern dances. This was the fourth, an old country dance in a square set called Round Reel of Eight. The music we used is by Muriel Johnstone''s SD Band from their CD "Dancing Live from Blair Castle". ', 1, 1, 'Y', 'zMtN0spLet4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2058, '2015-04-10 11:33:26.765049+00', '2015-04-15 15:54:10.385485+00', 2353, 2, 1041, '', 'B', 'Only once through.

The second half of the Tournee is replaced by something else to flow into another dance.', 1, 1, 'Y', 'US3_v8ISKPk', 253, 313, NULL);
INSERT INTO 'dancevideo' VALUES (3539, '2018-05-22 17:46:27.748444+00', '2019-01-05 23:39:18.325049+00', 2484, 2, 954, '', 'C', 'According to the original instructions, only the Women set on bars 27-28 and 31-32.  However, a variant description exists that says "All Set".  That is the version used in this video.', 1, 1, 'Y', 'lUbpID0uNew', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2062, '2015-04-19 09:45:26.924958+00', '2015-04-19 09:50:55.871815+00', 4803, 6, 106, '', 'D', 'Mrs. Stewart of Fasnacloich, a Scottish Country Dance on the evening programme at a Weekend School in Lyon, France in January 2009. Five members of the Telheiras SCD Group attended the weekend, including Roger Picken, seen dancing in this video with Sophie Rickebusch. The live music is by James Gray (piano) and Keith Smith (fiddle).', 1, 1, 'Y', 'WOBx4iwTWDU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2113, '2015-07-04 22:53:24.052932+00', '2015-07-05 00:02:47.588684+00', 2332, 2, 106, '', 'A', 'Third and final element of a display  by RSCDS London Branch Demonstration team in memory of John Laurie- Pont Street Christmas Dance 2014 ', 1, 1, 'Y', 'UsbN6O8kdYc', 147, 224, NULL);
INSERT INTO 'dancevideo' VALUES (2213, '2015-10-22 22:08:28.981521+00', '2015-10-22 22:08:45.465592+00', 2616, 8, 106, '', 'A', 'Newcastle Festival 2014 (German Team Mixed 1) Gothenburg''s Welcome ', 1, 1, 'Y', 'QW57JikkxoA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2166, '2015-09-10 16:46:53.104047+00', '2015-09-12 22:10:47.725921+00', 15401, 1, 513, '', 'A', '', 1, 1, 'Y', 'fpkG04R9VoU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2165, '2015-09-10 16:45:34.792343+00', '2015-09-12 22:12:39.764799+00', 15403, 2, 513, '', 'A', '', 1, 1, 'Y', 'HvXjIDySvjI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2065, '2015-04-26 22:16:37.28216+00', '2015-04-26 22:17:00.421495+00', 14535, 7, 106, '', 'B', 'On Saturday, 21st September, 2013, the Telheiras Scottish Country Dance Group performed six country dances at the "Olhar Carnide" festival in Carnide, Lisbon. Three were old dances from the 18th and 19th centuries and three were modern dances. This was the fourth, a modern country dance devised by Ann Dix called Rodney''s Rant. As we did not have the correct music to hand, and we only wanted to do the dance 4x through, we used "Gypsy Tap" (!) from the Marian Anderson Band''s CD "St. Bernard''s Waltz". We also adapted the ending of the dance so that it could be done in a three-couple set. ', 1, 1, 'Y', 'LM9o0yRs77k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2067, '2015-04-26 22:26:33.712922+00', '2015-04-26 22:30:02.152319+00', 8088, 1, 106, '', 'C', 'Iberian SCD Weekend - Madrid 2015 - The Reel of the Gordon Highlanders taught by Jessie Stuart at the Sunday class. The music is by The Craigellachie Band', 1, 1, 'Y', 'wzOEi_Kb0PM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2078, '2015-05-04 09:14:50.297857+00', '2015-05-04 12:55:54.241057+00', 10057, 1, 274, '', 'D', 'SCD Weekend Budapest 2015 - Sunday morning class', 1, 1, 'Y', 'JFLZuVS3rWk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2068, '2015-04-27 10:15:59.200489+00', '2015-04-27 17:00:20.54283+00', 902, 1, 513, '', 'C', 'Budapest, 25th April 2015', 1, 1, 'Y', 'UDXcUxfe03s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3477, '2018-03-15 21:05:50.913299+00', '2018-03-15 21:11:59.832282+00', 9562, 2, 1645, '', 'A', '', 1, 1, 'Y', 'EuyO6j7AkK4', 0, 148, NULL);
INSERT INTO 'dancevideo' VALUES (2070, '2015-04-30 09:33:23.470046+00', '2015-05-01 12:18:16.862291+00', 7313, 3, 274, '', 'C', 'The first man is the dance deviser :-)

', 1, 1, 'Y', '5gfrJetarnk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2613, '2016-08-21 18:43:33.615636+00', '2016-08-21 18:43:48.561195+00', 985, 1, 106, '', 'C', '', 1, 1, 'Y', '4MYC44EyQSo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6689, '2020-01-10 01:19:26.847801+00', '2020-01-10 23:38:01.717964+00', 19378, 2, 1296, '', 'C', 'Once through.', 1, 1, 'Y', 'fNGbDXg3ZDo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6692, '2020-01-10 01:19:27.31417+00', '2020-01-10 23:26:33.891542+00', 7973, 2, 1296, '', 'C', '', 1, 1, 'Y', 'dSWPgEsTBAM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6693, '2020-01-10 01:19:27.417269+00', '2020-01-15 23:47:06.444423+00', 14568, 3, 1296, '', 'A', 'Once through as part of a longer display.', 1, 1, 'Y', 'o1Tc9yQZcKM', 64, 100, NULL);
INSERT INTO 'dancevideo' VALUES (3512, '2018-04-17 14:31:04.74939+00', '2018-04-17 14:46:41.859261+00', 819, 1, 2586, '', 'D', 'Video starts part way through the dance.', 1, 1, 'Y', 'SqRM-PQC98c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2084, '2015-05-15 19:24:38.706068+00', '2017-03-10 13:33:45.796235+00', 10548, 1, 2482, '', 'B', 'https://youtu.be/qUuJAHZSyrM', 0, 0, 'Y', 'qUuJAHZSyrM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2069, '2015-04-29 23:23:25.61445+00', '2015-05-05 23:08:43.078092+00', 5013, 1, 106, '', 'D', '', 1, 1, 'Y', 'zUdhoMGNiVk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3536, '2018-05-16 01:55:14.189452+00', '2018-05-16 10:20:36.972678+00', 6932, 1, 2372, '', 'A', '', 1, 1, 'Y', '87ZzESz1Eo8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2082, '2015-05-13 09:36:56.280453+00', '2015-05-14 23:03:57.071412+00', 2263, 1, 2213, '', 'C', '8 bars have been removed from one repeat of the dance', 1, 1, 'Y', 'mt1L461GGNo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2083, '2015-05-13 22:25:37.133031+00', '2015-05-14 23:10:02.322904+00', 13282, 1, 784, '', 'C', 'There is no turn for 2nd couple at the end.', 1, 1, 'Y', 'Wf9hpT0xnsg', 0, 63, NULL);
INSERT INTO 'dancevideo' VALUES (3538, '2018-05-20 22:45:18.160489+00', '2018-05-21 08:14:18.351506+00', 14597, 3, 2821, '', 'A', 'Red Wine and Straight Lines (32J/32S/32R), a medley for 3 couples, performed by the Waltham Scottish Country Dance Group at the ASCDS Festival 2018 on 12 May.

', 1, 1, 'Y', 'XHnnnTIBR5E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2087, '2015-05-22 21:26:14.180691+00', '2015-06-14 21:10:36.552044+00', 373, 2, 1041, '', 'B', '', 1, 1, 'Y', 'YTbFK-EkCvA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2090, '2015-05-26 16:11:45.794469+00', '2015-06-14 21:08:56.425118+00', 4894, 1, 513, '', 'D', '', 1, 1, 'Y', 'bg7o1loD-kY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2086, '2015-05-22 20:37:46.030106+00', '2015-06-14 21:12:37.680842+00', 14712, 1, 1041, '', 'A', '', 1, 1, 'Y', 'gJ99HExKDC4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2085, '2015-05-22 20:14:22.856087+00', '2015-06-14 21:17:05.097906+00', 2004, 1, 1041, '', 'D', 'On bar 21 - 24 instead of a right hands turn, 1st couple dance or lead down below 3rd couple and cast up to 2nd place.

There are some more mistakes, but the video still gives a reasonable impression of how the dance goes.', 1, 1, 'Y', 'd2Avtlh9cyo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2088, '2015-05-23 17:40:37.754743+00', '2015-06-14 21:21:53.741739+00', 12635, 1, 1041, '', 'D', '', 1, 1, 'Y', 'pr5wkKeJxCw', 186, 540, NULL);
INSERT INTO 'dancevideo' VALUES (2081, '2015-05-13 09:25:53.715347+00', '2015-09-14 09:54:55.870816+00', 3231, 3, 2213, '', 'C', 'In this video, the dancers are giving hands during the Inveran reels, which is not in the original instructions.', 1, 1, 'Y', 'KeMX5EiDNIw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3537, '2018-05-16 18:07:19.935191+00', '2018-05-21 08:19:09.66792+00', 15646, 1, 3086, '', 'A', 'Excellent dancing but constant cutting between camera angles makes the dance a bit hard to follow.', 1, 1, 'Y', '-j4K2DaVSHg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2094, '2015-06-10 09:17:16.612916+00', '2015-06-10 09:18:24.75064+00', 9008, 2, 106, '', 'C', '''Mary Erskine'' was danced at the Manawatu SCD Club''s 60th Anniversary dance in the Whakarongo hall, near Palmerston North, on May 2.', 1, 1, 'Y', 'RWjoISI2aE8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2110, '2015-07-03 19:39:15.869796+00', '2015-07-03 19:41:15.31327+00', 12426, 6, 106, '', 'D', 'London Spring Fling 2015', 1, 1, 'Y', 'cpfeUObClAU', 574, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3514, '2018-04-17 21:32:45.828387+00', '2018-04-18 05:19:36.920364+00', 15639, 1, 3086, '', 'A', '', 1, 1, 'Y', 'd0Am4dQletI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2097, '2015-06-10 13:23:53.897666+00', '2015-06-10 13:24:08.540715+00', 1204, 1, 106, '', 'C', 'Published on 24 may 2015.  Thanks to Tony Szeto for this video. ', 1, 1, 'Y', 'aykK8QxM9d4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3578, '2018-06-18 08:54:30.126026+00', '2018-06-18 08:58:46.667346+00', 1907, 1, 3086, '', 'A', '', 1, 1, 'Y', 'aq6x8qpaeY0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2111, '2015-07-04 18:44:49.148127+00', '2015-07-04 19:12:23.710256+00', 221, 2, 1041, '', 'B', 'Once through only.  Royal Scottish Country Dance Society, Seattle Branch.  Social Dance Oct 2012.  ', 1, 1, 'Y', 'EnoOcMnfp9Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2099, '2015-06-13 21:03:10.471764+00', '2015-06-13 21:06:50.509618+00', 14712, 2, 106, '', 'A', '', 1, 1, 'Y', 'U14P5GGqOUQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2100, '2015-06-14 15:39:09.090577+00', '2015-06-14 20:54:43.720724+00', 15338, 1, 160, '', 'C', '', 1, 1, 'Y', 'WKpFidXmvNw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2093, '2015-06-10 09:13:29.041881+00', '2015-06-14 20:56:24.915073+00', 2126, 2, 106, '', 'D', 'The Ferry Louper'' was danced at the Manawatu SCD Club''s 60th Anniversary dance on May 2, 2015 in the Whakarongo hall, Palmerston North, New Zealand', 1, 1, 'Y', '17iQVwJKdgU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2092, '2015-06-10 09:10:26.655066+00', '2015-06-14 20:57:52.337295+00', 588, 2, 106, '', 'D', 'The Tawa SCD Club held a "rainbow" night in May 2015. There was no door charge ... as long as you wore colourful clothes. Anyone who dared to wear black, brown, grey or white had to pay a penalty!', 1, 1, 'Y', '3z0q-UuNMw0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2091, '2015-05-29 08:07:54.045426+00', '2015-06-14 21:01:35.081348+00', 14476, 1, 274, '', 'B', 'This dance was dedicated to the couple (Judit Kerner and Áron Diószegi) who starts the dance as first couple. The deviser (Zoltán Gräff) starts the dance as third man :-)

Online source: http://bstk.hu/dances/be-my-partner/', 1, 1, 'Y', '7V5lH3A6nVM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2101, '2015-06-16 02:26:00.028257+00', '2015-06-16 08:07:27.282105+00', 3743, 1, 961, '', 'C', '', 1, 1, 'Y', 'PdFcyx3g6vw', 14, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2103, '2015-06-22 04:41:39.287393+00', '2015-06-22 04:42:22.178471+00', 159, 5, 106, '', 'Z', 'Lower Hutt Scottish Dance Club 60th Dance Anniversary, 2014', 1, 1, 'Y', 'kAKLf_eB390', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2104, '2015-06-22 04:44:57.032826+00', '2015-06-22 04:51:03.697736+00', 159, 6, 106, '', 'A', 'Mixed Open Class Winners, Newcastle RSCDS Festival, 2009.  Once through, music interrupted by announcement.', 1, 1, 'Y', 'fy0ndDxhQ0w', 76, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2102, '2015-06-19 21:39:19.642573+00', '2015-06-26 20:32:52.480116+00', 16461, 1, 106, '', 'A', 'SCD Weekend Budapest - Farewell Ceilidh - 2015.05.01  Three times through.

Not that the the camera is standing behind 3c and facing 1c.', 1, 1, 'Y', 'ozRYc9I65Gk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2106, '2015-06-26 22:03:59.006673+00', '2015-06-26 22:54:14.356369+00', 12683, 1, 2213, '', 'B', '', 1, 1, 'Y', 'hFDBqEKfOGw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (407, '2012-12-17 14:17:48.302391+00', '2015-06-28 12:16:29.691717+00', 9562, 1, 1296, '', 'B', 'Part of a Newcastle display by the London team.  Demonstration quality dancing.   Two sets joined "bottom to bottom".  Once through only.  The last bars have been clipped as that was modified into a transition into the next dance of the display.', 1, 1, 'Y', 'GOjd6oMFeEM', 99, 133, NULL);
INSERT INTO 'dancevideo' VALUES (1048, '2013-08-18 00:52:27.034048+00', '2015-06-28 20:42:05.995319+00', 10288, 1, 1296, '', 'C', 'This is German folk dancing, using walking steps. The figures are exactly the same as for the SCD dance of this name, except that the final birl has become a BH turn R and L. Until there is an SCD video, this one can be used to show the dance. ', 1, 1, 'Y', 'xEDkiCw4hH4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2107, '2015-07-02 19:47:30.107075+00', '2015-07-02 19:48:21.667537+00', 4102, 14, 106, '', 'B', 'Video rather dark.  Danced with Irish steps.  3C set. Correct Left shoulder passes.', 1, 1, 'Y', 'X7RUp6DhJcw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2108, '2015-07-03 19:18:59.491068+00', '2015-07-03 19:22:45.85379+00', 3802, 3, 106, '', 'D', 'Spring Fling 2015, London', 1, 1, 'Y', 'cpfeUObClAU', 4, 282, NULL);
INSERT INTO 'dancevideo' VALUES (2114, '2015-07-04 23:09:15.08075+00', '2015-07-05 00:05:00.468197+00', 6848, 3, 106, '', 'A', 'Second of three elements of a display  by RSCDS London Branch Demonstration team in memory of John Laurie - Pont Street Christmas Dance 2014 ', 1, 1, 'Y', 'UsbN6O8kdYc', 83, 147, NULL);
INSERT INTO 'dancevideo' VALUES (2115, '2015-07-04 23:53:51.208282+00', '2015-07-05 00:07:32.327155+00', 4491, 2, 106, '', 'A', 'First of three elements of a display  by RSCDS London Branch Demonstration team in memory of John Laurie- Pont Street Christmas Dance 2014', 1, 1, 'Y', 'UsbN6O8kdYc', 10, 83, NULL);
INSERT INTO 'dancevideo' VALUES (2117, '2015-07-08 23:42:18.086858+00', '2015-07-08 23:43:55.299003+00', 6057, 1, 106, '', 'D', 'The Shores of Solway was on the programme at the Kelburn SCD Club''s tea dance on June 22, 2015, the New Zealand winter solstice.



The MC was Ann Oliver and live music was provided by Iain Matcham (fiddle) and Jean Malcolm (keyboard).', 1, 1, 'Y', 'EKEoMiuUJu8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2118, '2015-07-08 23:48:40.808533+00', '2015-07-08 23:49:14.040615+00', 13727, 2, 106, '', 'D', 'The Kelburn SCD Club held its annual tea dance on June 21, 2015 - the day of the New Zealand winter solstice.



The MC was Ann Oliver and live music was provided by Iain Matcham (fiddle) and Jean Malcolm (keyboard).', 1, 1, 'Y', 'cbS-qaWKKwA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2126, '2015-07-27 18:53:50.648608+00', '2015-07-31 19:54:58.572878+00', 13078, 1, 1022, '', 'B', '', 1, 1, 'Y', 'w1n_iWSsABo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2119, '2015-07-09 00:39:24.688501+00', '2015-07-09 00:41:57.293357+00', 16479, 1, 106, '', 'D', 'This video was our source of information for this dance.  Eric', 1, 1, 'Y', 'eln_pHnOd7c', 73, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2121, '2015-07-13 20:37:28.620695+00', '2015-07-13 21:33:52.253348+00', 11617, 2, 513, '', 'C', 'At the beginning of the video are a few bars of the dance missing!  



Recorded during the Summer Ball 2015 in Sterbfritz/Germany.  This is the Encore, so each dancing couple casts to the bottom when they finish.', 1, 1, 'Y', 'HiQ7eMeJIjA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2122, '2015-07-20 19:49:07.654251+00', '2015-07-20 23:04:19.510447+00', 4629, 1, 513, '', 'C', '', 1, 1, 'Y', 'E3gWvAuJbxQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2123, '2015-07-20 19:54:16.059495+00', '2015-07-20 23:10:41.918759+00', 9455, 1, 513, '', 'C', '', 1, 1, 'Y', 'YM3W2UlN7Lc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2125, '2015-07-20 20:05:41.125266+00', '2015-07-20 23:28:50.966026+00', 684, 1, 513, '', 'C', '', 1, 1, 'Y', 'nUqbHLPtwdY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2128, '2015-07-31 20:53:32.196051+00', '2015-07-31 20:59:37.894312+00', 16525, 1, 106, '', 'A', '', 1, 1, 'Y', 'AE1fJ6RbrR8', 215, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2127, '2015-07-31 13:16:44.909653+00', '2015-07-31 20:08:55.237922+00', 13648, 1, 513, '', 'A', 'RSCDS video of the Younger Hall Demonstration from 30.08.2015', 1, 1, 'Y', 'AE1fJ6RbrR8', 0, 213, NULL);
INSERT INTO 'dancevideo' VALUES (2133, '2015-08-06 19:23:19.600138+00', '2015-08-06 19:58:25.03809+00', 13648, 2, 2213, '', 'A', '', 1, 1, 'Y', 'UjNAxc6k5rI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2134, '2015-08-06 19:24:52.946382+00', '2015-08-06 20:27:40.932451+00', 16525, 2, 2213, '', 'A', '', 1, 1, 'Y', 'BWaV3IgMXWg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2135, '2015-08-06 19:25:52.302413+00', '2015-08-09 03:19:41.526309+00', 7219, 1, 2213, '', 'B', '', 1, 1, 'Y', 'kwA4E0eb-nQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2137, '2015-08-08 15:11:14.128255+00', '2015-08-11 16:35:16.321687+00', 7560, 1, 1041, '', 'B', '', 1, 1, 'Y', 'JEUM33Zbz-k', 302, 490, NULL);
INSERT INTO 'dancevideo' VALUES (2129, '2015-08-04 22:55:56.394976+00', '2015-08-09 14:29:06.567982+00', 9465, 1, 963, '', 'C', 'Gives you a good idea of how it goes.', 1, 1, 'Y', 'gERDROi134w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2138, '2015-08-08 18:21:28.715917+00', '2015-08-11 16:40:07.334646+00', 4441, 1, 1041, '', 'C', 'If you start the video at the beginning you get a full walk-through instruction.', 1, 1, 'Y', 'Mz5iAQ6GTos', 65, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2143, '2015-08-22 09:11:13.251178+00', '2015-08-22 21:36:41.697662+00', 16522, 1, 1056, '', 'A', '', 1, 1, 'Y', 'Tzo5VI_8_wk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2144, '2015-08-22 09:14:38.842393+00', '2015-08-22 21:40:30.354428+00', 16536, 1, 1056, '', 'A', 'Demonstration, but goes a bit awry at the end', 1, 1, 'Y', 'dLjTkWIaiqQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2124, '2015-07-20 20:02:07.545211+00', '2015-08-24 07:10:10.702003+00', 3524, 1, 513, '', 'C', '', 1, 1, 'Y', 'bAPGp5EltcY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2139, '2015-08-18 13:11:04.710985+00', '2015-08-23 13:31:04.369488+00', 16537, 1, 513, '', 'A', 'Summer School 2015', 1, 1, 'Y', '0tjYT2IhEeQ', 279, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2141, '2015-08-18 13:14:16.827516+00', '2015-08-23 13:21:59.328253+00', 16534, 1, 513, '', 'A', 'Video too dark.', 1, 1, 'Y', '7aJ3_hFeuPU', 0, 264, NULL);
INSERT INTO 'dancevideo' VALUES (2161, '2015-09-01 17:46:18.142942+00', '2015-09-12 21:28:24.539822+00', 6373, 2, 57, '', 'C', '', 1, 1, 'Y', 'AIBU-ezyGnQ', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2148, '2015-08-26 15:13:24.578637+00', '2015-08-26 20:20:17.409073+00', 1473, 9, 160, '', 'D', 'Culla Bay for eight couples.  "Letting our hair down."', 1, 1, 'Y', 'pNjyaLajddQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1121, '2013-08-18 10:47:59.124807+00', '2015-08-28 20:23:14.531431+00', 1792, 6, 1296, '', 'D', 'Camera at breast level, reasonable view of the set.', 1, 1, 'Y', 'j5LvJMvYWBg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2167, '2015-09-10 16:48:16.562985+00', '2015-09-12 21:30:32.958069+00', 13847, 3, 513, '', 'A', '', 1, 1, 'Y', 'dfpPDV8WhRA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1122, '2013-08-18 10:47:59.148336+00', '2015-08-28 20:32:17.678111+00', 1792, 7, 1296, '', 'C', 'Camera at head height, close to set. Shows figures reasonably. Old style dancing, with steps that deviate from the current RSCDS norm. 3C set, three times through. ', 1, 1, 'Y', 'vpfEnSxtiX4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2149, '2015-08-28 20:30:50.410508+00', '2015-08-28 20:33:09.505522+00', 1792, 8, 106, '', 'A', 'Unit 2 dances, as published by the RSCDS', 1, 1, 'Y', 'tPCUL-CMBGs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2170, '2015-09-12 12:14:05.826848+00', '2015-09-12 21:33:04.388015+00', 10376, 2, 513, '', 'A', '', 1, 1, 'Y', '8EI7bqPdddc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2171, '2015-09-12 12:15:41.91424+00', '2015-09-12 21:34:50.223476+00', 12941, 3, 513, '', 'A', '', 1, 1, 'Y', '1OVGuKQApTc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2152, '2015-08-29 20:10:44.614129+00', '2015-08-29 20:11:04.979165+00', 7061, 5, 106, '', 'A', 'Demonstration for RSCDS Teaching Certificate: Unit 2 Dances', 1, 1, 'Y', 'pCiVhKmYGzk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2154, '2015-08-29 20:22:02.484514+00', '2015-08-29 20:22:25.981882+00', 6287, 4, 106, '', 'A', 'Demonstration for RSCDS Teaching Certificate: Unit 2 Dances', 1, 1, 'Y', 't2JaGdNB-o4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2155, '2015-08-29 20:25:31.749993+00', '2015-08-29 20:25:46.693173+00', 4491, 3, 106, '', 'A', 'Demonstration for RSCDS Teaching Certificate: Unit 2 Dances', 1, 1, 'Y', '3Id34B-bYC4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2157, '2015-08-29 20:32:35.52945+00', '2015-08-29 20:34:27.954868+00', 109, 3, 106, '', 'A', 'Demonstration for RSCDS Teaching Certificate: Unit 2 Dances', 1, 1, 'Y', 'EfRgVAPGdIU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2158, '2015-08-29 20:36:07.917286+00', '2015-08-29 20:36:23.77487+00', 4484, 5, 106, '', 'A', 'Demonstration for RSCDS Teaching Certificate: Unit 2 Dances', 1, 1, 'Y', '1EK3PeGsrhY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2159, '2015-08-29 20:37:53.536732+00', '2015-08-29 20:38:05.485747+00', 4759, 2, 106, '', 'A', 'Demonstration for RSCDS Teaching Certificate: Unit 2 Dances', 1, 1, 'Y', '3pFmC9hjlZc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2160, '2015-08-29 20:40:20.182303+00', '2015-08-29 20:40:31.609281+00', 6885, 2, 106, '', 'A', 'Demonstration for RSCDS Teaching Certificate: Unit 2 Dances', 1, 1, 'Y', 'eJJ8uR6BA6c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3478, '2018-03-15 21:23:16.657922+00', '2018-03-15 21:40:26.393328+00', 2394, 4, 1645, '', 'A', 'Ignore the spurious "Reverend John MacFarlane" title about half way through.', 1, 1, 'Y', 'EuyO6j7AkK4', 149, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3513, '2018-04-17 14:45:30.151804+00', '2018-04-17 14:56:59.547103+00', 14898, 1, 3637, '', 'A', 'Greg Reznick''s Lost and Found performed by the New World Dancers at Dunsmuir House, Oakland, December 2014. A rare opportunity to watch devisor Greg Reznick dancing.  ', 1, 1, 'Y', '1Q8wxnW-3p4', 1217, 1295, NULL);
INSERT INTO 'dancevideo' VALUES (2156, '2015-08-29 20:29:18.730756+00', '2015-09-12 21:25:46.840373+00', 4805, 9, 106, '', 'A', 'Demonstration for RSCDS Teaching Certificate: Unit 2 Dances', 1, 1, 'Y', 'ZnLVXkXhpiY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2174, '2015-09-12 16:53:39.354501+00', '2015-09-12 21:37:04.75014+00', 12792, 4, 513, '', 'A', '', 1, 1, 'Y', '_22T5XU2GYA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2176, '2015-09-17 19:10:49.243733+00', '2015-09-18 21:33:41.310069+00', 16566, 1, 197, '', 'A', 'The dance is dedicated to Ruby Wilkinson on her retirement as Summer School director, and was devised by Alasdair Brown with music written by George Meikle.

The dancers are: Alice Stainer Angela Young, Jean Martin, Debbie Roxburgh, Adam Brady, Alasdair Brown, Jim Stott and Eric Finley.

Performed at the Ceilidh during Week 4 of Summer School 2015.

Video by Martina Mueller-Franz', 1, 1, 'Y', 'DjWBiMamM1c', 64, 313, NULL);
INSERT INTO 'dancevideo' VALUES (2173, '2015-09-12 16:37:48.028807+00', '2015-09-12 21:41:38.842176+00', 4511, 2, 513, '', 'A', '', 1, 1, 'Y', 'kqzLyn1VNEI', 43, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2168, '2015-09-12 11:57:29.286696+00', '2015-09-12 21:48:29.781111+00', 13591, 1, 513, '', 'A', '', 1, 1, 'Y', 'ieCeaiOx2Yo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2169, '2015-09-12 12:00:28.293426+00', '2015-09-12 21:50:02.238073+00', 13586, 2, 513, '', 'A', '', 1, 1, 'Y', 'lt7MfCivVXY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2177, '2015-09-19 19:37:12.849659+00', '2015-09-20 19:42:36.972459+00', 15710, 1, 106, '', 'A', 'Video discovered by Robb Quint', 1, 1, 'Y', 'iVK8T5RNUlc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2172, '2015-09-12 14:47:55.376409+00', '2015-09-12 21:58:12.004473+00', 13577, 2, 513, '', 'A', '', 1, 1, 'Y', 'BSmoln16dGs', 0, 155, NULL);
INSERT INTO 'dancevideo' VALUES (2147, '2015-08-25 20:22:58.8047+00', '2015-09-12 22:01:00.975794+00', 10595, 1, 1041, '', 'B', '', 1, 1, 'Y', 'p3V1JnI2tgI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2162, '2015-09-06 09:53:42.950097+00', '2015-09-12 22:08:43.565904+00', 16502, 1, 2121, '', 'D', '', 1, 1, 'Y', 'pCg7KNFzl3Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (205, '2012-09-09 20:06:05.832284+00', '2015-09-14 09:55:04.532445+00', 3231, 1, 1041, '', 'D', 'In this video, the dancers are giving hands during the Inveran reels, which is not in the original instructions.', 1, 1, 'Y', '0PjM_Grq5g4', 58, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2175, '2015-09-14 00:43:59.850884+00', '2015-09-15 20:12:05.696962+00', 7189, 1, 2709, '', 'C', '', 1, 1, 'Y', 'OQWUGOVGHVE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2179, '2015-09-23 14:23:56.99218+00', '2015-09-23 14:26:39.926237+00', 13757, 1, 106, '', 'D', 'Starts with the final circle of the previous turn, then once through only.', 1, 1, 'V', '63562983', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2180, '2015-09-23 14:32:56.017572+00', '2015-09-23 14:40:48.898948+00', 13745, 1, 106, '', 'D', 'Late start, not even once through; camera pans away at the end.', 1, 1, 'V', '50803777', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (303, '2012-10-17 02:57:41.486368+00', '2015-09-28 20:26:09.001402+00', 5308, 1, 513, '', 'D', 'Polharrow Burn performed at the RSCDS Manchester Annual Ball 2007', 1, 1, 'Y', 'Ggec5kkmLxM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2182, '2015-09-30 21:02:55.570795+00', '2015-09-30 21:03:10.688822+00', 16536, 2, 106, '', 'D', '', 1, 1, 'V', '135639712', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2183, '2015-09-30 21:50:30.809421+00', '2015-09-30 21:52:05.636474+00', 11063, 1, 106, '', 'C', '', 1, 1, 'V', '126997666', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2184, '2015-09-30 22:00:31.713433+00', '2015-09-30 22:02:58.737125+00', 6077, 1, 106, '', 'C', '', 1, 1, 'V', '127431767', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2238, '2015-10-29 15:14:39.720061+00', '2015-10-29 15:21:38.416579+00', 13270, 3, 2755, '', 'B', 'RSCDS Belfast Branch.', 1, 1, 'Y', 'qrqFekgriNc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2240, '2015-10-29 15:16:34.31176+00', '2015-10-29 22:50:05.2788+00', 9636, 3, 2755, '', 'B', 'Danced by RSCDS Belfast branch.  Twice through only.', 1, 1, 'Y', 'T66ORmdoDw4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1164, '2013-08-18 10:55:21.488689+00', '2015-10-03 22:11:34.045567+00', 2563, 1, 1296, '', 'C', 'Good dancing in a social setting. Good view from above.



A note by Robb Quint :  the right-shoulder pass of W1 and M3 on bars 7-8 the first three times through in the video is incorrect.  Elizabeth Campbell was kind enough to confirm directly in Northern Ireland that left-shoulder pass is correct.  Elizabeth herself begins in M1 position; it is not until she is herself dancing M3 fourth time through that the left-shoulder pass is danced correctly. ', 1, 1, 'Y', 'KpRHyIFZPl8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2185, '2015-10-01 22:51:08.446024+00', '2015-10-01 22:54:30.475182+00', 16465, 1, 106, '', 'B', 'Excerpt from a demo; once through only.', 1, 1, 'Y', 'O6aaE5y6tsk', 141, 176, NULL);
INSERT INTO 'dancevideo' VALUES (2188, '2015-10-03 22:43:12.149551+00', '2015-10-03 22:44:23.238233+00', 16526, 1, 105, '', 'A', '', 1, 1, 'Y', 'AiXD4Mhkwg4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2187, '2015-10-03 22:42:00.25371+00', '2015-10-03 22:44:48.104663+00', 16533, 1, 105, '', 'A', '', 1, 1, 'Y', 'BJlWjc83F8A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2189, '2015-10-03 23:02:58.484114+00', '2015-10-03 23:03:18.65818+00', 16523, 2, 105, '', 'A', '', 1, 1, 'Y', 'V8z63ELqtTo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2190, '2015-10-03 23:05:07.930351+00', '2015-10-03 23:05:29.495363+00', 16535, 2, 105, '', 'A', '', 1, 1, 'Y', 'qTx9U8juAqc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2191, '2015-10-03 23:28:56.565946+00', '2015-10-03 23:29:23.043697+00', 16534, 2, 105, '', 'A', '', 1, 1, 'Y', '9pws_4SvpIM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2178, '2015-09-23 14:19:03.647851+00', '2015-10-04 12:08:18.633653+00', 13771, 1, 106, '', 'D', 'A clear video, but the dancers are relative beginners.  ', 1, 1, 'V', '93921854', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2228, '2015-10-25 13:37:27.185237+00', '2018-10-03 22:18:33.648991+00', 13282, 2, 106, '', 'X', '', 1, 1, 'Y', 'r2ig1uYDLL8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2186, '2015-10-03 16:18:23.587008+00', '2015-10-04 12:27:59.884868+00', 5000, 1, 2722, '', 'A', '1987 video of John Drewry''s strathspey Nova Scotia featuring the 1987 Toronto Branch Advance class under the direction of Georgina Findlay. This was part of the Toronto Branch 30th anniversary Gala Day', 1, 1, 'Y', '16RMjSlLNg4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2192, '2015-10-05 11:01:41.023192+00', '2015-10-05 13:11:24.425565+00', 5667, 2, 513, '', 'C', '', 1, 1, 'Y', '2jjhN7KAOxM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2199, '2015-10-19 09:06:34.096822+00', '2015-10-19 14:00:18.385761+00', 7227, 1, 513, '', 'D', 'Twice through; first time with several fails.  Eindhoven Ball 2015-10-17', 1, 1, 'Y', 'O584Em-MqcU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (766, '2012-12-17 14:19:49.268592+00', '2015-10-10 20:35:41.499729+00', 7180, 4, 1296, '', 'A', 'Once through only.  Part of a longer display.  



The progression is in error.  On bars [27-28] and [31-32] the circle goes only 1/3 round (instead of 1/2), so the progression becomes (3,1,2) instead of the correct (2,3,1)', 1, 1, 'Y', 'wxjyNzIYdPo', 0, 66, NULL);
INSERT INTO 'dancevideo' VALUES (2200, '2015-10-19 09:07:10.106902+00', '2015-10-19 14:01:04.730146+00', 7227, 2, 513, '', 'D', 'Second time through only (first time is incomplete and confused).  Eindhoven Ball 2015-10-17', 1, 1, 'Y', 'tmDsHhpaWfY', 33, 0, NULL);
INSERT INTO 'dancevideo' VALUES (765, '2012-12-17 14:19:49.26481+00', '2015-10-10 20:40:38.550948+00', 7180, 3, 1296, '', 'C', 'The recording started late; only the final 2 times through can be shown.  The music quality is poor.



There is another (3x through) video of this same demo taken from floor level behind 3c position.



The progression is in error.  On bars [27-28] and [31-32] the circle goes only 1/3 round (instead of 1/2), so the progression becomes (3,1,2) instead of the correct (2,3,1)', 1, 1, 'Y', 'UVBR9AkyXsc', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (249, '2012-09-12 19:41:50.537943+00', '2015-10-10 20:45:56.644694+00', 7180, 2, 1041, '', 'B', '3 times through.  There is a second video of this same performance, taken from above 2c, but showing only 2nd and 3rd times through.



The progression is in error.  On bars [27-28] and [31-32] the circle goes only 1/3 round (instead of 1/2), so the progression becomes (3,1,2) instead of the correct (2,3,1)', 1, 1, 'Y', '7pmsTb6TVAA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2195, '2015-10-12 20:00:34.82332+00', '2015-10-12 21:18:35.39702+00', 13164, 1, 1041, '', 'B', 'Excerpt from a demo; twice through only; "Once and to the bottom".', 1, 1, 'Y', 'O6aaE5y6tsk', 0, 75, NULL);
INSERT INTO 'dancevideo' VALUES (2193, '2015-10-12 09:34:54.852295+00', '2015-10-13 14:50:16.767443+00', 454, 1, 274, '', 'C', 'Budapest Dance House for beginners, 10.10.2015



', 1, 1, 'Y', 'i0eZdfXwWMg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2194, '2015-10-12 09:38:08.301783+00', '2015-10-13 14:55:44.47677+00', 16525, 3, 274, '', 'A', '', 1, 1, 'Y', 's2HLKXDINsY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2196, '2015-10-13 20:18:02.833472+00', '2015-10-13 20:20:27.853581+00', 14977, 2, 106, '', 'A', 'Second part of the RSCDS Summer School 2013 Week 4 - Country Dem.', 1, 1, 'Y', '2G3JyAzWu7g', 79, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2198, '2015-10-19 08:39:08.32844+00', '2015-10-19 14:02:31.108091+00', 8128, 1, 513, '', 'C', 'Eindhoven Matinee 2015-10-17', 1, 1, 'Y', '8kJWmt-l9E8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1051, '2013-08-18 08:05:56.427098+00', '2015-10-18 01:05:00.880716+00', 816, 1, 1296, '', 'A', 'Part of a longer demo. Taken from a long distance against a confused background. Once through. Very confused beginning, especially bars 1-8 differ from the original.  It is hard to follow the dance even if you know it.', 1, 1, 'Y', 'JAc97ndtUZY', 0, 53, NULL);
INSERT INTO 'dancevideo' VALUES (2201, '2015-10-19 09:08:04.455092+00', '2015-10-19 13:50:29.664456+00', 16568, 1, 513, '', 'C', '', 1, 1, 'Y', 'VZpT9e4sBS0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2202, '2015-10-19 14:16:28.104227+00', '2015-10-19 14:21:27.809316+00', 11772, 3, 106, '', 'C', 'At the Eindhoven afternoon class, 2015-10-17.', 1, 1, 'Y', 'Pk4G7Ik8fak', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2203, '2015-10-19 19:47:37.659385+00', '2015-10-19 19:58:28.87504+00', 1966, 1, 1041, '', 'C', '', 1, 1, 'Y', 'aI8hjodkrSU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2212, '2015-10-22 22:03:29.224366+00', '2015-10-22 22:03:46.039386+00', 4404, 6, 106, '', 'A', 'Newcastle Festival 2015 - German Team Mixed 1 - Milton''s Welcome', 1, 1, 'Y', '1R3rF9naiiU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2205, '2015-10-21 09:41:51.26929+00', '2015-10-21 09:48:42.919825+00', 1708, 1, 106, '', 'A', 'Outdoor demo; third part of a display.  Twice through. Final bars slightly modified.  ', 1, 1, 'Y', 'yXU7TvzWHLw', 214, 359, NULL);
INSERT INTO 'dancevideo' VALUES (3475, '2018-03-11 13:45:24.062281+00', '2018-03-16 17:59:36.500856+00', 18257, 1, 513, '', 'A', 'Once through presentation at a wedding celebration', 1, 1, 'Y', 'j63zdRO6UGU', 18, 63, NULL);
INSERT INTO 'dancevideo' VALUES (2206, '2015-10-21 12:54:07.039969+00', '2015-10-21 12:56:41.282113+00', 9151, 1, 106, '', 'D', 'The Three-Legged cat'' was danced at the Johnsonville SCD Club''s tartan night on September 28, 2015, in the Johnsonville School hall, Wellington, New Zealand. Margaret Bailey, who now lives in Nelson, once danced regularly with this club.



The MC was club tutor Rod Downey, and live music was provided by Mild Heather - ie Wild Heather minus one member: Lynne Scott, Anne-Marie Forsyth and Mary McDonald. Sharlene Penman was overseas at the time.



Just a note for anyone planning to do this dance in future: After the advance and retire, the first couple should be not so much simply dancing around each other as dancing a close ''gypsy turn''.



The devisor writes: "The first couple are dancing the interactions between Tripod and Pinky, so dancing around is up close and glaring!"



So just think of warring cats!', 1, 1, 'Y', '18oBVjcgibg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2208, '2015-10-21 13:28:06.510547+00', '2015-10-21 13:29:46.428308+00', 8113, 1, 106, '', 'C', 'Danced at the Johnsonville SCD Club''s ''tartan night'' on September 28, 2015, in the Johnsonville School hall, Wellington, New Zealand. ', 1, 1, 'Y', 'crsz1aEdiiI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3472, '2018-03-11 13:41:57.24547+00', '2018-03-16 18:04:00.565778+00', 18254, 1, 513, '', 'A', 'Once through presentation at a wedding celebration', 1, 1, 'Y', 'zI7dY78dk4A', 20, 105, NULL);
INSERT INTO 'dancevideo' VALUES (2204, '2015-10-20 22:05:10.305437+00', '2015-10-21 23:12:25.694683+00', 3129, 4, 106, '', 'A', 'Chiswick Scottish Country Dance Club', 1, 1, 'Y', 'RSyUYGjcWWk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2209, '2015-10-21 16:20:39.563284+00', '2015-10-22 09:06:35.135042+00', 7149, 1, 106, '', 'C', 'It was danced at the Tawa SCD Club''s annual dance in the Ngaio town hall on September 19, 2015.

', 1, 1, 'Y', 'cwbIk9Yz5EE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2217, '2015-10-24 22:28:01.6255+00', '2018-10-03 22:06:39.530857+00', 588, 3, 106, '', 'X', '', 1, 1, 'Y', 'a7QP5uTnC34', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2211, '2015-10-22 12:39:29.609528+00', '2015-10-24 01:13:06.631691+00', 16071, 1, 1272, '', 'B', 'More than a Spring Fling (R32, 3/4L) – A&D Quarrie

Here the dance is only 4 times through and the dancing couple casts to the end of the set after the  DIAG R&L, which, of course,  is not necessary when dancing it 8 times through. 

', 1, 1, 'Y', 'efRUtaLQgc8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3474, '2018-03-11 13:44:24.503972+00', '2018-03-16 18:18:16.066622+00', 18253, 1, 513, '', 'A', 'Once through presentation at a wedding celebration', 1, 1, 'Y', 'bSPPqR9XcAk', 20, 80, NULL);
INSERT INTO 'dancevideo' VALUES (2235, '2015-10-25 16:56:22.958375+00', '2015-10-25 18:11:40.013573+00', 518, 1, 2121, '', 'B', 'Once through only', 1, 1, 'Y', 'fogrNJLZAdA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2236, '2015-10-26 00:37:30.13728+00', '2015-10-27 21:27:30.189523+00', 12508, 1, 2747, '', 'B', 'The dance "Deer" Friends was devised by Bob Anderson and created for a workshop delivered in Red Deer, Alberta. It is demonstrated here by dancers from the the  Vancouver Island Scottish Country Dance Society where Bob teaches.



Danced once through only.', 1, 1, 'Y', 'zdUzqkvTAaA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2242, '2015-10-29 15:18:47.466383+00', '2015-10-29 23:00:44.900138+00', 9640, 1, 2755, '', 'B', 'Danced by RSCDS Belfast branch.  Twice through only.', 1, 1, 'Y', 'C4rHL5HkrfE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2257, '2015-11-07 02:22:49.182356+00', '2015-11-07 02:23:15.3645+00', 16820, 1, 106, '', 'C', 'This video is the source on which this dance entry is based.  ', 1, 1, 'Y', 'HS4oSjCXKkQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2241, '2015-10-29 15:17:46.258912+00', '2015-10-29 23:18:19.49543+00', 3463, 2, 2755, '', 'B', 'Danced by RSCDS Belfast Branch.  Twice through only.', 1, 1, 'Y', '3mbqi10L4Cc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2239, '2015-10-29 15:15:38.037117+00', '2015-10-29 23:25:48.419017+00', 13585, 3, 2755, '', 'B', 'Danced by RSCDS Belfast branch.  Twice through only.', 1, 1, 'Y', 'r7k0sHLLq0o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1230, '2013-08-18 10:55:35.457988+00', '2015-10-30 12:58:50.036125+00', 3829, 1, 1296, '', 'A', 'This is  demonstration, based on Brisk Young Lad and Linkumdoddie, in which much of Linkumdoddie is are included, but elements have been moved around.  Nice demo, but not suitable as an example of the dance.', 1, 1, 'Y', 'JAc97ndtUZY', 49, 102, NULL);
INSERT INTO 'dancevideo' VALUES (2243, '2015-10-30 21:02:38.092382+00', '2015-10-30 21:03:10.173824+00', 9203, 2, 106, '', 'B', 'Once through only.   SCDGroup Hong Kong', 1, 1, 'Y', 'yWAG08UtmwE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3480, '2018-03-19 18:30:17.520224+00', '2018-03-19 22:54:12.955363+00', 15641, 1, 3086, '', 'A', '', 1, 1, 'Y', 'H2QfweP4yfo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2245, '2015-10-30 21:33:59.692717+00', '2015-10-30 21:39:13.561318+00', 9105, 1, 106, '', 'C', 'SCD Group Hog Kong, 2015', 1, 1, 'Y', 'V48eNhccWTI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2246, '2015-10-30 21:41:24.069056+00', '2015-10-30 21:41:45.801045+00', 16527, 2, 106, '', 'A', '', 1, 1, 'Y', '18J2R4vDp-M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2234, '2015-10-25 13:58:55.146952+00', '2018-10-03 22:23:42.275872+00', 15128, 1, 106, '', 'X', '', 1, 1, 'Y', 'dDa_MBH_u84', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2247, '2015-10-30 21:46:58.65159+00', '2018-10-01 23:31:04.247411+00', 1426, 1, 106, '', 'X', '', 1, 1, 'Y', 'wf1_7FM-47Y', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2250, '2015-10-30 21:53:54.661908+00', '2018-10-03 22:21:58.742906+00', 6756, 3, 106, '', 'X', '', 1, 1, 'Y', 'vAlkYz-VUZI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2251, '2015-10-30 21:55:28.293938+00', '2018-10-02 12:45:15.768344+00', 2498, 3, 106, '', 'X', '', 1, 1, 'Y', 'RnSIlBarFyM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (128, '2012-08-12 13:47:54.524665+00', '2015-11-08 22:02:31.641212+00', 1358, 1, 106, '', 'B', 'When the couples meet at the bottom during bars 12-15 they should cross up, each W passing in front of her P, and not loop with all M passing all W left shoulder.', 1, 1, 'Y', '73s-7ErcgvE', 0, 90, NULL);
INSERT INTO 'dancevideo' VALUES (3515, '2018-04-17 22:14:58.818192+00', '2018-04-18 05:21:45.887937+00', 14047, 1, 3637, '', 'A', 'This medley by members of the New World Dancers includes 2 dances: Mr. Steve Wyrick’s Strathspey and Mr. Steve Wyrick’s Reel.



Taken from a performance at Dunsmuir House, Oakland, December 2014. ', 1, 1, 'Y', '1Q8wxnW-3p4', 360, 475, NULL);
INSERT INTO 'dancevideo' VALUES (2258, '2015-11-09 18:36:21.09264+00', '2015-11-09 22:44:43.282011+00', 4595, 1, 274, '', 'C', 'Budapest Dance House for beginners, 2015.11.07

Two and a half times through :-)', 1, 1, 'Y', '_HfnJL_dJc8', 0, 83, NULL);
INSERT INTO 'dancevideo' VALUES (2259, '2015-11-12 23:58:14.910218+00', '2015-11-12 23:59:49.898427+00', 16525, 4, 106, '', 'A', 'Demonstration by the Aberdeen RSCDS branch team at Duthie Park, september 2015 (part of a longer display)', 1, 1, 'Y', 'oxwXlXegR4c', 288, 357, NULL);
INSERT INTO 'dancevideo' VALUES (2237, '2015-10-27 19:01:26.385406+00', '2015-11-18 15:38:49.43572+00', 11587, 1, 106, '', 'D', 'On first time through bars 17-24 are wrongly danced as a 6 bar chase + a 2 bar turn.  It is done correctly the second time (start at 1:05) as a 4-bar chase + a 4-bar turn.  The couples following have difficulties.  ', 1, 1, 'Y', '4ZdJpHua6ZQ', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3545, '2018-06-01 22:41:41.520727+00', '2018-06-03 14:06:36.603202+00', 4804, 1, 1332, '', 'B', 'Danced 3x, by a 2 couple set. Danced on a lawn.', 1, 1, 'Y', 'jC4VDC9z7ZA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2260, '2015-11-13 21:03:11.177435+00', '2015-11-14 01:55:54.027342+00', 2972, 1, 106, '', 'B', 'Published on 12 Nov 2015



Jim Stott, who is on the Management Board of the RSCDS and an active member of the Aberdeen Branch, began teaching P4/5 pupils at Meiklemill Primary School, Ellon in September 2013 to promote ''Jigs and Reels''.



The class learned a lot of Ceilidh dances, then were introduced to several dances from the Jigs and Reels pack offered by the RSCDS.



Jim worked with the teacher to practice steps and formations with her class during the week, and they all gained a Bronze Accreditation Medal and the school got its ''Bronze RSCDS Accreditation''.



The children passed their Introductory Medal Tests in June 2014 and then learned how to dance ''The Honeymoon'' for their Headteacher''s retirement in December 2014.



', 1, 1, 'Y', 'fgjPdXMewx0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2261, '2015-11-13 21:14:04.078065+00', '2015-11-14 01:56:21.883279+00', 4641, 7, 106, '', 'B', 'Published on 9 Nov 2015.  A video from the Saturday Night Formal Ball at the Bell''s Sports Centre in Perth!



The RSCDS AGM took place over the weekend of November 7th and 8th in Perth, Scotland, and we were pleased to welcome dancers from around the world.



Thank you to all those who made the weekend a success!', 1, 1, 'Y', '1E4Eh2KydKg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2262, '2015-11-13 21:19:05.706303+00', '2015-11-14 01:56:46.779092+00', 4411, 7, 106, '', 'B', '''The Minister on the Loch'' was danced on November 7, 2015 by members of the Upper Hutt Scottish Country Dancing Club at the annual Highland Gathering at Harcourt Park, Upper Hutt, by Wellington, New Zealand ', 1, 1, 'Y', 'wk4exQvB90k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2263, '2015-11-13 21:23:23.33758+00', '2015-11-14 01:57:09.777723+00', 3027, 3, 106, '', 'D', '''The Hunting Horn'' was on the programme of the Carterton SCD Club''s annual dance on November 7, 2015.

Live music was provided by Peter Elmes, Aileen Logie and Don McKay.

Carterton is by Wellington, N.Z.', 1, 1, 'Y', 'wlzwpChaNy4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1576, '2014-03-01 12:02:51.209434+00', '2016-04-28 02:27:23.438174+00', 14597, 1, 106, '', 'B', 'Medley: Jig - Strathspey - Reel



This dance has been changed since this Rechberg workshop, where Fred DeMarse taught the original version, which starts with 1c+3c set, petronella.   The definitive version starts with 1c+3c petronella into the center and set.



Note: Different to what is shown in the video, the final description says that on bars 15-16 ALL couples should set and the final turn on bars 29-32 should be done giving both hands if danced in Strathspey time.', 1, 1, 'Y', 'rK0Dgolnml0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3546, '2018-06-03 09:51:08.152723+00', '2018-06-03 14:07:15.969616+00', 7227, 3, 513, '', 'D', '', 1, 1, 'Y', '2kQh6tzAYHM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2304, '2015-12-11 17:35:29.616176+00', '2015-12-15 21:55:36.238894+00', 7629, 1, 2213, '', 'B', '', 1, 1, 'Y', 'vAVvZtMCfs4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1935, '2015-02-17 20:57:45.186355+00', '2016-04-28 02:27:29.629629+00', 14597, 2, 513, '', 'B', 'Medley: Jig - Strathspey - Reel



This dance has been changed since this Rechberg workshop, shown on another video, where Fred DeMarse taught the original version, which starts with 1c+3c set, petronella.   The definitive version shown here at Kuckucksnest starts with 1c+3c petronella into the center and set.



Note: Different to what is shown in the video, the final description says that on bars 15-16 ALL couples should set and the final turn on bars 29-32 should be done giving both hands if danced in Strathspey time.', 1, 1, 'Y', '63o9LyDm3Qo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2464, '2016-04-15 14:11:58.385495+00', '2016-04-17 03:00:44.080292+00', 16034, 2, 954, '', 'A', '', 1, 1, 'Y', '1OoQEIDcROY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2272, '2015-11-27 08:34:40.689553+00', '2016-11-12 20:49:00.351513+00', 16824, 1, 106, '', 'B', 'The dance was recorded at a social dance during the November Course 2015 at the "Kuckucksnest". 

', 1, 1, 'Y', '-nd0q60USdM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2289, '2015-12-08 16:51:35.386575+00', '2015-12-15 05:30:38.564346+00', 950, 1, 1041, '', 'C', '', 1, 1, 'Y', 'UyNUFTsQjBU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2361, '2016-02-20 15:12:21.050089+00', '2016-02-20 15:15:20.352613+00', 13581, 5, 106, '', 'A', '', 1, 1, 'Y', 'ZzoDjprDCsU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2264, '2015-11-13 22:29:02.550777+00', '2015-11-14 13:56:48.232091+00', 12907, 2, 1, '', 'B', 'Ian F Russell writes:



“It would appear that the Aberdeen Dem team have the last 8 bars wrong!!!



The 4 individual arches figures are each 2 bars.



In the dem, the dancers making the arch who are coming out from the middle are actually using 4 bars, except for the last change (2nd cpl and 1st cpl).



In the Dem, dancers coming out from the middle during the first 3 changes use an "extra" 2 bars  for the woman to turn under while the next two cpls do their arch figure (ie it becomes a "meanwhile" for these dancers) 



The last two cpls to change places have to change on the last 2 bars of the dance and so do not have any music to "borrow"!



 



But Jim tells me that all 4 changes should be "complete" (and the women turned under into place) in 2 bars!



Jim writes:



 



The end is in two bar phrases.



5s make an arch 4s go under.  5th lady goes in front of her of her partner under his right arm to 4th place.



4s make an arch 3s go under.  4th lady goes in front of her partner under his arm.



3s Make an arch 2s go under.  3rd lady goes in front of her partner under his arm.



2s make an arch 1s go under.  2nd lady passes in front of her partner under his arm.”

', 1, 1, 'Y', 'dr5zn1i7qDM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2367, '2016-02-20 15:49:12.960761+00', '2016-02-20 15:49:28.675487+00', 11369, 3, 106, '', 'A', 'Newcastle SCD festival 2016 - German mixed team 2', 1, 1, 'Y', '2uRtPOFF-DA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2265, '2015-11-13 22:55:22.688422+00', '2015-11-14 14:01:49.721921+00', 12907, 3, 1, '', 'B', 'Ian F Russell writes:



“It would appear that the Aberdeen Dem team have the last 8 bars wrong!!!



The 4 individual arches figures are each 2 bars.



In the dem, the dancers making the arch who are coming out from the middle are actually using 4 bars, except for the last change (2nd cpl and 1st cpl).



In the Dem, dancers coming out from the middle during the first 3 changes use an "extra" 2 bars  for the woman to turn under while the next two cpls do their arch figure (ie it becomes a "meanwhile" for these dancers) 



The last two cpls to change places have to change on the last 2 bars of the dance and so do not have any music to "borrow"!



 



But Jim [Stott, teacher from Aberdeen] tells me that all 4 changes should be "complete" (and the women turned under into place) in 2 bars!



Jim writes:



 



The end is in two bar phrases.



5s make an arch 4s go under.  5th lady goes in front of her of her partner under his right arm to 4th place.



4s make an arch 3s go under.  4th lady goes in front of her partner under his arm.



3s Make an arch 2s go under.  3rd lady goes in front of her partner under his arm.



2s make an arch 1s go under.  2nd lady passes in front of her partner under his arm.”', 1, 1, 'Y', 'kgqdeIP0oK8', 537, 651, NULL);
INSERT INTO 'dancevideo' VALUES (2416, '2016-03-14 23:13:52.362699+00', '2016-03-14 23:14:13.880868+00', 3580, 4, 106, '', 'D', 'Published on 1 Feb 2015



Royal Scottish Country Dance Society, Seattle Branch

Social Dance Oct 2012



Once through only', 1, 1, 'Y', '66wyqe83zjU', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2197, '2015-10-16 18:53:29.616184+00', '2015-11-15 20:31:47.825242+00', 11216, 1, 1358, '', 'D', 'The video shows "Back to Back" danced on the Saint-Petersburg Lermontov Ball (October 2014). The dance is danced 4 times, once for each couple. For bars 29-32 a variant is danced: instead of dancing out the ends and casting R to 2pl, 1c here dances out the sides, casts R and crosses in to 2pl.  1c then steps/dances down to 4pl.', 1, 1, 'Y', 'uAGYCzcbNos', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2266, '2015-11-18 15:36:43.659329+00', '2015-11-18 15:37:06.733119+00', 10433, 10, 106, '', 'B', 'A demo team from the Naramata Scottish Country Dancers performs the Dreamcatcher Strathspey at our local Robbie Burns dinner on 29 Jan 2013.', 1, 1, 'Y', 'QN343EYsT7w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2267, '2015-11-23 21:09:54.515277+00', '2015-11-23 21:10:41.321341+00', 1087, 8, 106, '', 'A', 'Scottish Flowers dancing the "Catch The Wind" at the 2015 Highland Gathering in Peine, May 2015', 1, 1, 'Y', 'GeV2hpDsqQg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2271, '2015-11-24 16:40:21.470778+00', '2015-11-25 21:59:45.307503+00', 4022, 1, 513, '', 'C', '', 1, 1, 'Y', '_SXZL--M1OY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2276, '2015-11-28 22:25:49.846767+00', '2015-11-28 22:26:18.606828+00', 11685, 1, 160, '', 'A', 'There is no recording for this dance. We chose the set of strathspeys for "Beauty of the North from The Music Makars'' CD titled "Jig for Joy". ', 1, 1, 'Y', 'BeyE8_yX0S0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2268, '2015-11-24 16:37:57.842133+00', '2015-11-25 23:05:11.014483+00', 14720, 2, 513, '', 'C', '', 1, 1, 'Y', '4_Digg1d_MQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2269, '2015-11-24 16:39:01.237703+00', '2015-11-25 23:19:16.083787+00', 7973, 1, 513, '', 'C', '', 1, 1, 'Y', 'r9w_WIaVVPg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3481, '2018-03-22 01:36:22.787706+00', '2018-03-22 01:37:22.015744+00', 11970, 2, 160, '', 'A', '', 1, 1, 'Y', 'uuu8AiWgLb4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2273, '2015-11-28 00:05:42.085054+00', '2015-11-28 05:36:12.15757+00', 3529, 1, 1330, '', 'C', '', 1, 1, 'Y', 'plXdt0QrQnE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2274, '2015-11-28 18:50:56.714758+00', '2015-11-28 18:53:59.961137+00', 10070, 1, 160, '', 'A', 'There is no recording for this dance. It is danced to "The Union Jig" from the CD "Moments in Time" by Muriel Johnston, Jim Lindsay, and Keith Smith.', 1, 1, 'Y', 'Gamx8S-ZeXE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2277, '2015-12-01 11:05:43.998479+00', '2015-12-05 17:20:14.271979+00', 16825, 1, 197, '', 'B', 'A new Scottish Country Dance by Lara Friedman-Shedlov in honor of teacher and friend Norma Briggs. 

Music by O''er the Border. Music: Atholl Highlanders, played by David Mullen, violin; Mary Deck, viola; Charlie Deck, cello; Francis Deck. bass; and Mike Briggs, keyboard. 

Danced by: Janice & Carl, Nancy & Lynn, Amy & Gayle', 1, 1, 'Y', 'MozsFAZlMu8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2296, '2015-12-09 05:05:51.2546+00', '2015-12-09 07:37:06.986051+00', 6035, 1, 2794, '', 'A', 'The full video is actually a display, beginning with Shene Gate, then followed by Autumn in Appin and The Clansman.



Danced by RSCDS London Branch at Pont Street.', 1, 1, 'Y', 'aC9vA2i-164', 17, 105, NULL);
INSERT INTO 'dancevideo' VALUES (2297, '2015-12-09 14:12:48.728347+00', '2015-12-09 14:14:19.460133+00', 314, 8, 106, '', 'A', 'Middle part of a longer display.  By London RSCDS Pont Street, 1998', 1, 1, 'Y', 'aC9vA2i-164', 105, 228, NULL);
INSERT INTO 'dancevideo' VALUES (2298, '2015-12-09 14:15:51.629967+00', '2015-12-09 14:29:19.903753+00', 1223, 7, 106, '', 'A', 'Final part of a longer display.  By London RSCDS Pont Street, 1998.



This is danced in a 4C set, 3c and 4c on opposite sides (1,2,3x,4x) with both 1c and 4c starting.  After once through the progression is (2,1,4x,3x), at the end the final 4 bars are modified to finish (1,2x,3,4x).', 1, 1, 'Y', 'aC9vA2i-164', 228, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3517, '2018-04-18 15:18:29.420899+00', '2018-04-18 15:30:10.10203+00', 1244, 6, 596, '', 'X', '', 1, 1, 'Y', '5asD9oqAQHg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2278, '2015-12-08 14:48:46.912633+00', '2015-12-15 05:39:27.385868+00', 11773, 1, 1041, '', 'B', '', 1, 1, 'Y', 'gB14eV9CrIY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2279, '2015-12-08 15:06:50.543197+00', '2015-12-15 05:42:10.110996+00', 11771, 1, 1041, '', 'B', '', 1, 1, 'Y', 'v6kB4uwNsnw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2280, '2015-12-08 15:11:12.614387+00', '2015-12-15 05:44:43.064484+00', 8930, 1, 1041, '', 'B', '', 1, 1, 'Y', 'A-MMA8KZHgU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2288, '2015-12-08 16:49:40.712016+00', '2015-12-15 21:43:56.930845+00', 4064, 1, 1041, '', 'B', '', 1, 1, 'Y', 'yGFfTsjas9A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2282, '2015-12-08 16:11:00.981865+00', '2015-12-15 05:48:42.630155+00', 15436, 1, 1041, '', 'D', '', 1, 1, 'Y', 'yhWS-V2EcBk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2283, '2015-12-08 16:16:01.19126+00', '2015-12-15 05:50:55.984468+00', 5376, 1, 1041, '', 'C', '', 1, 1, 'Y', 'nkOCaZTt9YI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2292, '2015-12-08 18:38:23.673015+00', '2015-12-15 06:41:56.896004+00', 140, 1, 1041, '', 'D', '', 1, 1, 'Y', 'uSuXncVV5gA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2285, '2015-12-08 16:28:55.959386+00', '2015-12-15 20:59:10.757746+00', 7085, 1, 1041, '', 'C', '', 1, 1, 'Y', 'x2fbYv1nndg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2284, '2015-12-08 16:18:47.698624+00', '2015-12-15 21:39:40.03166+00', 15437, 1, 1041, '', 'C', '', 1, 1, 'Y', 'g-OEW4sRGAE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2293, '2015-12-08 18:44:57.754475+00', '2015-12-15 21:48:56.35292+00', 723, 1, 1041, '', 'C', '4 times; "once and to the bottom".', 1, 1, 'Y', 'JoopfVaN16U', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2291, '2015-12-08 18:31:28.312908+00', '2015-12-15 21:59:05.407733+00', 4431, 1, 1041, '', 'C', '', 1, 1, 'Y', 'JDqVODFeCAA', 54, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2295, '2015-12-08 18:56:21.050079+00', '2015-12-15 22:01:05.517733+00', 16700, 1, 1041, '', 'B', '', 1, 1, 'Y', 'WVZEla1i1Yg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2294, '2015-12-08 18:48:16.614655+00', '2015-12-29 22:38:47.615545+00', 7109, 4, 1041, '', 'C', 'Danced "once and to the bottom" in a 4C set.', 1, 1, 'Y', 'RfLTJSRamvw', 30, 173, NULL);
INSERT INTO 'dancevideo' VALUES (2290, '2015-12-08 16:55:49.583461+00', '2015-12-29 22:44:05.278913+00', 1641, 4, 1041, '', 'C', '', 1, 1, 'Y', '0SGULg0x4gg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2299, '2015-12-09 20:13:42.673824+00', '2016-03-15 13:13:07.304818+00', 16508, 1, 2795, 'dd/dance/video/upload/Twenty-Three_Two_Ninety1_Prag_2015.MOD', 'A', 'Performed by the Prague Caledonian Club with Geraldine and Holger Schuckelt from Dresden, Germany. Prague, December 2015', 0, 1, 'Y', 'NL4kjz2RdgE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2306, '2015-12-12 17:14:53.631852+00', '2015-12-15 06:38:47.783885+00', 9560, 2, 274, '', 'B', 'Two times through', 1, 1, 'Y', '9fGhOzio7LY', 102, 169, NULL);
INSERT INTO 'dancevideo' VALUES (2286, '2015-12-08 16:32:03.384177+00', '2015-12-15 21:16:40.604311+00', 13469, 2, 1041, '', 'B', '', 1, 1, 'Y', 'L5seqD1lkEQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2305, '2015-12-12 17:10:32.946046+00', '2015-12-15 22:07:51.660812+00', 4185, 1, 274, '', 'B', 'This video is once through only, in Strathspey time.', 1, 1, 'Y', 'ePrYQWWh-yE', 0, 126, NULL);
INSERT INTO 'dancevideo' VALUES (2321, '2016-01-30 15:05:04.845193+00', '2016-01-30 15:11:46.969989+00', 16535, 1, 106, '', 'A', 'Published on 8 Aug 2015



John Cass (Book 49)

Judith Rousseau, Fiona Mackie, Margaret Plummer, Emma Orgeret, Caitlin Wilkinson, Antoine Rousseau, Mathias Ferber, Jean-Hervé Guilcher, Kenton Stutz and Andrew Watson.', 1, 1, 'Y', 'KSMgamI66IM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2308, '2016-01-04 15:13:36.09105+00', '2016-01-05 02:05:12.930334+00', 14418, 2, 223, '', 'A', '', 1, 1, 'Y', '3KrTTxmuJs8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2309, '2016-01-04 15:15:55.255476+00', '2016-01-05 21:48:33.387221+00', 16187, 1, 223, '', 'B', '', 1, 1, 'Y', 'ac9Ad1NYbcc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2311, '2016-01-08 08:29:28.234205+00', '2016-01-08 12:38:02.935701+00', 16186, 1, 223, '', 'B', '', 1, 1, 'Y', 'gfLg5eLWegk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2312, '2016-01-08 08:33:01.10012+00', '2016-01-09 00:15:25.182027+00', 16196, 1, 223, '', 'B', 'Now being danced as a medley 3x S32+R32', 1, 1, 'Y', '_1xs2KNp8L8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2313, '2016-01-14 17:28:10.852899+00', '2016-01-15 00:19:16.553591+00', 10819, 1, 197, '', 'A', ' Dance devised by Mary Cant to celebrate the opening of the new Fowlis Easter Village Hall in southwest Angus on June 22nd 2002.



The hall was designed by Iain Dunsire of Battledown Studio, Forgandenny, Perthshire, taking inspiration from paintings of Angus stackyards by the eminent landscape artist James McIntosh Patrick.



The formations in the dance reflect the architecture of the building. The wheels represent the round stacks of corn; the chase represents the passageways outside the main hall; the reel of four represents weaving in

and out of the various rooms; and the dance finishes with a celebratory circle representing the main hall, comprised of the two largest stacks.



The dancers in the video are: Jim McNicol and Joanne Reid, Bruce Marshall and Christine Cant; Bill and Mary Cant, and David and Morag Dorward. The musicians are: Jim Lindsay (accordion), Gillian Ramsay (fiddle), and Graham Sherrit (drums).



The tunes are: The New Fowlis Hall by Jim Lindsay; The Spider’s Web by Bill Cook; Davie’s Brae by Jim Johnstone; and Hoddum House

(Traditional).



Video by Malcolm Buckney', 1, 1, 'Y', 'fKcTor4vNn4', 18, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2314, '2016-01-14 18:17:24.817361+00', '2016-01-15 00:24:17.241828+00', 16842, 1, 197, '', 'D', 'Video by Robert Lockhart', 1, 1, 'Y', 'iv2JNFr0Qeg', 104, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2469, '2016-04-24 21:32:11.863201+00', '2016-04-26 08:56:07.865574+00', 3963, 1, 954, '', 'D', '', 1, 1, 'Y', 'D2ioCHeaTIk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3516, '2018-04-17 22:16:20.583354+00', '2018-04-18 05:21:12.550718+00', 14046, 1, 3637, '', 'A', 'This medley by members of the New World Dancers includes 2 dances: Mr. Steve Wyrick’s Strathspey and Mr. Steve Wyrick’s Reel.



Taken from a performance at Dunsmuir House, Oakland, December 2014. ', 1, 1, 'Y', '1Q8wxnW-3p4', 360, 475, NULL);
INSERT INTO 'dancevideo' VALUES (1875, '2014-10-31 00:33:01.843989+00', '2016-01-24 08:01:00.460303+00', 769, 5, 106, '', 'B', 'Published on Oct 28, 2014



This is a teaching video of a Scottish Country Dance. There are audio and on screen instructions and a bar counter. The dancers wear numbered coloured tabards so that the learner can follow a particular dancer through the dance.



The Ochil Scottish Country Dancers videoed this dance in August 2014 at St Ninian''s Parish Church Hall, Stirling, Scotland.

', 1, 1, 'Y', 'CSk2kg7R2aw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2316, '2016-01-24 16:52:56.384198+00', '2016-01-24 16:53:21.297221+00', 4641, 7, 106, '', 'B', '', 1, 1, 'Y', 'CdGdSdXvb4A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2324, '2016-02-08 15:24:45.65547+00', '2016-02-10 23:51:29.361129+00', 8492, 1, 2697, '', 'D', '', 1, 1, 'Y', 'gQHx2sv8ONI', 137, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2325, '2016-02-08 15:27:08.131292+00', '2016-02-11 00:00:45.882075+00', 8148, 1, 2697, '', 'D', '', 1, 1, 'Y', 'e0cLQpU3yfw', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2317, '2016-01-28 21:09:16.97092+00', '2016-01-29 23:17:48.105874+00', 13365, 1, 160, '', 'A', 'The full video starts earlier, at about bar 18 of the previous time through.', 1, 1, 'Y', 'BLFVttx-Dyw', 31, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2319, '2016-01-30 00:12:29.565496+00', '2016-01-30 00:16:54.289157+00', 14393, 2, 106, '', 'A', 'A video by the Montreal ''demo'' group.



The full video starts earlier, at bar 3 of the previous time through.  A pity those two bars are missing. ', 1, 1, 'Y', 'DrnB51YEIt4', 57, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2318, '2016-01-29 12:59:38.052733+00', '2016-02-01 13:11:54.64624+00', 14457, 1, 1957, '', 'B', 'Twice through only.', 1, 1, 'Y', 'aaOkOw14Txg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2320, '2016-01-30 14:59:19.047708+00', '2016-02-02 14:13:46.300618+00', 16858, 1, 106, '', 'A', 'Demonstration by members of the Kitchener - Waterloo RSCDS Branch (Ontario) at the 35th Annual Burns Supper, 2016', 1, 1, 'Y', 'BJWP_KBubD0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2435, '2016-03-27 03:40:50.359057+00', '2016-03-27 03:42:14.094837+00', 16732, 1, 160, '', 'B', 'Music: "Merrily Danced the Quaker''s Wife" by Bobby Frew from the CD "Memory Lane".

Some very slight bobbles in the repeat.

', 1, 1, 'Y', 'ym0L623H5r8', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2323, '2016-02-07 21:01:34.714163+00', '2016-02-07 21:03:12.135017+00', 3594, 4, 106, '', 'C', '2014 in Lower Hutt, New Zealand', 1, 1, 'Y', '31quhFV4vgg', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2326, '2016-02-10 14:02:06.870613+00', '2016-02-10 14:02:22.386599+00', 16868, 1, 106, '', 'B', '', 1, 1, 'Y', 'YUJX55iBCZw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2331, '2016-02-12 01:19:05.533319+00', '2016-02-12 01:19:23.305112+00', 13648, 3, 106, '', 'A', '', 1, 1, 'Y', 'HCJgNCe675g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2332, '2016-02-12 10:52:01.103303+00', '2016-02-12 10:52:29.0877+00', 462, 6, 106, '', 'D', '', 1, 1, 'Y', '6jOSnyNrkWA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2333, '2016-02-12 10:59:06.584644+00', '2016-02-12 10:59:22.552619+00', 10070, 2, 106, '', 'D', 'The dance was recorded during the Christmas Ball 2015 in Muenster/Germany.

It was done in a social situation and may contain errors!', 1, 1, 'Y', '9l0RfzDnRy4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2336, '2016-02-13 01:00:29.781058+00', '2016-02-13 01:01:00.838818+00', 16522, 2, 106, '', 'A', '', 1, 1, 'Y', 'kbTj5bdb9og', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2337, '2016-02-13 01:29:06.955851+00', '2016-02-13 01:29:21.662269+00', 16524, 2, 106, '', 'A', '', 1, 1, 'Y', '9DfE6uTmfmE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2338, '2016-02-13 01:33:50.823726+00', '2016-02-13 01:34:04.050879+00', 16536, 3, 106, '', 'A', '', 1, 1, 'Y', 'y3Cf49jrO4Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2339, '2016-02-13 01:36:43.559353+00', '2016-02-13 01:37:22.233662+00', 16537, 2, 106, '', 'A', '', 1, 1, 'Y', '7vP0KxWlz9Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2344, '2016-02-15 12:31:18.054463+00', '2016-02-15 12:59:46.915675+00', 1163, 3, 1675, '', 'A', 'International Team (Mixed, Black) at Newcastle Festival 2016', 1, 1, 'Y', 'e4uQ5XzDAek', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2342, '2016-02-15 12:29:44.120906+00', '2016-02-15 12:54:56.857359+00', 743, 4, 1675, '', 'A', 'International Team (Men) at Newcastle Festival 2016', 1, 1, 'Y', '8MNxB3d6ckw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2341, '2016-02-15 12:28:56.263319+00', '2016-02-15 12:57:37.008082+00', 794, 5, 1675, '', 'A', 'International Team (Ladies) at Newcastle Festival 2016', 1, 1, 'Y', 'VyFbXBO5hGw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2343, '2016-02-15 12:30:26.553661+00', '2016-02-15 13:06:59.755729+00', 4086, 4, 1675, '', 'A', 'International Team (Ladies) at Newcastle Festival 2016', 1, 1, 'Y', 'JKFMcJKmNxI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2345, '2016-02-15 12:33:12.211039+00', '2016-02-15 13:05:13.054383+00', 11770, 3, 1675, '', 'A', 'International Team (Mixed, White) at Newcastle Festival 2016', 1, 1, 'Y', 'buFtRUH00Mo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2334, '2016-02-12 15:38:38.249498+00', '2016-02-15 13:06:50.080822+00', 4862, 1, 2697, '', 'Z', '', 1, 1, 'Y', 'Nztf8MylFjQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2346, '2016-02-15 12:34:04.866658+00', '2016-02-15 13:08:28.204029+00', 16524, 3, 1675, '', 'A', 'International Team (Mixed, White) at Newcastle Festival 2016', 1, 1, 'Y', 'FIblxnG8vKw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2340, '2016-02-15 12:26:46.686266+00', '2016-02-15 13:09:31.522735+00', 11190, 2, 1675, '', 'A', 'International Team (Men) at Newcastle Festival 2016', 1, 1, 'Y', 'sJdFNCUQ3Aw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2347, '2016-02-15 14:52:44.048682+00', '2016-02-15 14:55:45.64685+00', 5885, 9, 1675, '', 'A', 'International Team (Mixed, Black) at Newcastle Festival 2016', 1, 1, 'Y', 'tFBDb-mDKCM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2335, '2016-02-12 16:25:34.336894+00', '2016-02-15 17:23:40.588593+00', 16034, 1, 106, '', 'D', 'Recorded in class in Nunspeet, 6 february 2016.', 1, 1, 'Y', 'IOXus4qifiQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2330, '2016-02-11 01:11:23.880928+00', '2016-02-19 20:55:22.835921+00', 16738, 1, 106, '', 'B', 'Danced by Simon Scott''s Gleneagles class.', 1, 1, 'Y', 'csqyA1QdN-A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2349, '2016-02-17 09:57:01.539471+00', '2016-02-17 10:44:53.468806+00', 2934, 1, 2824, '', 'B', 'Partly variations on the original dance description are danced, like "spin-turns down to 2nd place" instead of "turn RH, cast off, turn LH to face corners" or extra twirls in the "set to and turn corners".', 1, 1, 'Y', '28UGxjl6bbQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3547, '2018-06-03 14:12:46.957105+00', '2022-11-13 18:28:49.814485+00', 18357, 1, 202, '', 'A', 'Charlotte, North Carolina, 2018. Although the instructions say all couples turn partner in the last four bars, here the 1st couples keep setting and only 3rd & 2nd couples turn partner.', 1, 1, 'Y', 'J-gdNQBH8fE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2362, '2016-02-20 15:20:32.642091+00', '2016-02-20 15:20:51.232407+00', 2437, 4, 106, '', 'A', 'Newcastle SCD festival 2016 - German ladies team: The Gentleman', 1, 1, 'Y', '5fYlmcv7MhY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2363, '2016-02-20 15:24:45.739067+00', '2016-02-20 15:25:02.540248+00', 11284, 4, 106, '', 'A', 'Newcastle SCD festival 2016 - German mixed team 1: Linnea''s Strathspey', 1, 1, 'Y', '5GRgbBLyh1k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2364, '2016-02-20 15:29:34.180612+00', '2016-02-20 15:29:46.443357+00', 7542, 1, 106, '', 'A', 'Newcastle RSCDS Festival 2016 evening dance. 



Edinburgh University New Scotland country dance society', 1, 1, 'Y', 'fKghmWJW7v4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2365, '2016-02-20 15:36:46.581714+00', '2016-02-20 15:37:11.13527+00', 4404, 7, 106, '', 'A', 'Alba Clyde Ladies - Newcastle Festival 2016 ', 1, 1, 'Y', 'mxbZZI6gx3w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2353, '2016-02-20 00:30:38.836329+00', '2016-02-24 15:02:48.986932+00', 10327, 8, 106, '', 'D', 'Terri''s Memorial Ceilidh, Olympia Restaurant, Mil Palmeras, 21st Jan 2011', 1, 1, 'Y', 'P52z-ZF_sdo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2366, '2016-02-20 15:40:35.887152+00', '2016-02-20 15:43:42.180233+00', 4844, 5, 106, '', 'A', 'Newcastle SCD festival 2016 - German mixed team 1', 1, 1, 'Y', 'z3EH1QX-pJc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2368, '2016-02-20 15:52:32.313617+00', '2016-02-20 15:52:45.717832+00', 2631, 2, 106, '', 'A', 'Newcastle SCD Festival 2016 - German Team Men', 1, 1, 'Y', 'chj7Qhtzwjk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2369, '2016-02-20 15:58:36.978756+00', '2016-02-20 15:58:56.023327+00', 7242, 4, 106, '', 'A', 'Alba Mens - RSCDS Newcastle Festival 2016', 1, 1, 'Y', 'ptjGy7ojYWg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2370, '2016-02-21 16:14:19.453804+00', '2016-02-21 16:14:35.257327+00', 2110, 2, 106, '', 'B', 'By the Chiswick SCD club members         , february 2016', 1, 1, 'Y', 'Cgng-Y3kZnI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2371, '2016-02-24 13:16:29.394485+00', '2016-02-24 14:58:56.240906+00', 6720, 1, 2824, '', 'D', 'Twice only', 1, 1, 'Y', '-9abtHX5Ud8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2360, '2016-02-20 00:50:04.647725+00', '2016-02-24 15:00:20.027454+00', 10327, 15, 106, '', 'D', 'Ceilidh OXO Reel at St Andrew''s in Froideville Switzerland on November 30th 2012. Ref.: Loch Leman Ceilidh Band (LLCB).', 1, 1, 'Y', 'C2PJ6gCP1T4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2359, '2016-02-20 00:48:21.866434+00', '2016-02-24 15:00:41.382517+00', 10327, 14, 106, '', 'D', 'Published on 5 Apr 2012', 1, 1, 'Y', 'DIsM45omNQ4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2358, '2016-02-20 00:45:46.474596+00', '2016-02-24 15:00:52.182582+00', 10327, 13, 106, '', 'D', 'The OXO Reel as performed at the Lonach Hall Burns Celebration 2009', 1, 1, 'Y', 'f4oQ8tV_hWs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2424, '2016-03-19 22:36:05.536932+00', '2016-03-19 22:36:25.879279+00', 15310, 1, 106, '', 'A', 'An instructional Country Dance video by Chiswick Scottish Country Dance Club London. Once through.', 1, 1, 'Y', 'dArsUkrkreM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2357, '2016-02-20 00:43:01.938164+00', '2016-02-24 15:01:03.090743+00', 10327, 12, 106, '', 'D', 'Published on 22 Mar 2015.  Filmed during a workshop with professional dancers for the modern dance, for a research project leading to a new dance show in 2016.

The music is "Appalachian Joy".', 1, 1, 'Y', 'PfdPFWh0F_A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2356, '2016-02-20 00:38:32.733032+00', '2016-02-24 15:01:17.933363+00', 10327, 11, 106, '', 'D', 'The students and teachers from Gergel School (Kiev, Ukraine) learn foreign languages (English, French, German) through Scottish, English, Breton, Austrian songs and Dances.', 1, 1, 'Y', '1wIpA_wUUgY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2350, '2016-02-20 00:16:13.514056+00', '2016-02-24 15:01:46.48138+00', 10327, 5, 106, '', 'D', 'This is a music video, showing the band only, with the band leader calling the dance.', 1, 1, 'Y', 'sxLzNKFnXQI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2351, '2016-02-20 00:20:50.793312+00', '2016-02-24 15:02:21.784841+00', 10327, 6, 106, '', 'D', 'At a wedding?  ', 1, 1, 'Y', 'GpdCZQKYAKQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2352, '2016-02-20 00:26:30.188317+00', '2016-02-24 15:02:33.461996+00', 10327, 7, 106, '', 'D', 'Published on YouTube on 25 Sep 2013.   http://barndance.biz - Recovered from a Video CD, which in turn was created from a (literally) perishing VHS tape, this is a visual record of a historic gig - Tiger Moth''s farewell dance in 1989 at Bracknell Folk Festival.', 1, 1, 'Y', 'nT8RLmEA-tw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2354, '2016-02-20 00:33:11.722964+00', '2016-02-24 15:03:00.474087+00', 10327, 9, 106, '', 'D', '"The traditional English folk dance: The OXO Reel" ', 1, 1, 'Y', 'bsPM6fR_u88', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2372, '2016-02-27 22:28:39.312159+00', '2016-02-27 22:28:59.840437+00', 2242, 2, 106, '', 'A', 'Published on 27 Feb 2016.  Instructional Country Dance video by Chiswick Scottish Country Dance Club London.  

Twice through.', 1, 1, 'Y', '9vCoWzl2jVY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2376, '2016-03-04 21:09:11.526229+00', '2016-03-04 21:15:28.596018+00', 16465, 2, 106, '', 'D', 'To see the walk-through, play from 0:23.



Dufftown Dance Club - 2/10/15  www.dufftowndanceclub.com

Music from Robert Whitehead and his band ', 1, 1, 'Y', 'oPWsKbGvJPk', 140, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2375, '2016-03-01 10:53:26.277874+00', '2016-03-01 11:14:16.262288+00', 16887, 1, 1645, '', 'C', 'A rehearsal for a subsequent demo. Some infelicities of phrasing and position were still being worked out. There is one classic, but recovered, "where on earth am I supposed to be now" moment in the second time through. Otherwise its choreographically correct, while still showing the pitfalls of a fairly challenging dance.', 1, 1, 'Y', 'iuW033jkTkU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2378, '2016-03-04 22:27:04.839939+00', '2016-03-04 22:27:19.921146+00', 3672, 1, 106, '', 'D', 'Hamilton and Clydesdale Anniversary Ball    24th April 2015', 1, 1, 'Y', '7Fk7sgxE9_E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3485, '2018-03-24 16:48:46.973623+00', '2018-03-24 16:49:45.794495+00', 11185, 1, 160, '', 'A', '', 1, 1, 'Y', 'DDI5nsg19PA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2377, '2016-03-04 21:23:36.461914+00', '2016-03-04 22:32:44.6947+00', 14964, 2, 106, '', 'D', 'To see the walk-through, start  from 0:33.



Dufftown Dance Club - 2/10/15   www.dufftowndanceclub.com

Music from Robert Whitehead and his band', 1, 1, 'Y', 'FZFgZlHTENQ', 115, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2380, '2016-03-04 22:48:09.830213+00', '2016-03-04 22:48:22.644918+00', 3601, 1, 106, '', 'D', 'Recorded at the RSCDS Toronto January Monthly, 2016.', 1, 1, 'Y', 'TaXzTNLocVs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2381, '2016-03-04 22:52:02.829713+00', '2016-03-04 22:52:14.229745+00', 1393, 1, 106, '', 'B', 'Published on 17 Feb 2016', 1, 1, 'Y', 'Y0EHFDxPQGY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2382, '2016-03-04 22:57:53.333739+00', '2016-03-04 22:58:06.839227+00', 15954, 1, 106, '', 'B', 'Published on 8 Feb 2016', 1, 1, 'Y', 'Uo5P-XCxGLk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2383, '2016-03-04 23:32:03.781623+00', '2016-03-04 23:32:14.967226+00', 4312, 1, 106, '', 'B', 'Published on 8 Feb 2016', 1, 1, 'Y', '2mtkusPRrQg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2384, '2016-03-04 23:38:44.602529+00', '2016-03-04 23:39:01.353906+00', 899, 2, 106, '', 'D', 'Ardbrae Ball, February 6, 2016.', 1, 1, 'Y', 'uYxiCmwQyT4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2385, '2016-03-04 23:43:53.681432+00', '2016-03-04 23:44:06.737506+00', 1385, 1, 106, '', 'B', 'An interesting dance from The Imperial Book 4 that shape shifts from square set to longwise set and back again.', 1, 1, 'Y', 'JGrJTJcQ4ds', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2386, '2016-03-04 23:47:37.154145+00', '2016-03-04 23:47:49.167679+00', 9844, 1, 106, '', 'C', 'Published on 25 Feb 2016



At Broadlands Community Centre in Don Mills RSCDS Toronto hosts occasional Sunday afternoons where teachers are free to offer a themed program of dances. Teresa Lockhart''s session had a Hallowe''en theme: Dark & Sinister Dances.', 1, 1, 'Y', '4nh3yXW7KYc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2387, '2016-03-05 00:03:18.193263+00', '2016-03-05 00:03:29.532226+00', 16892, 1, 106, '', 'D', 'Published on 18 Feb 2016



', 1, 1, 'Y', 'GEWp9WDHwVo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3484, '2018-03-24 16:28:22.78055+00', '2019-02-13 17:19:19.123678+00', 17459, 1, 160, '', 'B', 'Xiaowen Yu was incorrectly credited. My sincere apologies. Peter 1672.', 1, 1, 'Y', 'vi41-fi54QE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2374, '2016-02-29 02:03:35.584965+00', '2016-03-08 16:41:12.000517+00', 16731, 2, 160, '', 'B', 'Just 1x through. The music is "Banks and Braes", Marian Anderson, Robert Burns Dances, HRMCD017 (2009) (Album 945)', 1, 1, 'Y', 'Rd3w2fCXtYE', 1, 40, NULL);
INSERT INTO 'dancevideo' VALUES (2783, '2017-01-13 14:14:47.304981+00', '2017-01-13 17:20:15.62453+00', 9286, 2, 2824, '', 'B', '', 1, 1, 'Y', 'bdJji0xd-qM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2787, '2017-01-17 18:12:12.435456+00', '2017-01-17 22:20:15.422699+00', 2813, 1, 954, '', 'A', '', 1, 1, 'Y', 'W0Bud2HTxK4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3486, '2018-03-26 09:46:22.731208+00', '2018-03-26 09:53:00.182521+00', 13596, 1, 2287, '', 'B', '', 1, 1, 'Y', 'W8bgODDgjuk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2789, '2017-01-17 18:16:15.144316+00', '2017-01-18 00:28:37.152859+00', 6947, 4, 954, '', 'A', 'Part of a longer display', 1, 1, 'Y', 'BW8nFzeYpYo', 0, 71, NULL);
INSERT INTO 'dancevideo' VALUES (3543, '2018-05-26 17:53:04.260316+00', '2018-05-26 18:00:22.93553+00', 9385, 1, 1720, '', 'A', '', 1, 1, 'Y', 'uiO0I0uwui4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2858, '2017-02-12 19:20:47.108798+00', '2017-02-13 17:08:07.862951+00', 6271, 3, 2084, '', 'A', 'Danced by the RSCDS Lyon men''s team, at Newcastle Festival 2017.', 1, 1, 'Y', '7mxkqTj2B8Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2388, '2016-03-05 00:08:28.029834+00', '2016-03-05 00:08:40.211948+00', 2431, 1, 106, '', 'D', 'Published on 19 Feb 2016



Geneva Park on Lake Couchiching was for many years the location of the Toronto Branch Annual Workshop Weekend. This dance was popular locally, as was the devisor, Bob Campbell.  In remembrance, the dance was on the programme for the 40th Tartan Ball in 2016.', 1, 1, 'Y', '7MkAP8QIEe4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2389, '2016-03-05 00:19:52.010269+00', '2016-03-05 00:20:06.536853+00', 2604, 4, 106, '', 'D', 'Published on 24 Dec 2015', 1, 1, 'Y', 'O3trurFtf6Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2390, '2016-03-05 00:23:28.736856+00', '2016-03-05 00:23:40.998648+00', 13391, 1, 106, '', 'C', 'Published on 25 Dec 2015



Danced at the 52nd Annual Tartan Ball, 2015.', 1, 1, 'Y', '1wa028OAUAM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2391, '2016-03-05 00:27:18.512391+00', '2016-03-05 00:27:32.684502+00', 3607, 3, 106, '', 'D', 'Published on 23 Dec 2015', 1, 1, 'Y', 'tPndMEbSgx8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2392, '2016-03-05 00:32:33.545282+00', '2016-03-05 00:32:48.305341+00', 5497, 5, 106, '', 'D', 'Red House at the Tartan Ball was a highlight of an evening full of highlights.', 1, 1, 'Y', 'jItekfF6kjo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2393, '2016-03-05 00:36:49.666085+00', '2016-03-05 00:37:03.986393+00', 1187, 1, 106, '', 'C', 'Published on 26 Dec 2015', 1, 1, 'Y', 'LE_uSeOV37o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2394, '2016-03-05 00:40:53.841487+00', '2016-03-05 00:41:04.533227+00', 10698, 1, 106, '', 'D', 'Published on 8 Jan 2016', 1, 1, 'Y', 'jackjIYFxeU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2395, '2016-03-05 16:44:20.790771+00', '2016-03-05 16:44:34.132227+00', 353, 1, 106, '', 'B', '', 1, 1, 'Y', 'fgGH-Y2pNsc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2847, '2017-02-12 18:03:45.217559+00', '2017-02-13 17:02:44.048736+00', 16524, 6, 2084, '', 'A', '', 1, 1, 'Y', '2EjjLm4fSRo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2418, '2016-03-15 00:34:59.496839+00', '2016-03-15 00:35:13.236984+00', 16509, 1, 106, '', 'A', 'Scottish Country Dancers Dresden', 1, 1, 'Y', 'QTUUyK3KOa0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2396, '2016-03-06 15:46:34.254263+00', '2016-03-06 22:01:31.622508+00', 12892, 1, 1041, '', 'Z', 'Video taken from behind the band and over their heads.  The dancers are very distant, hard to see, and sometimes off screen.  Useless.  Eric', 1, 1, 'Y', 'cC1TN56Wl2Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3488, '2018-03-26 10:00:32.828939+00', '2018-03-26 21:56:52.765677+00', 13600, 1, 2287, '', 'B', '', 1, 1, 'Y', '3aXUmHxLlDQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2398, '2016-03-10 22:35:49.966646+00', '2016-03-10 22:37:29.11072+00', 16856, 1, 106, '', 'B', '', 1, 1, 'Y', 'bElp3R4xzKc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2399, '2016-03-13 00:33:04.205859+00', '2018-10-02 08:54:15.6825+00', 5080, 2, 106, '', 'X', '', 1, 1, 'Y', '4tgkRSML2Mk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2412, '2016-03-14 22:53:37.498368+00', '2016-03-14 22:53:54.407876+00', 13077, 1, 106, '', 'B', 'Danced by members of the Belfast Branch', 1, 1, 'Y', 'f9q5cT8u0BM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2413, '2016-03-14 22:56:45.072348+00', '2016-03-14 22:57:13.077219+00', 8348, 2, 106, '', 'B', 'Danced by members of the Belfast Branch', 1, 1, 'Y', 'J1ptbhD0jnM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2422, '2016-03-19 15:44:55.62053+00', '2016-03-19 16:04:42.202221+00', 16018, 1, 197, '', 'Z', 'This video omits the first 8 bars of the dance, the all round poussette for the first two couples.  This figure was omitted from this performance at Capitol Weekend 2013.  Music by Thistle House, signature tune, Minnie Walker, composed by Dave Wiesler.', 1, 1, 'Y', 'qruhjn-xzqY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2417, '2016-03-15 00:29:28.844695+00', '2016-03-15 00:36:17.151881+00', 16676, 1, 106, '', 'A', 'Scottish Country Dancers Dresden', 1, 1, 'Y', 'C7jjOujTAFU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2419, '2016-03-15 00:41:35.973018+00', '2016-03-15 00:41:57.239613+00', 16617, 1, 106, '', 'A', 'Devised for Marie Stanzel in October 2012



Danced by the Prague Caledonian Club in (nearly) demonstration quality. Published in "Riverside Dances" 2015. ', 1, 1, 'Y', 'PrZ6RW3Usak', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2420, '2016-03-15 00:54:15.335344+00', '2016-03-15 00:54:37.026412+00', 16904, 1, 106, '', 'C', 'Danced by gymnasts from Pulsnitz who are not SC-dancers.', 1, 1, 'Y', 'l_CbntLz_qI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1661, '2014-05-06 19:54:22.666166+00', '2016-03-22 20:47:03.143099+00', 14453, 1, 1041, '', 'A', 'Twice through only, once as Strathspey, once as Reel.  The final bars are modified to link to the next dance in the display', 1, 1, 'Y', 'ThRNHJEWG2k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2414, '2016-03-14 23:00:06.377958+00', '2016-03-15 08:01:05.929006+00', 2563, 2, 106, '', 'B', 'Danced by members of the Belfast Branch



', 1, 1, 'Y', 'xUiXgwYlI7c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2415, '2016-03-14 23:05:21.571667+00', '2016-03-15 08:04:21.87817+00', 1804, 1, 106, '', 'B', 'Danced by dancers of the Belfast Branch', 1, 1, 'Y', 'KQRUGT2wcdY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2421, '2016-03-15 16:49:03.036882+00', '2016-03-15 21:30:59.221358+00', 9675, 1, 82, '', 'B', '', 1, 1, 'Y', 'ysO8TDx6akA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1263, '2013-08-18 10:55:40.654842+00', '2016-03-18 15:32:56.481895+00', 10589, 1, 1296, '', 'B', 'From an open air display;  once through.



Note:  bars 3-4 and 11-12 are done incorrectly.  They should dance "Set and Link", normal for the Women and mirrored for the Men.   In the video, the lower couples do not loop into their new places as in "Set and Link", but dance up, hands held, and slip into place the "short way". 

', 1, 1, 'Y', 'OoeqDjOMDTo', 99, 158, NULL);
INSERT INTO 'dancevideo' VALUES (2425, '2016-03-22 11:24:21.88852+00', '2016-03-22 22:17:39.709834+00', 14545, 1, 2824, '', 'C', '', 1, 1, 'Y', '9_dZbE-XseY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2426, '2016-03-23 20:34:47.558159+00', '2016-03-24 00:18:11.793922+00', 1615, 3, 2794, '', 'A', '', 1, 1, 'Y', 'pI5rBLf8Ajg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2427, '2016-03-23 20:36:28.750899+00', '2016-03-24 00:20:11.868329+00', 1615, 4, 2794, '', 'A', 'Different viewing point; 1 time through only.', 1, 1, 'Y', '822Gy2EI9_8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2428, '2016-03-24 17:23:51.025833+00', '2016-03-24 17:24:09.791609+00', 9636, 4, 106, '', 'D', 'Published on 21 Mar 2016



Recorded during the 60th anniversary Ball in Dardagny (near Geneva)', 1, 1, 'Y', '8AU6M6F_VQw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2429, '2016-03-24 17:50:05.75297+00', '2016-03-24 17:51:44.201665+00', 16840, 1, 106, '', 'A', 'Published on 19 Mar 2016  An 88 bar reel performed in a Square Set, devised by Hazel Convery, and danced here by members of RSCDS Belfast Branch. ', 1, 1, 'Y', 'Dr4_enMwi0s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2430, '2016-03-24 17:56:45.03329+00', '2016-03-24 17:57:06.106448+00', 1989, 3, 106, '', 'B', 'Published on 19 Mar 2016   A 32 bar jig Scottish Country Dance, (J4x32) 4C set Tom Izbicki Jean Patrick Collection, danced by members of RSCDS Belfast branch.', 1, 1, 'Y', 's6TPiS5QO2M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2431, '2016-03-24 18:00:55.592557+00', '2016-03-24 18:01:19.072156+00', 5860, 8, 106, '', 'B', 'Published on 19 Mar 2016  This is a reel for 3 couples in a 4 couple set (R8x32) 3C (4C set) Roy Goldring RSCDS Leaflet Dances 28. It features representations of the Saltire, the cross on the flag of St Andrew. Danced here by members of RSCDS Belfast branch.', 1, 1, 'Y', 'bw6yjQP2PQQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2432, '2016-03-27 01:13:45.999782+00', '2016-03-27 01:15:34.14286+00', 358, 4, 106, '', 'D', '', 1, 1, 'Y', 'uwzDOvpQArg', 228, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2433, '2016-03-27 01:19:10.948205+00', '2016-03-27 01:19:24.726343+00', 358, 5, 106, '', 'C', 'Houston Branch of the Royal Scottish Country Dance Society "Go Texan" Dance at Kennie Hall, in Kennie Texas.March 2, 2013', 1, 1, 'Y', 'nZki4Gvv07U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3548, '2018-06-03 15:05:11.176112+00', '2018-06-03 15:05:24.02218+00', 18371, 1, 202, '', 'A', '', 1, 1, 'Y', 'A0ze-IYbwMM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2436, '2016-03-28 15:47:56.25377+00', '2016-03-28 17:44:48.413859+00', 5204, 1, 2213, '', 'B', '', 1, 1, 'Y', 'GBCgFCLBFJI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2784, '2017-01-13 14:16:15.012235+00', '2017-01-16 22:23:38.651993+00', 13497, 1, 2824, '', 'C', '', 1, 1, 'Y', 'InU0CiUymIA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2437, '2016-03-29 19:37:55.176363+00', '2016-03-29 19:48:53.90021+00', 16623, 1, 106, '', 'B', 'Performed at the Kuckucksnest in Schlüchtern, Germany in spring 2014. In the video the dancers do an extra twirl in the solo for the first couple, which is not in the dance description. Occasionally, some dancers appear a little hesitant. ', 1, 1, 'Y', 'aao6JRKFuxA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2438, '2016-04-01 06:09:18.562312+00', '2016-04-02 19:17:09.309451+00', 6051, 1, 1178, '', 'C', '', 1, 1, 'Y', 'x2ksIuVxNiU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2442, '2016-04-04 02:08:41.685468+00', '2016-04-05 01:57:12.372311+00', 413, 7, 2929, '', 'Z', 'Incomplete: once through only, and starting at about bar 12.  Not suited for SCDDB.



Performed at a ceilidh with many brand new dancers in attendance.', 1, 1, 'Y', 'BdCfaCTY24k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2475, '2016-05-03 19:18:05.546251+00', '2016-05-03 19:21:53.328502+00', 9164, 1, 160, '', 'B', 'The music is Miss Gibson''s Strathspey by Donaldson, Gaddis, et. al. from the CD "Memories of Scottish Weekend"  (SW01).



During the 3rd round of the dance the reel goes south in a serious way (at 2:44 in). The dancers regroup at the end of the phrase and continue without any other major errors.', 1, 1, 'Y', 'RkYizndZJgk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (921, '2013-04-22 12:21:52.937414+00', '2016-04-06 01:56:17.349135+00', 877, 1, 513, '', 'C', 'Danced at the Rechberg (Germany) Workshop for advanced dancers.  Fiddle: Keith Smith.', 1, 1, 'Y', 'PnHGFZMV_AA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3490, '2018-03-26 10:05:11.133417+00', '2018-03-26 22:05:47.06114+00', 13611, 1, 2287, '', 'B', '', 1, 1, 'Y', 'WXNEAHnqmh4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2463, '2016-04-15 14:10:06.84828+00', '2016-04-17 14:37:07.057674+00', 14741, 2, 954, '', 'C', '', 1, 1, 'Y', 'NlDP6Lt2rNE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2445, '2016-04-04 10:55:31.660189+00', '2016-04-11 07:57:23.962103+00', 15224, 1, 2821, '', 'C', 'Danced at The Sunday Class on 13 March 2016.  www.thesundayclass.org.uk', 1, 1, 'Y', 'UWV5OXZSef8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2444, '2016-04-04 10:47:29.594919+00', '2016-04-11 08:03:12.309289+00', 15222, 1, 2821, '', 'B', '', 1, 1, 'Y', 'RaOnWCs3qoY', 40, 131, NULL);
INSERT INTO 'dancevideo' VALUES (3489, '2018-03-26 10:02:59.680516+00', '2018-03-26 22:09:28.874067+00', 13273, 1, 2287, '', 'B', '', 1, 1, 'Y', 'Va7MrSNaCdk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2440, '2016-04-03 21:28:42.65586+00', '2016-04-11 22:42:02.065369+00', 976, 1, 1751, '', 'A', '', 1, 1, 'Y', 'xcffzaXHImM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2553, '2016-07-03 12:37:02.820036+00', '2016-07-03 15:08:02.201322+00', 5007, 1, 513, '', 'C', '', 1, 1, 'Y', 'Ti2WNQhR_o8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2459, '2016-04-11 13:32:48.779967+00', '2016-04-11 22:44:51.281496+00', 11806, 1, 513, '', 'A', 'A few bar are missing at the beginning, as I didn''t manage to get to my camera early enough! :-)', 1, 1, 'Y', 'hiuKPhaJHvI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2441, '2016-04-04 02:06:43.452035+00', '2016-04-11 23:02:34.934134+00', 8042, 1, 2929, '', 'D', 'Ceilidh Madness being danced at the Seattle U District Ceilidh on April 2, 2016



First time through starts around bar 10, second time through is complete. ', 1, 1, 'Y', 'wYPks1CPuSA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2443, '2016-04-04 02:10:30.01722+00', '2016-04-11 23:11:13.372661+00', 8040, 1, 2929, '', 'D', 'Modified to be a 40-bar jig to allow 8 bars for the slipping and 8 for the weaving.  Performed in a ceilidh setting with many non-dancers in attendance, so we needed additional time.', 1, 1, 'Y', 'O1k0LTntVc0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2461, '2016-04-14 22:01:03.725719+00', '2016-04-15 15:40:24.518667+00', 1060, 2, 954, '', 'A', 'Excellent tutorial video', 1, 1, 'Y', 'ictGLXdd27Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2462, '2016-04-14 22:14:16.783203+00', '2016-04-15 15:44:02.899516+00', 816, 2, 954, '', 'D', '', 1, 1, 'Y', '51UkYKJmu_8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2852, '2017-02-12 18:43:47.996703+00', '2017-02-13 17:04:55.784818+00', 301, 3, 2084, '', 'A', '', 1, 1, 'Y', 'Kez6-6GF7PQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2476, '2016-05-03 19:55:02.441721+00', '2016-05-03 19:55:37.363715+00', 2263, 2, 160, '', 'B', 'The music used is from Marian Anderson''s CD "Diamond Jubilee Dances (RSCDS Belfast Branch)", set of Jigs, lead tune "Famous Baravan". 



The correct tune is "Captain White" but we have no suitable recording.', 1, 1, 'Y', '5BLGyHY9mlQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2468, '2016-04-24 14:50:44.497964+00', '2016-04-24 15:55:41.938727+00', 7311, 2, 274, '', 'B', 'First man devised this dance ;-)

Budapest, 2016', 1, 1, 'Y', '1kpCgKMW3v4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2471, '2016-04-25 10:39:48.288478+00', '2016-04-26 08:59:35.546289+00', 10795, 1, 513, '', 'D', '', 1, 1, 'Y', 'MV-Qkn0KGVE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2470, '2016-04-25 09:11:53.878829+00', '2016-04-26 09:01:45.192284+00', 2423, 1, 513, '', 'C', '', 1, 1, 'Y', '35cE2EGaXWE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2472, '2016-04-28 07:11:39.848469+00', '2016-04-29 21:21:26.086173+00', 873, 1, 274, '', 'C', 'Stops just short of twice though.  Whole set not shown, the formationas are not fully clear without seeing the crib too.', 1, 1, 'Y', 'nUOrIWBxzNM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2479, '2016-05-07 19:14:36.389372+00', '2016-05-07 19:15:12.614115+00', 5040, 3, 106, '', 'A', 'RSCDS London Branch Picnic Dance- Polesden Lacey 08/06/1996.



This is part of a display, the ending of the second time through has been modified.', 1, 1, 'Y', 'jO1m6dlixoE', 26, 97, NULL);
INSERT INTO 'dancevideo' VALUES (2477, '2016-05-06 06:48:52.820896+00', '2016-05-06 06:49:44.346786+00', 13629, 3, 106, '', 'D', 'Recorded during the Brussels SCD dayschool 2016', 1, 1, 'Y', 'yy7mnjzwi_c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2480, '2016-05-07 20:20:52.633139+00', '2016-05-08 10:35:55.640784+00', 6448, 1, 106, '', 'A', 'RSCDS London Branch Picnic Dance- Polesden Lacey 08/06/1996



Final part of a display.  In this demo 1c turns RH on bars [7-8], the instructions say LH.



The final bars of second time through have been modified for the display.', 1, 1, 'Y', 'jO1m6dlixoE', 219, 330, NULL);
INSERT INTO 'dancevideo' VALUES (2478, '2016-05-07 16:19:35.407209+00', '2016-05-07 19:46:46.790714+00', 5473, 1, 106, '', 'A', 'RSCDS London Branch Picnic Dance- Polesden Lacey 08/06/1996.



This is part of a display; the end of the second time through has been modified.', 1, 1, 'Y', 'jO1m6dlixoE', 97, 220, NULL);
INSERT INTO 'dancevideo' VALUES (2481, '2016-05-08 09:16:38.585964+00', '2016-05-08 10:43:34.244712+00', 9088, 1, 2821, '', 'B', 'The Saltire Medley (48S/48R)

Performed by the Waltham Scottish Country Dance Group on 07 May 2016 at the ASCDS Festival, Nottingham

https://youtu.be/NyvV_-FNPV8 

', 1, 1, 'Y', 'NyvV_-FNPV8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2482, '2016-05-08 22:03:09.665931+00', '2016-05-08 22:06:57.561572+00', 5964, 3, 106, '', 'A', 'Adapted from the original description for a better choreography in this display', 1, 1, 'Y', 'IhJfrIxjUsc', 60, 133, NULL);
INSERT INTO 'dancevideo' VALUES (794, '2012-12-30 22:58:00.003285+00', '2016-05-13 15:51:20.245277+00', 14633, 1, 106, '', 'B', '100 Jahre Frohnau

"The Berlin Hopalots", Scottish Country Dancing

20. Juni 2010 Ludolfingerplatz

Uraufführung des Tanzes', 1, 1, 'Y', 'w4UimyKzFcc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2483, '2016-05-14 07:13:00.972945+00', '2016-05-14 07:13:40.542089+00', 7353, 1, 106, '', 'C', 'Fanwood, New Jersey, 2013', 1, 1, 'V', '76821456', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2485, '2016-05-20 22:38:49.962499+00', '2016-05-20 22:39:19.772577+00', 13581, 6, 106, '', 'C', 'Danced at the Ngaio SCD Club''s annual dance in the Ngaio town hall, Wellington, New Zealand on May 14 2016.', 1, 1, 'Y', 'j804T44njXM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2486, '2016-05-20 23:18:15.265753+00', '2016-05-20 23:18:43.250361+00', 4484, 7, 106, '', 'C', 'Danced at the Ngaio SCD Club''s annual dance for 2016, in the Ngaio town hall. The MC was club tutor Melva Waite, and live music provided by Peter Elmes, Aileen Logie and Don McKay.', 1, 1, 'Y', 'kg93hkmN8e8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2487, '2016-05-22 22:06:07.254679+00', '2016-05-22 22:06:22.072755+00', 7230, 1, 106, '', 'D', 'More walking than dancing', 1, 1, 'V', '124376806', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3491, '2018-03-26 11:36:53.197909+00', '2018-03-26 22:02:54.880861+00', 18262, 1, 942, '', 'B', '', 1, 1, 'Y', 'FIp-5cJFOIA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2511, '2016-06-03 12:21:20.190372+00', '2016-06-04 21:45:03.415692+00', 3691, 1, 1041, '', 'B', 'Instruction video', 1, 1, 'Y', 'uhUImMbxMnY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2493, '2016-05-23 22:28:37.924374+00', '2016-05-23 23:09:13.475502+00', 15644, 1, 2697, '', 'D', 'Dancing on Rybinsk (Fishburg) railway station, all of a sudden.  Kudos to "Shiehallion" and "Trip to Skye" dancing schools, all from Saint-Petersburg.  Video shot on our way back from Spring Scottish School. Published on 20 May 2016.', 1, 1, 'Y', '7Dqr_IoO3_M', 47, 190, NULL);
INSERT INTO 'dancevideo' VALUES (2490, '2016-05-22 22:31:41.649694+00', '2016-05-24 12:31:35.396596+00', 7135, 1, 106, '', 'A', 'Final part of a display.  RSCDS London Branch Ball- Battersea 2502/1995', 1, 1, 'Y', '7poKsWw9N7g', 277, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2488, '2016-05-22 22:14:04.275955+00', '2016-05-24 12:31:56.399299+00', 3783, 1, 106, '', 'A', 'First part of a display; final bars modified.  RSCDS London Branch Ball- Battersea 2502/1995', 1, 1, 'Y', '7poKsWw9N7g', 44, 150, NULL);
INSERT INTO 'dancevideo' VALUES (2495, '2016-05-24 13:17:06.774615+00', '2016-05-24 13:17:18.867353+00', 8094, 1, 106, '', 'B', 'Youth Weekend West is held annually on the West coast of North America.    2016 Ball ', 1, 1, 'Y', 'r7kL8bzeGwY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2496, '2016-05-25 19:15:03.160891+00', '2016-05-25 21:12:45.057691+00', 5982, 5, 2847, '', 'A', '', 1, 1, 'Y', 'BuF7xFU95ks', 25, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2501, '2016-05-25 19:30:47.087221+00', '2016-05-25 21:50:17.623282+00', 3759, 6, 2847, '', 'A', '', 1, 1, 'Y', 'rdZS68HFnS0', 25, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2499, '2016-05-25 19:25:00.454691+00', '2016-05-25 21:52:44.435598+00', 3834, 6, 2847, '', 'A', '', 1, 1, 'Y', 'K935EsHyQtM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2502, '2016-05-25 19:32:42.41147+00', '2016-05-25 21:55:27.166755+00', 2777, 2, 2847, '', 'A', '', 1, 1, 'Y', 'RSbKvVN1Ot0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2498, '2016-05-25 19:23:02.216198+00', '2016-05-25 21:57:57.935448+00', 2645, 1, 2847, '', 'A', '', 1, 1, 'Y', 'yHSEVjgzyZY', 25, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2500, '2016-05-25 19:28:00.580611+00', '2016-05-25 22:00:52.832826+00', 11372, 2, 2847, '', 'A', '', 1, 1, 'Y', 'RjKkYXASywM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2497, '2016-05-25 19:19:27.347912+00', '2016-05-25 22:03:25.487673+00', 3986, 3, 2847, '', 'A', '', 1, 1, 'Y', 'z1Mvwmluh_4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2503, '2016-05-26 15:46:41.22987+00', '2016-05-26 22:02:42.315099+00', 3577, 2, 2824, '', 'B', 'Once through. First two bars missing.', 1, 1, 'Y', 'klM-bsZrqfY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2504, '2016-05-29 21:46:15.323277+00', '2016-05-29 22:03:16.679816+00', 14025, 1, 1041, '', 'B', '1 time through', 1, 1, 'Y', 'k5e5hFLI9s8', 0, 35, NULL);
INSERT INTO 'dancevideo' VALUES (2505, '2016-06-02 23:32:24.575337+00', '2016-06-03 09:48:22.893061+00', 77, 1, 2794, '', 'B', '', 1, 1, 'Y', 'wqDZ9qX8s7w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2465, '2016-04-17 21:08:11.216978+00', '2019-10-11 00:55:54.386198+00', 10832, 1, 2954, '', 'B', 'As danced at the Ottawa Branch 50th Anniversary Ball 2016.', 1, 1, 'Y', '9E0MzxMPwm4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2512, '2016-06-03 12:23:41.79051+00', '2016-06-04 21:47:18.581603+00', 7420, 3, 1041, '', 'B', 'Instruction video', 1, 1, 'Y', 'CYvXa5PlrXU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2510, '2016-06-03 12:18:49.003311+00', '2016-06-04 21:50:33.736533+00', 2110, 3, 1041, '', 'B', 'Instruction video, slow motion', 1, 1, 'Y', '0-amUBWWPXc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2509, '2016-06-03 12:11:17.72327+00', '2016-06-04 21:52:52.345032+00', 13593, 1, 1041, '', 'B', 'Instruction video', 1, 1, 'Y', 'TsToyBTwFHQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2508, '2016-06-03 10:15:10.388606+00', '2016-06-03 10:15:30.484281+00', 2228, 2, 106, '', 'A', 'Part of a longer display.  Some of the video only shows part of the set.', 1, 1, 'Y', 'iGpUQj6ucAA', 196, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2513, '2016-06-04 16:56:23.240792+00', '2016-06-04 21:57:48.215557+00', 1280, 6, 2070, '', 'A', 'First bar missing; second time through complete.', 1, 1, 'Y', '_4N_sI_SLBg', 0, 73, NULL);
INSERT INTO 'dancevideo' VALUES (2506, '2016-06-02 23:38:46.156255+00', '2016-06-03 10:19:55.911732+00', 2354, 1, 2794, '', 'A', 'Part of a longer display.  For large parts of the dance the video only shows part of the set.', 1, 1, 'Y', 'iGpUQj6ucAA', 71, 195, NULL);
INSERT INTO 'dancevideo' VALUES (2551, '2016-07-02 17:00:15.168042+00', '2016-07-03 19:02:42.954689+00', 17121, 1, 106, '', 'A', 'RSCDS York and North Humberside branch 40th anniversary ball, November 2015', 1, 1, 'Y', 'sFPyhtWzcAQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (989, '2013-08-16 20:24:15.283419+00', '2016-06-07 08:04:28.594573+00', 4662, 1, 1041, '', 'Z', 'Systematic deviation from the instructions. 



1c omits the second Inveran crossing to finish on opposite side; the instructions say to make a full Inveran Reel and 1c cross at the end



At bar 16 1st couple ends on the sideline at the bottom, and then sets to 3c up/down. They should end back to back between 3rd couple and set across.



At bar 24 in the video 1st couple ends on the sideline at the top, and then sets to 2c up/down.

They should end back to back between 2ndcouple.

But apart from that is a very good and clear video.', 1, 1, 'Y', 'ZAVYpdbH-VA', 22, 316, NULL);
INSERT INTO 'dancevideo' VALUES (2514, '2016-06-06 21:25:28.587464+00', '2016-06-07 08:11:12.837509+00', 4324, 1, 1041, '', 'A', '', 1, 1, 'Y', 'jWnjIWUm_3g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2529, '2016-06-07 12:04:50.109088+00', '2016-06-07 12:05:45.2367+00', 11772, 4, 106, '', 'A', 'Moscow School of SCD ', 1, 1, 'Y', 'gejPHsE7erI', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2609, '2016-08-13 20:01:44.168775+00', '2016-08-13 20:12:34.695977+00', 16903, 1, 106, '', 'B', 'By the Hong Kong group.', 1, 1, 'Y', 'UX90JgDxiHA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2515, '2016-06-06 21:32:12.608064+00', '2016-06-07 08:22:53.671053+00', 13483, 1, 1041, '', 'C', 'Class situation, instead of staying with ne set, the video sometimes pans around the class and shows close-ups, making it difficult to follow the dance unless you know it already.', 1, 1, 'Y', 'zGEe0OcONu8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2516, '2016-06-07 08:31:00.275394+00', '2016-06-07 08:34:40.017404+00', 4830, 1, 106, '', 'A', 'Moscow School of SCD.', 1, 1, 'Y', 'D5QNKhYwfkk', 45, 278, NULL);
INSERT INTO 'dancevideo' VALUES (2517, '2016-06-07 08:41:29.195358+00', '2016-06-07 08:43:31.731116+00', 4103, 1, 106, '', 'A', 'Moscow School of SCD', 1, 1, 'Y', 'D5QNKhYwfkk', 306, 428, NULL);
INSERT INTO 'dancevideo' VALUES (3520, '2018-04-19 10:23:41.465521+00', '2018-04-19 20:35:59.936058+00', 1465, 1, 2586, '', 'D', 'Quite difficult to make out the formations with the cramped space in the hall.', 1, 1, 'Y', 'yDxHQYE7_9Q', 180, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2525, '2016-06-07 11:56:29.789414+00', '2016-06-07 13:26:42.114937+00', 7204, 5, 1041, '', 'B', 'Instruction Video', 1, 1, 'Y', 'HMOC8lF_qdM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2523, '2016-06-07 11:48:46.715015+00', '2016-06-07 13:28:11.023297+00', 7282, 4, 1041, '', 'B', 'Instruction Video', 1, 1, 'Y', 'SH0VkNcStSs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2522, '2016-06-07 11:43:49.636555+00', '2016-06-07 13:36:28.888377+00', 7475, 1, 1041, '', 'B', 'Instruction Video', 1, 1, 'Y', 'QVx_0kWpVw4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2533, '2016-06-07 12:32:33.769933+00', '2016-06-07 13:38:18.217338+00', 5436, 1, 1041, '', 'B', '', 1, 1, 'Y', 'dRWkOe-bCco', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2526, '2016-06-07 11:59:21.338899+00', '2016-06-07 13:39:34.628723+00', 9770, 3, 1041, '', 'B', 'Instruction Video', 1, 1, 'Y', 'eWB9DrUvqas', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2524, '2016-06-07 11:55:00.290911+00', '2016-06-07 13:43:38.103344+00', 3365, 6, 1041, '', 'B', 'Instruction Video', 1, 1, 'Y', 'ph1Gby1ecCM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2521, '2016-06-07 11:40:40.470987+00', '2016-06-07 13:57:46.369425+00', 1884, 3, 1041, '', 'B', 'Instruction Video', 1, 1, 'Y', 'FbB_1Fnycu0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2531, '2016-06-07 12:24:24.3687+00', '2016-06-07 14:00:34.58103+00', 2723, 1, 1041, '', 'C', '', 1, 1, 'Y', 'UeJ7_MssBI4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2519, '2016-06-07 11:30:56.396655+00', '2016-06-07 13:48:56.295504+00', 3165, 1, 1041, '', 'D', 'First four bars missing.  Last time through incomplete.', 1, 1, 'Y', 'xpGSXaIrD6A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2527, '2016-06-07 12:02:27.128371+00', '2016-06-07 13:50:22.048466+00', 12428, 4, 1041, '', 'B', 'Instruction Video', 1, 1, 'Y', '31iSi6J4egE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2520, '2016-06-07 11:38:30.02216+00', '2016-06-07 13:53:20.53518+00', 3057, 6, 1041, '', 'B', 'Instruction Video', 1, 1, 'Y', 'EnvU87vkrPQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2532, '2016-06-07 12:30:04.633708+00', '2016-06-07 13:55:21.658376+00', 16842, 2, 1041, '', 'B', '', 1, 1, 'Y', 'b8WtQRc72Kw', 0, 132, NULL);
INSERT INTO 'dancevideo' VALUES (2535, '2016-06-08 10:54:40.141222+00', '2016-06-08 11:02:31.258642+00', 16469, 1, 1330, '', 'B', 'The video shows the 4c version of the dance, authorised by the deviser (who is dancing in the video). The 4th couple do everything except the allemande.  The music was also chosen by the deviser (an edited version of a track by MARIAN ANDERSON''S SCOTTISH DANCE BAND)', 1, 1, 'Y', 'OFxMemYi_Qg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2534, '2016-06-07 12:35:40.74479+00', '2016-06-07 15:19:24.454499+00', 3520, 1, 1041, '', 'B', 'recorded during the Munich Whitsun 2016', 1, 1, 'Y', '84SeUbWuJNk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2536, '2016-06-08 11:08:03.391499+00', '2016-06-08 11:13:47.234259+00', 16469, 2, 1330, '', 'D', 'This video shows the published (3c) version of Early Spring danced at a social event. The music was live and the pianist chose a strathspey set composed by Dave Wiesler for the dance, "The Silver Thistle Ball", kindly provided by the composer.', 1, 1, 'Y', 'KeORGR8kDSM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3549, '2018-06-03 15:07:59.825159+00', '2018-06-03 15:08:20.198468+00', 2428, 7, 202, '', 'A', '', 1, 1, 'Y', 'uxlHy2fwkMg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3550, '2018-06-03 15:21:43.124107+00', '2018-06-03 15:22:34.059781+00', 18363, 1, 202, '', 'A', '', 1, 1, 'Y', 'RYC_UyjnmNQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3561, '2018-06-06 14:15:16.080095+00', '2018-06-06 14:36:35.49002+00', 3397, 4, 2824, '', 'A', '4 times through.

Newcastle Festival 2018, Lyon RSCDS team', 1, 1, 'Y', 'QCN63HQJgm0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2507, '2016-06-03 10:04:55.568336+00', '2019-01-02 18:25:55.120891+00', 445, 9, 106, '', 'B', 'Part of a longer display.  Some of the video only shows part of the set.', 1, 1, 'Y', 'iGpUQj6ucAA', 0, 71, NULL);
INSERT INTO 'dancevideo' VALUES (2315, '2016-01-21 11:54:56.214094+00', '2016-06-09 20:50:06.100138+00', 1782, 5, 106, '', 'Z', 'The SCD Group Hong Kong published this new video, but mistakenly titled it "The Fireside Reel".



Comment received on 2016-06-07:  This version is incorrectly danced. 1) After the advance and retire, then two hands round with your partner, the 1st couple should cast off and touch hands between the 2s in the centre of the dance, then cast up from below the 3s, meet in the centre after casting in between the 2s, and cast off at the top of the dance to 2nd place. 2) The 1st couple should turn 1st corner and then PARTNER and not go straight to 2nd corner. For these reasons, I don''t consider this is a "good" version, at best it''s "Social/Informal" and it is misleading.



True.  Quality set to "block", in agreement with Anselm''s suggestion.', 1, 1, 'Y', '0E2W1db41NI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2537, '2016-06-09 22:13:52.372963+00', '2016-06-09 23:04:00.26728+00', 89, 2, 954, '', 'A', 'Precise and elegant dancing.  Once through only.', 1, 1, 'Y', 'HCHuTmfghjQ', 0, 64, NULL);
INSERT INTO 'dancevideo' VALUES (2538, '2016-06-10 22:29:07.09354+00', '2016-06-10 22:44:43.168809+00', 9563, 1, 954, '', 'A', '', 1, 1, 'Y', 'qlf249M467k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2539, '2016-06-11 17:42:05.544888+00', '2016-06-11 20:47:47.131847+00', 17022, 1, 1645, '', 'D', 'Volunteers testing the dance: the schiehallion reels suffered a bit from phrasing and lack of space, but the first part of the dance is fairly clear with few errors.', 1, 1, 'Y', 'Hw2fJJ5mKVQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2541, '2016-06-13 20:29:54.517998+00', '2016-06-13 20:30:06.967546+00', 8709, 1, 106, '', 'A', 'A Chiswick Scottish instructional video, june 2016', 1, 1, 'Y', 'W6LNwJxiYxM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2543, '2016-06-27 12:47:02.260152+00', '2016-06-27 12:59:32.106734+00', 10842, 1, 106, '', 'D', 'Recorded on the 30.06.2012 during the Summer Ball in Sterbfritz/Germany.  Music by George Meikle and members of the Musicians Workshop at the Summer Course at the "Kuckucksnest".', 1, 1, 'Y', '4-NX9Q_-LXg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2544, '2016-06-27 14:03:35.153766+00', '2016-06-27 14:03:50.064107+00', 13128, 1, 106, '', 'D', 'Recorded on the 14.04.2012 at the SCD Ball during the "Celtic-Days" in Hude/Germany.  http://www.celticdays.de/', 1, 1, 'Y', 'vO4mwK8hJUU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2545, '2016-06-27 15:26:06.906023+00', '2016-06-27 15:26:28.209104+00', 16198, 1, 106, '', 'D', 'Recorded on the 14.04.2012 at the SCD Ball during the "Celtic-Days" in Hude/Germany.

http://www.celticdays.de/', 1, 1, 'Y', 'msO823ZgYUA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2546, '2016-06-30 13:29:26.917454+00', '2016-06-30 13:29:43.871315+00', 12795, 1, 106, '', 'C', 'SCDGroup Hk.   Published on 26 Jun 2016.   Japan Dancing Camp 2016.', 1, 1, 'Y', 'LnSsd71sP6U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2549, '2016-06-30 13:40:14.935382+00', '2016-06-30 13:40:44.540457+00', 14977, 4, 106, '', 'C', 'SCDGroup Hk    Published on 25 Jun 2016', 1, 1, 'Y', 'sBp8L5MyI4U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2550, '2016-06-30 21:28:09.207245+00', '2016-06-30 21:28:29.534138+00', 1786, 4, 106, '', 'C', 'Linden SCD Club, 2016', 1, 1, 'Y', 'sWjM0Ebe1yE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2558, '2016-07-06 13:43:20.291773+00', '2016-07-06 14:12:17.613382+00', 8709, 2, 3016, '', 'B', 'A Scottish Country Dance performed by the Oxford University Scottish Dance Society. From RSCDS Book 24.

 

Music: "The Campbells are Coming" from the RSCDS CD for Book 24

A Quickstep by the Duke of Gordon (R. Petrie)

Miss Russell of Blackhall’s Reel (R. Mackintosh)

Miss Nancy Dick’s Favourite (R. Mackintosh)

The Campbells are coming (trad.)

Performed by Muriel Johnstone and her Dance Band', 1, 1, 'Y', '0A17TMXsgAc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2552, '2016-07-02 17:01:43.289131+00', '2016-07-02 20:47:26.807827+00', 17121, 2, 106, '', 'B', 'Recording taken at York & North Humberside Branch''s 40th Anniversary Ball, nov. 2015', 1, 1, 'Y', 'bpEUoPusGqE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2554, '2016-07-03 12:39:51.874152+00', '2016-07-03 15:02:56.206913+00', 8729, 1, 513, '', 'C', '', 1, 1, 'Y', 'mtigq1UsLMI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2611, '2016-08-20 20:24:11.505368+00', '2018-10-02 14:20:39.577764+00', 7375, 1, 106, '', 'X', '', 1, 1, 'Y', '673cD8xCjmc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2583, '2016-08-07 17:51:02.866625+00', '2019-01-03 23:50:44.219545+00', 16827, 1, 784, '', 'A', '', 1, 1, 'Y', 'WjzbU_ov8eQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2610, '2016-08-13 20:08:04.86254+00', '2016-08-20 23:49:18.851423+00', 16903, 2, 106, '', 'D', 'Dufftown Dance Club - 24/7/15

Music by Graeme Mitchell and his band



Most of the dancers are walking the dance; many errors.', 1, 1, 'Y', 'il-hZVBH7c0', 233, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2557, '2016-07-06 13:42:34.511743+00', '2016-07-06 14:55:42.565443+00', 5451, 1, 3016, '', 'B', 'A Scottish Country Dance performed by the Oxford University Scottish Dance Society. Dance from RSCDS Oxfordshire Branch - The Oxford Silver Jubilee Book of Dances (1993) and Oxford Connections. Dance devised by Todd Pierce. 



Music: "Radcliffe Square" from the Oxford Connections CD

Millbank Cottage (W. D. Dumbreck)

Barney''s Balmoral (E. MacDonald)

Performed by The Craigellachie Band', 1, 1, 'Y', '2ObSt60em2Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2559, '2016-07-06 13:44:18.381704+00', '2016-07-06 15:17:14.65022+00', 14723, 1, 3016, '', 'B', 'A Scottish Country Dance performed by the Oxford University Scottish Dance Society. From Oxford Connections. Dance devised by Pat Davoll.



Music: "Lamp Black Lizzy" from the Oxford Connections CD.

Lamp Black Lizzie (I. Muir)

Balcomie House (trad.)

Dumfries House (trad.)

G B Bell''s Fancy (George Bell)

Performed by The Craigellachie Band', 1, 1, 'Y', 'Y_RsTgWSWOo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2556, '2016-07-04 23:22:09.211612+00', '2016-07-06 15:20:09.259793+00', 17122, 1, 2273, '', 'A', 'The dance was demonstrated at the special ball of ''Mie SCDF'' in May 2016 to the piano and fiddle played by Hiroko Kokai and Hidenori Omori.', 1, 1, 'Y', '9CcluxqFxdk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2555, '2016-07-03 12:42:38.042023+00', '2016-07-06 15:23:26.747906+00', 3862, 2, 513, '', 'D', '', 1, 1, 'Y', '5GCR6p1Qmpk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3542, '2018-05-26 17:46:32.884658+00', '2018-05-26 18:00:51.445889+00', 16509, 2, 1720, '', 'B', '', 1, 1, 'Y', 'IxZjxPmErT0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2565, '2016-07-14 12:46:19.347607+00', '2016-07-14 17:14:03.446534+00', 15098, 2, 3019, '', 'A', '', 1, 1, 'Y', '_J4E12jsiAc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2561, '2016-07-10 19:32:51.566959+00', '2016-07-10 22:20:38.503999+00', 14386, 1, 513, '', 'Z', '[We were specifically asked not to post photographs or video on social media because various people at the party didn''t want to show up there. I don''t know particularly who objected but I''m blocking the video just to be safe. It''s a pity because it is a good video and my own dance to boot, but there we are; this is not up for discussion. –Anselm]', 1, 1, 'Y', '5OtaO9gyebs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2562, '2016-07-10 19:39:56.20317+00', '2016-07-10 22:24:52.409663+00', 17135, 1, 513, '', 'Z', '[We were specifically asked not to post photographs or video on social media because various people at the party didn''t want to show up there. I don''t know particularly who objected but I''m blocking the video just to be safe, even though it shows mostly the six people performing the dance – there''s a big panoramic sweep at the end that contains various other attendees. It''s a pity because it is a good video and a very nice dance, but there we are; this is not up for discussion. –Anselm]', 1, 1, 'Y', '8ecMwJuFSMM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3551, '2018-06-03 15:25:04.419282+00', '2018-06-03 15:25:17.49279+00', 18370, 1, 202, '', 'A', '', 1, 1, 'Y', '03qbjtnltoc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2566, '2016-07-14 12:51:51.367833+00', '2016-07-16 16:33:41.298159+00', 9107, 6, 3019, '', 'A', 'First part of the Demonstration at the Street Party held by RSCDS London Branch in celebration of HM The Queen''s 90th Birthday.



Twice through only.  Danced in two three-couple sets joined top to top.  ', 1, 1, 'Y', 'xK3N8OCzNw4', 0, 78, NULL);
INSERT INTO 'dancevideo' VALUES (2567, '2016-07-14 12:56:06.403909+00', '2016-07-16 16:24:25.211346+00', 373, 3, 3019, '', 'A', 'Part of the Demonstration at the Street Party held by RSCDS London Branch in celebration of HM The Queen''s 90th Birthday.



Once through only.  Danced in two three-couple sets joined top to top.  Dance adapted to this 6C set by replacing the reels of 4 by reels of 3, and other changes.', 1, 1, 'Y', 'xK3N8OCzNw4', 78, 141, NULL);
INSERT INTO 'dancevideo' VALUES (2568, '2016-07-14 12:58:37.68881+00', '2016-07-16 16:24:01.484442+00', 1782, 6, 3019, '', 'A', 'Final part of the Demonstration at the Street Party held by RSCDS London Branch in celebration of HM The Queen''s 90th Birthday.



Twice through only.  Danced in two three-couple sets joined top to top.  Final big circle in danced as a full 6C set.', 1, 1, 'Y', 'xK3N8OCzNw4', 141, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2569, '2016-07-23 14:32:46.424092+00', '2016-08-01 22:17:09.393722+00', 17135, 2, 1506, '', 'B', '', 1, 1, 'Y', '8ecMwJuFSMM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3487, '2018-03-26 09:55:15.441815+00', '2018-03-26 23:38:33.830793+00', 13604, 2, 2287, '', 'B', 'The devisor, Jeff Middleton, wrote the dance so that the 1st lady changes on to the left foot on bar 13 and does not change back until the end of the pousette.', 1, 1, 'Y', 'vcsHMPcIZ0o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2605, '2016-08-10 11:03:12.130925+00', '2016-08-10 11:04:02.659054+00', 159, 7, 106, '', 'A', '', 1, 1, 'Y', 'DcJkGOPmZLI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2584, '2016-08-10 09:56:29.922189+00', '2017-09-29 22:37:33.468905+00', 1615, 6, 106, '', 'A', 'Mixed Open Alba SCD Kelvin (Glasgow).  Filmed by Vladimir Garbuzov', 1, 1, 'Y', 'QgMt-KafYEM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2576, '2016-07-30 12:13:24.726024+00', '2016-07-30 21:14:36.815582+00', 17138, 1, 513, '', 'A', 'RSCDS Summer School 2016 week 2 demonstration', 1, 1, 'Y', 'LdUFPtaAbS8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2575, '2016-07-30 12:06:16.751892+00', '2016-07-30 21:18:23.228053+00', 17140, 1, 513, '', 'A', 'RSCDS Summer School 2016 week 2 demonstration', 1, 1, 'Y', 'Z0HvKwMy2ss', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2577, '2016-07-30 21:21:55.538165+00', '2016-07-30 21:22:34.253473+00', 17138, 2, 342, '', 'A', '', 1, 1, 'Y', 'pKr0S1DouFk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2616, '2016-08-24 07:45:41.40989+00', '2016-08-24 21:07:05.385545+00', 1647, 5, 2824, '', 'D', '', 1, 1, 'Y', 'ksMEZU6OS0A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2570, '2016-07-24 15:53:50.911692+00', '2016-08-01 22:07:41.069469+00', 17144, 1, 513, '', 'A', 'RSCDS Summer School 2016 - week 1 - Demonstration Team', 1, 1, 'Y', 'hFstIA4yXyI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2573, '2016-07-26 11:05:03.494712+00', '2016-08-01 22:08:45.113439+00', 17144, 2, 1056, '', 'A', '', 1, 1, 'Y', 'TNAcMUBs_P4', 219, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2581, '2016-08-01 20:41:03.944067+00', '2016-08-01 22:11:11.695118+00', 17138, 3, 2213, '', 'A', '', 1, 1, 'Y', 'ww9gxKsoKiE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2571, '2016-07-24 15:56:18.326618+00', '2016-08-01 22:13:27.851321+00', 17134, 1, 513, '', 'A', 'RSCDS Summer School 2016 - week 1 - Demonstation Team', 1, 1, 'Y', 'UqhVm1_M29w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2572, '2016-07-26 11:03:37.403921+00', '2016-08-01 22:14:28.085248+00', 17134, 2, 1056, '', 'A', '', 1, 1, 'Y', 'TNAcMUBs_P4', 0, 215, NULL);
INSERT INTO 'dancevideo' VALUES (2578, '2016-07-30 21:24:57.077626+00', '2016-08-01 22:19:22.61892+00', 6037, 4, 342, '', 'A', '', 1, 1, 'Y', '5GOP5qIK7TU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2582, '2016-08-07 16:04:35.767909+00', '2016-08-07 22:49:41.322926+00', 17140, 2, 2213, '', 'A', '', 1, 1, 'Y', 'gXmD7V6KT-I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3553, '2018-06-05 13:19:48.189158+00', '2018-06-05 14:44:43.717994+00', 1280, 10, 2824, '', 'A', 'Twice through.', 1, 1, 'Y', 'mrogFhxfaeE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2585, '2016-08-10 10:05:48.744435+00', '2016-08-10 10:07:16.905541+00', 4857, 4, 106, '', 'A', '', 1, 1, 'Y', 'CYC2xVkJ-SY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2586, '2016-08-10 10:08:51.831479+00', '2016-08-10 10:09:34.555152+00', 5860, 9, 106, '', 'A', '', 1, 1, 'Y', 'TYXk4cxdRys', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2587, '2016-08-10 10:12:34.359247+00', '2016-08-10 10:12:53.452122+00', 16522, 3, 106, '', 'A', '', 1, 1, 'Y', 'hLqIgV33DgU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2588, '2016-08-10 10:14:16.801773+00', '2016-08-10 10:15:24.876529+00', 4579, 1, 106, '', 'A', '', 1, 1, 'Y', 'HNwNA85HjHE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2589, '2016-08-10 10:16:50.2109+00', '2016-08-10 10:17:32.0556+00', 11543, 3, 106, '', 'A', '', 1, 1, 'Y', 'b9aqt0d6RF8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2590, '2016-08-10 10:20:35.97098+00', '2016-08-10 10:21:57.874413+00', 16524, 4, 106, '', 'A', '', 1, 1, 'Y', 'c2KBDWdwDCY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2591, '2016-08-10 10:24:43.16679+00', '2016-08-10 10:25:27.401907+00', 794, 6, 106, '', 'A', '', 1, 1, 'Y', 'Dp-qYB8R6Cs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2592, '2016-08-10 10:26:29.900186+00', '2016-08-10 10:27:04.039205+00', 7242, 5, 106, '', 'A', '', 1, 1, 'Y', 'sa1xY9bDQlk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2593, '2016-08-10 10:32:51.015703+00', '2016-08-10 10:33:59.904768+00', 4404, 8, 106, '', 'A', '', 1, 1, 'Y', '5YKbKNy_do0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2594, '2016-08-10 10:35:42.563647+00', '2016-08-10 10:36:21.710441+00', 3326, 5, 106, '', 'A', '', 1, 1, 'Y', 'KimyCg7tN3Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2595, '2016-08-10 10:37:52.545195+00', '2016-08-10 10:39:30.61996+00', 13588, 6, 106, '', 'A', '', 1, 1, 'Y', 'i_VPt8BC7Ug', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2596, '2016-08-10 10:40:38.255144+00', '2016-08-10 10:42:16.402063+00', 6701, 3, 106, '', 'A', '', 1, 1, 'Y', 'tS7zsjuxFnw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2597, '2016-08-10 10:44:32.633288+00', '2016-08-10 10:45:09.305912+00', 5326, 4, 106, '', 'A', '', 1, 1, 'Y', 'vqJn5dnqByc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2598, '2016-08-10 10:46:10.171009+00', '2016-08-10 10:47:37.577268+00', 7351, 1, 106, '', 'A', '', 1, 1, 'Y', 'f3e9-OgffOs', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2599, '2016-08-10 10:49:26.186439+00', '2016-08-10 10:50:11.100247+00', 40, 2, 106, '', 'A', '', 1, 1, 'Y', 'SZtoHVMIh8Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2600, '2016-08-10 10:51:44.582698+00', '2016-08-10 10:52:34.678069+00', 13149, 9, 106, '', 'A', '', 1, 1, 'Y', '3MI3OtdM1k8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2601, '2016-08-10 10:55:05.062099+00', '2016-08-10 10:55:43.063248+00', 340, 3, 106, '', 'A', '', 1, 1, 'Y', 'RT3RQKJc3F4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2602, '2016-08-10 10:56:45.513286+00', '2016-08-10 10:57:47.228118+00', 7061, 5, 106, '', 'A', '', 1, 1, 'Y', 'bcnUl8tJCqU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2603, '2016-08-10 10:59:24.978331+00', '2016-08-10 11:00:02.510681+00', 4720, 2, 106, '', 'A', '', 1, 1, 'Y', 'k8S2rkzftoU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2604, '2016-08-10 11:01:11.045695+00', '2016-08-10 11:02:10.010449+00', 16537, 3, 106, '', 'A', '', 1, 1, 'Y', 'v_RAL4wXZOY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2606, '2016-08-10 11:05:21.135178+00', '2016-08-10 11:05:40.751758+00', 9770, 4, 106, '', 'A', '', 1, 1, 'Y', 'JXQD4lJ2EAU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2607, '2016-08-10 11:07:45.188841+00', '2016-08-10 11:08:46.113991+00', 794, 7, 106, '', 'A', '', 1, 1, 'Y', 'S1pxQ1fGAok', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2608, '2016-08-10 11:19:36.970827+00', '2016-08-10 11:20:27.853433+00', 4646, 6, 106, '', 'A', '', 1, 1, 'Y', 'pEmNAnNvFn8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (288, '2012-10-04 07:22:46.219544+00', '2016-08-22 15:41:12.548204+00', 14426, 1, 513, '', 'C', 'NOTE: Since the original publication of "Dancing on Air" in 2011, bars [13-16] and [21-24] of this dance have been modified.  The formation is now "set to corner; turn corner BH".  The diagrams are correct. 



In this video, these turns are made incorrectly with RH instead of BH.



', 1, 1, 'Y', 'rbJrORRqsp0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2614, '2016-08-22 19:12:21.480519+00', '2016-08-22 19:12:35.120978+00', 17194, 1, 106, '', 'B', 'Dance for the 2016 Asilomar Friday night program. Note that the correct and spectacular tune is not used.', 1, 1, 'Y', 'VWG0ux0NQHQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3560, '2018-06-06 14:11:17.509618+00', '2018-06-06 14:37:35.56803+00', 2084, 2, 2824, '', 'A', '4 times through', 1, 1, 'Y', '6rdbL-Aj5v8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2617, '2016-08-24 19:00:29.247363+00', '2016-08-24 19:01:43.523008+00', 16962, 1, 160, '', 'B', '', 1, 1, 'Y', 'yHU2_BhHwME', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2618, '2016-08-29 21:35:45.729755+00', '2016-08-29 22:26:59.290202+00', 6150, 1, 1041, '', 'C', 'Published on 21 Apr 2015



Royal Scottish Country Dance Society, Seattle Branch (rscds-seattle.org) runs a beginner Scottish country dance class in Seattle''s University district on Tuesdays.

', 1, 1, 'Y', 'Dcpn2GjA7_U', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2620, '2016-09-04 19:00:46.648335+00', '2016-09-04 19:04:12.647493+00', 17136, 1, 1041, '', 'A', '', 1, 1, 'Y', 'lyA1HOjhG-s', 142, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2619, '2016-09-04 18:56:37.480031+00', '2016-09-05 12:56:10.126381+00', 4511, 3, 1041, '', 'A', 'Excellent dancing, but one serious error in second time through.', 1, 1, 'Y', 'lyA1HOjhG-s', 7, 142, NULL);
INSERT INTO 'dancevideo' VALUES (2621, '2016-09-06 14:21:12.256193+00', '2016-09-06 15:51:13.249761+00', 3659, 5, 106, '', 'A', 'Published on 17 Feb 2016



This is a teaching video of a Scottish Country Dance. There are audio and on screen instructions and a bar counter. The dancers wear numbered coloured tabards so that the learner can follow a particular dancer through the dance.



The Ochil Scottish Country Dancers videoed this dance in August 2015 at Cambusbarron Church Hall, Stirling, Scotland. ', 1, 1, 'Y', 'OZ25dgJpAo8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2622, '2016-09-06 14:23:54.002033+00', '2016-09-06 15:51:26.438183+00', 3659, 6, 106, '', 'B', 'Published on 8 Oct 2013



Performed by the Silver State Scottish Country Dancers at the 2013 Celtic Celebration in Reno, Nevada.', 1, 1, 'Y', 'SGBj2KrHBcc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2627, '2016-09-07 01:26:29.77512+00', '2016-09-07 14:12:16.564815+00', 7521, 1, 1330, '', 'C', '', 1, 1, 'Y', 'RpNAEGHMsfY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2626, '2016-09-07 01:24:34.877173+00', '2016-09-07 14:14:01.443514+00', 9984, 1, 1330, '', 'C', '', 1, 1, 'Y', '56eL8g9GFvI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2625, '2016-09-06 15:55:42.461825+00', '2016-09-07 14:00:04.345245+00', 3659, 8, 106, '', 'D', 'LowerHutt Scottish DC 60th Dance Anniversary ', 1, 1, 'Y', 'RwntgzY9P7I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3492, '2018-03-28 15:20:21.442685+00', '2018-03-28 15:20:21.442685+00', 12983, 4, 1296, '', 'X', '"The Drunken Sailor" is a 32 bar reel for 3 couples.', 1, 1, 'Y', '64VtjtBs2ac', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2648, '2016-09-13 19:41:42.874968+00', '2016-09-13 19:42:00.215401+00', 17233, 1, 106, '', 'C', '', 1, 1, 'Y', 'V-eiOYaE_Ss', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2647, '2016-09-13 11:31:52.27202+00', '2016-09-13 20:14:07.496796+00', 17141, 2, 590, '', 'A', '', 1, 1, 'Y', 'TlGXCWLiWVI', 215, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2645, '2016-09-11 17:57:24.527247+00', '2016-09-13 20:14:21.227565+00', 17141, 1, 105, '', 'A', '', 1, 1, 'Y', 'iiVfa5NoeU8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3493, '2018-03-28 15:20:21.707467+00', '2018-03-28 15:20:21.707467+00', 16465, 4, 1296, '', 'X', '*', 1, 1, 'Y', '0cUfIvpgfGc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3494, '2018-03-28 15:20:21.737852+00', '2018-03-28 15:20:21.737852+00', 17897, 3, 1296, '', 'X', '*', 1, 1, 'Y', '83MTpY8rILA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2650, '2016-09-25 21:34:12.773546+00', '2016-09-26 09:33:31.941002+00', 17143, 1, 1041, '', 'A', '', 1, 1, 'Y', 'kwYcZgzzI_4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2653, '2016-09-25 21:39:19.975944+00', '2016-09-26 09:50:43.028667+00', 17137, 1, 1041, '', 'A', '', 1, 1, 'Y', 'rl5pj0y2xQM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2655, '2016-09-25 21:50:12.463869+00', '2016-09-26 10:00:15.755285+00', 2126, 3, 1041, '', 'C', '', 1, 1, 'Y', 'JijX7b1m7Fs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2656, '2016-09-25 21:52:42.996619+00', '2016-09-26 10:02:07.621498+00', 2931, 2, 1041, '', 'C', '', 1, 1, 'Y', 'Xb1ASddvOGg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2649, '2016-09-25 19:43:10.399364+00', '2016-09-26 10:09:22.779229+00', 17133, 1, 1684, '', 'A', 'Book 50 videos by RSCDS', 1, 1, 'Y', 'aaezP049s9k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2657, '2016-09-25 21:54:57.98754+00', '2016-09-26 10:41:58.984908+00', 15964, 1, 1041, '', 'B', '', 1, 1, 'Y', '3lqR_2clM-s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2658, '2016-09-26 10:55:57.124488+00', '2016-09-26 11:01:28.757057+00', 17142, 1, 106, '', 'A', '', 1, 1, 'Y', 'k0RIiAU1djc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2652, '2016-09-25 21:37:54.81795+00', '2016-09-26 11:13:20.703313+00', 17139, 1, 1041, '', 'A', '', 1, 1, 'Y', '9jBfHYwzfKU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2659, '2016-09-26 19:30:25.040519+00', '2016-09-27 00:01:43.540218+00', 11890, 1, 274, '', 'B', '2. Austro-Hungarian Weekend - Győr, Hungary, 2016.09.25

Teacher: David Hall', 1, 1, 'Y', '1E7ky0m9TF8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2660, '2016-09-27 18:46:56.67722+00', '2016-09-27 19:56:11.790935+00', 8334, 1, 106, '', 'C', 'Music is off sync. with the dancing, which is also not terrific.



The dancers make a systematic error: 17-24 should be 1c+3c R&L ; this is danced "2c+1c R&L" each time.

', 1, 1, 'Y', '8QXYlQ7VF50', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2615, '2016-08-22 22:04:10.262909+00', '2016-09-30 08:13:58.856718+00', 17195, 1, 106, '', 'B', 'On bars 25-26, the dancers set, while the instructions say "All advance and retire".



Dancers shown are from the RSCDS, Northern Virginia and Washington DC Branches. Music is by Terpsichore: Elke Baker, fiddle and Liz Donaldson, piano. Video courtesy of Eva Lanyi.', 1, 1, 'Y', '63UAPbB9nKI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3495, '2018-03-28 15:20:21.8715+00', '2018-03-28 15:20:21.8715+00', 14903, 1, 1296, '', 'X', 'This is a test.', 1, 1, 'Y', 'GGpXRHrUZWA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2663, '2016-09-30 13:39:10.502962+00', '2016-09-30 14:31:54.947071+00', 4890, 5, 2457, '', 'B', 'A 32 bar strathspey for 3 couples performed by Lucy Clark Scottish Country Dance Club members.', 1, 1, 'Y', 'Fkn_3sfG1YU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2661, '2016-09-30 13:29:24.449994+00', '2016-09-30 14:34:52.490446+00', 12321, 1, 2457, '', 'B', 'A 32 bar reel for 3 couples in a 4-couple longwise set. Devised by Valerie Farr and performed by Lucy Clark Scottish Country Dance Club members.', 1, 1, 'Y', 'npqsr6dSP3E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2664, '2016-09-30 14:49:41.057746+00', '2016-09-30 14:55:10.057731+00', 3891, 1, 106, '', 'B', 'A 32 bar reel for 3 couples in a 4-couple longwise set. Performed by Lucy Clark Scottish Country Dance Club.', 1, 1, 'Y', 'JiibHCOt_uw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2665, '2016-09-30 21:44:13.531828+00', '2016-09-30 22:22:41.40673+00', 4845, 1, 197, '', 'A', 'This video shows one repetition of the dance, "The Music o'' Spey" a 4x32 Strathspey, performed by Bedford Scottish Dance Group for the Bedford Scots'' Society, September 2016.', 1, 1, 'Y', '8qncWuaEQg8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2666, '2016-10-02 07:43:30.925773+00', '2016-10-02 15:31:53.529001+00', 17134, 3, 197, '', 'A', '', 1, 1, 'Y', 'aSbWomd3P24', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2965, '2017-04-10 14:23:01.240991+00', '2017-04-10 14:24:06.86124+00', 3309, 2, 160, '', 'B', '', 1, 1, 'Y', 'H-yyBN1UU38', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3540, '2018-05-24 14:14:26.414238+00', '2018-05-26 14:38:23.683285+00', 16508, 2, 2821, '', 'A', 'Twenty-three Two Ninety (3x32S) danced by Nottingham RSCDS at the ASCDS Festival on 12 May 2018.', 1, 1, 'Y', 'O_y5-jhLpAE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2669, '2016-10-07 14:19:24.980354+00', '2016-10-07 17:17:31.49487+00', 17136, 2, 197, '', 'A', 'Recorded during Summer School 2016 for the RSCDS by Red Barn Studios.', 1, 1, 'Y', 'q8r-gbs2rHE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2671, '2016-10-07 14:25:04.875853+00', '2016-10-07 17:18:19.194954+00', 17140, 3, 197, '', 'A', 'Recorded during Summer School 2016 for the RSCDS by Red Barn Studios.', 1, 1, 'Y', 'rSWg7kIzo6g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2670, '2016-10-07 14:23:33.446496+00', '2016-10-07 17:18:58.413185+00', 17138, 4, 197, '', 'A', 'Recorded during Summer School 2016 for the RSCDS by Red Barn Studios.', 1, 1, 'Y', 'ImIBTQcNq6o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2672, '2016-10-07 14:26:15.227966+00', '2016-10-07 17:19:30.256454+00', 17144, 3, 197, '', 'A', 'Recorded during Summer School 2016 for the RSCDS by Red Barn Studios.', 1, 1, 'Y', '4taSPAdJ2H0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2687, '2016-10-16 23:41:17.6492+00', '2017-11-24 17:23:03.44118+00', 17229, 1, 106, '', 'C', 'The set omits the setting on bars 19-20', 1, 1, 'Y', 'ZVIfweEsJ_E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2667, '2016-10-07 13:58:26.444258+00', '2016-10-07 17:20:40.84023+00', 17141, 3, 197, '', 'A', '', 1, 1, 'Y', '11Wd8JJMSAc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2673, '2016-10-09 16:40:34.925731+00', '2016-10-09 17:51:39.355175+00', 3504, 1, 954, '', 'C', '', 1, 1, 'Y', 'xt5k5vcjra8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2675, '2016-10-09 19:32:08.633506+00', '2016-10-09 19:32:35.600608+00', 14533, 4, 106, '', 'D', 'The Castle of Mey - 51st Tartan Ball.  Dancescottish.ca', 1, 1, 'Y', 'BJRKNxSl040', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2674, '2016-10-09 16:44:20.054997+00', '2016-10-09 19:33:51.228434+00', 14976, 1, 954, '', 'C', '', 1, 1, 'Y', 'Gp1Dabt37Ok', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (253, '2012-09-12 23:50:50.031623+00', '2016-10-10 21:51:25.532644+00', 13387, 1, 106, '', 'D', 'Cincinnati Branch RSCDS Founders Ball 2009.', 1, 1, 'Y', 'I54v12AgPZk', 104, 213, NULL);
INSERT INTO 'dancevideo' VALUES (3022, '2017-05-09 16:49:55.519845+00', '2017-05-09 16:52:07.514502+00', 3317, 1, 3637, '', 'C', '', 1, 1, 'Y', 'x64k-LOg6bU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2677, '2016-10-11 12:10:23.003224+00', '2016-10-11 22:33:54.009544+00', 17347, 1, 2213, '', 'B', 'The Dance was devised by Les Burden, who along with his wife Dawn, run the Bude Weekend, 7-9 October this year (2016).  

They are dancing as first couple in the video: https://youtu.be/i0pVt0aTBiQ', 1, 1, 'Y', 'i0pVt0aTBiQ', 8, 7, NULL);
INSERT INTO 'dancevideo' VALUES (2686, '2016-10-16 23:30:19.792201+00', '2016-10-16 23:32:52.671141+00', 17238, 1, 106, '', 'A', '', 1, 1, 'Y', 'Fg58T9q50z4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2679, '2016-10-12 11:05:47.463262+00', '2016-10-12 22:57:35.392037+00', 14419, 1, 513, '', 'C', '', 1, 1, 'Y', 'MFLuI2gyMKI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2684, '2016-10-16 12:16:24.432315+00', '2017-01-14 17:18:12.358965+00', 14548, 2, 106, '', 'C', 'RSCDS Sheffield, probably May 2015.  The dancing in this big hall is quite good, but the music is played 10 x 32 instead of 8 x 40. ', 1, 1, 'Y', '49vKb-o3G9Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2682, '2016-10-12 19:06:55.711465+00', '2016-10-12 23:02:16.920648+00', 140, 2, 2794, '', 'D', '', 1, 1, 'Y', 'sbY-pxNtEvc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2676, '2016-10-10 08:12:37.410517+00', '2016-10-12 23:03:02.40176+00', 16474, 1, 513, '', 'C', '', 1, 1, 'Y', 'MhaInlIHkEA', 15, 172, NULL);
INSERT INTO 'dancevideo' VALUES (2678, '2016-10-12 02:07:05.825817+00', '2016-10-12 23:12:30.184525+00', 2254, 1, 940, '', 'A', 'Part of a larger demonstration. Ending circle leads dancers to enter next demonstration dance positions. Not great video quality (Appears to be a converted VHS/PAL type tape), but sufficient.', 1, 1, 'Y', 'NrhtBxJtgw0', 80, 227, NULL);
INSERT INTO 'dancevideo' VALUES (2683, '2016-10-14 19:07:42.005793+00', '2016-10-14 22:07:12.129836+00', 9462, 1, 1022, '', 'B', '', 1, 1, 'Y', 'rnIRNv8etU8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2688, '2016-10-16 23:46:11.321679+00', '2016-10-16 23:47:40.070364+00', 17230, 1, 106, '', 'A', '', 1, 1, 'Y', 'HrHlkt8grAc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2692, '2016-10-17 22:42:14.412038+00', '2016-10-17 22:43:38.807984+00', 16845, 1, 106, '', 'A', '', 1, 1, 'Y', '56dg5vPG7N8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2693, '2016-10-17 22:48:12.392848+00', '2016-10-17 22:57:19.274039+00', 16847, 1, 106, '', 'A', '', 1, 1, 'Y', 'XTbo15IJtMw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2694, '2016-10-17 23:00:58.1478+00', '2016-10-17 23:01:47.721421+00', 16846, 1, 106, '', 'A', '', 1, 1, 'Y', 'pX4pY4WZL0o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2690, '2016-10-17 13:09:15.722522+00', '2016-10-18 20:38:04.795425+00', 8143, 2, 1751, '', 'C', 'Poor camera handling: too close, view on feet often obstructed; moving between dancers.  No use for teaching.', 1, 1, 'Y', 'LSgowIQPvq4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2696, '2016-10-17 23:16:35.015068+00', '2016-10-17 23:17:52.941435+00', 15279, 1, 106, '', 'D', 'The Greenbelt Jig, devised by Elaine Brunken, was danced at the Lower Hutt SCD Club''s annual dance on September 5, 2015. The dance was held in St Bernard''s School gym and the MC was club tutor Damon Collin.



Balmoral Band comprises Anne-Marie Forsyth, Sharlene Penman and Ian McKenzie.



Many newer dancers attended this dance, which for many of them was their first formal dance. More experienced dancers partnered them for ''The Greenbelt Jig''.', 1, 1, 'Y', 'Y2SNz4oTQwc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2071, '2015-04-30 21:07:37.619967+00', '2016-11-04 17:14:30.897025+00', 1578, 2, 1041, '', 'D', 'Watch the middle  top set on the floor, NOT the closest set! ~



The first 8 bars are missing in the first time through; this video starts at the second time through.  



', 1, 1, 'Y', 'XExj80m1byw', 25, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2697, '2016-10-17 23:19:27.296353+00', '2016-10-17 23:22:56.705152+00', 14977, 5, 106, '', 'D', 'The Kissing Bridge was on the programme for the Lower Hutt SCD Club''s annual dance on September 5, 2015. The MC was club tutor Damon Collin and live music was provided by the Balmoral Band.



The Kissing Bridge was devised by Romaine Butterfield, who can be seen dancing in the middle set across.



The Balmoral Band comprises Ian McKenzie, Sharlene Penman and Anne-Marie Forsyth.



The dance was held this year in the St Bernard''s School gym in Lower Hutt.', 1, 1, 'Y', '3JHoQdHydzU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1648, '2014-05-05 19:41:55.319296+00', '2016-10-18 20:33:47.40754+00', 8143, 1, 1041, '', 'C', 'Educational video to help everyone to take the floor and participate in the commonwealth ceilidh on the 21st June 2014', 1, 1, 'V', '89897870', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2700, '2016-10-28 21:37:08.856839+00', '2016-10-28 21:37:26.707751+00', 13468, 1, 106, '', 'B', '', 1, 1, 'Y', 'W3GZr1V4DAE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2714, '2016-11-11 01:51:34.563286+00', '2016-11-11 01:51:54.361948+00', 16534, 3, 106, '', 'B', 'Published on 8 Nov 2016



Recorded during the RSCDS Conference WE 2016 in Perth at the Saturday evening Ball. Music by Jim Lindsay and his band.

A part of the 1st turn through of the dance is missing in this video!', 1, 1, 'Y', 'eIg_ZK5PrQY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2701, '2016-10-31 00:06:35.453192+00', '2016-10-31 00:07:15.83228+00', 3027, 4, 106, '', 'C', 'Danced at the Eastbourne SCD Club''s 60th Anniversary dance on October 1 2016, in the Muritai School hall, Eastbourne (New Zealand).', 1, 1, 'Y', 'mF8QBdIpWiE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2702, '2016-10-31 00:12:41.615189+00', '2016-10-31 00:13:01.872447+00', 445, 10, 106, '', 'C', 'Bluebonnet Scottish Country Dancers perform Bees of Maggieknockater at the Texas State Fair--Oct. 2, 2016.', 1, 1, 'Y', 'XIiFVFFzYGg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2703, '2016-10-31 00:16:49.989514+00', '2016-10-31 00:17:06.478364+00', 5496, 1, 106, '', 'C', 'Bluebonnet Scottish Country Dancers performing Red Ghillies at the Texas State Fair--Oct. 1, 2016', 1, 1, 'Y', 'oP_uP4HxxHM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2704, '2016-10-31 00:21:40.688308+00', '2016-10-31 00:21:59.633449+00', 1786, 6, 106, '', 'D', 'The dance was held in the Muritai School hall in Eastbourne (New Zealand). The MC was Catherine McCutcheon and live music was provided by Iain Matcham (who is also the club tutor), Jean Malcolm and Terry Bradshaw.', 1, 1, 'Y', 'YGjBlVFabf0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2705, '2016-10-31 11:36:41.858422+00', '2016-10-31 11:37:35.331765+00', 7019, 2, 106, '', 'D', '', 1, 1, 'Y', 'xubPARoYB8U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3521, '2018-04-19 14:31:50.050175+00', '2018-04-19 17:20:44.478158+00', 5497, 7, 3637, '', 'A', 'Red House danced by the members of the New World Dancers. Taken from a performance at Dunsmuir House, Oakland, California in December 2014.  

', 1, 1, 'Y', '1Q8wxnW-3p4', 1435, 1532, NULL);
INSERT INTO 'dancevideo' VALUES (2707, '2016-10-31 16:34:23.789855+00', '2016-10-31 16:34:45.536829+00', 6048, 9, 106, '', 'D', 'Very informal and ragged (Ceilidh-style)', 1, 1, 'Y', 'I-jvoCEnAC8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2708, '2016-10-31 16:37:11.089092+00', '2016-10-31 16:37:30.048697+00', 15711, 1, 106, '', 'D', '', 1, 1, 'Y', 'uFu8V8wnixQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2709, '2016-10-31 16:41:16.510985+00', '2016-10-31 16:42:22.570314+00', 8151, 1, 106, '', 'D', '', 1, 1, 'Y', 'f10VXoWp29g', 50, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2710, '2016-11-01 15:35:55.607211+00', '2016-11-01 15:39:40.56231+00', 16158, 2, 106, '', 'D', 'The preceding part fo this video includes a full instruction session.

Dufftown Dance Club - 01/10/2016

Music from Gordon Brown and his band

https://www.dufftowndanceclub.com', 1, 1, 'Y', 'icasFuhr-NQ', 340, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2711, '2016-11-01 15:47:44.590299+00', '2016-11-01 15:48:10.028568+00', 16765, 1, 106, '', 'D', '', 1, 1, 'Y', '1MS0bHEvYyI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2712, '2016-11-02 01:22:22.063617+00', '2016-11-02 01:22:44.9858+00', 17458, 1, 106, '', 'B', '', 1, 1, 'Y', 'IToeLDRG98U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2713, '2016-11-02 17:51:01.361109+00', '2016-11-02 23:19:10.760646+00', 13587, 2, 954, '', 'C', 'Once through only; starts a little late.

Published on 20 Nov 2013

We run a beginner Scottish country dance class in Seattle''s University district on Tuesdays. 

Royal Scottish Country Dance Society, Seattle Branch', 1, 1, 'Y', '-bSDVvN6KdY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2715, '2016-11-17 06:32:48.123337+00', '2016-11-17 06:33:52.95023+00', 1891, 1, 106, '', 'B', '', 1, 1, 'Y', 'ImDsx2H2cTQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2717, '2016-11-21 16:24:12.735163+00', '2016-11-21 18:25:52.735403+00', 10437, 1, 513, '', 'B', '', 1, 1, 'Y', 'DEoKD2SGc7Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2721, '2016-11-21 22:01:01.105637+00', '2016-11-22 02:41:53.261557+00', 12877, 1, 513, '', 'B', '', 1, 1, 'Y', '_v5IfTWHRx8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2723, '2016-11-21 22:36:00.214394+00', '2016-11-22 02:43:44.715076+00', 11282, 1, 513, '', 'C', '', 1, 1, 'Y', 'cOh7ApCG2Mc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2722, '2016-11-21 22:23:18.990972+00', '2016-11-22 02:45:49.068398+00', 13769, 1, 513, '', 'C', '', 1, 1, 'Y', 'MH7bhQ5fJ_Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2716, '2016-11-20 21:47:36.568793+00', '2016-11-22 02:47:13.222878+00', 17462, 1, 3019, '', 'D', '', 1, 1, 'Y', 'pIw5jAGtXD0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2718, '2016-11-21 21:22:05.986979+00', '2016-11-22 02:50:21.073781+00', 17304, 1, 513, '', 'B', '', 1, 1, 'Y', 'HzSwFekfyrI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2719, '2016-11-21 21:41:38.233847+00', '2016-11-22 02:51:29.329296+00', 17141, 4, 513, '', 'D', '', 1, 1, 'Y', 'lQCpfFauPmk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2548, '2016-06-30 13:33:19.221393+00', '2016-11-26 20:10:50.3355+00', 9220, 1, 106, '', 'C', 'SCDGroup Hk   Published on 26 Jun 2016



There is an error in bars 5-8: 1c should cast behind 3c and dance up between them.  ', 1, 1, 'Y', 'KCt9VvovVCk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2724, '2016-11-26 22:16:59.878158+00', '2016-11-26 22:17:26.961725+00', 16853, 1, 106, '', 'B', '', 1, 1, 'Y', 'zMUZ-CBnbz4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2726, '2016-11-27 05:08:27.35207+00', '2016-11-27 05:11:27.542117+00', 3802, 4, 106, '', 'B', 'Published on Nov 22, 2016

Instructional Country Dance video by Chiswick Scottish Country Dance Club London', 1, 1, 'Y', 'v2Mxz2BLZUY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3196, '2017-08-21 20:41:21.012141+00', '2017-08-23 16:18:16.705253+00', 17315, 1, 3129, '', 'A', '', 1, 1, 'Y', 'EW-onUoVlIw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2728, '2016-11-27 05:15:42.167061+00', '2016-11-27 05:17:14.896233+00', 6152, 2, 106, '', 'B', 'Published on Nov 20, 2016

Instructional Country Dance video by Chiswick Scottish Country Dance Club London', 1, 1, 'Y', 'OeSPUuWLpyY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2729, '2016-11-27 05:24:54.468242+00', '2016-11-27 05:26:37.757736+00', 754, 3, 106, '', 'D', 'Published on Nov 19, 2016

The Braes of Tulliemet (3 times thru at the 50th Tartan Ball)', 1, 1, 'Y', 'z4uOCrbXg14', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3033, '2017-05-10 07:21:10.772352+00', '2017-05-10 07:25:36.356811+00', 16492, 1, 106, '', 'A', '', 1, 1, 'Y', '5tNZqfCdaTo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2730, '2016-11-27 05:29:35.932884+00', '2016-11-27 05:30:52.563963+00', 6386, 2, 106, '', 'D', 'Published on Nov 19, 2016

Summer Wooing at 2013 St Andrews Summer School', 1, 1, 'Y', 'FEDD3AxDxag', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2731, '2016-11-27 05:35:05.973939+00', '2016-11-27 05:35:53.124483+00', 8333, 1, 106, '', 'D', 'Published on Nov 20, 2016

Gentle Annie 8s32 shown once thru', 1, 1, 'Y', 'k23H52xepqs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2725, '2016-11-27 04:36:36.501647+00', '2016-11-28 19:49:04.348824+00', 221, 3, 106, '', 'C', '', 1, 1, 'Y', '0b3Sksf_MF4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2733, '2016-11-27 05:47:03.774822+00', '2016-11-27 05:48:18.411684+00', 17140, 4, 106, '', 'B', 'Published on Nov 21, 2016', 1, 1, 'Y', 'ZBcNnAm2nYo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2863, '2017-02-12 19:45:52.756331+00', '2017-02-13 00:49:08.443926+00', 743, 6, 2084, '', 'A', 'The Braes of Breadalbane (Bk21), danced by the German men''s team, at Newcastle Festival 2017.', 1, 1, 'Y', 'xVdf_QaHOzc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2734, '2016-11-27 05:55:22.942488+00', '2016-11-27 05:55:53.868635+00', 8162, 2, 106, '', 'D', 'Published on Nov 22, 2016

Virginia Reel (32-bar variation).   Each year RSCDS Toronto has a Family Ceilidh & Pizza Party', 1, 1, 'Y', 'xHCDPZEnf3I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2732, '2016-11-27 05:40:49.914564+00', '2016-11-28 08:36:02.322394+00', 1558, 1, 106, '', 'D', 'Published on Nov 20, 2016



The deviser writes:  In this video the dance is performed incorrectly.  The original instructions clearly state that first woman and second man pass by right shoulders to finish the reel of four across.  This allows dancers to flow from the reel of four into the ''little spiral''.  PLEASE, do not teach dances from a crib unless you already have danced it, and, even then, double check with the original instructions. This plea applies to all dances not just mine.

', 1, 1, 'Y', '--334AUKJWs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2782, '2017-01-13 14:13:32.21642+00', '2017-01-16 22:20:04.705052+00', 5807, 2, 2824, '', 'D', '', 1, 1, 'Y', 'XevOdTurXQo', 40, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2788, '2017-01-17 18:15:10.768029+00', '2017-01-18 00:22:24.117463+00', 6947, 3, 954, '', 'A', 'Part of a longer display', 1, 1, 'Y', 'AMVhkllL1Co', 20, 93, NULL);
INSERT INTO 'dancevideo' VALUES (2736, '2016-11-27 06:15:38.765145+00', '2016-11-27 06:16:56.343622+00', 16832, 1, 106, '', 'D', 'Published on Nov 21, 2016

''Snow Flurries'' was on the programme for the Johnsonville SCD Club''s final night for 2016.



This strathspey was devised by Charlotte Williams (née Dunn) for the Lower Hutt SCD Club''s 60th Anniversary. Snow is very rare in Wellington and the Hutt Valley, and the dance title refers to a time in 2011 when the district experienced just a few magical days of snowfall.', 1, 1, 'Y', 'ExWqF1hPiMA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2737, '2016-11-27 06:20:50.077589+00', '2016-11-27 06:21:25.153524+00', 5525, 15, 106, '', 'D', 'Published on Nov 21, 2016

''The Reel of the 51st Division'' was on the programme of the Johnsonville SCD Club''s final night for 2016. The club has both new and experienced dancers, and several visitors from other Wellington clubs attended this final night. The MC was Johnsonville club tutor Rod Downey.



The music was provided by a five-piece band comprising Heather Elder, Lynne Scott, Don McKay, Peter Elmes and Aileen Logie', 1, 1, 'Y', 'YeMfjt1VoPU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2758, '2016-12-14 02:19:49.261271+00', '2016-12-14 02:20:33.684682+00', 1537, 2, 202, '', 'B', '', 1, 1, 'Y', 'MBFtdeemymA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2738, '2016-11-28 11:30:13.694759+00', '2016-11-28 19:48:14.048966+00', 2372, 1, 274, '', 'B', 'Berlin Hopalots Ball 26.11.2016

Two times through', 1, 1, 'Y', 'FtFknM7yLZ4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2744, '2016-11-29 16:57:27.159076+00', '2018-10-03 22:13:55.455114+00', 3891, 2, 596, '', 'X', '', 1, 1, 'Y', 'nBjLhYKmqpM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2755, '2016-12-11 11:47:05.232707+00', '2018-09-04 13:13:04.784306+00', 9001, 1, 2482, '', 'C', 'Alastair Hunter''s reel', 1, 1, 'Y', 'ZDEiqU1ccTY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2750, '2016-12-02 15:13:58.025898+00', '2016-12-02 19:51:54.636366+00', 12690, 1, 954, '', 'D', '', 1, 1, 'Y', 'WA9uSeKidIM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2754, '2016-12-11 11:43:15.13532+00', '2016-12-14 02:23:15.634169+00', 2423, 2, 2482, '', 'B', ' Geese in the Bog', 1, 1, 'Y', 'zmaoC0k-EQI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2747, '2016-12-01 13:20:57.622987+00', '2016-12-03 08:06:26.80809+00', 3418, 2, 2482, '', 'B', '', 1, 1, 'Y', 'vCfZocCMVAw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2748, '2016-12-01 13:26:15.060588+00', '2016-12-03 08:24:19.223076+00', 10773, 2, 2482, '', 'B', '', 1, 1, 'Y', 'N02L_V0xgNQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2749, '2016-12-02 15:10:23.110987+00', '2016-12-03 08:27:49.984836+00', 7018, 1, 954, '', 'D', '', 1, 1, 'Y', 'UF6QckaRlE4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2760, '2016-12-14 15:14:54.270373+00', '2016-12-16 21:42:52.080489+00', 12802, 1, 2213, '', 'B', '', 1, 1, 'Y', 'YCcvrNaQhtE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2759, '2016-12-14 14:03:51.384609+00', '2016-12-16 21:54:23.882296+00', 12803, 2, 2824, '', 'B', '', 1, 1, 'Y', 'm3uFZvnZMmA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2752, '2016-12-03 17:13:44.738409+00', '2017-01-11 17:12:19.653773+00', 11583, 1, 202, '', 'B', '', 1, 1, 'Y', 'm4MSySYGnSM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2753, '2016-12-03 19:07:56.533683+00', '2016-12-07 23:15:11.980492+00', 6152, 3, 202, '', 'B', '', 1, 1, 'Y', 'ONfyBmZTjLk', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2767, '2016-12-31 00:18:11.191087+00', '2016-12-31 00:18:24.517681+00', 3108, 3, 106, '', 'C', 'Published on 22 Dec 2016', 1, 1, 'Y', 'RcWbGzPrrj0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2761, '2016-12-17 16:15:40.48568+00', '2016-12-17 16:16:32.407115+00', 50, 1, 202, '', 'B', '', 1, 1, 'Y', 'OitaBm_ebTA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2756, '2016-12-13 15:47:30.471532+00', '2016-12-13 23:55:06.756363+00', 10542, 1, 2824, '', 'D', 'Published on 13 Dec 2016



Ball at 15th anniversary Berlin Hopalots weekend (26.11.2016)', 1, 1, 'Y', 'LSPYyDZRVlA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2757, '2016-12-13 15:55:48.406707+00', '2016-12-14 00:11:48.55682+00', 7180, 7, 2824, '', 'B', 'RSCDS Vienna Branch - dem at Christ Church Bazaar, 19.11.2016



Part of a Medley: preceded by The Duke of Atholl''s Reel (J32 - 2/4L), followed by Montgomeries'' Rant (R32 - 3/4L)



Third time through the last eight bars are modified to move back to a longwise set for the next part of the medley. Camera point-of-view less than ideal.', 1, 1, 'Y', 'TVmyrqdFBuc', 54, 179, NULL);
INSERT INTO 'dancevideo' VALUES (2764, '2016-12-21 05:43:25.944745+00', '2016-12-21 05:44:25.785665+00', 2768, 1, 202, '', 'B', '', 1, 1, 'Y', 'n1Gnt7pj36A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2763, '2016-12-21 01:22:31.042785+00', '2016-12-21 08:58:26.588294+00', 8992, 1, 2220, '', 'C', 'Devised for their wedding on Jan 1 2001, this was danced at the Berkeley Holiday Party 2016 with the devisor as first man and the dedicatees as 2nd couple.  The band of 13 musicians who play for the Berkeley classes was led by Patti Cobb, who composed the main strathspey tune.', 1, 1, 'Y', 'XzjP8cx6Fyk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2765, '2016-12-28 17:05:29.633331+00', '2016-12-28 23:21:47.018651+00', 16255, 4, 513, '', 'X', '', 1, 1, 'Y', 'zvV87XRjASU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2968, '2017-04-10 15:16:34.83382+00', '2017-04-10 15:20:09.936647+00', 9286, 3, 160, '', 'B', '', 1, 1, 'Y', 'vw6AfQ-84V8', 0, 175, NULL);
INSERT INTO 'dancevideo' VALUES (2077, '2015-05-01 23:09:07.34251+00', '2016-12-28 23:36:49.450465+00', 16255, 1, 106, '', 'C', 'Danced at the Spring Fling 2015, held over the weekend of April 17th to the 19th in Hounslow, London.



On the last day of Spring Fling a dance competition was held to choose a dance for the upcoming Book. In total, 46 dances from around the world were submitted and trialled, with 7 finalists chosen to be voted on by Spring Fling attendees.



The winning dance, shown here, was the culmination of many hours of devising, dancing and deliberation. It was danced by Spring Fling attendees who, after a long weekend of dancing, with a lot of energy spent (and sleep lost), were up for one more dance!



Thank you to all who submitted a dance and we are proud to present to you "The Spring Fling Reel".', 1, 1, 'Y', '_CgiDzE0Dn4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2766, '2016-12-31 00:05:22.883236+00', '2016-12-31 00:05:47.663253+00', 4484, 8, 106, '', 'C', 'At the 2016 Tartan Ball, Toronto', 1, 1, 'Y', '-D1cfGZ2h9A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2768, '2016-12-31 00:21:58.358142+00', '2016-12-31 00:22:15.289144+00', 3027, 5, 106, '', 'C', '', 1, 1, 'Y', 'mmveGDHpgZk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2769, '2016-12-31 00:25:30.795924+00', '2016-12-31 00:25:44.463045+00', 11184, 2, 106, '', 'C', '', 1, 1, 'Y', 'wfA1UTQfGNo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2770, '2016-12-31 00:29:02.56417+00', '2016-12-31 00:29:15.51613+00', 13812, 1, 106, '', 'C', '', 1, 1, 'Y', 'JFDUtO79Ssk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2771, '2016-12-31 00:32:14.704198+00', '2016-12-31 00:32:28.29792+00', 2030, 3, 106, '', 'B', '', 1, 1, 'Y', 'qlXiVwfaQYw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2772, '2016-12-31 00:35:20.679123+00', '2016-12-31 00:35:31.621601+00', 15648, 1, 106, '', 'D', 'Toronto Family Christmas Dance 2016', 1, 1, 'Y', 'nlZC7u1xyMU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2773, '2016-12-31 00:40:00.742124+00', '2016-12-31 00:40:17.858316+00', 16534, 4, 106, '', 'B', 'Rosedale Youth and others, RSCDS Family Ceilidh 2015', 1, 1, 'Y', 'SWP-uZQpWEE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3283, '2017-10-15 16:03:55.887896+00', '2017-10-15 21:28:23.860773+00', 12055, 1, 596, '', 'X', '', 1, 1, 'Y', '3dMTX2MDrpU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2774, '2016-12-31 00:43:02.634281+00', '2016-12-31 00:43:13.455442+00', 8042, 2, 106, '', 'D', '2016 RSCDS Toronto Family Ceilidh', 1, 1, 'Y', 'UFlmcnwV6zE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2775, '2016-12-31 00:47:30.058+00', '2016-12-31 00:48:39.530596+00', 17500, 1, 106, '', 'D', 'RSCDS Toronto Family Day Ceilidh 2016', 1, 1, 'Y', 'FEZfo7M3vn8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2778, '2017-01-09 05:14:46.023916+00', '2017-01-10 14:05:57.206244+00', 3351, 1, 2794, '', 'B', '', 1, 1, 'Y', 'E0WitEN4MIU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2781, '2017-01-10 15:02:54.338315+00', '2017-01-10 15:03:07.171972+00', 2321, 1, 106, '', 'C', '', 1, 1, 'Y', 'omVhhiGgNhg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3030, '2017-05-10 07:17:50.635325+00', '2017-05-10 07:27:33.87225+00', 5658, 2, 2824, '', 'C', '', 1, 1, 'Y', 'Ju-3uhvpJKg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2780, '2017-01-10 11:41:15.668248+00', '2017-01-10 15:20:34.850792+00', 16469, 3, 2254, '', 'B', 'Early Spring - Scottish Country Dance - VI Telheiras Festival May 2015



The dance has been adapted to a 4C set.  All dancers dance the loops and turns for [1-16], and on [25-32], both top and bottom pairs of couples dance the Tourbillon, finishing (2,3,4,1)', 1, 1, 'Y', 'HZObJOt6PVo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2790, '2017-01-18 00:34:53.392005+00', '2017-01-18 00:40:50.352213+00', 13894, 1, 106, '', 'A', 'Middle part of a longer display.   Recorded on 29/07/2011 by the Dunedin Dancers, Edinburgh', 1, 1, 'Y', 'BW8nFzeYpYo', 70, 139, NULL);
INSERT INTO 'dancevideo' VALUES (2785, '2017-01-17 16:43:39.138182+00', '2017-01-18 00:45:14.273045+00', 7111, 4, 2482, '', 'B', '', 1, 1, 'Y', 'klXYmFdr8xw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2793, '2017-01-18 18:59:20.279992+00', '2019-03-05 23:00:43.683985+00', 15307, 1, 1483, '', 'D', '', 1, 1, 'V', '171351110', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2792, '2017-01-18 18:54:48.404647+00', '2017-01-19 15:30:50.651841+00', 4799, 1, 1483, '', 'C', 'Taken at a ''private'' class in New Jersey 2016 - most of the dancers had only just been taught it and danced it once before filming.', 1, 1, 'V', '177932222', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2795, '2017-01-20 19:00:20.983744+00', '2017-01-21 01:06:06.814478+00', 4728, 2, 1041, '', 'B', 'Only once through; part of a large demonstration.

The last 4 bars all 3 couples circle Left instead off 2c+1c circle Right.', 1, 1, 'Y', 'YT_BdUiZAcw', 1159, 1193, NULL);
INSERT INTO 'dancevideo' VALUES (2797, '2017-01-24 10:55:07.565133+00', '2017-01-24 14:04:51.390904+00', 16339, 1, 2824, '', 'B', 'Workshop at 15th anniversary Berlin Hopalots weekend;

Teacher: Zsófia József', 1, 1, 'Y', 'R20rp3-gbvs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1382, '2013-08-18 10:56:03.249174+00', '2017-01-24 18:58:45.842433+00', 6712, 5, 1296, '', 'D', '', 1, 1, 'Y', 'KQqFNtZG2v0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2794, '2017-01-19 16:45:55.693838+00', '2017-01-24 19:03:21.450137+00', 6712, 8, 2482, '', 'B', '', 1, 1, 'Y', '4DFluC5GwN0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2796, '2017-01-21 11:34:47.531498+00', '2017-01-24 19:04:47.308849+00', 8579, 1, 197, '', 'A', 'The Thistle Scottish Country Dancers Waltz

Choreographed by John Wood and danced to the tune "The Wedding Gift" by Rawlins Cross.

Performed by the Thistle Scottish Country Dancers at the Friday night ceilidh for the ISCDS in Halifax, Nova Scotia, July 2004', 1, 1, 'Y', 'TAndvE7FAKg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2800, '2017-01-25 18:06:09.362515+00', '2017-01-25 21:52:37.730066+00', 12664, 2, 2482, '', 'B', '', 1, 1, 'Y', '6_VUR5jTmOE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2814, '2017-01-31 16:46:18.910914+00', '2017-01-31 16:46:44.843799+00', 16527, 4, 106, '', 'Z', 'Poor and distorted music; poor dancing, bad view.  Not worth showing.', 1, 1, 'Y', 'T7F9N44mykA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2802, '2017-01-25 20:17:25.1763+00', '2017-01-26 00:04:36.64208+00', 16661, 3, 963, '', 'C', '', 1, 1, 'Y', 'GS7MEEaXFnk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2812, '2017-01-31 16:40:58.499644+00', '2017-01-31 16:49:19.990318+00', 16527, 2, 106, '', 'A', 'Published on 1 Jun 2016  The Ruby Rant at Gala Day.  Danced 3 x by teachers of RSCDS Toronto.', 1, 1, 'Y', 'fWJAnkN5xII', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2801, '2017-01-25 18:07:30.931759+00', '2017-01-26 00:16:49.601104+00', 3743, 2, 2482, '', 'B', '', 1, 1, 'Y', '9qOJrvOKGSc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3522, '2018-04-20 21:14:57.308857+00', '2018-04-20 21:45:57.634098+00', 13859, 1, 954, '', 'D', '', 1, 1, 'Y', 'Ioev3wGFIsw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2803, '2017-01-26 18:00:51.876008+00', '2017-01-27 00:21:11.027862+00', 2947, 1, 2482, '', 'B', '', 1, 1, 'Y', 'RxtXbBOMJ7k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2804, '2017-01-26 18:02:09.302177+00', '2017-01-27 00:27:18.180111+00', 4884, 1, 2482, '', 'B', '', 1, 1, 'Y', 'dLKf_RGXr68', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2816, '2017-02-03 01:05:47.706462+00', '2017-02-03 01:08:11.427104+00', 6712, 9, 106, '', 'D', 'Freiburg Midwinter Ball 2017.  Music provided by Christine Moos (violin), Ilona Stitz (recorder) und Edwin Werner (Piano)', 1, 1, 'Y', 'nKl4fHFaNWs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2805, '2017-01-27 08:56:00.714165+00', '2017-01-28 01:02:47.704561+00', 5915, 5, 274, '', 'B', 'Burns Supper 2017, Budapest', 1, 1, 'Y', 'cNPpcRrZxD4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2806, '2017-01-27 22:16:54.068752+00', '2017-01-28 01:05:29.58592+00', 4862, 2, 2697, '', 'D', 'Round the room version from 2016 Moscow St Valentine''s Ball', 1, 1, 'Y', 'y1ADvETUkMs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2807, '2017-01-29 16:17:54.385354+00', '2017-01-29 21:08:39.292779+00', 13309, 1, 954, '', 'C', '', 1, 1, 'V', '64432403', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2810, '2017-01-29 21:26:32.40939+00', '2017-01-29 21:26:51.425562+00', 15311, 2, 106, '', 'C', '', 1, 1, 'V', '190669587', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2824, '2017-02-06 10:23:54.104474+00', '2017-02-06 11:24:49.943098+00', 15245, 1, 513, '', 'C', 'Recorded at the Nunspeet weekend, 4-5 february 2017', 1, 1, 'Y', 'OkrMdLU6dTY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2817, '2017-02-03 18:46:22.825596+00', '2017-02-03 18:46:53.015055+00', 17577, 1, 106, '', 'B', 'Danced "once and to the bottom".', 1, 1, 'Y', 'eztIIv7R85s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2813, '2017-01-31 16:43:45.036063+00', '2017-02-04 09:19:07.04861+00', 16527, 3, 106, '', 'B', '', 1, 1, 'Y', 'JJ3BGGCL744', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2811, '2017-01-30 21:03:10.322605+00', '2017-02-04 09:20:06.076206+00', 7465, 2, 106, '', 'D', '', 1, 1, 'Y', 'XrMDxFNlk94', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2822, '2017-02-06 09:43:16.600324+00', '2017-02-06 10:39:42.146184+00', 7637, 2, 513, '', 'C', 'Recorded at the Nunspeet weekend, 4-5 february 2017', 1, 1, 'Y', 'ciUG9W8JSpM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2825, '2017-02-08 03:25:53.113194+00', '2017-02-08 07:44:43.817378+00', 760, 2, 2709, '', 'D', '', 1, 1, 'Y', '-bPO0767p0U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2820, '2017-02-06 09:30:19.70727+00', '2017-02-06 10:53:32.294543+00', 16126, 1, 513, '', 'C', 'Recorded at the Nunspeet weekend, 4-5 february 2017.  The video is preceded by a recap, starting at timer  0.', 1, 1, 'Y', 'AYv3YPQeSTA', 51, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2821, '2017-02-06 09:36:24.834264+00', '2017-02-06 11:04:23.643685+00', 16789, 1, 513, '', 'C', 'Once through only.  Recorded at the Nunspeet weekend, 4-5 february 2017', 1, 1, 'Y', '0D9ilpbjL0g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2819, '2017-02-06 09:22:14.849264+00', '2017-02-06 11:10:24.486441+00', 7375, 2, 513, '', 'C', 'Recorded at the Nunspeet weekend, 4-5 february 2017.  First two bars missing.', 1, 1, 'Y', 'pu4Bjkw6e8o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2823, '2017-02-06 09:52:05.761499+00', '2017-02-06 11:16:45.641845+00', 17186, 1, 513, '', 'C', 'Recorded at the Nunspeet weekend, 4-5 february 2017', 1, 1, 'Y', 'qE6A7FWxCHg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2839, '2017-02-12 14:32:44.350413+00', '2017-06-05 13:35:02.385601+00', 17527, 1, 513, '', 'A', 'This is a 3C/4L dance, but this video is danced in a 3C set.', 1, 1, 'Y', '4ZqzIPA7QzM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2826, '2017-02-09 23:08:11.787155+00', '2017-02-09 23:09:12.671904+00', 16046, 1, 106, '', 'C', 'Recorded during the Lyon November Weekend 2016', 1, 1, 'Y', 'aTBq_is1hTI', 22, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2832, '2017-02-11 14:33:32.722582+00', '2017-02-11 23:28:16.640063+00', 1796, 1, 2447, '', 'B', '', 1, 1, 'Y', 'II_tgLlKyT4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2827, '2017-02-10 02:49:32.007574+00', '2017-02-10 12:39:37.756329+00', 9341, 1, 784, '', 'B', '', 1, 1, 'Y', 'OeLbA_Q6Olk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2969, '2017-04-10 15:44:23.880301+00', '2017-04-10 15:45:54.037106+00', 6057, 3, 160, '', 'B', '', 1, 1, 'Y', 'rJQjR4rk8ls', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2830, '2017-02-11 14:28:52.580248+00', '2017-02-11 23:41:07.137478+00', 10800, 1, 2447, '', 'B', 'Includes voice-over instructions and on-screen crib, but at a public festival and there is a lot of background chatter.', 1, 1, 'Y', 'dMdD5krpyyY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2831, '2017-02-11 14:32:11.936837+00', '2017-02-11 23:53:29.240693+00', 13606, 1, 2447, '', 'D', 'Includes recap. Dance starts on 1:10', 1, 1, 'Y', '7wk1fEsvWDE', 69, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2829, '2017-02-11 00:46:40.2724+00', '2017-02-11 00:50:41.917152+00', 6615, 1, 106, '', 'C', 'Published on 26 Jan 2017  Workshop led by Gary Cuill  8 x 32 danced in a 7-couple set', 1, 1, 'Y', 'FechRwDcXo4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3554, '2018-06-05 13:26:57.207382+00', '2018-06-05 14:45:22.986816+00', 18360, 1, 2824, '', 'A', '', 1, 1, 'Y', 'YgdBLXJDEI4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3552, '2018-06-05 13:14:28.070104+00', '2018-06-05 14:46:41.277621+00', 3422, 3, 2824, '', 'A', '', 1, 1, 'Y', 'ab2IKOzOgFw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3556, '2018-06-05 13:50:59.335297+00', '2018-06-05 14:48:11.586567+00', 18365, 1, 2824, '', 'A', '', 1, 1, 'Y', 'xLYw3Cono9Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2837, '2017-02-12 14:30:33.238289+00', '2017-02-12 18:24:23.731108+00', 17535, 1, 513, '', 'A', '', 1, 1, 'Y', 'fZJ20AGb7mw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2843, '2017-02-12 18:00:53.692888+00', '2017-02-12 18:25:58.469302+00', 1280, 7, 2084, '', 'A', '', 1, 1, 'Y', '0MML3U3_dW8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2841, '2017-02-12 15:01:13.485171+00', '2017-02-12 18:29:14.053862+00', 2244, 1, 513, '', 'C', '', 1, 1, 'Y', 'B9sbwgk0am8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2838, '2017-02-12 14:31:35.566365+00', '2017-02-13 00:33:19.037044+00', 17528, 1, 513, '', 'A', '', 1, 1, 'Y', 'E-UpzE3fUJc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2853, '2017-02-12 18:49:42.905818+00', '2017-02-13 00:43:47.945164+00', 10787, 7, 2084, '', 'A', 'The Chequered Court (Bk42), danced by the International Team ladies, at Newcastle Festival 2017.', 1, 1, 'Y', '9abVdy7_DOE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2851, '2017-02-12 18:35:08.697868+00', '2017-02-13 13:51:06.00303+00', 222, 1, 2084, '', 'A', 'Argyll''s Bowling Green (Bk15), danced by the RSCDS Lyon, Ladies I team, at Newcastle Festival 2017.

', 1, 1, 'Y', 's23OqVfR31E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2833, '2017-02-12 13:51:10.740616+00', '2017-02-13 16:52:53.002992+00', 4461, 1, 513, '', 'A', '', 1, 1, 'Y', 'ZYB-Cw9rQaQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3279, '2017-10-15 15:56:18.262575+00', '2017-10-15 21:28:40.896418+00', 6384, 2, 596, '', 'X', '', 1, 1, 'Y', 'TFiyMsY80eg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2836, '2017-02-12 14:15:39.297113+00', '2017-02-13 15:08:13.650682+00', 2725, 1, 513, '', 'A', 'Newcastle Festival 2017 - Edinburgh Scottish Dancers - Mixed Team - Haig of Bemersyde', 1, 1, 'Y', '5q4k-mb_cBA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2834, '2017-02-12 13:52:46.288951+00', '2017-02-13 16:55:21.072185+00', 4925, 1, 513, '', 'A', '', 1, 1, 'Y', 'EwEEWNAzxLk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2835, '2017-02-12 13:54:36.724141+00', '2017-02-13 16:57:52.051704+00', 5555, 3, 513, '', 'A', '', 1, 1, 'Y', 'Y8_xX1UbxoU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2850, '2017-02-12 18:34:35.314434+00', '2017-02-13 17:14:24.832259+00', 4579, 2, 2084, '', 'A', 'danced by the RSCDS Lyon, Ladies I, at Newcastle Festival 2017.', 1, 1, 'Y', 'Bqm0dOF5vLw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3496, '2018-04-01 18:39:54.584726+00', '2018-04-03 11:39:13.651602+00', 15645, 1, 3086, '', 'A', '', 1, 1, 'Y', 'f3u526Gz6wQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2848, '2017-02-12 18:15:47.603118+00', '2017-02-12 23:43:26.846691+00', 9836, 4, 513, '', 'B', '', 1, 1, 'Y', 'ZH1knKXxqf0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2864, '2017-02-12 19:52:23.323772+00', '2017-02-13 00:28:12.327923+00', 10663, 4, 2084, '', 'A', '', 1, 1, 'Y', '4CFsnxIExnQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2840, '2017-02-12 15:00:12.149314+00', '2017-02-13 00:37:44.297375+00', 17384, 1, 513, '', 'C', 'Ball at 15th anniversary Berlin Hopalots weekend (26.11.2016)', 1, 1, 'Y', 'mObrQZNBnKk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2857, '2017-02-12 19:12:15.649434+00', '2017-02-13 00:41:14.711998+00', 13582, 3, 513, '', 'A', 'The Valientine, danced by the RSCDS Lyon, Saône team, at Newcastle Festival 2017.', 1, 1, 'Y', 'p7MHIWjOGoI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2925, '2017-03-16 15:13:30.456465+00', '2017-03-16 23:54:15.237881+00', 13621, 2, 1041, '', 'B', '', 1, 1, 'Y', 'Mukv15AENRs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2868, '2017-02-12 23:21:04.01354+00', '2017-02-13 00:53:59.088207+00', 1586, 1, 1978, '', 'A', 'Newcastle Festival 2017 - Edinburgh Scottish Dancers - Deacon of the Weavers', 1, 1, 'Y', 'QxeYLTwZwcs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2865, '2017-02-12 23:18:42.67801+00', '2017-02-13 01:09:13.542153+00', 1884, 4, 1978, '', 'A', 'Newcastle Festival 2017 - Edinburgh Scottish Dancers - The Earl of Mansfield', 1, 1, 'Y', '-djI5Xdpm4U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2867, '2017-02-12 23:20:17.584141+00', '2017-02-13 02:16:51.270487+00', 2725, 3, 1978, '', 'A', 'Newcastle Festival 2017 - Edinburgh Scottish Dancers - Mixed Team - Haig of Bemersyde', 1, 1, 'Y', 'HnIGnqzbHxg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2870, '2017-02-12 23:22:49.283523+00', '2017-02-13 02:19:46.822686+00', 9836, 5, 1978, '', 'A', 'Newcastle Festival 2017 - East Scotland Dancers - The Inimitable Derek', 1, 1, 'Y', '2goG6O014M4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2869, '2017-02-12 23:21:56.958856+00', '2017-02-13 02:24:34.839922+00', 6271, 5, 1978, '', 'A', 'Newcastle Festival 2017 East Scotland Dancers Staffin Harvest', 1, 1, 'Y', '5bfsJGmr8eg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2866, '2017-02-12 23:19:40.453755+00', '2017-02-13 02:31:11.052034+00', 4461, 3, 1978, '', 'A', 'Newcastle Festival 2017 - Edinburgh Scottish Dancers - Mixed Team - Miss Dumbreck', 1, 1, 'Y', 't2AupncO1_0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2859, '2017-02-12 19:31:41.626862+00', '2017-02-13 15:05:54.283296+00', 3338, 4, 2084, '', 'A', 'Johnnie''s Welcome Hame (Bk32), danced by the RSCDS Lyon men''s team, at Newcastle Festival 2017.', 1, 1, 'Y', 'GQxkoaSchec', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2871, '2017-02-13 19:03:04.997179+00', '2017-02-13 19:12:57.791651+00', 17578, 1, 106, '', 'B', 'Scottish Country Dancers Dresden, getanzt in Pirna-Liebethal', 1, 1, 'Y', 'Mc57hWEMzcQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2872, '2017-02-13 19:18:46.003109+00', '2017-02-13 19:19:00.939267+00', 17581, 1, 106, '', 'C', 'getanzt in Pirna-Liebethal', 1, 1, 'Y', 'heQc8FMwtb0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2873, '2017-02-15 16:56:45.8429+00', '2017-02-15 18:18:45.848794+00', 13619, 4, 2794, '', 'B', 'RSCDS NZ Branch Christchurch Summer School 2016



Suggesting it because it appears to me to be a little better quality, in how well danced, than the other videos already on the server for this dance.', 1, 1, 'Y', 'BLZ1l6z-OY4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2818, '2017-02-04 08:51:42.911131+00', '2017-02-16 23:26:28.202089+00', 15340, 1, 2254, '', 'B', 'Demonstration Quality in an Informal Social Setting; size of room means camera is necessarily up close but excellent to watch and learn. Thank You Lisbon Lapa ScD Group and Betty McKenzie for devising!



The tune is "The Craven Jig" by the Marian Anderson band.', 1, 1, 'Y', 'sOzP39f1O1I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2874, '2017-02-17 18:43:46.342285+00', '2017-02-18 14:07:06.182325+00', 10918, 1, 1022, '', 'B', 'Once through, at the 2013 Calvin Spring Dance, with Don Bartlett on piano.', 1, 1, 'Y', 'Hxl_efxhY1w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (237, '2012-09-12 06:44:15.49608+00', '2017-02-19 10:05:24.126841+00', 5802, 1, 1041, '', 'Z', 'The music is nearly one bar behind the dancing.



In his leaflet for this dance, Roy Goldring instructs the 2nd couple ONLY to step up on bars 3 and 4.  In this video the 3rd couple steps up too and down again.  That disagrees with the instructions.', 1, 1, 'Y', 't_pHry4NIpI', 320, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2875, '2017-02-24 19:45:17.725061+00', '2017-02-24 19:45:37.187498+00', 17619, 1, 106, '', 'B', 'Demonstration in by Chiswick dancers at Chiswick House of a new dance written for Barbara Martlew by Brian Pearson, July 2013. Tune "Bar''s Lullaby" by Ken and Bar Martlew.', 1, 1, 'Y', 'FtU8SzHM8Tk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2876, '2017-02-25 16:55:49.140441+00', '2017-02-25 16:56:53.37146+00', 17620, 1, 1, '', 'C', '', 1, 1, 'Y', 'o8DEt_dnSnw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2668, '2016-10-07 14:05:47.589448+00', '2017-02-26 23:51:33.02775+00', 16255, 3, 197, '', 'B', 'Filmed during Summer School 2016 for the RSCDS by Red Barn Studios.



Note that this video shows 2nd corners, on bar 32, dancing directly from the half diagonal reel of four

into the left hands across. This is not in the instructions but was unilaterally added by the Summer

School teachers. In fact, the deviser''s original intention was for 2nd corners to finish the half reel of

four and then pivot right about in place to be ready for the left hands across (as seen in the video

from the 2015 Spring Fling).', 1, 1, 'Y', 'BXm0Hp_8-yM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2560, '2016-07-09 13:57:42.812504+00', '2017-02-26 23:55:10.40965+00', 16255, 2, 1041, '', 'B', 'This video would be “demonstration quality” if it used the official music for the dance. The producers of the video can''t be blamed for this because when this video was recorded the official music for the dance hadn''t been picked.', 1, 1, 'Y', 'FYyFTELZVW0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2877, '2017-02-27 00:38:11.288281+00', '2017-02-27 00:38:33.054195+00', 5843, 2, 106, '', 'D', 'Published on 20 Aug 2016', 1, 1, 'Y', 'OCHFiGHhdGI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2878, '2017-02-28 22:23:13.9798+00', '2018-10-02 14:33:00.435129+00', 9169, 2, 596, '', 'X', '', 1, 1, 'Y', 'Fy8GbT5BkYw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2890, '2017-02-28 22:37:38.954112+00', '2018-10-03 22:12:12.934741+00', 12309, 2, 596, '', 'X', '', 1, 1, 'Y', '_jaTKcL1KSI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2896, '2017-03-01 07:23:27.591701+00', '2018-08-05 10:31:48.842788+00', 6405, 2, 106, '', 'X', '', 1, 1, 'Y', 'Cs3sZM-n38g', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2899, '2017-03-01 09:29:27.610987+00', '2018-10-02 14:22:38.637434+00', 1077, 1, 106, '', 'X', '', 1, 1, 'Y', 'OhsRgh3vBTs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2908, '2017-03-01 15:43:22.686473+00', '2017-03-01 16:53:40.036271+00', 16833, 1, 25, '', 'C', '', 1, 1, 'Y', 'LtrWN9ce12Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2970, '2017-04-10 15:58:38.417976+00', '2017-04-10 21:47:24.538193+00', 14567, 1, 2213, '', 'B', '', 1, 1, 'Y', 'suPqmyBX5O8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2909, '2017-03-02 16:08:29.493169+00', '2017-04-01 19:46:08.223744+00', 16963, 1, 513, '', 'C', 'Danced in Lyon en Nov 2016.  Small error: on bars 23-24 all couples should set; here sometimes only 1c+2c set.', 1, 1, 'Y', '-lX6LsC8hgA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2911, '2017-03-03 00:27:23.535389+00', '2017-03-03 00:31:24.647979+00', 17628, 2, 106, '', 'A', 'Published on 13 Jun 2016    Danced by OUSDS: The Oxford University Scottish Dance Society', 1, 1, 'Y', 'K1y-7p4VWoY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2910, '2017-03-03 00:24:42.53922+00', '2017-03-03 00:32:03.14843+00', 17628, 1, 106, '', 'A', 'Published on 17 Jun 2016.  Performed by the Oxford University Scottish Dance Society', 1, 1, 'Y', 'eYDMKAwzCu4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2912, '2017-03-07 00:04:46.029325+00', '2017-03-07 02:06:00.573185+00', 17392, 1, 1330, '', 'A', 'The music written for the dance (in the 1990s?) has unfortunately been mislaid!  Frank Thomson therefore chose suitable tunes for the purposes of this video, which was made at the 2017 Iberian Weekend, where the dance was on the programme. ', 1, 1, 'Y', '_diy-n4_U9M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2936, '2017-03-20 12:49:24.210102+00', '2017-03-20 14:12:03.684613+00', 10920, 8, 2824, '', 'A', 'Only once through ', 1, 1, 'Y', 'UT5XoXuGm00', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2913, '2017-03-07 16:23:45.739203+00', '2017-03-07 16:26:58.402774+00', 17347, 2, 106, '', 'C', 'Dance written for the Marhamchurch Scottish Country Dancers'' Club''s 21st residential weekend in Bude in October 2016. Music provided by Sandy Nixon & his Scottish Dance Band.', 1, 1, 'Y', 'qSq7AcqEo5E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2915, '2017-03-08 21:01:24.102961+00', '2017-03-08 23:30:26.682049+00', 12796, 3, 2482, '', 'B', '', 1, 1, 'Y', 'tmtVtoHEw7g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2916, '2017-03-08 21:04:46.790135+00', '2017-03-08 23:39:25.986079+00', 3783, 2, 2482, '', 'B', '', 1, 1, 'Y', 'GYnINg9Yiis', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2940, '2017-03-22 17:14:39.823624+00', '2017-03-23 01:10:01.480911+00', 9103, 2, 2794, '', 'C', '', 1, 1, 'Y', 'g5IlaUzeATk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2914, '2017-03-07 17:40:10.895836+00', '2017-03-08 23:42:11.751882+00', 6057, 2, 2794, '', 'C', '', 1, 1, 'Y', '1G3MRtOXvw0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2919, '2017-03-10 12:51:53.7125+00', '2017-03-10 12:58:09.10266+00', 6897, 2, 106, '', 'B', '', 1, 1, 'Y', '7SXOZFzKr3M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2918, '2017-03-09 16:26:27.649684+00', '2017-03-10 13:04:34.744558+00', 10256, 1, 2482, '', 'B', '', 1, 1, 'Y', 's8HXnh9o8-Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2920, '2017-03-11 09:46:43.918857+00', '2017-03-11 23:54:18.208491+00', 11606, 1, 3469, '', 'B', '

video from Pat Reesby



''The Lady in Pink'' was danced at the Johnsonville SCD Club''s September tartan night in 2016. The MC was club tutor Rod Downey, who devised this dance.



', 1, 1, 'Y', 'lxZCFLpyRZk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3081, '2017-06-12 13:30:39.16318+00', '2017-06-14 21:53:07.935946+00', 2719, 1, 596, '', 'X', '', 1, 1, 'Y', 'AF7vN8-3fMM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2950, '2017-04-06 21:57:53.565407+00', '2017-04-06 22:11:50.980924+00', 15622, 1, 160, '', 'B', 'Loch Leven Dancers

Music: Feisty Women

Band  The Music Makars

CD:     Catch the Wind (EWO 004 (2006))', 1, 1, 'Y', 'SwQ2HXMptOU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2922, '2017-03-14 10:36:57.399713+00', '2017-03-14 10:38:34.93679+00', 16881, 1, 106, '', 'D', '', 1, 1, 'Y', '2ltf67q2rdk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2923, '2017-03-16 14:57:15.314724+00', '2017-03-16 15:08:19.597986+00', 10428, 1, 1041, '', 'B', '', 1, 1, 'Y', 'HIQPOT6xyjA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2932, '2017-03-16 15:37:05.127977+00', '2017-03-16 17:03:37.689184+00', 8203, 2, 1041, '', 'C', '', 1, 1, 'Y', 'Kn-mttNAV_s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2933, '2017-03-16 15:45:21.549952+00', '2017-03-16 17:03:59.066027+00', 15438, 1, 1041, '', 'B', '', 1, 1, 'Y', 'E9MzudMHbm4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2928, '2017-03-16 15:25:12.801003+00', '2017-03-16 17:08:01.939343+00', 442, 1, 1041, '', 'B', '', 1, 1, 'Y', 'L5DZ6waQuiY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2927, '2017-03-16 15:21:21.246528+00', '2017-03-16 23:48:22.822837+00', 1033, 1, 1041, '', 'C', '', 1, 1, 'Y', 'Or1I0Q8Yyls', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2924, '2017-03-16 15:02:17.917127+00', '2017-03-16 23:50:26.271817+00', 1480, 3, 1041, '', 'B', '', 1, 1, 'Y', 'j4OMm4Z8588', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2926, '2017-03-16 15:18:15.196919+00', '2017-03-16 23:51:39.675869+00', 1535, 2, 1041, '', 'B', '', 1, 1, 'Y', 'QVC_fUA3RYg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2929, '2017-03-16 15:27:59.554732+00', '2017-03-16 23:53:06.122418+00', 1908, 1, 1041, '', 'C', '', 1, 1, 'Y', 'za0GamY41Wk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2931, '2017-03-16 15:34:14.403604+00', '2017-03-16 23:57:19.566196+00', 9087, 2, 1041, '', 'D', '', 1, 1, 'Y', '3lbYh2aj1_0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2930, '2017-03-16 15:30:20.918102+00', '2017-03-16 23:58:55.575285+00', 5160, 1, 1041, '', 'C', '', 1, 1, 'Y', 'GWNpfn5k-Tk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2934, '2017-03-18 17:01:23.911973+00', '2017-03-18 17:39:26.913579+00', 15044, 1, 1041, '', 'B', '', 1, 1, 'Y', 'QwLwPVyfCIc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2935, '2017-03-19 19:40:37.512094+00', '2017-03-19 21:30:25.739187+00', 14548, 3, 2219, '', 'C', 'At the Watford and West Herts Scottish Society Caledonian Ball 2017 with Marian Anderson, Isobel Hodgson and Max Ketchin.



The earlier part of the video is omitted as it does not keep one single set constantly in view, making it impossible to follow the pattern of the dance.', 1, 1, 'Y', 'olGjbE1szR0', 80, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2938, '2017-03-20 13:06:29.977136+00', '2017-03-20 14:07:06.568232+00', 377, 2, 2824, '', 'A', 'Only once through.', 1, 1, 'Y', 'DzMr9MbY0Hw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2937, '2017-03-20 13:02:32.1655+00', '2017-03-20 14:09:21.357983+00', 3365, 7, 2824, '', 'A', 'Only twice through', 1, 1, 'Y', 'YLAVlFt28MI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2939, '2017-03-22 15:33:22.68209+00', '2017-03-23 01:24:05.409383+00', 9634, 1, 2794, '', 'B', 'The video begins with a title mentioning Ian Muir of Prestwick.  I am interpreting this to be the name of the band, not a dance name.  About 15 seconds into the video, the dance title, "The Findlays'' Jig" is provided. 



The video spends much time panning around the room or showing the band.  What is shown here the best we could find, a short section, giving a reasonable impression of the dance once though.', 1, 1, 'Y', '90PAP7p12fQ', 52, 87, NULL);
INSERT INTO 'dancevideo' VALUES (2942, '2017-03-26 23:53:52.319143+00', '2017-03-26 23:54:39.888006+00', 17675, 2, 106, '', 'A', '', 1, 1, 'Y', 'PAQn7wha-GY', 0, 161, NULL);
INSERT INTO 'dancevideo' VALUES (2946, '2017-04-04 03:34:38.695123+00', '2017-04-04 19:19:07.757738+00', 3593, 1, 3809, '', 'B', 'Lady C Bruce''s Reel was on the programme for the Johnsonville SCD Club''s first tartan night of 2016 in Wellington, New Zealand,

The MC was club tutor Rod Downey and live music was supplied by Peter Elmes, Aileen Logie and Don McKay.', 1, 1, 'Y', '6lj3Ha4bhiY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2096, '2015-06-10 10:19:53.149873+00', '2017-04-04 20:06:40.922746+00', 16456, 1, 106, '', 'A', '''Tribute to Alba'' was composed by Yoshiki Oyama for SCD group Alba''s 15 years anniversary.

The members of Alba demonstrated at their anniversary party in March 2015 to the fiddle played by Kana Otake.



Found on Youtube, for this database, this is the first source for this new dance.  June 2015.  Eric', 1, 1, 'Y', 'kU_OJup4cfw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2952, '2017-04-07 06:23:42.760802+00', '2018-10-01 23:35:56.341708+00', 1100, 6, 106, '', 'X', '', 1, 1, 'Y', 'm5lgmVIwKy8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2921, '2017-03-12 01:44:15.832513+00', '2017-04-04 20:08:54.15358+00', 16456, 2, 2273, '', 'A', 'Mixed Team Demonstration.



Published on 11 Mar 2017



''Tribute to Alba'' was written by Yoshiki Oyama for SCD group Alba''s 15 years anniversary.This demonstration was danced at Nikko in Japan to the music played by James Gray and Kana Otake who composed the original tune.', 1, 1, 'Y', 'H7FBu04jxhk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2943, '2017-03-30 18:13:09.311719+00', '2017-03-31 06:07:13.332905+00', 4911, 1, 954, '', 'D', '', 1, 1, 'Y', 'dZjfAwbbYgc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2944, '2017-03-31 20:33:21.852359+00', '2017-04-01 15:42:24.897311+00', 17406, 1, 2821, '', 'A', 'The dance is performed by members of the Newark Scottish Country Dance Society where Pat Harland, the deviser, is a member.  ', 1, 1, 'Y', 'tP-rEvh-Lro', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2945, '2017-03-31 20:35:21.74418+00', '2017-04-01 15:45:05.261282+00', 17405, 1, 2821, '', 'A', 'The dance is performed by members of the Newark Scottish Country Dance Society where Pat Harland, the deviser, is a member.  

', 1, 1, 'Y', 'B8hdkHzlmVs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2954, '2017-04-07 06:27:23.134943+00', '2017-04-07 06:27:40.358182+00', 7284, 6, 106, '', 'X', '', 1, 1, 'Y', 'zSiZBENL9Fw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2947, '2017-04-06 21:55:22.635631+00', '2017-04-06 22:04:15.210648+00', 14017, 1, 160, '', 'B', '', 1, 1, 'Y', 'jiebwAAorwU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2949, '2017-04-06 21:56:59.778645+00', '2017-04-06 22:13:06.760064+00', 140, 3, 160, '', 'B', '', 1, 1, 'Y', 'mZpiw-oe_PE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2956, '2017-04-07 06:30:55.988281+00', '2017-04-07 06:31:13.071541+00', 14533, 6, 106, '', 'X', '', 1, 1, 'Y', '3OcRv-xBU3g', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3007, '2017-04-27 17:36:38.000519+00', '2017-04-27 21:15:49.020722+00', 14496, 1, 2213, '', 'B', '', 1, 1, 'Y', 'GZlts1ez2v8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2958, '2017-04-07 21:47:11.474967+00', '2017-04-07 21:52:31.397836+00', 8855, 1, 106, '', 'B', 'Майская танцевальная школа, г.Владимир, 2014 год. / (May Dance School, Vladimir, Russia, 2014)', 1, 1, 'Y', 'wJusOYRI1vQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2959, '2017-04-07 22:14:52.140694+00', '2017-04-07 22:16:34.963537+00', 10663, 5, 106, '', 'A', 'The University of St Andrews Celtic Society''s ladies team dancing the jig Alan J Smith at Newcastle Festival 2013.', 1, 1, 'Y', 'KLJ_e9xdrrg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2960, '2017-04-10 08:14:53.052172+00', '2017-04-10 14:01:43.162531+00', 5403, 1, 2709, '', 'D', '', 1, 1, 'Y', 'Y_y32VhsaLo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2964, '2017-04-10 14:14:14.211762+00', '2017-04-10 14:15:45.029142+00', 4799, 2, 160, '', 'B', '', 1, 1, 'Y', 'BjcS__Mk7w4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2974, '2017-04-11 21:37:16.869808+00', '2017-04-16 15:04:21.131961+00', 17706, 1, 202, '', 'B', 'Note: the video was assembled by alternating two videos, taken from top and bottom of the set.  They are beautifully linked, but the switches between the two views, occuring at odd moments, are confusing as one cannot follow individual dancers, and so learn the dance from the video.  Let''s hope for a new video that does not switch viewpoints; that would be more useful.  ', 1, 1, 'Y', 'RjiD19fyHoY', 14, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2962, '2017-04-10 09:55:06.739273+00', '2017-04-10 21:54:01.012059+00', 542, 3, 513, '', 'C', 'Lyon SCD WE April 2017



One time through - recorded during the Saturday afternoon class', 1, 1, 'Y', 'v888QKpXXBk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1751, '2014-08-23 08:21:03.166246+00', '2017-04-16 23:35:57.920047+00', 13590, 1, 106, '', 'D', 'This is the ZOOLOGIST dance at Carnoustie on 24 July 2013 with the band of James Coutts playing the music for Scottish Country Dancing at the Beach Hall.



Unfortunately the set most in view is constantly confused.', 1, 1, 'Y', 'y2c20hqWkAo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2961, '2017-04-10 08:59:35.243275+00', '2017-04-10 23:00:29.395752+00', 183, 2, 2709, '', 'D', 'Clearly labelled a ''practice'', this video does give a good idea of the geography of the dance with all formations quite clear except the 4th couple don''t move in with pas de basque. More walked than danced.', 1, 1, 'Y', 'SJKxpLx64mc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2963, '2017-04-10 11:29:53.452316+00', '2017-04-10 23:04:39.434018+00', 15677, 1, 513, '', 'C', 'Published on 10 Apr 2017

Recorded at the Friday night social, during the Lyon Branch SCD Weekend.

Music by Sharlene Penman and Andrew Lyon', 1, 1, 'Y', 'HRUIde8BoIE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2975, '2017-04-13 13:18:31.664472+00', '2017-04-13 23:06:09.491917+00', 10937, 1, 2824, '', 'C', 'First 2 bars missing', 1, 1, 'Y', 'BWf1W6iqE3A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2977, '2017-04-13 13:20:16.036105+00', '2017-04-13 23:11:58.868914+00', 5688, 1, 2824, '', 'C', 'These sets still follow the outdated instructions to make nearly a full turn om [1-2] and [9-10], puttting M below W on the midline.  This makes it nearly impossible to do the associated setting neatly.', 1, 1, 'Y', 'R_N-h25cebg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2976, '2017-04-13 13:19:34.380097+00', '2017-04-13 23:13:11.278102+00', 15308, 1, 2824, '', 'C', '', 1, 1, 'Y', 'WuJBOXl0b0o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3023, '2017-05-09 16:51:51.531765+00', '2017-05-09 20:43:12.217623+00', 9800, 1, 3637, '', 'B', 'Taken from a very long distance.  Three times through in a 3C set, with modified progression (2,3,1).  The turn on [33-34] is not always done correctly.', 1, 1, 'Y', '4_VdbpGLD80', 31, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3029, '2017-05-10 07:17:40.244608+00', '2017-05-10 07:24:42.227807+00', 16488, 1, 106, '', 'A', '', 1, 1, 'Y', 'wfItOx82fFw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3034, '2017-05-10 07:23:40.743532+00', '2017-05-10 07:25:13.55804+00', 16490, 1, 106, '', 'A', '', 1, 1, 'Y', 'F-wtYeplyP0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3206, '2017-08-31 22:44:10.625579+00', '2017-08-31 22:44:50.702965+00', 12669, 3, 106, '', 'X', '', 1, 1, 'Y', 'd9jg-Eijp38', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2981, '2017-04-17 08:51:39.101402+00', '2017-04-17 08:54:54.040986+00', 3748, 1, 106, '', 'Z', 'I have discovered a new video of Lauderdale Lads...sort of!...which I am however NOT going to distribute generally via SCD-SoCal-mail because although it is indeed announced as Lauderdale Lads 

1. it is done as part of a round-the-room medley, 

2. both its beginning and its ending have been altered, 

3. at the end of the men''s LH turn, W2''s step-up has been eliminated, and 

4. within the continuous eight bars of pas-de-basque half of them are not so, and at the end thereof the repositioning has been altered as well!  

Interesting how a dance can (often with good reason) be altered for performance purposes but this is hardly the same dance and certainly of no value whatsoever as an instructional instrument!...and as far as I am concerned the SCD Dictionary (with which I personally have no connection) should not have posted it as Lauderdale Lads, and I am fairly confident that the SCDDB (with which I do enjoy a personal connection) will reject (or perhaps already will have rejected) it as such.  

 

But merely FYI and for interest''s sake, here ''tis...if you set your timing marker at 3:35 you''ll just manage to catch it!

Robb Quint 

', 1, 1, 'Y', 'NuY2ni5MDKw', 218, 0, NULL);
INSERT INTO 'dancevideo' VALUES (385, '2012-12-17 14:17:23.165521+00', '2017-04-17 16:12:20.744775+00', 3791, 1, 1296, '', 'B', 'Twice through in a 3C set, with the progression adjusted when starting the second time.', 1, 1, 'Y', 'Pv3wLkxMFvE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2978, '2017-04-16 00:28:54.00771+00', '2017-04-16 00:30:09.078763+00', 8778, 1, 106, '', 'A', 'Vancouver RSCDS Demonstration Team, St Andrew''s Ball,  November 22, 2014', 1, 1, 'Y', 'yScKjwa2xYk', 0, 150, NULL);
INSERT INTO 'dancevideo' VALUES (2979, '2017-04-16 00:46:10.605017+00', '2017-04-16 01:18:00.5152+00', 13497, 2, 106, '', 'A', 'Second part of a demo by the Vancouver RSCDS Demonstration Team, St Andrew''s Ball, 22 November 2014.



Danced in two 3C sets, joined bottom to bottom, which rearranges itself from 6 longwise to 6 crosswise after first time through.  After the second time through the finals bars have been modified to make a transition into a 6C square set for the next dance,', 1, 1, 'Y', 'yScKjwa2xYk', 180, 260, NULL);
INSERT INTO 'dancevideo' VALUES (2982, '2017-04-17 15:12:51.856117+00', '2017-04-17 16:18:46.256637+00', 14201, 1, 513, '', 'C', '', 1, 1, 'Y', 'WdmNTdqBkJQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2989, '2017-04-25 17:10:32.835147+00', '2017-04-25 17:43:44.175669+00', 2084, 1, 2482, '', 'B', '', 1, 1, 'Y', 'I0dL7TNxDYc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2984, '2017-04-17 15:52:05.579439+00', '2017-04-17 16:26:48.616731+00', 6614, 1, 513, '', 'C', 'In this video the dance is performed as a S32+R32 medley, four times through. The dance description says “This may also be danced as a strathspey”, so doing it as a medley is only logical in order to give each dancing couple the opportunity to experience it both ways.



Recorded at the Kuckucksnest, 14 April 2017. Music (a spur-of-the-moment arrangement) played by Anselm Lingnau.', 1, 1, 'Y', 'mHzpTK1hgZw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2983, '2017-04-17 15:24:08.581032+00', '2017-04-17 16:30:34.654691+00', 13604, 1, 513, '', 'B', '', 1, 1, 'Y', 'MCWfD4kxL-w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2980, '2017-04-16 01:22:50.563398+00', '2017-04-18 00:37:01.564536+00', 14262, 1, 106, '', 'A', 'Twice through.  Third part of a demo by Vancouver RSCDS Demonstration Team, St Andrew''s Ball, 22 November 2014 ', 1, 1, 'Y', 'yScKjwa2xYk', 260, 340, NULL);
INSERT INTO 'dancevideo' VALUES (2988, '2017-04-24 15:12:30.463371+00', '2017-04-24 15:13:02.006113+00', 16499, 1, 106, '', 'A', '', 1, 1, 'Y', '_kKiXGqUsX4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2986, '2017-04-24 10:42:54.759598+00', '2017-04-24 15:24:36.56319+00', 2372, 2, 2824, '', 'C', '', 1, 1, 'Y', 'gOlYUX_AwBE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2985, '2017-04-24 10:42:10.652191+00', '2017-04-24 15:46:25.642207+00', 13602, 1, 2824, '', 'D', '', 1, 1, 'Y', 'bnVfnyBZ-rU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2987, '2017-04-24 10:47:47.971385+00', '2017-04-24 15:54:52.338113+00', 445, 11, 2824, '', 'C', 'Slightly confusing w. several sets in view - adequate incarnation of the apparent chaos of a beehive ;-)', 1, 1, 'Y', 'q0tUvjLq8dw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3000, '2017-04-26 07:49:18.469416+00', '2017-04-26 10:59:56.105351+00', 17474, 1, 81, '', 'A', '', 1, 1, 'Y', '3BPq2X7j9hc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2992, '2017-04-26 07:44:07.020865+00', '2017-04-26 11:02:46.316729+00', 17466, 1, 81, '', 'A', '', 1, 1, 'Y', 'tQPRlo_lUrs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2997, '2017-04-26 07:47:28.598482+00', '2017-04-26 11:06:08.458218+00', 17471, 1, 81, '', 'A', '', 1, 1, 'Y', 'mqPJd5LoGJM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2993, '2017-04-26 07:44:47.068586+00', '2017-04-26 11:08:49.144935+00', 17467, 1, 81, '', 'A', '', 1, 1, 'Y', 'JgYQcveZoPQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2994, '2017-04-26 07:45:24.453217+00', '2017-04-26 11:10:51.532277+00', 17468, 1, 81, '', 'A', '', 1, 1, 'Y', 'mtNVERCYL5g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3004, '2017-04-26 07:51:57.771401+00', '2017-04-26 11:25:59.978471+00', 17478, 1, 81, '', 'A', '', 1, 1, 'Y', 'lF-AmYIdIEI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2995, '2017-04-26 07:46:08.612181+00', '2017-04-26 11:27:41.827612+00', 17469, 1, 81, '', 'A', '', 1, 1, 'Y', 'ANkpDFkmBBM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3002, '2017-04-26 07:50:29.368024+00', '2017-04-26 11:41:18.75174+00', 17476, 1, 81, '', 'A', '', 1, 1, 'Y', 'koLkN85jPko', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3006, '2017-04-26 11:17:42.030237+00', '2017-04-26 11:43:36.608035+00', 14809, 1, 81, '', 'D', 'The dancers take allemande hold rather than promenade hold in the last 8 bars.  The caller blocks part of the view at times.', 1, 1, 'Y', 'Pc3MV31FKVg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2991, '2017-04-26 07:43:20.591978+00', '2017-04-26 13:24:51.928425+00', 17465, 1, 81, '', 'A', '', 1, 1, 'Y', 'qZclfLO778Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2990, '2017-04-26 07:42:18.449283+00', '2017-04-26 13:43:19.42345+00', 17464, 1, 81, '', 'A', '', 1, 1, 'Y', 'U2w-5kRt6c0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3005, '2017-04-26 07:54:02.638801+00', '2017-04-26 13:45:53.869414+00', 780, 2, 2482, '', 'B', '', 1, 1, 'Y', '5a8uu02pCqI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2996, '2017-04-26 07:46:44.537761+00', '2017-04-26 13:48:17.417896+00', 17470, 1, 81, '', 'A', '', 1, 1, 'Y', 'NRQ9dhoC-Rk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2998, '2017-04-26 07:48:14.869815+00', '2017-04-26 13:49:50.204101+00', 17472, 1, 81, '', 'A', '', 1, 1, 'Y', 't1q32vxdOPs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3003, '2017-04-26 07:50:56.222479+00', '2017-04-26 14:03:13.646495+00', 17477, 1, 81, '', 'A', '', 1, 1, 'Y', 'jGdnjZgkhok', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2999, '2017-04-26 07:48:47.305748+00', '2017-04-26 14:06:06.941585+00', 17473, 1, 81, '', 'A', '', 1, 1, 'Y', 'nsCe1ppJjeA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3001, '2017-04-26 07:49:52.459957+00', '2017-04-26 14:09:13.518821+00', 17475, 1, 81, '', 'A', '', 1, 1, 'Y', '-qaXS84yvNM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3009, '2017-04-27 21:21:26.943753+00', '2017-04-27 21:23:31.919851+00', 5437, 1, 106, '', 'B', '', 1, 1, 'Y', 'us3RPPUxh9E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3010, '2017-04-27 23:35:13.430689+00', '2017-04-28 00:46:54.505147+00', 8063, 1, 1330, '', 'B', 'Twice through.  Done in a five-couple set, rather than the usual four-couple set. ', 1, 1, 'Y', '0QffOhWneQ8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3011, '2017-04-30 23:11:13.466311+00', '2017-04-30 23:13:25.460137+00', 8526, 1, 106, '', 'C', 'Video Published on 6 Mar 2017.  Vancouver Island Scottish Country Dance Society, Mar 2017.     http://viscds.ca/', 1, 1, 'Y', 'ENwPNktoOj4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3012, '2017-05-01 16:07:53.267939+00', '2017-05-01 20:28:36.601568+00', 13590, 3, 2482, '', 'B', '', 1, 1, 'Y', 'JDwHwAeZRqE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3013, '2017-05-02 22:07:59.724545+00', '2017-05-02 22:24:27.859561+00', 16460, 1, 274, '', 'C', 'Budapest, 2017.05.01', 1, 1, 'Y', 'PDt8AvApgaQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3014, '2017-05-06 00:03:34.436138+00', '2017-05-06 00:06:02.44303+00', 3031, 1, 106, '', 'B', 'Middle part of a longer demo.  Twice through.  On the second time, 1c take opposite sides after the rondel to finish the dance (2,1x,3) for the beginning of the following demo section.  Danced at the 1987 Pacific Grove Concert.', 1, 1, 'Y', 'F8OORiTtq0o', 160, 283, NULL);
INSERT INTO 'dancevideo' VALUES (3016, '2017-05-07 00:25:04.189996+00', '2017-05-07 02:08:09.465019+00', 17133, 2, 1330, '', 'D', '', 1, 1, 'Y', 'xD4u6fox9Bs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3017, '2017-05-07 16:36:42.336819+00', '2017-05-07 16:58:37.285743+00', 17140, 5, 1121, '', 'A', '', 1, 1, 'Y', 'j_D25CBvNGo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3015, '2017-05-06 23:15:33.194229+00', '2017-05-08 07:11:23.329881+00', 14649, 2, 106, '', 'D', 'Part of a long event.  Once through only.', 1, 1, 'Y', 'A2tnfX8k2MQ', 2211, 2275, NULL);
INSERT INTO 'dancevideo' VALUES (3018, '2017-05-08 06:31:09.973127+00', '2017-05-08 07:20:00.922153+00', 4563, 1, 513, '', 'C', 'Recorded at the Sunday morning class during the 10th Ann. Weekend of the Budapest SCD club in May 2017.

Music by Phill Jones', 1, 1, 'Y', 'egI4fw9Q2q0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3019, '2017-05-08 13:32:16.660718+00', '2017-05-08 14:13:29.862962+00', 9581, 1, 274, '', 'C', 'Workshop, SCD Weekend, Budapest, 2017

Two (and a half) times trough :-)', 1, 1, 'Y', 'RXrFioruHGM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3479, '2018-03-16 16:23:05.5492+00', '2018-03-31 23:04:26.471741+00', 14983, 1, 106, '', 'C', ' Danced by the Orange County Branch of the RSCDS on February 10, 2018, at the Senior Center, in Tustin, CA.   

The beginning of the video was truncated; the video now starts at 3nd time through,', 1, 1, 'Y', '_sdzQlSWdoM', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3024, '2017-05-09 16:58:18.834731+00', '2017-05-09 20:29:14.128004+00', 9800, 2, 3637, '', 'A', 'The Red Thistle Dancers performing Artistic Director Jennifer Kelly''s dance Scallywag.

Danced twice through in a 3C set, progression modified to (2,3,1)', 1, 1, 'Y', 'JmcelyNN1yU', 1310, 1399, NULL);
INSERT INTO 'dancevideo' VALUES (3021, '2017-05-09 12:44:13.345011+00', '2017-05-09 21:04:56.73691+00', 5658, 1, 2824, '', 'C', 'Welcome Dance at the 10th Jubilee Scottish Country Dance Weekend in Budapest, 5.5.2017

Musicians: Muriel Johnstone and Keith Smith', 1, 1, 'Y', 'B4wlRxDlOmA', 17, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3025, '2017-05-09 17:00:39.185466+00', '2017-05-09 22:17:48.093251+00', 11438, 1, 3637, '', 'D', 'Danced in a 4C set, only six times through, the last two times being missing.  The 3rd time through shows only the musicians.  The set is uncertain about this dance, and makes several errors.  The 5th and 6th times through (starting on 2:28) are the best.', 1, 1, 'Y', 'WGp3LJ6_af0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3027, '2017-05-09 23:55:34.538128+00', '2017-05-10 07:10:12.12441+00', 16495, 1, 106, '', 'A', '', 1, 1, 'Y', 'daQnbE1-OAw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3028, '2017-05-09 23:56:38.391909+00', '2017-05-10 07:13:12.417555+00', 16489, 1, 106, '', 'A', '', 1, 1, 'Y', 'UUjqn4b4mAA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3026, '2017-05-09 23:52:29.967185+00', '2017-05-10 07:13:41.339092+00', 16493, 1, 106, '', 'A', '', 1, 1, 'Y', '-Nri6PgGDEU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3032, '2017-05-10 07:20:14.3561+00', '2017-05-10 07:28:03.161896+00', 16497, 1, 106, '', 'A', '', 1, 1, 'Y', '8lzDBbr7xhA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3031, '2017-05-10 07:19:12.119691+00', '2017-05-10 07:28:20.576066+00', 16498, 1, 106, '', 'A', '', 1, 1, 'Y', 'dwL5mymE7qI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3036, '2017-05-10 07:34:24.744973+00', '2017-05-10 08:26:27.88714+00', 16491, 1, 106, '', 'A', '', 1, 1, 'Y', 'LAbaaRcyNn0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3037, '2017-05-10 07:36:22.994003+00', '2017-05-10 08:32:41.636146+00', 16496, 1, 106, '', 'A', '', 1, 1, 'Y', 'Gc6hHNuenZc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3039, '2017-05-10 07:44:25.883979+00', '2017-05-10 08:34:10.59206+00', 2398, 1, 2824, '', 'D', 'Camera wanders between sets halfway through the dance and briefly to the band', 1, 1, 'Y', '9qBAsZ-XhUA', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3038, '2017-05-10 07:37:03.575503+00', '2017-05-10 08:36:40.454663+00', 9286, 4, 2824, '', 'B', '', 1, 1, 'Y', 'MhB93JWRx3c', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3040, '2017-05-10 13:40:56.508583+00', '2017-05-10 16:04:05.619532+00', 16461, 2, 2824, '', 'C', '', 1, 1, 'Y', '_rPWxa0q9y0', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3041, '2017-05-10 14:54:23.089109+00', '2017-05-10 17:47:11.331191+00', 5398, 1, 513, '', 'C', '', 1, 1, 'Y', '3yrt-AiOYyg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3042, '2017-05-11 11:56:12.70633+00', '2017-05-12 21:04:41.657371+00', 6972, 3, 2824, '', 'D', '', 1, 1, 'Y', 's4PuAW2Y09k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3044, '2017-05-14 08:12:23.750483+00', '2017-05-14 10:01:21.387483+00', 4646, 7, 2709, '', 'A', 'Excellent dancing, but a poor video, taken against bright light from a window behind, so that at the beginning the dancers can hardly be distinguished.  Towards the end some parts are better.  



', 1, 1, 'Y', 'sGRQfYOsvPI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3043, '2017-05-13 18:23:22.683705+00', '2017-05-13 23:47:33.853191+00', 7239, 1, 954, '', 'D', 'Dufftown Dance Club - 07/04/2017

Music from Colin Dewar and Gus Millar', 1, 1, 'Y', 'RppoblIror0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3523, '2018-04-24 14:37:47.018173+00', '2018-04-24 14:49:38.10697+00', 183, 3, 106, '', 'X', '', 1, 1, 'Y', 'ahKgQ3veQP4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3045, '2017-05-15 15:18:27.002948+00', '2017-05-15 15:57:42.720921+00', 14484, 4, 2824, '', 'D', 'Danced at the Ball of the 10th Jubilee Scottish Country Dance Weekend in Budapest, 6.5.2017

Musicians: Muriel Johnstone and Keith Smith', 1, 1, 'Y', 'aLtlgQRtZBA', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3046, '2017-05-15 15:19:26.555621+00', '2017-05-15 16:01:17.026591+00', 2604, 5, 2824, '', 'D', 'First dance at the Ball of the 10th Jubilee Scottish Country Dance Weekend in Budapest, 6.5.2017

Musicians: Muriel Johnstone and Keith Smith', 1, 1, 'Y', 'WB_w_mK32yw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3047, '2017-05-18 10:06:49.01951+00', '2017-05-18 13:43:38.35887+00', 13689, 1, 57, '', 'C', 'Shows the band for part of the dance', 1, 1, 'Y', '3WpnBZHmYbM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3049, '2017-05-24 22:53:41.89696+00', '2017-05-24 23:09:11.527784+00', 17760, 1, 2220, '', 'A', 'Performed at the San Francisco branch monthly Party in Mountain View in April 2017.  This was the inital presentation to the honorees - Janet and Roy Hayter

', 1, 1, 'Y', 'Vxry4mz9qBI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3050, '2017-05-24 22:57:34.742841+00', '2017-05-24 23:09:37.875163+00', 17760, 2, 2220, '', 'D', 'This is the assembled party-goers dancing after a demo and talk-through.  The honoree Roy Hayter is the man in the orange shirt in the center of the room, dancing with his daughter-in-law, Joy Hayter.  The band was better acquainted with the tune in this version than in the demo video. ', 1, 1, 'Y', '22ZN6KjGr2g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3054, '2017-05-25 18:06:46.448211+00', '2017-05-26 00:24:59.786669+00', 15051, 1, 2824, '', 'D', 'RSCDS Vienna Branch - Saturday Dance 20.5.2017

Musician: David Hall', 1, 1, 'Y', 'UIWxTri1JIg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3053, '2017-05-25 17:59:29.49244+00', '2017-05-26 16:22:02.391058+00', 5199, 1, 2824, '', 'D', 'RSCDS Vienna Branch - Saturday Dance 20.5.2017

Musician: David Hall', 1, 1, 'Y', 'DS3V9_dDYJo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3055, '2017-05-27 14:39:00.750843+00', '2017-05-27 15:21:13.383679+00', 2956, 3, 1041, '', 'Z', 'In this display all couples have replaced the "half turn partner" on bars [5-6] and [13-14] with setting.  

That makes the couples end up on the correct places at the end, but the dancing is just wrong. This error makes the video useless for the database, so I have blocked it.  Eric', 1, 1, 'Y', 'jyLQJsyNzHk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3058, '2017-05-27 20:58:33.014608+00', '2017-05-27 21:14:14.40153+00', 9939, 1, 1041, '', 'B', '', 1, 1, 'Y', '4snZzr3DWXo', 50, 128, NULL);
INSERT INTO 'dancevideo' VALUES (3056, '2017-05-27 19:54:50.87729+00', '2017-05-27 21:17:19.2753+00', 2453, 3, 1041, '', 'C', '', 1, 1, 'Y', '4qlegDrREek', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3059, '2017-05-27 21:16:59.608469+00', '2017-05-28 15:02:12.959798+00', 16728, 1, 1041, '', 'C', 'The first "set" is missing.  Twice through.', 1, 1, 'Y', 'UcjaeQPlolk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3057, '2017-05-27 20:28:09.752853+00', '2017-05-27 23:43:27.220309+00', 1207, 1, 1041, '', 'C', 'Demonstration.  Don Mills Social Group,  Toronto Gala Day, May 2016.  Danced 4 times through as "once and to the bottom".  On the final bars 1c dances to 4th place (4c steps up) instead of casting to 2nd place.', 1, 1, 'Y', 'yHB6xw9qSZA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3091, '2017-06-12 22:26:35.814122+00', '2017-06-13 20:58:53.521852+00', 17757, 1, 1645, '', 'C', 'View from the bottom of this Gay Gordons set with a deliberate choice of all possible gender combinations dancing together: M+M, W+W, M+W, W+M. Those dancing as men start on the left. Basically correct albeit with a few extra turns and quickly corrected false starts.

', 1, 1, 'Y', 'IFMXKIQo5-U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3060, '2017-06-02 19:49:07.830814+00', '2017-06-04 21:04:52.646539+00', 14738, 2, 1041, '', 'B', 'Recorded at the Saturday morning class during the Easter Course 2017 at the "Kuckucksnest"', 1, 1, 'Y', '4W1e5e6CD2s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3090, '2017-06-12 22:24:05.343469+00', '2017-06-13 21:02:16.314209+00', 17755, 1, 1645, '', 'C', 'View from the bottom of the set. Those dancing as men are wearing bands. Things start to go wrong towards the end of the 2nd repeat and the rest is faded out to spare further blushes.', 1, 1, 'Y', 'AyDoO7lFP9o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3092, '2017-06-14 16:58:33.213884+00', '2017-06-14 17:01:55.819718+00', 17768, 1, 2697, '', 'B', 'Deviser is present on the video', 1, 1, 'Y', '32svTSpUDYc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3062, '2017-06-05 10:10:40.273903+00', '2017-06-05 10:13:23.186843+00', 17524, 1, 106, '', 'B', '', 1, 1, 'Y', 'soYdZIwTAYE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3063, '2017-06-05 10:14:28.072073+00', '2017-06-05 10:15:59.094968+00', 17526, 1, 106, '', 'B', '', 1, 1, 'Y', '8mp_ZzUuhxc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3083, '2017-06-12 13:32:49.053182+00', '2017-06-14 21:51:02.749763+00', 1529, 1, 596, '', 'X', '', 1, 1, 'Y', 'xOYHGWpTpFk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3086, '2017-06-12 13:36:50.54362+00', '2017-06-14 21:51:30.39381+00', 1799, 2, 596, '', 'X', '', 1, 1, 'Y', 'hYzir88Chz8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3088, '2017-06-12 13:40:06.054524+00', '2017-06-14 21:51:45.564688+00', 2257, 1, 596, '', 'X', '', 1, 1, 'Y', 'oPBrQByVnjA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3067, '2017-06-05 10:28:16.436956+00', '2018-04-10 16:09:49.24664+00', 17538, 1, 106, '', 'A', '', 1, 1, 'Y', 'wh_zNXH7_e8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3069, '2017-06-05 10:39:08.18135+00', '2017-06-05 10:39:47.474008+00', 17530, 1, 106, '', 'B', '', 1, 1, 'Y', 'yYtUeLds4Nk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3070, '2017-06-05 10:45:08.024474+00', '2017-06-05 10:46:23.690442+00', 17531, 1, 106, '', 'B', '', 1, 1, 'Y', 'QgWKANqOPJg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3071, '2017-06-05 10:47:30.560326+00', '2017-06-05 10:48:42.721245+00', 17532, 1, 106, '', 'B', '', 1, 1, 'Y', '-HVxSheDHSQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3072, '2017-06-05 10:49:56.512088+00', '2017-06-05 10:50:07.58651+00', 17533, 1, 106, '', 'B', '', 1, 1, 'Y', 'wksFWSdc3zQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3074, '2017-06-05 11:51:09.054408+00', '2017-06-05 11:53:09.788769+00', 17537, 1, 106, '', 'B', '', 1, 1, 'Y', 'PHBbWnBC824', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3073, '2017-06-05 11:48:41.575145+00', '2017-06-05 11:53:37.794207+00', 17536, 1, 106, '', 'B', '', 1, 1, 'Y', '3w3D68zo_qU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3061, '2017-06-05 10:06:46.708075+00', '2017-06-05 13:35:23.532721+00', 17523, 1, 106, '', 'B', 'This is a 3C/4L dance, but this video is danced in a 3C set.', 1, 1, 'Y', '8eO6ukxYo7Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3068, '2017-06-05 10:34:54.870916+00', '2017-06-05 14:16:55.15722+00', 17781, 2, 2821, '', 'B', 'Nimbus 2017 at Wellow Maypole Celebrations 29 May 2017.  Music used: Silver Roses played by Sandy Nixon.', 1, 1, 'Y', 'spnZx8YsH5w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3082, '2017-06-12 13:31:51.241087+00', '2017-06-14 21:52:02.003445+00', 14843, 1, 596, '', 'X', '', 1, 1, 'Y', 'sDPNZwD8ocw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3066, '2017-06-05 10:26:26.466472+00', '2017-06-05 14:34:36.069638+00', 17781, 1, 2821, '', 'B', 'Waltham Scottish Country Dance Group at the ASCDS Festival, Nottingham 06 May 2017.  Music: Neil Barron and his Band.



', 1, 1, 'Y', 'Lhzttw0lNCA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3075, '2017-06-05 14:24:35.909862+00', '2017-06-05 14:34:56.450794+00', 17781, 3, 106, '', 'B', 'Performance Of Nimbus 2017 - Waltham Scottish Country Dance Group, ASCDS Festival, Nottingham, 2017.

Music By Neil Barron And His Band. ', 1, 1, 'Y', 'qv4O62mhrs0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3076, '2017-06-05 15:25:53.958352+00', '2017-06-05 15:28:07.377885+00', 17781, 4, 106, '', 'B', 'Waltham Scottish Country Dance Group at the ASCDS Festival, Nottingham 06 May 2017. Music: Neil Barron and his Band.', 1, 1, 'Y', 'dSyr0OJAW8g', 70, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3077, '2017-06-11 21:15:11.341277+00', '2017-06-11 23:14:58.588622+00', 2024, 1, 954, '', 'B', '', 1, 1, 'Y', 'wQd996MZWR0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3080, '2017-06-12 13:29:25.956686+00', '2017-06-14 21:53:33.546116+00', 3918, 1, 596, '', 'X', '', 1, 1, 'Y', '_B2l5y3a_7I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3084, '2017-06-12 13:34:11.824352+00', '2017-06-14 21:54:02.069966+00', 4366, 1, 596, '', 'X', '', 1, 1, 'Y', 'S5dyVDbmhUc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3085, '2017-06-12 13:35:16.594391+00', '2017-06-14 21:54:27.067164+00', 5616, 1, 596, '', 'X', '', 1, 1, 'Y', 'm8V34opjm3A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3089, '2017-06-12 18:31:28.49594+00', '2017-06-14 21:54:53.674388+00', 10381, 4, 596, '', 'X', 'This is a correction. The previous danciemaetion should be deleted.', 1, 1, 'Y', 'uZqnyw4hcTc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3087, '2017-06-12 13:38:06.001743+00', '2017-06-14 21:55:11.032243+00', 6720, 2, 596, '', 'X', '', 1, 1, 'Y', 'Sx2y3BoLj30', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3078, '2017-06-12 13:26:20.453272+00', '2017-06-14 21:55:56.180566+00', 6736, 1, 596, '', 'X', '', 1, 1, 'Y', 'lfKrh99DQu8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3079, '2017-06-12 13:28:02.244156+00', '2017-06-14 21:56:27.540062+00', 7533, 1, 596, '', 'X', '', 1, 1, 'Y', 'nOrwxG8d684', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3095, '2017-06-15 23:07:06.475428+00', '2017-06-16 09:02:03.816457+00', 3996, 2, 106, '', 'B', 'There are lots of great videos of Scottish country dances available, and I use them quite frequently if I want some details about a dance.



But those video always show the dance from the outside and do not catch a dancer''s point of view. And dancing is so much nicer when you are part of the set rather than watching from the sideline.



I wanted to make a video, which is shot from the inside and provides some immersion feeling. We ran through the dance more than a dozen times and I collated one version from all the takes. I did not succeed of really catching a single dancer''s perspective, as the clip from the body cameras were too hectic; but I like the result well enough to share.



(Source: Strathspey posting of the creator of the video)', 1, 1, 'Y', 'kpJSHGLGTH8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3093, '2017-06-15 11:16:48.196046+00', '2017-06-15 19:46:59.818272+00', 15098, 3, 2824, '', 'C', 'Contains some variations; danced according to description until bar 48 and for bars 81 - 88, but:

in bars 49 - 64 it''s the Grand Chain+Setting (which should be in bars 65 - 80)

in bars 65 - 80 there''s arches+setting, where the description (for bars 49 - 64) specifies couples dancing past each other w. slip-step+BH turn



Wearing/not wearing the yellow sash is not distinguishing W from M.



Cockermouth Scottish Country Dance Club dancing in Workington prior to the 4 nations Scotland/New Zealand rugby league match November 2016.  For more details visit www.derwentscdc.com', 1, 1, 'Y', 'Y4UwPf-3rlo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3094, '2017-06-15 13:28:32.44374+00', '2017-06-15 22:28:11.656587+00', 10298, 2, 1041, '', 'B', '', 1, 1, 'Y', 't_vm54-1nrg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3065, '2017-06-05 10:22:44.921078+00', '2018-04-10 16:01:17.833227+00', 17529, 1, 106, '', 'A', '', 1, 1, 'Y', 'GVq4QkV6SgA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3100, '2017-06-23 05:20:15.046069+00', '2017-06-23 05:22:38.849649+00', 15440, 1, 106, '', 'D', 'The dance is shown here the last two times through at the launch party at Clarke Memorial Hall, Mississauga, for the CD Coast To Coast by Scotch Mist. ', 1, 1, 'Y', 'YVqPqIAitIE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3102, '2017-06-25 02:59:15.612648+00', '2017-06-25 03:01:03.624269+00', 13070, 1, 106, '', 'C', 'Danced in june 2017 at St Clement''s social group''s "Last Night Treat" -- closing the season with stylish playing by Don Bartlett. The venue is The Great Hall of Bishop Strachan School. BSS is exactly as old as Canada.', 1, 1, 'Y', 'BhjRaJIXl0A', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3096, '2017-06-20 08:01:56.568121+00', '2017-06-30 06:44:59.989124+00', 17137, 2, 2824, '', 'D', 'Ball at the Hamburg Weekend Course, 3.6.2017

Musician: Fred Moyes', 1, 1, 'Y', 'bCp6Fvlt93c', 9, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3104, '2017-06-26 00:36:28.816846+00', '2017-06-30 06:06:02.042149+00', 8568, 1, 1055, '', 'C', '', 1, 1, 'Y', 'tXmzj_LGBLc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3099, '2017-06-21 12:13:49.534211+00', '2017-06-30 06:16:24.896559+00', 16792, 1, 81, '', 'C', '', 1, 1, 'Y', 'YbSNX9ocAF8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3098, '2017-06-20 08:08:57.555895+00', '2017-06-30 07:17:52.159607+00', 984, 2, 2824, '', 'D', 'Less than ideal camera angle and crowded dancefloor makes things a bit confusing

Social Dance at the Hamburg Weekend Course, 2.6.2017

Musician: Fred Moyes', 1, 1, 'Y', 'wCUzf35HhRU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3103, '2017-06-26 00:34:36.399715+00', '2017-06-30 07:02:13.371067+00', 12835, 1, 1055, '', 'C', '', 1, 1, 'Y', 'YCri9qNm9wY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3525, '2018-05-02 15:26:07.726916+00', '2018-05-02 18:17:56.135959+00', 18266, 1, 14561, '', 'A', '', 1, 1, 'Y', 'JprVpkLMq_w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3524, '2018-05-02 15:24:22.367796+00', '2018-05-02 18:13:55.72401+00', 18265, 1, 14561, '', 'A', '', 1, 1, 'Y', 'NG0CkrDwIB8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3555, '2018-06-05 13:45:38.659663+00', '2018-06-05 14:47:20.151395+00', 3637, 2, 2824, '', 'A', 'Twice through', 1, 1, 'Y', '3e14OVGfpd8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3114, '2017-06-30 04:34:12.611918+00', '2017-06-30 04:36:32.198812+00', 17882, 1, 106, '', 'B', 'Once through only.', 1, 1, 'Y', 'il6GyApzYHM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3115, '2017-06-30 04:40:23.347367+00', '2017-06-30 04:41:24.413404+00', 17882, 2, 106, '', 'B', 'Outdoor display on grass.  26 June 2017.  Danced by the RSCDS Toronto Demo Pool.', 1, 1, 'Y', 'UVmgeiBX1r0', 25, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3113, '2017-06-29 22:05:21.286384+00', '2017-06-30 05:57:16.684114+00', 738, 1, 2220, '', 'C', 'Braes of Atholl performed by the Berkeley CA adjudication Team at the Pleasanton Highland Games 2012, led by Bruce Herbold the dancers are Greg Wilcox, Madge Tsang, Gary Knox, Witsie MacElvey, Bex Clark, Amanda Whitehead, Paula Buell and Jane Samuelson', 1, 1, 'Y', 'bwLS5Gqd13o', 138, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3107, '2017-06-27 22:17:58.711025+00', '2017-06-30 06:09:54.403613+00', 8568, 2, 186, '', 'C', 'Danced at 2016 Asilomar Workshop, hosted by the San Francisco Branch, Royal Scottish Country Dance Society.', 1, 1, 'Y', 'Nbn0k7b6Iy0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3097, '2017-06-20 08:05:07.811678+00', '2017-06-30 06:42:51.912001+00', 10788, 1, 2824, '', 'D', 'Social Dance at the Hamburg Weekend Course, 2.6.2017

Musician: George Meikle', 1, 1, 'Y', 'AgcliVHJ2Ck', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3106, '2017-06-26 14:54:46.245584+00', '2017-06-30 06:56:14.678327+00', 2745, 1, 2824, '', 'C', '2nd time through 6H round becomes 4H round, 4th time through 1st couple birls instead of turn BH, 7th+8th time through 1st woman casts round 2nd man to end between the 2s rather than step up in the middle of the set.



Ball at the Hamburg Weekend Course, 3.6.2017

Musician: George Meikle', 1, 1, 'Y', 'h4HNiumS9qw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3112, '2017-06-29 22:03:54.782244+00', '2017-06-30 07:04:07.494212+00', 4442, 1, 2220, '', 'C', 'Miss Cahoon''s Reel performed by the Berkeley CA adjudication Team at the Pleasanton Highland Games 2012, led by Bruce Herbold the dancers are Greg Wilcox, Madge Tsang, Gary Knox, Witsie MacElvey, Bex Clark, Amanda Whitehead, Paula Buell and Jane Samuelson', 1, 1, 'Y', 'bwLS5Gqd13o', 0, 137, NULL);
INSERT INTO 'dancevideo' VALUES (3124, '2017-07-06 10:33:46.644288+00', '2017-07-06 10:54:34.354859+00', 4366, 2, 2219, '', 'C', 'The set in the foreground has 5 couples but this video is 8x32', 1, 1, 'Y', 'Sg0H0kDr4fg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3118, '2017-07-04 21:38:42.442764+00', '2017-07-07 10:26:59.150877+00', 9009, 1, 1332, '', 'B', '', 1, 1, 'Y', '_l4r5TMvo1A', 0, 176, NULL);
INSERT INTO 'dancevideo' VALUES (3126, '2017-07-06 10:57:52.366318+00', '2017-07-07 10:31:23.547557+00', 15000, 1, 2219, '', 'B', 'At 00:36 lady at top should dance only a half reel of three

', 1, 1, 'Y', 'D07KQ8yb0T0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3127, '2017-07-06 11:02:53.473494+00', '2017-07-07 10:32:35.009118+00', 15000, 2, 2219, '', 'C', '', 1, 1, 'Y', 'ChfpYHeWvj8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3119, '2017-07-04 21:41:46.746603+00', '2017-07-07 20:23:36.10638+00', 1390, 1, 1332, '', 'B', 'Danced only within 2 couples set.  Normal situation would be 4 couple set.', 1, 1, 'Y', '4zZeaLSlei4', 0, 66, NULL);
INSERT INTO 'dancevideo' VALUES (3277, '2017-10-15 15:52:54.965843+00', '2017-10-15 21:24:49.76547+00', 754, 4, 596, '', 'X', '', 1, 1, 'Y', 'aDPwxxsIBmU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3280, '2017-10-15 15:57:53.289205+00', '2017-10-15 21:28:58.791859+00', 6771, 1, 596, '', 'X', '', 1, 1, 'Y', 'BUExX782Yqc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3105, '2017-06-26 00:37:57.898555+00', '2023-02-19 10:06:44.473218+00', 1283, 1, 1055, '', 'D', 'Asilomoar Weekend, 2016', 1, 1, 'Y', 'IOhETQMVguI', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3117, '2017-07-04 21:36:09.608786+00', '2021-05-27 23:24:43.823581+00', 15339, 1, 1332, '', 'B', 'Two times through.



The music does not appear to be syncrhonised.', 1, 1, 'Y', 'nHDXxXNo29w', 13, 71, NULL);
INSERT INTO 'dancevideo' VALUES (3125, '2017-07-06 10:49:36.097825+00', '2017-07-07 20:26:00.248514+00', 3538, 1, 2219, '', 'B', 'At 01:58 for double figures of eight, Couple in 3rd place should cast off and Couple in 4th place should cross up

At 02:11 the entry for the Rondel should be more fluid

At 03:08 for the double figures of eight, man in 3rd Man''s position should cast off

At 04:08 for the half rights and lefts, lady in 1st Man''s position should cross

At 04:34 the entry for the Rondel should be more fluid

At 04:39 in the Rondel, ladies should use nearer hand ', 1, 1, 'Y', 'vFUhKOMD7gA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3121, '2017-07-04 22:44:44.913615+00', '2017-07-07 20:26:59.97863+00', 15341, 2, 1330, '', 'A', 'Once through only; video starts one bar late.', 1, 1, 'Y', 'om09viQ4tzU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3130, '2017-07-15 21:00:21.860734+00', '2017-07-16 14:26:20.275185+00', 13602, 2, 2287, '', 'B', '', 1, 1, 'Y', 'R2leOaclN6s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3131, '2017-07-15 21:01:25.26004+00', '2017-07-16 14:27:56.478106+00', 13598, 1, 2287, '', 'B', '', 1, 1, 'Y', 'xXv0XQCJPjA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3132, '2017-07-15 21:02:14.179966+00', '2017-07-16 14:30:32.370027+00', 13597, 1, 2287, '', 'B', '', 1, 1, 'Y', '-Bk3bako4eo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3133, '2017-07-15 21:03:04.487499+00', '2017-07-16 14:32:42.580584+00', 13275, 1, 2287, '', 'B', '', 1, 1, 'Y', 'fhjp7rtOgaE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3138, '2017-07-15 21:08:18.029544+00', '2017-07-16 14:35:28.300855+00', 2135, 1, 2287, '', 'B', '', 1, 1, 'Y', 'zL7i1ig65XE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3134, '2017-07-15 21:03:46.473045+00', '2017-07-16 14:38:04.106262+00', 13610, 1, 2287, '', 'B', '', 1, 1, 'Y', '3aQxpGxCpLE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3128, '2017-07-10 23:19:04.213451+00', '2017-07-16 14:39:37.145477+00', 2401, 1, 1332, '', 'B', '', 1, 1, 'Y', 'B5TkxPJoFF8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3135, '2017-07-15 21:04:34.38645+00', '2017-07-16 14:42:22.407901+00', 13601, 1, 2287, '', 'B', '', 1, 1, 'Y', '8Rj3l1tx4x0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3136, '2017-07-15 21:05:23.014344+00', '2017-07-16 14:43:27.193357+00', 13606, 2, 2287, '', 'B', '', 1, 1, 'Y', 'vkVG17kioko', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3137, '2017-07-15 21:06:23.591629+00', '2017-07-16 14:45:34.361592+00', 13609, 2, 2287, '', 'B', '', 1, 1, 'Y', 'BkwbHX1ro9g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3152, '2017-07-18 08:31:19.941689+00', '2017-07-18 08:37:06.554769+00', 2437, 6, 2824, '', 'A', '4 times through', 1, 1, 'Y', 'ZIexn2cfYEk', 45, 301, NULL);
INSERT INTO 'dancevideo' VALUES (3153, '2017-07-18 08:36:00.112847+00', '2017-07-18 08:41:04.98877+00', 1543, 3, 2824, '', 'A', '4 times through', 1, 1, 'Y', 'ZIexn2cfYEk', 308, 454, NULL);
INSERT INTO 'dancevideo' VALUES (3159, '2017-07-23 20:58:52.078029+00', '2017-07-23 20:59:19.925586+00', 1495, 1, 106, '', 'D', 'Sandy Nixon and his band, with guest Ian Robertson, perform Dagmar''s Fancy, at the Watford Caledonian Ball



A rather full dance floor makes it hard to see the boundaries between the sets.', 1, 1, 'Y', '-vlhmcRPtkM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3148, '2017-07-18 07:41:42.514215+00', '2017-07-24 20:23:53.790603+00', 5904, 5, 2824, '', 'A', '3 times through', 1, 1, 'Y', 'PME2-zdMvA0', 35, 225, NULL);
INSERT INTO 'dancevideo' VALUES (3142, '2017-07-16 21:24:47.953455+00', '2017-07-24 20:06:18.973731+00', 280, 2, 2287, '', 'B', '', 1, 1, 'Y', 'mvKE45kNzEg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3146, '2017-07-17 10:40:20.081017+00', '2017-07-24 20:07:55.99097+00', 658, 2, 513, '', 'C', '', 1, 1, 'Y', 'gyvgn96QN7U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3147, '2017-07-17 10:41:52.248101+00', '2017-07-24 20:08:57.035278+00', 658, 3, 513, '', 'C', '', 1, 1, 'Y', 'OE9DI7qOn44', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3155, '2017-07-22 12:42:01.936817+00', '2017-07-24 20:10:47.409647+00', 15276, 1, 513, '', 'C', '', 1, 1, 'Y', 'KCoOhctxCiA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3143, '2017-07-17 10:20:03.578545+00', '2017-07-24 20:11:56.80565+00', 8105, 1, 513, '', 'C', '', 1, 1, 'Y', 'Wt258yQlLoc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3145, '2017-07-17 10:34:45.884579+00', '2017-07-24 20:13:11.940423+00', 1884, 5, 513, '', 'B', 'view from the top, dance 1x through for 1st cpl.', 1, 1, 'Y', 'rPl2R4G0ujo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3150, '2017-07-18 07:53:24.102877+00', '2017-07-24 20:15:43.447531+00', 3609, 1, 2824, '', 'A', '4 times through', 1, 1, 'Y', 'c7PZ6FuPo2Y', 35, 180, NULL);
INSERT INTO 'dancevideo' VALUES (3139, '2017-07-16 21:21:58.359563+00', '2017-07-24 20:22:00.420703+00', 5980, 2, 2287, '', 'B', 'This video shows a demontration medley of Seagreen and Two Furlongs interlinked; this has required major changes to the dances.', 1, 1, 'Y', 'yj_qEeP2djI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3149, '2017-07-18 07:45:46.068282+00', '2017-07-24 20:27:03.695578+00', 3862, 3, 2824, '', 'A', '3 times through, starting from 2nd place in a 3 cpl-set', 1, 1, 'Y', 'PME2-zdMvA0', 238, 350, NULL);
INSERT INTO 'dancevideo' VALUES (3151, '2017-07-18 08:03:24.811869+00', '2017-07-24 20:25:57.172787+00', 4629, 2, 2824, '', 'A', '4 times through, occasional wobble in the corners pass and turn', 1, 1, 'Y', 'c7PZ6FuPo2Y', 195, 443, NULL);
INSERT INTO 'dancevideo' VALUES (3140, '2017-07-16 21:23:09.844571+00', '2017-08-23 16:46:33.982802+00', 2581, 1, 2287, '', 'B', '', 1, 1, 'Y', '9Om0g_tJUrw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3157, '2017-07-22 13:21:53.081025+00', '2017-07-24 21:10:05.939739+00', 13887, 1, 513, '', 'C', '', 1, 1, 'Y', 'F_VkmOfRhAY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3156, '2017-07-22 13:05:53.506112+00', '2017-08-23 16:42:55.746944+00', 13894, 2, 513, '', 'B', 'Recorded at a class during the Summer Course 2017 at the „Kuckucksnest“ in Schlüchtern/Germany.', 1, 1, 'Y', 'XE3TAgyRRNA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3162, '2017-07-26 11:56:49.46347+00', '2017-07-27 00:26:15.451191+00', 15402, 3, 2824, '', 'A', '4 times through', 1, 1, 'Y', 'sqB7WEoYxUI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3161, '2017-07-26 11:51:39.56142+00', '2017-07-31 15:10:29.255103+00', 17133, 3, 2824, '', 'A', '4 times through', 1, 1, 'Y', '2wwimeaLyk0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3160, '2017-07-26 11:17:33.403941+00', '2017-07-31 15:14:12.948133+00', 2353, 4, 2824, '', 'A', '4 times through', 1, 1, 'Y', 'ciiJQmizjno', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3164, '2017-07-31 10:42:16.031377+00', '2017-07-31 15:18:55.680155+00', 2494, 2, 2824, '', 'C', '', 1, 1, 'Y', '55M3YbpWfNQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3163, '2017-07-31 10:14:48.689357+00', '2017-07-31 22:05:52.429333+00', 10232, 2, 2824, '', 'C', 'Encore, each couple dances once.', 1, 1, 'Y', 'Mheu8IYS-MU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3158, '2017-07-22 13:32:30.113802+00', '2017-08-18 10:54:04.371944+00', 15239, 1, 513, '', 'C', '', 1, 1, 'Y', 'Hb9rNBf9My0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3261, '2017-09-30 19:58:01.893166+00', '2017-09-30 21:19:14.115102+00', 14076, 1, 1041, '', 'C', '', 1, 1, 'Y', 'fqDYwBI3k6o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3419, '2018-01-31 10:15:33.927603+00', '2018-01-31 16:58:30.878446+00', 14633, 2, 274, '', 'B', 'part 2 of the demonstration at Burns Supper 2018, Budapest ', 1, 1, 'Y', 'EQDUiDmbKjI', 166, 276, NULL);
INSERT INTO 'dancevideo' VALUES (3165, '2017-07-31 11:01:30.449673+00', '2017-07-31 21:54:48.110076+00', 2494, 3, 2824, '', 'B', 'Video point of view changes between sets half-way through the dance, also when it zooms in it becomes a partial portrayal of the dance.', 1, 1, 'Y', 'x1Js6A9qA9w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3166, '2017-08-01 15:25:43.270465+00', '2017-08-01 19:15:11.194198+00', 15000, 3, 2219, '', 'B', 'See comments made when uploading a video from a different angle https://youtu.be/D07KQ8yb0T0', 1, 1, 'Y', 'wueqvJhv0co', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3167, '2017-08-01 15:31:12.695713+00', '2017-08-02 03:47:25.693467+00', 3538, 2, 2219, '', 'B', 'See comments for video from different angle https://youtu.be/vFUhKOMD7gA', 1, 1, 'Y', 'lvcZI91peXE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3172, '2017-08-03 21:04:53.532295+00', '2017-08-04 15:19:29.502162+00', 10792, 2, 596, '', 'X', '', 1, 1, 'Y', '5ZEcnvnDvYk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3176, '2017-08-15 13:07:24.514877+00', '2017-08-15 13:09:44.923304+00', 5198, 3, 106, '', 'B', 'Toronto AGM 2016.  4 x through.', 1, 1, 'Y', '55H2bmfIPvA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3178, '2017-08-15 13:36:35.11865+00', '2017-08-15 13:40:14.180093+00', 1777, 3, 106, '', 'A', 'Middle part of a demo; twice through only.', 1, 1, 'Y', 'BZ91Md1ZRwk', 104, 225, NULL);
INSERT INTO 'dancevideo' VALUES (3179, '2017-08-15 13:45:06.040262+00', '2017-08-15 13:47:03.80256+00', 1280, 9, 106, '', 'A', 'Final part of the LEX dance demo 1,  2014', 1, 1, 'Y', 'BZ91Md1ZRwk', 224, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3180, '2017-08-15 15:20:01.896112+00', '2017-08-15 15:24:33.991551+00', 3834, 5, 106, '', 'A', 'First dance of a demo.  Twice through.', 1, 1, 'Y', 'BZ91Md1ZRwk', 31, 104, NULL);
INSERT INTO 'dancevideo' VALUES (3181, '2017-08-18 12:22:05.920586+00', '2017-08-18 16:28:17.587679+00', 14001, 1, 513, '', 'C', '', 1, 1, 'Y', 'tRAqWu-p4D4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3154, '2017-07-22 11:45:51.778306+00', '2017-08-18 16:32:34.645697+00', 15244, 1, 513, '', 'C', 'Both for bars 5-8 and 25-28 the couples make 1 3/4 LH turns.  The instructions say 3/4 turns. ', 1, 1, 'Y', '9y3d0JaJm34', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3527, '2018-05-03 21:45:21.644138+00', '2018-05-05 09:46:41.027005+00', 18238, 1, 1645, '', 'B', '', 1, 1, 'Y', 'cHTdTQcv1Ww', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3568, '2018-06-08 16:26:57.070619+00', '2018-06-10 10:49:33.841738+00', 9882, 1, 954, '', 'D', '', 1, 1, 'Y', 'CfS1gU821es', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3584, '2018-06-30 10:19:41.806763+00', '2018-06-30 19:49:47.817762+00', 684, 2, 513, '', 'B', '', 1, 1, 'Y', 'LUFLaGL1z10', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3190, '2017-08-20 07:26:20.843164+00', '2017-08-20 07:26:34.76271+00', 17920, 1, 106, '', 'C', 'Devised in honour of Désirée''s 70th birthday, Monday 14/8/2017.', 1, 1, 'Y', 'X_1A-i0otTY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3191, '2017-08-20 11:21:17.944408+00', '2017-08-20 11:24:47.082315+00', 1469, 2, 197, '', 'A', 'Dancers from the DAA class, Summer School 2017, tutored by Ruby Wilkinson.  Music by Edwin Werner and Ilona Stitz.', 1, 1, 'Y', 'wL-Fn3iN-W0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3192, '2017-08-20 16:00:51.576977+00', '2017-08-20 16:01:12.205628+00', 3397, 2, 106, '', 'D', '', 1, 1, 'Y', 'uTmqLd_sLiM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3193, '2017-08-21 14:23:44.733522+00', '2017-08-21 14:49:14.493889+00', 14985, 1, 2824, '', 'B', 'Boys'' Brigade Hall - St. Andrews, 8.8.2017

Music: Jim Lindsay and his Band', 1, 1, 'Y', 'y1nGsqXlI6M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3175, '2017-08-03 21:08:55.831226+00', '2017-08-21 21:59:25.437072+00', 7204, 6, 596, '', 'X', '', 1, 1, 'Y', 'oQl-OFcb7AQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3198, '2017-08-22 19:36:27.785324+00', '2017-08-23 13:04:28.493279+00', 8739, 1, 2482, '', 'B', '', 1, 1, 'Y', 'uawuf0Z39IY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3197, '2017-08-22 19:35:15.800301+00', '2017-08-23 13:10:20.660357+00', 905, 2, 2482, '', 'B', '', 1, 1, 'Y', 'O2pkXuNjFtM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3174, '2017-08-03 21:08:12.701149+00', '2017-08-23 16:13:28.636476+00', 6386, 3, 596, '', 'X', '', 1, 1, 'Y', 'O7_ZgMj2VNQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3194, '2017-08-21 14:25:56.772714+00', '2017-08-23 16:32:15.311689+00', 4324, 2, 2824, '', 'D', 'Younger Hall - St. Andrews, 7.8.2017

Music: Ian Muir & Judith Muir', 1, 1, 'Y', 'ML4cKKKuKwo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3195, '2017-08-21 14:27:40.21962+00', '2017-08-23 16:35:46.886708+00', 1469, 3, 2824, '', 'B', 'Younger Hall - St. Andrews, 10.8.2017

Music: Marian Anderson''s Scottish Country Dance Band', 1, 1, 'Y', 'ZJ8okJMCkPs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3170, '2017-08-03 21:03:23.269217+00', '2017-08-23 16:36:14.949558+00', 13391, 2, 596, '', 'X', '', 1, 1, 'Y', '5ZF_ov8S75E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3171, '2017-08-03 21:04:10.259698+00', '2017-08-23 16:43:28.448686+00', 17137, 3, 596, '', 'X', '', 1, 1, 'Y', 'Z7Xj-yZF9WA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3177, '2017-08-15 13:18:48.35761+00', '2017-08-23 16:44:10.487757+00', 1777, 2, 106, '', 'B', 'Published on 31 Oct 2016



This is a teaching video of a Scottish Country Dance. There are audio and on screen instructions and a bar counter. The dancers wear numbered coloured tabards so that the learner can follow a particular dancer through the dance.

The Ochil Scottish Country Dancers videoed this dance in June 2016 at St Ninian''s Church Hall, Stirling, Scotland. ', 1, 1, 'Y', 'dntyw1tx6xE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2397, '2016-03-06 22:12:24.338745+00', '2017-08-28 21:29:36.460053+00', 1330, 2, 106, '', 'A', 'Published on 6 Mar 2016



Instructional Country Dance video by Chiswick Scottish Country Dance Club London



Note: the instructions tell 2c to step up on [9-10].  In the video they step up on [1-2]', 1, 1, 'Y', 'HRxG7iQAOr4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3183, '2017-08-19 12:04:39.478128+00', '2017-08-30 22:15:02.119741+00', 17896, 1, 2213, '', 'A', 'The final few bars have been adapted to fit a longer demonstration.', 1, 1, 'Y', 'sMiCKYvfQBM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3208, '2017-09-01 12:45:59.499279+00', '2017-09-01 19:17:40.851935+00', 10790, 3, 1041, '', 'B', 'Part of a demonstration.  First time through, bars 27-32 are modified to reform the set across the hall.

Second time through is danced across the hall.', 1, 1, 'Y', 'OJxN4TYhA-M', 301, 376, NULL);
INSERT INTO 'dancevideo' VALUES (3203, '2017-08-30 22:27:25.085662+00', '2017-09-01 05:38:24.969955+00', 17898, 1, 106, '', 'C', 'Third part of a demo at Summer School 2017, 3rd week.  Third part of a longer demo.  Two 3C sets, botttom to bottom.  Twice through, the last 4 bars being modified for the transition.', 1, 1, 'Y', 'w41gBaw0W6s', 202, 270, NULL);
INSERT INTO 'dancevideo' VALUES (3204, '2017-08-30 22:33:20.391925+00', '2017-08-30 22:35:27.212355+00', 17897, 1, 106, '', 'A', 'Part of a longer demo.  Summer School 2017, 3rd week.  Twice through, the final bars being modified for the transition.', 1, 1, 'Y', 'w41gBaw0W6s', 83, 202, NULL);
INSERT INTO 'dancevideo' VALUES (3182, '2017-08-19 11:14:05.410036+00', '2017-08-30 22:44:32.083885+00', 17893, 1, 2213, '', 'A', 'The last few bars of the recording have been adapted to fit a longer demonstration.', 1, 1, 'Y', 'aczE8NGLUOc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3184, '2017-08-19 13:24:07.717319+00', '2017-08-30 22:55:33.661517+00', 17892, 1, 2213, '', 'A', 'This 3 couple dance has been adapted here for 4 couples.', 1, 1, 'Y', 'qswoGa1i7E0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3202, '2017-08-30 22:18:00.081442+00', '2017-09-01 05:35:57.135345+00', 17896, 2, 106, '', 'C', 'Once only; final part of a longer demo, Summer School 2017 3rd week', 1, 1, 'Y', 'w41gBaw0W6s', 270, 308, NULL);
INSERT INTO 'dancevideo' VALUES (3205, '2017-08-30 22:37:51.264649+00', '2017-09-01 21:57:38.330347+00', 9486, 1, 106, '', 'C', 'Start of a longer demo.  Summer School 2017 3rd week.  Two 2C sets, bottom to bottom.  As the "lead down and up" of [17-24] then would collide, bars [19-20] were adapted.  Twice through.  Final bars modified for the transition.', 1, 1, 'Y', 'w41gBaw0W6s', 0, 84, NULL);
INSERT INTO 'dancevideo' VALUES (3210, '2017-09-04 06:40:31.675186+00', '2017-09-04 06:45:02.667567+00', 4784, 2, 106, '', 'B', '', 1, 1, 'Y', 'jq_0ovwy8nI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3207, '2017-09-01 12:37:03.909546+00', '2017-09-01 12:48:15.334104+00', 6380, 2, 1041, '', 'B', 'First part of a longer demo.  Once through only.  Bars 79-88 have been changed to make the link to the next dance.', 1, 1, 'Y', 'OJxN4TYhA-M', 64, 174, NULL);
INSERT INTO 'dancevideo' VALUES (3255, '2017-09-29 14:35:27.721226+00', '2017-09-29 22:45:18.729401+00', 1615, 5, 596, '', 'X', 'A corrected video. The previous danciemaetion video has been removed.', 1, 1, 'Y', 'g81oS51UT-k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3209, '2017-09-02 13:08:27.580287+00', '2017-09-04 22:45:36.314741+00', 17630, 1, 513, '', 'A', 'RSCDS Winter School 2017 - Danced as Medley, twice through:  S32 + R32. ', 1, 1, 'Y', 'ofml194ZYNs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3265, '2017-10-03 23:22:29.968316+00', '2017-10-04 14:51:18.390957+00', 312, 5, 106, '', 'D', '2013 Banksia Ball  in Gosford, New South Wales (with ongoing squaredancesque calling, which you may possibly find helpful).  Banksia is a genus of about 170 species of exotic-looking native Australian flowering plants.', 1, 1, 'Y', 'VoZS-yrtyms', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3212, '2017-09-04 09:41:26.525029+00', '2017-09-04 11:14:51.363628+00', 4111, 1, 1645, '', 'C', 'Once through excerpt from a demonstration medley with two sets joined at 1st couple.



There are two modifications to the dance:

(1) on bars 1-2 the two 1st couples join hands to set together instead of singly;

(2) on bars 33-36 the 2nd and 3rd couples continue to set advancing through the other set instead of finishing at the top of their own set.

', 1, 1, 'Y', 'yScKjwa2xYk', 543, 622, NULL);
INSERT INTO 'dancevideo' VALUES (3313, '2017-11-14 19:14:00.911255+00', '2017-11-14 19:14:21.967919+00', 17140, 6, 106, '', 'B', 'Nottingham RSCDS team performing at ASCDS Festival in Nottingham on 06 May 2017.  

Music: Neil Barron and his Band.', 1, 1, 'Y', 'QB8OCWSAUEw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1099, '2013-08-18 10:47:56.226231+00', '2017-09-24 13:40:50.914145+00', 1562, 2, 1296, '', 'D', 'REJECTED.  "artistic" views from the side, blow, feet above, alternating so the overview is lost. Dancing is Ceilidh style, using elbow hold in turns and by some in the reels. No value in SCDDB', 1, 1, 'Y', 'S1iE_NTFhcQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3213, '2017-09-04 15:36:43.224037+00', '2017-09-04 22:30:50.659397+00', 3046, 1, 2824, '', 'C', '8 times through.  The sets shown in the 4th, 5th and 6th times through dance a variation for bars 13-16: crossing down between the 3s and casting up round them rather than crossing LH and casting off one place to lead up.



*******************

Younger Hall - St. Andrews, 12.8.2017

Week 4 RSCDS Summer School

Music: Sandy Nixon and his Scottish Dance Band', 1, 1, 'Y', '2EgTlTA9TsY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3217, '2017-09-10 21:44:19.646248+00', '2017-09-10 21:44:35.846606+00', 4808, 2, 106, '', 'A', '4 times through.', 1, 1, 'Y', 'y9IB6OOlQwU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3218, '2017-09-11 12:49:20.860809+00', '2017-09-11 13:34:11.876049+00', 2421, 1, 513, '', 'A', '', 1, 1, 'Y', 'fAlCJGetNHM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3263, '2017-10-03 23:17:04.121665+00', '2017-10-04 14:51:39.327976+00', 312, 3, 106, '', 'X', 'New version', 1, 1, 'Y', 'u7LDlY6ZMOU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3241, '2017-09-27 08:59:29.811588+00', '2017-09-27 09:17:12.480547+00', 17948, 2, 274, '', 'B', 'The dance was a present for the first couple, from the third man :-)

', 1, 1, 'Y', 'Yi31cTxQDCI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3220, '2017-09-11 12:52:18.274425+00', '2017-09-11 13:41:35.109539+00', 12635, 2, 513, '', 'B', '', 1, 1, 'Y', 'EylxeQp8NI8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3214, '2017-09-06 16:38:53.813499+00', '2017-09-11 13:46:05.656343+00', 377, 3, 2824, '', 'C', 'Crowded dancefloor makes the dance somewhat hard to follow

Younger Hall - St. Andrews, 7.8.2017

Week 4 RSCDS Summer School, Music: Ian Muir & Judith Muir', 1, 1, 'Y', 'uuazuqhouGo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3215, '2017-09-06 16:43:57.416218+00', '2017-09-11 13:54:07.645161+00', 109, 4, 2824, '', 'D', 'Younger Hall - St. Andrews, 10.8.2017, Week 4 RSCDS Summer School

Music: Marian Anderson''s Scottish Country Dance Band', 1, 1, 'Y', 'C7ECLL-LLeE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3216, '2017-09-06 16:49:39.691278+00', '2017-09-11 13:56:56.226177+00', 10535, 6, 2824, '', 'D', 'Younger Hall - St. Andrews, 10.8.2017

Music: Marian Anderson''s Scottish Country Dance Band', 1, 1, 'Y', 'dwKILXmEOUI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3222, '2017-09-15 16:44:45.097186+00', '2017-09-15 16:45:41.059823+00', 1495, 2, 106, '', 'B', '', 1, 1, 'Y', 'dopaUmZoAMs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3223, '2017-09-17 13:38:47.763908+00', '2017-09-18 07:21:23.95702+00', 13467, 1, 954, '', 'C', '', 1, 1, 'Y', 'YZ4fj-9zFOU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3221, '2017-09-14 13:20:54.234124+00', '2017-09-18 09:01:55.708373+00', 2389, 1, 954, '', 'B', '', 1, 1, 'Y', 'BWfhjADUuh4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3224, '2017-09-22 12:02:56.810217+00', '2017-09-22 12:06:16.010935+00', 17781, 5, 2821, '', 'A', 'Nimbus 2017, a dance medley based on the game of Quidditch, written by Vicky Goodloe and dedicated to the Waltham Scottish Country Dance Group, performed at the Waltham Charter Fair on 16 Sept 2017.', 1, 1, 'Y', '5XmApWDgwtE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3247, '2017-09-28 06:30:49.891464+00', '2017-09-28 07:50:47.340068+00', 17769, 1, 117, '', 'C', 'Devised as a tribute to the late Jay Fourie.  Filmed in Fish Hoek, Cape Town, May 2016.', 1, 1, 'Y', '0YBQcgffeCU', 39, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3225, '2017-09-22 15:52:19.690688+00', '2017-09-22 19:13:44.232513+00', 9638, 7, 1330, '', 'B', '', 1, 1, 'Y', '_6QTOu6HbL0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3231, '2017-09-23 12:20:13.086228+00', '2017-09-24 13:42:47.468077+00', 1562, 5, 8372, '', 'D', 'Instructions for Reelers.', 1, 1, 'Y', '3m_ZuXddYz0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3235, '2017-09-23 12:30:56.136815+00', '2017-09-23 16:51:37.369624+00', 17308, 1, 3129, '', 'A', '', 1, 1, 'Y', '8TgZwv84RME', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3281, '2017-10-15 15:59:38.041048+00', '2017-10-15 21:29:37.500122+00', 8083, 1, 596, '', 'X', '', 1, 1, 'Y', 'W3T4K-5mORI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3228, '2017-09-23 11:52:21.817589+00', '2017-09-23 22:45:22.035114+00', 6535, 1, 8372, '', 'D', 'Danced by Reelers.  The dance differs from the RSCDS dance of the same name.', 1, 1, 'Y', 'UOINViLwuyQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3229, '2017-09-23 11:58:16.225299+00', '2017-09-23 22:47:09.149575+00', 6233, 1, 8372, '', 'D', 'Aberdonian style Inverness Country Dance, instructional tutorial by Reelers.  The dance differs from the RSCDS dance of the same name.', 1, 1, 'Y', 'rFEXQfgNCLQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3226, '2017-09-22 16:23:02.818346+00', '2017-09-27 09:23:59.415528+00', 17948, 1, 106, '', 'C', '', 1, 1, 'Y', 'VePpipeiPt0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3237, '2017-09-25 14:30:01.10589+00', '2017-09-25 16:41:12.62003+00', 4355, 1, 3159, '', 'B', 'Danced by members of the Leicester Branch Demonstration Team', 1, 1, 'Y', 'XfMXI11fR7c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3227, '2017-09-23 11:46:46.200228+00', '2017-09-23 22:59:07.487182+00', 6130, 2, 8372, '', 'C', 'Instructional tutorial by Reelers.  The dance differs from the RSCDS dance of the same name.', 1, 1, 'Y', '794lY0vV7OA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3230, '2017-09-23 12:13:39.282964+00', '2017-09-23 23:20:02.25481+00', 5525, 16, 8372, '', 'Z', 'Aberdonian style instructions, instructional tutorial by Reelers.  The dance differs from the RSCDS dance of the same name.', 1, 1, 'Y', 'Lk_tpP8oRSY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3219, '2017-09-11 12:51:05.640232+00', '2018-09-04 13:11:04.307427+00', 15044, 2, 513, '', 'B', '', 1, 1, 'Y', 'bzS8pTX6h9g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3233, '2017-09-23 12:24:55.267771+00', '2017-09-24 13:38:36.189627+00', 1792, 9, 8372, '', 'D', 'Instructional tutorial by Reelers.  The dance differs from the RSCDS dance of the same name.', 1, 1, 'Y', '3JNdCZqmbaU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3239, '2017-09-26 11:19:49.724558+00', '2017-09-26 18:43:43.204632+00', 13584, 1, 513, '', 'C', 'Dancers performing Christine M Phillips at the 2017 Tartan Ball, organised by the Brighton & Hove Scottish Country Dance Club. Music by Craigievar.', 1, 1, 'Y', '__rMBDjGoAM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3232, '2017-09-23 12:22:41.123802+00', '2017-09-24 13:39:18.78943+00', 1782, 7, 8372, '', 'D', 'Instructions for Reelers.', 1, 1, 'Y', 'GM6s4-cZk74', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3234, '2017-09-23 12:27:01.482181+00', '2017-09-24 13:40:10.851927+00', 2317, 6, 8372, '', 'D', 'Instructional tutorial by Reelers.  The dance differs from the RSCDS dance of the same name.', 1, 1, 'Y', 'Stl5jaQ5uWI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3240, '2017-09-26 11:20:39.117011+00', '2017-09-26 19:06:20.769322+00', 9856, 1, 513, '', 'C', 'Dancers performing the Farm House Jig at the 2017 Tartan Ball, organised by the Brighton & Hove Scottish Country Dance Club. Music by Craigievar.', 1, 1, 'Y', 'Qmf9Nlg9XS0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3238, '2017-09-26 11:18:50.644487+00', '2017-09-26 19:10:45.800994+00', 13614, 1, 513, '', 'C', 'Dancers performing The Spinnaker Tower at the 2017 Tartan Ball, organised by the Brighton & Hove Scottish Country Dance Club. Music by Craigievar. ', 1, 1, 'Y', 'TrqfkQIDv_I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1027, '2013-08-18 00:51:58.603743+00', '2017-09-27 22:16:54.719823+00', 445, 7, 1296, '', 'A', 'Mixed team dancing "The Bees of Maggieknockater" at the Singapore St. Andrew''s Ball, 2011', 1, 1, 'Y', '7zDVlqjfH20', 26, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3242, '2017-09-27 14:41:58.047722+00', '2017-09-27 22:34:09.244669+00', 16774, 1, 117, '', 'B', '', 1, 1, 'Y', 'j3WISKpsDmY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3243, '2017-09-27 14:44:01.783097+00', '2017-09-27 22:37:50.696216+00', 10548, 2, 117, '', 'B', 'TAY DANCERS "The Waternish Tangle" 12/05/2015', 1, 1, 'Y', 'qUuJAHZSyrM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3246, '2017-09-27 14:52:48.296269+00', '2017-09-27 22:43:49.526322+00', 10820, 2, 117, '', 'C', '', 1, 1, 'Y', 'D8KEm_D5EPg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3245, '2017-09-27 14:50:05.333034+00', '2017-09-27 22:45:42.721688+00', 10820, 1, 117, '', 'D', '', 1, 1, 'Y', 'tr-RMY0TFPY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3249, '2017-09-29 14:27:10.123875+00', '2017-09-29 16:46:22.941187+00', 5671, 3, 596, '', 'X', '', 1, 1, 'Y', 'Y4YUHtGhTok', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3258, '2017-09-29 14:39:21.335326+00', '2017-09-29 22:29:13.446315+00', 535, 2, 596, '', 'X', '', 1, 1, 'Y', 'nSmLI0toXdk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3248, '2017-09-29 11:48:09.628421+00', '2017-09-29 19:34:10.828519+00', 10113, 1, 117, '', 'C', '(Video starts at bar 9.)', 1, 1, 'Y', 'ko7ohTj1GZ8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3256, '2017-09-29 14:36:59.609148+00', '2017-09-29 22:32:54.462096+00', 13581, 7, 596, '', 'X', 'A corrected video. The previous danciemaetion video should be removed.', 1, 1, 'Y', 'znnqVALNo5M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3254, '2017-09-29 14:33:52.344661+00', '2017-09-29 22:38:36.250364+00', 2394, 3, 596, '', 'X', '', 1, 1, 'Y', '7xhk3v2T6t0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3257, '2017-09-29 14:38:31.635422+00', '2017-09-29 22:47:46.361233+00', 549, 4, 596, '', 'X', 'A corrected video. The previous danciemaetion video has been removed.', 1, 1, 'Y', 'mVkglPRI-X4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3253, '2017-09-29 14:32:44.879894+00', '2017-09-29 22:44:38.181692+00', 15272, 1, 596, '', 'X', '', 1, 1, 'Y', 'DCX4iKeh07U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3252, '2017-09-29 14:30:35.417995+00', '2017-09-29 22:50:51.461885+00', 2616, 9, 596, '', 'X', '', 1, 1, 'Y', 'GB7o7qBkwzY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3250, '2017-09-29 14:28:51.042072+00', '2017-09-29 22:53:10.481166+00', 14907, 2, 596, '', 'X', 'This is a corrected video. The previous Danciemaetion link has been removed. ', 1, 1, 'Y', 'pgZ2cTP-1lE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3259, '2017-09-30 10:12:00.261435+00', '2017-09-30 11:01:24.41207+00', 17769, 2, 117, '', 'B', '', 1, 1, 'Y', 'LDAESdv6ff0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3260, '2017-09-30 13:16:37.509557+00', '2017-09-30 14:54:31.146308+00', 16774, 2, 117, '', 'B', '', 1, 1, 'Y', 'iV06tAz0U2Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3315, '2017-11-14 19:34:43.862932+00', '2017-11-14 23:22:33.983217+00', 9108, 1, 2213, '', 'D', 'First two bars missing.  Twice through.', 1, 1, 'Y', '_Je-9xIvKwg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3314, '2017-11-14 19:33:07.31042+00', '2017-11-14 23:41:40.094108+00', 8466, 1, 2213, '', 'D', 'Danced at the "Thistle Club" Ball, Eindhoven, 21 october 2017', 1, 1, 'Y', 'Ga7jRCz5GjI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3591, '2018-07-02 08:47:00.215984+00', '2018-07-02 08:52:50.356929+00', 17463, 1, 513, '', 'B', '', 1, 1, 'Y', 'P04wavVLLwA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3266, '2017-10-03 23:50:37.947836+00', '2017-10-03 23:50:58.70644+00', 16126, 2, 106, '', 'B', 'This is a teaching video of a Scottish Country Dance. There are audio and screen instructions and a bar counter. The dancers wear numbered coloured tabards so that the learner can follow a particular dancer through the dance. The dance was recorded in St Ninian''s Church Hall, Stirling, Scotland in February 2016.', 1, 1, 'Y', 'br8sQdP89q4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3264, '2017-10-03 23:19:19.695216+00', '2017-10-04 14:49:43.119652+00', 312, 4, 106, '', 'B', 'A 2011 "dem" in South Australia''s Nuriootpa.  There is a curious glitch towards the end of the second time through.

 

', 1, 1, 'Y', 'rv8y_qdnT4k', 68, 140, NULL);
INSERT INTO 'dancevideo' VALUES (3267, '2017-10-04 14:09:08.415796+00', '2017-10-04 14:54:13.489673+00', 7406, 1, 2697, '', 'B', '', 1, 1, 'Y', 'XQet80Ul6mY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3244, '2017-09-27 14:45:36.444188+00', '2017-10-04 22:04:39.401381+00', 4500, 1, 117, '', 'B', 'For bars 17-24 the original instructions say:  1st couple turn by the right hand, lead down the middle, cross below 3rd couple and cast up one place on the wrong side (2nd couple move up on bars 19 and 20)



This agrees with the crib and the diagram.  The video deviates slightly from the instructions, in that 1c already moves down on the second half turn..', 1, 1, 'Y', 'dEzH2-ZY4Rk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3269, '2017-10-07 15:24:01.421106+00', '2017-10-07 15:24:51.800381+00', 15405, 1, 106, '', 'D', 'Bethankit was on the 2017 annual dance programme of the Tawa SCD Club. The MC was club tutor Maureen Robson and live music was provided by Peter Elmes, Aileen Logie, Don McKay and Hilary Ferral. The dance was held in the Ngaio town hall, Wellington, on September 16 2017.', 1, 1, 'Y', 'oFh2fvtiFC8', 34, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3268, '2017-10-07 10:23:35.493247+00', '2017-10-07 16:22:43.659439+00', 16177, 1, 274, '', 'B', 'Budapest local club, 2017.10.05,

second man is the dance deviser', 1, 1, 'Y', 'JWTham2TGP0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3271, '2017-10-12 19:56:55.85445+00', '2017-10-12 23:11:10.154372+00', 743, 8, 1024, '', 'A', '', 1, 1, 'Y', 'VPxaxNJxE3Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1789, '2014-08-24 22:35:29.157772+00', '2017-10-13 23:05:48.453994+00', 1934, 1, 106, '', 'D', 'First Scottish Ball, Sole Dance School, Omsk, Russia, 30 nov. 2013.  Very enthusiastic dancers, but low on precision.', 1, 1, 'Y', 'J1IyGwlh_50', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3278, '2017-10-15 15:54:19.877059+00', '2017-10-15 21:27:37.644026+00', 2992, 1, 596, '', 'X', '', 1, 1, 'Y', 'NZyPPxaoNO8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3273, '2017-10-14 22:22:19.219797+00', '2017-10-14 22:27:10.939663+00', 1934, 3, 106, '', 'B', 'Performance Of Eilean Donan Castle - Sole Dance School, Omsk, Russia, 2014, at the International Festival of Culture.', 1, 1, 'Y', 'pH8cmaEa3W0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3282, '2017-10-15 16:02:00.724902+00', '2017-10-15 21:28:07.826199+00', 16744, 1, 596, '', 'X', '', 1, 1, 'Y', 'tCtawrH5DPo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3274, '2017-10-14 22:26:57.172065+00', '2017-10-14 22:27:38.691812+00', 1934, 4, 106, '', 'C', 'Eilean Donan Castle - Sole Dance School, Omsk, Russia, 2013.', 1, 1, 'Y', 'vzp_FjtDsZs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3272, '2017-10-14 22:15:38.645493+00', '2017-10-14 22:29:05.806012+00', 1934, 2, 106, '', 'A', 'Last 4 bars modified to link to the next dance.



MacLennan Scottish Group, dancing the "Eilean Donan Castle" set in Marjamaa, Estonia in August 2013, as guests of group Hopsani. This was part of a wonderful final concert,featuring groups from Poland, Czech Republic, Slovakia, Russia, and many local Estonian Groups.', 1, 1, 'Y', 'yAKBnZzFxnw', 21, 124, NULL);
INSERT INTO 'dancevideo' VALUES (3276, '2017-10-15 15:50:39.917469+00', '2017-10-15 21:24:25.712831+00', 4403, 1, 596, '', 'X', '', 1, 1, 'Y', 'ZNhxDAIkaqk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3294, '2017-10-21 03:15:51.77753+00', '2017-10-21 03:16:28.976319+00', 17896, 3, 202, '', 'A', '', 1, 1, 'Y', '74DStN4wZwM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3284, '2017-10-17 01:09:19.436705+00', '2017-10-17 01:14:17.761886+00', 1479, 3, 106, '', 'D', 'The dance is preceded by an instruction and partial walk-through.



Dufftown Dance Club - 01/10/2016 

Music from Gordon Brown and his band https://www.dufftowndanceclub.com', 1, 1, 'Y', 'eC01Rup7U4E', 150, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3295, '2017-10-21 03:17:13.407591+00', '2017-10-21 03:17:49.319811+00', 9486, 2, 202, '', 'A', '', 1, 1, 'Y', 'cZ255ngJ560', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3286, '2017-10-18 19:28:37.96437+00', '2017-10-18 23:34:56.495681+00', 2822, 4, 2219, '', 'C', '', 1, 1, 'Y', 'EDdUm1_7SI8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3291, '2017-10-21 03:09:42.183557+00', '2017-10-21 03:10:44.072803+00', 17891, 1, 202, '', 'A', '', 1, 1, 'Y', 'AAQncFJ-x20', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3292, '2017-10-21 03:12:20.513168+00', '2017-10-21 03:12:55.561841+00', 17900, 1, 202, '', 'A', '', 1, 1, 'Y', 'r7kU9wo4G5A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3293, '2017-10-21 03:14:22.634257+00', '2017-10-21 03:15:00.427406+00', 17898, 2, 202, '', 'A', '', 1, 1, 'Y', 'h71yZHgZgtY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3296, '2017-10-21 03:18:52.749783+00', '2017-10-21 03:19:31.924151+00', 17897, 2, 202, '', 'A', '', 1, 1, 'Y', 'lV-0JQzUXKM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3297, '2017-10-21 03:20:48.260217+00', '2017-10-21 03:21:16.631577+00', 17901, 1, 202, '', 'A', '', 1, 1, 'Y', 'o0oBOCJyL6E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3298, '2017-10-21 03:22:16.138713+00', '2017-10-21 03:22:40.079099+00', 17899, 1, 202, '', 'A', '', 1, 1, 'Y', 'ZDd5Qk8d-54', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3299, '2017-10-21 03:23:40.892181+00', '2017-10-21 03:24:57.863195+00', 17895, 1, 202, '', 'A', '', 1, 1, 'Y', 'SqEBJEOIsyg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3300, '2017-10-21 03:26:14.839255+00', '2017-10-21 03:26:45.64364+00', 16803, 2, 202, '', 'A', '', 1, 1, 'Y', 'P732udJ0oZo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3301, '2017-10-21 03:28:43.154195+00', '2017-10-21 03:29:22.128626+00', 17893, 2, 202, '', 'A', '', 1, 1, 'Y', '_tF9KlXqSIA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3302, '2017-10-21 03:30:33.456114+00', '2017-10-21 03:30:57.960763+00', 17892, 2, 202, '', 'A', '', 1, 1, 'Y', 'J5Nwgsc0TVY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3288, '2017-10-20 22:02:58.985225+00', '2017-10-22 14:45:15.845476+00', 17919, 1, 1645, '', 'C', 'View from the top of the set.

There is one overturn into the reel of 4 in the 1st repeat (neatly recovered 8 bars later) and one missed entry into the chase.

', 1, 1, 'Y', 'aG_WnlIazKI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3307, '2017-11-01 11:29:33.582329+00', '2019-01-04 20:09:49.060241+00', 1998, 2, 2482, '', 'B', 'The dancing itself is of demonstration quality.  On [29-30] only 1st couple should set (and cross on [31-32]).  As all couples here set on [29-30], the video has been reclassified as "good".', 1, 1, 'Y', 'oz5n5fRp7E4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3289, '2017-10-20 22:08:02.92313+00', '2017-10-22 15:31:06.509181+00', 17759, 1, 1645, '', 'B', 'View from the top of the set.

The couples mostly pass left shoulder into promenade hold at the end of the half reels of 4 in bars 13-16.

This flows well ("Mairi''s Divorce" style) but the original intention was for them to make the final

right shoulder pass on bar 16 which is only done during the 3rd repeat.

', 1, 1, 'Y', 'IDETufyo_uU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3306, '2017-10-29 19:24:58.867272+00', '2017-10-29 20:52:15.014887+00', 11368, 1, 954, '', 'A', 'Glasgow Ladies, at Newcastle Festival 2017', 1, 1, 'Y', 'TUduH2wgOq4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3303, '2017-10-24 09:29:44.997487+00', '2017-10-27 12:58:20.925144+00', 3172, 6, 274, '', 'C', 'Budapest, local ball,  14.10.2017', 1, 1, 'Y', 'O6Q3NaPIdgw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3304, '2017-10-24 11:38:15.717932+00', '2017-10-27 13:19:34.322556+00', 15227, 1, 1483, '', 'B', '', 1, 1, 'Y', 'CXoILQ7rVj4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3305, '2017-10-29 19:11:03.784105+00', '2017-10-29 20:56:56.228095+00', 295, 1, 954, '', 'C', 'Scottish Country Dance, Chelmsford, MA, 10/29/2016. "Animal" themed party.', 1, 1, 'Y', 'aLkt8S6dKV8', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3309, '2017-11-01 15:34:27.041473+00', '2017-11-02 02:38:22.879537+00', 17785, 1, 197, '', 'A', 'RSCDS Cheltenham Branch Demonstration Team with Pipe Major Sandy Walker.', 1, 1, 'Y', 'MdDN_MO1cw4', 22, 152, NULL);
INSERT INTO 'dancevideo' VALUES (3308, '2017-11-01 11:31:37.620553+00', '2017-11-02 02:41:56.128803+00', 5354, 1, 2482, '', 'B', '', 1, 1, 'Y', '6chLyngnR1Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3310, '2017-11-05 18:41:47.417205+00', '2017-11-05 23:43:00.469898+00', 3941, 5, 513, '', 'B', 'Recorded on the 04.11.2017 during the RSCDS Conference WE at the Bell''s Sports Centre in Perth (UK)   Music by Colin Dewar and his SCD Band', 1, 1, 'Y', 'H2ZGr0zih-o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3569, '2018-06-11 21:57:27.465212+00', '2018-06-11 22:02:42.680173+00', 7283, 4, 1645, '', 'A', '', 1, 1, 'Y', '7swZCrpPQRc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3399, '2018-01-23 10:24:13.736343+00', '2018-01-23 15:29:54.624057+00', 3870, 1, 954, '', 'C', 'Some parts of the video show the feet only.  All turns are made using linked elbows rather than L or R hands.', 1, 1, 'Y', 'odcXvk74fTU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3585, '2018-06-30 10:27:10.313693+00', '2018-06-30 19:50:11.696928+00', 18017, 1, 513, '', 'D', '', 1, 1, 'Y', 'CXU11JlbNqQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4197, '2018-12-27 21:11:26.814193+00', '2018-12-27 21:11:49.369999+00', 3980, 6, 202, '', 'D', '', 1, 1, 'Y', 'gr8-K8-skgM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3316, '2017-11-14 23:56:27.21525+00', '2017-11-15 00:18:08.549462+00', 6763, 4, 2220, '', 'C', 'The other videos of this dance do not show the different nature of the reels in Tulloch Gorm, instead doing them as in Cadgers in the Canongate.  In the San Francisco branch we have always danced these parallel reels with the 1s crossing home on bars 7&8 so that those bars, and 9&10 become something like a gypsy into a chase.  Quite a nice movement.', 1, 1, 'Y', 'xxFPAvU-nso', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3317, '2017-11-15 21:40:34.45194+00', '2017-11-15 22:55:07.085172+00', 17321, 1, 8690, '', 'C', '', 1, 1, 'Y', 'oz1dkF89trs', 0, 190, NULL);
INSERT INTO 'dancevideo' VALUES (3497, '2018-04-02 05:03:59.802718+00', '2018-04-02 05:36:37.239073+00', 18271, 1, 8724, '', 'C', 'Tomsk Scottish Ball



Vintage and the Scottish dance group "Mystery"  https://vk.com/the_dance_misteria   



Студия старинного и шотландского танца "Мистерия" https://vk.com/the_dance_misteria  



31.03.2018  Tomsk  г. Томск 



', 1, 1, 'Y', 'gVbQZ7KOyNE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3324, '2017-11-26 18:15:27.915785+00', '2017-12-13 13:52:49.382338+00', 11617, 3, 513, '', 'B', '', 1, 1, 'Y', 'TDmwDTq2-yU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3236, '2017-09-23 15:19:14.125138+00', '2017-11-23 15:03:58.391176+00', 17404, 1, 513, '', 'C', 'Please note that in this video the dance is not performed to the to the correct music.



The dancing itself however is correct.', 1, 1, 'Y', 'S69n-6IROhk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3319, '2017-11-22 13:11:13.782699+00', '2017-11-24 03:58:29.764741+00', 15650, 1, 3086, '', 'A', '', 1, 1, 'Y', '3DZwBjQ8v-M', 13, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2739, '2016-11-29 13:20:16.067165+00', '2017-11-24 08:49:35.736708+00', 12869, 1, 954, '', 'C', 'This dance was composed for the marriage of two of the dancers who are in this video.  



All the dancers are members of "The Ericht Scottish Country Dance Club" in Blairgowrie. This club is a Branch Member of the RSCDS.  

', 1, 1, 'Y', '1R5XdCjDQXA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3328, '2017-11-26 21:04:08.498093+00', '2018-01-22 01:15:55.647132+00', 15649, 1, 3086, '', 'A', '', 1, 1, 'Y', 'iDpctXSObCo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3323, '2017-11-25 14:27:40.672918+00', '2017-11-25 20:18:28.802818+00', 14439, 1, 513, '', 'B', '', 1, 1, 'Y', 'zVd0-DzMvYk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3321, '2017-11-24 13:22:50.939982+00', '2017-11-25 22:03:17.345814+00', 17229, 2, 197, '', 'A', 'This video accurately shows the dance according to the published instructions.  (The other video differs from the instructions at bars 17-20)

 

The tutor of the group is the deviser!, the first man is Gaye''s husband Damon.

', 1, 1, 'Y', 'f9JsKMjQYKI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3326, '2017-11-26 18:34:45.39214+00', '2017-11-26 19:50:41.517509+00', 14527, 2, 513, '', 'B', '', 1, 1, 'Y', 'caefvRd0ms8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3327, '2017-11-26 20:27:24.737427+00', '2017-11-26 23:39:34.763587+00', 17311, 1, 3129, '', 'A', '', 1, 1, 'Y', 'cSEy3MUCMoM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3339, '2017-11-28 19:07:13.042974+00', '2017-11-29 21:18:48.686317+00', 4799, 3, 596, '', 'X', '', 1, 1, 'Y', '9r4ymFwkAvE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3211, '2017-09-04 09:32:59.790405+00', '2018-04-21 16:16:51.615649+00', 6482, 1, 1645, '', 'B', 'Three times through excerpt from a lovely demo display with two back to back sets (joined at 4th couple). One hesitation in moving up during the 2nd repeat.

In principle 1st couple should give hands when changing places up and down in bars 17-24.

', 1, 1, 'Y', 'yScKjwa2xYk', 638, 747, NULL);
INSERT INTO 'dancevideo' VALUES (3435, '2018-02-14 02:21:16.34025+00', '2018-02-26 12:31:18.506753+00', 10232, 3, 1024, '', 'A', '', 1, 1, 'Y', 'ASO2z4sHvPA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3444, '2018-02-14 16:21:46.228188+00', '2018-02-26 12:31:43.112914+00', 9008, 4, 513, '', 'A', '', 1, 1, 'Y', 'JjbX3Ydl3EA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3664, '2018-10-01 22:07:47.208297+00', '2018-10-01 22:07:47.208297+00', 14572, 2, 1296, '', 'X', '"A Wee Dram Before Tea" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'snTEG7_ZDpk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3579, '2018-06-18 13:34:58.066565+00', '2021-05-25 17:20:29.291542+00', 7273, 1, 513, '', 'B', 'SCD Weekend in Grenoble in June 2018.', 1, 1, 'Y', '30yZBtBwmY0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3322, '2017-11-25 14:10:48.675578+00', '2021-10-21 21:45:53.859867+00', 16520, 1, 513, '', 'B', '', 1, 1, 'Y', 'yydhLvkWqTo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (591, '2012-12-17 14:18:46.363929+00', '2017-12-01 22:24:40.622559+00', 3980, 2, 1296, '', 'C', 'Twice through.  On bars 1-8 of the first time through, 2c makes wrong crossings in the reel across.  After 1st time through, a new couple starts at the top, and the old 1c dances a reel across with the old 4c.



', 1, 1, 'Y', 'rv8y_qdnT4k', 0, 69, NULL);
INSERT INTO 'dancevideo' VALUES (3351, '2017-12-06 13:21:59.547428+00', '2017-12-06 15:29:05.419396+00', 15640, 1, 3086, '', 'A', '', 1, 1, 'Y', 'R6bdB_cFsqA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3360, '2017-12-09 18:40:32.444848+00', '2017-12-09 19:10:19.563698+00', 18103, 1, 160, '', 'B', 'This dance is still being tweaked; it was written in response to a story about a close encounter of the slothful kind, and because the story is so good and we just can''t keep straight face, we are dancing with slothful toes.



The Half Sloth Reel of 4 appropriately takes a full 8 bars.', 1, 1, 'Y', '8rk03qxWjxg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3352, '2017-12-06 22:22:43.776461+00', '2017-12-06 22:26:37.235539+00', 5623, 2, 160, '', 'A', 'The music used was "Rob Roy" from Peter White and his Scottish Dance Band.', 1, 1, 'Y', 'E5gydg84I4E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3358, '2017-12-08 20:48:05.431883+00', '2017-12-09 01:40:17.223327+00', 8328, 1, 160, '', 'A', '', 1, 1, 'Y', 'eYnAuRwcLvc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3359, '2017-12-08 21:08:13.093055+00', '2017-12-08 21:12:03.708791+00', 8328, 2, 160, '', 'B', 'For Fun Only - This was unrehearsed, at the end of the video session and we were letting it all hang out.

', 1, 1, 'Y', 'mcDlz7p4R3o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3355, '2017-12-07 05:17:54.766251+00', '2017-12-09 01:41:03.984043+00', 3244, 1, 160, '', 'A', '', 1, 1, 'Y', 'h7cwv5I28Io', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3342, '2017-11-28 19:09:51.21982+00', '2017-12-13 11:31:55.923873+00', 10070, 3, 596, '', 'X', '', 1, 1, 'Y', 'wvIwf6FKN2s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3337, '2017-11-28 19:05:38.571963+00', '2017-12-13 11:32:13.923462+00', 15177, 2, 596, '', 'X', '', 1, 1, 'Y', '_ZsqVRktTb0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3343, '2017-11-28 19:10:40.694179+00', '2017-12-13 11:32:33.337329+00', 10071, 2, 596, '', 'X', '', 1, 1, 'Y', 'bnef1Cp2Dzg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3349, '2017-12-02 14:52:33.045711+00', '2017-12-13 11:35:30.164148+00', 15648, 2, 3086, '', 'A', '', 1, 1, 'Y', '_JcSz_7Ehh8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3345, '2017-11-28 19:12:59.327475+00', '2017-12-13 11:37:13.101467+00', 6763, 5, 596, '', 'X', 'This is a corrected / updated video. Please replace the previous video.', 1, 1, 'Y', 'hscd4o68rp4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3331, '2017-11-28 18:59:46.516823+00', '2017-12-13 11:37:31.547172+00', 14712, 3, 596, '', 'X', '', 1, 1, 'Y', 'f0jGXS_pTEo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3330, '2017-11-28 18:58:01.421262+00', '2017-12-13 11:37:54.697307+00', 5525, 17, 596, '', 'X', 'This video has been updated / corrected. Please replace the previous video', 1, 1, 'Y', 'Fxn1yQx3hOM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3335, '2017-11-28 19:04:00.903409+00', '2017-12-13 11:38:14.433977+00', 3770, 1, 596, '', 'X', '', 1, 1, 'Y', 'hxCYO-I4ujc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3334, '2017-11-28 19:02:52.756781+00', '2017-12-13 11:38:28.822899+00', 8730, 1, 596, '', 'X', '', 1, 1, 'Y', '89tNi7Q3A0w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3338, '2017-11-28 19:06:26.310248+00', '2017-12-13 11:38:49.811483+00', 3397, 3, 596, '', 'X', '', 1, 1, 'Y', 'RCq3dXpDNKc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3329, '2017-11-28 18:56:18.547623+00', '2017-12-13 11:39:11.213862+00', 10459, 3, 596, '', 'X', 'This video has been corrected - please replace the previous video', 1, 1, 'Y', '-0zKyxn698s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3336, '2017-11-28 19:04:43.248474+00', '2017-12-13 11:39:35.758023+00', 1864, 1, 596, '', 'X', '', 1, 1, 'Y', '4qOPRw8KFWc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3332, '2017-11-28 19:01:05.895269+00', '2017-12-13 11:39:53.278209+00', 11456, 1, 596, '', 'X', '', 1, 1, 'Y', 'wfYKbTDjwD8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3341, '2017-11-28 19:08:56.373224+00', '2017-12-13 11:40:31.520062+00', 17395, 1, 596, '', 'X', '', 1, 1, 'Y', 'b3UffN2Kt3g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3344, '2017-11-28 19:11:33.081478+00', '2017-12-13 11:40:45.384628+00', 9985, 1, 596, '', 'X', '', 1, 1, 'Y', '2L4LwLOpXok', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3347, '2017-11-30 21:24:22.326763+00', '2017-12-13 11:45:58.90923+00', 18044, 1, 1645, '', 'C', 'Some troubles in the first two repeats (three casts to the left in the last 16 bars of the 2nd repeat) but pretty good for the last six repeats.

', 1, 1, 'Y', 'ymrS6NNruEc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3346, '2017-11-30 21:22:33.345489+00', '2017-12-13 11:48:23.280078+00', 17756, 1, 1645, '', 'C', 'Just the first and last repeats (omitting some mishaps in the central two repeats which resulted in an unplanned partner change).

', 1, 1, 'Y', 'fBfV2p2PzoU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3320, '2017-11-23 01:45:51.051+00', '2017-12-13 12:25:55.668288+00', 1128, 2, 562, '', 'B', 'Danced by Bedford Scottish Dance Group at the President''s Evening, Bedford Scots Society, 10 September 2016.', 1, 1, 'Y', 'xBWPkhqv2BM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3325, '2017-11-26 18:16:04.50581+00', '2017-12-13 13:53:50.468128+00', 11617, 4, 513, '', 'B', '', 1, 1, 'Y', 'LpJfiTtahTc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3357, '2017-12-07 16:01:53.362379+00', '2017-12-13 13:57:41.94233+00', 3336, 4, 274, '', 'B', 'Budapest Scottish Dance Club    St. Andrews Night  2017', 1, 1, 'Y', 'aQcP4X_PrpE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3400, '2018-01-23 19:50:24.685384+00', '2018-01-23 19:52:45.444914+00', 6614, 2, 106, '', 'B', '', 1, 1, 'Y', 'jIG14nD0HwY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3394, '2018-01-18 12:40:03.606797+00', '2018-01-23 15:45:49.171022+00', 10291, 1, 2121, '', 'C', 'Two sets, once through only.  ', 1, 1, 'Y', 'A6yHv4AFVSQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3401, '2018-01-27 09:05:51.1803+00', '2018-01-27 09:13:36.037345+00', 2506, 3, 2824, '', 'D', '', 1, 1, 'Y', 'MdCx_n40nMI', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3365, '2017-12-13 11:20:23.72411+00', '2017-12-13 11:43:51.797292+00', 14405, 1, 1645, '', 'B', 'Video starts a bar or so into the dance. A few wobbles on the last repeat otherwise pretty good.', 1, 1, 'Y', 'n4y8iGCql70', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3420, '2018-01-31 10:18:19.604049+00', '2018-01-31 16:38:08.986022+00', 314, 10, 274, '', 'A', 'part 3 of the demonstration at Burns Supper 2018, Budapest', 1, 1, 'Y', 'EQDUiDmbKjI', 295, 417, NULL);
INSERT INTO 'dancevideo' VALUES (3368, '2017-12-19 12:15:04.220465+00', '2017-12-19 14:28:57.136926+00', 18053, 1, 1645, '', 'C', 'A blend of the first two attempts at a challenging new dance: generally good but also displaying various potential pitfalls.

There are some missed casts and startled turns, a late entry into the central circle in the 2nd repeat and wrong order into a chase in the 4th repeat (neatly corrected at the end of the circle).

The last repeat is best viewed as a surprising recovery from a momentary lapse and also shows the classic error of birling too long to end back on the sidelines.

', 1, 1, 'Y', 'vKzIiAE9rJ8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3366, '2017-12-13 11:29:33.686595+00', '2018-04-12 21:32:34.736662+00', 18046, 1, 1645, '', 'B', '', 1, 1, 'Y', 'aXOzlTYy9q4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3362, '2017-12-10 19:13:07.282091+00', '2017-12-13 12:07:17.381105+00', 2812, 1, 1717, '', 'A', 'Ninety years ago, in 1927, the Scottish Country Dance Society held its first Summer School here in St Andrews. In the same year Book 4 was published.  



To celebrate this occasion the team demonstrated three dances from that book. They started with ‘Torryburn Lassies’ then danced ‘Haughs o’ Cromdale’ and finished with ‘The Merry Dancers’.  The dancers come from Canada, England, Germany, Hungary, Norway and Trinidad. The team was trained by Mervyn Short and accompanied by Robert Mackay on the piano.  Filmed at Younger Hall in St. Andrews, the Royal Scottish Country Dance Society holds their Summer School every year during the months of July and August. ', 1, 1, 'Y', 'HpJ7NYnBG98', 90, 151, NULL);
INSERT INTO 'dancevideo' VALUES (3363, '2017-12-10 19:19:54.513626+00', '2017-12-13 12:16:30.396158+00', 4324, 3, 1717, '', 'A', 'Each couple dances once only - moving to 4pl with a modified figure at end of each time through.



Ninety years ago, in 1927, the Scottish Country Dance Society held its first Summer School here in St Andrews. In the same year Book 4 was published.  



To celebrate this occasion the team demonstrated three dances from that book. They started with ‘Torryburn Lassies’ then danced ‘Haughs o’ Cromdale’ and finished with ‘The Merry Dancers’.  The dancers come from Canada, England, Germany, Hungary, Norway and Trinidad. The team was trained by Mervyn Short and accompanied by Robert Mackay on the piano.  Filmed at Younger Hall in St. Andrews, the Royal Scottish Country Dance Society holds their Summer School every year during the months of July and August. ', 1, 1, 'Y', 'HpJ7NYnBG98', 151, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3361, '2017-12-10 19:07:54.776824+00', '2017-12-13 12:23:59.103314+00', 6658, 1, 1717, '', 'A', 'Danced in a 4 couple set, consisting of two 2-couple sets, joined top to top.  Twice through.



Ninety years ago, in 1927, the Scottish Country Dance Society held its first Summer School here in St Andrews. In the same year Book 4 was published.  



To celebrate this occasion the team demonstrated three dances from that book. They started with ‘Torryburn Lassies’ then danced ‘Haughs o’ Cromdale’ and finished with ‘The Merry Dancers’.  The dancers come from Canada, England, Germany, Hungary, Norway and Trinidad. The team was trained by Mervyn Short and accompanied by Robert Mackay on the piano.  Filmed at Younger Hall in St. Andrews, the Royal Scottish Country Dance Society holds their Summer School every year during the months of July and August. ', 1, 1, 'Y', 'HpJ7NYnBG98', 0, 90, NULL);
INSERT INTO 'dancevideo' VALUES (3367, '2017-12-15 14:04:35.611272+00', '2017-12-15 14:04:49.122856+00', 2926, 1, 106, '', 'B', 'Music is Rose Amang the Heather, a traditional tune, recorded by David South and His Scottish Dance Band.', 1, 1, 'Y', 'CTbl2Zc6mUs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3370, '2017-12-20 09:10:34.467088+00', '2017-12-22 18:35:36.48023+00', 6051, 2, 2482, '', 'B', '', 1, 1, 'Y', '9AccpCRiwY4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3371, '2017-12-25 23:09:21.045432+00', '2017-12-25 23:10:17.286454+00', 824, 1, 106, '', 'C', '', 1, 1, 'Y', '004bghQAKvk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3372, '2017-12-26 20:29:35.429289+00', '2017-12-26 20:35:11.988922+00', 15326, 2, 596, '', 'X', 'This upgraded Danciemaetion video should replace the current Danciemaetion video ', 1, 1, 'Y', 'WV_ediSK_ss', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3388, '2017-12-29 20:22:47.172992+00', '2017-12-29 20:23:40.57776+00', 12124, 3, 106, '', 'B', 'Twice through.  Second part of a medley display', 1, 1, 'Y', '_Cfuta-6vsk', 158, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2941, '2017-03-26 23:51:35.130424+00', '2017-12-30 00:05:39.651173+00', 17675, 1, 106, '', 'A', 'The Red Thistle Dancers accompanied by Red Thistle Music and bagpipes .  Demo at 151st Anniversary - Caledonian Games, Pleasanton CA, September 3, 2015, 2:00 p.m.

', 1, 1, 'Y', '_Cfuta-6vsk', 0, 159, NULL);
INSERT INTO 'dancevideo' VALUES (3389, '2018-01-03 12:52:08.934295+00', '2018-01-03 17:45:32.623202+00', 17304, 2, 3129, '', 'A', '', 1, 1, 'Y', 'DObxzX_0JHA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3387, '2017-12-29 18:59:05.064533+00', '2018-01-03 17:57:09.204537+00', 15643, 1, 3086, '', 'A', '', 1, 1, 'Y', 'tPDphDqhhjE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3390, '2018-01-08 13:53:21.649746+00', '2018-01-08 14:27:49.928127+00', 8676, 1, 1272, '', 'A', '', 1, 1, 'Y', 'tvHNVDP11lY', 0, 128, NULL);
INSERT INTO 'dancevideo' VALUES (3391, '2018-01-08 13:54:57.406247+00', '2018-01-08 15:06:55.617828+00', 4185, 2, 1272, '', 'A', '', 1, 1, 'Y', 'hkgoAk5NY7Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3393, '2018-01-17 18:43:55.720056+00', '2018-01-17 23:23:22.705014+00', 14719, 1, 1121, '', 'A', 'Twice through.  First two bars missing.', 1, 1, 'Y', '5V9D7AY8xoQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3396, '2018-01-18 17:51:04.507517+00', '2018-01-19 21:47:00.990423+00', 6634, 2, 954, '', 'X', '', 1, 1, 'Y', 'p2KO0YOmo6Y', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3395, '2018-01-18 17:43:39.731225+00', '2018-01-18 19:44:51.752538+00', 11375, 2, 954, '', 'C', '', 1, 1, 'Y', 'z8ZAgmrOYdc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3398, '2018-01-19 01:15:19.483087+00', '2018-01-19 21:54:04.193385+00', 15644, 2, 3086, '', 'A', '', 1, 1, 'Y', 'GVDUzxN8_iw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3413, '2018-01-27 10:44:31.926411+00', '2018-01-27 13:52:38.267341+00', 10433, 11, 2824, '', 'A', '', 1, 1, 'Y', 'KmDKI9FeKj0', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3414, '2018-01-27 10:47:13.185132+00', '2018-01-27 13:57:08.743514+00', 17905, 1, 2824, '', 'A', '', 1, 1, 'Y', 'nbP8uHSShps', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3402, '2018-01-27 09:24:44.835013+00', '2018-01-27 14:33:47.743292+00', 17122, 2, 2824, '', 'B', 'Slight wobble in the middle of the Corners Pass & Turn during the third time through', 1, 1, 'Y', '5w3-cezI1cE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3412, '2018-01-27 10:39:16.344994+00', '2018-01-27 15:07:16.987306+00', 1537, 3, 2824, '', 'C', 'Tea Dance Montreal 2017', 1, 1, 'Y', 'CVq3O8sqJKM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3417, '2018-01-27 11:01:08.402537+00', '2018-01-27 15:59:12.238192+00', 8482, 1, 2824, '', 'A', 'Twice through', 1, 1, 'Y', 'fzKd1_8bDFQ', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3416, '2018-01-27 10:58:12.742905+00', '2018-01-27 16:03:43.087535+00', 5384, 3, 2824, '', 'A', 'Twice through', 1, 1, 'Y', 'R0etMKGMdRo', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3410, '2018-01-27 10:21:54.847298+00', '2018-01-27 16:28:46.450447+00', 6177, 2, 2824, '', 'C', 'Filmed from the bottom end of the set, ', 1, 1, 'Y', 'Vwf3Zhaz8dY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3403, '2018-01-27 09:28:32.423419+00', '2018-01-27 17:14:14.827626+00', 413, 8, 2824, '', 'D', 'Dancing at beginnr''s level.  Weak music.  ', 1, 1, 'Y', 'BXJPgrSqBEE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3404, '2018-01-27 09:34:05.139412+00', '2018-01-27 17:19:41.123764+00', 3336, 5, 2824, '', 'C', 'The Jig part is rather chaotic at times.', 1, 1, 'Y', 'stlHacj3oxc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3407, '2018-01-27 09:54:03.801549+00', '2018-01-27 17:25:14.044438+00', 13362, 2, 2824, '', 'C', '2 times through', 1, 1, 'Y', 'RSCsgUYettA', 25, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3408, '2018-01-27 09:57:51.4778+00', '2018-01-27 17:26:37.362521+00', 13362, 3, 2824, '', 'D', '', 1, 1, 'Y', 'KffZWYqrZA0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3415, '2018-01-27 10:53:06.953631+00', '2018-01-27 17:30:22.094987+00', 13589, 4, 2824, '', 'B', '2 times through', 1, 1, 'Y', 'CPic9ymDdMs', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3409, '2018-01-27 10:10:31.349972+00', '2018-01-27 17:33:06.757403+00', 17882, 3, 2824, '', 'C', '2 times through; camera is on same level as dancers and a bit far away.', 1, 1, 'Y', 'tP4Hg5sqxgY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3411, '2018-01-27 10:35:27.112669+00', '2018-01-28 00:49:08.924423+00', 3791, 5, 2824, '', 'C', '1 time through; camera focus wanders off to the musicians briefly during the last 8 bars.', 1, 1, 'Y', 'fecV1mFUFmE', 29, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3418, '2018-01-30 08:17:46.195271+00', '2018-01-30 14:10:10.698149+00', 18219, 1, 2697, '', 'B', '', 1, 1, 'Y', 'BzFDfiPW0TE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3432, '2018-02-12 15:21:26.084683+00', '2018-02-24 16:05:03.922822+00', 3176, 1, 2482, '', 'B', '', 1, 1, 'Y', '171FlS60Jkg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3425, '2018-01-31 11:46:35.297335+00', '2018-01-31 15:24:28.486474+00', 6373, 3, 2447, '', 'A', '', 1, 1, 'Y', 'HHopwlDJMtg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3422, '2018-01-31 10:23:09.167586+00', '2018-01-31 16:11:34.045556+00', 7152, 4, 274, '', 'A', 'part 5 of the demonstration at Burns Supper 2018, Budapest', 1, 1, 'Y', 'EQDUiDmbKjI', 515, 655, NULL);
INSERT INTO 'dancevideo' VALUES (3421, '2018-01-31 10:21:05.018872+00', '2018-01-31 16:35:24.790257+00', 9169, 3, 274, '', 'A', 'part 4 of the demonstration at Burns Supper 2018, Budapest

Two two-couple set :-)

', 1, 1, 'Y', 'EQDUiDmbKjI', 418, 492, NULL);
INSERT INTO 'dancevideo' VALUES (3426, '2018-02-03 10:43:03.984083+00', '2018-02-03 11:17:24.574806+00', 6037, 5, 274, '', 'B', 'Part 1 of the demonstration at Burns Supper 2018, Budapest

Bars 1-8 different from the description', 1, 1, 'Y', 'EQDUiDmbKjI', 13, 160, NULL);
INSERT INTO 'dancevideo' VALUES (3428, '2018-02-05 21:17:22.758366+00', '2018-02-05 21:21:26.176659+00', 14719, 2, 106, '', 'B', 'Published on Dec 26, 2017', 1, 1, 'Y', 's5eplTkuMS0', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3405, '2018-01-27 09:38:04.076287+00', '2018-02-05 21:35:36.315305+00', 144, 1, 2824, '', 'C', '', 1, 1, 'Y', '8YS7FIE5INo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3406, '2018-01-27 09:45:49.698425+00', '2018-02-05 21:35:47.772512+00', 144, 2, 2824, '', 'C', '4 times through (+ a couple of bars), good view from elevated position, roaming camera angle', 1, 1, 'Y', '9bN4P4rwqmU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3427, '2018-02-04 19:43:06.172711+00', '2018-02-05 21:42:06.853879+00', 11877, 1, 3086, '', 'A', '', 1, 1, 'Y', 'ZSo5uBQgliI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3423, '2018-01-31 11:38:27.518876+00', '2018-02-05 21:45:04.510491+00', 16724, 1, 2447, '', 'A', '', 1, 1, 'Y', 'kgqdeIP0oK8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3433, '2018-02-12 15:23:04.410008+00', '2018-02-24 16:13:17.998323+00', 5710, 1, 2482, '', 'B', '', 1, 1, 'Y', 'H-mGj9dkLKI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3434, '2018-02-13 14:12:01.412912+00', '2018-02-13 15:26:22.900745+00', 6792, 1, 106, '', 'A', 'The first 40 bars of a long demo of linked dances.  New dancers join in at the bottom on [24] and start while the three top couples finish the last 16 bars.   After that the next dance starts from the top.', 1, 1, 'Y', 'quqk6MyatLU', 7, 54, NULL);
INSERT INTO 'dancevideo' VALUES (3441, '2018-02-14 15:34:16.510408+00', '2018-02-14 15:36:52.793759+00', 11483, 3, 106, '', 'A', 'A really young dem team', 1, 1, 'Y', 'SvrSB7-eJr0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1873, '2014-10-31 00:23:33.813367+00', '2018-02-16 21:27:43.039532+00', 3980, 4, 106, '', 'B', ' Published on Oct 28, 2014



This is a teaching video of a Scottish Country Dance. There are on screen instructions and a bar counter together with audio instructions. The dancers wear number coloured tabards to help the learner follow a particular dancer through the dance.



The video was made by the Ochil Country Dancers in August 2014 in St Ninian''s Parish Church Hall, Stirling, Scotland.

', 1, 1, 'Y', 'Sw7cvuoCDr4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3447, '2018-02-20 11:54:36.093333+00', '2018-02-20 11:54:46.853885+00', 14926, 1, 106, '', 'B', 'RSCDS Toronto Gala Day 2010.  Danced by the Humbercrest Social Group.', 1, 1, 'Y', 'NnJVpJ9aO2Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3429, '2018-02-08 17:32:23.212776+00', '2018-02-24 16:19:13.040542+00', 10595, 2, 2824, '', 'A', 'Twice through', 1, 1, 'Y', '4snZzr3DWXo', 254, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3431, '2018-02-12 14:14:16.75967+00', '2018-02-25 22:55:00.337832+00', 13577, 4, 1675, '', 'A', '', 1, 1, 'Y', 'tMa8DQi2FnY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3430, '2018-02-12 14:13:35.595461+00', '2018-02-25 23:03:30.765575+00', 754, 5, 1675, '', 'A', '', 1, 1, 'Y', '5EuQqtrOSQ4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3436, '2018-02-14 02:22:20.084513+00', '2018-02-25 23:13:48.985799+00', 40, 4, 1024, '', 'A', '', 1, 1, 'Y', 'SbYg977ruIU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3443, '2018-02-14 16:20:49.589835+00', '2018-02-25 23:22:48.880575+00', 89, 3, 513, '', 'A', '', 1, 1, 'Y', 'rkGv7BT7Mgs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3439, '2018-02-14 02:25:50.001905+00', '2018-02-26 12:25:32.900578+00', 7210, 1, 1024, '', 'A', '', 1, 1, 'Y', 'SKqFo_LK49M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3446, '2018-02-14 16:23:16.293938+00', '2018-02-26 12:27:31.766892+00', 7068, 1, 513, '', 'A', '', 1, 1, 'Y', 'k8eHeCjEDXA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3438, '2018-02-14 02:25:09.153583+00', '2018-02-26 12:27:51.574044+00', 4309, 1, 1024, '', 'A', '', 1, 1, 'Y', '9d7v7yC6Ukg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3440, '2018-02-14 02:26:58.353567+00', '2018-02-26 12:28:29.131402+00', 2501, 2, 1024, '', 'A', '', 1, 1, 'Y', 'aI5H6Ij_DWo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3442, '2018-02-14 16:18:52.140247+00', '2018-02-26 12:29:32.217308+00', 5111, 2, 513, '', 'A', '', 1, 1, 'Y', 'Dd0-qZRvNP4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3445, '2018-02-14 16:22:35.314147+00', '2018-02-26 12:30:37.537199+00', 6323, 2, 513, '', 'A', '', 1, 1, 'Y', 'x58kzWfRXkc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3437, '2018-02-14 02:23:59.189893+00', '2018-02-26 12:32:20.482404+00', 2428, 6, 1024, '', 'A', '', 1, 1, 'Y', 'PTAYy9Q9CsY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (891, '2013-02-23 10:31:47.332458+00', '2018-08-05 10:35:45.748845+00', 6405, 1, 106, '', 'C', 'The Youtube video states that this strathspey part of their medley is "A Trip to Saint Andrews". However that appears to be incorrect; it is actually "Susie Petrov''s Strathspey".', 1, 1, 'Y', '4cQ-vaS3Nsc', 79, 209, NULL);
INSERT INTO 'dancevideo' VALUES (3607, '2018-07-28 00:10:03.625638+00', '2018-08-09 17:24:54.026378+00', 18486, 1, 2586, '', 'A', 'The first two bars of the music/video are missing.



Music by Christina Hood, Stelios Christodoulou and Kevin Williams.', 1, 1, 'Y', 'ySfWuNHXrsE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1699, '2014-06-20 11:13:43.131356+00', '2018-08-14 13:01:25.557004+00', 15479, 1, 197, '', 'C', 'Heather & Thistle Ball 2014, Maple Grove Grange, Colorado. The initial second couple is very good as dancing couple



Music by Unstrung Heroes - Deb Carstensen, Tina Gugeler & Rodney Sauer

', 1, 1, 'Y', '1swYrUV2nmA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4037, '2018-10-18 19:02:42.206104+00', '2018-10-18 20:20:37.958862+00', 1641, 5, 118, '', 'B', '', 1, 1, 'Y', 'hA5pjKtERY8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1938, '2015-02-17 21:25:47.026654+00', '2018-04-26 07:58:58.313775+00', 4217, 1, 513, '', 'C', 'Marjorie McLaughlin writes:  There are three mistakes in the video and, as they are done the same way by all of the dancers, I assume it was taught incorrectly, as opposed to a mistake by a single couple.



Bars 1 - 2  the ladies dance a Petronella turn to face partners on a diagonal line.  In the video the gentlemen are moving slightly right and left to form a straight line, which is incorrect.  



Bars 5-8 the turns are Right Hand turns, not two-hand turns as shown in the video.



Bars 29-32 both couples turn partner Right Hands to face ready for the next repetition, not two-hand turns as shown in the video. 

', 1, 1, 'Y', '5Zpc3ek995Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3499, '2018-04-02 18:01:01.072015+00', '2018-04-03 11:53:25.108308+00', 18244, 1, 1904, '', 'A', 'Demonstration danced by RSCDS Falkirk branch members at their 2018 Crieff Hydro Weekend, which Anna has organised for 25 years.



Music composed and performed by Gordon Shand: http://www.GordonShand.Com/



Photo album: https://www.facebook.com/media/set/?set=a.10216380278559012.1073741934.1216794850&type=1&l=2ecb3e284c



Branch website: http://web.RSCDS-Falkirk.Org.UK/



This demonstration is only twice through in a 3 couple set. Bars 31-32 of the first repeat are modified so that 1st couple cross to the bottom.', 1, 1, 'Y', 'PmbpNt9nL6o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3544, '2018-05-26 17:55:28.900456+00', '2018-05-27 00:24:49.571853+00', 13942, 1, 1720, '', 'B', 'The first time through is danced at very good standard, however, afterwards it becomes a little chaotic.  Video made at the Bochum Ruhrball 2017-11-04.', 1, 1, 'Y', 'bS3GJ7mrL08', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3530, '2018-05-04 22:20:36.391779+00', '2018-05-14 21:06:29.886426+00', 18331, 1, 197, '', 'B', 'Demonstrated by members of the Glenburn class at the Glasgow Branch Dance in memory of deviser Jimmy McMillan on 23 March 2018.



Four times through, each 1st couple dancing once. Some of the half reels in bars 13-16 and 21-24 are missing the expected left shoulder passes in the middle.

', 1, 1, 'Y', '2breJDgHqzw', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3541, '2018-05-25 18:23:58.697958+00', '2018-05-25 19:47:40.551768+00', 9157, 5, 3637, '', 'C', 'Cranberry Tart danced by members of the New World Dancers. This is part of a dance medley that also includes Lake Geneva and Second Salute to Miss Milligan. Taken from a performance at the Dixon Highland Games, CA in September, 2011. A rare opportunity to watch Greg Reznick dancing with the New World Dancers, the dance troupe he helped to form. 



Please note: Despite the fact that the dance was recorded during a demonstration performed by good dancers, the video had to be down-rated to ''reasonable'' for technical reasons. Due to the view-point it is hardly possible to use the video to understand the choreography of the dance from the video (but this is also required to get ratings ''good'' or ''demonstration quality'').', 1, 1, 'Y', 'RFTDIc6JoiM', 6, 79, NULL);
INSERT INTO 'dancevideo' VALUES (3562, '2018-06-06 14:18:18.150944+00', '2018-06-06 14:33:48.01828+00', 6972, 4, 2824, '', 'A', 'Newcastle Festival 2018, Lyon RSCDS team', 1, 1, 'Y', 'E4LmNM2hY68', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3563, '2018-06-06 14:21:38.774383+00', '2018-06-06 14:34:54.984142+00', 6734, 4, 2824, '', 'A', '4 times through.

Newcastle Festival 2018, East Scotland Dancers', 1, 1, 'Y', 'aRt9eo9sqpQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3565, '2018-06-06 14:26:13.267126+00', '2018-06-06 14:35:20.848163+00', 11769, 4, 2824, '', 'A', '4 times through.

Newcastle Festival 2018, Russian team', 1, 1, 'Y', 'C4EVgSaMPLQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3567, '2018-06-06 14:30:26.522309+00', '2018-06-06 14:35:47.661215+00', 6964, 5, 2824, '', 'A', '4 times through.

Newcastle festival 2018, Newcastle RSCDS team', 1, 1, 'Y', '2sRMCcqL-Uo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3557, '2018-06-06 14:00:51.870984+00', '2018-06-06 14:37:13.344834+00', 2437, 7, 2824, '', 'A', '4 times through.

Newcastle Festival 2015, Lyon RSCDS team', 1, 1, 'Y', 'Fpw6J_9E_Ec', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3559, '2018-06-06 14:08:35.395137+00', '2018-06-06 14:38:09.071773+00', 10663, 6, 2824, '', 'A', '4 times through.

Newcastle Festival 2018, Glasgow University team', 1, 1, 'Y', '4z-kivdNyEY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (261, '2012-09-14 05:36:13.861453+00', '2018-06-12 11:04:21.243787+00', 14577, 1, 106, '', 'D', 'Recorded on 03.07.2010 during the Summer Ball in Sterbfritz.

Music provided by Keith Smith and members of the musicians workshop of the Summer Course at the "Kuckucksnest".', 1, 1, 'Y', 'uMgzKSwExy4', 25, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3580, '2018-06-18 14:31:21.226527+00', '2018-06-18 16:35:23.908574+00', 7295, 1, 513, '', 'C', 'Four times through (twice each for the top two couples).', 1, 1, 'Y', 'KZOf9v7Uq98', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3587, '2018-07-01 12:39:51.299092+00', '2018-07-02 08:26:50.122906+00', 4998, 8, 2821, '', 'A', 'Nottingham Lace, performed by members of Nottingham RSCDS at East Bridgford Village Show on 30 Jun 2018.', 1, 1, 'Y', 's_6BpcBZSeU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3589, '2018-07-02 08:10:28.506519+00', '2018-07-02 08:24:33.056926+00', 18254, 2, 513, '', 'C', '', 1, 1, 'Y', '9Jrjdz6gY60', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3590, '2018-07-02 08:29:06.928596+00', '2018-07-02 08:37:03.916752+00', 17327, 1, 513, '', 'C', '', 1, 1, 'Y', 'o9XTxqGWm8I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3592, '2018-07-02 08:53:12.042143+00', '2018-07-02 08:55:38.122368+00', 17463, 2, 513, '', 'B', 'danced once through (32 Bars) - view from the top', 1, 1, 'Y', 'MYB6UjQVnFM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3593, '2018-07-02 09:01:44.79468+00', '2018-07-02 09:20:43.207418+00', 4767, 1, 513, '', 'B', '', 1, 1, 'Y', 'gs-Z8-40haA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3594, '2018-07-02 11:58:59.499508+00', '2018-07-02 12:13:33.997174+00', 6792, 2, 2213, '', 'B', '4 times through only', 1, 1, 'Y', 'x0zoB9ycNYo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3595, '2018-07-09 18:15:52.275964+00', '2018-07-09 19:18:03.154844+00', 18309, 1, 2269, '', 'A', 'June 2018 revision of the dance: Pass Rsh on the 2nd and 4th reels instead of Lsh as it flows more easily.', 1, 1, 'Y', 'COln44dWv1U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3597, '2018-07-10 16:17:25.375534+00', '2018-07-11 01:24:05.883962+00', 713, 3, 3637, '', 'D', 'Beginners dancing The Borrowdale Exchange at the Fall Ceilidh, RSCDS Seattle - Oct 2013 .', 1, 1, 'Y', 'qfHJpi_Bjkc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3598, '2018-07-10 16:20:50.395019+00', '2018-07-11 01:24:51.073766+00', 7441, 1, 3637, '', 'C', 'Danced at the Spring Scottish ball in Voronezh - 10th anniversary of the "Stone Bridge" school - April 9, 2016. Video quality is poor but dancing is reasonable.', 1, 1, 'Y', '-6etWSlM3do', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3610, '2018-08-02 18:05:29.809016+00', '2018-08-02 18:08:38.631519+00', 16838, 1, 2213, '', 'A', 'Once through only in strathspey time and in reel time.', 1, 1, 'Y', 'g6PuOmKr8hg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3596, '2018-07-10 16:13:43.047419+00', '2018-07-11 01:27:46.495088+00', 9011, 3, 3637, '', 'B', 'Dance performance by the Bellingham Scottish Country Dancers Demonstration Team at the Skagit Valley Highland Games & Celtic Festival, July 8, 2017.', 1, 1, 'Y', 'ukb1g7qbqx8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3599, '2018-07-15 15:24:31.948648+00', '2018-07-15 15:59:55.921267+00', 15647, 1, 3086, '', 'A', '', 1, 1, 'Y', 'hoc3wEBonBU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3600, '2018-07-15 21:52:29.686265+00', '2018-07-15 22:02:38.724895+00', 12369, 1, 3005, '', 'C', 'Performance by Watford and West Herts Scottish Society at Donald Wallace''s memorial service July 2018 ', 1, 1, 'Y', 'BtG8C4ZEZzw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3601, '2018-07-19 09:17:36.696292+00', '2018-07-19 16:57:32.053048+00', 18393, 1, 1645, '', 'C', 'Once through. All goes well until the last few bars.', 1, 1, 'Y', 'dKFJeEv-2OI', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3602, '2018-07-19 09:21:41.366374+00', '2018-07-19 16:58:14.767081+00', 18335, 1, 1645, '', 'D', 'Some hesitations, variable phrasing and a little confusion in the schiehallion reels, but otherwise OK.



For teaching purposes the recording used for the danced was slowed down slightly.', 1, 1, 'Y', 'iLxsD-JVWLE', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3603, '2018-07-19 09:22:52.03531+00', '2018-07-19 16:59:34.434055+00', 18239, 1, 1645, '', 'B', '', 1, 1, 'Y', 'zw5Dd3CsvzU', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3604, '2018-07-19 09:24:41.895875+00', '2018-07-19 17:00:28.156167+00', 17754, 1, 1645, '', 'B', 'One wrong turn in the 4th repeat, otherwise fine.', 1, 1, 'Y', 'w274qftJ0Zk', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3605, '2018-07-19 09:25:49.745841+00', '2018-07-19 17:01:11.15717+00', 18395, 1, 1645, '', 'B', '', 1, 1, 'Y', 'YHrzEfWeOC4', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3606, '2018-07-25 13:57:18.669555+00', '2018-07-25 14:02:00.797939+00', 18410, 1, 513, '', 'A', 'Younger Hall Dem w1 2018 - The dance is the 1st half of the video!!!', 1, 1, 'Y', 'lWppN13-PP0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3608, '2018-07-30 13:20:45.553294+00', '2018-07-30 13:33:10.834263+00', 6712, 10, 2824, '', 'B', 'Teaching video including instructions, first 4 bars in slow-motion, 2 times through', 1, 1, 'Y', 'BfQsZzMCyqI', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3609, '2018-07-30 13:28:14.478831+00', '2018-07-30 13:34:33.762707+00', 5204, 2, 2824, '', 'A', 'Teaching video (including written/voice-over instruction), 2 times through.', 1, 1, 'Y', 'RgXT31v2JEc', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3611, '2018-08-02 20:26:19.192327+00', '2018-08-02 20:39:40.733625+00', 18408, 1, 2213, '', 'A', 'Twice through only. The final bars have been amended to finish a demonstration with 10 dancers.', 1, 1, 'Y', 'HRGEFvuS7e8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3618, '2018-09-03 15:31:09.133689+00', '2018-09-04 09:54:03.316631+00', 14909, 1, 513, '', 'B', 'The first and third dancing couples use Right Hands Joined on bars [5-6].  The instructions say "dance", which is a standard term that implies Nearer Hands Joined.', 1, 1, 'Y', 'E6VzvO-CsX8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3613, '2018-08-12 02:47:04.219252+00', '2018-08-21 13:49:52.913654+00', 13727, 4, 2709, '', 'B', '', 1, 1, 'Y', 'LuMsIqh2Wuo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3615, '2018-08-21 16:06:06.575456+00', '2018-08-21 16:50:01.804725+00', 7267, 1, 2824, '', 'C', '', 1, 1, 'V', '215773249', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2809, '2017-01-29 21:16:04.996951+00', '2018-08-21 20:30:28.056069+00', 17460, 1, 106, '', 'C', 'This is a 3C/4L dance, but here it is danced in a 3L set', 1, 1, 'V', '190668592', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3614, '2018-08-21 13:44:59.56492+00', '2018-08-21 21:23:06.280028+00', 3957, 1, 1338, '', 'B', '', 1, 1, 'Y', 'E2N2EtssjoI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3625, '2018-09-08 22:08:46.393829+00', '2018-09-08 22:29:55.375796+00', 17904, 1, 2755, '', 'A', '', 1, 1, 'Y', 'nNAKvvrDxys', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3616, '2018-09-03 15:26:40.496033+00', '2018-09-04 10:06:13.693123+00', 16960, 1, 513, '', 'C', '', 1, 1, 'Y', 'k-nm6r7qZXY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (409, '2012-12-17 14:17:49.190672+00', '2018-09-03 22:37:19.420254+00', 633, 1, 1296, '', 'B', '', 1, 1, 'Y', 'qsgqpVRnf2M', 194, 314, NULL);
INSERT INTO 'dancevideo' VALUES (3617, '2018-09-03 15:28:31.996105+00', '2018-09-04 10:10:49.091301+00', 12633, 1, 513, '', 'B', '', 1, 1, 'Y', 'taN4Pobjr2Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3620, '2018-09-04 13:37:02.983668+00', '2018-09-04 13:37:25.468715+00', 14741, 3, 106, '', 'D', '', 1, 1, 'Y', 'p420XDbth44', 82, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3622, '2018-09-04 15:18:39.537768+00', '2018-09-04 15:21:31.1087+00', 1198, 1, 106, '', 'B', '', 1, 1, 'Y', 'N9ZF3DWQqHc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3621, '2018-09-04 13:42:48.152404+00', '2018-09-06 16:07:47.952829+00', 6010, 3, 106, '', 'B', '', 1, 1, 'Y', 'sx29pm3gF0M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3623, '2018-09-06 11:48:50.643325+00', '2018-09-06 16:11:55.32546+00', 5802, 5, 2824, '', 'B', '', 1, 1, 'Y', 'Q4-pC1HVLE0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3619, '2018-09-04 12:52:17.958602+00', '2018-09-06 16:15:48.165447+00', 6395, 1, 106, '', 'B', '', 1, 1, 'Y', '2jI-Nmsjs2E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3627, '2018-09-10 23:34:42.982553+00', '2018-09-10 23:35:07.347789+00', 16534, 5, 106, '', 'A', '', 1, 1, 'Y', 'KqgsNRQwnmA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3626, '2018-09-10 21:32:14.139808+00', '2018-09-11 06:15:59.870043+00', 16537, 4, 238, '', 'B', '', 1, 1, 'Y', 'ApleI1I3Xm4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3628, '2018-09-13 11:56:04.332974+00', '2018-09-13 13:09:26.399115+00', 14963, 1, 2824, '', 'B', '3 times through', 1, 1, 'Y', 'R54mt3BLzEQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3629, '2018-09-13 11:59:03.749073+00', '2018-09-13 13:16:51.607914+00', 16478, 1, 2824, '', 'C', '', 1, 1, 'Y', 'SMhz8aP8gdA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3631, '2018-09-13 13:15:11.391391+00', '2018-09-13 13:28:57.352437+00', 18580, 2, 2824, '', 'B', '', 1, 1, 'Y', 'HyaGc39aqdg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3630, '2018-09-13 13:13:17.593351+00', '2018-09-13 13:29:00.637825+00', 18580, 1, 2824, '', 'C', 'The camera angle shows 3/4 of two sets rather than 1 set in its entirety', 1, 1, 'Y', 'cpxMaHXX6XA', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3633, '2018-09-13 13:32:22.795295+00', '2018-09-13 13:51:49.365747+00', 12729, 1, 2824, '', 'C', '', 1, 1, 'Y', '0QJWNHScQGc', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3632, '2018-09-13 13:26:14.930661+00', '2018-09-13 13:51:53.993427+00', 18579, 1, 2824, '', 'B', '3 times through', 1, 1, 'Y', '1NBRt-eWZN8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3637, '2018-09-17 11:31:54.094536+00', '2018-09-18 05:43:40.417992+00', 17383, 1, 2824, '', 'A', '4 times through', 1, 1, 'Y', 'x9x9ma0jdBc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3634, '2018-09-13 21:23:55.686042+00', '2018-09-18 05:44:13.761925+00', 9406, 2, 3086, '', 'A', '', 1, 1, 'Y', 'Jzy9t9uSDEE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3638, '2018-09-20 20:12:52.818797+00', '2018-09-20 20:48:15.038132+00', 5525, 18, 1, '', 'A', '', 1, 1, 'Y', 'pebyQJ58dc8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3639, '2018-09-21 19:03:15.798003+00', '2018-09-21 19:05:59.023644+00', 10370, 1, 106, '', 'B', 'Danced by members of the RSCDS Ottawa Branch, in May 2018.



The music for this video is Blue Mess Jacket by Rob Gordon and his Scottish Dance Band. It is still available with the first tune of Squadron Leader Douglas Henderson on the Let’s go Scottish Country Dancing, Volume 1', 1, 1, 'Y', 'c-HprAthSBg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3643, '2018-09-24 08:17:11.184826+00', '2018-09-25 10:21:26.553733+00', 2786, 1, 513, '', 'D', 'Video starts just before bar 25 (R&L) of one repeat.', 1, 1, 'Y', 'SMf9VlwAVUE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3666, '2018-10-01 22:07:47.241753+00', '2018-10-01 22:07:47.241753+00', 7055, 4, 1296, '', 'X', '"West''s Hornpipe" is a 32 bar reel for 4 couples.', 1, 1, 'Y', 'qckaafzGs3U', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3696, '2018-10-01 22:07:48.260214+00', '2018-10-01 22:07:48.260214+00', 5982, 6, 1296, '', 'X', '"Seann Truibhas Willichan" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', '3uUd-ZqrLys', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3640, '2018-09-23 19:53:01.680385+00', '2018-09-25 10:29:50.154324+00', 17957, 2, 963, '', 'B', 'It falls apart at the beginning of the second time through because 4th woman is taking a video instead of dancing.', 1, 1, 'Y', 'g6I2Jmnc4OQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3667, '2018-10-01 22:07:47.258579+00', '2018-10-01 22:07:47.258579+00', 7109, 5, 1296, '', 'X', '"The White Cockade" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'iUX_ZLDArNw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3641, '2018-09-23 21:17:59.566397+00', '2018-09-25 10:45:33.95369+00', 2125, 4, 513, '', 'C', 'Danced once each couple.', 1, 1, 'Y', 'Ru65Dmsc3oI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3642, '2018-09-24 08:14:32.548023+00', '2018-09-25 10:48:25.749789+00', 8037, 1, 513, '', 'C', '', 1, 1, 'Y', 'hdjzlZOvX5o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3644, '2018-09-25 09:55:36.87433+00', '2018-09-27 10:05:17.826213+00', 18659, 1, 1645, '', 'C', 'Once through.

Unfortunately the camera was too close so several loops of the reels are out of view.

In bars 37-40 the 2nd corners should have half turned with the right hand not the left hand.

', 1, 1, 'Y', '_5-RxCukM2o', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3645, '2018-09-25 09:59:57.184874+00', '2018-09-27 10:06:50.121957+00', 18660, 1, 1645, '', 'B', 'There are a few hesitations and missed setting by 2nd/3rd couple at times but otherwise choreographically correct though the last half turns in bars 29-30 are generally taken a bit too fast.

', 1, 1, 'Y', 'QZKBzl4KUAw', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3646, '2018-09-25 10:02:18.499358+00', '2018-09-27 10:07:56.098704+00', 18661, 1, 1645, '', 'B', 'One missed cast into the reels on the last repeat and a few hesitations and false starts here and there but otherwise no choreographic errors.

', 1, 1, 'Y', 'eWbZAlVlSLw', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3647, '2018-09-25 10:03:44.81169+00', '2018-09-27 10:09:18.787459+00', 18288, 1, 1645, '', 'B', 'The camera was a bit too close, so dancers are occasionally partly out of view (but never completely so).', 1, 1, 'Y', 'JQXJXIM14V8', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3650, '2018-09-26 10:19:56.044196+00', '2018-09-27 10:16:11.183484+00', 17122, 3, 2824, '', 'A', '', 1, 1, 'Y', '98S7U8qzfiU', 9, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3651, '2018-09-30 14:49:38.173801+00', '2018-09-30 14:50:24.133342+00', 18667, 1, 202, '', 'C', '', 1, 1, 'Y', '5m3-CO_RArc', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3652, '2018-09-30 15:15:37.357749+00', '2018-09-30 15:35:06.640818+00', 18655, 1, 202, '', 'B', '', 1, 1, 'Y', 'wMdWFIFBcYU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3653, '2018-09-30 16:06:35.308941+00', '2018-09-30 16:06:50.178546+00', 18669, 1, 202, '', 'D', '', 1, 1, 'Y', 'LB2Cb0pHsG0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3655, '2018-10-01 22:07:46.963155+00', '2018-10-01 22:07:46.963155+00', 8081, 3, 1296, '', 'X', '"Through the Garden Gate" is a 32 bar jig for 2 couples.', 1, 1, 'Y', '3Ysu0IhlLyY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3656, '2018-10-01 22:07:47.029474+00', '2018-10-01 22:07:47.029474+00', 3252, 5, 1296, '', 'X', '"Tomalena" is a 32 bar reel for 5 couples.', 1, 1, 'Y', 'pQlZFYGZ4uE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3657, '2018-10-01 22:07:47.055278+00', '2018-10-01 22:07:47.055278+00', 14680, 2, 1296, '', 'X', '"Tokyo Flyer" is a 40 bar jig for 3 couples.', 1, 1, 'Y', 'BINq6NVEZzI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3658, '2018-10-01 22:07:47.077073+00', '2018-10-01 22:07:47.077073+00', 6701, 4, 1296, '', 'X', '"Tribute to the Borders" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'gtngT100kDA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3659, '2018-10-01 22:07:47.094812+00', '2018-10-01 22:07:47.094812+00', 6712, 11, 1296, '', 'X', '"A Trip to Bavaria" is a 32 bar reel for 4 couples.', 1, 1, 'Y', 'XClAKvvSxYs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3660, '2018-10-01 22:07:47.13553+00', '2018-10-01 22:07:47.13553+00', 6848, 4, 1296, '', 'X', '"Up in the Air" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'Il6zJ0TC_s8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3661, '2018-10-01 22:07:47.150302+00', '2018-10-01 22:07:47.150302+00', 6885, 4, 1296, '', 'X', '"Village Reel" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'v0vkDORgx4U', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4370, '2019-03-12 01:19:33.668458+00', '2019-03-12 18:47:34.23872+00', 12689, 2, 1330, '', 'C', '', 1, 1, 'Y', '_OECpszkW1o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3663, '2018-10-01 22:07:47.193543+00', '2018-10-01 22:07:47.193543+00', 6915, 4, 1296, '', 'X', '"Waltz Country Dance" is a 40 bar waltz for 2 couples.', 1, 1, 'Y', '_hQwi13_CxI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3668, '2018-10-01 22:07:47.283653+00', '2018-10-01 22:07:47.283653+00', 7111, 5, 1296, '', 'X', '"White Heather Jig" is a 40 bar jig for 4 couples.', 1, 1, 'Y', 'lm5Ac4vYHug', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3669, '2018-10-01 22:07:47.302159+00', '2018-10-01 22:07:47.302159+00', 7147, 7, 1296, '', 'X', '"The Wild Geese" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'fy5DHmWb77U', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3670, '2018-10-01 22:07:47.319555+00', '2018-10-01 22:07:47.319555+00', 7179, 2, 1296, '', 'X', '"The Wind in the Willows" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'cqg8fpuaRpg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3671, '2018-10-01 22:07:47.338073+00', '2018-10-01 22:07:47.338073+00', 7182, 3, 1296, '', 'X', '"The Wind that Shakes the Barley" is a 32 bar reel for 3 couples.', 1, 1, 'Y', '3OX65CQyagc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3672, '2018-10-01 22:07:47.360314+00', '2018-10-01 22:07:47.360314+00', 15322, 2, 1296, '', 'X', '"The Wing" is a 40 bar reel for 3 couples.', 1, 1, 'Y', 'rvwEYU7swNw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3673, '2018-10-01 22:07:47.388683+00', '2018-10-01 22:07:47.388683+00', 10713, 2, 1296, '', 'X', '"Ye Ken It Well" is a 32 bar jig for 3 couples.', 1, 1, 'Y', '5CyV4iS4vmw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3674, '2018-10-01 22:07:47.410352+00', '2018-10-01 22:07:47.410352+00', 7242, 6, 1296, '', 'X', '"Ye''ll Aye Be Welcome Back Again" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'o3KHbxbKG3k', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3675, '2018-10-01 22:07:47.428684+00', '2018-10-01 22:07:47.428684+00', 13590, 4, 1296, '', 'X', '"The Zoologist" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'dSZG0volj6o', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3676, '2018-10-01 22:07:47.77332+00', '2018-10-01 22:07:47.77332+00', 5529, 13, 1296, '', 'X', '"Reel of the Royal Scots" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'lIpC9_GKO1E', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3677, '2018-10-01 22:07:47.801832+00', '2018-10-01 22:07:47.801832+00', 5530, 2, 1296, '', 'X', '"The Reel of the Sound" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'R30HbWA4cWE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3678, '2018-10-01 22:07:47.822467+00', '2018-10-01 22:07:47.822467+00', 17133, 4, 1296, '', 'X', '"Remparts de Seville, Les" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'IwzGdKDwZFY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3679, '2018-10-01 22:07:47.841402+00', '2018-10-01 22:07:47.841402+00', 5552, 4, 1296, '', 'X', '"Rest and Be Thankful" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'dhOTZkbIAzc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3680, '2018-10-01 22:07:47.860477+00', '2018-10-01 22:07:47.860477+00', 5555, 4, 1296, '', 'X', '"The Reverend John MacFarlane" is a 32 bar reel for 4 couples.', 1, 1, 'Y', 'pSNuvOWOxMk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3681, '2018-10-01 22:07:47.877791+00', '2018-10-01 22:07:47.877791+00', 5621, 4, 1296, '', 'X', '"Roaring Jelly" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'IyPtHRnjAG8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3682, '2018-10-01 22:07:47.942325+00', '2018-10-01 22:07:47.942325+00', 5637, 6, 1296, '', 'X', '"The Robertson Rant" is a 80 bar strathspey for 4 couples.', 1, 1, 'Y', 'QJhVdh_OR00', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3683, '2018-10-01 22:07:47.970516+00', '2018-10-01 22:07:47.970516+00', 5641, 1, 1296, '', 'X', '"The Rock and the Wee Pickle Tow" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'bqnXqzan9eg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3684, '2018-10-01 22:07:47.990074+00', '2018-10-01 22:07:47.990074+00', 14535, 9, 1296, '', 'X', '"Rodney''s Rant" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'lMYqdvx4NY4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3685, '2018-10-01 22:07:48.008403+00', '2018-10-01 22:07:48.008403+00', 5702, 2, 1296, '', 'X', '"Rothesay Country Dance" is a 48 bar jig for 2 couples.', 1, 1, 'Y', 'C_XHNJ4q0Js', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3686, '2018-10-01 22:07:48.062995+00', '2018-10-01 22:07:48.062995+00', 5703, 4, 1296, '', 'X', '"The Rothesay Rant" is a 32 bar jig for 4 couples.', 1, 1, 'Y', 'OmU84OC_s8g', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3687, '2018-10-01 22:07:48.093408+00', '2018-10-01 22:07:48.093408+00', 5713, 5, 1296, '', 'X', '"Round Reel of Eight" is a 88 bar reel for 4 couples.', 1, 1, 'Y', 'IuAWrn6tL2o', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3688, '2018-10-01 22:07:48.11724+00', '2018-10-01 22:07:48.11724+00', 9110, 6, 1296, '', 'X', '"The Royal Deeside Railway" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'M4wheRkVQmM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3689, '2018-10-01 22:07:48.138271+00', '2018-10-01 22:07:48.138271+00', 13163, 3, 1296, '', 'X', '"Rye Twist" is a 32 bar reel for 5 couples.', 1, 1, 'Y', 'Brw6r02TX6A', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3648, '2018-09-26 09:52:14.363407+00', '2018-10-05 20:27:46.698419+00', 16729, 1, 2824, '', 'A', '', 1, 1, 'Y', 'kgqdeIP0oK8', 209, 339, NULL);
INSERT INTO 'dancevideo' VALUES (3690, '2018-10-01 22:07:48.158254+00', '2018-10-01 22:07:48.158254+00', 5794, 8, 1296, '', 'X', '"The Sailor" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'knR5hn7ahhs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3691, '2018-10-01 22:07:48.178481+00', '2018-10-01 22:07:48.178481+00', 5885, 10, 1296, '', 'X', '"Sands of Morar" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'JZOmjEWefVk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3692, '2018-10-01 22:07:48.195648+00', '2018-10-01 22:07:48.195648+00', 14571, 2, 1296, '', 'X', '"Saturday Market" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'xkNAHvrkXnY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3693, '2018-10-01 22:07:48.211955+00', '2018-10-01 22:07:48.211955+00', 5904, 6, 1296, '', 'X', '"The Sauchie Haugh" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'A0i3mEn8pJc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3694, '2018-10-01 22:07:48.227548+00', '2018-10-01 22:07:48.227548+00', 5964, 4, 1296, '', 'X', '"Scottish Reform" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'yQY1XF5RTvk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3695, '2018-10-01 22:07:48.243382+00', '2018-10-01 22:07:48.243382+00', 15316, 2, 1296, '', 'X', '"The Screaming Eels" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'ciG0y2b6jJU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3697, '2018-10-01 22:07:48.276613+00', '2018-10-01 22:07:48.276613+00', 15320, 2, 1296, '', 'X', '"Secrets of the Fire Swamp" is a 32 bar jig for 3 couples.', 1, 1, 'Y', '-aP5Wj3MsG4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3698, '2018-10-01 22:07:48.293234+00', '2018-10-01 22:07:48.293234+00', 6010, 4, 1296, '', 'X', '"Seton''s Ceilidh Band" is a 64 bar jig for 4 couples.', 1, 1, 'Y', 'K1FJ7uCof7g', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3699, '2018-10-01 22:07:48.318145+00', '2018-10-01 22:07:48.318145+00', 14025, 3, 1296, '', 'X', '"The Shetland Shepherdess" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'TJO3YgTAmNs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3700, '2018-10-01 22:07:48.342324+00', '2018-10-01 22:07:48.342324+00', 6048, 10, 1296, '', 'X', '"Shiftin'' Bobbins" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'AAIXrdHKBmg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3701, '2018-10-01 22:07:48.362197+00', '2018-10-01 22:07:48.362197+00', 6091, 7, 1296, '', 'X', '"The Silver Tassie" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'lIpOSEydym0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3702, '2018-10-01 22:07:48.377817+00', '2018-10-01 22:07:48.377817+00', 15323, 3, 1296, '', 'X', '"The Six-Figured Man" is a 48 bar jig for 3 couples.', 1, 1, 'Y', 'K72aBVn5DYE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3703, '2018-10-01 22:07:48.394581+00', '2018-10-01 22:07:48.394581+00', 6152, 4, 1296, '', 'X', '"Sleepy Maggie" is a 32 bar reel for 3 couples.', 1, 1, 'Y', '42s7rdBr_JY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3704, '2018-10-01 22:07:48.411263+00', '2018-10-01 22:07:48.411263+00', 9161, 2, 1296, '', 'X', '"Smoke Rings in the Night" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'BmmpMvonrlQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3705, '2018-10-01 22:07:48.438236+00', '2018-10-01 22:07:48.438236+00', 16255, 6, 1296, '', 'X', '"The Spring Fling Reel" is a 40 bar reel for 3 couples.', 1, 1, 'Y', 'oekn7B63xNA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3706, '2018-10-01 22:07:48.456824+00', '2018-10-01 22:07:48.456824+00', 16749, 2, 1296, '', 'X', '"Springbank" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'IoU3wmPT9wg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3707, '2018-10-01 22:07:48.481724+00', '2018-10-01 22:07:48.481724+00', 17625, 2, 1296, '', 'X', '"St Andrew''s Anniversary Strathspey" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'U32xG_2WUSY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3708, '2018-10-01 22:07:48.504747+00', '2018-10-01 22:07:48.504747+00', 5802, 6, 1296, '', 'X', '"St Andrew''s Fair" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'Pcz_OjAVfDo', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3709, '2018-10-01 22:07:48.521483+00', '2018-10-01 22:07:48.521483+00', 6271, 5, 1296, '', 'X', '"Staffin Harvest" is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'Cp73J6fC1OU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3710, '2018-10-01 22:07:48.544287+00', '2018-10-01 22:07:48.544287+00', 10684, 3, 1296, '', 'X', '"Stanford Swing" is a 40 bar jig for 3 couples.', 1, 1, 'Y', 'WQ7oexu_inE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3711, '2018-10-01 22:07:48.561077+00', '2018-10-01 22:07:48.561077+00', 6287, 5, 1296, '', 'X', '"The Starry-Eyed Lassie" is a 32 bar jig for 3 couples.', 1, 1, 'Y', '9eovDTINWdQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3712, '2018-10-01 22:07:48.577541+00', '2018-10-01 22:07:48.577541+00', 15566, 2, 1296, '', 'X', '"State of Grace" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'JZ-ssreoM8s', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3713, '2018-10-01 22:07:48.594024+00', '2018-10-01 22:07:48.594024+00', 17624, 2, 1296, '', 'X', '"Statuary Falls" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'Jotv7vPHnxc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3714, '2018-10-01 22:07:48.610763+00', '2018-10-01 22:07:48.610763+00', 12792, 6, 1296, '', 'X', '"Sueno''s Stone" is a 32 bar reel for 3 couples.', 1, 1, 'Y', '__XnuXrG9FI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3716, '2018-10-01 22:07:48.662537+00', '2018-10-01 22:07:48.662537+00', 9643, 2, 1296, '', 'X', '"Susanne''s Strathspey" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 's1miXt9KHzI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3717, '2018-10-01 22:07:48.680064+00', '2018-10-01 22:07:48.680064+00', 15317, 2, 1296, '', 'X', '"Swashbuckling Dread Pirate Roberts" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'joarRNyRf68', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3718, '2018-10-01 22:07:48.69604+00', '2018-10-01 22:07:48.69604+00', 8577, 2, 1296, '', 'X', '"Swashbuckling Iain" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'jjOLvfqM_fw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3719, '2018-10-01 22:07:48.719087+00', '2018-10-01 22:07:48.719087+00', 7282, 6, 1296, '', 'X', '"Swiss Lassie" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'S5BqfWhXbpk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3720, '2018-10-01 22:07:48.766693+00', '2018-10-01 22:07:48.766693+00', 8166, 2, 1296, '', 'X', '"The Teddy Bears'' Picnic" is a 32 bar jig for 4 couples.', 1, 1, 'Y', 'CuloGJT7pCA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3721, '2018-10-01 22:07:48.782513+00', '2018-10-01 22:07:48.782513+00', 7527, 3, 1296, '', 'X', '"Thornycroft" is a 32 bar reel for 2 couples.', 1, 1, 'Y', 'cLjJVOPtKoQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3722, '2018-10-01 22:07:48.798861+00', '2018-10-01 22:07:48.798861+00', 17402, 2, 1296, '', 'X', '"Those Eyes" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'Yl_ljjwZ9Z4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3723, '2018-10-01 22:07:49.141598+00', '2018-10-01 22:07:49.141598+00', 4227, 2, 1296, '', 'X', '"The Mason''s Apron" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'YumAXUZlfhg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3724, '2018-10-01 22:07:49.296804+00', '2018-10-01 22:07:49.296804+00', 4239, 6, 1296, '', 'X', '"Maxwell''s Rant" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'nZxFyZLabBw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3725, '2018-10-01 22:07:49.341272+00', '2018-10-01 22:07:49.341272+00', 4354, 4, 1296, '', 'X', '"The Micmac Rotary" is a 96 bar reel for 4 couples.', 1, 1, 'Y', 've1EcnFm_Ys', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3726, '2018-10-01 22:07:49.36522+00', '2018-10-01 22:07:49.36522+00', 16524, 7, 1296, '', 'X', '"Midsummer Common" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'mfES4X4TCpk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3727, '2018-10-01 22:07:49.386688+00', '2018-10-01 22:07:49.386688+00', 7543, 3, 1296, '', 'X', '"The Milltimber Jig" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'HntlKxiwEU8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3728, '2018-10-01 22:07:49.409923+00', '2018-10-01 22:07:49.409923+00', 14022, 3, 1296, '', 'X', '"The Millville Grange" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'QB804uduWN0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4032, '2018-10-17 20:59:30.14191+00', '2018-10-18 20:21:56.499853+00', 15443, 1, 1645, '', 'C', '', 1, 1, 'Y', 'nvnP0zb2PSk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3729, '2018-10-01 22:07:49.427245+00', '2018-10-01 22:07:49.427245+00', 4404, 9, 1296, '', 'X', '"Milton''s Welcome" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'LP-8GL392Kw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3730, '2018-10-01 22:07:49.451881+00', '2018-10-01 22:07:49.451881+00', 4411, 8, 1296, '', 'X', '"The Minister on the Loch" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'V139KRgrb8k', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3731, '2018-10-01 22:07:49.477525+00', '2018-10-01 22:07:49.477525+00', 14376, 2, 1296, '', 'X', '"Mint Truffles" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'cteHx-qoHnk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3732, '2018-10-01 22:07:49.501635+00', '2018-10-01 22:07:49.501635+00', 4424, 4, 1296, '', 'X', '"Miss Allie Anderson" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'txMyGgtxkes', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3733, '2018-10-01 22:07:49.529631+00', '2018-10-01 22:07:49.529631+00', 4484, 9, 1296, '', 'X', '"Miss Gibson''s Strathspey" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'XhkDiQ3XtzQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3734, '2018-10-01 22:07:49.551851+00', '2018-10-01 22:07:49.551851+00', 4506, 2, 1296, '', 'X', '"Miss Isabella McLeod" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'QYvS2s1nYkU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3735, '2018-10-01 22:07:49.572415+00', '2018-10-01 22:07:49.572415+00', 9638, 8, 1296, '', 'X', '"Miss Johnstone of Ardrossan" is a 32 bar reel for 5 couples.', 1, 1, 'Y', '9Zo4FC9wKc4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3736, '2018-10-01 22:07:49.592617+00', '2018-10-01 22:07:49.592617+00', 4555, 7, 1296, '', 'X', '"Miss Milligan''s Strathspey" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'RA8ylf5MYnc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3737, '2018-10-01 22:07:49.608506+00', '2018-10-01 22:07:49.608506+00', 4562, 2, 1296, '', 'X', '"Miss Nancy Frowns" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'jAR9O7PrPaE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3738, '2018-10-01 22:07:49.636113+00', '2018-10-01 22:07:49.636113+00', 14576, 2, 1296, '', 'X', '"Miss Sarah Smiles" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'SlgO5_UzneU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3739, '2018-10-01 22:07:49.659507+00', '2018-10-01 22:07:49.659507+00', 14534, 5, 1296, '', 'X', '"Mist O''er the Loch" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '6eyiTKOUsEg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3740, '2018-10-01 22:07:49.681661+00', '2018-10-01 22:07:49.681661+00', 14570, 2, 1296, '', 'X', '"Mixed Nuts" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'G5_e3gM2lHE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3741, '2018-10-01 22:07:49.702001+00', '2018-10-01 22:07:49.702001+00', 4641, 8, 1296, '', 'X', '"The Montgomeries'' Rant" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'zE8VoMKB8yA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3742, '2018-10-01 22:07:49.722605+00', '2018-10-01 22:07:49.722605+00', 4646, 8, 1296, '', 'X', '"Monymusk" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'UZVamyv3kM8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3743, '2018-10-01 22:07:49.741557+00', '2018-10-01 22:07:49.741557+00', 4707, 2, 1296, '', 'X', '"Mr Edward Wagstaff''s Fancy" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'TvCxqXaMMus', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3744, '2018-10-01 22:07:49.758125+00', '2018-10-01 22:07:49.758125+00', 13617, 2, 1296, '', 'X', '"Mr Michael Bear''s Reel" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'Aaz1Q_SWG9Q', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3745, '2018-10-01 22:07:49.775002+00', '2018-10-01 22:07:49.775002+00', 4728, 3, 1296, '', 'X', '"Mr. Wilson''s Hornpipe" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'xoA6CJ9q-fk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3746, '2018-10-01 22:07:49.799593+00', '2018-10-01 22:07:49.799593+00', 4782, 3, 1296, '', 'X', '"Mrs Macleod" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'i0L0hyJubPY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3747, '2018-10-01 22:07:49.819468+00', '2018-10-01 22:07:49.819468+00', 4805, 10, 1296, '', 'X', '"Mrs Stewart''s Jig" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'CyhRnIdOo3U', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3748, '2018-10-01 22:07:49.867354+00', '2018-10-01 22:07:49.867354+00', 4827, 6, 1296, '', 'X', '"Muirland Willie" is a 32 bar jig for 3 couples.', 1, 1, 'Y', '6JkPdGlvN9A', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3749, '2018-10-01 22:07:49.893667+00', '2018-10-01 22:07:49.893667+00', 4844, 6, 1296, '', 'X', '"The Music Makars" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'IKh8eEPF2i4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3750, '2018-10-01 22:07:49.918243+00', '2018-10-01 22:07:49.918243+00', 10535, 7, 1296, '', 'X', '"Napier''s Index" is a 40 bar jig for 3 couples.', 1, 1, 'Y', 'Cw9NJ46TQ78', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3751, '2018-10-01 22:07:49.93896+00', '2018-10-01 22:07:49.93896+00', 4890, 6, 1296, '', 'X', '"Neidpath Castle" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '08y_nuuvXK8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3752, '2018-10-01 22:07:49.956382+00', '2018-10-01 22:07:49.956382+00', 7474, 2, 1296, '', 'X', '"New Abbey" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'xXZDdkYk6mg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3753, '2018-10-01 22:07:49.983872+00', '2018-10-01 22:07:49.983872+00', 5028, 2, 1296, '', 'X', '"Odd Thoughts" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '33b8Hg7g6QI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3754, '2018-10-01 22:07:50.010334+00', '2018-10-01 22:07:50.010334+00', 13727, 5, 1296, '', 'X', '"The Paisley Weavers" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'V6KbehcrcFM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3755, '2018-10-01 22:07:50.02528+00', '2018-10-01 22:07:50.02528+00', 5198, 5, 1296, '', 'X', '"The Peat Fire Flame" is a 40 bar reel for 3 couples.', 1, 1, 'Y', 'cGn2izxblwc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3756, '2018-10-01 22:07:50.049879+00', '2018-10-01 22:07:50.049879+00', 5209, 12, 1296, '', 'X', '"Pelorus Jack" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'RcI4CI2j3FE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3757, '2018-10-01 22:07:50.070121+00', '2018-10-01 22:07:50.070121+00', 5239, 8, 1296, '', 'X', '"The Petronella" is a 32 bar reel for 2 couples.', 1, 1, 'Y', 'i8d_GceuHGc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3758, '2018-10-01 22:07:50.095088+00', '2018-10-01 22:07:50.095088+00', 5262, 5, 1296, '', 'X', '"Pinewoods Reel" is a 32 bar reel for 3 couples.', 1, 1, 'Y', '3IUkhcm_Pfs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3760, '2018-10-01 22:07:50.145107+00', '2018-10-01 22:07:50.145107+00', 5264, 2, 1296, '', 'X', '"Pink Roses" is a 32 bar reel for 2 couples.', 1, 1, 'Y', 'nUv1FMm5Bdc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3761, '2018-10-01 22:07:50.165944+00', '2018-10-01 22:07:50.165944+00', 13469, 4, 1296, '', 'X', '"The Pleasure is Mine" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', '2w0Kxi7c0D0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3762, '2018-10-01 22:07:50.184842+00', '2018-10-01 22:07:50.184842+00', 16025, 1, 1296, '', 'X', '"A Plethora of Pinatas" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'JkRvoHCNVWU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3763, '2018-10-01 22:07:50.201333+00', '2018-10-01 22:07:50.201333+00', 5308, 6, 1296, '', 'X', '"Polharrow Burn" is a 32 bar reel for 5 couples.', 1, 1, 'Y', 'kqU-lifwA-8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3764, '2018-10-01 22:07:50.217947+00', '2018-10-01 22:07:50.217947+00', 8788, 2, 1296, '', 'X', '"The Postage Stamp" is a 48 bar jig for 4 couples.', 1, 1, 'Y', '1LsZ5-EqU88', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3765, '2018-10-01 22:07:50.234929+00', '2018-10-01 22:07:50.234929+00', 5330, 13, 1296, '', 'X', '"Postie''s Jig" is a 32 bar jig for 4 couples.', 1, 1, 'Y', '-cofaNHEYhA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3766, '2018-10-01 22:07:50.252901+00', '2018-10-01 22:07:50.252901+00', 5384, 4, 1296, '', 'X', '"The Provost Wynd" is a 32 bar reel for 3 couples.', 1, 1, 'Y', '7CK17XvB-_8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3767, '2018-10-01 22:07:50.275017+00', '2018-10-01 22:07:50.275017+00', 5407, 8, 1296, '', 'X', '"Quarrie''s Jig" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'XVckARxrZtY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3768, '2018-10-01 22:07:50.308362+00', '2018-10-01 22:07:50.308362+00', 5462, 2, 1296, '', 'X', '"Rakes of Glasgow" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'hUAE2au3qp8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3769, '2018-10-01 22:07:50.329387+00', '2018-10-01 22:07:50.329387+00', 5463, 3, 1296, '', 'X', '"The Rakish Highlandman" is a 40 bar jig for 3 couples.', 1, 1, 'Y', 'pTGUDU_HO_k', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3770, '2018-10-01 22:07:50.35505+00', '2018-10-01 22:07:50.35505+00', 10773, 3, 1296, '', 'X', '"The Raven''s Dance" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'v0QTNiRrF5E', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3771, '2018-10-01 22:07:50.379545+00', '2018-10-01 22:07:50.379545+00', 5497, 8, 1296, '', 'X', '"Red House" is a 40 bar reel for 2 couples.', 1, 1, 'Y', 'KREkgzivkRw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3772, '2018-10-01 22:07:50.62869+00', '2018-10-01 22:07:50.62869+00', 3027, 6, 1296, '', 'X', '"The Hunting Horn" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'In1kNlHet04', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3773, '2018-10-01 22:07:50.704183+00', '2018-10-01 22:07:50.704183+00', 7285, 5, 1296, '', 'X', '"The Immigrant Lass" is a 32 bar jig for 4 couples.', 1, 1, 'Y', 'CVdLyd-3PBk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3774, '2018-10-01 22:07:50.728923+00', '2018-10-01 22:07:50.728923+00', 15321, 2, 1296, '', 'X', '"The Impressive Clergyman" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '-IifAnHQNM0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4028, '2018-10-16 20:52:37.077033+00', '2018-10-16 21:13:29.983062+00', 8060, 1, 1645, '', 'C', 'Danced in three couple sets', 1, 1, 'Y', 'AJ4rCwTmInA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3775, '2018-10-01 22:07:50.753971+00', '2018-10-01 22:07:50.753971+00', 13465, 2, 1296, '', 'X', '"It Should Be Fun" is a 32 bar jig for 4 couples.', 1, 1, 'Y', '6HKTuLNAsHg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3776, '2018-10-01 22:07:50.785867+00', '2018-10-01 22:07:50.785867+00', 9087, 3, 1296, '', 'X', '"It''s Nae Bother" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'V9Axf0Hm4n8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3777, '2018-10-01 22:07:50.800476+00', '2018-10-01 22:07:50.800476+00', 3129, 5, 1296, '', 'X', '"The Irish Rover" is a 32 bar reel for 3 couples.', 1, 1, 'Y', '7St3J1LnHKg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3779, '2018-10-01 22:07:50.877543+00', '2018-10-01 22:07:50.877543+00', 12542, 9, 1296, '', 'X', '"Jean Martin of Aberdeen" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'rFt-palyxbY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3780, '2018-10-01 22:07:50.902325+00', '2018-10-01 22:07:50.902325+00', 3231, 4, 1296, '', 'X', '"Jennifer''s Jig" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'cJYPBprPwy4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3781, '2018-10-01 22:07:50.923615+00', '2018-10-01 22:07:50.923615+00', 3246, 3, 1296, '', 'X', '"Jessie''s Hornpipe" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'N7I6xUPGT4A', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3782, '2018-10-01 22:07:50.948642+00', '2018-10-01 22:07:50.948642+00', 13618, 3, 1296, '', 'X', '"Jig to the Music" is a 32 bar jig for 3 couples.', 1, 1, 'Y', '7db9tcfpUjw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4038, '2018-10-18 19:15:42.196401+00', '2018-10-18 20:25:13.650432+00', 209, 1, 118, '', 'C', '', 1, 1, 'Y', '0Gnfe1JGUmU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3783, '2018-10-01 22:07:50.970613+00', '2018-10-01 22:07:50.970613+00', 3310, 3, 1296, '', 'X', '"Joe MacDiarmid''s Jig" is a 32 bar jig for 4 couples.', 1, 1, 'Y', 'BFRWVqwmGrg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3784, '2018-10-01 22:07:50.991462+00', '2018-10-01 22:07:50.991462+00', 3323, 3, 1296, '', 'X', '"John McAlpin" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'icAoNmtkqRY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3785, '2018-10-01 22:07:51.011372+00', '2018-10-01 22:07:51.011372+00', 3326, 7, 1296, '', 'X', '"John of Bon Accord" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'vtMpPzcGRu8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3786, '2018-10-01 22:07:51.03194+00', '2018-10-01 22:07:51.03194+00', 7283, 6, 1296, '', 'X', '"Joie de Vivre" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'NfreT3R_xrY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3787, '2018-10-01 22:07:51.05186+00', '2018-10-01 22:07:51.05186+00', 3365, 8, 1296, '', 'X', '"The Jubilee Jig" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'w3VUZA_vzWs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3788, '2018-10-01 22:07:51.072726+00', '2018-10-01 22:07:51.072726+00', 14573, 2, 1296, '', 'X', '"Katherine''s Birthday" is a 32 bar reel for 2 couples.', 1, 1, 'Y', 'fjoUJyw00k4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3789, '2018-10-01 22:07:51.088136+00', '2018-10-01 22:07:51.088136+00', 3435, 6, 1296, '', 'X', '"Kendall''s Hornpipe" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'CVD25yb2rQU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3790, '2018-10-01 22:07:51.104818+00', '2018-10-01 22:07:51.104818+00', 15324, 2, 1296, '', 'X', '"A King in Patagonia" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'WYFSfl7vI54', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3791, '2018-10-01 22:07:51.21352+00', '2018-10-01 22:07:51.21352+00', 3528, 2, 1296, '', 'X', '"Kiss Me Quick, My Mither''s Coming" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'ZDwsbjXF274', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3792, '2018-10-01 22:07:51.255396+00', '2018-10-01 22:07:51.255396+00', 14977, 6, 1296, '', 'X', '"The Kissing Bridge" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'tob_3jL0eWc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3793, '2018-10-01 22:07:51.284644+00', '2018-10-01 22:07:51.284644+00', 14447, 2, 1296, '', 'X', '"Ladies of Berkeau" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '9snXwF_W6-o', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3794, '2018-10-01 22:07:51.318205+00', '2018-10-01 22:07:51.318205+00', 3580, 6, 1296, '', 'X', '"Ladies'' Fancy" is a 32 bar jig for 2 couples.', 1, 1, 'Y', '9ojWWZOnPEI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3795, '2018-10-01 22:07:51.343141+00', '2018-10-01 22:07:51.343141+00', 3588, 3, 1296, '', 'X', '"Lady Auckland''s Reel" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'FWNesRlE-pY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3796, '2018-10-01 22:07:51.367832+00', '2018-10-01 22:07:51.367832+00', 3594, 5, 1296, '', 'X', '"Lady Catherine Bruce''s Reel" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'jGwGZsWibXQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3797, '2018-10-01 22:07:51.392334+00', '2018-10-01 22:07:51.392334+00', 3607, 4, 1296, '', 'X', '"Lady Glasgow" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'g9JRd6ngZxs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3798, '2018-10-01 22:07:51.418178+00', '2018-10-01 22:07:51.418178+00', 3616, 3, 1296, '', 'X', '"Lady Lucy Ramsay" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'CN4fE1GqY5k', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3799, '2018-10-01 22:07:51.443333+00', '2018-10-01 22:07:51.443333+00', 3659, 7, 1296, '', 'X', '"The Laird of Milton''s Daughter" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'XAv8klKff0Q', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3800, '2018-10-01 22:07:51.467561+00', '2018-10-01 22:07:51.467561+00', 7795, 4, 1296, '', 'X', '"The Lass of Richmond Hill" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'Hyga1QQ3R3Q', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3801, '2018-10-01 22:07:51.486959+00', '2018-10-01 22:07:51.486959+00', 3802, 5, 1296, '', 'X', '"Light and Airy" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'naZkT5ADRbc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3802, '2018-10-01 22:07:51.507362+00', '2018-10-01 22:07:51.507362+00', 3803, 2, 1296, '', 'X', '"Light on the Water" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '3c9M5ROpro4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3803, '2018-10-01 22:07:51.524263+00', '2018-10-01 22:07:51.524263+00', 14341, 2, 1296, '', 'X', '"The Lightnin'' Bug" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'UoPMgiY97zQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3961, '2018-10-03 22:47:42.862895+00', '2018-10-03 22:48:01.26047+00', 18721, 1, 106, '', 'X', '', 1, 1, 'Y', 'pa5QlgyMEt8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3804, '2018-10-01 22:07:51.540725+00', '2018-10-01 22:07:51.540725+00', 11284, 6, 1296, '', 'X', '"Linnea''s Strathspey" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'vtGD0xb_Xf0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3805, '2018-10-01 22:07:51.557346+00', '2018-10-01 22:07:51.557346+00', 3834, 7, 1296, '', 'X', '"The Linton Ploughman" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'wg5klQ-SM6E', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3806, '2018-10-01 22:07:51.58789+00', '2018-10-01 22:07:51.58789+00', 3980, 6, 1296, '', 'X', '"Luckenbooth Brooch" is a 32 bar jig for 3 couples.', 1, 1, 'Y', '1fxMjaQDcSs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3807, '2018-10-01 22:07:51.611105+00', '2018-10-01 22:07:51.611105+00', 14375, 2, 1296, '', 'X', '"MAB of McLeod" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'h9-e0PD0g9A', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3808, '2018-10-01 22:07:51.690269+00', '2018-10-01 22:07:51.690269+00', 4015, 8, 1296, '', 'X', '"MacDonald of the Isles" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '6AHMYKB1UGM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3809, '2018-10-01 22:07:51.740621+00', '2018-10-01 22:07:51.740621+00', 4032, 4, 1296, '', 'X', '"The Machine Without Horses" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'cxte3fMiJbc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3810, '2018-10-01 22:07:51.772729+00', '2018-10-01 22:07:51.772729+00', 4058, 2, 1296, '', 'X', '"The Mad Hatter" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'PYb6pE0efOY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3811, '2018-10-01 22:07:51.805941+00', '2018-10-01 22:07:51.805941+00', 13357, 2, 1296, '', 'X', '"The Magic of Merrill" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'Iw9Zc2Cxm_w', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3812, '2018-10-01 22:07:51.831952+00', '2018-10-01 22:07:51.831952+00', 4102, 13, 1296, '', 'X', '"Mairi''s Wedding" is a 40 bar reel for 3 couples.', 1, 1, 'Y', 'WwOPNOZHQ5g', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3813, '2018-10-01 22:07:51.853306+00', '2018-10-01 22:07:51.853306+00', 4106, 5, 1296, '', 'X', '"Major Ian Stewart" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'tcGXW-PTTs0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3815, '2018-10-01 22:07:51.911167+00', '2018-10-01 22:07:51.911167+00', 4196, 2, 1296, '', 'X', '"The Marquis of Lorne" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'pzbnl-eXbbw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3816, '2018-10-01 22:07:51.927261+00', '2018-10-01 22:07:51.927261+00', 9008, 5, 1296, '', 'X', '"Mary Erskine" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'MKa7-ZMmb9M', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3817, '2018-10-01 22:07:52.160079+00', '2018-10-01 22:07:52.160079+00', 2044, 2, 1296, '', 'X', '"The Fairy Dance" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'N6MbQ6gW-1Y', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3818, '2018-10-01 22:07:52.268+00', '2018-10-01 22:07:52.268+00', 2063, 5, 1296, '', 'X', '"The Falls of Rogie" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'mKnP3fBl3fM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3819, '2018-10-01 22:07:52.291677+00', '2018-10-01 22:07:52.291677+00', 15315, 2, 1296, '', 'X', '"Farm Boy" is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'IVXnrZww8-U', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3820, '2018-10-01 22:07:52.311485+00', '2018-10-01 22:07:52.311485+00', 2125, 5, 1296, '', 'X', '"Ferla Mor" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'is-Qxvis6Ik', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3821, '2018-10-01 22:07:52.333717+00', '2018-10-01 22:07:52.333717+00', 8630, 3, 1296, '', 'X', '"Fermat''s Bicycle" is a 40 bar strathspey for 4 couples.', 1, 1, 'Y', 'Uyab1rVFYeU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3822, '2018-10-01 22:07:52.365741+00', '2018-10-01 22:07:52.365741+00', 2126, 4, 1296, '', 'X', '"The Ferry Louper" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'WoJpTAq3rR0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3823, '2018-10-01 22:07:52.387817+00', '2018-10-01 22:07:52.387817+00', 10647, 2, 1296, '', 'X', '"Fiddlin'' Round" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'Fb2QQzXsAiw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3824, '2018-10-01 22:07:52.413114+00', '2018-10-01 22:07:52.413114+00', 2166, 3, 1296, '', 'X', '"Fight About the Fireside" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'eRlBJFXBMFA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3826, '2018-10-01 22:07:52.462341+00', '2018-10-01 22:07:52.462341+00', 11483, 4, 1296, '', 'X', '"Flight to Melbourne" is a 32 bar reel for 4 couples.', 1, 1, 'Y', 'ZjTEBi2h0Lg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3827, '2018-10-01 22:07:52.482676+00', '2018-10-01 22:07:52.482676+00', 9382, 2, 1296, '', 'X', '"Flights of Fancy" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'vlAcQms5dUQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3825, '2018-10-01 22:07:52.439183+00', '2020-12-19 01:40:03.834141+00', 2222, 3, 1296, '', 'Z', '"Flight of the Falcon" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'pOW8fOxYY-s', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3778, '2018-10-01 22:07:50.855478+00', '2021-11-21 22:33:41.875133+00', 3172, 8, 1296, '', 'X', '"J. B. Milne" is a 32 bar reel for 3 couples.', 1, 1, 'Y', '6bVdgfRE36A', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3828, '2018-10-01 22:07:52.498062+00', '2018-10-01 22:07:52.498062+00', 2228, 3, 1296, '', 'X', '"The Flirtation Hornpipe" is a 32 bar reel for 4 couples.', 1, 1, 'Y', 'cXs32a99tTw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3829, '2018-10-01 22:07:52.514437+00', '2018-10-01 22:07:52.514437+00', 16533, 3, 1296, '', 'X', '"Flora''s Fancy" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'lbtQCxm_AZc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3830, '2018-10-01 22:07:52.531022+00', '2018-10-01 22:07:52.531022+00', 12941, 5, 1296, '', 'X', '"The Flower of Glasgow" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '5xKcAHuD2FQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3831, '2018-10-01 22:07:52.556966+00', '2018-10-01 22:07:52.556966+00', 8258, 2, 1296, '', 'X', '"The Folksy Fivesome" is a 32 bar reel for 5 couples.', 1, 1, 'Y', 'Bnnad0tTdpE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3832, '2018-10-01 22:07:52.572766+00', '2018-10-01 22:07:52.572766+00', 2267, 8, 1296, '', 'X', '"Follow Me Home" is a 32 bar jig for 3 couples.', 1, 1, 'Y', '2NhheEugnDs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3833, '2018-10-01 22:07:52.597925+00', '2018-10-01 22:07:52.597925+00', 15325, 2, 1296, '', 'X', '"Four White Horses" is a 32 bar jig for 4 couples.', 1, 1, 'Y', 'tjbw9iBfpVQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3834, '2018-10-01 22:07:52.617383+00', '2018-10-01 22:07:52.617383+00', 2349, 4, 1296, '', 'X', '"The Frisky" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'eVj_yz-uELA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3889, '2018-10-01 22:07:54.212824+00', '2018-10-01 22:07:54.212824+00', 9084, 6, 1296, '', 'X', '"Domino Five" is a 32 bar reel for 5 couples.', 1, 1, 'Y', 'qDzKlR_Ken8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3835, '2018-10-01 22:07:52.636016+00', '2018-10-01 22:07:52.636016+00', 2353, 5, 1296, '', 'X', '"From Scotia''s Shores We''re Noo Awa''" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'Ysocmbsq0rU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3836, '2018-10-01 22:07:52.652717+00', '2018-10-01 22:07:52.652717+00', 695, 3, 1296, '', 'X', '"Gaelforce Wind" is a 32 bar jig for 3 couples.', 1, 1, 'Y', '1klIrYBGTpc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3837, '2018-10-01 22:07:52.669173+00', '2018-10-01 22:07:52.669173+00', 13585, 4, 1296, '', 'X', '"The Gardeners'' Fantasia" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'H8tQ-_h2R9Y', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3838, '2018-10-01 22:07:52.685957+00', '2018-10-01 22:07:52.685957+00', 2409, 5, 1296, '', 'X', '"Garry Strathspey" is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'Haj3EUdpq6M', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3839, '2018-10-01 22:07:52.702665+00', '2018-10-01 22:07:52.702665+00', 2428, 8, 1296, '', 'X', '"General Stuart''s Reel" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'biXVzZnxOBI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3840, '2018-10-01 22:07:52.722715+00', '2018-10-01 22:07:52.722715+00', 2437, 8, 1296, '', 'X', '"The Gentleman" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'usTsPicX9SU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3842, '2018-10-01 22:07:52.768549+00', '2018-10-01 22:07:52.768549+00', 2506, 4, 1296, '', 'X', '"Glayva" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'Dwww_X6Wc9Q', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3843, '2018-10-01 22:07:52.787746+00', '2018-10-01 22:07:52.787746+00', 11217, 2, 1296, '', 'X', '"The Glenora Ferry" is a 40 bar jig for 3 couples.', 1, 1, 'Y', '_AAXTNIGeAo', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3844, '2018-10-01 22:07:52.80352+00', '2018-10-01 22:07:52.80352+00', 10695, 2, 1296, '', 'X', '"Gloria''s Wee Jig" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'WV05fVj0upU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3845, '2018-10-01 22:07:52.820308+00', '2018-10-01 22:07:52.820308+00', 13742, 2, 1296, '', 'X', '"The Golden Apple Jig" is a 40 bar jig for 3 couples.', 1, 1, 'Y', 'zbORQxfv9T8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3846, '2018-10-01 22:07:52.844156+00', '2018-10-01 22:07:52.844156+00', 2604, 6, 1296, '', 'X', '"Good Hearted Glasgow" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'KakF7zF4MOA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3847, '2018-10-01 22:07:52.868226+00', '2018-10-01 22:07:52.868226+00', 2651, 2, 1296, '', 'X', '"Great Expectations" is a 32 bar reel for 2 couples.', 1, 1, 'Y', '4azyj8RS61w', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3848, '2018-10-01 22:07:52.888547+00', '2018-10-01 22:07:52.888547+00', 2686, 2, 1296, '', 'X', '"Grey Daylight" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'YE-A2gpGN4I', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3849, '2018-10-01 22:07:52.908876+00', '2018-10-01 22:07:52.908876+00', 2711, 2, 1296, '', 'X', '"HISCD" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'aN-z9dl_EmU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3850, '2018-10-01 22:07:52.924574+00', '2018-10-01 22:07:52.924574+00', 2747, 3, 1296, '', 'X', '"The Hamilton Rant" is a 48 bar reel for 3 couples.', 1, 1, 'Y', 'DSYs5KOqsLg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3851, '2018-10-01 22:07:52.947494+00', '2018-10-01 22:07:52.947494+00', 2777, 3, 1296, '', 'X', '"The Happy Meeting" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'jb9LucRzPhg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3852, '2018-10-01 22:07:52.972321+00', '2018-10-01 22:07:52.972321+00', 15137, 2, 1296, '', 'X', '"The Hare Reel" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'unEDLyYnuA0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3853, '2018-10-01 22:07:52.993496+00', '2018-10-01 22:07:52.993496+00', 2807, 4, 1296, '', 'X', '"Haste to the Wedding" is a 32 bar jig for 2 couples.', 1, 1, 'Y', '9eTYLA-PQAQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3854, '2018-10-01 22:07:53.013365+00', '2018-10-01 22:07:53.013365+00', 13619, 5, 1296, '', 'X', '"Hedwig''s Reel" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'yM3uYchHdEc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3855, '2018-10-01 22:07:53.041038+00', '2018-10-01 22:07:53.041038+00', 2900, 2, 1296, '', 'X', '"The High Lodge" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'Lv_rrfpMdS8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3856, '2018-10-01 22:07:53.056756+00', '2018-10-01 22:07:53.056756+00', 2910, 5, 1296, '', 'X', '"Highland Fair" is a 32 bar jig for 2 couples.', 1, 1, 'Y', '0SwknQRJ8tA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3963, '2018-10-03 23:30:18.886541+00', '2018-10-03 23:30:57.898533+00', 2428, 9, 1645, '', 'B', '', 1, 1, 'Y', 'oCBQWzBzVO8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3857, '2018-10-01 22:07:53.073476+00', '2018-10-01 22:07:53.073476+00', 2918, 2, 1296, '', 'X', '"The Highland Lass" is a 32 bar reel for 3 couples.', 1, 1, 'Y', '-sTMeKpOlr8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3858, '2018-10-01 22:07:53.090235+00', '2018-10-01 22:07:53.090235+00', 8056, 3, 1296, '', 'X', '"Highland Mary" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'HEIK5NX9Sd4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3859, '2018-10-01 22:07:53.106757+00', '2018-10-01 22:07:53.106757+00', 2924, 6, 1296, '', 'X', '"Highland Rambler" is a 40 bar reel for 3 couples.', 1, 1, 'Y', 'K2UKz-cnpxk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3860, '2018-10-01 22:07:53.132252+00', '2018-10-01 22:07:53.132252+00', 2935, 2, 1296, '', 'X', '"The Highlandman''s Umbrella" is a 32 bar reel for 4 couples.', 1, 1, 'Y', 'cFOuNrPM2iA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3861, '2018-10-01 22:07:53.153732+00', '2018-10-01 22:07:53.153732+00', 2979, 4, 1296, '', 'X', '"Hooper''s Jig" is a 32 bar jig for 3 couples.', 1, 1, 'Y', '6YgS76LgnXI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3862, '2018-10-01 22:07:53.171711+00', '2018-10-01 22:07:53.171711+00', 7420, 4, 1296, '', 'X', '"Hope Little''s Strathspey" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'oUvpJyRhimc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3863, '2018-10-01 22:07:53.432947+00', '2018-10-01 22:07:53.432947+00', 373, 4, 1296, '', 'X', '"Balmoral Strathspey" is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'Avq6Lt31VNI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3864, '2018-10-01 22:07:53.499231+00', '2018-10-01 22:07:53.499231+00', 377, 4, 1296, '', 'X', '"Balquidder Strathspey" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '4tonGm2yU2I', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3865, '2018-10-01 22:07:53.524193+00', '2018-10-01 22:07:53.524193+00', 13149, 10, 1296, '', 'X', '"Barbara''s Strathspey" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'jYBxBM9OYMg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3866, '2018-10-01 22:07:53.57351+00', '2018-10-01 22:07:53.57351+00', 410, 3, 1296, '', 'X', '"Barley Bree" is a 40 bar jig for 4 couples.', 1, 1, 'Y', 'tIH8tyfB7A8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3867, '2018-10-01 22:07:53.603537+00', '2018-10-01 22:07:53.603537+00', 413, 9, 1296, '', 'X', '"The Barmkin" is a 88 bar reel for 4 couples.', 1, 1, 'Y', 'ard2ojZdYyU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3868, '2018-10-01 22:07:53.628192+00', '2018-10-01 22:07:53.628192+00', 445, 12, 1296, '', 'X', '"The Bees of Maggieknockater" is a 32 bar jig for 4 couples.', 1, 1, 'Y', '2z9P1Y4pgZM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3869, '2018-10-01 22:07:53.649916+00', '2018-10-01 22:07:53.649916+00', 462, 7, 1296, '', 'X', '"The Belle of Bon Accord" is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'EYNvREKEi3w', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3870, '2018-10-01 22:07:53.667606+00', '2018-10-01 22:07:53.667606+00', 12426, 7, 1296, '', 'X', '"Best Set in the Hall" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'VfeI7S6XSM4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3871, '2018-10-01 22:07:53.683225+00', '2018-10-01 22:07:53.683225+00', 13577, 5, 1296, '', 'X', '"Bill Clement MBE" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'SXiT1EpTTcw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3873, '2018-10-01 22:07:53.716444+00', '2018-10-01 22:07:53.716444+00', 541, 3, 1296, '', 'X', '"The Black Dance" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'vrk_QrHBpcY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3874, '2018-10-01 22:07:53.733328+00', '2018-10-01 22:07:53.733328+00', 542, 4, 1296, '', 'X', '"Black Donald" is a 32 bar jig for 2 couples.', 1, 1, 'Y', '5rFtzdlinKY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3875, '2018-10-01 22:07:53.750304+00', '2018-10-01 22:07:53.750304+00', 11108, 3, 1296, '', 'X', '"Blackadder Jig" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'DZT7ARAWHkU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3876, '2018-10-01 22:07:53.773744+00', '2018-10-01 22:07:53.773744+00', 584, 6, 1296, '', 'X', '"Blooms of Bon Accord" is a 32 bar reel for 4 couples.', 1, 1, 'Y', '5qxVbYgHRXc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3877, '2018-10-01 22:07:53.877421+00', '2018-10-01 22:07:53.877421+00', 604, 4, 1296, '', 'X', '"Bob Campbell" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '-Bh65RmUz5Y', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3878, '2018-10-01 22:07:53.900182+00', '2018-10-01 22:07:53.900182+00', 674, 5, 1296, '', 'X', '"Bonnie Stronshiray" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'TVYgFl0HEAY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3879, '2018-10-01 22:07:53.924756+00', '2018-10-01 22:07:53.924756+00', 743, 9, 1296, '', 'X', '"Braes of Breadalbane" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'vJkflZPIH3Q', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3880, '2018-10-01 22:07:53.990219+00', '2018-10-01 22:07:53.990219+00', 760, 3, 1296, '', 'X', '"The Bramble Bush" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'BxQwzDcSBMc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4327, '2019-02-13 22:12:06.848439+00', '2019-02-16 10:29:05.551765+00', 4155, 6, 1645, '', 'A', '', 1, 1, 'Y', 'NOTCSM0v_Bk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3881, '2018-10-01 22:07:54.039228+00', '2018-10-01 22:07:54.039228+00', 769, 6, 1296, '', 'X', '"Bratach Bana" is a 32 bar reel for 3 couples.', 1, 1, 'Y', '4nQuU1McZec', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3882, '2018-10-01 22:07:54.071327+00', '2018-10-01 22:07:54.071327+00', 776, 2, 1296, '', 'X', '"The Breakdown" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'mIKFyETzD_0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3883, '2018-10-01 22:07:54.092006+00', '2018-10-01 22:07:54.092006+00', 794, 8, 1296, '', 'X', '"Bridge of Nairn" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'PW65XmUMlgk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3884, '2018-10-01 22:07:54.1202+00', '2018-10-01 22:07:54.1202+00', 845, 3, 1296, '', 'X', '"The Brudenell Jig" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'vn1Xq1PW3jo', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3885, '2018-10-01 22:07:54.14722+00', '2018-10-01 22:07:54.14722+00', 888, 3, 1296, '', 'X', '"The Button Boy" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'JNErGWCpqJk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3886, '2018-10-01 22:07:54.162194+00', '2018-10-01 22:07:54.162194+00', 894, 5, 1296, '', 'X', '"The Byron Strathspey" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'AxE9PWViZeE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3887, '2018-10-01 22:07:54.178848+00', '2018-10-01 22:07:54.178848+00', 895, 4, 1296, '', 'X', '"C''est L''Amour" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'k4QdnJk2bR4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3888, '2018-10-01 22:07:54.196006+00', '2018-10-01 22:07:54.196006+00', 15319, 2, 1296, '', 'X', '"A Dizzying Intellect" is a 32 bar jig for 3 couples.', 1, 1, 'Y', '_nAVCsUK4eE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3890, '2018-10-01 22:07:54.232075+00', '2018-10-01 22:07:54.232075+00', 1677, 3, 1296, '', 'X', '"Donald Bane" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'wncKl97Q1mI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3891, '2018-10-01 22:07:54.25265+00', '2018-10-01 22:07:54.25265+00', 1668, 2, 1296, '', 'X', '"Dr Sally Hayes" is a 32 bar jig for 3 couples.', 1, 1, 'Y', '9XujYPWvCkQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3892, '2018-10-01 22:07:54.27416+00', '2018-10-01 22:07:54.27416+00', 10433, 12, 1296, '', 'X', '"The Dream Catcher" is a 96 bar strathspey for 4 couples.', 1, 1, 'Y', 'zY3HIA3C_Ec', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3893, '2018-10-01 22:07:54.294618+00', '2018-10-01 22:07:54.294618+00', 1782, 8, 1296, '', 'X', '"Duke & Duchess of Edinburgh" is a 40 bar reel for 3 couples.', 1, 1, 'Y', 'gFjhqUDoerc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3894, '2018-10-01 22:07:54.315511+00', '2018-10-01 22:07:54.315511+00', 1786, 7, 1296, '', 'X', '"The Duke of Atholl''s Reel" is a 32 bar jig for 2 couples.', 1, 1, 'Y', '5TL5yiVNiH0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3895, '2018-10-01 22:07:54.336324+00', '2018-10-01 22:07:54.336324+00', 1792, 10, 1296, '', 'X', '"Duke of Perth" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'xhmpaUPVOwY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3896, '2018-10-01 22:07:54.357358+00', '2018-10-01 22:07:54.357358+00', 9107, 8, 1296, '', 'X', '"EH3 7AF" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'BI7JvPhTzK8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3897, '2018-10-01 22:07:54.37823+00', '2018-10-01 22:07:54.37823+00', 1961, 2, 1296, '', 'X', '"Ellie''s Jig" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'gUVDdoQuaM0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3898, '2018-10-01 22:07:54.397551+00', '2018-10-01 22:07:54.397551+00', 10102, 3, 1296, '', 'X', '"The Elusive Muse" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'iwVA73oNbb4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3899, '2018-10-01 22:07:54.417917+00', '2018-10-01 22:07:54.417917+00', 14574, 2, 1296, '', 'X', '"Emerald Hills of Home" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'A60tEiZmHbU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3900, '2018-10-01 22:07:54.433905+00', '2018-10-01 22:07:54.433905+00', 1982, 3, 1296, '', 'X', '"The Enchanted Garden" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'H7kS5lk6hNQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3901, '2018-10-01 22:07:54.451214+00', '2018-10-01 22:07:54.451214+00', 1983, 2, 1296, '', 'X', '"The Enchanted Isle" is a 32 bar reel for 2 couples.', 1, 1, 'Y', 'uGnixc6Pglk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3902, '2018-10-01 22:07:54.466756+00', '2018-10-01 22:07:54.466756+00', 1989, 4, 1296, '', 'X', '"Enniskillen Dragoons" is a 32 bar jig for 4 couples.', 1, 1, 'Y', 'F7SBa-i050I', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3904, '2018-10-01 22:07:54.500199+00', '2018-10-01 22:07:54.500199+00', 2027, 2, 1296, '', 'X', '"The Faerie Flag of the McLeods" is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'l8Nr7cDnc-4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3905, '2018-10-01 22:07:54.517176+00', '2018-10-01 22:07:54.517176+00', 2030, 4, 1296, '', 'X', '"Fair Donald" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'YcNEVd65Fm8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3906, '2018-10-01 22:07:54.533504+00', '2018-10-01 22:07:54.533504+00', 16803, 3, 1296, '', 'X', '"Fair Enough" is a 32 bar jig for 4 couples.', 1, 1, 'Y', 'hn_iNMnNhbw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3907, '2018-10-01 22:07:54.591905+00', '2018-10-01 22:07:54.591905+00', 2034, 5, 1296, '', 'X', '"Fair Jenny''s Jig" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'SmksbuesolE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3908, '2018-10-01 22:07:54.877458+00', '2018-10-01 22:07:54.877458+00', 1022, 2, 1296, '', 'X', '"Captain Ross" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'Oc_4CGXwYT4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3909, '2018-10-01 22:07:54.908731+00', '2018-10-01 22:07:54.908731+00', 1066, 3, 1296, '', 'X', '"Castle Douglas" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'nZ5VlDJaV28', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3910, '2018-10-01 22:07:54.946286+00', '2018-10-01 22:07:54.946286+00', 1087, 9, 1296, '', 'X', '"Catch the Wind" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'WsxjaYQ6BdY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3962, '2018-10-03 23:19:43.506253+00', '2018-10-03 23:31:23.919685+00', 17006, 1, 1645, '', 'B', '', 1, 1, 'Y', 'Oh9wAhOGauU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3911, '2018-10-01 22:07:54.969383+00', '2018-10-01 22:07:54.969383+00', 1163, 4, 1296, '', 'X', '"The Charmer" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'x8Yl9oN8Bb8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3912, '2018-10-01 22:07:54.98329+00', '2018-10-01 22:07:54.98329+00', 14738, 3, 1296, '', 'X', '"Chasing the Eclipse" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'HBTr2oOv2ic', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3913, '2018-10-01 22:07:55.00883+00', '2018-10-01 22:07:55.00883+00', 10787, 8, 1296, '', 'X', '"The Chequered Court" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'IDE5mAGnSIY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3914, '2018-10-01 22:07:55.036518+00', '2018-10-01 22:07:55.036518+00', 14371, 3, 1296, '', 'X', '"Chopped Nuts and Chocolate Swirls" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'gWi-V_6flSY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3915, '2018-10-01 22:07:55.059861+00', '2018-10-01 22:07:55.059861+00', 13847, 5, 1296, '', 'X', '"City of Belfast" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '2fLSIkJvx18', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3916, '2018-10-01 22:07:55.077644+00', '2018-10-01 22:07:55.077644+00', 15318, 2, 1296, '', 'X', '"The Cliffs of Insanity" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'DHrSBC2NYZ0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3917, '2018-10-01 22:07:55.092965+00', '2018-10-01 22:07:55.092965+00', 8653, 3, 1296, '', 'X', '"The Clumsy Lover" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'tuvX7sXOuJE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3918, '2018-10-01 22:07:55.108642+00', '2018-10-01 22:07:55.108642+00', 7369, 2, 1296, '', 'X', '"Clydebank Strathspey" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'C_Oe71qFeXk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3919, '2018-10-01 22:07:55.125563+00', '2018-10-01 22:07:55.125563+00', 1280, 11, 1296, '', 'X', '"The College Hornpipe" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'RoU5habLkpY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3920, '2018-10-01 22:07:55.14214+00', '2018-10-01 22:07:55.14214+00', 14552, 3, 1296, '', 'X', '"The Compleat Gardener" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'DnC4KNc0wUM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3921, '2018-10-01 22:07:55.158717+00', '2018-10-01 22:07:55.158717+00', 1348, 7, 1296, '', 'X', '"Corn Rigs" is a 32 bar reel for 2 couples.', 1, 1, 'Y', 'zv3xyIHUPrk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3922, '2018-10-01 22:07:55.185522+00', '2018-10-01 22:07:55.185522+00', 9157, 6, 1296, '', 'X', '"The Cranberry Tart" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'EV6KdPnWSYo', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3923, '2018-10-01 22:07:55.207322+00', '2018-10-01 22:07:55.207322+00', 10463, 3, 1296, '', 'X', '"The Craven Reel" is a 32 bar reel for 3 couples.', 1, 1, 'Y', '7TAIE-XRBPw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3924, '2018-10-01 22:07:55.235422+00', '2018-10-01 22:07:55.235422+00', 1469, 4, 1296, '', 'X', '"Cuillins of Skye" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'pF5S3R-2TZ0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3925, '2018-10-01 22:07:55.250454+00', '2018-10-01 22:07:55.250454+00', 1473, 10, 1296, '', 'X', '"Culla Bay" is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'hm4RMJMkv0I', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3926, '2018-10-01 22:07:55.274923+00', '2018-10-01 22:07:55.274923+00', 1483, 2, 1296, '', 'X', '"The Cupar Jig" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'htI3ijTlskc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3927, '2018-10-01 22:07:55.295256+00', '2018-10-01 22:07:55.295256+00', 1486, 3, 1296, '', 'X', '"Currie Mountain" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'YG8NIagzm_g', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3928, '2018-10-01 22:07:55.324617+00', '2018-10-01 22:07:55.324617+00', 1492, 3, 1296, '', 'X', '"Da Rain Dancin''''" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'JN1jLdg1Mhk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3929, '2018-10-01 22:07:55.341928+00', '2018-10-01 22:07:55.341928+00', 1501, 7, 1296, '', 'X', '"Dalkeith''s Strathspey" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'C0-YIU2puhQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3930, '2018-10-01 22:07:55.358703+00', '2018-10-01 22:07:55.358703+00', 10693, 2, 1296, '', 'X', '"Dance for Alisa" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'NSObDXbiZ28', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3931, '2018-10-01 22:07:55.375242+00', '2018-10-01 22:07:55.375242+00', 1537, 4, 1296, '', 'X', '"Dancing Dolphins" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'uYPvvgoWql0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3932, '2018-10-01 22:07:55.392031+00', '2018-10-01 22:07:55.392031+00', 13047, 2, 1296, '', 'X', '"Dare to Dance" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'AVgXTPqS6H4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3933, '2018-10-01 22:07:55.446563+00', '2018-10-01 22:07:55.446563+00', 1562, 6, 1296, '', 'X', '"The Dashing White Sergeant" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'yhO4ORCtHfw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3934, '2018-10-01 22:07:55.46546+00', '2018-10-01 22:07:55.46546+00', 1578, 3, 1296, '', 'X', '"Davy Nick Nack" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'vr59Tzjg_BE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3935, '2018-10-01 22:07:55.482259+00', '2018-10-01 22:07:55.482259+00', 1582, 9, 1296, '', 'X', '"The De''''il Amang the Tailors" is a 32 bar reel for 3 couples.', 1, 1, 'Y', '6nUd-oOQUd4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3936, '2018-10-01 22:07:55.496781+00', '2018-10-01 22:07:55.496781+00', 1647, 6, 1296, '', 'X', '"The Diamond Jubilee" is a 32 bar jig for 4 couples.', 1, 1, 'Y', '8HDSAXiJ7jA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3937, '2018-10-01 22:07:55.620706+00', '2018-10-01 22:07:55.620706+00', 899, 3, 1296, '', 'X', '"Ca'' the Ewes tae the Knowes" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'zLZCBvKT8jM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3938, '2018-10-01 22:07:55.636726+00', '2018-10-01 22:07:55.636726+00', 909, 6, 1296, '', 'X', '"Cadgers in the Canongate" is a 48 bar reel for 3 couples.', 1, 1, 'Y', 'Bd6rddumcmQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3939, '2018-10-01 22:07:55.655337+00', '2018-10-01 22:07:55.655337+00', 980, 3, 1296, '', 'X', '"Campbell''s Frolic" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'Bj5kTaJ6apw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3940, '2018-10-01 22:07:55.673985+00', '2018-10-01 22:07:55.673985+00', 1018, 2, 1296, '', 'X', '"Captain MacDonald''s Fancy" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'SVMEpXetXUc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3903, '2018-10-01 22:07:54.483417+00', '2018-10-01 22:19:25.726495+00', 1998, 1, 1296, '', 'X', '"Equilibrium" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'DjAldB_sq5g', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3649, '2018-09-26 09:56:14.891277+00', '2018-10-01 23:01:10.540893+00', 16727, 1, 2824, '', 'A', 'Once through. Part of a demonstration set with bars 29-32 altered (here half turn and half circle, but should be turning one and a half on the sides).', 1, 1, 'Y', 'kgqdeIP0oK8', 341, 420, NULL);
INSERT INTO 'dancevideo' VALUES (1063, '2013-08-18 10:47:50.718855+00', '2018-10-02 14:29:40.908995+00', 1087, 5, 1296, '', 'Z', 'Camera keeps moving around between sets and showing parts of sets, it''s impossilble to follow the dance.. Dancing quality "informal". Reject for SCDDB.', 1, 1, 'Y', 'bD2CX9oM2DI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3943, '2018-10-02 15:43:53.218792+00', '2018-10-02 15:45:07.705884+00', 16773, 1, 1645, '', 'C', '', 1, 1, 'Y', 'hrdn6AOT43g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3944, '2018-10-02 16:52:37.835978+00', '2018-10-02 16:56:51.073702+00', 16104, 1, 1645, '', 'C', '', 1, 1, 'Y', 'Q7GB2SHJaOM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3945, '2018-10-02 16:55:52.972421+00', '2018-10-02 16:58:31.545512+00', 7565, 1, 1645, '', 'C', 'Twice through.', 1, 1, 'Y', 'w6snQyy11Ls', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3946, '2018-10-02 17:08:42.430124+00', '2018-10-02 17:09:50.159883+00', 633, 7, 1645, '', 'B', '', 1, 1, 'Y', '61fW0fFWX_I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3947, '2018-10-02 18:48:49.987472+00', '2018-10-02 18:49:22.595698+00', 10689, 2, 106, '', 'C', '', 1, 1, 'Y', 'Qf3dmhr5_nQ', 33, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2564, '2016-07-13 09:44:27.529428+00', '2018-10-02 18:53:44.779768+00', 10689, 1, 106, '', 'D', 'At the Johnsonville SCD Club''s midwinter dine&dance 2016 (New Zealand).



It looks as if all sets make the error that only 1c+2c instead of 1c+2c+3c dance bars [1-8].', 1, 1, 'Y', 'euJ-mDcF46c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3942, '2018-10-02 15:28:54.017962+00', '2018-10-02 19:32:07.207823+00', 16473, 1, 1645, '', 'C', 'Danced at the RSCDS Torotno 2014 Gala Day in a three couple set with modifications in bars 17-24 to allow a 231 progression instead of 213 as expected for a four couple set.



The instructions say 1st couple should cross up above 2nd woman and cast to 2nd place. Here they cross straight over and cast to 3rd place.

', 1, 1, 'Y', 'G_3pDGJOtBA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3948, '2018-10-02 19:40:14.53458+00', '2018-10-03 17:17:15.524033+00', 15077, 1, 1645, '', 'C', '', 1, 1, 'Y', 'F07VaqYSJLI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3949, '2018-10-02 19:46:08.906621+00', '2018-10-04 10:01:55.016218+00', 11525, 1, 1645, '', 'B', '', 1, 1, 'Y', '3CEuB_OKaO8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2643, '2016-09-07 14:07:18.811599+00', '2018-10-02 12:43:34.606249+00', 6748, 3, 596, '', 'X', '', 1, 1, 'Y', '873MukIFbXc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3941, '2018-10-02 00:12:56.099433+00', '2018-10-02 00:16:27.78744+00', 1100, 5, 106, '', 'X', '', 1, 1, 'Y', 'sAwY72sQPAA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3955, '2018-10-02 20:53:44.936005+00', '2018-10-02 21:02:32.522517+00', 18696, 1, 1645, '', 'C', 'Done four times through (once to the bottom each couple) in a five couple set.', 1, 1, 'Y', 't1YKL0cIdt0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3957, '2018-10-03 16:20:53.868488+00', '2018-10-03 17:14:25.046331+00', 54, 3, 1645, '', 'C', 'In bars 17-32 the crossing/arches should start on the diagonal instead of straight across as seems to be done here.', 1, 1, 'Y', '2q2m-hCVEXE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3950, '2018-10-02 19:55:49.34419+00', '2018-10-03 17:15:36.597883+00', 14435, 2, 1645, '', 'C', 'Danced in a three couple set: the last four bars are modified with 1st couple casting to 3rd place.', 1, 1, 'Y', 'ufqNZGV19j4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3953, '2018-10-02 20:36:18.113606+00', '2018-10-03 17:16:34.588345+00', 5421, 1, 1645, '', 'C', '', 1, 1, 'Y', 'mtOZ0XH33HA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3951, '2018-10-02 20:11:29.109977+00', '2018-10-03 17:18:23.718351+00', 9009, 2, 1645, '', 'B', 'A few wobbles in the later repeats.', 1, 1, 'Y', 'lQIjGhdCqOA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3958, '2018-10-03 17:14:11.102279+00', '2018-10-03 17:19:02.563038+00', 4239, 7, 1645, '', 'B', '', 1, 1, 'Y', 'drnomo7YSaQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3954, '2018-10-02 20:41:35.420901+00', '2018-10-03 17:22:54.249029+00', 2469, 1, 1645, '', 'B', '', 1, 1, 'Y', 'ijsuW4M8DuM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3952, '2018-10-02 20:30:22.296085+00', '2018-10-03 17:25:36.230116+00', 15676, 1, 1645, '', 'B', '', 1, 1, 'Y', 'Kxzwp8FpiZM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3960, '2018-10-03 22:26:27.272551+00', '2018-10-03 22:26:43.076076+00', 16746, 1, 106, '', 'X', '', 1, 1, 'Y', 'J9TglfdEsWg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3965, '2018-10-04 06:25:17.378481+00', '2018-10-04 09:53:56.814852+00', 18208, 2, 20354, '', 'B', 'This is the first time it was danced to my recommended music. It is at a tartan night at Johnsonville. ', 1, 1, 'Y', 'DrlXR-vaTts', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3967, '2018-10-04 09:42:55.470925+00', '2018-10-04 09:55:24.409152+00', 5525, 19, 1645, '', 'D', 'An all male set having a lot of fun (once each couple).', 1, 1, 'Y', 'ZXJePUsflQ8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3956, '2018-10-03 04:14:06.738552+00', '2018-10-04 09:56:06.469631+00', 18408, 2, 513, '', 'A', '', 1, 1, 'Y', 'bvidrsnx0lc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3966, '2018-10-04 07:31:53.134976+00', '2018-10-04 09:59:27.553214+00', 17122, 4, 274, '', 'B', 'Regional SCD Weekend - Znojmo - September 2018', 1, 1, 'Y', '8XHmBKiPMgw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3982, '2018-10-06 01:14:33.664071+00', '2018-10-06 10:59:13.555685+00', 11618, 1, 20354, '', 'B', 'Cayuga Lake is a beautiful ``finger'''' lake in upstate New York. This was danced for the first time here in 1993 in Tawa. Nowadays I  would have had less repetition in the dance, but it is still a reasonable entry in the Cane Toad Collection. This is resurrected from an ancient VHS tape and converted to mp4 by John Patterson. The quality of the recording had deteriorated a wee bit.', 1, 1, 'Y', 'ednf1_ajrxs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3976, '2018-10-05 19:40:05.793254+00', '2018-10-05 19:52:41.681986+00', 18806, 1, 1645, '', 'B', 'The 1st repeat has a little glitch in the set & link which is recovered after the circle.', 1, 1, 'Y', 'fs0A1GovPac', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3968, '2018-10-04 22:26:13.447741+00', '2018-10-05 20:17:45.641026+00', 18033, 1, 1580, '', 'C', '', 1, 1, 'Y', 'nCHuRknYSWs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3969, '2018-10-04 22:30:27.600658+00', '2018-10-05 20:21:17.81466+00', 18272, 2, 1580, '', 'C', '', 1, 1, 'Y', 'qgPKVTaZLqA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3974, '2018-10-05 19:30:12.68821+00', '2018-10-05 21:51:53.30667+00', 5667, 3, 20354, '', 'A', 'Scottish Country Dancing demonstration from 1994 Anzac School, Wellington, in Onslow College. The dances done are Argyll Strathspey, Mrs Stewart''s Jig, and The Rose of Glamis. The entry and exit routines were devised by Noeline O''Connor. The music is provided by Peter Elmes, John Smith, and Merren Simmonds. This was resurrected from an old VHS tape, and converted to an mp4 by John Patterson. Sadly the quality is affected by the deterioration of the tape, but the dancing and playing is of quite high quality.', 1, 1, 'Y', 'Gqo38J6eW98', 466, 677, NULL);
INSERT INTO 'dancevideo' VALUES (68, '2012-03-12 09:46:55.653571+00', '2018-10-03 22:17:14.391252+00', 6484, 1, 1, '', 'X', '', 1, 1, 'Y', '-9rYljhj6Lw', 9, 0, 1);
INSERT INTO 'dancevideo' VALUES (3975, '2018-10-05 19:33:18.770467+00', '2018-10-05 22:40:06.945747+00', 11624, 1, 20354, '', 'B', 'Dance written for the boys (Carlton and Alex) ``joining'''' our dancing. This is from 1993, and recorded in Tawa. The music is from Peter Elmes who selected the tunes. This is resurrected from an old VHS tape, and converted into mp4 by John Patterson, hence the deterioration of the video quality. The dancing is good, especially as this was the first time it had been danced.', 1, 1, 'Y', 'ROltY1wqMBo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3970, '2018-10-05 08:29:28.793558+00', '2018-10-05 22:33:58.872612+00', 11610, 1, 20354, '', 'A', 'This was in fact the first time the dance had been danced. This was by a group of very experienced dancers in 1994. I have recovered this from a video taken at the time. The three tunes used by Peter Elmes are in the title page. I have made no changes to the dance since and the recommended tune is the second in the set.', 1, 1, 'Y', '2LpMjgSa148', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3978, '2018-10-05 19:43:40.709681+00', '2018-10-05 22:42:46.897626+00', 11621, 1, 20354, '', 'B', 'The first time this was danced in 1993, with a group in Tawa. Patricia London is my mother. The music is provided by Peter Elmes, who picked the tune. The dance is from the Cane Toad Collection, my first book of dances. This was resurrected from a VHS tape by John Patterson and converted to mp4. There had been some deterioration ', 1, 1, 'Y', 'wXnjVlqXvfo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4326, '2019-02-13 22:06:12.010849+00', '2019-02-16 10:30:31.279632+00', 5207, 5, 1645, '', 'A', '', 1, 1, 'Y', 'TjYOf9qLZf0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3972, '2018-10-05 19:27:14.532244+00', '2018-10-06 10:21:48.750573+00', 221, 5, 20354, '', 'A', 'Scottish Country Dancing demonstration from 1994 Anzac School, Wellington, in Onslow College. The dances done are Argyll Strathspey, Mrs Stewart''s Jig, and The Rose of Glamis. The entry and exit routines were devised by Noeline O''Connor. The music is provided by Peter Elmes, John Smith, and Merren Simmonds. This was resurrected from an old VHS tape, and converted to an mp4 by John Patterson. Sadly the quality is affected by the deterioration of the tape, but the dancing and playing is of quite high quality.', 1, 1, 'Y', 'Gqo38J6eW98', 76, 321, NULL);
INSERT INTO 'dancevideo' VALUES (3977, '2018-10-05 19:41:41.112401+00', '2018-10-06 11:38:50.070929+00', 11620, 1, 20354, '', 'B', 'From the first time this was danced in 1993 at Tawa. Resurrected from an old VHS tape and hence the video quality is not what it might be. Converted to mp4 by John Patterson. Music by Peter Elmes.



NB this clip starts towards the end of bar 2.', 1, 1, 'Y', 'kpQ5psTAebI', 5, 247, NULL);
INSERT INTO 'dancevideo' VALUES (4034, '2018-10-18 06:00:19.826328+00', '2018-10-18 20:10:48.607034+00', 18206, 1, 20350, '', 'C', 'Danced at Levin SCD Club, 2018.



Rather few clear views of one set, so the dance is a bit hard to follow.

', 1, 1, 'Y', 'V9OYwvikKgI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4035, '2018-10-18 18:59:52.931365+00', '2018-10-18 20:14:19.919228+00', 410, 4, 118, '', 'B', '', 1, 1, 'Y', 'lqlAJryPiq0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3985, '2018-10-06 04:33:52.137397+00', '2018-10-06 11:38:18.529087+00', 11615, 1, 20354, '', 'B', 'First time danced in 1993 in Tawa. Maureen was a lovely dance teacher from Ithaca in upstate New York, and loved vigorous dances, so I wrote this for her in that spirit. She also was a founder of Moosewood Restaurant. Music was by Peter Elmes. Resurrected from and ancient VHS to mp4 by John  Patterson.', 1, 1, 'Y', 'yh-NvoO_RNs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3959, '2018-10-03 22:04:39.421314+00', '2018-10-03 22:05:00.425229+00', 13449, 1, 106, '', 'X', '', 1, 1, 'Y', 'vmj_b56m68s', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3983, '2018-10-06 02:49:53.816994+00', '2018-10-06 08:55:56.500758+00', 11610, 2, 20354, '', 'A', 'Danced in 1994 at Tawa. Resurrected from a VHS tape by John Patterson. Watching Iain Boyd and Noeline O''Connor dance together in the Cane Toad Jig is a joy with their lovely covering. Music by Peter Elmes.', 1, 1, 'Y', 'vqSLBgO-_Qo', 0, 277, NULL);
INSERT INTO 'dancevideo' VALUES (3973, '2018-10-05 19:29:03.505444+00', '2018-10-06 10:25:31.190573+00', 4805, 11, 20354, '', 'A', 'Scottish Country Dancing demonstration from 1994 Anzac School, Wellington, in Onslow College. The dances done are Argyll Strathspey, Mrs Stewart''s Jig, and The Rose of Glamis. The entry and exit routines were devised by Noeline O''Connor. The music is provided by Peter Elmes, John Smith, and Merren Simmonds. This was resurrected from an old VHS tape, and converted to an mp4 by John Patterson. Sadly the quality is affected by the deterioration of the tape, but the dancing and playing is of quite high quality.



NB the first four bars of this clip of Mrs Stewart''s Jig are modified with the couple in 3rd place also setting and casting to 4th place.', 1, 1, 'Y', 'Gqo38J6eW98', 321, 466, NULL);
INSERT INTO 'dancevideo' VALUES (3991, '2018-10-08 18:02:30.07575+00', '2018-10-09 00:05:01.460892+00', 14346, 2, 1645, '', 'A', '', 1, 1, 'Y', '9eTjBpaG5Nk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3984, '2018-10-06 02:54:44.970559+00', '2018-10-06 11:39:02.161987+00', 11620, 2, 20354, '', 'A', 'Danced in 1994 at Tawa. Resurrected from a VHS tape by John Patterson.  Music by Peter Elmes.', 1, 1, 'Y', 'vqSLBgO-_Qo', 284, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3988, '2018-10-08 10:40:02.383416+00', '2018-10-09 00:05:39.194432+00', 13282, 3, 1645, '', 'C', 'Once per couple (1st couple turning to the bottom on the last four bars) with some walking rather than dancing but choreographically a very clear view.

', 1, 1, 'Y', 'J1ATP-Fp3rc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (362, '2012-12-08 16:28:21.296844+00', '2018-10-06 19:13:02.518968+00', 5525, 3, 106, '', 'A', 'Men''s demo from 1998 Anzac School Ceilidh in Wellington. Musicians are John Smith and Peter Elmes. Resurrected from an ancient VHS and turned into an mp4 by John Patterson. The MC was Marjorie Crawford.', 1, 1, 'Y', 'OYadT9LwDAg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3992, '2018-10-08 23:53:35.478587+00', '2018-10-09 00:05:50.516126+00', 18342, 1, 20354, '', 'B', 'There is also a simplified version for near beginners  in the instructions. It differs at bars 9-24 which need the most phrasing.  I am not sure why everyone is slenderized. The music I am using is Nottingham Lace recorded live.', 1, 1, 'Y', 'SpRJUz_RYec', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3987, '2018-10-06 07:22:03.252519+00', '2018-10-07 10:51:05.005748+00', 11623, 1, 20354, '', 'B', 'This video is of the earlier 3C/4L version of this dance. Bars 1-8 and 17-24 are unchanged but in bars 9-16 the order of setting and moving is exchanged and bars 25-32 are completely different.



Buttermilk Falls is a beautiful series of waterfalls in Ithaca. I seem to remember the elements of the dance were inspired by the shapes in the water. This was danced in Tawa in 1993, here for the first time. It does have elements I would no longer put in dances. Resurrected from VHS by John Patterson. Music by Peter Elmes.', 1, 1, 'Y', '8E3xoGSGSiY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3989, '2018-10-08 10:48:54.970145+00', '2018-10-09 00:03:52.301373+00', 13385, 2, 1645, '', 'K', '', 1, 1, 'Y', 'Q4sYSiR6nos', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4194, '2018-12-27 20:58:37.12826+00', '2018-12-27 20:58:57.676004+00', 5808, 2, 202, '', 'D', '', 1, 1, 'Y', 'Ep3nQVmX9v0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3990, '2018-10-08 17:53:03.23676+00', '2018-10-09 00:04:37.036199+00', 4246, 2, 1645, '', 'B', 'On bars 29-32 the women only move on to the next partner: they should pass one man before taking a new partner.

', 1, 1, 'Y', '1_vzaJRpmjg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4004, '2018-10-10 03:55:43.604377+00', '2018-10-10 21:07:53.786541+00', 17460, 2, 20350, '', 'C', 'Slytherin House was on the programme for the Johnsonville Scottish Country Dancing Club''s tartan night on October 1, 2018. The MC was club tutor Rod Downey and live music was provided by the band Wild Heather, comprising Sharlene Penman, Anne-Marie Forsyth, Lynne Scott and Mary McDonald.', 1, 1, 'Y', '-cr9vOnNTnM', 76, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4001, '2018-10-09 23:20:01.800832+00', '2018-10-10 00:00:52.310228+00', 18495, 1, 513, '', 'A', 'Four times through in a three couple set.', 1, 1, 'Y', '1qkVAb7071g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3996, '2018-10-09 22:51:20.878359+00', '2018-10-10 00:01:13.058438+00', 8732, 1, 1645, '', 'C', 'Twice through only.', 1, 1, 'Y', '2QoiBV4cTIo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3993, '2018-10-09 22:17:27.98894+00', '2018-10-10 00:01:44.016028+00', 15640, 2, 1645, '', 'B', 'One or two false starts  but otherwise a very clear view from a fixed, if slightly low, camera position.', 1, 1, 'Y', '-vOO_B50F1A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4002, '2018-10-09 23:24:16.773273+00', '2018-10-10 00:02:04.223209+00', 12699, 1, 1645, '', 'B', '', 1, 1, 'Y', 'Y9kMxge7K3Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3997, '2018-10-09 23:05:54.598122+00', '2018-10-10 00:02:22.863484+00', 3104, 1, 1645, '', 'C', '', 1, 1, 'Y', 'wyVgIcOTvRE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3994, '2018-10-09 22:42:26.395305+00', '2018-10-10 00:02:40.580802+00', 5499, 2, 1645, '', 'D', 'Some cribs suggest the advance and retire at the end should be one bar each.', 1, 1, 'Y', 'qcjPTQB-M3U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3998, '2018-10-09 23:12:28.104846+00', '2018-10-10 00:02:59.749365+00', 5552, 5, 1645, '', 'B', 'One to the bottom each couple.', 1, 1, 'Y', 'zO5Q7DD0BZo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4000, '2018-10-09 23:19:21.670199+00', '2018-10-10 00:03:16.723038+00', 5829, 2, 1645, '', 'B', '', 1, 1, 'Y', 'lWs3IUt2Id0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3995, '2018-10-09 22:46:58.646165+00', '2018-10-10 00:03:37.064664+00', 6471, 1, 1645, '', 'C', '', 1, 1, 'Y', '1HthmC_UccM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3999, '2018-10-09 23:16:39.543977+00', '2018-10-10 00:09:34.753354+00', 12019, 1, 513, '', 'A', '', 1, 1, 'Y', 'no1HmshPduw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4003, '2018-10-09 23:27:51.174938+00', '2018-10-10 00:15:19.754223+00', 15455, 1, 513, '', 'B', 'Danced  as r40/s40/r40 due to the lack of suitable music.', 1, 1, 'Y', 'OtwCQb_sUa0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4007, '2018-10-11 06:28:50.947706+00', '2018-10-11 10:15:13.021686+00', 18408, 3, 513, '', 'A', '', 1, 1, 'Y', 'V4BRca-OrDM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4009, '2018-10-11 06:30:52.375849+00', '2018-10-11 10:20:03.139071+00', 17121, 3, 513, '', 'A', '', 1, 1, 'Y', 'vJfPNmRDMRw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4006, '2018-10-11 06:27:55.220236+00', '2018-10-11 10:25:43.404663+00', 9800, 3, 513, '', 'A', '', 1, 1, 'Y', 'PIxK9OvzEYA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4008, '2018-10-11 06:29:44.41481+00', '2018-10-11 10:31:21.23488+00', 17460, 3, 513, '', 'A', '', 1, 1, 'Y', 'HfYXLlyutso', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4005, '2018-10-11 06:26:58.263496+00', '2018-10-11 10:35:54.105303+00', 18409, 1, 513, '', 'A', '', 1, 1, 'Y', 'UpRd1qdytB8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4010, '2018-10-12 00:01:06.646807+00', '2018-10-12 18:45:17.470083+00', 6817, 1, 1645, '', 'C', 'Twice per couple in three couple sets.', 1, 1, 'Y', 'WqZx-AnpVC4', 77, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4011, '2018-10-12 00:12:29.787424+00', '2018-10-12 18:46:04.937711+00', 5000, 2, 1645, '', 'B', '', 1, 1, 'Y', 'sV5GjpBBMqs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4014, '2018-10-12 11:06:08.850215+00', '2018-10-12 18:47:51.621348+00', 14401, 2, 513, '', 'A', '', 1, 1, 'Y', '1kMXL-x_qYA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4015, '2018-10-12 11:06:46.872177+00', '2018-10-12 18:53:41.932877+00', 16838, 2, 513, '', 'A', '', 1, 1, 'Y', '9XMlCNnfbSY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4013, '2018-10-12 11:05:28.255595+00', '2018-10-12 18:55:59.501081+00', 18272, 3, 513, '', 'A', '', 1, 1, 'Y', '4tdGCkmPNoI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4019, '2018-10-12 11:17:24.984107+00', '2018-10-12 20:47:45.194454+00', 16566, 2, 513, '', 'A', '', 1, 1, 'Y', '20BEDPWyT-U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4016, '2018-10-12 11:11:03.094305+00', '2018-10-12 20:51:57.598265+00', 17122, 5, 513, '', 'A', '', 1, 1, 'Y', 'pJega3n7zRw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4018, '2018-10-12 11:16:37.524932+00', '2018-10-12 20:57:56.409249+00', 14903, 2, 513, '', 'A', '', 1, 1, 'Y', 'dmZVnjeioWA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4017, '2018-10-12 11:16:05.445819+00', '2018-10-12 21:01:00.261515+00', 18410, 2, 513, '', 'A', '', 1, 1, 'Y', 'ialPCIEp07E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4027, '2018-10-16 13:20:26.229995+00', '2018-10-16 21:13:08.694613+00', 3119, 3, 2824, '', 'B', 'first 4 bars missing; variation of 3/4 clw. chase instead of 3/4 8 H round to the left on bars 29-32 (and some mishaps the last time through)



Regional SCD weekend - Znojmo - September 2018', 1, 1, 'Y', 'MeNBr_2D8xs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4030, '2018-10-16 21:07:32.150615+00', '2018-10-16 21:13:39.904252+00', 5818, 1, 1645, '', 'B', '', 1, 1, 'Y', 'T8PM_7woZKw', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4029, '2018-10-16 21:01:21.517052+00', '2018-10-16 21:13:48.582682+00', 12632, 1, 1645, '', 'C', 'Danced in three couple sets with a modification on bars 27-28 (1st couple cast instead of setting a second time). The first time through is the clearest - after that the camera is moving around.', 1, 1, 'Y', 'lRS6i2Sfh1E', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4033, '2018-10-17 21:14:36.636646+00', '2018-10-18 20:22:20.742779+00', 15768, 1, 1645, '', 'B', '', 1, 1, 'Y', 'ZGyV1_RXIK0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4031, '2018-10-16 21:40:40.87944+00', '2018-10-18 20:22:43.526102+00', 5525, 20, 1645, '', 'C', 'Modified version for a 5 couple set', 1, 1, 'Y', 'DBmlowJZ0bQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4036, '2018-10-18 19:00:59.854805+00', '2018-10-18 20:16:52.535006+00', 1478, 4, 118, '', 'B', '', 1, 1, 'Y', 'sJmDSwLDuZQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4043, '2018-10-22 00:16:46.891027+00', '2018-10-22 08:55:30.745843+00', 18355, 1, 1332, '', 'B', 'Once through.  ', 1, 1, 'Y', 'zT0V4zKdKUE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4044, '2018-10-22 01:10:44.02208+00', '2018-10-22 09:26:43.558468+00', 18354, 1, 1332, '', 'B', '3C dance in 3C set. ', 1, 1, 'Y', '2TvbTF79y50', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4045, '2018-10-22 22:25:00.961719+00', '2018-10-22 22:26:55.749021+00', 18287, 2, 1645, '', 'B', '', 1, 1, 'Y', 'k5_A9ok3RS4', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4041, '2018-10-21 21:31:57.394041+00', '2018-10-22 22:27:03.879274+00', 7283, 7, 1645, '', 'C', '', 1, 1, 'Y', 'Zl-HLTKzzPc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4040, '2018-10-21 20:08:56.882149+00', '2018-10-22 22:28:09.633143+00', 14597, 4, 1645, '', 'B', 'Three sets at angles to each other. A couple of quickly corrected glitches.', 1, 1, 'Y', '6sgUyxZL9do', 42, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4042, '2018-10-21 21:46:24.652+00', '2018-10-22 22:28:35.041502+00', 13463, 1, 1645, '', 'D', '', 1, 1, 'Y', 'ccIL_omuMq8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4039, '2018-10-21 20:00:05.739163+00', '2018-10-22 22:29:09.740152+00', 9532, 2, 1645, '', 'B', '', 1, 1, 'Y', 'lPXgNPIJ_FU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4046, '2018-10-23 00:40:03.919955+00', '2018-10-23 00:40:03.919955+00', 11583, 2, 1296, '', 'X', '"Autumn Wind" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'PDVWJF2xRZs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4047, '2018-10-23 00:40:03.997469+00', '2018-10-23 00:40:03.997469+00', 10649, 1, 1296, '', 'X', '"Firecracker Reel" is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'lhj83jZE6LY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4048, '2018-10-23 00:40:04.022766+00', '2018-10-23 00:40:04.022766+00', 5829, 3, 1296, '', 'X', '"The Saint John River" is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'nTGqf-TiDq4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4049, '2018-10-23 00:40:04.045299+00', '2018-10-23 00:40:04.045299+00', 6349, 6, 1296, '', 'X', '"Strathglass House" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'Kq5tvtFV8EI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4050, '2018-10-25 15:49:57.826277+00', '2018-10-25 18:54:11.850891+00', 2794, 1, 1811, '', 'B', 'Not sure this is ''demo'' quality as there is no set music for it!

Notes:

(1) the dance is done just three times through

(2) the transistion to a new top couple bringing in the new third couple as the cross up into the 3pl R&L as the old dancing cpl step down behind them

(3) at the end of bar 32 the lady may omit the polite turn may to make it easier to get into the  reel but it is possible to do te ;polite turn and get into the reel.', 1, 1, 'Y', 'U6FUXeUc5js', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4051, '2018-10-25 15:55:58.407128+00', '2018-10-25 18:55:21.906607+00', 14683, 1, 1811, '', 'B', 'Danced through three times to final chord.', 1, 1, 'Y', 'fO6PRADMrBM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4052, '2018-10-25 22:09:20.181053+00', '2018-10-25 22:09:35.696015+00', 2189, 1, 106, '', 'C', '', 1, 1, 'Y', 'jkJ1mjiZSmM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4053, '2018-10-25 22:33:21.384132+00', '2018-10-25 22:38:22.129826+00', 10771, 1, 106, '', 'C', 'Once through and most of second time.  Danced at the Hermitage Academy in Helensburgh on 6th April 2018', 1, 1, 'Y', 'fb19g722_A8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4070, '2018-10-30 21:43:10.482344+00', '2018-10-30 21:48:33.082108+00', 1535, 3, 1645, '', 'B', '', 1, 1, 'Y', 'PG3bwnP27Z0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4195, '2018-12-27 21:03:18.078475+00', '2018-12-27 21:04:52.957149+00', 9084, 7, 202, '', 'C', '', 1, 1, 'Y', 'B_BiKctwaUs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4069, '2018-10-30 03:42:02.835119+00', '2018-10-30 22:48:53.174134+00', 3685, 1, 20354, '', 'A', 'From 1998, mainly members of the Teacher''s Certificate training class of the time. Anzac Summer School in Wellington New Zealand. Old VHS tape so the quality of the recording had deteriorated a lot by the time John Patterson digitized it. Music by Peter Elmes.', 1, 1, 'Y', 'wsaWjPY8nII', 194, 317, NULL);
INSERT INTO 'dancevideo' VALUES (4068, '2018-10-30 03:40:06.161102+00', '2018-10-30 22:50:57.917868+00', 3695, 1, 20354, '', 'A', 'From 1998, mainly members of the Teacher''s Certificate training class of the time. Anzac Summer School in Wellington New Zealand. Old VHS tape so the quality of the recording had deteriorated a lot by the time John Patterson digitized it. Music by Peter Elmes, and adapted for a 3C dance.

', 1, 1, 'Y', 'wsaWjPY8nII', 89, 195, NULL);
INSERT INTO 'dancevideo' VALUES (4060, '2018-10-26 21:24:59.436797+00', '2018-10-30 22:52:56.332607+00', 9106, 3, 1645, '', 'B', '', 1, 1, 'Y', 'OuUyJTMo0Zs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4058, '2018-10-26 16:47:49.932397+00', '2018-10-30 22:53:50.195679+00', 152, 2, 1645, '', 'C', 'Just once through from part way through the dance.', 1, 1, 'Y', 'ijywBivXgXY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4057, '2018-10-26 16:35:29.050594+00', '2018-10-30 23:12:58.043751+00', 8203, 3, 1645, '', 'C', '', 1, 1, 'Y', 'X2BQ-2-Ut8U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4064, '2018-10-27 14:44:39.85284+00', '2018-10-30 22:57:12.904518+00', 15770, 1, 1645, '', 'A', 'Four times through (once per couple).



In the set are the devisor (first 1st lady) and three members of Barbara''s family.﻿

', 1, 1, 'Y', 'wS8rMrEXHHI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4055, '2018-10-26 16:19:55.647975+00', '2018-10-30 23:14:18.692379+00', 5885, 11, 1645, '', 'B', '', 1, 1, 'Y', 'zSAjmLCnd0M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4066, '2018-10-27 15:20:05.368984+00', '2018-10-30 22:58:54.262593+00', 2587, 1, 1645, '', 'B', '', 1, 1, 'Y', 'g8RGhfkXw_Q', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4059, '2018-10-26 16:56:50.373203+00', '2018-10-30 22:59:54.685202+00', 15302, 1, 1645, '', 'C', '', 1, 1, 'Y', '7PGx4m87OYI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4056, '2018-10-26 16:30:22.484201+00', '2018-10-30 23:00:48.394031+00', 3267, 1, 1645, '', 'C', 'Twice through.', 1, 1, 'Y', 'vGyty5QbO-4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4061, '2018-10-26 21:33:03.314271+00', '2018-10-30 23:08:37.637162+00', 15077, 2, 1645, '', 'B', '', 1, 1, 'Y', 'p85SZRBA3so', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4067, '2018-10-27 15:38:48.530353+00', '2018-10-30 23:09:44.991092+00', 10535, 8, 1645, '', 'C', 'The first few times are good, later on there are some little mishaps.', 1, 1, 'Y', 'wS8BD7JqshE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4063, '2018-10-27 14:35:24.52979+00', '2018-10-30 23:11:08.4371+00', 15406, 1, 1645, '', 'B', '', 1, 1, 'Y', '5Fr6DToeIqA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4062, '2018-10-26 21:45:47.418964+00', '2018-10-30 23:12:00.956454+00', 5671, 4, 1645, '', 'B', '', 1, 1, 'Y', 'p6fQWoqbNa8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4072, '2018-10-31 01:40:04.636359+00', '2018-10-31 01:40:04.636359+00', 2956, 4, 1296, '', 'X', '"The Hollin Buss" is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'RNvIr0joZiE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4073, '2018-10-31 01:40:04.736763+00', '2018-10-31 01:40:04.736763+00', 16535, 3, 1296, '', 'X', '"John Cass" is a 32 bar jig for 5 couples.', 1, 1, 'Y', 'ggO8OyiZySg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4074, '2018-10-31 01:40:04.757242+00', '2018-10-31 01:40:04.757242+00', 7441, 2, 1296, '', 'X', '"The Lady Wynd" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'I8KcIlRCYNk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4075, '2018-10-31 01:40:04.782435+00', '2018-10-31 01:40:04.782435+00', 17898, 3, 1296, '', 'X', '"New Year Jig" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'wSYg1_Xzr1A', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4076, '2018-10-31 01:40:04.807543+00', '2018-10-31 01:40:04.807543+00', 5065, 3, 1296, '', 'X', '"Old Nick''s Lumber Room" is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'vMEncV0VhVE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4077, '2018-10-31 01:40:04.832315+00', '2018-10-31 01:40:04.832315+00', 11772, 5, 1296, '', 'X', '"The Wishing Well" is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'IrOgkCRyxnY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4078, '2018-10-31 01:40:04.857948+00', '2018-10-31 01:40:04.857948+00', 2562, 4, 1296, '', 'X', '"The Glens of Angus" is a 32 bar reel for 4 couples.', 1, 1, 'Y', '4Dal2pf4tJ0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4071, '2018-10-30 23:04:34.688733+00', '2018-10-31 11:46:50.34328+00', 3787, 2, 1645, '', 'C', 'The first 1st couple have a few problems in bars17-24 (despite being directed by the youngest member of the set). The following couples manage better.', 1, 1, 'Y', 'LRNyk2tGvDk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4080, '2018-11-01 18:46:38.066077+00', '2018-11-04 22:50:50.759952+00', 713, 4, 3637, '', 'C', 'Good view from above of social dancers enjoying the dance to music by Fiddlesticks & Ivory. ', 1, 1, 'Y', 'XV182IcMAg0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4079, '2018-11-01 18:03:29.224139+00', '2018-11-04 22:47:38.445914+00', 1501, 8, 784, '', 'B', 'Once though, video starts around bar 3.', 1, 1, 'Y', 'Mo9PutZMnOM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4081, '2018-11-01 19:23:48.168983+00', '2018-11-05 13:07:41.98561+00', 12219, 1, 2824, '', 'C', 'twice through, including teacher''s prompts', 1, 1, 'Y', '3znTHyAuogU', 40, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4082, '2018-11-01 19:29:07.153083+00', '2018-11-05 13:09:03.018516+00', 4293, 1, 2824, '', 'A', 'Twice through', 1, 1, 'Y', 'QGqi2v_daq8', 0, 62, NULL);
INSERT INTO 'dancevideo' VALUES (4084, '2018-11-01 19:38:22.071598+00', '2018-11-05 13:12:10.394392+00', 10589, 3, 2824, '', 'B', '', 1, 1, 'Y', 'LzDVqcpy7PE', 56, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4085, '2018-11-01 19:42:03.574565+00', '2018-11-05 13:27:16.842271+00', 10653, 2, 2824, '', 'C', 'Some confusion in the transition between the two sets of reels in bars 17-24 and 25-32 especially in the first time through. Subsequent repeats are better.', 1, 1, 'Y', 'uzEO37h66pg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4054, '2018-10-26 16:09:13.943495+00', '2018-11-04 22:44:56.493003+00', 10129, 1, 1645, '', 'D', 'This clip of the dance is preceded by a long recap of the background and of the instructions. The sets on view often omit to turn partners for the last two bars - but are clearly enjoying themselves.

', 1, 1, 'Y', 'Tvt9ZfyzASE', 110, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4089, '2018-11-04 22:44:11.811834+00', '2018-11-04 22:45:04.865125+00', 13163, 4, 1645, '', 'D', '', 1, 1, 'Y', 'M0Uz86QJsr8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4087, '2018-11-01 19:50:46.343624+00', '2018-11-05 12:59:48.269997+00', 10463, 4, 2824, '', 'B', 'Starts well but there are some confusions in the reels later on.', 1, 1, 'Y', 'D1rjY-wdMKo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4086, '2018-11-01 19:46:47.287215+00', '2018-11-05 13:05:57.597575+00', 10367, 2, 2824, '', 'B', '', 1, 1, 'Y', '1FVgOv7Efn0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4127, '2018-11-27 02:30:59.107627+00', '2018-11-27 09:35:28.19705+00', 4491, 4, 20354, '', 'A', 'From teachers'' training class of 1997/98 Wellington. Converted to mp4 from old VHS.', 1, 1, 'Y', 'MXH0Qicrhic', 176, 249, NULL);
INSERT INTO 'dancevideo' VALUES (4146, '2018-12-13 11:59:01.99707+00', '2018-12-13 22:19:57.130783+00', 14600, 1, 513, '', 'C', '', 1, 1, 'Y', 'WDkKmE5LqWo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4083, '2018-11-01 19:34:22.824864+00', '2018-11-05 15:33:27.890443+00', 5355, 1, 2824, '', 'D', 'Apart from a variety of individual dancers mistakes, the version of the dance being performed here seems to consistently differ from that described in crib and diagram in several places:  

- in bars 3-4 1st and 4th couples here set on the sides and turn more than once RH instead of petronella and half turning RH;  

- at bar 32 1st and 4th men do not end the reel of four across by taking RH;  

- in bars 33-36 1st and 4th couples dance half way round in promenade hold instead of forming one line.  

NB John Drewry revised this dance but the video shows another variation, neither the original or revised versions.', 1, 1, 'Y', 'qeCem5_bjGQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4092, '2018-11-06 01:40:05.019018+00', '2018-11-06 01:40:05.019018+00', 15275, 1, 1296, '', 'X', '''The Comeback Jig'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'VrHQ-Qqz6Dk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4093, '2018-11-06 01:40:05.057493+00', '2018-11-06 01:40:05.057493+00', 3104, 2, 1296, '', 'X', '''Inveraray'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '3yGEgP-6KNU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4094, '2018-11-06 01:40:05.089823+00', '2018-11-06 01:40:05.089823+00', 6682, 1, 1296, '', 'X', '''The Travelling Men'' is a 32 bar jig for 5 couples.', 1, 1, 'Y', '6nApuueXIc4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4100, '2018-11-08 00:37:26.272968+00', '2018-11-08 00:41:33.791715+00', 7037, 3, 106, '', 'D', 'Danced at RSCDS Toronto Beginners'' Night', 1, 1, 'Y', 'FbSFhjWq2vE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4099, '2018-11-08 00:33:48.710513+00', '2018-11-08 00:41:46.09845+00', 7037, 2, 106, '', 'C', 'Social dance in Hall,  Once through.', 1, 1, 'Y', '5Zmy9uU9yJk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4091, '2018-11-06 00:14:05.408647+00', '2018-11-06 19:43:01.321503+00', 18669, 2, 3637, '', 'D', 'The Hoy Head was taught by Linda Henderson at the 2018 Asilomar Weekend''s Sunday morning combined class and then danced. Here''s the dance viewed from above, of social dancers dancing to live music by the Weekend''s musicians.', 1, 1, 'Y', 'mKVJQtfR--k', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4090, '2018-11-05 23:31:08.857041+00', '2018-11-06 19:43:34.30072+00', 5882, 1, 3637, '', 'D', 'John Drewry''s Sands of Asilomar danced by attendees at the San Francisco Branch''s Asilomar Weekend. The dance was first taught by Craig Williams during Sunday morning''s general class, on October 28, 2018 and then danced. This video provides a good view from above of all levels of social dancers enjoying the dance to live music by the Weekend''s musicians. ', 1, 1, 'Y', '7oFAJqqOkxM', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4097, '2018-11-06 18:52:28.971837+00', '2018-11-06 19:46:56.596383+00', 2593, 1, 20354, '', 'A', 'From practice session for the teachers'' training class of 1997-98. Wellington, New Zealand. Resurrected from an old VHS tape.', 1, 1, 'Y', 'fKF_2OJtLSE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4096, '2018-11-06 12:17:01.884902+00', '2018-11-06 19:51:58.245229+00', 7639, 1, 513, '', 'C', '', 1, 1, 'Y', 'oxc5IdwxHn4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4095, '2018-11-06 01:40:05.138033+00', '2018-11-08 00:29:10.796224+00', 7037, 1, 1296, '', 'X', '''Well Done Jack'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'Tp-fmCDdFiM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4196, '2018-12-27 21:07:54.515442+00', '2018-12-27 21:08:28.860291+00', 2367, 1, 202, '', 'D', '', 1, 1, 'Y', 'Chl2REZqYH0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4110, '2018-11-15 14:20:32.770542+00', '2018-11-15 23:02:38.525408+00', 3119, 4, 2586, '', 'A', '2nd dance within a demonstration performance: shows only the strathspey section of the dance, and not the reel section, but the formations are correct, clearly demonstrated and well danced.

Last few bars of this clip are slightly adjusted for the transition into the next part of the demonstration.', 1, 1, 'Y', 'd01Ixed7ueQ', 138, 263, NULL);
INSERT INTO 'dancevideo' VALUES (4101, '2018-11-08 17:15:29.245054+00', '2018-11-08 20:39:46.596224+00', 18578, 1, 784, '', 'B', 'Twice through.', 1, 1, 'Y', 'O570VijXqiM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4111, '2018-11-16 01:40:03.7033+00', '2018-11-16 01:40:03.7033+00', 11278, 2, 1296, '', 'X', '''The Diamond Quarrie'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'H3LCdqQA0m4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4102, '2018-11-08 17:18:03.352758+00', '2018-11-08 20:45:02.439469+00', 5480, 2, 784, '', 'C', 'Twice through - starting with the last few bars of the previous repeat.', 1, 1, 'Y', 'hNisoXZAufk', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4098, '2018-11-07 22:52:03.397152+00', '2018-11-08 20:59:30.413897+00', 18409, 2, 2794, '', 'A', 'The Ullapool Ferry is the first segment of a medley, recorded at the 2018 RSCDS Summer School.



This clip shows one repeat of the dance as written. The medley continues with a variation leading into the other dances.', 1, 1, 'Y', '80_K1-MrpNk', 0, 49, NULL);
INSERT INTO 'dancevideo' VALUES (4103, '2018-11-08 23:07:27.506214+00', '2018-11-09 00:54:29.135755+00', 12686, 5, 7602, '', 'A', '', 1, 1, 'Y', 'sPbA1DbSEuY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4104, '2018-11-11 07:03:54.639054+00', '2018-11-11 11:05:24.49534+00', 19050, 1, 117, '', 'B', '', 1, 1, 'Y', '3DX-s68eZfo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4106, '2018-11-14 14:29:08.646366+00', '2018-11-14 14:29:32.700791+00', 12539, 2, 106, '', 'D', 'Great fun on a cold and windy beach', 1, 1, 'Y', 'CYvR2BZIYLE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4107, '2018-11-15 01:40:03.202495+00', '2018-11-15 01:40:03.202495+00', 887, 6, 1296, '', 'X', '''Butterscotch and Honey'' is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'RTC9908xIE0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4108, '2018-11-15 01:40:03.23798+00', '2018-11-15 01:40:03.23798+00', 4155, 5, 1296, '', 'X', '''Margaret Parker''s Strathspey'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'rWbQpwHj8i4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4109, '2018-11-15 01:40:03.270887+00', '2018-11-15 01:40:03.270887+00', 7520, 3, 1296, '', 'X', '''Saint Columba''s Strathspey'' is a 32 bar strathspey for 5 couples.', 1, 1, 'Y', 'qPnQVHRE2Ig', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4114, '2018-11-19 03:18:43.573701+00', '2018-11-19 09:31:15.830981+00', 11616, 1, 20354, '', 'B', 'From my wife''s 50th celebration. ', 1, 1, 'Y', 'S0qLDZGaa7Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4169, '2018-12-18 09:28:21.059494+00', '2018-12-18 10:06:19.624153+00', 3700, 2, 513, '', 'B', 'Lovely dancing, but 1st couple are supposed to turn both hands in bars 27-28 and 31-32 whereas here they consistently turn right hand.

', 1, 1, 'Y', 'Nzf_bRio1l8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4174, '2018-12-19 01:02:02.011852+00', '2018-12-19 11:43:15.370919+00', 998, 3, 2586, '', 'C', 'Middle section of a longer demonstration display.', 1, 1, 'Y', 'qX2gRrs2o8A', 311, 380, NULL);
INSERT INTO 'dancevideo' VALUES (2957, '2017-04-07 06:32:14.562102+00', '2017-04-07 06:32:29.394492+00', 1176, 4, 106, '', 'X', '', 1, 1, 'Y', 'vN6qsb_FcrM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3373, '2017-12-26 20:32:12.202477+00', '2017-12-26 23:56:52.806811+00', 9286, 5, 596, '', 'X', 'This upgraded Danciemaetion video should replace the current Danciemaetion video ', 1, 1, 'Y', 'IHTqhthY09E', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4113, '2018-11-18 14:12:43.616323+00', '2018-11-18 19:39:43.698467+00', 19054, 1, 197, '', 'A', 'Devised for and presented to Marilyn Stocker in March 2016 by Jimmie Lomath, RSCDS teacher, highland dance teacher, dance choreographer, longtime member of the RSCDS and good friend to many of the dancers & musicians. The first tune of the dance is the James Lomath Strathspey composed by Barbara McOwen who played with Thistle Glen on Saturday night. Andy Imbrie put together the arrangement with the other two strathspeys. 

Music by ''Thistle Glen'': Janet Kurnick (band leader), Patty Van Winkle & Barbara McOwen (guest) on fiddle, Andy Imbrie on keyboard, and Sherryl Fawx on recorder 

The dancers: Bill & Marilyn Stocker Tim Wilson & Mary Tindall Sylvain Pelletier & Rachel Pusey Lyle Ramshaw & Jewel Murphy

At the Truckee worshop & dance 2016', 1, 1, 'Y', 'GfHC19QssE0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4112, '2018-11-18 00:58:44.528822+00', '2018-11-18 19:41:50.784356+00', 16930, 1, 2821, '', 'B', 'Performed by members of Nottingham RSCDS on 17 Nov 2018,  Music by Ian Robertson and his Scottish Dance Band.', 1, 1, 'Y', 'TRBQYudLybg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4118, '2018-11-24 01:40:03.288092+00', '2018-11-24 01:40:03.288092+00', 9106, 4, 1296, '', 'X', '''12 Coates Crescent'' is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'OEgFuDgL4rA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4115, '2018-11-22 20:07:07.133435+00', '2018-11-23 12:03:04.966172+00', 4782, 4, 1957, '', 'C', 'Danced in a 3 couple set, once and to the foot.', 1, 1, 'Y', 'w2wzBq9QNhU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4119, '2018-11-24 01:40:03.396371+00', '2018-11-24 01:40:03.396371+00', 8041, 1, 1296, '', 'X', '''The Caterpillar'' is a 32 bar reel for 4 couples.', 1, 1, 'Y', '_9UwECoxF-0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4121, '2018-11-24 01:40:03.449521+00', '2018-11-24 01:40:03.449521+00', 8465, 1, 1296, '', 'X', '''A Scottish Jaunt'' is a 32 bar jig for 4 couples.', 1, 1, 'Y', '1d8KyZ6oeu8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4117, '2018-11-23 17:23:50.52999+00', '2018-11-24 10:57:13.890706+00', 3953, 1, 1753, '', 'D', '', 1, 1, 'Y', 'qOFJSuaIz9A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4122, '2018-11-24 18:39:06.792811+00', '2018-11-24 23:44:49.178377+00', 16893, 1, 1332, '', 'C', 'Twice through.', 1, 1, 'Y', 'pOqwUq5Ghz0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4120, '2018-11-24 01:40:03.429282+00', '2018-12-02 01:40:03.826667+00', 7406, 2, 1296, '', 'Z', '''The Goat Fell Gallop'' is a 32 bar jig for 4 couples.', 1, 1, 'Y', '2faP0z2VkJc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4126, '2018-11-26 11:13:55.050094+00', '2018-11-26 23:53:26.375905+00', 3788, 2, 513, '', 'C', '', 1, 1, 'Y', 'ib6jJo8JN6s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4125, '2018-11-26 11:12:24.926148+00', '2018-11-27 00:02:30.677639+00', 5463, 4, 513, '', 'C', 'Video clipped to start from second repeat. After a few more repeats the standing dancers start joining in...', 1, 1, 'Y', 'rR0DGDMXYXI', 39, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4124, '2018-11-26 11:11:46.933722+00', '2018-11-27 00:08:01.936542+00', 6632, 1, 513, '', 'C', '', 1, 1, 'Y', 'T_c-xadOJVY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4150, '2018-12-13 14:58:05.09921+00', '2018-12-13 22:27:51.349913+00', 18244, 2, 513, '', 'D', '', 1, 1, 'Y', '3_OEoaxDk78', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4129, '2018-11-27 05:42:34.529358+00', '2018-11-27 16:57:17.856295+00', 6420, 3, 513, '', 'C', 'Video starts about one bar into the dance.', 1, 1, 'Y', 'jbPSIcK6j-8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4151, '2018-12-13 15:00:36.391907+00', '2018-12-13 22:31:50.545091+00', 1201, 1, 513, '', 'D', '', 1, 1, 'Y', 'fuCpCYtbOpw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4128, '2018-11-27 02:33:05.156318+00', '2018-11-27 17:24:55.457768+00', 109, 5, 20354, '', 'A', 'From teachers training class of 1997/98 Wellington New Zealand.

Transferred from old VHS to mp4.', 1, 1, 'Y', 'MXH0Qicrhic', 44, 170, NULL);
INSERT INTO 'dancevideo' VALUES (4130, '2018-11-28 16:56:42.889897+00', '2018-11-28 16:58:00.395284+00', 17649, 1, 1645, '', 'B', '', 1, 1, 'Y', 'qZiAIaEfb5Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4131, '2018-11-28 19:28:41.418039+00', '2018-11-28 23:28:04.690591+00', 8741, 1, 1684, '', 'C', '', 1, 1, 'Y', '-90OPdsV3pc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4144, '2018-12-13 11:56:44.029819+00', '2018-12-13 22:35:50.399921+00', 10880, 1, 513, '', 'D', '', 1, 1, 'Y', 'JjkNtbDjHEc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4132, '2018-11-29 21:05:10.979129+00', '2018-11-29 21:07:14.878904+00', 11929, 1, 1645, '', 'C', 'Video starts about one bar into the dance.', 1, 1, 'Y', 'LfdBDwlKL7c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4133, '2018-12-02 01:40:03.886803+00', '2018-12-02 01:40:03.886803+00', 7406, 3, 1296, '', 'X', '''The Goat Fell Gallop'' is a 32 bar jig for 4 couples.', 1, 1, 'Y', 'jxdEtZ_gsH8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4134, '2018-12-02 01:40:04.157023+00', '2018-12-02 01:40:04.157023+00', 6202, 1, 1296, '', 'X', '''The Sorcerer''s Apprentice'' is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'u8b7gYY8fzY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4140, '2018-12-13 10:41:54.61574+00', '2018-12-13 22:39:53.015164+00', 13907, 1, 513, '', 'C', '', 1, 1, 'Y', 'oyaKsb8DU8U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4136, '2018-12-05 22:46:12.598389+00', '2018-12-06 00:12:47.769055+00', 12477, 1, 2794, '', 'B', 'Danced by the Red Thistle dancers as part of a longer performance at a 2011 public event.  Could be considered demonstration quality; although, the filming is one grade less than top notch.', 1, 1, 'Y', 'JmcelyNN1yU', 1522, 1609, NULL);
INSERT INTO 'dancevideo' VALUES (4135, '2018-12-03 14:15:20.91978+00', '2018-12-06 00:15:24.423893+00', 312, 5, 1056, '', 'A', 'Teaching video, with the dancers wearing coloured, numbered smocks.

Two times through.', 1, 1, 'Y', 'vfbk64eyaEA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4137, '2018-12-08 00:38:09.154372+00', '2018-12-08 23:08:17.638907+00', 19033, 1, 3637, '', 'A', 'Presentation of Jennifer Kelly''s C. Stewart Smith at the Asilomar Weekend''s Friday night Ceilidh by members of the Red Thistle Dancers.', 1, 1, 'Y', 'IhPlSw8k76c', 48, 128, NULL);
INSERT INTO 'dancevideo' VALUES (4152, '2018-12-13 15:45:36.265297+00', '2018-12-13 22:43:31.990809+00', 18580, 3, 513, '', 'C', '', 1, 1, 'Y', 'pcVJmMhhh7I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4138, '2018-12-10 21:31:40.668182+00', '2018-12-10 21:32:36.620771+00', 16158, 1, 106, '', 'B', '"Tay Dancers" video published by Tom Geoghegan on 8 oct 2018', 1, 1, 'Y', 'ktu51UuPNlg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4141, '2018-12-13 11:41:07.790048+00', '2018-12-13 22:51:12.344816+00', 3553, 1, 513, '', 'C', '', 1, 1, 'Y', 'UGSo_ZLJaTc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4142, '2018-12-13 11:42:11.707218+00', '2018-12-13 23:08:35.685709+00', 13592, 1, 513, '', 'C', '', 1, 1, 'Y', '8snPM6PfVBA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4147, '2018-12-13 12:01:21.298219+00', '2018-12-13 23:18:16.602262+00', 4897, 1, 513, '', 'C', '', 1, 1, 'Y', 'ZSlyJzCAkng', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4145, '2018-12-13 11:58:00.003155+00', '2018-12-14 17:25:43.461418+00', 5061, 1, 513, '', 'D', 'Six times through in three couple sets.', 1, 1, 'Y', '_-hpY7dleb4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4149, '2018-12-13 14:57:04.99031+00', '2018-12-14 17:31:34.610431+00', 18579, 2, 513, '', 'D', '', 1, 1, 'Y', 'U72UwWs_V7s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4148, '2018-12-13 14:55:26.360629+00', '2018-12-14 17:37:38.993949+00', 12532, 1, 513, '', 'C', '', 1, 1, 'Y', 'pN_FaaZrLtY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4153, '2018-12-14 18:06:51.715347+00', '2018-12-14 18:07:05.186303+00', 19118, 1, 1645, '', 'B', '', 1, 1, 'Y', 'EuchY7M2jFs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4154, '2018-12-15 15:37:37.899641+00', '2018-12-15 16:19:49.06459+00', 19120, 1, 1645, '', 'C', 'Twice through.', 1, 1, 'Y', 'eELBtgucC58', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4157, '2018-12-15 16:17:29.663996+00', '2018-12-15 16:19:56.78399+00', 19010, 1, 1645, '', 'B', 'Danced in a 7 couple set (occasionally a surprise to the borrowed couples).', 1, 1, 'Y', 'xgG8B_NP_Jg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4155, '2018-12-15 15:37:52.491043+00', '2018-12-15 16:20:03.117474+00', 19119, 1, 1645, '', 'C', '', 1, 1, 'Y', 'JttG_S0Rcvc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4156, '2018-12-15 16:07:50.596812+00', '2018-12-15 16:20:10.669382+00', 19123, 1, 1645, '', 'C', '', 1, 1, 'Y', 'uqKnIT7VGe0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4158, '2018-12-16 02:35:10.203022+00', '2018-12-16 02:35:31.115673+00', 4092, 2, 202, '', 'D', '', 1, 1, 'Y', 'RQOUzWFmg28', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4159, '2018-12-16 02:38:09.08821+00', '2018-12-16 02:38:56.613153+00', 5006, 3, 202, '', 'B', '', 1, 1, 'Y', 'Id5KBvRuScc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4160, '2018-12-16 02:40:53.259002+00', '2018-12-16 02:41:25.494552+00', 6484, 3, 202, '', 'C', '', 1, 1, 'Y', '2x0VUcFSi5A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4161, '2018-12-16 02:45:18.291029+00', '2018-12-16 02:46:42.59005+00', 5755, 3, 202, '', 'D', '', 1, 1, 'Y', 'sJUlJULffPM', 45, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4162, '2018-12-16 02:51:30.73349+00', '2018-12-16 02:51:45.569695+00', 10787, 9, 202, '', 'D', '', 1, 1, 'Y', '--kRhnpw764', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4163, '2018-12-16 20:28:09.390675+00', '2018-12-17 10:28:03.553007+00', 4662, 4, 2586, '', 'B', 'Danced through only once but correct choreography and formations.', 1, 1, 'Y', '7SIOMzuSUKc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4164, '2018-12-16 20:41:18.450693+00', '2018-12-17 10:34:06.531137+00', 7520, 4, 2586, '', 'B', 'Some hesitations and partial mistakes but a clear view of the set and perfectly adequate for learning the dance.

Note: My Strathspey lists this dance as "Saint" Columba''s Strathspey but a common spelling on programmes is "St" Columba''s Strathspey.', 1, 1, 'Y', 'RAImVYF7asU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4165, '2018-12-18 01:40:03.220899+00', '2018-12-18 01:40:03.220899+00', 9124, 1, 1296, '', 'X', '''Sheena''s Buckle'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'cgk1nwpsG8E', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4170, '2018-12-18 09:31:10.159967+00', '2018-12-18 09:51:59.123679+00', 17460, 4, 513, '', 'C', '', 1, 1, 'Y', 'fjOWj8RnqCQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4172, '2018-12-18 16:52:32.758578+00', '2018-12-18 18:17:53.017124+00', 3310, 4, 2586, '', 'C', 'Four times through.', 1, 1, 'Y', 'g4zRnpMkwpA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4317, '2019-02-12 13:11:38.691834+00', '2019-02-12 19:09:12.899632+00', 3953, 2, 513, '', 'A', '', 1, 1, 'Y', 'HfdwWeGzZDk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3374, '2017-12-26 20:33:55.286777+00', '2018-01-03 17:46:36.182589+00', 40, 3, 596, '', 'X', 'This upgraded Danciemaetion video should replace the current Danciemaetion video', 1, 1, 'Y', '5wq5AJUqd-U', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3375, '2017-12-26 20:35:08.424371+00', '2018-01-03 17:46:09.804328+00', 14369, 2, 596, '', 'X', 'This upgraded Danciemaetion video should replace the current Danciemaetion video', 1, 1, 'Y', 'bJUVethZfkc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3376, '2017-12-26 20:36:20.048606+00', '2018-01-03 17:44:12.852186+00', 59, 2, 596, '', 'X', 'This upgraded Danciemaetion video should replace the current Danciemaetion video', 1, 1, 'Y', 'Ksihw7yLbNc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4167, '2018-12-18 01:40:03.30026+00', '2018-12-21 01:40:04.388206+00', 12573, 1, 1296, '', 'Z', '''Summer with McKinnon'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'Ag0ku8itQt0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4168, '2018-12-18 01:40:03.319846+00', '2018-12-21 01:40:04.454138+00', 14931, 1, 1296, '', 'Z', '''Winter Wonder'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'bS1GbuTyE5g', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3377, '2017-12-26 20:37:49.561831+00', '2018-01-03 17:44:33.412026+00', 14575, 2, 596, '', 'X', 'This upgraded Danciemaetion video should replace the current Danciemaetion video', 1, 1, 'Y', 'I2cOXkihVOA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3378, '2017-12-26 20:39:06.114489+00', '2018-01-03 17:44:51.58308+00', 7337, 2, 596, '', 'X', 'This upgraded Danciemaetion video should replace the current Danciemaetion video', 1, 1, 'Y', 'oNQZkGPPF8Y', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3379, '2017-12-26 20:40:14.945304+00', '2018-01-03 17:48:10.137081+00', 105, 3, 596, '', 'X', 'This upgraded Danciemaetion video should replace the current Danciemaetion video', 1, 1, 'Y', '3GekojVx8Zc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3380, '2017-12-26 20:41:47.210781+00', '2018-01-03 17:55:13.885825+00', 159, 8, 596, '', 'X', 'This upgraded Danciemaetion video should replace the current Danciemaetion video', 1, 1, 'Y', 'SnAQf9Es9x8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3381, '2017-12-26 20:43:00.633627+00', '2018-01-03 17:47:07.141405+00', 221, 4, 596, '', 'X', 'This upgraded Danciemaetion video should replace the current Danciemaetion video', 1, 1, 'Y', 'YVfmJV02v2I', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3382, '2017-12-26 20:44:34.247657+00', '2018-01-03 17:47:41.972958+00', 3791, 4, 596, '', 'X', 'This upgraded Danciemaetion video should replace the current Danciemaetion video', 1, 1, 'Y', 'xwzscT_5cBE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3383, '2017-12-26 20:45:54.055314+00', '2018-01-03 17:43:45.646584+00', 291, 2, 596, '', 'X', 'This upgraded Danciemaetion video should replace the current Danciemaetion video', 1, 1, 'Y', 'womHmQjgOMk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3384, '2017-12-26 20:47:34.178199+00', '2018-01-03 17:47:25.272005+00', 301, 4, 596, '', 'X', 'This upgraded Danciemaetion video should replace the current Danciemaetion video', 1, 1, 'Y', '8qBi5EntSQ0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3386, '2017-12-26 20:50:27.881259+00', '2018-01-03 17:55:31.100689+00', 314, 9, 596, '', 'X', 'This upgraded Danciemaetion video should replace the current Danciemaetion video', 1, 1, 'Y', 'bazg01TqAO0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4175, '2018-12-20 15:41:11.097137+00', '2018-12-20 18:07:49.342422+00', 14548, 4, 513, '', 'C', '', 1, 1, 'Y', 'n0n8iM3MUYc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4342, '2019-03-05 15:42:27.574982+00', '2019-03-06 13:00:25.928436+00', 13771, 2, 2586, '', 'A', '', 1, 1, 'Y', 'VNrJzdeXPKI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4176, '2018-12-21 01:40:04.35377+00', '2018-12-21 01:40:04.35377+00', 11769, 5, 1296, '', 'X', '''Starlight'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'V34Yrp-m0hs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4177, '2018-12-21 01:40:04.404033+00', '2018-12-21 01:40:04.404033+00', 12573, 2, 1296, '', 'X', '''Summer with McKinnon'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'JspnDDA9tbY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4178, '2018-12-21 01:40:04.470649+00', '2018-12-21 01:40:04.470649+00', 14931, 2, 1296, '', 'X', '''Winter Wonder'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'F2c9Oh5G2U0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4179, '2018-12-21 11:11:57.990712+00', '2018-12-21 11:12:21.021816+00', 19129, 1, 1645, '', 'A', '', 1, 1, 'Y', 'oAgZA4Tosqc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4180, '2018-12-21 11:31:53.794932+00', '2018-12-23 11:49:23.614483+00', 40, 4, 1645, '', 'B', 'The first four repeats are good with some hello-goodbye problems later on.', 1, 1, 'Y', 'yg0Vc-F2Lrk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4181, '2018-12-21 11:55:30.645174+00', '2018-12-23 11:49:58.475491+00', 14738, 4, 1645, '', 'C', '', 1, 1, 'Y', 'LHwtlS_gYdA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4186, '2018-12-21 13:15:35.467378+00', '2018-12-23 11:50:55.895521+00', 1647, 6, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'kMpb1rvqkNc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4183, '2018-12-21 12:29:19.867927+00', '2018-12-23 11:51:51.149388+00', 15767, 1, 1645, '', 'B', '', 1, 1, 'Y', 'dr1QCYGO07c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4185, '2018-12-21 12:43:50.413257+00', '2018-12-23 11:52:44.199102+00', 3503, 2, 1645, '', 'C', '1st couple are here slipping down and back instead of leading down and back.', 1, 1, 'Y', '33YeV3NEgE0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4187, '2018-12-21 13:19:33.377226+00', '2018-12-23 11:53:00.438988+00', 4796, 3, 1645, '', 'B', 'Twice through with the ending changed slightly to link to the next demo in a medley.', 1, 1, 'Y', '9Zu2Kncytz0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4182, '2018-12-21 12:01:30.695593+00', '2018-12-23 11:55:25.55511+00', 6177, 3, 1645, '', 'C', 'Once per couple, filmed from the top of a five couple set.', 1, 1, 'Y', '0SYrRO04E_U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4184, '2018-12-21 12:36:25.691589+00', '2018-12-23 11:57:54.62572+00', 17577, 2, 1645, '', 'C', '', 1, 1, 'Y', '8xHiaFUdZmY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4188, '2018-12-23 12:31:28.647108+00', '2018-12-23 12:35:41.43465+00', 19127, 1, 1645, '', 'C', '', 1, 1, 'Y', 'R_d-LAlucJE', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4189, '2018-12-23 12:32:12.123638+00', '2018-12-23 12:37:11.945515+00', 16886, 1, 1645, '', 'B', '', 1, 1, 'Y', 'KfgPEhviMGw', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4190, '2018-12-23 12:33:01.12696+00', '2018-12-23 12:38:32.726559+00', 18394, 1, 1645, '', 'B', '', 1, 1, 'Y', 'H8_79S6_8SY', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4192, '2018-12-27 12:22:26.80846+00', '2018-12-27 20:52:59.809351+00', 12689, 1, 513, '', 'D', '', 1, 1, 'Y', 'Y7JtGhWZX9Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4193, '2018-12-27 20:52:04.439743+00', '2018-12-27 20:54:53.954423+00', 2260, 4, 202, '', 'C', '', 1, 1, 'Y', 'gq1EncrLb1c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4205, '2019-01-04 00:04:19.486515+00', '2019-01-04 10:34:01.739793+00', 16827, 2, 106, '', 'A', 'Twice through as part of a longer medley.', 1, 1, 'Y', 'z6Zc1_dzZIQ', 0, 73, NULL);
INSERT INTO 'dancevideo' VALUES (4198, '2018-12-30 18:49:00.015146+00', '2019-01-04 11:24:41.267436+00', 1486, 3, 2586, '', 'C', 'Each couple dances only once and then casts to the bottom of the set.  The crib''s instructions are "After the second turn the dancing couple continues the reel with bottom couple to change places".', 1, 1, 'Y', 'hEjVmv0PIBY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4200, '2019-01-01 14:07:17.570246+00', '2019-01-04 11:30:26.76+00', 16833, 2, 513, '', 'C', '', 1, 1, 'Y', 'nBeo5HWIhFU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4204, '2019-01-03 20:35:54.946636+00', '2019-01-04 11:36:17.978477+00', 18492, 1, 513, '', 'C', 'Twice through. Video starts about 1 bar into the dance.', 1, 1, 'Y', 'y7hab6B-6nQ', 0, 121, NULL);
INSERT INTO 'dancevideo' VALUES (4199, '2018-12-31 17:59:50.631595+00', '2019-01-04 11:41:55.961853+00', 6451, 2, 513, '', 'C', '', 1, 1, 'Y', 'lND8fhcA9PQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3290, '2017-10-20 22:10:10.981424+00', '2019-01-04 15:16:45.086204+00', 17918, 1, 1645, '', 'B', 'View from the top of the set (in a trapezoidal room).

Choreographically fine albeit with a few hesitations.



This video was filmed using the recording Tribute to Drummond Cook by Colin Dewar.

Subsequently a tune (<<ddt:Confiture Maison>>) was composed for the dance by Marian Anderson.', 1, 1, 'Y', 'o7KjgAwCtVc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4202, '2019-01-01 17:35:10.541099+00', '2019-01-04 15:52:58.658693+00', 3834, 7, 513, '', 'A', 'Twice through.', 1, 1, 'Y', 'Ol2ISVYDr7c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4206, '2019-01-05 10:52:07.667978+00', '2019-01-05 11:06:52.908961+00', 15430, 1, 2824, '', 'C', '', 1, 1, 'Y', '_71Rex49xQU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4105, '2018-11-11 22:28:06.217262+00', '2019-01-05 23:41:44.994838+00', 2484, 3, 2586, '', 'B', 'According to the original instructions, only the Women set on bars 27-28 and 31-32.  However, a variant description exists that says "All Set".  That is the version used in this video.  That is why this video is not classified as "demonstration quality".', 1, 1, 'Y', 'f9ZOMKBprYc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4207, '2019-01-05 23:46:36.969377+00', '2019-01-05 23:57:32.52279+00', 2484, 4, 106, '', 'B', 'According to the original instructions, only the Women set on bars 27-28 and 31-32.  However, a variant description exists that says "All Set".  That is the version used in this video.  That is why this video is not classified as "demonstration quality".', 1, 1, 'Y', '7DGNpwcH3h0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4313, '2019-02-12 13:06:03.015383+00', '2019-02-12 19:21:19.506213+00', 3986, 3, 513, '', 'A', '', 1, 1, 'Y', 'mECnmwOEV48', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4208, '2019-01-05 23:53:11.584187+00', '2019-01-06 00:04:52.641778+00', 2484, 1, 106, '', 'B', 'According to the original instructions, only the Women set on bars 27-28 and 31-32.  However, a variant description exists that says "All Set".  That is the version used in this video.  That is why this video is not classified as "demonstration quality".', 1, 1, 'Y', 'c3p3V_epNMM', 26, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4251, '2019-01-20 19:41:06.068681+00', '2019-01-20 23:07:07.6167+00', 19166, 1, 3129, '', 'A', 'Mistakenly danced in a 4-couple set instead of a 3-couple set.', 1, 1, 'Y', 'a0p83NM5nZM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4210, '2019-01-06 00:15:48.776269+00', '2019-01-07 11:16:37.738259+00', 2484, 6, 106, '', 'C', 'According to the original instructions, only the Women set on bars 27-28 and 31-32.  However, a variant description exists that says "All Set".  That is the version used in this video.

The video starts about 4 bars into the dance.', 1, 1, 'Y', 'UOPZ6H8ZWjk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4234, '2019-01-16 14:16:26.756312+00', '2019-01-16 15:14:31.562186+00', 5703, 4, 2219, '', 'C', 'at the Improvers/Beginners class of the Watford and West Herts Scottish Society...', 1, 1, 'Y', 'wNhIHzXQVEE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4209, '2019-01-06 00:12:59.460124+00', '2019-01-07 11:19:56.930672+00', 2484, 5, 106, '', 'C', 'According to the original instructions, only the Women set on bars 27-28 and 31-32.  However, a variant description exists that says "All Set".  That is the version used in this video.

This clip is just once through.', 1, 1, 'Y', '_JjzgbYpKxc', 35, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4212, '2019-01-07 19:08:34.660966+00', '2019-01-08 10:18:36.14068+00', 3799, 1, 1645, '', 'D', '', 1, 1, 'Y', 'KHOBbMhdGYg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4216, '2019-01-09 15:14:51.886864+00', '2019-01-09 15:17:43.263587+00', 3637, 4, 1645, '', 'A', 'Four times through. First part of a longer demonstration.', 1, 1, 'Y', 'UOfaBl_iHNo', 0, 147, NULL);
INSERT INTO 'dancevideo' VALUES (4227, '2019-01-09 22:21:24.710244+00', '2019-01-10 02:11:52.594976+00', 18537, 2, 2219, '', 'C', '', 1, 1, 'Y', 'NTRfxtH7piw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4215, '2019-01-09 15:10:05.095065+00', '2019-01-09 15:24:15.778354+00', 3637, 3, 1645, '', 'B', 'After the hello-goodbye setting, 1st couple are here ending (at bar 17) facing their 3rd corner, not their 1st corner and consequently need an additional fast turn at the end of the corner-partner (bar 24) to end back on their own sides.', 1, 1, 'Y', '68LVWLWD9VQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4228, '2019-01-09 22:27:55.363885+00', '2019-01-10 10:55:21.712574+00', 12369, 2, 2219, '', 'D', '', 1, 1, 'Y', 'bkUm5dGErr0', 4, 157, NULL);
INSERT INTO 'dancevideo' VALUES (4213, '2019-01-09 12:41:43.304543+00', '2019-01-09 15:46:37.516846+00', 445, 12, 1645, '', 'B', 'Video starts about 4 bars into the dance.', 1, 1, 'Y', 'FmtsrFuiPHA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4214, '2019-01-09 12:55:26.651317+00', '2019-01-09 15:47:53.83517+00', 14685, 2, 1645, '', 'B', 'Danced to a japanese childrens song.', 1, 1, 'Y', 'OpMG-MxUP5s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4218, '2019-01-09 15:47:04.392983+00', '2019-01-09 15:53:06.116298+00', 6634, 2, 513, '', 'B', '', 1, 1, 'Y', 'ipfmziKUh7M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4217, '2019-01-09 15:45:35.593359+00', '2019-01-09 16:00:05.50759+00', 6792, 3, 513, '', 'C', '', 1, 1, 'Y', 'y9VRXR-V4uw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4220, '2019-01-09 15:50:17.828976+00', '2019-01-09 17:36:07.789169+00', 2506, 4, 513, '', 'B', '', 1, 1, 'Y', 'UJeRt_W-SDA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4219, '2019-01-09 15:48:47.67585+00', '2019-01-09 17:57:06.903031+00', 6853, 1, 513, '', 'B', '', 1, 1, 'Y', 'ER8kTO23S7c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4230, '2019-01-11 18:46:51.078603+00', '2019-01-11 19:30:41.031584+00', 153, 2, 1957, '', 'A', 'Part of a longer demonstration so no chord with bows or curtseys before start, but it is the full dance from the beginning.', 1, 1, 'V', '310664068', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4225, '2019-01-09 19:31:44.988414+00', '2019-01-09 20:35:52.148475+00', 5497, 8, 2269, '', 'A', '', 1, 1, 'Y', 'IhJfrIxjUsc', 256, 343, NULL);
INSERT INTO 'dancevideo' VALUES (4229, '2019-01-10 21:30:14.108567+00', '2019-01-11 19:33:46.747274+00', 19142, 1, 197, '', 'C', '', 1, 1, 'Y', 'ftHMhA9E90I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4224, '2019-01-09 17:13:33.72302+00', '2019-01-09 20:38:26.754914+00', 458, 1, 1645, '', 'C', 'This performance is not entirely correct according to the youtube comment - but is nonetheless a very useful display of all three sections of this long demonstration dance. NB the video is silent for the first few seconds.', 1, 1, 'Y', 'j4qWc82BGvQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5440, '2019-11-28 10:54:07.009265+00', '2019-11-28 23:41:36.173942+00', 15067, 1, 1645, '', 'C', '', 1, 1, 'Y', 'f0mYbXOZiNA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4226, '2019-01-09 22:06:56.612252+00', '2019-01-10 02:04:29.083194+00', 18537, 1, 2219, '', 'B', 'Ian Robertson composed  the tunes: strathspey "Derby Road "(so named because his grandparents lived in Derby Road Watford around the time the society was founded) and a reel, "Watford Centenary Reel". ', 1, 1, 'Y', '7PQsOWeafE0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4222, '2019-01-09 16:45:31.186133+00', '2019-01-11 19:34:40.148906+00', 2267, 8, 1645, '', 'B', 'Very clear with colour coded shirts, but not using the suggested music. Four times through.', 1, 1, 'Y', '35YUxWDEwsw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4223, '2019-01-09 16:51:22.801085+00', '2019-01-11 19:36:08.266099+00', 2267, 9, 1645, '', 'B', 'Extract from a longer demonstration. Twice through with bars 31-32 adapted for a three couple set (the bottom two couples here dance half right hands across instead of crossing).', 1, 1, 'Y', 'RiKpkAjQrGk', 10, 86, NULL);
INSERT INTO 'dancevideo' VALUES (4171, '2018-12-18 09:33:21.613838+00', '2019-01-13 16:46:08.98591+00', 17979, 1, 513, '', 'C', 'This video (mostly) follows the updated instructions, not the version originally printed in the "Quick Scotch Book of Records" of 2017 which is wrong and has been changed.

', 1, 1, 'Y', '6yU3ysyMG9s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4232, '2019-01-14 17:11:58.924961+00', '2019-01-15 11:35:38.73792+00', 16535, 4, 513, '', 'A', '', 1, 1, 'Y', 'T-OiR3MJWJM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4231, '2019-01-13 17:06:52.972397+00', '2019-01-15 11:36:07.944434+00', 6196, 1, 1645, '', 'C', 'First time round the two hand turn (in bars 23-24) is skipped before the circle that should be in bars 25-28. Subsequent repeats are better. Also they consistent start with only 1st couple dancing bars 1-8 whereas Minicrib suggests both 1st and 3rd couples should start.', 1, 1, 'Y', '6O1mj0XwaYQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4233, '2019-01-16 14:12:27.199538+00', '2019-01-16 15:10:07.539948+00', 2711, 2, 2219, '', 'C', '1 pass of the dance from the Improvers/Beginners class of Watford and West Hert Scottish Society - the general shapes and movements are ok - the footwork and technique are at an entry level!', 1, 1, 'Y', '_GcRLKU_JG0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4402, '2019-03-26 22:44:04.143729+00', '2019-03-27 12:25:34.603372+00', 15307, 3, 2213, '', 'B', '', 1, 1, 'Y', 'W7fIczRloKc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4241, '2019-01-17 22:40:27.923283+00', '2019-01-18 11:01:04.638004+00', 5644, 1, 1645, '', 'C', 'The camera is moving around a bit, but its still fairly clear.', 1, 1, 'Y', 'hTjZmVVGyog', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4242, '2019-01-18 03:29:17.402449+00', '2019-01-18 09:47:39.348815+00', 11373, 2, 784, '', 'B', 'Once each couple.', 1, 1, 'Y', '2uki_udxY6M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4236, '2019-01-17 20:36:26.224204+00', '2019-01-18 10:58:23.465335+00', 19168, 1, 1645, '', 'C', '', 1, 1, 'Y', 'xfOZ9hEUHKg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4238, '2019-01-17 20:59:23.66489+00', '2019-01-18 10:59:25.952576+00', 2675, 1, 1645, '', 'C', '', 1, 1, 'Y', 'BV1XxEWxRBk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4235, '2019-01-17 20:06:52.840863+00', '2019-01-18 10:59:39.165441+00', 19167, 1, 1645, '', 'C', 'Its not clear whether all corners should set in bars 25-32 or just those facing 1st & 5th couples.', 1, 1, 'Y', 'qNy0nDgCDRg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4237, '2019-01-17 20:49:10.491655+00', '2019-01-18 10:59:57.327508+00', 5463, 4, 1645, '', 'B', 'Clear but a few glitches on some of the later repeats.', 1, 1, 'Y', 'z8uvEh3xZhU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4240, '2019-01-17 22:30:12.527815+00', '2019-01-18 11:00:15.520588+00', 15866, 1, 1645, '', 'D', '', 1, 1, 'Y', '-F1NF1GaCFs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4239, '2019-01-17 21:35:16.304901+00', '2019-01-18 11:02:03.797993+00', 6551, 1, 1645, '', 'B', 'Once through.', 1, 1, 'Y', 'EmPByF-j8oo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4243, '2019-01-18 12:16:27.466468+00', '2019-01-18 16:06:11.327082+00', 4102, 13, 513, '', 'B', '', 1, 1, 'Y', '91HTk9GQbKs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4249, '2019-01-19 20:48:35.046272+00', '2019-01-20 23:08:11.929671+00', 10497, 1, 1645, '', 'C', '', 1, 1, 'Y', '8cPOXKTY1rc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4247, '2019-01-19 20:22:22.667421+00', '2019-01-20 23:09:13.732164+00', 8749, 1, 1645, '', 'A', '', 1, 1, 'Y', 'aQHUNMqMj08', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4250, '2019-01-19 20:59:10.464947+00', '2019-01-20 23:10:22.349097+00', 11107, 1, 1645, '', 'C', 'The first time though is the best.', 1, 1, 'Y', 'jJyLqVFzhu0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4246, '2019-01-19 20:17:21.725396+00', '2019-01-20 23:11:10.106195+00', 15177, 3, 1645, '', 'C', '', 1, 1, 'Y', 'oO1Q-Jbg8wA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4244, '2019-01-19 19:50:43.322897+00', '2019-01-20 23:11:57.112283+00', 1391, 1, 1645, '', 'D', 'Twice through.', 1, 1, 'Y', '5SpY-KMVobU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4248, '2019-01-19 20:37:22.351078+00', '2019-01-20 23:12:48.763661+00', 3580, 7, 1645, '', 'C', '', 1, 1, 'Y', 'NJmbxEMQUxk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4245, '2019-01-19 20:00:24.19426+00', '2019-01-20 23:14:17.628911+00', 2656, 1, 1645, '', 'C', 'Done six times through in a three couple set.', 1, 1, 'Y', '4kFBZeLm31o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4257, '2019-01-21 03:22:37.712713+00', '2019-01-21 12:38:26.986717+00', 18164, 1, 2372, '', 'A', '', 1, 1, 'Y', 'g85THB5ORlY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4253, '2019-01-20 22:26:34.845086+00', '2019-01-22 10:34:16.7271+00', 7511, 1, 1645, '', 'C', '', 1, 1, 'Y', 'b8evLiQ4Q1I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4255, '2019-01-20 22:50:09.792579+00', '2019-01-22 10:35:35.341753+00', 2918, 2, 1645, '', 'C', 'Last 4 times through.', 1, 1, 'Y', '-_BBAWkxeNQ', 147, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4256, '2019-01-20 22:59:57.012457+00', '2019-01-22 10:36:57.198285+00', 1838, 3, 1645, '', 'B', 'Some shepherding of beginners with a few hesitations but a clear view of the dance.', 1, 1, 'Y', 'Ibc-ZSwT5ds', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4254, '2019-01-20 22:41:38.092382+00', '2019-01-22 10:32:26.829416+00', 9103, 3, 1645, '', 'C', 'Rather distant view.', 1, 1, 'Y', 'CJc9UTnk0YQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4252, '2019-01-20 22:09:18.354097+00', '2019-01-22 10:33:19.221201+00', 10459, 3, 1645, '', 'B', 'One or two glitches on later repeats but generally very clear.', 1, 1, 'Y', 'dOdIUnHUnRY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4262, '2019-01-24 18:02:07.847699+00', '2019-01-25 11:09:59.728861+00', 6981, 1, 1645, '', 'B', '', 1, 1, 'Y', 'LvLKwFVb1fo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4266, '2019-01-24 19:32:23.256182+00', '2019-01-25 11:38:25.867729+00', 15706, 1, 1645, '', 'A', '', 1, 1, 'Y', '8KTv0nQrtiM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4267, '2019-01-25 17:16:24.379831+00', '2019-01-25 18:16:04.006919+00', 18941, 1, 197, '', 'A', 'Performed by  Lower Hutt Club, Wellington, New Zealand, 2017', 1, 1, 'Y', 'VmNejPfm8pM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4270, '2019-01-25 17:40:46.199788+00', '2019-01-25 18:20:09.709423+00', 19136, 1, 197, '', 'A', 'Performed byLower Hutt Club, Wellington, New Zealand, 2018', 1, 1, 'Y', 'vkPQ6e7Z8X4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4263, '2019-01-24 18:07:02.573916+00', '2019-01-25 18:21:33.597655+00', 12941, 5, 1645, '', 'B', '', 1, 1, 'Y', 'woYqkyofFO4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4264, '2019-01-24 18:14:34.247224+00', '2019-01-25 18:22:16.910873+00', 4303, 1, 1645, '', 'C', 'Some 1st couples cross right hand at the end rather than passing right shoulder.', 1, 1, 'Y', 'D3uyKR3z5M0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4265, '2019-01-24 18:33:35.124473+00', '2019-01-25 18:23:10.428193+00', 5462, 3, 1645, '', 'B', '', 1, 1, 'Y', 'IV7PZ3McOv4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4290, '2019-02-05 20:19:40.787496+00', '2019-02-06 22:58:46.061669+00', 3782, 1, 1645, '', 'B', 'Twice through (the first part of a demonstration).', 1, 1, 'Y', 'TeZBVRVONgA', 10, 80, NULL);
INSERT INTO 'dancevideo' VALUES (4261, '2019-01-24 17:55:06.953681+00', '2019-01-25 18:24:19.859646+00', 6686, 1, 1645, '', 'D', 'The video starts with a demonstration of the figure in the last 16 bars, then once through the dance.', 1, 1, 'Y', 'Rkt11VXXJfc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6699, '2020-01-10 01:19:28.254657+00', '2020-01-11 14:45:04.165197+00', 16055, 2, 1296, '', 'C', '', 1, 1, 'Y', 'rL-hBBbYNUU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4269, '2019-01-25 17:27:39.096119+00', '2019-01-25 18:30:09.332246+00', 18956, 1, 197, '', 'A', 'Performed by Lower Hutt Club, Wellington, New Zealand, and friends, 2016', 1, 1, 'Y', 'EzghmlIoe-8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4268, '2019-01-25 17:22:42.905368+00', '2019-01-25 19:58:37.359703+00', 18946, 1, 197, '', 'A', 'Performed by Lower Hutt Club, Wellington, New Zealand, 2017', 1, 1, 'Y', 'iuaXrp7NZrg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4271, '2019-01-27 21:13:22.521001+00', '2019-01-27 22:49:16.251318+00', 999, 1, 2586, '', 'A', 'The dance should have two chords at the beginning, for the 3rd and 4th couples to cross over to the opposite side.  In this video, the 3rd and 4th couples are already on the opposite side.', 1, 1, 'Y', 'PNrnNwdCjiE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4273, '2019-01-28 16:44:08.650904+00', '2019-01-28 20:57:47.602533+00', 387, 1, 274, '', 'A', 'Burns Supper 2019, Budapest', 1, 1, 'Y', 'FNWKSGq8XKc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4275, '2019-01-29 10:27:23.960137+00', '2019-01-29 12:30:42.961279+00', 4014, 3, 274, '', 'A', 'Burns Supper 2019, Budapest', 1, 1, 'Y', 'D-pOETVGhZg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4276, '2019-01-29 12:12:53.705983+00', '2019-01-29 23:40:30.484081+00', 19171, 1, 1645, '', 'C', 'There is some slight confusion near the end among the couples closest to the camera, otherwise its good.', 1, 1, 'Y', '_OiRjVDxl5Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4277, '2019-01-29 22:34:36.212353+00', '2019-01-29 23:42:11.278178+00', 12508, 2, 2586, '', 'A', '', 1, 1, 'Y', 'xVSd-PTwomY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4278, '2019-01-29 22:35:42.205852+00', '2019-01-29 23:47:17.458784+00', 2056, 1, 2586, '', 'A', '', 1, 1, 'Y', 'HeQiPZ-r0Jo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4291, '2019-02-05 20:24:38.66357+00', '2019-02-06 23:00:57.328953+00', 11638, 1, 1645, '', 'B', 'Twice through (as part of a longer demonstration).', 1, 1, 'Y', 'TeZBVRVONgA', 80, 200, NULL);
INSERT INTO 'dancevideo' VALUES (4282, '2019-02-03 14:36:59.998826+00', '2019-02-03 20:46:13.728671+00', 8144, 2, 274, '', 'C', 'Scottish Dance House for beginners 02.02.2019, Budapest

', 1, 1, 'Y', 'S7GGUyLBilw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4281, '2019-02-03 14:06:11.399113+00', '2019-02-03 20:58:33.407152+00', 11731, 2, 274, '', 'D', 'Scottish Dance House for beginners 02.02.2019, Budapest



The version shown here is a variation of that described in the e-crib.', 1, 1, 'Y', 'PhdgvcL0F5g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4279, '2019-02-01 05:25:05.118611+00', '2019-02-03 20:59:02.087211+00', 19169, 1, 513, '', 'A', '', 1, 1, 'Y', 'abadR_xmsGE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5447, '2019-11-28 18:35:29.90889+00', '2019-11-28 23:41:42.618481+00', 15071, 1, 1645, '', 'C', '', 1, 1, 'Y', 'pioDzuQyrs0', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4280, '2019-02-02 10:24:31.277681+00', '2019-02-03 20:53:51.423621+00', 5927, 2, 274, '', 'C', 'The first two repeats are good but there are some problems after that.', 1, 1, 'Y', 'pcgVBp7JW6Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4284, '2019-02-04 10:30:38.193347+00', '2019-02-04 12:12:30.474908+00', 10794, 2, 513, '', 'C', '', 1, 1, 'Y', 'pwVwinEYo6A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4283, '2019-02-04 09:23:18.634442+00', '2019-02-04 12:21:39.221156+00', 19117, 1, 513, '', 'C', '', 1, 1, 'Y', 'cdOmoa-szQI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4292, '2019-02-05 20:29:51.4803+00', '2019-02-06 23:02:20.806121+00', 3252, 5, 1645, '', 'B', 'Twice through (end of a longer demonstration).', 1, 1, 'Y', 'TeZBVRVONgA', 200, 273, NULL);
INSERT INTO 'dancevideo' VALUES (4286, '2019-02-04 10:58:03.468514+00', '2019-02-04 12:49:29.610499+00', 5911, 1, 513, '', 'D', 'Mostly too confused to be very useful for learning the dance. The best repeats are in the middle part of the video, eg one starting at 1:47.', 1, 1, 'Y', 'uA1_QBUoAJ8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4285, '2019-02-04 10:48:28.227516+00', '2019-02-04 12:59:31.170721+00', 18010, 1, 513, '', 'C', '', 1, 1, 'Y', 'tJQq6ei53PY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4289, '2019-02-04 14:30:20.98047+00', '2019-02-04 17:11:20.042259+00', 13859, 2, 513, '', 'B', '', 1, 1, 'Y', 'bgMRJJo2BdM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4288, '2019-02-04 14:29:06.216347+00', '2019-02-04 17:25:14.663586+00', 14117, 1, 513, '', 'B', '', 1, 1, 'Y', 'I0Zc9OIzpDY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4287, '2019-02-04 14:27:34.745255+00', '2019-02-04 17:28:38.10496+00', 11628, 1, 513, '', 'B', '', 1, 1, 'Y', 'gQecV3Z-PSY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4412, '2019-04-03 08:15:53.197462+00', '2019-04-03 17:52:23.114673+00', 17327, 2, 513, '', 'C', '', 1, 1, 'Y', 'YaY1ASo3xPM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4413, '2019-04-03 11:10:20.975833+00', '2019-04-04 21:22:49.127044+00', 9009, 3, 513, '', 'C', 'Once through.', 1, 1, 'Y', 'cpOjmJO4Esk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4293, '2019-02-06 15:27:39.070422+00', '2019-02-06 18:43:23.590863+00', 6104, 2, 2586, '', 'B', 'The Red Thistle Dancers - 2007 Pleasanton, California.

One of the dances within a demonstration.  Twice through.  Excellent dancing but a great deal of background noise on the soundtrack.', 1, 1, 'Y', 'jFIHP2xIVgc', 1186, 1310, NULL);
INSERT INTO 'dancevideo' VALUES (4294, '2019-02-07 18:50:34.035319+00', '2019-02-07 18:52:36.051503+00', 2428, 8, 1645, '', 'A', 'Demonstration of RSCDS Teaching Certificate: Unit 2 Dances', 1, 1, 'Y', '8gk991Ax8eo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4297, '2019-02-08 21:02:46.895096+00', '2019-02-11 16:50:39.082696+00', 6817, 2, 1645, '', 'C', 'Four times through (danced in 3 couple sets).', 1, 1, 'Y', 'LPT12n2R9N4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4306, '2019-02-11 15:38:55.759996+00', '2019-02-11 16:04:24.322801+00', 745, 3, 513, '', 'A', '', 1, 1, 'Y', '8k4zeQtiz_I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4301, '2019-02-11 15:30:22.659647+00', '2019-02-11 16:35:16.759291+00', 2661, 2, 513, '', 'A', '', 1, 1, 'Y', 'DQNWcuJ2KF8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4302, '2019-02-11 15:31:32.420048+00', '2019-02-11 16:08:50.939062+00', 17121, 4, 513, '', 'A', '', 1, 1, 'Y', 'ZY08wRPydB0', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4303, '2019-02-11 15:33:16.880033+00', '2019-02-11 16:12:20.926037+00', 10232, 5, 513, '', 'A', '', 1, 1, 'Y', 'Hvffk0h_URs', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4305, '2019-02-11 15:38:02.708853+00', '2019-02-11 16:38:08.973207+00', 5981, 1, 513, '', 'A', '', 1, 1, 'Y', 'jUlGV4sHvRg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4307, '2019-02-11 15:39:42.588967+00', '2019-02-11 16:41:52.020083+00', 6406, 1, 513, '', 'A', '', 1, 1, 'Y', 'R0Exm6wUjwg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4300, '2019-02-08 21:34:23.123119+00', '2019-02-11 16:48:39.437549+00', 11773, 2, 1645, '', 'C', '', 1, 1, 'Y', '__QU8XUFgVo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4296, '2019-02-08 20:46:15.334696+00', '2019-02-11 16:49:12.931931+00', 3444, 1, 1645, '', 'D', 'Twice through only with a few problems here and there, especially the last 8 bars.', 1, 1, 'Y', 'VNbnLMJ2mfQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4298, '2019-02-08 21:13:57.307129+00', '2019-02-11 16:49:33.09915+00', 4474, 1, 1645, '', 'B', '', 1, 1, 'Y', 'EhypgQ9TEOY', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4295, '2019-02-08 20:30:29.809137+00', '2019-02-11 16:49:51.9117+00', 5095, 1, 1645, '', 'D', 'Once per couple (at a beginners night). Both advance and retire figures should be for all three couples which is mostly not the case in the set on the right.', 1, 1, 'Y', 'LlGmJETo6RY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4299, '2019-02-08 21:27:05.451965+00', '2019-02-11 16:51:17.756197+00', 14820, 1, 1645, '', 'C', 'This clip is the last two repeats of a demonstration. Still a few glitches. Here the dancers always set advancing past each other on bars 27-28 (which works well) whereas the cribs suggest they should change places left hands.', 1, 1, 'Y', 'vwwsKqKqcB4', 138, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4308, '2019-02-11 20:10:42.568223+00', '2019-02-11 20:11:01.225449+00', 652, 2, 2697, '', 'A', '', 1, 1, 'Y', 'N0sXopEceSM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4309, '2019-02-11 20:11:36.861673+00', '2019-02-11 20:11:43.372979+00', 10787, 9, 2697, '', 'A', '', 1, 1, 'Y', '4viIzdTj8uM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4304, '2019-02-11 15:34:42.520219+00', '2019-02-13 22:20:35.949388+00', 7242, 6, 513, '', 'A', '', 1, 1, 'Y', 'JaPRS1osbHM', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4318, '2019-02-12 13:40:25.202724+00', '2019-02-12 18:26:51.056881+00', 894, 5, 2586, '', 'B', '', 1, 1, 'Y', 'HB6FI5pXvWk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4314, '2019-02-12 13:06:59.903006+00', '2019-02-12 19:05:40.876582+00', 1030, 1, 513, '', 'A', '', 1, 1, 'Y', 'X932Kvs6_pU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4335, '2019-02-23 12:40:34.154621+00', '2019-02-25 23:18:42.786694+00', 271, 1, 1645, '', 'C', 'Once through.



In bars 17-24 1st couple should lead down followed by 2nd couple and back to progressed places, but here only 1st couple lead down, back and cast off.', 1, 1, 'Y', '1usW2xgS_zM', 24, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4315, '2019-02-12 13:08:06.783239+00', '2019-02-12 20:42:34.973165+00', 14534, 3, 513, '', 'A', '', 1, 1, 'Y', 'sRQBAFn6mQg', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4310, '2019-02-12 13:02:58.93231+00', '2019-02-12 20:56:27.999754+00', 13589, 5, 513, '', 'A', 'Excellent dancing but with a distraction in the camera''s view.', 1, 1, 'Y', 'wlcOLfSl9a8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4311, '2019-02-12 13:04:08.471544+00', '2019-02-12 20:59:16.544587+00', 17133, 5, 513, '', 'A', '', 1, 1, 'Y', '6notYwkc7aw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4312, '2019-02-12 13:05:11.013728+00', '2019-02-12 21:04:33.718074+00', 16566, 3, 513, '', 'A', '', 1, 1, 'Y', 'AXXf0nSS8xA', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4336, '2019-02-28 00:13:07.29902+00', '2019-02-28 00:13:36.589035+00', 19204, 1, 202, '', 'B', '', 1, 1, 'Y', 'x2-3Y1VpY40', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4316, '2019-02-12 13:10:27.115789+00', '2019-02-12 21:10:59.567301+00', 11772, 6, 513, '', 'A', '', 1, 1, 'Y', 'PIHRmnnoE9w', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4320, '2019-02-13 04:16:23.817143+00', '2019-02-13 21:05:14.043904+00', 15030, 1, 2709, '', 'C', 'The submitter of this video suggested that the correct title of this dance may well be "The Prairie Crocus".

However the TAC books page for the Prairie Gold book lists it as "A Prairie Crocus".', 1, 1, 'Y', 'EY5vRjLuQFo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4324, '2019-02-13 21:56:25.42267+00', '2019-02-16 10:17:03.451993+00', 895, 4, 1645, '', 'A', '', 1, 1, 'Y', 'DQotPMGACNM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4344, '2019-03-06 16:29:43.138823+00', '2019-03-06 16:50:33.912222+00', 954, 2, 1645, '', 'B', '', 1, 1, 'Y', 'UiyZDNE48SE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4323, '2019-02-13 21:47:08.694167+00', '2019-02-16 10:18:29.187102+00', 3108, 5, 1645, '', 'A', '', 1, 1, 'Y', 'ggDzt9vDOhg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4328, '2019-02-13 22:19:08.299349+00', '2019-02-16 10:24:23.100432+00', 3608, 3, 1645, '', 'B', '', 1, 1, 'Y', 'jiLp8oiiRvQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4322, '2019-02-13 21:43:56.660927+00', '2019-02-16 10:26:09.536336+00', 16534, 6, 1645, '', 'A', '', 1, 1, 'Y', '1OkhedA9rIA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4325, '2019-02-13 22:00:49.886596+00', '2019-02-16 10:27:41.997803+00', 3953, 3, 1645, '', 'A', '', 1, 1, 'Y', 'WAHMsuXTn8E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4337, '2019-03-01 09:23:21.181116+00', '2019-03-01 09:46:39.636372+00', 17630, 2, 2581, '', 'C', 'Dancers from Helen''s favourite class, who wanted to remember her.', 1, 1, 'Y', 'NJoZnlEeMB4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4321, '2019-02-13 21:37:02.177149+00', '2019-02-16 11:26:04.778434+00', 19184, 1, 1645, '', 'C', 'The video starts about two bars into the dance.', 1, 1, 'Y', 'zaONDrju9ow', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4330, '2019-02-16 22:15:18.230306+00', '2019-02-16 22:16:58.295175+00', 2887, 1, 1645, '', 'A', '', 1, 1, 'Y', 'sITDgjBHi2o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4331, '2019-02-17 14:59:50.022648+00', '2019-02-17 19:51:23.054432+00', 2415, 2, 2586, '', 'B', '', 1, 1, 'Y', 'W9-Yda07yeY', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4333, '2019-02-18 23:06:23.391468+00', '2019-02-19 00:45:18.495362+00', 1492, 3, 2586, '', 'B', 'Cambridge Freshers'' Ceilidh, 2018 - part of a display, twice through.  Danced in a 3-couple set rather than the 3-couples in a 4-couple set, as devised.', 1, 1, 'Y', 'RiKpkAjQrGk', 210, 285, NULL);
INSERT INTO 'dancevideo' VALUES (4332, '2019-02-18 11:27:53.726084+00', '2019-02-19 00:46:48.436528+00', 16473, 2, 1645, '', 'B', 'In some of the "set and links" the link is done just as a step up, but overall its very clear.', 1, 1, 'Y', 'QjqPqN73upU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4334, '2019-02-23 12:35:09.877679+00', '2019-02-23 12:36:13.730033+00', 3285, 1, 1645, '', 'C', 'Once through.', 1, 1, 'Y', 'k2_uLgrKqyw', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4338, '2019-03-02 20:39:55.468393+00', '2019-03-02 20:40:10.684237+00', 3364, 1, 106, '', 'D', 'Clear video, but hardly useable as example.', 1, 1, 'V', '127991823', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4350, '2019-03-09 10:16:36.889006+00', '2019-03-09 20:26:31.300544+00', 19237, 3, 197, '', 'B', 'Danced by RSCDS Lyon Branch, 2018.

1st couple should retain hands throughout bars 9-18 and tap partner on shoulder in bars 19 and 27', 1, 1, 'V', '290437657', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4341, '2019-03-04 11:52:05.526573+00', '2019-03-04 11:53:09.47292+00', 10798, 1, 106, '', 'C', 'The Ruby Hornpipe was on the programme for the Waikanae SCD Club''s 40th anniversary dance on August 2, 2015 in the lovely hall at the Southwards Car Museum north of Paraparaumu (New Zealand).   

Live music was provided by Catherine Fraser and Duncan Smith.', 1, 1, 'Y', 'rwWAjFBxdJ8', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4340, '2019-03-03 23:02:32.830222+00', '2019-03-04 20:31:52.54405+00', 1128, 4, 1645, '', 'C', 'Once through excerpt.', 1, 1, 'Y', '-1_1TeWl0oY', 20, 71, NULL);
INSERT INTO 'dancevideo' VALUES (4339, '2019-03-03 22:52:11.73889+00', '2019-03-04 20:32:05.330541+00', 1128, 3, 1645, '', 'A', 'Once through (part of a demonstration medley) with the final promenade leading off rather than round the set.', 1, 1, 'Y', '_22T5XU2GYA', 159, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4343, '2019-03-06 16:22:53.693638+00', '2019-03-06 16:50:14.438633+00', 954, 1, 1645, '', 'C', 'Twice through by one couple. Clear view of the set.', 1, 1, 'V', '124376656', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4346, '2019-03-06 18:23:50.458715+00', '2019-03-06 18:25:33.36395+00', 16466, 1, 106, '', 'B', 'Once only', 1, 1, 'Y', 'XixmQUH8vqE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4405, '2019-04-03 07:19:51.186893+00', '2019-04-03 17:47:23.972454+00', 8577, 2, 513, '', 'C', 'The video starts about 1 bar into the dance. Six times through in three couple sets.', 1, 1, 'Y', 'm5JVqVe_i44', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4347, '2019-03-08 12:39:06.768701+00', '2019-03-08 15:22:30.109923+00', 14478, 1, 274, '', 'B', 'Budapest Local Club 07.03.2019.  Note the elegant way 1W and 4W correct a position error on the last 2 bars of the third time through.

', 1, 1, 'Y', 'f4hujL4aizs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4351, '2019-03-10 00:29:39.390127+00', '2019-03-10 00:31:35.345044+00', 3364, 2, 106, '', 'B', 'Videotaped  by the RSCDS Ottawa Branch in the summer of 2018', 1, 1, 'Y', 'ZQHFaQjZW9k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4352, '2019-03-10 00:53:05.886528+00', '2019-03-10 01:14:22.247752+00', 19058, 1, 2586, '', 'A', 'The deviser has suggested that taking hands in the reels of three could be helpful for beginners.', 1, 1, 'Y', 'nOLlST2_JwU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4353, '2019-03-10 01:20:42.976103+00', '2019-03-10 01:20:57.466967+00', 19238, 1, 106, '', 'B', '', 1, 1, 'Y', '8lhaqgtMqPE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4354, '2019-03-10 13:08:11.581326+00', '2019-03-10 13:08:25.881071+00', 16502, 2, 2697, '', 'C', '', 1, 1, 'Y', '2e1taBraDVo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4355, '2019-03-10 13:09:07.965964+00', '2019-03-10 13:09:15.345181+00', 12634, 1, 2697, '', 'C', '', 1, 1, 'Y', 'p_oHH5Gyqj0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4367, '2019-03-10 13:15:26.378951+00', '2019-03-10 13:16:36.031796+00', 7243, 1, 2697, '', 'C', '', 1, 1, 'Y', 'YTujjgR-t7o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4359, '2019-03-10 13:11:03.382933+00', '2019-03-10 13:16:46.027579+00', 2534, 1, 2697, '', 'C', '', 1, 1, 'Y', 'sNaTMwQQ1jA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4364, '2019-03-10 13:14:24.632732+00', '2019-03-10 13:16:59.969858+00', 2920, 1, 2697, '', 'C', '', 1, 1, 'Y', 'cKRJDzCgvRo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4361, '2019-03-10 13:11:42.372324+00', '2019-03-10 13:17:04.970691+00', 3336, 6, 2697, '', 'C', '', 1, 1, 'Y', '1smy9BDQzTw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4363, '2019-03-10 13:14:04.963946+00', '2019-03-10 13:17:14.154618+00', 18099, 2, 2697, '', 'B', '', 1, 1, 'Y', 'OanJcCDoUMo', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4362, '2019-03-10 13:12:06.095554+00', '2019-03-10 13:17:18.854165+00', 18099, 1, 2697, '', 'C', '', 1, 1, 'Y', 'bVZq9QK4uuQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4369, '2019-03-10 13:16:20.181852+00', '2019-03-10 13:17:23.687593+00', 4894, 2, 2697, '', 'C', '', 1, 1, 'Y', 'Ws-nRxDP3bI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4366, '2019-03-10 13:15:04.955364+00', '2019-03-10 13:17:27.726853+00', 6443, 1, 2697, '', 'C', '', 1, 1, 'Y', 'GZiVr4ZDIXw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4357, '2019-03-10 13:10:14.004595+00', '2019-03-10 13:17:31.527245+00', 8174, 1, 2697, '', 'C', '', 1, 1, 'Y', 'Yt4FMZ4mf7w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4360, '2019-03-10 13:11:20.269156+00', '2019-03-10 13:16:28.48917+00', 278, 1, 2697, '', 'C', '', 1, 1, 'Y', 'n-Ko_EdtDRY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4358, '2019-03-10 13:10:38.343609+00', '2019-03-10 13:16:55.637141+00', 2551, 1, 2697, '', 'C', '', 1, 1, 'Y', 'LUsh4iIvkMI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4387, '2019-03-20 22:32:55.600097+00', '2019-03-20 22:35:11.641726+00', 5589, 1, 106, '', 'C', '', 1, 1, 'Y', '082vJUeYRmw', 200, 350, NULL);
INSERT INTO 'dancevideo' VALUES (4388, '2019-03-20 22:57:03.612578+00', '2019-03-20 23:09:22.833269+00', 6861, 1, 106, '', 'C', 'This is a 3C/4L dance,  In this demonstration, the set consists of two 3C sets, bottom to bottom.  The progression on bar 24 has been changesd (to 2,3,1), and the 6 hands round in [25-32] has been modified into three times 4 hands round or a single 12 hands round.  Do not try to learn the dance from this demo.', 1, 1, 'Y', '082vJUeYRmw', 621, 734, NULL);
INSERT INTO 'dancevideo' VALUES (4371, '2019-03-12 18:40:20.27653+00', '2019-03-12 18:48:04.122872+00', 705, 1, 1645, '', 'B', 'An excerpt from a longer demonstration medley. Although the dancing is clearly excellent, this demonstration shows just bars 1-88 and 121-128 of the whole dance, skipping bars 89-120 inclusive.', 1, 1, 'Y', 'z7hmXOOAQXg', 281, 388, NULL);
INSERT INTO 'dancevideo' VALUES (4377, '2019-03-16 17:28:50.058071+00', '2019-03-21 00:04:09.96999+00', 12089, 1, 1645, '', 'C', 'Three times through - unfortunately with some background piping over the music.', 1, 1, 'Y', 'z18kl-O7wTo', 29, 217, NULL);
INSERT INTO 'dancevideo' VALUES (4383, '2019-03-19 12:32:40.55231+00', '2019-03-21 00:08:18.340307+00', 9862, 6, 513, '', 'A', '', 1, 1, 'Y', 'bt5CQlrLTWw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4372, '2019-03-13 12:23:41.956576+00', '2019-03-13 23:41:45.949878+00', 11198, 1, 2447, '', 'B', 'Excellent performance and love the music but not the suggested music.



Twice through excerpt from a long display.', 1, 1, 'Y', 'SMi8NB4qJSk', 238, 305, NULL);
INSERT INTO 'dancevideo' VALUES (4374, '2019-03-15 00:19:36.666205+00', '2019-03-15 19:19:36.070363+00', 4618, 2, 2586, '', 'A', '', 1, 1, 'Y', 'J7fNZHyiKWQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4375, '2019-03-15 01:04:07.661023+00', '2019-03-15 19:20:33.010755+00', 10171, 2, 2586, '', 'A', '', 1, 1, 'Y', 'XMOWfULsRVY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4373, '2019-03-14 23:38:25.654194+00', '2019-03-15 19:27:44.660766+00', 18044, 2, 2586, '', 'A', 'On the last two bars of each time through the dance, 2nd man and 3rd woman both have a polite turn.  Occasionally in this video the polite turn is omitted.



Although this is a 3 couple dance, the instructions encourage 1st couple to repeat the first 4 bars after their second time to end in 4th place and also suggest that optionally the 3rd & 4th couples can do that at the start which is done here.', 1, 1, 'Y', '78c7LHMKwn0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4378, '2019-03-17 15:20:12.096296+00', '2019-03-21 00:09:28.126542+00', 9933, 1, 26003, '', 'D', 'There are errors, but they seem obvious so do not detract from the value of the video.', 1, 1, 'Y', 'upG5Z4Fok4k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4376, '2019-03-16 12:49:25.513758+00', '2019-03-16 17:12:25.10674+00', 2713, 1, 3129, '', 'C', 'Twice through (part of a longer demonstration).', 1, 1, 'Y', 'NYknBI9_cn8', 120, 198, NULL);
INSERT INTO 'dancevideo' VALUES (4384, '2019-03-20 21:38:12.345737+00', '2019-03-20 21:38:46.2911+00', 13502, 1, 106, '', 'D', '', 1, 1, 'Y', 'qsWBPVUKRJo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2699, '2016-10-28 21:30:33.314162+00', '2019-03-20 21:54:15.633323+00', 15403, 3, 106, '', 'A', 'There is a choreography error around 1:32; in entering the second half reel across First Woman loops around 4W.', 1, 1, 'Y', '3oi1k4wBa5k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4385, '2019-03-20 22:12:40.3981+00', '2019-03-20 22:12:51.47354+00', 2687, 1, 106, '', 'C', 'Cologne Ball  26.9.2015 - There and Back again.   Music: Luke & Adam Brady', 1, 1, 'Y', 'XqgNI5wGtK0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4349, '2019-03-09 10:04:50.525281+00', '2021-10-14 23:30:35.27521+00', 19237, 2, 197, '', 'Z', 'Clan McBedoin SCD group at Association day in Carpentras, France, 2018. The deviser, Erika Ritzau, is dancing as first lady.

Video no longer available: perhaps changed from Unlisted to Private?', 1, 1, 'Y', 'G-j3C1zKQ-0', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4386, '2019-03-20 22:19:12.051239+00', '2019-03-20 22:25:48.219789+00', 2687, 2, 106, '', 'B', 'RSCDS Canberra Branch display performed on 24 April 2015 at the National Folk Festival in Canberra.', 1, 1, 'Y', '082vJUeYRmw', 360, 594, NULL);
INSERT INTO 'dancevideo' VALUES (4380, '2019-03-19 09:33:10.407225+00', '2019-03-21 00:16:14.781199+00', 16337, 1, 274, '', 'B', 'Twice through excerpt from a longer demonstration.', 1, 1, 'Y', 'z6Zc1_dzZIQ', 73, 197, NULL);
INSERT INTO 'dancevideo' VALUES (4382, '2019-03-19 09:44:36.685248+00', '2019-03-21 00:21:45.306343+00', 10086, 1, 274, '', 'A', 'Twice through as part of a longer demonstration with the last 8 bars of the second repeat adapted for the transition to the next dance.', 1, 1, 'Y', '17UxOxtRtRM', 208, 324, NULL);
INSERT INTO 'dancevideo' VALUES (4381, '2019-03-19 09:40:30.919172+00', '2019-03-21 00:24:57.982508+00', 8368, 2, 274, '', 'A', 'Two couple set', 1, 1, 'Y', '17UxOxtRtRM', 324, 398, NULL);
INSERT INTO 'dancevideo' VALUES (4393, '2019-03-24 00:22:39.695115+00', '2019-03-24 00:36:37.616518+00', 9102, 3, 106, '', 'A', 'RSCDS Glasgow Branch.  Dances for Primary School Festival 2016', 1, 1, 'Y', 'DoUPONyEAcA', 18, 96, NULL);
INSERT INTO 'dancevideo' VALUES (4379, '2019-03-19 09:30:51.326507+00', '2019-03-21 00:27:58.206605+00', 8368, 1, 274, '', 'B', 'Twice through (end of a longer demonstration).', 1, 1, 'Y', 'z6Zc1_dzZIQ', 197, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4390, '2019-03-23 12:08:52.942387+00', '2019-03-24 00:15:47.810104+00', 18537, 3, 2219, '', 'B', 'Video commences at bar 5. The set in front of the microphone does a ''good job''.  In that set, the deviser is dancing as first lady at 00:57.', 1, 1, 'Y', 'fztuoozAxZo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4394, '2019-03-24 00:27:27.3912+00', '2019-03-24 00:36:48.835762+00', 8202, 1, 106, '', 'A', 'RSCDS Glasgow Branch.  Dances for Primary School Festival 2016', 1, 1, 'Y', 'DoUPONyEAcA', 110, 188, NULL);
INSERT INTO 'dancevideo' VALUES (4391, '2019-03-24 00:17:54.187938+00', '2019-03-24 00:21:39.114014+00', 13619, 5, 106, '', 'A', 'RSCDS Glasgow Branch.  Dances for Primary School Festival 2016', 1, 1, 'Y', 'DoUPONyEAcA', 588, 707, NULL);
INSERT INTO 'dancevideo' VALUES (4395, '2019-03-24 00:30:49.092871+00', '2019-03-24 00:36:57.824421+00', 5713, 5, 106, '', 'A', 'RSCDS Glasgow Branch.  Dances for Primary School Festival 2016', 1, 1, 'Y', 'DoUPONyEAcA', 197, 302, NULL);
INSERT INTO 'dancevideo' VALUES (4400, '2019-03-24 22:49:27.865402+00', '2019-03-25 10:27:31.835911+00', 1074, 1, 2213, '', 'B', '', 1, 1, 'Y', 'Ad9pGOQl0-4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4396, '2019-03-24 00:34:10.645066+00', '2019-03-24 00:59:41.357634+00', 8203, 4, 106, '', 'A', 'This video shows a 4C set, 

RSCDS Glasgow Branch.  Dances for Primary School Festival 2016', 1, 1, 'Y', 'DoUPONyEAcA', 316, 397, NULL);
INSERT INTO 'dancevideo' VALUES (4398, '2019-03-24 01:08:23.671083+00', '2019-03-24 01:10:19.939872+00', 1562, 6, 106, '', 'B', 'RSCDS Glasgow Branch.  Dances for Primary School Festival 2016', 1, 1, 'Y', 'DoUPONyEAcA', 498, 574, NULL);
INSERT INTO 'dancevideo' VALUES (4397, '2019-03-24 01:03:07.256304+00', '2019-03-24 01:10:31.41888+00', 2260, 5, 106, '', 'A', 'RSCDS Glasgow Branch.  Dances for Primary School Festival 2016', 1, 1, 'Y', 'DoUPONyEAcA', 411, 487, NULL);
INSERT INTO 'dancevideo' VALUES (4389, '2019-03-22 14:48:23.142654+00', '2019-03-24 09:08:01.263315+00', 6386, 4, 1645, '', 'A', '', 1, 1, 'Y', '_sfgb1mqdWM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4404, '2019-04-01 23:50:00.759306+00', '2019-04-01 23:50:18.008225+00', 19252, 1, 106, '', 'C', 'Rachel Pusey, 22 okt. 2017:  At the Heavenly Seventies Party we celebrated with Donna, Jennifer, Linda, Paula and Trudy.

Trudy devised the dance "Emma''s Strathspey" and wrote the lead tune in honor of her daughter.

Music by Deby Benton Grosjean (fiddle) and Andy Imbrie (piano)

', 1, 1, 'Y', 'DMF_Y2oRqy4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4401, '2019-03-26 15:06:20.716185+00', '2019-03-26 15:06:32.25264+00', 2551, 2, 2697, '', 'D', '', 1, 1, 'Y', 'OLptu0teswk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4409, '2019-04-03 07:23:45.042886+00', '2019-04-04 21:20:20.977006+00', 3021, 3, 513, '', 'C', '', 1, 1, 'Y', 'H0wI_ek3VLA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4408, '2019-04-03 07:22:53.172218+00', '2019-04-04 21:34:15.794675+00', 1931, 8, 513, '', 'D', 'Many variations going on here but great fun being had by all.', 1, 1, 'Y', 'huVZ-YjjpI4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4407, '2019-04-03 07:21:42.071765+00', '2019-04-04 21:28:12.641007+00', 13627, 1, 513, '', 'C', '', 1, 1, 'Y', 'jrlzpUGwlfE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4411, '2019-04-03 08:09:04.957699+00', '2019-04-04 21:34:00.60098+00', 14673, 1, 513, '', 'C', '', 1, 1, 'Y', 'zhop_-bhuwE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4406, '2019-04-03 07:20:43.413985+00', '2019-04-04 21:41:27.014053+00', 9800, 4, 513, '', 'C', '', 1, 1, 'Y', 'NZyMoHO95BA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (945, '2013-06-01 07:43:29.626041+00', '2019-04-03 21:45:52.907702+00', 4759, 1, 1506, '', 'B', 'Lugnasad Celtic Dance School demo at Lviv, october 2007.



The transition on [15-16] from the mirror reels into the rondel is danced according to Drewry''s original text in Book 23 which says: "First couple, giving right hands cross to own sides, dance up to the top and turn to face the second couple who have danced in ready for the Rondel."  The current instructions say: "First couple, giving right hands, dance up turning halfway round to finish facing second couple ready for the Rondel."   For further information look at the “Extra Info” for the dance.  Many dancers prefer the original instructions.



The dancers here take hands during the reels, possibly following that suggestion in earlier versions of the e-crib and minicrib. However taking hands is not mentioned in the original instructions (except for 1st couple when crossing). As of April 2019 the e-crib has been updated to match and the comment forwarded to the minicrib team.

', 1, 1, 'Y', 'inNjSs6i3IQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4414, '2019-04-05 16:50:14.869323+00', '2019-04-05 20:22:01.849881+00', 15330, 2, 274, '', 'C', 'Farewell Ceilidh, Budapest, 2015', 1, 1, 'Y', 'K8p1B0-S3Qs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4417, '2019-04-09 19:04:04.457008+00', '2019-04-09 19:04:29.521186+00', 1562, 4, 106, '', 'B', 'I''ve found that it''s quite often that there are people left over for the Dashing White Sergeant.  Rather than having people sitting out, below is a link to a new video showing how to do the dance with 4 rather than 3.    I know it''s reeling, thus beyond the pale to many fellow SCD-ers, but please would you consider adding it to your databases.  Iain Ross

', 1, 1, 'Y', '1gAR32ukJ0A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4449, '2019-04-10 00:58:05.127399+00', '2019-04-10 00:58:05.127399+00', 11081, 1, 1296, '', 'X', '''Salute to Noel Lillie'' is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'Z0nG1Mfw7P8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4450, '2019-04-10 00:58:05.14238+00', '2019-04-10 00:58:05.14238+00', 17460, 5, 1296, '', 'X', '''Slytherin House'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'NsCcJoaacbA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4451, '2019-04-10 00:58:05.157467+00', '2019-04-10 00:58:05.157467+00', 3665, 2, 1296, '', 'X', '''Lake Geneva'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'N-l26LZDHgI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4452, '2019-04-10 00:58:05.174027+00', '2019-04-10 00:58:05.174027+00', 14217, 1, 1296, '', 'X', '''Ruby Lips'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'IIexYCnVtzw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4453, '2019-04-10 00:58:05.202744+00', '2019-04-10 00:58:05.202744+00', 5062, 2, 1296, '', 'X', '''The Old Man of Storr'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'RWae7KHR1ZU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4454, '2019-04-10 00:58:05.216333+00', '2019-04-10 00:58:05.216333+00', 6490, 1, 1296, '', 'X', '''The Silver Square'' is a 32 bar reel for 5 couples.', 1, 1, 'Y', '5N0DIBSge8M', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4455, '2019-04-10 00:58:05.232401+00', '2019-04-10 00:58:05.232401+00', 7042, 1, 1296, '', 'X', '''Wells House'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '2XGQviVfBsw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4456, '2019-04-10 00:58:05.249928+00', '2019-04-10 00:58:05.249928+00', 14997, 1, 1296, '', 'X', '''Easy Does It'' is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'mwXY-g3fqD0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (4747, '2019-04-11 08:16:45.858537+00', '2019-04-11 18:36:08.333836+00', 888, 3, 2824, '', 'B', 'Two and a half times through, the couples wear colour co-ordinated t-shirts which helps following the dance.', 1, 1, 'Y', '9DrHp8vfYyY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4748, '2019-04-11 09:29:48.900186+00', '2019-04-11 18:39:38.238013+00', 8932, 2, 2824, '', 'C', '4 times through in a 3cpl. set', 1, 1, 'Y', 'prt4O7pasCE', 50, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4745, '2019-04-11 08:04:44.499099+00', '2019-04-11 18:47:30.113853+00', 4032, 3, 2824, '', 'C', 'Good camera angle/elevated point of view of two rows of sets.', 1, 1, 'Y', '_OipqN3E2H8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4746, '2019-04-11 08:08:13.902059+00', '2019-04-11 18:53:00.3932+00', 4032, 4, 2824, '', 'B', 'Video shows excellent dancing, due to the camera being very close to the set the camera angle just about manages to capture the three  active couples.', 1, 1, 'Y', '2xbWCRHQ2yc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4754, '2019-04-12 11:44:17.646704+00', '2019-04-12 17:56:51.014273+00', 13581, 6, 2824, '', 'A', 'Twice through, teaching video with audio/subtitle description included', 1, 1, 'Y', '2qZh1ppXV4U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4751, '2019-04-12 10:05:49.770976+00', '2019-04-12 18:17:00.924913+00', 5199, 2, 2824, '', 'B', '', 1, 1, 'Y', 'SHZq1hC0G1k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4752, '2019-04-12 10:09:51.035832+00', '2019-04-12 18:22:08.662762+00', 17800, 1, 2824, '', 'B', 'One dancer turns away from rather than towards partner during the cast down and back. All couples take hands in the reels though that is not specified in the instructions.', 1, 1, 'Y', '94CAUHbMqPA', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4753, '2019-04-12 10:16:30.980691+00', '2019-04-12 18:27:59.010045+00', 8569, 1, 2824, '', 'B', 'Four times through.', 1, 1, 'Y', 'QVlsmkK2ezw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6700, '2020-01-10 01:19:28.347245+00', '2020-01-10 23:59:55.749735+00', 2312, 2, 1296, '', 'D', 'Encore with variations.', 1, 1, 'Y', 'pCwsQI4m45A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4755, '2019-04-13 00:38:33.86708+00', '2019-04-13 00:40:56.285133+00', 18851, 1, 106, '', 'D', 'Video made at the Johnsonville SCD Club''s first Tartan Night for 2019.  Live music was provided by Lynne Scott, Mary McDonald and Heather Elder. The MC was club tutor Rod Downey.  The beginning of the dance is missing.', 1, 1, 'Y', 'h3fhbjPrs7Q', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4415, '2019-04-07 19:15:43.446007+00', '2019-04-07 19:28:35.759658+00', 7197, 1, 1645, '', 'C', 'Twice through this very complex fugal dance. The first time round 1st couples path crossing through reels of three in bars 57-64 causes some confusion. It works better the second time.', 1, 1, 'Y', 'nw51P7Zfehc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4756, '2019-04-14 08:04:39.01323+00', '2019-04-14 22:12:01.836287+00', 19194, 1, 513, '', 'C', '', 1, 1, 'Y', 'Yha8c24BBv4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4757, '2019-04-14 08:06:37.827146+00', '2019-04-14 22:17:24.434373+00', 17229, 3, 513, '', 'C', 'Four times, once each couple.', 1, 1, 'Y', 'MAOaVCnDDOo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5324, '2019-10-31 23:46:31.424319+00', '2019-10-31 23:51:30.47269+00', 11546, 1, 106, '', 'B', 'Recorded at the Queen Mary Scottish Festival 2012', 1, 1, 'Y', 'b-7SCyWJjMQ', 60, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5326, '2019-11-01 21:34:12.527197+00', '2019-11-01 21:38:21.761506+00', 6798, 4, 1645, '', 'B', 'Twice through as the last part of a longer demo.', 1, 1, 'Y', 'JmcelyNN1yU', 1754, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5325, '2019-11-01 21:21:08.272635+00', '2019-11-01 21:38:36.678101+00', 4527, 1, 1645, '', 'A', 'Once through clip from a longer demo. Here danced in a 3 couple set with the last few bars adapted to get 1st couple to 3rd place.', 1, 1, 'Y', 'JmcelyNN1yU', 1398, 1462, NULL);
INSERT INTO 'dancevideo' VALUES (5320, '2019-10-30 22:45:07.210295+00', '2019-11-01 21:41:16.257911+00', 729, 1, 1645, '', 'A', 'Twice through as part of a longer display medley. Danced here in two 3 couple sets with 1st couple casting to 3rd place in bars 31-32 (instead of 2nd place).', 1, 1, 'Y', 'JmcelyNN1yU', 149, 278, NULL);
INSERT INTO 'dancevideo' VALUES (5315, '2019-10-30 21:12:31.789801+00', '2019-11-01 21:42:09.769322+00', 8653, 3, 1645, '', 'A', '', 1, 1, 'Y', '9hQx3gaM8yk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5317, '2019-10-30 21:41:26.85517+00', '2019-11-01 21:43:30.892064+00', 10459, 4, 1645, '', 'B', 'The video starts two or three bars into the dance. Four times through. The corners here turn right hand in the pass and turn figure whereas the instructions mention turning with both hands.', 1, 1, 'Y', 'fgShlKOvrL4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5335, '2019-11-06 00:43:59.96616+00', '2019-11-06 00:52:09.016455+00', 13544, 3, 1, '', 'C', 'Missing a couple of bars at the beginning. The music is <<ddrec:Rendezvous, The>> from <<ddp:Fiddlesticks & Ivory>>''s <<dda:Ghillies on the Golden Gate>>.', 1, 1, 'Y', '6kcXvHg-Pq8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5327, '2019-11-01 22:04:40.084404+00', '2019-11-01 22:13:42.068239+00', 9101, 1, 1645, '', 'A', 'Twice through as part of a longer demo. Danced once each couple in a 3 couple set, as if for their 2nd repeat.', 1, 1, 'Y', '2mDwELTZxf8', 36, 109, NULL);
INSERT INTO 'dancevideo' VALUES (5177, '2019-09-26 11:37:06.346988+00', '2019-11-07 12:12:43.738473+00', 14688, 4, 1645, '', 'B', 'Twice through (part of a longer demo).', 1, 1, 'Y', '0uQiDKdwJMs', 238, 308, NULL);
INSERT INTO 'dancevideo' VALUES (5176, '2019-09-26 11:31:30.174563+00', '2019-11-07 12:13:17.609836+00', 6756, 4, 1645, '', 'B', 'Twice through clip from a longer demo. The last few bars of the second repeat are adapted to lead into the next dance.', 1, 1, 'Y', '0uQiDKdwJMs', 113, 238, NULL);
INSERT INTO 'dancevideo' VALUES (5328, '2019-11-01 22:11:06.355517+00', '2019-11-02 02:15:06.497834+00', 6736, 2, 1645, '', 'A', 'Twice through as the last part of a demo. Here danced starting once from each end in a 3 couple set.', 1, 1, 'Y', '2mDwELTZxf8', 231, 322, NULL);
INSERT INTO 'dancevideo' VALUES (5330, '2019-11-02 09:09:03.446028+00', '2019-11-02 18:11:16.283357+00', 1982, 3, 1645, '', 'A', 'Twice through as part of a longer display. The end of the 2nd repeat is adapted to lead into the next dance (two sets of 6 hands round replaced by three sets of 4 hands round).', 1, 1, 'Y', 'vwQpWEmcJDs', 88, 213, NULL);
INSERT INTO 'dancevideo' VALUES (5329, '2019-11-02 09:03:15.348978+00', '2019-11-02 22:31:30.026079+00', 9767, 1, 1645, '', 'A', 'Twice through as the last part of a longer display.', 1, 1, 'Y', 'vwQpWEmcJDs', 212, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5332, '2019-11-04 00:06:54.125186+00', '2019-11-04 11:16:24.351894+00', 5637, 7, 2709, '', 'B', 'dance title on video is incorrect, should be The Robertson Rant, not Robertson''s Rant', 1, 1, 'Y', 'ovRVAjn0hfM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5334, '2019-11-06 00:41:00.828239+00', '2019-11-06 00:41:36.495369+00', 13544, 2, 1, '', 'D', 'There''s a walkthrough and recap at the beginning of the video, which the offset skips.', 1, 1, 'Y', 'TKbSsPS8jZg', 133, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5337, '2019-11-07 23:26:01.425959+00', '2019-11-08 21:46:10.069713+00', 2825, 1, 1645, '', 'B', '', 1, 1, 'Y', '6Q61tP6j6xQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5341, '2019-11-08 21:40:57.556538+00', '2019-11-08 21:46:18.281184+00', 16816, 1, 1645, '', 'C', 'Twice through.', 1, 1, 'Y', 'mqNDbZ1cRSA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5339, '2019-11-08 21:27:56.199517+00', '2019-11-08 21:46:25.197422+00', 19326, 1, 1645, '', 'D', 'This video shows a group being walked through then dancing the strathspey section, then doing the same again for the reel section. Finally from 6:30 they dance it all the way through.', 1, 1, 'Y', 'WvhYB1Fmr80', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5340, '2019-11-08 21:32:10.630236+00', '2019-11-08 21:46:33.418817+00', 19326, 2, 1645, '', 'C', 'A good performance but constant cutting between camera angles makes it a little hard to follow at times.', 1, 1, 'Y', 'ODX8PqtXl60', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5338, '2019-11-07 23:30:11.881515+00', '2019-11-08 21:47:18.752656+00', 5966, 1, 1645, '', 'B', '', 1, 1, 'Y', 'NlhmPc_8z8g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5336, '2019-11-07 23:21:47.56726+00', '2019-11-08 21:50:57.304086+00', 5976, 1, 1645, '', 'B', '', 1, 1, 'Y', 'PkCq0bf91FU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6703, '2020-01-10 01:19:28.537093+00', '2020-01-16 17:21:12.128279+00', 17121, 7, 1296, '', 'C', '', 1, 1, 'Y', 'yIFPqD_OaeA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5342, '2019-11-09 21:32:32.998802+00', '2019-11-11 22:05:22.364588+00', 89, 4, 202, '', 'B', '', 1, 1, 'Y', 'FwNdZVqIWYg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5350, '2019-11-09 21:45:22.376793+00', '2019-11-11 23:16:52.712002+00', 3129, 5, 202, '', 'B', '', 1, 1, 'Y', 'hH7nfj7opDM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5360, '2019-11-11 19:13:57.819747+00', '2019-11-11 23:52:39.985299+00', 11524, 2, 2586, '', 'A', '', 1, 1, 'Y', 'hbjxlUrnWjU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5361, '2019-11-12 11:43:27.334621+00', '2019-11-12 11:50:41.131856+00', 15237, 1, 2755, '', 'A', '', 1, 1, 'Y', '3ItHq27EqgE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5362, '2019-11-12 11:49:37.546267+00', '2019-11-12 12:19:58.549325+00', 5842, 1, 2755, '', 'A', '', 1, 1, 'Y', 'kaCmSmdFER4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5363, '2019-11-12 11:54:24.602302+00', '2019-11-12 12:18:54.699633+00', 15021, 2, 2755, '', 'A', '', 1, 1, 'Y', '_LFhKm4mCxM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5346, '2019-11-09 21:38:21.448441+00', '2019-11-13 12:53:07.382868+00', 822, 4, 202, '', 'B', 'This clip starts at the 3rd repeat to skip over one or two little problems with the reels before that.', 1, 1, 'Y', 'Au5OmwQpBMQ', 82, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5331, '2019-11-03 23:26:56.426246+00', '2019-11-13 15:31:43.668093+00', 12334, 1, 2586, '', 'A', '', 1, 1, 'Y', '8WTD9rvygEk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5348, '2019-11-09 21:42:42.46941+00', '2019-11-13 15:58:06.497407+00', 9103, 4, 202, '', 'B', '', 1, 1, 'Y', 'kUXNVYvE3RQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5357, '2019-11-09 21:59:17.278797+00', '2019-11-13 16:09:09.234464+00', 4102, 13, 202, '', 'B', '', 1, 1, 'Y', 'H87vp6P-lvc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5353, '2019-11-09 21:49:44.105528+00', '2019-11-13 17:39:33.056301+00', 16523, 4, 202, '', 'B', 'Excellent dancing in the two top sets, though neither is fully in view.', 1, 1, 'Y', '9lJPzI1IC8I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5345, '2019-11-09 21:37:28.227354+00', '2019-11-23 18:45:07.33825+00', 13588, 7, 202, '', 'B', 'From the Perth AGM. Mostly excellent dancing with a few confusions here and there.', 1, 1, 'Y', 'Dfa3l8cK2k4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5355, '2019-11-09 21:54:53.787543+00', '2019-11-17 08:18:32.672055+00', 10433, 12, 202, '', 'A', '', 1, 1, 'Y', 'C0JJvSctL1E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5358, '2019-11-09 22:01:05.160279+00', '2019-11-23 18:47:57.343466+00', 4827, 7, 202, '', 'B', '', 1, 1, 'Y', '5S4vytKXLhQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5344, '2019-11-09 21:35:24.847101+00', '2019-11-24 11:01:02.192036+00', 4484, 7, 202, '', 'B', '', 1, 1, 'Y', 'H_pGBwoN0Vo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5352, '2019-11-09 21:48:08.878357+00', '2019-11-23 18:57:55.171035+00', 9638, 8, 202, '', 'C', 'Slightly distant/angled view from the end of the hall at the Perth AGM.', 1, 1, 'Y', '_ryvYUckyn8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5343, '2019-11-09 21:33:41.970974+00', '2019-11-24 11:05:24.743843+00', 7283, 7, 202, '', 'B', '', 1, 1, 'Y', 'WjiwO63Nw1U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5359, '2019-11-09 22:04:19.614862+00', '2019-11-24 11:09:55.246633+00', 2979, 4, 202, '', 'D', '', 1, 1, 'Y', 'yh13sad1Jbw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5349, '2019-11-09 21:43:55.983998+00', '2019-11-24 11:09:24.436827+00', 3326, 8, 202, '', 'B', 'This clip starts at the 2nd repeat, skipping over some little mishaps in the 1st one.', 1, 1, 'Y', 'eORG22XOQeI', 36, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5356, '2019-11-09 21:56:49.226097+00', '2019-11-24 23:39:31.167634+00', 10787, 11, 202, '', 'B', 'The first six repeats look excellent, the last two have a few mistakes. However in all cases the corners are here dancing the final reels for 8 bars whereas they should finish in 6 bars.', 1, 1, 'Y', 'dhqDLmBng04', 0, 280, NULL);
INSERT INTO 'dancevideo' VALUES (5392, '2019-11-20 12:24:57.159411+00', '2019-11-20 23:08:42.749433+00', 4562, 2, 2824, '', 'A', 'Three times through.', 1, 1, 'Y', 'x3JiPR9Q6oE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5370, '2019-11-13 23:49:10.20572+00', '2019-11-13 23:56:08.570121+00', 9570, 1, 1645, '', 'B', 'Danced three times to non-traditional music.', 1, 1, 'Y', 'LdK62HUZJ5k', 1112, 1220, NULL);
INSERT INTO 'dancevideo' VALUES (5373, '2019-11-14 20:40:10.766885+00', '2019-11-29 22:47:12.758687+00', 3708, 1, 2219, '', 'D', '', 1, 1, 'Y', 'vNJgqzjCVhY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5367, '2019-11-13 23:21:50.97577+00', '2019-11-13 23:57:12.931524+00', 1969, 2, 1645, '', 'B', 'Adapted for a 3 couple set with 1st couple crossing the bottom in the last two bars.', 1, 1, 'Y', 'LdK62HUZJ5k', 108, 216, NULL);
INSERT INTO 'dancevideo' VALUES (5371, '2019-11-14 09:07:36.163302+00', '2019-11-14 09:07:56.206924+00', 19769, 1, 1645, '', 'B', 'Most of two repeats, starting around bar 9.', 1, 1, 'Y', 'MFlqzGrgcEQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5372, '2019-11-14 13:48:21.501428+00', '2019-11-14 15:21:03.866464+00', 19550, 2, 177, '', 'B', 'Music is http://my.strathspey.org/dd/recording/7033/.', 1, 1, 'Y', 'DBONJFJgyes', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5374, '2019-11-14 22:37:03.182883+00', '2019-11-14 22:37:19.452054+00', 19770, 1, 1645, '', 'A', '', 1, 1, 'Y', '6BsxpCTFsak', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5375, '2019-11-15 12:10:28.063456+00', '2019-11-15 22:04:24.353879+00', 9000, 2, 177, '', 'C', 'The video starts around bar 9.', 1, 1, 'Y', 'l_VICgIyci4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5376, '2019-11-15 12:18:53.08564+00', '2019-11-15 22:11:18.19158+00', 13299, 3, 177, '', 'B', '', 1, 1, 'Y', 'F0Wy9UQsuxc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5377, '2019-11-15 23:29:20.206353+00', '2019-11-15 23:29:59.991413+00', 19771, 1, 1645, '', 'B', 'The dedicatee, Maureen Robson, is dancing as 1st woman.', 1, 1, 'Y', 'hodeZQ9-xoY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5378, '2019-11-16 09:18:45.296561+00', '2019-11-16 09:19:05.409537+00', 19772, 1, 1645, '', 'B', '', 1, 1, 'Y', '3Kw7IaXNJuE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5379, '2019-11-16 18:16:14.567112+00', '2019-11-16 18:16:28.21003+00', 19773, 1, 1645, '', 'B', '', 1, 1, 'Y', 'jQeEeUSQHUs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5380, '2019-11-17 17:32:27.702637+00', '2019-11-17 17:32:51.102105+00', 5529, 12, 202, '', 'D', '', 1, 1, 'Y', 'X1rtiiCVAzs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5381, '2019-11-17 17:36:45.55193+00', '2019-11-17 17:37:10.262002+00', 18408, 4, 202, '', 'D', '', 1, 1, 'Y', 'gYWwEI717hw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5382, '2019-11-17 17:39:38.28512+00', '2019-11-17 17:40:09.968014+00', 11189, 12, 202, '', 'D', '', 1, 1, 'Y', 'BmynSJCk2TA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5383, '2019-11-17 17:44:03.071777+00', '2019-11-17 17:44:26.065376+00', 5755, 4, 202, '', 'A', '', 1, 1, 'Y', 'zFPaYDdj0-Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5384, '2019-11-17 19:13:07.57285+00', '2019-11-17 22:30:15.348503+00', 454, 2, 274, '', 'X', '', 1, 1, 'Y', 'qzGgK-p5Y8g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5385, '2019-11-17 19:52:57.284891+00', '2019-11-17 22:31:20.707051+00', 7350, 1, 5297, '', 'B', 'Once through from 2nd place, missing the last two bars', 1, 1, 'Y', 'MhZu8iBsjUg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5390, '2019-11-18 10:49:30.477252+00', '2019-11-18 10:58:44.507596+00', 183, 4, 2586, '', 'A', '', 1, 1, 'Y', '4vchnQp3CrI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5386, '2019-11-17 22:37:12.343697+00', '2019-11-18 12:14:44.167672+00', 15661, 1, 513, '', 'C', '', 1, 1, 'Y', 'GpD7g-3A_QE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5393, '2019-11-20 23:34:50.946462+00', '2019-11-21 11:57:19.573719+00', 13085, 1, 5297, '', 'A', 'Twice through with a new top couple each time (once and to the bottom).', 1, 1, 'Y', 'uoG5EooYE4A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5387, '2019-11-17 22:38:07.289391+00', '2019-11-18 12:19:18.929068+00', 15661, 2, 513, '', 'D', 'A once each couple encore with the camera moving between sets.', 1, 1, 'Y', 'atAv68E1BgU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5394, '2019-11-20 23:45:44.620226+00', '2019-11-21 12:01:21.857232+00', 2968, 1, 5297, '', 'A', '', 1, 1, 'Y', 'PHNM3P8HVR0', 91, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5388, '2019-11-17 22:39:19.268486+00', '2019-11-18 12:22:03.088367+00', 999, 2, 513, '', 'B', 'Once through.', 1, 1, 'Y', 'WUMtUWXpRIU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5391, '2019-11-19 00:42:51.375543+00', '2019-11-19 00:46:07.644657+00', 7147, 7, 202, '', 'C', '', 1, 1, 'Y', '79Gpwb4M7PQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6746, '2020-01-10 01:19:36.675621+00', '2020-01-14 14:42:16.965523+00', 9838, 2, 1296, '', 'C', 'Once through.', 1, 1, 'Y', 'OD7Uh5whew0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6724, '2020-01-10 01:19:33.663037+00', '2020-01-16 00:10:50.350216+00', 77, 2, 1296, '', 'C', '', 1, 1, 'Y', 'fp_gHQvxeQw', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2063, '2015-04-26 22:07:04.112703+00', '2019-11-19 02:24:10.348757+00', 3541, 3, 106, '', 'B', 'On Saturday, 21st September, 2013, the Telheiras Scottish Country Dance Group performed six country dances at the "Olhar Carnide" festival in Carnide, Lisbon. Three were old dances from the 18th and 19th centuries and three were modern dances. This was the second, an old Scottish country dance called Knit the Pocky. This music is by John Renton and his SD band, available from the RSCDS (Book 11). You can see a compilation-video of all the six dances we did at http://youtu.be/Z1pz7nfWj10', 1, 1, 'Y', 'NbCdg9z1CAs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5396, '2019-11-21 21:14:32.16268+00', '2019-11-21 23:20:21.387965+00', 13465, 2, 1645, '', 'D', 'Partial view from the side.', 1, 1, 'Y', 'vBt9CU9VQ4k', 0, 157, NULL);
INSERT INTO 'dancevideo' VALUES (5399, '2019-11-21 22:11:06.538818+00', '2019-11-21 23:20:49.523604+00', 4232, 1, 1645, '', 'C', 'Twice through. The phrasing of the cast, cross, cast, cross, cast, cross of the first 8 bars is clearly a bit of a challenge.', 1, 1, 'V', '165652049', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5401, '2019-11-21 22:51:12.247778+00', '2019-11-21 23:21:33.316348+00', 9161, 2, 1645, '', 'C', 'Some dancers are walking but the choreography is clear. Four times through in a 3 couple set.', 1, 1, 'V', '124376720', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5402, '2019-11-21 23:08:24.726081+00', '2019-11-21 23:19:33.519846+00', 867, 1, 1645, '', 'C', 'Last two complete repeats (starting at offset 0:56). The video starts about 8 bars into the previous repeat.



In bars 5-6 the instructions suggest 1st man & 2nd woman should retain hands and half turn before casting but here they just pass right shoulder.', 1, 1, 'V', '124148495', 56, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5397, '2019-11-21 21:54:29.650869+00', '2019-11-21 23:19:43.291405+00', 1382, 1, 1645, '', 'D', 'Once through (cut off 4 bars before the end) of a set being taught the dance with some walking and voiceover.', 1, 1, 'V', '175321509', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5398, '2019-11-21 21:59:05.748175+00', '2019-11-21 23:20:03.342656+00', 10016, 1, 1645, '', 'C', 'Twice through.', 1, 1, 'V', '171348619', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5400, '2019-11-21 22:44:08.078045+00', '2019-11-21 23:22:08.445884+00', 9897, 1, 1645, '', 'C', '', 1, 1, 'V', '124376805', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5395, '2019-11-21 21:10:56.089754+00', '2019-11-21 23:22:48.303756+00', 14118, 1, 1645, '', 'C', 'This clip shows the last three repeats. The camera is moving around a bit and the first few repeats of the whole video are not so clear.', 1, 1, 'Y', 'trZCXiW7hbU', 172, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5409, '2019-11-22 23:22:37.696927+00', '2019-11-23 10:48:13.483605+00', 250, 2, 2586, '', 'A', '', 1, 1, 'Y', 'nrfG9GeV46U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5405, '2019-11-21 23:52:42.877408+00', '2019-11-23 10:48:29.007124+00', 18785, 1, 1645, '', 'D', 'A little hard to follow with quite a lot of mistakes and omissions.', 1, 1, 'V', '108851210', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5404, '2019-11-21 23:39:43.705697+00', '2019-11-23 10:49:10.168125+00', 9090, 1, 1645, '', 'C', 'Twice through.', 1, 1, 'V', '110966079', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5403, '2019-11-21 23:32:03.485882+00', '2019-11-23 10:51:03.60787+00', 4073, 1, 1645, '', 'C', 'Class being coached through the dance. Twice through, the 2nd repeat (from 1:08) being better. The Rondel in the 1st repeat is rather rushed.', 1, 1, 'V', '124148494', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5354, '2019-11-09 21:53:18.007333+00', '2019-11-24 11:17:03.126029+00', 1931, 10, 202, '', 'C', 'This video just shows part of the men''s solo section with a variety of lively variations. Fabulous dancing but not good for learning the dance if you do not know it well already.', 1, 1, 'Y', 'kjiprhsTkoU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5412, '2019-11-23 18:21:12.552459+00', '2019-11-24 11:18:57.183747+00', 7105, 3, 1645, '', 'A', '', 1, 1, 'Y', '_qJ_5SYHk8g', 2, 157, NULL);
INSERT INTO 'dancevideo' VALUES (5413, '2019-11-23 18:26:31.06948+00', '2019-11-24 11:19:44.850599+00', 221, 5, 1645, '', 'A', '', 1, 1, 'Y', '_qJ_5SYHk8g', 159, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5410, '2019-11-23 17:25:25.37084+00', '2019-11-24 11:21:00.118574+00', 11187, 1, 1645, '', 'B', 'Coats Land: 8 times through (and no appearance of Lady C Bruce''s Reel despite the title credits).', 1, 1, 'Y', '2GorPWpgWw0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5411, '2019-11-23 17:46:37.630292+00', '2019-11-24 11:22:08.362272+00', 11375, 4, 1645, '', 'A', '', 1, 1, 'Y', 'b-lvZRrhxHk', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5414, '2019-11-24 11:32:21.464476+00', '2019-11-25 10:10:18.140938+00', 17704, 1, 1645, '', 'B', 'The full 8 times plus a once to the bottom encore - with a few extra twirls throughout.', 1, 1, 'Y', '9pjLfzydN_s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5368, '2019-11-13 23:32:24.403256+00', '2020-02-01 16:57:15.489402+00', 10009, 1, 1645, '', 'B', 'Slightly adapted for a 3 couple set with the former 1st couple turning down to 3rd place as a new 1st couple starts.

Also the corners here start bars 9 and 17 by casting whereas the instructions are to simply dance up/down the sides - as pointed out by the deviser in <<https://my.strathspey.org/dd/issue/1995/|issue 1995>>.', 1, 1, 'Y', 'LdK62HUZJ5k', 665, 772, NULL);
INSERT INTO 'dancevideo' VALUES (6704, '2020-01-10 01:19:28.960433+00', '2020-01-16 17:00:05.018929+00', 17135, 3, 1296, '', 'A', '', 1, 1, 'Y', 'bAEfXZhEupI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5419, '2019-11-25 07:48:16.458159+00', '2019-11-25 08:16:21.925205+00', 7494, 1, 4804, '', 'C', '', 1, 1, 'Y', 'xxwpi_eIurQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5422, '2019-11-25 09:37:15.702608+00', '2019-11-25 10:00:44.462227+00', 16682, 1, 513, '', 'B', '', 1, 1, 'Y', 'kh3fx16XDo8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5421, '2019-11-25 09:31:59.665224+00', '2019-11-25 10:02:29.533776+00', 17905, 2, 513, '', 'B', '', 1, 1, 'Y', 'UCo20b7AV_c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5417, '2019-11-24 13:02:23.601834+00', '2019-11-25 10:09:33.135359+00', 15455, 2, 1645, '', 'C', 'Full 2x32S+2x32R plus a complete encore.', 1, 1, 'Y', 'pSaDU6fLmg8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5416, '2019-11-24 12:52:51.248647+00', '2019-11-25 10:09:41.975526+00', 18211, 1, 1645, '', 'C', '', 1, 1, 'Y', '6ZypwIiywDk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5415, '2019-11-24 12:21:23.4289+00', '2019-11-25 10:10:05.31622+00', 14817, 1, 1645, '', 'C', 'Danced the full 4 times plus a complete encore including a ninth person. Some slight mishaps the first time through, then good dancing, though well decorated with extra arches and twirls.', 1, 1, 'Y', '16-yzZrZtDU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5426, '2019-11-25 12:54:43.341211+00', '2019-11-26 09:52:15.786227+00', 16680, 1, 513, '', 'C', '', 1, 1, 'Y', 'tXxLRY6HS64', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5428, '2019-11-25 16:25:04.238184+00', '2019-11-26 09:53:43.294606+00', 1743, 2, 513, '', 'B', 'Once through.', 1, 1, 'Y', 'xWD_YSRpIg0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5427, '2019-11-25 16:05:47.097039+00', '2019-11-26 09:54:44.264365+00', 8128, 2, 513, '', 'B', '', 1, 1, 'Y', 'pH9npHZyR8U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5425, '2019-11-25 12:38:58.535703+00', '2019-11-26 09:56:14.366266+00', 18310, 2, 13151, '', 'A', 'Dancers: Angelika Schmidkonz, Viktor Lehmann, Petra Kaiser-Kutsche, Wolfgang Kutsche, Friederike Joens, Ralf Bolte. Music thanks to Stefan Schatz. Thanks to Martina Müller-Franz for recording @ Kuckucksnest Schlüchtern, 23 Nov 2019.', 1, 1, 'Y', 'Lwkt6HrBj8s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5423, '2019-11-25 12:16:08.627352+00', '2019-11-26 09:57:17.878762+00', 19727, 1, 13151, '', 'A', 'Dancers: Angelika Schmidkonz, Viktor Lehmann, Emma Orgeret, Mathias Ferber, Petra Kaiser-Kutsche, Wolfgang Kutsche, Friederike Joens, Ralf Bolte. Music thanks to Stefan Schatz. Thanks to Martina Müller-Franz for recording @ Kuckucksnest Schlüchtern, 23 Nov 2019.

', 1, 1, 'Y', '_zmefqrjxLg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5424, '2019-11-25 12:17:43.607895+00', '2019-11-26 09:58:14.35452+00', 19726, 1, 13151, '', 'A', 'Dancers: Angelika Schmidkonz, Viktor Lehmann, Friederike Joens, Ralf Bolte, Petra Kaiser-Kutsche, Wolfgang Kutsche, Emma Orgeret, Mathias Ferber. Music thanks to Stefan Schatz. Thanks to Martina Müller-Franz for recording @ Kuckucksnest Schlüchtern, 23 Nov 2019.', 1, 1, 'Y', 'WaJIhhH62wQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5431, '2019-11-26 12:27:39.405367+00', '2019-11-26 12:49:28.368575+00', 18383, 2, 24698, '', 'A', '', 1, 1, 'Y', 'AR80XM3y8Ec', 0, 106, NULL);
INSERT INTO 'dancevideo' VALUES (5369, '2019-11-13 23:37:06.118994+00', '2019-11-26 22:01:44.221789+00', 5464, 1, 1645, '', 'B', 'Twice through in two 2 couple sets.



The extra info for the <<ddd:#5464|dance>> has some detailed advice on how this dance should be performed.', 1, 1, 'Y', 'LdK62HUZJ5k', 808, 916, NULL);
INSERT INTO 'dancevideo' VALUES (5433, '2019-11-27 20:14:33.36582+00', '2019-11-27 20:16:14.274189+00', 4679, 1, 106, '', 'D', '', 1, 1, 'Y', 'LT71ApFrTiY', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5434, '2019-11-27 20:31:47.369825+00', '2019-11-27 20:32:23.829722+00', 5906, 1, 106, '', 'C', '', 1, 1, 'Y', 'kJF9BE5z9sI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5432, '2019-11-27 00:04:40.392385+00', '2019-11-27 23:07:35.13853+00', 17626, 1, 1645, '', 'B', 'Energetic performance with a well recovered mishap on the first set and link.', 1, 1, 'Y', 'dMRsI1kXDZw', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5429, '2019-11-26 10:53:19.125677+00', '2019-11-27 23:07:41.713075+00', 19777, 1, 1645, '', 'D', 'Extra twirls being added to an already twirly dance.', 1, 1, 'Y', 'KRdRTd9VmOM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5430, '2019-11-26 10:57:16.175365+00', '2019-11-27 23:07:48.534523+00', 19777, 2, 1645, '', 'B', 'Four times through.', 1, 1, 'Y', 'mSwUqFtub5w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5450, '2019-11-28 18:52:45.682936+00', '2019-11-28 23:41:22.257939+00', 19779, 1, 1645, '', 'C', 'Four times (plus a bit). In the first repeat 1st couple do not quite slot in correctly to the chase. The later repeats are better.', 1, 1, 'Y', 's_bsT8OwaSg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5438, '2019-11-28 10:23:34.145078+00', '2019-11-28 23:41:29.452108+00', 15064, 1, 1645, '', 'C', 'Some walking rather than dancing but the choreography is clear.', 1, 1, 'Y', 'EpoNihH-Xo4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5446, '2019-11-28 18:13:09.385761+00', '2019-11-28 23:41:47.901829+00', 15069, 1, 1645, '', 'C', 'The video starts at bar 5. Generally clear with one or two errors in the last 8 bars of a couple of the later repeats of the dance.', 1, 1, 'Y', 'uefvOjma2mw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5449, '2019-11-28 18:45:59.293285+00', '2019-11-28 23:41:54.05356+00', 18077, 2, 1645, '', 'B', '', 1, 1, 'Y', 'sJnRq28BP9E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5445, '2019-11-28 18:03:47.896685+00', '2019-11-28 23:41:59.376542+00', 15061, 1, 1645, '', 'C', '', 1, 1, 'Y', 'CgZae91knlY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5439, '2019-11-28 10:41:45.101082+00', '2019-11-28 23:42:04.472056+00', 15063, 1, 1645, '', 'C', 'Some walking rather than dancing but choreographically clear.', 1, 1, 'Y', '3eWVZrEAkTI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5444, '2019-11-28 17:55:57.965052+00', '2019-11-28 23:42:09.732098+00', 15065, 1, 1645, '', 'C', '', 1, 1, 'Y', '7ajYKWLp0zo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5436, '2019-11-27 23:43:11.481812+00', '2019-11-28 23:42:16.687696+00', 11287, 2, 1645, '', 'B', 'Twice through as part of a longer demo.', 1, 1, 'Y', 'gInky1nU_BY', 0, 71, NULL);
INSERT INTO 'dancevideo' VALUES (5443, '2019-11-28 17:48:59.832233+00', '2019-11-28 23:42:22.582089+00', 15073, 1, 1645, '', 'C', '', 1, 1, 'Y', 'fMVB2ETPCSs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5437, '2019-11-28 10:13:04.851342+00', '2019-11-28 23:42:28.877442+00', 15059, 1, 1645, '', 'B', '', 1, 1, 'Y', 'bF0YUqTUEDw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5442, '2019-11-28 17:39:50.757605+00', '2019-11-28 23:42:34.057467+00', 15070, 1, 1645, '', 'C', 'Twice through. More walking than dancing but still clear.', 1, 1, 'Y', 'zg9HDvR9Td8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5451, '2019-11-28 18:58:12.914106+00', '2019-11-28 23:42:40.370852+00', 19780, 1, 1645, '', 'C', '', 1, 1, 'Y', 'BXxlTcGG-oE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5448, '2019-11-28 18:41:59.344403+00', '2019-11-28 23:43:00.105979+00', 15066, 1, 1645, '', 'C', '', 1, 1, 'Y', 'LSMAKV1ms94', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5441, '2019-11-28 17:28:15.775907+00', '2019-11-28 23:43:05.412498+00', 15060, 1, 1645, '', 'C', 'The variation for a three couple set here done three times. More walking than dancing but the choreography is clear.', 1, 1, 'Y', 'BpybUQkox_o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5453, '2019-11-28 23:41:06.002501+00', '2019-11-28 23:43:12.850129+00', 19781, 1, 1645, '', 'A', 'Twice through demonstration in two different orientations.', 1, 1, 'Y', 'gZhszMden04', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5455, '2019-11-29 19:03:31.505984+00', '2019-11-29 19:35:32.241332+00', 10856, 1, 1645, '', 'A', 'Once through as part of a longer demonstration. The whole video starts with a clock-like sequence to bring dancers into starting places. This clip starts with the dance itself. The last four bars (all turn 1 1/2) is here modified to lead into the next dance.', 1, 1, 'Y', 'WLQyIxd3w34', 20, 57, NULL);
INSERT INTO 'dancevideo' VALUES (5452, '2019-11-28 22:25:46.659712+00', '2019-11-29 20:55:35.514575+00', 17704, 2, 1645, '', 'B', 'Four times through (twice each for the first two couples). Good dancing, but the dancers here are adding a few extra twirls to the corners pass and turn and anticipating a little at bar 4.', 1, 1, 'Y', '2sqdIvkb8gM', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5456, '2019-11-29 21:03:10.452577+00', '2019-11-29 21:03:24.358832+00', 17704, 3, 1645, '', 'B', 'Twice through (without the extra twirls seen in other videos of the dance).', 1, 1, 'Y', 'sIYKZI53kNg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5457, '2019-12-02 23:58:22.175532+00', '2019-12-02 23:59:48.159032+00', 19788, 1, 1645, '', 'B', '', 1, 1, 'Y', 'dwdDCa73ook', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5458, '2019-12-02 23:59:33.04997+00', '2019-12-02 23:59:52.816346+00', 19787, 1, 1645, '', 'B', '', 1, 1, 'Y', 'eI66JHoZgwM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5459, '2019-12-05 16:38:54.647354+00', '2019-12-05 17:46:41.884297+00', 14313, 1, 2824, '', 'B', '', 1, 1, 'Y', 'X6g7o1IkBeE', 63, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5460, '2019-12-07 12:38:53.542789+00', '2019-12-07 13:14:00.364004+00', 4227, 2, 2900, '', 'B', '"The Mason''s Apron," danced at Northern Virginia''s Argyle Weekend 2016.', 1, 1, 'Y', 'Yq_kvkHc9y4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5555, '2020-01-06 11:54:09.505359+00', '2020-01-06 11:55:41.945973+00', 19813, 1, 1645, '', 'C', 'Once through as part of a longer demonstration.', 1, 1, 'Y', 'GCIDX_yOYUI', 160, 220, NULL);
INSERT INTO 'dancevideo' VALUES (5566, '2020-01-06 23:59:08.664824+00', '2020-01-07 21:23:47.478005+00', 5366, 1, 1645, '', 'C', 'Twice through.', 1, 1, 'Y', 'CBTU49PZpN0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6710, '2020-01-10 01:19:30.338666+00', '2020-01-17 22:19:27.775263+00', 9509, 1, 1296, '', '?', '', 1, 1, 'Y', 'F8OORiTtq0o', 3803, 3908, NULL);
INSERT INTO 'dancevideo' VALUES (6709, '2020-01-10 01:19:30.254321+00', '2020-01-17 16:58:32.693224+00', 1931, 11, 1296, '', 'Z', '', 1, 1, 'Y', 'N5fjhkt_Mb0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5462, '2019-12-08 05:16:02.257337+00', '2019-12-08 05:16:28.393598+00', 4174, 1, 106, '', 'C', 'Marie''s Jig was on the programme for a dance on December 7, 2019 in the Ngaio town hall, Wellington, New Zealand. The dance was in honour of the Tawa SCD Club tutor, Maureen Robson, who is retiring as club tutor after 38 years. The late Marie Malcolm tutored the Ngaio SCD Club in Wellington.', 1, 1, 'Y', '3kR15qA1-OM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5476, '2019-12-14 14:00:14.020605+00', '2019-12-14 14:05:36.693913+00', 19796, 1, 1645, '', 'B', 'Shows a demo of the "2 couple rigg" formation in strathspey time, then one set doing the dance twice through, then two sets doing the full 6x32.



There is also a video showing a quick time version of the dance.

', 1, 1, 'Y', 'XqNxFgAzfL0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5463, '2019-12-08 21:33:24.484318+00', '2019-12-08 21:39:30.460919+00', 19789, 1, 106, '', 'D', 'Salute to Mrs Mac featured on the programme of dance held on December 7, 2019 as a tribute to Maureen Robson, who is taking semi-retirement after 38 years tutoring the Tawa SCD Club in Wellington, New Zealand.', 1, 1, 'Y', 'lwqKxjJ2WEg', 68, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1836, '2014-09-08 09:46:49.661052+00', '2019-12-09 01:55:47.806401+00', 2924, 4, 274, '', 'B', 'Six times, music: Red House', 1, 1, 'Y', 'k1E7QSmCxHQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5464, '2019-12-09 15:13:11.673753+00', '2019-12-09 15:13:29.440679+00', 19576, 1, 106, '', 'D', 'Dancing the Four Hand Star during the Leonard Brown Dance Weekend March 2019 in the Park Hotel Tynemouth. The Neil Hardie Scottish Dance Band in full swing.', 1, 1, 'Y', 'WZOi8wmlHZk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5465, '2019-12-09 15:17:09.243674+00', '2019-12-09 15:17:37.362157+00', 19576, 2, 106, '', 'D', 'Dancing in St Boswell''s public hall 19th Jan 2018 to the Neil Hardie Scottish Dance Band. 



Young and Old going great guns a superb night with Nancy Whitely calling the dances with her lovely smile.', 1, 1, 'Y', 'tQK0IaHCfto', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5467, '2019-12-10 23:10:45.092854+00', '2019-12-10 23:10:59.315252+00', 2357, 1, 1645, '', 'B', 'Twice through in a 2 couple set.', 1, 1, 'Y', '2abeP8Lk0Xo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5466, '2019-12-10 23:02:22.245834+00', '2019-12-10 23:11:07.080385+00', 2556, 1, 1645, '', 'C', '', 1, 1, 'Y', 'TD2mSpaM9LI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5469, '2019-12-12 21:45:45.396336+00', '2019-12-12 21:50:39.174814+00', 10578, 1, 1645, '', 'A', 'Twice through (once from each end) as part of a longer demonstration.', 1, 1, 'Y', 'QPDl2U-6idc', 47, 169, NULL);
INSERT INTO 'dancevideo' VALUES (5470, '2019-12-12 21:47:25.365183+00', '2019-12-12 21:53:07.815317+00', 7139, 3, 1645, '', 'A', 'Once through as part of a longer demonstration.', 1, 1, 'Y', 'QPDl2U-6idc', 9, 48, NULL);
INSERT INTO 'dancevideo' VALUES (5468, '2019-12-12 21:35:36.429432+00', '2019-12-12 21:53:20.412943+00', 6833, 1, 1645, '', 'B', 'One or two minor slips from the 5th repeat on but the first 4 repeats look good.', 1, 1, 'Y', 'HdXuzpCKEsM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5471, '2019-12-12 22:04:11.692958+00', '2019-12-12 22:49:40.551312+00', 8872, 1, 1645, '', 'C', 'A good once through demo followed by 3 times in several sets with a few little glitches. ', 1, 1, 'Y', 'CB2YWlGkZhU', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5473, '2019-12-12 22:49:14.233198+00', '2019-12-12 22:50:41.123273+00', 19601, 2, 1645, '', 'B', 'Here done as a strathspey, first with a demo of a progressive all round poussette, then danced three times in one set, then another three times in two sets.', 1, 1, 'Y', 'qMckhZ3VwL8', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5472, '2019-12-12 22:41:39.845105+00', '2019-12-12 22:50:47.188983+00', 19601, 1, 1645, '', 'B', 'Here done as a reel, first with a demo of the "ancient" quicktime all round poussette, then danced once in one set, then three times in two sets.', 1, 1, 'Y', 'SvpzyMctbAs', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5474, '2019-12-13 13:51:02.075009+00', '2019-12-13 16:00:38.402601+00', 14311, 1, 2824, '', 'A', '', 1, 1, 'Y', 'UBr_sl130Eg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5491, '2019-12-17 10:22:45.604821+00', '2019-12-17 11:05:43.693671+00', 6689, 1, 1645, '', 'B', '', 1, 1, 'Y', 'zX-TQ6elew8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5475, '2019-12-13 16:03:08.527513+00', '2019-12-14 14:04:51.451618+00', 4827, 8, 1645, '', 'A', 'Once through.', 1, 1, 'Y', 'wBZQR359PAw', 0, 38, NULL);
INSERT INTO 'dancevideo' VALUES (5477, '2019-12-14 14:03:45.071173+00', '2019-12-14 14:05:30.38801+00', 19796, 2, 1645, '', 'B', 'Shows a demo of the "2 couple rigg" formation in quick time, then one set doing the dance twice through, then two sets doing the full 6x32.



The title credits say 6x32 Reel but it actually seems to be done using jig time music. There is also a video showing the dance as a strathspey.

', 1, 1, 'Y', 'V7AMJ8XWA2w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5480, '2019-12-14 16:24:28.818749+00', '2019-12-14 17:48:03.783686+00', 11236, 1, 1645, '', 'B', 'The video starts with a demonstration of  the "Corrie" formation in reel time, then from 0:23 the whole dance is done three times in a four couple set.', 1, 1, 'Y', 'iZIzTvY9uBI', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5479, '2019-12-14 16:17:28.853833+00', '2019-12-14 17:48:11.412137+00', 11235, 1, 1645, '', 'B', 'First shows just the "Corrie" formation, then from 0:34 the whole dance is done three times in a four couple set.', 1, 1, 'Y', '6XuqxaVGKtk', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5482, '2019-12-14 17:42:40.260018+00', '2019-12-14 17:48:17.670413+00', 15787, 1, 1645, '', 'B', 'The videos starts with a demonstration of the "3 couple rigg" formation, then from 0:21 shows the dance once through in a single set, then from 1:00 its done three time in two sets (one of them a 4 couple set with a 4th couple mixing in).', 1, 1, 'Y', 'nof3D-tZkYw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5481, '2019-12-14 17:18:57.621767+00', '2019-12-14 17:48:22.572022+00', 11659, 1, 1645, '', 'B', 'The video starts with a demonstration of the "sailors step" (old style strathspey setting step used in the first 8 bars of the dance), then from 0:20 the dance is shown once through in one set, then from 1:29 its done three times in two sets.', 1, 1, 'Y', 'Q21T-z7ic9o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5478, '2019-12-14 15:28:21.015753+00', '2019-12-14 17:48:27.307348+00', 19584, 1, 1645, '', 'B', 'First shows the Keppoch formation, then at 0:34 once through the dance in one set, then at 1:36 three times through in several sets.', 1, 1, 'Y', '06MSZQOsRMM', 9, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5486, '2019-12-17 09:50:47.265755+00', '2019-12-17 09:51:13.047338+00', 9107, 7, 202, '', 'D', '', 1, 1, 'Y', 'I1h3nwWOHxQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5483, '2019-12-15 11:29:39.368273+00', '2019-12-17 11:04:34.355901+00', 14796, 1, 1645, '', 'C', 'This clip shows once through the dance. The whole video starts 8 bars into the previous repeat.', 1, 1, 'Y', 'vxrOpNLoARI', 36, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5484, '2019-12-15 11:48:15.104224+00', '2019-12-17 11:03:47.983719+00', 1207, 3, 1645, '', 'C', 'Twice through.', 1, 1, 'Y', 'wd8JYELRos8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5489, '2019-12-17 10:11:13.116927+00', '2019-12-17 11:03:55.18668+00', 19616, 1, 1645, '', 'B', '', 1, 1, 'Y', 'nfrM7IaKvvg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5492, '2019-12-17 10:52:54.983753+00', '2019-12-17 11:04:43.234466+00', 11890, 2, 1645, '', 'B', '', 1, 1, 'Y', 'q3iyN2ciSBc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5485, '2019-12-15 12:27:42.260381+00', '2019-12-17 11:05:30.886265+00', 19187, 1, 1645, '', 'C', 'Generally good, albeit with a few hesitations, but the music track seems to get progressively out of sync with the dancing.



Devised by Anne Thorn to celebrate RSCDS Helensburgh & District''s 40th Weekend School, danced at the 41st Weekend''s Dance. Music played by Glencraig (Nicol McLaren)', 1, 1, 'Y', '2MoNEdkx_Bo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5490, '2019-12-17 10:17:17.05667+00', '2019-12-17 11:05:38.867436+00', 6627, 2, 1645, '', 'B', '', 1, 1, 'Y', 'Au5KRlPl7BA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5493, '2019-12-17 17:03:14.241754+00', '2019-12-17 17:05:24.85582+00', 19797, 2, 106, '', 'A', '', 1, 1, 'Y', 'eaTG8435MiU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5494, '2019-12-17 18:35:54.155066+00', '2019-12-17 18:36:18.129401+00', 18655, 2, 106, '', 'A', '', 1, 1, 'Y', 'Pcx91sMQmI8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5496, '2019-12-17 20:03:36.218893+00', '2019-12-17 20:03:47.965546+00', 18941, 2, 106, '', 'A', '', 1, 1, 'Y', 'PxuOFCf8CCg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5497, '2019-12-17 20:06:06.432175+00', '2019-12-17 20:06:19.304678+00', 19138, 1, 106, '', 'A', '', 1, 1, 'Y', 'JcPoaO981nc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5498, '2019-12-18 01:40:03.90422+00', '2019-12-18 01:40:03.90422+00', 14370, 1, 1296, '', 'X', 'CapeDisappointmentLight.mp4', 1, 1, 'Y', 'Rw8vCSgE9No', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5499, '2019-12-18 01:40:03.944953+00', '2019-12-18 01:40:03.944953+00', 1478, 5, 1296, '', 'X', 'CumberlandReel.mp4', 1, 1, 'Y', 'Bnzt7vT1-Uk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5500, '2019-12-18 01:40:03.97691+00', '2019-12-18 01:40:03.97691+00', 3722, 1, 1296, '', 'X', 'LassOLivingston.mp4', 1, 1, 'Y', '3_1ObUYLHrA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5501, '2019-12-18 01:40:04.005507+00', '2019-12-27 01:40:03.180427+00', 3854, 1, 1296, '', 'Z', 'LobsterInThePot.mp4', 1, 1, 'Y', 'DG4EpAb_0Jg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (6713, '2020-01-10 01:19:31.486374+00', '2020-01-16 17:07:17.665037+00', 19169, 2, 1296, '', 'B', 'Once through, starting about 1 bar into the dance.', 1, 1, 'Y', 'i08MZGxH5SA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5557, '2020-01-06 15:02:24.879668+00', '2020-01-07 21:20:50.687545+00', 4043, 1, 1645, '', 'B', '', 1, 1, 'Y', 'r_egNQoTCIk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5563, '2020-01-06 16:48:45.755877+00', '2020-01-07 21:23:37.432713+00', 17345, 1, 1645, '', 'B', 'Fine, but with one missed setting step at the start of the first repeat.', 1, 1, 'Y', 'vg7_REcD9pQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6712, '2020-01-10 01:19:30.995661+00', '2020-01-16 17:10:16.305633+00', 9, 1, 1296, '', 'D', 'Very dark and with the camera roving this is hard to follow.', 1, 1, 'Y', 'n4u2f1rkUhU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5495, '2019-12-17 19:18:45.337832+00', '2019-12-18 13:03:15.119003+00', 2383, 1, 1645, '', 'B', 'In bars 25-28 the original instructions say "1st woman passes 3rd man left shoulder and 2nd man and woman right shoulder. 1st man passes 2nd woman left shoulder and 3rd woman and man right shoulder". Here 1st couple pass all three corner people right shoulder. This looks quite natural but seems not to have been the deviser''s intention.', 1, 1, 'Y', '6B1_jezA2Us', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5504, '2019-12-18 14:02:13.732969+00', '2019-12-18 14:11:39.440583+00', 22, 1, 1645, '', 'B', '', 1, 1, 'Y', 'meD-uq7WJI8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5503, '2019-12-18 13:51:13.302255+00', '2019-12-18 14:11:44.392599+00', 873, 2, 1645, '', 'B', '', 1, 1, 'Y', 'EY3kF6j8asY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5502, '2019-12-18 13:45:40.364132+00', '2019-12-18 14:11:50.75066+00', 11405, 1, 1645, '', 'B', '', 1, 1, 'Y', 'rqeUVL-9ZL8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5527, '2019-12-20 11:26:09.714838+00', '2019-12-22 22:44:22.860657+00', 16525, 6, 1645, '', 'A', '', 1, 1, 'Y', 'tN1ZQHIcqb0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5507, '2019-12-18 19:07:15.69485+00', '2019-12-19 00:36:31.01356+00', 1477, 1, 1645, '', 'B', '', 1, 1, 'Y', '_RvLe8OwkcM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5506, '2019-12-18 19:03:02.249041+00', '2019-12-19 00:36:36.347149+00', 1847, 1, 1645, '', 'B', '', 1, 1, 'Y', '4Ntog_3C55U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5511, '2019-12-19 00:21:06.180092+00', '2019-12-19 00:36:42.98961+00', 19136, 2, 1645, '', 'A', '', 1, 1, 'Y', 'qlvblG6oOEA', 9, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5505, '2019-12-18 18:57:47.384869+00', '2019-12-19 00:36:49.294377+00', 4371, 1, 1645, '', 'B', '', 1, 1, 'Y', 'qe0ahYnpaOM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5508, '2019-12-18 19:23:45.943546+00', '2019-12-19 00:36:56.283411+00', 19798, 1, 1645, '', 'B', '', 1, 1, 'Y', 'AfTzYTB031g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5510, '2019-12-19 00:16:47.698155+00', '2019-12-19 00:37:05.578375+00', 18956, 2, 1645, '', 'A', '', 1, 1, 'Y', 'N_4k4yIxU4g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5512, '2019-12-19 00:26:56.870299+00', '2019-12-19 00:37:11.199589+00', 18956, 3, 1645, '', 'A', '', 1, 1, 'Y', 'QVUs0tqGLQA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5509, '2019-12-19 00:11:29.40819+00', '2019-12-19 00:37:15.828252+00', 19140, 1, 1645, '', 'A', '', 1, 1, 'Y', '9Tzg4lCQNDA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5513, '2019-12-19 00:34:58.932607+00', '2019-12-19 00:37:20.396897+00', 19135, 1, 1645, '', 'A', 'Four times through.', 1, 1, 'Y', '6BamPZX4p0M', 0, 258, NULL);
INSERT INTO 'dancevideo' VALUES (5515, '2019-12-19 14:58:36.138577+00', '2019-12-19 15:01:42.760919+00', 2063, 5, 1645, '', 'B', 'Twice through with voiceover and subtitles.', 1, 1, 'Y', 'KKjNOhYswr4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5514, '2019-12-19 11:34:18.590603+00', '2019-12-19 15:01:51.848197+00', 6252, 1, 1645, '', 'B', 'Three times (once each couple).', 1, 1, 'Y', 'x-3FVlhypGA', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5518, '2019-12-19 20:24:58.392708+00', '2019-12-20 11:19:14.698099+00', 464, 1, 1645, '', 'D', '', 1, 1, 'Y', 'AhXwwqv9wB0', 34, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5519, '2019-12-19 20:30:14.367812+00', '2019-12-20 11:19:22.024112+00', 497, 1, 1645, '', 'C', '', 1, 1, 'Y', 'fS0pjPXSA9k', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5520, '2019-12-19 20:42:42.490219+00', '2019-12-20 11:19:28.58561+00', 1020, 1, 1645, '', 'C', 'Once through (1st couple starting from 2nd place just into the 1st bar).', 1, 1, 'Y', 'sAIyCOceIuM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5521, '2019-12-19 20:52:51.181511+00', '2019-12-20 11:19:35.118502+00', 8250, 1, 1645, '', 'C', '', 1, 1, 'Y', 'XEnfKU1oEm4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5522, '2019-12-19 21:31:55.035133+00', '2019-12-20 11:19:42.131836+00', 19799, 1, 1645, '', 'C', '', 1, 1, 'Y', 'xinlsBaz5mc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5524, '2019-12-19 22:21:47.70526+00', '2019-12-20 11:19:47.156483+00', 19800, 1, 1645, '', 'B', '', 1, 1, 'Y', 'YBcyeOSCbS0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5523, '2019-12-19 21:50:19.154433+00', '2019-12-20 11:19:56.313259+00', 12122, 1, 1645, '', 'B', 'Outdoor demo starting at about bar 3. There is a quickly recovered anticipation of the schiehallion in the 3rd repeat.', 1, 1, 'Y', 'oDBChM3NsBg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5517, '2019-12-19 19:51:18.711928+00', '2019-12-20 11:20:08.120677+00', 6334, 1, 1645, '', 'D', 'Four times through. The video clip starts during the first bar.', 1, 1, 'Y', 'eCnguu7iWNI', 5, 146, NULL);
INSERT INTO 'dancevideo' VALUES (5516, '2019-12-19 19:45:23.502725+00', '2019-12-20 11:20:14.16251+00', 6771, 2, 1645, '', 'C', '', 1, 1, 'Y', 'fjSal4uK8pA', 1, 291, NULL);
INSERT INTO 'dancevideo' VALUES (5532, '2019-12-22 11:36:10.749352+00', '2019-12-22 22:33:36.148671+00', 14479, 1, 274, '', 'B', 'Budapest 19.12.2019 ; Devised by the second man', 1, 1, 'Y', 'g6k-1aG9z8c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5531, '2019-12-22 11:05:02.553234+00', '2019-12-22 22:39:48.071387+00', 19391, 1, 274, '', 'B', 'Budapest 19.12.2019 ; devised by the first man ;-)', 1, 1, 'Y', 'rGKzhN8LwDw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5529, '2019-12-21 23:45:43.934061+00', '2019-12-22 22:41:10.233627+00', 6680, 1, 1645, '', 'C', '', 1, 1, 'Y', '8F5m8HjMEVI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5526, '2019-12-20 11:25:26.341316+00', '2019-12-22 22:46:16.188043+00', 3108, 7, 1645, '', 'B', 'Here done four times (twice each by two couples). The demo ends with an additional circle.', 1, 1, 'Y', 'EHeJw9a3JwU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5528, '2019-12-20 11:28:58.300066+00', '2019-12-22 22:47:19.101112+00', 6712, 12, 1645, '', 'A', '', 1, 1, 'Y', 'N8vh1jptm1k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5525, '2019-12-20 11:21:24.940404+00', '2019-12-22 22:47:57.974921+00', 19801, 1, 1645, '', 'A', 'Here done as 32J+32S+32R instead of the intended 32S+32R.', 1, 1, 'Y', 'cPuNzWZNwOU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5530, '2019-12-21 23:52:39.048011+00', '2019-12-22 22:48:18.244584+00', 13537, 1, 1645, '', 'B', '', 1, 1, 'Y', 'CXBhKjW7Stg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5544, '2019-12-27 01:40:03.193584+00', '2019-12-27 01:40:03.193584+00', 3854, 2, 1296, '', 'X', '''Lobster in the Pot'' is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'Rq8mk8dDVKM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5545, '2019-12-28 09:32:50.041682+00', '2019-12-28 09:33:57.121034+00', 7637, 5, 202, '', 'D', '', 1, 1, 'Y', 'CrjNBPP5bZs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6737, '2020-01-10 01:19:36.143131+00', '2020-01-16 12:59:36.462439+00', 153, 3, 1296, '', 'B', 'The last 8 bars of both repeats are different from the original instructions.', 1, 1, 'Y', 'DoKa3RX6m08', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5546, '2019-12-28 21:58:07.006979+00', '2019-12-29 00:48:06.876831+00', 9157, 6, 2220, '', 'B', 'The first half of each time through is fugal (really a canon, but everyone calls it a fugue) in which 2nd lady does exactly what her partner does, just two bars later. Patti Cobb was bandleader and arranged three tunes to be canons so the women dance to the recorder and the men dance to the fiddles.  Jim Oakden is on recorder and the fiddlers are Shira Kammen and Caroline McCaskey (the 2019 US Scottish Fiddle champion).  The jig tunes are Sailor''s Wife, A Hundred Pipers, and Lady Elizabeth Cole', 1, 1, 'Y', '7SLEaHJVh-8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5533, '2019-12-23 00:22:30.106373+00', '2020-01-01 02:51:29.334326+00', 13559, 1, 1645, '', 'B', 'Twice through. The last four bars of each repeat are adapted with 2nd & 3rd couples (at the ends) additionally casting into a chase ¼ round to change the orientation of the set (instead of just standing).', 1, 1, 'Y', '4snZzr3DWXo', 127, 255, NULL);
INSERT INTO 'dancevideo' VALUES (5548, '2020-01-03 14:48:29.569731+00', '2020-01-04 23:00:45.888948+00', 2484, 7, 274, '', 'C', 'Budapest Scottish Dance Weekend 2019', 1, 1, 'Y', 'oY8e-ePYZt4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5550, '2020-01-05 11:22:54.88693+00', '2020-01-05 11:23:07.32941+00', 19810, 1, 1645, '', 'B', '', 1, 1, 'Y', 'jW868hbaTjs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5534, '2019-12-26 10:38:01.283888+00', '2020-01-05 11:32:55.163689+00', 13079, 3, 274, '', 'C', 'It''s 3 couple set version!!

STRICTLY SCOTTISH Vancouver Demonstration Team dancing

', 1, 1, 'Y', 'oDftVCIbqqA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5537, '2019-12-26 10:45:34.687974+00', '2020-01-05 11:30:07.658008+00', 13079, 4, 274, '', 'A', 'STRICTLY SCOTTISH Vancouver Demonstration Team (twice through)', 1, 1, 'Y', 'NtwSwpTWCbc', 0, 104, NULL);
INSERT INTO 'dancevideo' VALUES (5549, '2020-01-04 22:55:33.401875+00', '2020-01-05 11:33:28.732294+00', 19061, 2, 1645, '', 'A', 'Twice through.', 1, 1, 'Y', 'kFqi7tFD0T0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5547, '2020-01-01 15:59:54.469598+00', '2020-01-05 18:30:18.580368+00', 19359, 1, 2023, '', 'B', '', 1, 1, 'Y', 'SZ2xxWT2Tdc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5551, '2020-01-05 17:58:53.207343+00', '2020-01-05 18:34:38.165612+00', 343, 1, 1645, '', 'B', '', 1, 1, 'Y', '_a4hFheiN5o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5535, '2019-12-26 10:40:53.162339+00', '2020-01-05 18:48:42.007887+00', 2722, 1, 274, '', 'A', 'STRICTLY SCOTTISH Vancouver Demonstration Team', 1, 1, 'Y', 'k1FFqZOy6Rg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5541, '2019-12-26 10:56:58.615221+00', '2020-01-05 18:40:27.548252+00', 14356, 1, 274, '', 'A', 'RSCDS Vancouver Demonstration Team (twice through)', 1, 1, 'Y', 'YLuxlftKmWI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5539, '2019-12-26 10:49:06.296163+00', '2020-01-05 18:43:56.052254+00', 9338, 1, 274, '', 'A', 'STRICTLY SCOTTISH Vancouver Demonstration Team (twice through)', 1, 1, 'Y', 'nYMzdx1Xlp0', 0, 76, NULL);
INSERT INTO 'dancevideo' VALUES (5538, '2019-12-26 10:47:35.148501+00', '2020-01-05 18:51:59.630803+00', 4888, 1, 274, '', 'A', 'STRICTLY SCOTTISH Vancouver Demonstration Team (twice through)', 1, 1, 'Y', '503fQDvKxuE', 0, 73, NULL);
INSERT INTO 'dancevideo' VALUES (5540, '2019-12-26 10:53:56.649864+00', '2020-01-05 18:55:35.26076+00', 4990, 1, 274, '', 'A', 'STRICTLY SCOTTISH Vancouver Demonstration Team (twice through)', 1, 1, 'Y', 'BGjdVKGoD3k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5542, '2019-12-26 11:00:45.129923+00', '2020-01-05 18:58:28.153998+00', 15306, 1, 274, '', 'A', 'RSCDS Vancouver Demonstration Team (twice through)', 1, 1, 'Y', 'qoxrjknbw6g', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5552, '2020-01-06 10:43:08.378194+00', '2020-01-06 10:44:04.541407+00', 19812, 1, 1645, '', 'A', 'Once through.', 1, 1, 'Y', 'eJzYldsQ-_U', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5553, '2020-01-06 10:53:11.345206+00', '2020-01-06 11:10:42.054802+00', 6309, 1, 1645, '', 'B', '', 1, 1, 'Y', 'elU2S7aUYUM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5554, '2020-01-06 11:09:10.118438+00', '2020-01-06 11:10:48.876293+00', 11170, 1, 1645, '', 'B', '', 1, 1, 'Y', '-2mhGQXHDUA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5565, '2020-01-06 23:54:34.256728+00', '2020-01-07 21:18:39.915501+00', 15676, 2, 1645, '', 'B', '', 1, 1, 'Y', 'm7xC-cJyMUk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5558, '2020-01-06 15:10:17.909686+00', '2020-01-07 21:18:48.911176+00', 16537, 5, 1645, '', 'B', 'Once each couple demonstration with the deviser starting as 1st lady.', 1, 1, 'Y', 'IAZQJxtDcIg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5569, '2020-01-07 21:01:40.913503+00', '2020-01-07 21:18:55.510124+00', 19083, 1, 1645, '', 'B', 'Three times through (almost).', 1, 1, 'Y', '16XY70w3VCA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5567, '2020-01-07 00:17:07.62387+00', '2020-01-07 21:19:05.301123+00', 14200, 1, 1645, '', 'D', 'This clip is the encore but still has many mistakes so is not that useful for learning the dance. The walk through from 2:24 to 3:40 may be more helpful.', 1, 1, 'Y', 'MhXRdVxU6q4', 532, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5572, '2020-01-07 21:15:50.764189+00', '2020-01-07 21:19:23.284261+00', 19064, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'e71CEc9Nk_g', 0, 91, NULL);
INSERT INTO 'dancevideo' VALUES (5556, '2020-01-06 14:51:56.518824+00', '2020-01-07 21:20:42.54439+00', 19604, 1, 1645, '', 'B', 'Once through.', 1, 1, 'Y', 'PKLVuoqJiQ8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5560, '2020-01-06 16:13:21.73709+00', '2020-01-07 21:20:58.601796+00', 19815, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'e3ISPXjavkc', 0, 71, NULL);
INSERT INTO 'dancevideo' VALUES (5559, '2020-01-06 16:04:29.212422+00', '2020-01-07 21:21:05.175951+00', 19814, 1, 1645, '', 'B', '', 1, 1, 'Y', 'viuecohwweA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5561, '2020-01-06 16:25:16.05215+00', '2020-01-07 21:23:14.065252+00', 14251, 1, 1645, '', 'C', '', 1, 1, 'Y', 'blqHXFZezY4', 18, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5571, '2020-01-07 21:10:52.405126+00', '2020-01-07 21:23:54.718128+00', 19059, 1, 1645, '', 'B', '', 1, 1, 'Y', 'opK_xw4-LPo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5570, '2020-01-07 21:06:25.128734+00', '2020-01-07 21:24:02.050035+00', 19060, 1, 1645, '', 'B', '', 1, 1, 'Y', 'XRaEQt5c1g8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5564, '2020-01-06 16:52:55.557208+00', '2020-01-07 21:24:08.787067+00', 14314, 1, 1645, '', 'A', '', 1, 1, 'Y', 'fe3rhlP6K_c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5574, '2020-01-07 21:40:41.92672+00', '2020-01-07 21:40:50.958889+00', 19134, 1, 1645, '', 'A', 'Four times through.', 1, 1, 'Y', 'TFLM8HLC61A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5573, '2020-01-07 21:33:31.283575+00', '2020-01-07 21:40:56.618807+00', 19080, 1, 1645, '', 'B', '', 1, 1, 'Y', 'DfkzRzEBIBs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5568, '2020-01-07 00:38:02.548319+00', '2020-01-08 11:14:19.245497+00', 14102, 1, 1645, '', 'B', 'Once each couple.', 1, 1, 'Y', 'i2aZ1eVWGLI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6755, '2020-01-10 01:19:37.646935+00', '2020-01-10 22:54:42.55333+00', 12243, 3, 1296, '', 'C', 'Rather distant view.', 1, 1, 'Y', '9IWk7gBHKqw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6728, '2020-01-10 01:19:34.550419+00', '2020-01-16 16:57:14.306758+00', 15273, 3, 1296, '', 'D', '', 1, 1, 'Y', 'IgJ1bROMDic', 29, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6762, '2020-01-10 01:19:38.222995+00', '2020-01-10 22:56:32.114816+00', 222, 2, 1296, '', 'A', '', 1, 1, 'Y', 'ZiVINVkdXSY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6757, '2020-01-10 01:19:38.005813+00', '2020-01-12 18:38:06.280772+00', 11376, 3, 1296, '', 'A', 'Part of a longer demonstration medley. The last 4 bars of the dance (circling back to place) are altered to end in a longwise set for the next dance.', 1, 1, 'Y', 'w48CR27rTUQ', 48, 156, NULL);
INSERT INTO 'dancevideo' VALUES (6760, '2020-01-10 01:19:38.118769+00', '2020-01-12 18:44:49.962977+00', 221, 7, 1296, '', 'A', 'Four times through.', 1, 1, 'Y', '2ohTmVCrAK4', 0, 267, NULL);
INSERT INTO 'dancevideo' VALUES (6756, '2020-01-10 01:19:37.990589+00', '2020-01-12 18:39:37.963909+00', 11376, 2, 1296, '', 'A', '', 1, 1, 'Y', '_DO9GVlQGqQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6761, '2020-01-10 01:19:38.130285+00', '2020-01-12 18:48:02.285751+00', 221, 8, 1296, '', 'D', '', 1, 1, 'Y', 'Ro8r93bu9Pk', 55, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6759, '2020-01-10 01:19:38.10589+00', '2020-01-12 18:49:39.953264+00', 221, 6, 1296, '', 'A', 'Four time through.', 1, 1, 'Y', 'czIZO3yq6is', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6767, '2020-01-10 01:19:38.874748+00', '2020-01-12 19:08:44.713223+00', 3791, 5, 1296, '', 'D', 'Starts around bar 9.', 1, 1, 'Y', 'ISbJWxALg0Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6766, '2020-01-10 01:19:38.606467+00', '2020-01-12 18:53:26.615179+00', 245, 3, 1296, '', 'B', '', 1, 1, 'Y', 'Es9zP17f_rM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6769, '2020-01-10 01:19:38.8997+00', '2020-01-12 19:15:05.661648+00', 3791, 7, 1296, '', 'C', '', 1, 1, 'Y', 'VS6DlTVmY6c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6734, '2020-01-10 01:19:35.42429+00', '2020-01-12 19:23:38.789952+00', 17896, 6, 1296, '', 'B', 'Twice through as the last part of a longer demo with the teams dancing off in the last 8 bars of the 2nd repeat.', 1, 1, 'Y', '4HFzWZsXkAI', 200, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6735, '2020-01-10 01:19:35.43166+00', '2020-01-12 19:18:21.574053+00', 17896, 7, 1296, '', 'D', '', 1, 1, 'Y', 'jHuJW5_DxDs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6730, '2020-01-10 01:19:34.842384+00', '2020-01-12 19:34:27.521686+00', 116, 2, 1296, '', 'A', 'Twice through (last part of a longer demo).', 1, 1, 'Y', 'k5e5hFLI9s8', 98, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6751, '2020-01-10 01:19:37.426717+00', '2020-01-13 00:18:21.080005+00', 11184, 3, 1296, '', 'C', 'Twice through (part of a longer medley in a class).', 1, 1, 'Y', 'xgluNXZsr2M', 0, 74, NULL);
INSERT INTO 'dancevideo' VALUES (6741, '2020-01-10 01:19:36.349692+00', '2020-01-12 19:53:23.331632+00', 15338, 2, 1296, '', 'B', 'With extra turns and twirls.', 1, 1, 'Y', 'JQ4GcB8CkvU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6749, '2020-01-10 01:19:37.063727+00', '2020-01-13 00:24:01.840402+00', 17429, 1, 1296, '', 'D', 'The video starts just into bar 1.', 1, 1, 'Y', '2tK55VqhAUU', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6743, '2020-01-10 01:19:36.462215+00', '2020-01-14 14:05:44.056794+00', 159, 9, 1296, '', 'A', 'Four times.', 1, 1, 'Y', 'G_xJJ0B4gqk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6736, '2020-01-10 01:19:35.879002+00', '2020-01-14 14:01:02.820334+00', 144, 3, 1296, '', 'C', '', 1, 1, 'Y', 'EYnu-kRi_s4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6742, '2020-01-10 01:19:36.453326+00', '2020-01-14 14:12:04.779856+00', 159, 8, 1296, '', 'A', 'Three times.', 1, 1, 'Y', 'U4rKc5JI7mA', 27, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5562, '2020-01-06 16:38:02.695396+00', '2022-02-16 23:55:44.906108+00', 13460, 1, 1645, '', 'Z', 'No longer available (was informal).', 1, 1, 'Y', 'QuhCoahJDcU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6726, '2020-01-10 01:19:34.440318+00', '2020-01-16 00:16:04.825599+00', 7421, 2, 1296, '', 'C', '', 1, 1, 'Y', 'JtEziGNvxsY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6718, '2020-01-10 01:19:32.123396+00', '2020-01-16 12:39:49.019399+00', 43, 2, 1296, '', 'D', '', 1, 1, 'Y', 'KyLySVdk3Zo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6748, '2020-01-10 01:19:36.87858+00', '2020-01-16 14:13:41.288767+00', 9381, 4, 1296, '', 'C', 'Good dancing but the camera is both moving and rather close so its not easy to follow the dance.', 1, 1, 'Y', 'Z26Q-rJcUjQ', 161, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6723, '2020-01-10 01:19:33.19465+00', '2020-01-16 13:59:46.811881+00', 10663, 10, 1296, '', 'C', '', 1, 1, 'Y', 'IjTY1rAMZ2c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6745, '2020-01-10 01:19:36.489304+00', '2020-01-16 14:07:31.676508+00', 159, 11, 1296, '', 'A', 'Twice through extract from a longer demonstration.', 1, 1, 'Y', 'l3_NaekV70o', 37, 165, NULL);
INSERT INTO 'dancevideo' VALUES (6764, '2020-01-10 01:19:38.326309+00', '2020-01-16 16:38:42.566459+00', 223, 4, 1296, '', 'D', '', 1, 1, 'Y', 'dCMJ6OGN3-M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6747, '2020-01-10 01:19:36.868983+00', '2020-01-16 14:16:18.952569+00', 9381, 3, 1296, '', 'D', '', 1, 1, 'Y', 'zrZXvqBuJM8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6717, '2020-01-10 01:19:32.111678+00', '2020-01-16 17:30:13.165938+00', 43, 1, 1296, '', 'Z', 'This seems to be a heavily modified version of the dance.', 1, 1, 'Y', 'FcVDEf0PWvI', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6725, '2020-01-10 01:19:34.175691+00', '2020-01-16 17:34:02.324692+00', 89, 5, 1296, '', 'C', '', 1, 1, 'Y', 'L1NRQcK5xBQ', 48, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6765, '2020-01-10 01:19:38.335484+00', '2020-01-16 23:11:44.650303+00', 223, 5, 1296, '', 'D', 'Mostly shows the lively band and not so much dancing, apart from one repeat from around 0:58.', 1, 1, 'Y', 'MY_tmRMwp8s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6729, '2020-01-10 01:19:34.745855+00', '2020-01-16 17:38:22.947425+00', 109, 7, 1296, '', 'A', '', 1, 1, 'Y', '5sHVGqyAmd4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6719, '2020-01-10 01:19:32.756107+00', '2020-01-16 23:32:59.972079+00', 55, 1, 1296, '', 'A', 'Once through as part of a longer display.', 1, 1, 'Y', 'ilBTIZAGv4o', 181, 230, NULL);
INSERT INTO 'dancevideo' VALUES (6740, '2020-01-10 01:19:36.171319+00', '2020-01-16 23:55:55.912584+00', 153, 6, 1296, '', 'A', 'Video starts around bar 17.', 1, 1, 'Y', 'IKSoLsh9SUM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6720, '2020-01-10 01:19:32.86002+00', '2020-01-17 00:13:56.934509+00', 56, 3, 1296, '', 'D', 'Five times plus encore.', 1, 1, 'Y', 'oU1ycsTh954', 143, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6753, '2020-01-10 01:19:37.455946+00', '2020-01-17 00:23:28.517109+00', 11184, 5, 1296, '', 'D', '', 1, 1, 'Y', 'AFawRZMNQVM', 124, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6750, '2020-01-10 01:19:37.160015+00', '2020-01-17 00:17:55.490744+00', 16724, 2, 1296, '', 'D', '', 1, 1, 'Y', 'GSku8qcFR_c', 116, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6732, '2020-01-10 01:19:35.323871+00', '2020-01-17 00:29:26.728997+00', 132, 4, 1296, '', 'Z', 'Obviously dem quality, but only a slightly different view of the same performance as video 3 (https://youtu.be/ijp9eUy7lQ8). So this one is blocked to avoid unnecessary duplication. It should be unblocked if video 3 is ever removed.', 1, 1, 'Y', 'uCkZCXFt1Ms', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6787, '2020-01-13 10:59:24.543181+00', '2020-01-13 11:13:26.784051+00', 7517, 2, 2219, '', 'C', 'Best to  watch the set at lower left of screen', 1, 1, 'Y', 'n38wGFAuAzE', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6685, '2020-01-10 01:19:26.324494+00', '2020-01-10 22:29:41.158379+00', 17136, 5, 1296, '', 'D', 'Last three times. One couple turns with the opposite hands (partner left, sides right) in part A.', 1, 1, 'Y', 'IOZP9hiYkFA', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6782, '2020-01-10 01:19:40.743815+00', '2020-01-11 15:03:06.109354+00', 14401, 6, 1296, '', 'C', '', 1, 1, 'Y', 'Xih7BhnI7lw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6683, '2020-01-10 01:19:26.302907+00', '2020-01-10 22:37:18.811494+00', 17136, 3, 1296, '', 'B', 'This clip shows the dance once through as part of a longer demo (the complete video alternates 192 Miles Home and La Baratte Your Way Home).', 1, 1, 'Y', 'BqrZSWzATmU', 0, 70, NULL);
INSERT INTO 'dancevideo' VALUES (5576, '2020-01-08 15:31:46.686827+00', '2020-01-10 22:38:10.194368+00', 16205, 1, 1645, '', 'C', '', 1, 1, 'Y', 'hnIWCs1TjcI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5575, '2020-01-08 15:23:25.21356+00', '2020-01-10 22:38:29.494049+00', 3611, 1, 1645, '', 'C', 'The original instructions for bars 29-32 just say "cross over" (in 4 bars) whereas the dancers here clearly enjoy their turns: they turn one and a half times in 29-32 and often turn two and half times in 5-8 and 13-16.', 1, 1, 'Y', 'HoGtW7ii-gk', 65, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1768, '2014-08-23 20:34:18.208086+00', '2020-01-13 11:14:50.624075+00', 7517, 1, 106, '', 'C', '', 1, 1, 'Y', 'mWtepYYQKTM', 36, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6691, '2020-01-10 01:19:26.950209+00', '2020-01-10 22:42:13.267719+00', 10578, 2, 1296, '', 'C', 'Here the dance is done as a medley Strathspey, Reel, Strathspey, Reel instead of the intended 4 times Strathspey.', 1, 1, 'Y', 'AYUwCYm8ea8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6698, '2020-01-10 01:19:28.137451+00', '2020-01-10 22:48:44.546552+00', 9151, 2, 1296, '', 'C', '', 1, 1, 'Y', 'eA1H6PAWLkU', 15, 290, NULL);
INSERT INTO 'dancevideo' VALUES (6771, '2020-01-10 01:19:39.017594+00', '2020-01-10 23:00:37.272711+00', 14393, 5, 1296, '', 'B', 'Once each couple in a 3 couple set.', 1, 1, 'Y', 'hoIIGwiQNGo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6778, '2020-01-10 01:19:40.351762+00', '2020-01-11 15:06:14.679188+00', 8111, 3, 1296, '', 'C', 'Once through, starting around bar 4.', 1, 1, 'Y', 'SQM9KQEYZOU', 0, 51, NULL);
INSERT INTO 'dancevideo' VALUES (6780, '2020-01-10 01:19:40.54967+00', '2020-01-10 23:06:48.75254+00', 11583, 3, 1296, '', 'C', '', 1, 1, 'Y', 'KD__LiPwuWM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6701, '2020-01-10 01:19:28.520291+00', '2020-01-10 23:09:29.009774+00', 17121, 5, 1296, '', 'B', 'Twice through.', 1, 1, 'Y', 'vmyMTA03qs4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6791, '2020-01-14 16:35:51.890289+00', '2020-01-16 14:44:48.89556+00', 12793, 7, 1645, '', 'B', 'Twice through, in two different orientations, as part of a longer display.', 1, 1, 'Y', 'uBtIJzhGtOg', 213, 290, NULL);
INSERT INTO 'dancevideo' VALUES (6777, '2020-01-10 01:19:40.338681+00', '2020-01-11 15:09:20.82491+00', 8111, 2, 1296, '', 'A', 'Twice through.', 1, 1, 'Y', 'zMG4uEg_-O4', 0, 125, NULL);
INSERT INTO 'dancevideo' VALUES (6770, '2020-01-10 01:19:39.008521+00', '2020-01-10 23:40:34.687962+00', 14393, 4, 1296, '', 'D', '', 1, 1, 'Y', 'j7AVyFvj3Lk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6784, '2020-01-10 23:55:56.035116+00', '2020-01-10 23:56:25.104958+00', 4175, 1, 1645, '', 'D', '', 1, 1, 'Y', 'VO1msUY2EJM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6783, '2020-01-10 23:50:28.36236+00', '2020-01-10 23:56:32.558178+00', 18503, 1, 1645, '', 'X', '', 1, 1, 'Y', 'tmUbMXgJ3nM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6785, '2020-01-11 00:58:14.394403+00', '2020-01-11 09:45:44.140798+00', 7555, 1, 106, '', 'B', '', 1, 1, 'Y', '_CBGzwttgac', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6772, '2020-01-10 01:19:39.349932+00', '2020-01-11 15:13:07.313043+00', 277, 1, 1296, '', 'D', 'The camera is moving around so its a bit hard to follow the dance.', 1, 1, 'Y', 'Wv2A7JBhJAA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6687, '2020-01-10 01:19:26.668069+00', '2020-01-11 14:26:57.564215+00', 9533, 2, 1296, '', 'B', 'Part of a longer demonstration medley. This extract just shows the first 24 bars of Two Furlongs. The dancers then repeat bars 1-8 (instead of doing the Rondel of bars 25-32) in order to move into the next dance.', 1, 1, 'Y', 'yj_qEeP2djI', 70, 117, NULL);
INSERT INTO 'dancevideo' VALUES (6697, '2020-01-10 01:19:28.007784+00', '2020-01-11 14:29:56.58788+00', 6535, 3, 1296, '', 'D', '', 1, 1, 'Y', '0pE1CxzZq54', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6702, '2020-01-10 01:19:28.528947+00', '2020-01-11 14:36:00.370717+00', 17121, 6, 1296, '', 'B', 'This clip shows the dance twice through. The full video begins with the class being taught the dance.', 1, 1, 'Y', 'yAYMvQY8Y28', 255, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6678, '2020-01-10 01:16:59.438508+00', '2020-01-11 14:49:41.014546+00', 7554, 6, 1296, '', 'C', 'Progressive version.', 1, 1, 'Y', 'DP_07wa2ZeU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6775, '2020-01-10 01:19:40.175228+00', '2020-01-12 18:57:56.359832+00', 314, 11, 1296, '', 'A', '', 1, 1, 'Y', 'vc7erpa9q2s', 0, 271, NULL);
INSERT INTO 'dancevideo' VALUES (6779, '2020-01-10 01:19:40.453028+00', '2020-01-11 15:02:00.268733+00', 16833, 3, 1296, '', 'B', 'This clip skips the first time through which has one or two little glitches.', 1, 1, 'Y', 'j4Ao6-J80Lc', 38, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6788, '2020-01-13 11:03:21.934311+00', '2020-01-13 11:20:07.253478+00', 845, 3, 2219, '', 'C', 'best to watch the set in lower right of screen', 1, 1, 'Y', 'OQ4PhG383uw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6776, '2020-01-10 01:19:40.183969+00', '2020-01-12 19:04:37.333256+00', 314, 12, 1296, '', 'B', 'Good dancing, but the camera moves around so its not always easy to follow.', 1, 1, 'Y', 'vhFebEJuD7U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6774, '2020-01-10 01:19:40.167309+00', '2020-01-12 19:05:02.468084+00', 314, 10, 1296, '', 'B', '', 1, 1, 'Y', 't8EnDEhifyk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6768, '2020-01-10 01:19:38.882659+00', '2020-01-12 19:13:03.427443+00', 3791, 6, 1296, '', 'C', 'Generally good dancing, but the camera is constantly moving between sets so its hard to follow the dance.', 1, 1, 'Y', 'FL-nzIySsJQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6731, '2020-01-10 01:19:35.018743+00', '2020-01-12 19:28:09.902898+00', 15341, 3, 1296, '', 'A', 'Once only (as part of a longer demonstration).', 1, 1, 'Y', 'kgqdeIP0oK8', 469, 535, NULL);
INSERT INTO 'dancevideo' VALUES (384, '2012-12-17 14:17:21.851403+00', '2020-01-12 19:40:04.982929+00', 12243, 1, 1296, '', 'B', '', 1, 1, 'Y', 'ISnJEbwuMVQ', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6754, '2020-01-10 01:19:37.636011+00', '2020-01-12 19:45:10.058604+00', 12243, 2, 1296, '', 'C', 'Part of a longer demo. In many places it differs from the instructions: bars 21-24 and 45-48 should be set and turn both hands (rather than a 4 bar turn); in bars 49-56 the dancers should loop round standing dances (rather than turn them).', 1, 1, 'Y', 'JEUM33Zbz-k', 720, 788, NULL);
INSERT INTO 'dancevideo' VALUES (6789, '2020-01-13 20:33:37.466695+00', '2020-01-13 20:33:37.466695+00', 12924, 1, 24432, 'dd/dance/video/upload/Irish_in_the_Rain_720p.mp4', 'B', '', 0, 0, 'I', '', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6786, '2020-01-13 10:51:41.432264+00', '2020-01-13 23:11:51.584784+00', 8043, 1, 2219, '', 'C', 'For [21-24] this video shows turning with both hands,  but the instructions have RIGHT hand turns', 1, 1, 'Y', 'MuC2Xnm_kA4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6686, '2020-01-10 01:19:26.48431+00', '2022-02-18 18:50:35.035792+00', 16525, 7, 1296, '', 'Z', 'Now private in youtube (was graded Good)', 1, 1, 'Y', 'Vd9TcrpKdvM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6744, '2020-01-10 01:19:36.478385+00', '2020-01-14 14:14:52.311698+00', 159, 10, 1296, '', 'B', '', 1, 1, 'Y', 'GCIDX_yOYUI', 288, 349, NULL);
INSERT INTO 'dancevideo' VALUES (6708, '2020-01-10 01:19:29.856979+00', '2020-01-15 23:41:02.983111+00', 19546, 2, 1296, '', 'B', '', 1, 1, 'Y', '2AzSh8Irn98', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6707, '2020-01-10 01:19:29.700252+00', '2020-01-15 23:52:24.469049+00', 14600, 2, 1296, '', 'B', 'Once through.', 1, 1, 'Y', 'kdNpkzdLLG4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6711, '2020-01-10 01:19:30.825096+00', '2020-01-15 23:58:52.28262+00', 9286, 5, 1296, '', 'C', '', 1, 1, 'Y', 'A2tnfX8k2MQ', 726, 862, NULL);
INSERT INTO 'dancevideo' VALUES (6715, '2020-01-10 01:19:31.836462+00', '2020-01-16 12:34:59.151738+00', 19768, 1, 1296, '', 'A', '', 1, 1, 'Y', 'q1X_P4m0A7M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6721, '2020-01-10 01:19:33.03701+00', '2020-01-16 12:50:19.836427+00', 9109, 2, 1296, '', 'B', 'Once through as part of a longer demo. Excellent dancing but the last half of the dance is heavily adapted to bring in more dancers so its not a good model to follow to learn the dance.', 1, 1, 'Y', 'ZVmx3qNLulg', 38, 77, NULL);
INSERT INTO 'dancevideo' VALUES (6738, '2020-01-10 01:19:36.15294+00', '2020-01-16 13:05:19.238399+00', 153, 4, 1296, '', 'B', 'Bars 49-52 are slightly adapted from the original, involving turning corners rather than casting around them.', 1, 1, 'Y', 'L58oEYzdvH4', 214, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6705, '2020-01-10 01:19:29.12725+00', '2020-01-16 14:28:14.175425+00', 5525, 21, 1296, '', 'A', 'Once through dancing extract. The video continues with a repeat just walking the dance.', 1, 1, 'Y', 'o2UfaYpMhao', 786, 829, NULL);
INSERT INTO 'dancevideo' VALUES (6781, '2020-01-10 01:19:40.732201+00', '2020-01-16 14:31:34.440888+00', 14401, 5, 1296, '', 'B', 'Slow motion demonstration of the dance with commentary.', 1, 1, 'Y', 'hM51UnMI09M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6773, '2020-01-10 01:19:39.746917+00', '2020-01-17 17:23:57.902849+00', 12608, 2, 1296, '', 'Z', 'Seems to be broken on youtube.', 1, 1, 'Y', '', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6714, '2020-01-10 01:19:31.746199+00', '2020-01-16 17:00:48.50935+00', 10844, 1, 1296, '', 'Z', 'This is a good demonstration but is much too heavily modified to be of any use in learning the dance as summarised in the MiniCrib.', 1, 1, 'Y', 'MWyj8lKp7k0', 42, 166, NULL);
INSERT INTO 'dancevideo' VALUES (6790, '2020-01-14 16:27:02.025888+00', '2020-01-16 17:13:14.953387+00', 13100, 1, 1645, '', 'C', 'This dance is published as a strathspey but the choreography is here done in reel time - hence is classified as "Reasonable" despite being done well by good dancers. Twice through as part of a longer display.', 1, 1, 'Y', 'uBtIJzhGtOg', 23, 92, NULL);
INSERT INTO 'dancevideo' VALUES (6680, '2020-01-10 01:16:59.582885+00', '2020-01-16 14:37:46.529136+00', 5093, 2, 1296, '', 'A', '', 1, 1, 'Y', '3Xju5rN4Jlw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6792, '2020-01-16 14:36:44.964226+00', '2020-01-16 14:43:08.072621+00', 19759, 1, 2254, '', 'C', 'The SCD Owen Sutherland’s Reel was devised in June 2019 in Owen’s memory. This demonstration in Jan 2020, is by members of the Javea SCD of which he was a member.', 1, 1, 'Y', '5xv64pv8UPU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6696, '2020-01-10 01:19:27.535818+00', '2020-01-16 14:55:20.364982+00', 6569, 1, 1296, '', 'B', 'Twice through as part of a longer demonstration medley.', 1, 1, 'Y', 'uBtIJzhGtOg', 92, 214, NULL);
INSERT INTO 'dancevideo' VALUES (6694, '2020-01-10 01:19:27.428806+00', '2020-01-16 16:10:03.956459+00', 14568, 4, 1296, '', 'B', 'Twice through as part of a longer demonstration. In the second repeat 1st couple set on bars 19-20 before dancing back up (rather than continuing to dance down).', 1, 1, 'Y', 'hf8K9l3nHYU', 333, 401, NULL);
INSERT INTO 'dancevideo' VALUES (6695, '2020-01-10 01:19:27.443131+00', '2020-01-16 16:27:47.856983+00', 14568, 5, 1296, '', 'C', 'This clips shows the last two repeats.', 1, 1, 'Y', '_IhOWdvbVvU', 24, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6675, '2020-01-10 01:16:59.234671+00', '2020-01-16 16:30:43.692971+00', 8142, 4, 1296, '', 'D', '', 1, 1, 'Y', 'mW0ZBgzljis', 95, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6763, '2020-01-10 01:19:38.313224+00', '2020-01-16 16:34:47.625625+00', 223, 3, 1296, '', 'B', '', 1, 1, 'Y', '4QHvSvo8fck', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6799, '2020-01-17 19:11:17.654813+00', '2020-01-17 22:19:21.442207+00', 2475, 1, 1645, '', 'A', 'Twice through as part of a longer demo.', 1, 1, 'Y', 'F8OORiTtq0o', 282, 372, NULL);
INSERT INTO 'dancevideo' VALUES (6804, '2020-01-17 21:45:43.311235+00', '2020-01-17 22:19:35.358093+00', 5355, 2, 1645, '', 'B', 'This video shows the original version of the 1st 4 bars.', 1, 1, 'Y', 'PZPkuSwcmkA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6727, '2020-01-10 01:19:34.528264+00', '2020-01-16 16:54:13.461906+00', 15273, 2, 1296, '', 'D', 'Last two repeats (with the optional twirls).', 1, 1, 'Y', 'm6iFG7FQvL4', 21, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6690, '2020-01-10 01:19:26.8563+00', '2020-01-16 17:24:09.558167+00', 19378, 3, 1296, '', 'Z', 'Excellent! But identical footage to video 1 (https://youtu.be/0_3-dV56y3g). So this one is blocked to avoid unnecessary duplication. If video 1 ever disappears this copy should be unblocked.', 1, 1, 'Y', 'PdNqnE0e-Bs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6758, '2020-01-10 01:19:38.017633+00', '2020-01-16 23:18:26.036046+00', 11376, 4, 1296, '', 'B', 'Dark video with unusual choice of music.', 1, 1, 'Y', 'ARjTdNyon3c', 0, 110, NULL);
INSERT INTO 'dancevideo' VALUES (6722, '2020-01-10 01:19:33.175521+00', '2020-01-16 23:21:48.017824+00', 10663, 9, 1296, '', 'Z', 'Obviously dem quality, but only a slightly different view of the same performance as video 4 (https://youtu.be/4CFsnxIExnQ). So this one is blocked to avoid unnecessary duplication. It should be unblocked if video 4 is ever removed.', 1, 1, 'Y', '9TRjwtA-AZk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6716, '2020-01-10 01:19:31.933441+00', '2020-01-16 23:28:04.874652+00', 40, 6, 1296, '', 'Z', 'Obviously dem quality, but only a slightly different view of the same performance as video 4 (https://youtu.be/SbYg977ruIU). So this one is blocked to avoid unnecessary duplication. It should be unblocked if video 4 is ever removed.', 1, 1, 'Y', '9u2iv6ON03A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6733, '2020-01-10 01:19:35.417315+00', '2020-01-17 00:00:45.366616+00', 17896, 5, 1296, '', 'Z', 'Obviously dem quality, but only a slightly different view of the same performance as video 1 (https://youtu.be/sMiCKYvfQBM). So this one is blocked to avoid unnecessary duplication. It should be unblocked if video 1 is ever removed.', 1, 1, 'Y', 'JtV7mBhAuHU', 141, 212, NULL);
INSERT INTO 'dancevideo' VALUES (6706, '2020-01-10 01:19:29.138002+00', '2020-01-17 00:26:59.197995+00', 5525, 22, 1296, '', 'Z', 'Obviously dem quality, but identical footage to video 12 (https://youtu.be/UuTMz-d99Hg). So this one is blocked to avoid unnecessary duplication. It should be unblocked if video 12 is ever removed.', 1, 1, 'Y', 'i4e7rCHyuL0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6796, '2020-01-17 10:26:38.272185+00', '2020-01-17 10:28:59.637394+00', 14325, 1, 1645, '', 'C', 'The video starts at bar 3.', 1, 1, 'Y', '_y7XU7gnge8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6794, '2020-01-17 10:10:08.77775+00', '2020-01-17 10:29:08.717196+00', 1315, 3, 1645, '', 'C', 'Once through.', 1, 1, 'Y', 'MfkcGK7CANM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6795, '2020-01-17 10:19:16.553277+00', '2020-01-17 10:29:19.90425+00', 13278, 1, 1645, '', 'C', 'Once through extract. Part of the set is out of  the narrow camera view.', 1, 1, 'Y', 'I8jI13rxTzU', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6797, '2020-01-17 15:35:34.737289+00', '2020-01-17 16:46:59.813712+00', 17983, 1, 586, '', 'D', 'This is done here as a dance for a basic class.', 1, 1, 'Y', 'OVUjQasFyTk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6752, '2020-01-10 01:19:37.442627+00', '2020-01-17 16:52:35.177873+00', 11184, 4, 1296, '', 'B', 'Twice through as part of a longer demo with the end of the 2nd repeat adapted to move into the next dance.', 1, 1, 'Y', 'RQn3CKRNRWc', 157, 225, NULL);
INSERT INTO 'dancevideo' VALUES (6688, '2020-01-10 01:19:26.752495+00', '2020-01-17 17:23:38.264326+00', 15311, 3, 1296, '', 'Z', 'Seems to be broken on youtube.', 1, 1, 'Y', '', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6801, '2020-01-17 19:45:19.777296+00', '2020-01-17 22:19:40.309159+00', 5734, 3, 1645, '', 'B', 'Three times, once each couple, in two 3 couple sets. One 2nd man omits to retire down.', 1, 1, 'Y', 'F8OORiTtq0o', 3227, 3334, NULL);
INSERT INTO 'dancevideo' VALUES (6803, '2020-01-17 21:36:50.508236+00', '2020-01-17 22:19:45.716073+00', 18597, 1, 1645, '', 'B', '', 1, 1, 'Y', 'GtnxazwkYEU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6793, '2020-01-16 16:13:47.029088+00', '2020-01-17 22:18:59.166783+00', 8524, 2, 1645, '', 'B', 'Twice through as the final part of a longer demo.', 1, 1, 'Y', 'hf8K9l3nHYU', 401, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6805, '2020-01-17 21:52:56.333958+00', '2020-01-17 22:19:07.510624+00', 14183, 1, 1645, '', 'B', '', 1, 1, 'Y', 'QA0s4UifN_8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6800, '2020-01-17 19:34:37.909371+00', '2020-01-17 22:19:13.996306+00', 2063, 6, 1645, '', 'B', 'Three times, once each couple in two 3 couple sets (as part of a longer demo). In bars 21-24 1st couple here turn left hand instead of the expected right hand.', 1, 1, 'Y', 'F8OORiTtq0o', 3006, 3108, NULL);
INSERT INTO 'dancevideo' VALUES (6798, '2020-01-17 19:03:13.356508+00', '2020-01-17 22:19:52.599183+00', 6830, 1, 1645, '', 'A', 'Once through as part of a longer demo.', 1, 1, 'Y', 'F8OORiTtq0o', 126, 161, NULL);
INSERT INTO 'dancevideo' VALUES (6802, '2020-01-17 21:04:13.305799+00', '2020-01-17 22:19:57.840464+00', 6847, 1, 1645, '', 'B', '', 1, 1, 'Y', 'JOOFb5kUMxc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6806, '2020-01-18 18:01:07.424447+00', '2020-01-18 18:28:37.788291+00', 12924, 2, 1586, '', 'A', 'Irish in the Rain - a 32 bar jig for 3 couples in a 4 couple set

Danced only once through', 1, 1, 'Y', 'sZKZ9zflQbw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6807, '2020-01-18 22:16:44.199632+00', '2020-01-18 22:34:26.487379+00', 8732, 2, 1586, '', 'A', 'Dancers from the Silver Thistle Dancers of Richmond VA

Music played live by Hanneke Cassel and Susie Petrov', 1, 1, 'Y', 'sriJ7A52le8', 32, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6808, '2020-01-18 22:37:15.269712+00', '2020-01-19 18:36:02.927125+00', 3129, 6, 1586, '', 'A', 'Danced by members of the Silver Thistle Dancers of Richmond VA

Music played live by John Turner', 1, 1, 'Y', 'c3F4LMzhG20', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6809, '2020-01-18 22:45:56.918755+00', '2020-01-19 18:38:55.03233+00', 6037, 7, 1586, '', 'A', 'Members of The Silver Thistle Dancers of Richmond VA

Music played live by John Turner', 1, 1, 'Y', 'I1T6fz0hv2k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6814, '2020-01-19 12:22:46.19186+00', '2020-01-19 18:00:54.576095+00', 708, 1, 3140, '', 'B', 'There is another copy of this same video on Youtube, with a simpler presentation.  ', 1, 1, 'Y', '2bYzSBA6HGI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6810, '2020-01-18 22:55:40.735402+00', '2020-01-19 18:47:46.902677+00', 3057, 7, 1586, '', 'B', 'Members of The Silver Thistle Dancers of Richmond VA

Music played live by John Turner



Very good, but one little confusion of shoulders in the men''s solo towards the end.', 1, 1, 'Y', 'OnGSzC1vxEA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6811, '2020-01-19 12:02:37.018675+00', '2020-01-19 18:49:53.55589+00', 570, 2, 3140, '', 'B', 'Once through.', 1, 1, 'Y', 'OOBNR2UivMk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6812, '2020-01-19 12:03:39.249813+00', '2020-01-19 18:54:50.000431+00', 4236, 2, 3140, '', 'B', '', 1, 1, 'Y', 'f80BFyttRmA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6815, '2020-01-19 21:26:30.52029+00', '2020-01-19 21:26:53.173887+00', 19592, 1, 1645, '', 'A', 'Four times through. This clip just shows the dancing but the whole video starts with a short introduction by the deviser Moira Stacey.', 1, 1, 'Y', '47p8ZXBjF20', 22, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6816, '2020-01-23 19:32:41.994109+00', '2020-01-23 19:43:03.566123+00', 19826, 1, 1645, '', 'B', '', 1, 1, 'Y', 'naQM5paw2Sc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6817, '2020-01-23 19:42:54.198403+00', '2020-01-23 19:43:09.503697+00', 12568, 1, 1645, '', 'B', 'Danced by two sets of junior dancers at the Johnsonville SCD Club''s 50th anniversary dance.', 1, 1, 'Y', 'AePvP5vTwCY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6819, '2020-01-24 10:24:47.832344+00', '2020-01-24 10:33:43.782396+00', 365, 1, 1645, '', 'B', '', 1, 1, 'Y', 'JbyLVXEKpEk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6818, '2020-01-24 10:14:20.678125+00', '2020-01-24 10:33:48.993844+00', 15613, 1, 1645, '', 'B', '', 1, 1, 'Y', 'vIhRg_0kKrw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6820, '2020-01-24 10:31:05.815457+00', '2020-01-24 10:33:55.384056+00', 11392, 1, 1645, '', 'B', 'Twice through completely, carrying on to show the transition into the start of the 3rd repeat.', 1, 1, 'Y', 'J2eabDGbR1Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6825, '2020-01-24 20:33:12.700251+00', '2020-01-24 20:47:44.049283+00', 5347, 1, 1645, '', 'D', 'Twice through with a little coaching.', 1, 1, 'Y', 'HupvHL9N71U', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6824, '2020-01-24 20:27:57.468994+00', '2020-01-24 20:47:49.938269+00', 19122, 1, 1645, '', 'C', 'Four times through, with one or two minor glitches.', 1, 1, 'Y', 'vzFaelYsKSs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6823, '2020-01-24 20:27:14.446371+00', '2020-01-24 20:48:03.872609+00', 6638, 1, 1645, '', 'D', 'Social dance with camera roving between sets.', 1, 1, 'Y', 'XJskhCjRHe0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6822, '2020-01-24 20:10:40.689574+00', '2020-01-24 20:48:12.417694+00', 8583, 1, 1645, '', 'A', 'Three times: once per couple with 1st couple turning to the foot each time.', 1, 1, 'Y', 'bqFUHEMHGdc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6827, '2020-01-27 10:33:56.768611+00', '2020-01-27 23:02:13.042911+00', 19137, 1, 274, '', 'A', 'Budapest Burns Supper 2020

', 1, 1, 'Y', '-IEQqZmkqpU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6828, '2020-01-28 19:15:03.194499+00', '2020-01-28 20:52:16.506437+00', 5465, 1, 24432, '', 'D', '', 1, 1, 'Y', 'IkICbD8de3Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6829, '2020-01-28 19:40:58.481271+00', '2020-01-28 21:11:43.40787+00', 11278, 2, 24432, '', 'D', '', 1, 1, 'Y', 'R4NLCpr6eNw', 110, 150, NULL);
INSERT INTO 'dancevideo' VALUES (6830, '2020-01-28 20:52:09.768387+00', '2020-01-28 21:13:55.385676+00', 10569, 1, 35713, '', 'C', 'Video taken at the first outing of this dance, on the occasion of Diane Lamb’s 40th birthday party - February 2000. 



', 1, 1, 'Y', 'z6bF5hT55IM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6832, '2020-02-02 10:07:58.124697+00', '2020-02-02 20:34:53.753028+00', 894, 5, 1645, '', 'B', 'The video starts around bar 4 (after initial petronella and starting to set).', 1, 1, 'Y', 'gTQ-jG4anqU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6834, '2020-02-02 20:34:20.942492+00', '2020-02-02 20:34:59.497379+00', 1838, 4, 1645, '', 'B', 'Twice through. The last few bars of the 2nd repeat are modified to end ready for the next dance in this demonstration.', 1, 1, 'Y', 'XwmIZzvF5Mk', 0, 135, NULL);
INSERT INTO 'dancevideo' VALUES (6833, '2020-02-02 20:31:48.348108+00', '2020-02-02 20:35:04.826197+00', 10772, 1, 1645, '', 'B', 'Twice through. The last few bars of the 2nd repeat are modified to end with all in one line.', 1, 1, 'Y', 'XwmIZzvF5Mk', 135, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6831, '2020-02-02 10:02:49.774438+00', '2020-02-02 20:35:09.712639+00', 9087, 4, 1645, '', 'B', 'The video starts at bar 3 (missing 2 bars of setting).', 1, 1, 'Y', 'lqaAC0cQXLg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6836, '2020-02-04 14:26:29.630095+00', '2020-02-04 18:55:35.918386+00', 5493, 2, 23285, '', 'B', '', 1, 1, 'Y', 'Mn5xoZbXVyY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6835, '2020-02-03 18:47:49.677592+00', '2020-02-04 18:55:46.621333+00', 3748, 2, 1645, '', 'A', 'Twice through teaching video.', 1, 1, 'Y', 'awwnH6JKRys', 9, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6839, '2020-02-04 14:46:15.669624+00', '2020-02-04 18:58:11.770178+00', 420, 1, 23285, '', 'B', '', 1, 1, 'Y', '18iT7xQQacw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6838, '2020-02-04 14:42:52.118857+00', '2020-02-04 18:59:44.97362+00', 11635, 1, 23285, '', 'A', '', 1, 1, 'Y', 'VVD1K2yEmqg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6837, '2020-02-04 14:30:20.053002+00', '2020-02-04 19:05:15.689881+00', 12652, 1, 23285, '', 'B', '', 1, 1, 'Y', 'YEKx2CA0mnM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6840, '2020-02-05 19:00:50.29412+00', '2020-02-05 23:57:13.967401+00', 18553, 1, 1645, '', 'B', '', 1, 1, 'Y', 'VJSB1CuGzz0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6842, '2020-02-05 23:57:03.417494+00', '2020-02-05 23:57:19.692402+00', 13584, 2, 1645, '', 'B', '', 1, 1, 'Y', 'NSi6JYSp-wk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6841, '2020-02-05 23:25:25.499847+00', '2020-02-05 23:57:24.513781+00', 10010, 1, 1645, '', 'B', '', 1, 1, 'Y', 'Ggb1OXSIkNI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6847, '2020-02-07 15:44:08.638252+00', '2020-02-08 21:55:08.529977+00', 16222, 1, 2219, '', 'B', 'Showing the fun of Scottish Country Dancing - two men are wearing ''street'' shoes - narration perhaps by the deviser John Wilkinson, dancers include Elaine Davies, Edward Davies, Stephen Webb, Liz Douglas, Andrew Kellet. Produced by STV for the Children''s Appeal 2015', 1, 1, 'Y', 'Y18GD6GqF1A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6846, '2020-02-07 13:53:33.16842+00', '2020-02-08 21:55:18.595075+00', 2430, 1, 1645, '', 'X', '', 1, 1, 'Y', 'jvyQHeSuQew', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6844, '2020-02-07 13:43:02.996734+00', '2020-02-08 21:55:25.182414+00', 19410, 1, 1645, '', 'C', 'Danced by family and friends to celebrate the dedicatee''s 85th birthday.', 1, 1, 'Y', 'AAFLhqb4IC4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6843, '2020-02-07 13:33:17.190376+00', '2020-02-08 21:55:33.063818+00', 19618, 1, 1645, '', 'B', '', 1, 1, 'Y', 'ee7DNIOQHLs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6845, '2020-02-07 13:47:56.926002+00', '2020-02-08 21:55:41.087308+00', 11516, 1, 1645, '', 'B', '', 1, 1, 'Y', 'jK87FEv_PuQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6848, '2020-02-09 00:40:00.190885+00', '2020-02-09 00:40:14.235831+00', 14974, 2, 106, '', 'D', 'Twice through, in class setting', 1, 1, 'Y', '0ji7o-9azZM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6853, '2020-02-09 18:35:38.992833+00', '2020-02-09 18:37:57.23775+00', 7173, 1, 1645, '', 'D', 'This clip starts at the 2nd repeat and shows the first 32 bars of this 48 bar dance being done reasonably successfully but then the camera moves away to sets with more problems. Not very useful for learning the dance.', 1, 1, 'Y', 'HaxG3ZjvkhI', 88, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6851, '2020-02-09 13:55:00.75949+00', '2020-02-09 18:45:03.628846+00', 3084, 1, 3129, '', 'A', '', 1, 1, 'Y', 'zAxIifTSquE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6850, '2020-02-09 09:35:32.34724+00', '2020-02-09 18:48:14.760409+00', 14977, 7, 3129, '', 'A', '', 1, 1, 'Y', 'YYQuehelRbg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6852, '2020-02-09 13:55:40.942401+00', '2020-02-09 18:51:36.035314+00', 4491, 6, 3129, '', 'A', '', 1, 1, 'Y', 'JAYjK9zQghI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6849, '2020-02-09 09:24:19.773916+00', '2020-02-09 18:57:14.898168+00', 6599, 1, 3129, '', 'A', '', 1, 1, 'Y', 'AJycvEheOYI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6854, '2020-02-10 01:40:04.257442+00', '2020-02-10 01:40:04.257442+00', 8335, 2, 1296, '', 'X', '''Kabin Fever'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'VkjNIcK_Wbs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (6855, '2020-02-10 01:40:04.288104+00', '2020-02-10 01:40:04.288104+00', 13070, 3, 1296, '', 'X', '''The Kangaroo Paw'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'HG5uywP_Cjc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (6856, '2020-02-10 01:40:04.320512+00', '2020-02-10 01:40:04.320512+00', 3398, 1, 1296, '', 'X', '''Kate and Dod'' is a 32 bar jig for 4 couples.', 1, 1, 'Y', 'a40bdryyBnk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (6857, '2020-02-10 01:40:04.354141+00', '2020-02-10 01:40:04.354141+00', 9011, 4, 1296, '', 'X', '''My Jo'' is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', '_g2PWj2H8ac', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (6858, '2020-02-10 01:40:04.387029+00', '2020-02-10 01:40:04.387029+00', 5296, 5, 1296, '', 'X', '''The Plantation Reel'' is a 32 bar reel for 5 couples.', 1, 1, 'Y', 'rPg9U3_LwHE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (6859, '2020-02-10 01:40:04.407337+00', '2020-02-10 01:40:04.407337+00', 9800, 5, 1296, '', 'X', '''The Scallywag'' is a 40 bar jig for 3 couples.', 1, 1, 'Y', '4_cbag3ewSg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3353, '2017-12-06 22:29:33.35739+00', '2020-02-11 01:47:13.968521+00', 14401, 1, 160, '', 'A', '', 1, 1, 'Y', 'pyNndWIJf9U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6869, '2020-02-11 01:50:27.115744+00', '2020-02-11 09:39:59.463034+00', 10268, 1, 160, '', 'A', '', 1, 1, 'Y', 'akQm9wz8Abg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6862, '2020-02-10 16:36:42.208851+00', '2020-02-11 09:40:10.636227+00', 652, 3, 1645, '', 'B', '', 1, 1, 'Y', '6zI95ebMFbU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6860, '2020-02-10 10:37:51.70873+00', '2020-02-11 09:40:20.846547+00', 3416, 1, 1645, '', 'D', 'The clip starts after a few repeats (once people have got the hang of it).', 1, 1, 'Y', 'u014lZK8uc8', 112, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6861, '2020-02-10 10:55:06.422931+00', '2020-02-11 09:40:49.913624+00', 19822, 1, 1645, '', 'D', 'This clip starts with the dancing. The whole video begins with a recap.', 1, 1, 'Y', 'ag3j76Id5NA', 45, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6866, '2020-02-10 21:18:58.569964+00', '2020-02-11 09:47:38.732607+00', 3932, 5, 513, '', 'A', '', 1, 1, 'Y', 'I8mw3il6jbk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6871, '2020-02-11 06:05:43.619355+00', '2020-02-11 09:51:28.81099+00', 4407, 2, 513, '', 'A', '', 1, 1, 'Y', 'wuy10kCvqh8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6864, '2020-02-10 19:32:36.886043+00', '2020-02-11 12:37:44.224469+00', 7284, 5, 513, '', 'A', '', 1, 1, 'Y', '5mMJZLN_EVI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6873, '2020-02-11 06:14:37.560677+00', '2020-02-11 12:41:10.882362+00', 17121, 8, 513, '', 'A', '', 1, 1, 'Y', 'BPbB4KGFU7g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6865, '2020-02-10 19:35:06.921532+00', '2020-02-11 12:44:04.59583+00', 9836, 6, 513, '', 'A', '', 1, 1, 'Y', 'eHzD2lKB-Dk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6874, '2020-02-11 06:18:06.26832+00', '2020-02-11 12:59:13.430898+00', 16534, 7, 513, '', 'A', '', 1, 1, 'Y', '8XyhJPJOQVc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6870, '2020-02-11 06:01:46.671427+00', '2020-02-11 14:53:31.733612+00', 14688, 6, 513, '', 'A', '', 1, 1, 'Y', 'r1yXfkFphHY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6867, '2020-02-10 21:30:36.329358+00', '2020-02-11 14:56:51.617565+00', 14688, 5, 513, '', 'A', '', 1, 1, 'Y', 'Z1tr8UH-HfU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6875, '2020-02-11 13:13:27.561382+00', '2020-02-11 18:02:44.901758+00', 9093, 2, 513, '', 'A', '', 1, 1, 'Y', 'PCvDHcfHSBU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6876, '2020-02-11 13:18:23.065832+00', '2020-02-11 18:08:10.775631+00', 6964, 7, 513, '', 'A', '', 1, 1, 'Y', 'B4ayYhWqMKE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6868, '2020-02-10 21:47:44.998677+00', '2020-02-13 19:05:06.963596+00', 16524, 8, 513, '', 'A', '', 1, 1, 'Y', 'IvJQqgY7AXg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6872, '2020-02-11 06:09:26.919884+00', '2020-02-13 21:28:09.36022+00', 6523, 3, 513, '', 'A', '', 1, 1, 'Y', 'odz4TWCqni0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6886, '2020-02-11 16:01:01.260159+00', '2020-02-11 16:04:53.621573+00', 5804, 1, 513, '', 'A', '', 1, 1, 'Y', 'uOAjMnd1BCo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6877, '2020-02-11 15:27:16.361293+00', '2020-02-11 17:06:02.997692+00', 1647, 7, 513, '', 'A', '', 1, 1, 'Y', '55ixlEz5o-k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6890, '2020-02-11 16:21:05.469832+00', '2020-02-11 17:11:32.687725+00', 4444, 3, 513, '', 'A', '', 1, 1, 'Y', 'tr4lqF7Dl7c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6889, '2020-02-11 16:18:08.734796+00', '2020-02-11 17:58:52.770617+00', 6701, 4, 513, '', 'A', '', 1, 1, 'Y', '4DrvCmONg20', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6900, '2020-02-12 09:12:44.262624+00', '2020-02-13 18:59:50.096472+00', 4155, 8, 513, '', 'A', '', 1, 1, 'Y', 'jX9vIOIjPfo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6881, '2020-02-11 15:39:51.581414+00', '2020-02-11 18:52:12.985128+00', 3623, 2, 513, '', 'A', '', 1, 1, 'Y', 'YX_ySJHS2y8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6895, '2020-02-11 22:12:54.520582+00', '2020-02-13 19:12:08.037673+00', 6349, 6, 513, '', 'A', '', 1, 1, 'Y', 'z01NcDv1xDM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6879, '2020-02-11 15:32:49.200891+00', '2020-02-11 18:57:47.483393+00', 5885, 11, 513, '', 'A', '', 1, 1, 'Y', 'GzMgBgtWyMo', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6883, '2020-02-11 15:44:46.166404+00', '2020-02-11 19:02:48.40615+00', 4404, 9, 513, '', 'A', '', 1, 1, 'Y', 'H0GByyzX0AA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6887, '2020-02-11 16:05:42.310473+00', '2020-02-11 21:14:56.296317+00', 4968, 4, 513, '', 'A', '', 1, 1, 'Y', 'ZU76TyWbE6Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6878, '2020-02-11 15:30:08.847686+00', '2020-02-11 21:20:12.01773+00', 13589, 7, 513, '', 'A', '', 1, 1, 'Y', 'dsdIS28GmFA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6891, '2020-02-11 16:24:10.522697+00', '2020-02-11 21:24:08.896332+00', 14977, 8, 513, '', 'A', '', 1, 1, 'Y', 'b3gSiHU15HY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6888, '2020-02-11 16:08:37.686726+00', '2020-02-11 21:25:26.615148+00', 1768, 1, 513, '', 'A', '', 1, 1, 'Y', 'A82JYV7IlGE', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6894, '2020-02-11 22:09:24.613735+00', '2020-02-11 22:45:57.8709+00', 76, 1, 513, '', 'A', '', 1, 1, 'Y', 'EszLcqs0mVQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6885, '2020-02-11 15:57:40.590265+00', '2020-02-12 08:05:53.684664+00', 219, 2, 513, '', 'A', '', 1, 1, 'Y', 'm02zXr4-eXk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6893, '2020-02-11 22:03:24.789103+00', '2020-02-12 08:10:40.738663+00', 10790, 4, 513, '', 'A', '', 1, 1, 'Y', 'FtuSatbn9jo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6884, '2020-02-11 15:47:51.945796+00', '2020-02-12 08:15:46.929339+00', 16566, 5, 513, '', 'A', '', 1, 1, 'Y', '3Ix6nTTBfAE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6909, '2020-02-12 09:41:21.70719+00', '2020-02-12 23:43:44.589699+00', 16566, 6, 513, '', 'A', '', 1, 1, 'Y', 'kAxrg--_CBo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6899, '2020-02-12 09:09:54.870365+00', '2020-02-12 23:48:58.778693+00', 219, 3, 513, '', 'A', '', 1, 1, 'Y', 'Xgs3dGezPyg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6896, '2020-02-12 09:00:52.243485+00', '2020-02-12 23:53:41.373672+00', 13149, 10, 513, '', 'A', '', 1, 1, 'Y', 'JCKGdM0lwFI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6905, '2020-02-12 09:29:22.800624+00', '2020-02-12 23:58:43.487794+00', 794, 8, 513, '', 'A', '', 1, 1, 'Y', 'xSp3kEq3m8o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6898, '2020-02-12 09:07:04.317685+00', '2020-02-13 11:10:10.210086+00', 16537, 6, 513, '', 'A', '', 1, 1, 'Y', 'FseAilH323E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6902, '2020-02-12 09:18:05.883678+00', '2020-02-13 19:16:01.977957+00', 5006, 4, 513, '', 'A', '', 1, 1, 'Y', '8CLQlCIZkv0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6915, '2020-02-12 11:02:33.563294+00', '2020-02-13 11:14:17.563704+00', 2153, 1, 513, '', 'A', '', 1, 1, 'Y', '1Fj4CrUydRw', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6916, '2020-02-12 11:03:41.193865+00', '2020-02-13 11:20:32.94443+00', 3934, 1, 513, '', 'A', '', 1, 1, 'Y', 'E-OQSEZfRf8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6907, '2020-02-12 09:35:55.279957+00', '2020-02-13 11:23:38.29042+00', 3973, 1, 513, '', 'A', '', 1, 1, 'Y', 'x_DSK8MUhRk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6897, '2020-02-12 09:03:54.630811+00', '2020-02-13 11:36:52.984614+00', 2158, 3, 513, '', 'A', '', 1, 1, 'Y', 'quYzF88XzW0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6911, '2020-02-12 09:46:51.053424+00', '2020-02-13 11:42:30.314908+00', 4477, 3, 513, '', 'A', '', 1, 1, 'Y', '_v3Itj9oofk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6910, '2020-02-12 09:44:25.112416+00', '2020-02-13 11:51:15.427318+00', 4563, 3, 513, '', 'A', '', 1, 1, 'Y', 'RTKBvfaIeGg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6914, '2020-02-12 09:57:05.23516+00', '2020-02-13 11:56:26.099847+00', 4720, 3, 513, '', 'A', '', 1, 1, 'Y', 'Grdaha8EOgY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6908, '2020-02-12 09:38:50.317191+00', '2020-02-13 12:02:19.244804+00', 2593, 2, 513, '', 'A', '', 1, 1, 'Y', 'jBI0EVHFrEE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6903, '2020-02-12 09:21:03.463773+00', '2020-02-13 12:16:39.017006+00', 2600, 6, 513, '', 'A', '', 1, 1, 'Y', 'Lih66s63s90', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6917, '2020-02-13 12:01:01.589316+00', '2020-02-13 18:29:18.551872+00', 4455, 1, 513, '', 'A', '', 1, 1, 'Y', 'EI70FV5V-Aw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6901, '2020-02-12 09:15:15.633147+00', '2020-02-13 18:47:52.962728+00', 3620, 1, 513, '', 'A', '', 1, 1, 'Y', '695Jw2zJzGU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6904, '2020-02-12 09:26:15.181228+00', '2020-02-13 18:53:56.012837+00', 9836, 7, 513, '', 'A', '', 1, 1, 'Y', 'IsZ3BXq7cUE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3101, '2017-06-25 02:48:35.988847+00', '2020-02-15 21:27:17.594983+00', 5136, 1, 106, '', 'C', '', 1, 1, 'Y', 'DFkkwgOmLU8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6880, '2020-02-11 15:36:11.880213+00', '2020-02-13 20:42:40.082441+00', 14688, 7, 513, '', 'A', '', 1, 1, 'Y', 'Bv4rCzvL0II', 19, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6912, '2020-02-12 09:50:00.966317+00', '2020-02-13 20:45:34.016321+00', 6701, 5, 513, '', 'A', '', 1, 1, 'Y', 'jnkkCBD9AAI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6906, '2020-02-12 09:33:10.021418+00', '2020-02-13 21:02:01.787168+00', 18410, 6, 513, '', 'A', '', 1, 1, 'Y', 'nnmKQ1DnOXY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6913, '2020-02-12 09:52:59.892641+00', '2020-02-13 21:20:27.645459+00', 13582, 4, 513, '', 'A', '', 1, 1, 'Y', 'pyt2uBpELdw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6892, '2020-02-11 16:26:27.191899+00', '2020-02-13 21:33:07.374696+00', 6599, 2, 513, '', 'A', '', 1, 1, 'Y', 'oIf6itKVLfE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6882, '2020-02-11 15:42:09.633956+00', '2020-02-13 21:41:58.868249+00', 5885, 12, 513, '', 'A', '', 1, 1, 'Y', 'BAhjJRTxLHU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6918, '2020-02-15 15:35:38.987767+00', '2020-02-15 15:57:32.089646+00', 16906, 1, 160, '', 'A', 'The music used in the video, Slopes of Hlidarendi, is suitable music. (CD - Devil''s Quandary; D B Grosjean & A Imbrie)

The name tune is *Lou Hanson''s Strathspey*, composed by Peter Macfarlane, has not been recorded. If you want the dots please contact him.', 0, 1, 'Y', 'asVw--_rJro', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6920, '2020-02-16 21:33:43.440225+00', '2020-02-16 21:36:44.591891+00', 15130, 2, 106, '', 'C', '', 1, 1, 'Y', 'JmKKK4J2gvU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6923, '2020-02-18 00:44:19.296569+00', '2020-02-18 00:45:01.647027+00', 2714, 1, 106, '', 'B', '', 1, 1, 'Y', 'RTBqBEIG0Ts', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2540, '2016-06-11 17:48:17.69698+00', '2020-02-16 21:40:53.010424+00', 16889, 1, 1645, '', 'C', 'Rehearsing for a demo. The first 24 bars of each repeat are mostly choreographically correct with a few hesitations, the last 8 bars still mostly had some problems of phrasing and precedence.



This video was taken when the dance was intended as a reel. Subsequently it has been changed to be a jig.', 1, 1, 'Y', '1-UBSFKRDzU', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6932, '2020-02-20 11:05:12.941054+00', '2020-03-19 01:06:19.925008+00', 14540, 1, 1645, '', 'C', 'From a class taught by the deviser.  All three couples should set on bars 9-10 and 13-14, but this is sometimes missed when couples are late.', 1, 1, 'Y', 'OLwblXw4dFw', 35, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6921, '2020-02-16 21:46:09.861317+00', '2020-02-16 21:49:14.279159+00', 17021, 1, 1645, '', 'B', '', 1, 1, 'Y', '6CSgLsS-Pu4', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6922, '2020-02-16 21:47:16.109209+00', '2020-02-16 21:51:10.754301+00', 16889, 2, 1645, '', 'B', 'In the last 8 bars of each turn the corners are supposed to cast away from the approaching 1st couple which does not always happen consistently. NB the dance was originally a reel but was subsequently changed to be a jig.', 1, 1, 'Y', 'OP7Akml35i0', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6924, '2020-02-18 09:07:30.827899+00', '2020-02-18 16:36:47.352999+00', 19137, 2, 274, '', 'A', 'Just the Reel part

', 1, 1, 'Y', 'cHxhT6kzbjg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6929, '2020-02-18 22:41:23.415541+00', '2020-02-18 22:42:08.088898+00', 3063, 1, 1645, '', 'C', '', 1, 1, 'Y', 'zo3m1J3bd_o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6928, '2020-02-18 22:30:26.021608+00', '2020-02-18 23:07:49.825929+00', 10793, 1, 1645, '', 'B', '', 1, 1, 'Y', 'keHiBUJxucQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6927, '2020-02-18 22:23:15.71364+00', '2020-02-19 00:54:48.168991+00', 224, 1, 1645, '', 'B', '', 1, 1, 'Y', 'OLPtraHT-fc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6925, '2020-02-18 22:13:00.275876+00', '2020-02-19 00:58:04.680848+00', 10097, 1, 1645, '', 'B', '', 1, 1, 'Y', 'Q3sdCllPmFo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6930, '2020-02-19 19:54:23.81987+00', '2020-02-19 19:55:05.032449+00', 6471, 2, 202, '', 'D', '', 1, 1, 'Y', 'WRLgd-CbN1Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6926, '2020-02-18 22:17:56.122072+00', '2020-02-20 10:19:08.332611+00', 11397, 1, 1645, '', 'B', '', 1, 1, 'Y', '-NCMrdnEYm0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6931, '2020-02-20 10:44:32.6627+00', '2020-02-20 12:39:29.542848+00', 19818, 1, 1645, '', 'X', '', 1, 1, 'Y', 'G_PER3gzcC4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6934, '2020-02-20 11:23:28.616019+00', '2020-02-20 12:39:39.549574+00', 5996, 1, 1645, '', 'C', 'Two 3 couple sets (end couples slightly out of view).', 1, 1, 'Y', 'tJ90oz6_9fs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6935, '2020-02-20 11:25:32.604207+00', '2020-02-20 12:39:49.987099+00', 5989, 1, 1645, '', 'D', '', 1, 1, 'Y', '0Kl4WRiIeK8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6936, '2020-02-20 11:43:44.533796+00', '2020-02-20 12:39:56.633175+00', 19850, 1, 1645, '', 'C', '', 1, 1, 'Y', 'PsLTA-tqAqI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7036, '2020-03-20 09:53:12.851438+00', '2020-03-20 21:13:32.2798+00', 10825, 1, 1645, '', 'A', '', 1, 1, 'Y', '5Pvf3s_kohw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7034, '2020-03-20 09:09:38.922842+00', '2020-03-20 21:13:44.732101+00', 19599, 1, 1645, '', 'B', '', 1, 1, 'Y', 'brUPh0sg7CM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7037, '2020-03-20 10:11:09.337455+00', '2020-03-20 21:14:09.616123+00', 19894, 1, 1645, '', 'B', '', 1, 1, 'Y', 'J7uZByAVI7k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7089, '2020-03-31 18:08:50.502071+00', '2020-03-31 18:09:51.490598+00', 11770, 4, 1645, '', 'A', '', 1, 1, 'Y', 'BJmZpfhSorM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6863, '2020-02-10 19:26:49.596091+00', '2020-05-05 22:35:45.392841+00', 3225, 2, 513, '', 'A', '', 1, 1, 'Y', 'iMm2wE_WIW0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7900, '2021-04-06 20:12:21.970572+00', '2021-04-06 20:41:51.64409+00', 14975, 2, 2824, '', 'B', '', 1, 1, 'Y', '1xRcQvkP6uQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6937, '2020-02-20 12:29:18.058515+00', '2020-02-20 12:40:04.218354+00', 8702, 1, 1645, '', 'B', '', 1, 1, 'Y', '40Fpsry81jA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6938, '2020-02-20 12:36:57.068954+00', '2020-02-20 12:40:10.408457+00', 16339, 2, 1645, '', 'B', '', 1, 1, 'Y', 'aLdaQm03cVY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6933, '2020-02-20 11:13:32.157173+00', '2020-02-20 16:34:49.839716+00', 8477, 1, 1645, '', 'C', 'Danced in two 3 couple sets. Some less experienced dancers are being guided.', 1, 1, 'Y', 'jJO4NcT8mcw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6956, '2020-02-24 23:07:04.931447+00', '2020-02-24 23:07:13.649484+00', 9561, 4, 1645, '', 'A', 'Once through as part of a longer demo. The last few bars are altered to link in with the next dance in the medley.', 1, 1, 'Y', 'ZVmx3qNLulg', 162, 227, NULL);
INSERT INTO 'dancevideo' VALUES (6950, '2020-02-20 19:46:26.860357+00', '2020-02-21 11:53:23.423706+00', 10011, 1, 1645, '', 'B', 'Once through clip from the final part of a longer demo. Very good - after a slightly late start to the opening half reels (and the final reel is not quite finished).', 1, 1, 'Y', 'D-S9mNPsyKE', 288, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6948, '2020-02-20 19:07:56.403346+00', '2020-02-21 11:53:42.683583+00', 755, 1, 1645, '', 'A', 'Twice through as part of a longer demo. The end of the 2nd repeat is slightly adapted to leave 3rd & 4th couples on opposite sides for the next dance in the medley.', 1, 1, 'Y', 'D-S9mNPsyKE', 128, 253, NULL);
INSERT INTO 'dancevideo' VALUES (6944, '2020-02-20 17:40:41.898656+00', '2020-02-21 11:54:12.693898+00', 4518, 1, 1645, '', 'A', '', 1, 1, 'Y', 'YWXrSyXD6UE', 204, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6945, '2020-02-20 17:57:18.071438+00', '2020-02-21 11:58:25.353641+00', 7543, 3, 1645, '', 'C', 'This clip shows the most successful repeat from a longer video.', 1, 1, 'Y', 'V6kYNPdrzPE', 68, 103, NULL);
INSERT INTO 'dancevideo' VALUES (6951, '2020-02-23 09:36:57.189899+00', '2020-02-23 09:50:34.347626+00', 16338, 1, 197, '', 'A', '', 1, 1, 'Y', '0w6WJxNgSmY', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6947, '2020-02-20 18:42:08.463942+00', '2020-02-23 09:54:11.947507+00', 11939, 1, 1645, '', 'B', '', 1, 1, 'Y', '3trss98AkJU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6942, '2020-02-20 13:51:59.92774+00', '2020-02-23 09:54:20.476198+00', 3139, 1, 1645, '', 'A', '', 1, 1, 'Y', 'wMpBUcdksnc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6939, '2020-02-20 12:52:50.595894+00', '2020-02-23 09:54:32.743728+00', 3449, 1, 1645, '', 'D', 'Starts well, but no repeat is completely successful.', 1, 1, 'Y', '-l7nadWVCyU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6940, '2020-02-20 13:36:32.543829+00', '2020-02-23 09:54:42.496331+00', 3615, 1, 1645, '', 'D', 'Dance with some beginners.', 1, 1, 'Y', '22H1HZ9dDkg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6943, '2020-02-20 17:39:51.418619+00', '2020-02-23 09:54:49.573311+00', 5982, 6, 1645, '', 'A', '', 1, 1, 'Y', 'YWXrSyXD6UE', 0, 202, NULL);
INSERT INTO 'dancevideo' VALUES (6946, '2020-02-20 18:26:34.465354+00', '2020-02-23 09:54:57.197627+00', 753, 3, 1645, '', 'B', 'Excellent performance by a young team (though not with the suggested music for the dance).', 1, 1, 'Y', 'RqOAWMIFZlg', 0, 200, NULL);
INSERT INTO 'dancevideo' VALUES (6952, '2020-02-23 16:36:25.901225+00', '2020-02-23 21:46:39.670603+00', 10832, 2, 2954, '', 'B', 'Once through the dance with 3 couples but is danced as 3 couples in 4 couple set', 1, 1, 'Y', '779jyPZ1NAE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6953, '2020-02-24 02:45:48.650813+00', '2020-02-24 09:14:29.35375+00', 10285, 1, 586, '', 'B', 'Dancers from the Delaware Valley Branch, Dave Wiesler on piano. ', 1, 1, 'Y', 'D-giYxtsKPQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6954, '2020-02-24 11:22:52.71507+00', '2020-02-24 11:23:25.971278+00', 9561, 3, 202, '', 'A', '', 1, 1, 'Y', 'SySuIVSyB2I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6955, '2020-02-24 22:44:52.314042+00', '2020-02-24 22:45:03.385348+00', 5232, 1, 1645, '', 'C', 'Generally good with a few problems in the set & cast away figure.', 1, 1, 'Y', '7q9_b1mXSWM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6963, '2020-02-26 21:52:00.593942+00', '2020-02-26 22:04:31.112624+00', 3979, 1, 1645, '', 'C', '', 1, 1, 'Y', 'pH_7n5yCR80', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6964, '2020-02-26 22:04:06.360074+00', '2020-02-26 22:04:36.503273+00', 3989, 1, 1645, '', 'C', '', 1, 1, 'Y', 'fbI8aPJqAhM', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6962, '2020-02-26 21:42:15.341865+00', '2020-02-26 22:04:42.718868+00', 4136, 1, 1645, '', 'X', '', 1, 1, 'Y', 'zOGjT4ysA0A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6965, '2020-02-26 22:15:08.204733+00', '2020-02-26 22:15:17.408717+00', 16101, 1, 1645, '', 'C', '', 1, 1, 'Y', 'knw7_cwNz9I', 9, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6966, '2020-02-27 21:42:01.078101+00', '2020-02-29 11:29:34.593163+00', 431, 1, 1645, '', 'C', '', 1, 1, 'Y', 'JCoOdDYlEXQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6970, '2020-02-28 17:24:30.806625+00', '2020-02-29 11:29:42.500107+00', 11370, 3, 1645, '', 'A', 'Last part of a longer demo.', 1, 1, 'Y', 'w48CR27rTUQ', 231, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6971, '2020-02-28 17:41:01.719848+00', '2020-02-29 11:29:52.266883+00', 5803, 1, 1645, '', 'B', 'Danced in a 5 couple set, 4th & 5th couple dancing once each (with minor glitch towards the end).', 1, 1, 'Y', 't7Ffdj72L9E', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6969, '2020-02-28 17:16:02.420016+00', '2020-02-29 11:30:03.060054+00', 11371, 1, 1645, '', 'A', 'Once through extract from a longer demo. The last 4 bars (of the final circle 8 hands round and back) are adapted to move into the next dance.', 1, 1, 'Y', 'w48CR27rTUQ', 156, 232, NULL);
INSERT INTO 'dancevideo' VALUES (6968, '2020-02-28 17:02:19.162899+00', '2020-02-29 11:30:20.793822+00', 6449, 1, 1645, '', 'C', '', 1, 1, 'Y', '3wrrB7XAuTM', 23, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6967, '2020-02-28 16:54:31.448485+00', '2020-02-29 11:30:35.36964+00', 19543, 1, 1645, '', 'B', '', 1, 1, 'Y', 'DFg0MD_03Zc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6975, '2020-03-01 17:36:13.149079+00', '2020-03-01 17:36:30.011881+00', 1616, 2, 106, '', 'D', '', 1, 1, 'Y', 'SYYYh_dz7B0', 22, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6973, '2020-02-29 11:43:22.415374+00', '2020-03-01 17:52:39.163218+00', 17679, 1, 1645, '', 'C', 'Danced by the Manchester Gay Gordons. Those wearing white bands are the ladies.', 1, 1, 'Y', 'srMRMkYHe08', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6974, '2020-02-29 16:09:08.728519+00', '2020-03-01 17:52:45.784773+00', 19856, 1, 1645, '', 'B', '', 1, 1, 'Y', 'iGsujFjSu9o', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6976, '2020-03-01 17:51:56.893784+00', '2020-03-01 17:54:56.198938+00', 8207, 1, 1645, '', 'D', 'The first couple have their hands occupied, later on the dancers take hands when expected.', 1, 1, 'Y', 'o4_T5ngzTRQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6972, '2020-02-29 11:34:20.271314+00', '2020-03-01 17:55:08.482412+00', 19254, 1, 1645, '', 'C', 'Danced by the Manchester Gay Gordons in a 3 couple set, each couple dancing as if their 2nd turn. Those wearing sashes are the ladies.', 1, 1, 'Y', '1Pr5MZ6zlEg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6977, '2020-03-01 20:10:53.693854+00', '2020-03-01 20:12:28.699255+00', 12848, 1, 160, '', 'A', '', 1, 1, 'Y', 'oMeTBkZL2Hw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6978, '2020-03-01 21:08:24.364909+00', '2020-03-01 21:11:30.978438+00', 18211, 2, 160, '', 'A', '', 1, 1, 'Y', 'y1ksZ0bXfvY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6979, '2020-03-01 21:30:28.186829+00', '2020-03-01 21:31:02.822679+00', 8068, 1, 160, '', 'A', 'Some minor editing issues - the information cards were not placed where intended but the first two rounds are clear and unimpeded.', 1, 1, 'Y', 'WORX4ml86lA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6980, '2020-03-01 23:44:57.469319+00', '2020-03-01 23:45:14.329358+00', 19597, 1, 160, '', 'A', 'a palindrome - it starts out right handed and halfway through unwinds left handed.', 1, 1, 'Y', 'rfS7wEiFRRw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6983, '2020-03-02 09:03:36.410367+00', '2020-03-02 09:04:30.57232+00', 3593, 2, 202, '', 'A', '', 1, 1, 'Y', 'tlC76Et4dE8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6984, '2020-03-02 09:08:11.074296+00', '2020-03-02 09:08:42.182619+00', 7546, 5, 202, '', 'A', '', 1, 1, 'Y', 'E7fikiE39Ws', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6961, '2020-02-25 21:18:48.087411+00', '2022-05-31 22:03:37.219595+00', 8956, 7, 1645, '', 'Z', 'Twice through extract from the end of a longer demo. The closing reel of the 2nd repeat is here replaced with a final flourish.



Was Good, now unavailable.', 1, 1, 'Y', 'hYe0lIfqp8w', 946, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6957, '2020-02-25 20:34:31.205095+00', '2022-09-05 10:58:49.173727+00', 10007, 3, 1645, '', 'Z', 'Twice through extract from a longer demo.



Was Good, now unavailable.', 1, 1, 'Y', 'hYe0lIfqp8w', 0, 71, NULL);
INSERT INTO 'dancevideo' VALUES (6982, '2020-03-02 01:16:04.640572+00', '2023-02-19 09:44:33.699848+00', 15130, 3, 160, '', 'A', 'This vimeo has no thumbnail image.



Performance by The Loch Leven Dancers.

Music by The Macadians -  Set of Jigs.', 1, 1, 'V', '394835314', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6959, '2020-02-25 21:00:13.4865+00', '2023-02-23 20:43:33.24449+00', 5843, 3, 1645, '', 'Z', 'Once through extract from a longer demo in a 3 couple set. The last few bars are adapted (2nd & 3rd couples turning) to lead into the next dance in the medley.



Was Good, now unavailable.', 1, 1, 'Y', 'hYe0lIfqp8w', 570, 624, NULL);
INSERT INTO 'dancevideo' VALUES (7026, '2020-03-17 12:24:36.875071+00', '2020-03-19 22:40:20.459243+00', 12021, 1, 1645, '', 'B', 'Last part of a demonstration medley, two mirrored (back to back) 3 couple sets.', 1, 1, 'Y', 'MKFFaBnmaeg', 169, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6985, '2020-03-02 15:59:01.628933+00', '2020-03-02 23:55:27.918781+00', 5028, 2, 1645, '', 'B', 'This clip starts with the first complete repeat (2nd turn of the 1st couple). Some hesitations restarting with a new top couple but generally good, with the camera roving between a few sets.', 1, 1, 'Y', 'tIKzUthIPp8', 41, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6986, '2020-03-04 01:40:03.826814+00', '2020-03-04 01:40:03.826814+00', 11373, 3, 1296, '', 'X', '''Bea''s Delight'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'KFAAPIy8NKA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (6987, '2020-03-04 01:40:03.851656+00', '2020-03-04 01:40:03.851656+00', 8578, 1, 1296, '', 'X', '''Tiraluin'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 't27RQzfk3lw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (6988, '2020-03-04 18:15:24.995096+00', '2020-03-04 23:16:42.623238+00', 9102, 4, 3086, '', 'A', '', 1, 1, 'Y', 'hO1bLGAVgqY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6989, '2020-03-04 18:17:33.132686+00', '2020-03-04 23:18:14.949495+00', 1562, 8, 3086, '', 'A', 'One set demonstrating, once through, what is normally a round the room dance.', 1, 1, 'Y', 'Txb520ENUvc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6993, '2020-03-05 00:19:36.265565+00', '2020-03-05 00:20:48.077163+00', 11512, 2, 1645, '', 'B', 'Once through as part of a longer demonstration.', 1, 1, 'Y', 'kj6NGBY2vWw', 171, 234, NULL);
INSERT INTO 'dancevideo' VALUES (6992, '2020-03-05 00:18:04.785041+00', '2020-03-05 00:22:09.046723+00', 13535, 1, 1645, '', 'B', 'Once through as part of a longer demonstration.', 1, 1, 'Y', 'kj6NGBY2vWw', 111, 172, NULL);
INSERT INTO 'dancevideo' VALUES (6991, '2020-03-05 00:12:19.538616+00', '2020-03-05 00:23:06.034627+00', 13526, 1, 1645, '', 'B', 'Once through as part of a longer demonstration.', 1, 1, 'Y', 'kj6NGBY2vWw', 70, 111, NULL);
INSERT INTO 'dancevideo' VALUES (6990, '2020-03-05 00:03:58.700717+00', '2020-03-05 00:23:22.074994+00', 9219, 1, 1645, '', 'B', 'This clip starts with the dancing, the video begins with an introduction.', 1, 1, 'Y', '0aG96WHeIko', 36, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6995, '2020-03-05 17:30:40.385356+00', '2020-03-05 23:19:01.432923+00', 1478, 6, 3086, '', 'A', 'Twice through. The audio does not seem quite synchronised with the dancing.', 1, 1, 'Y', 'B4uRdCXBDKE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6996, '2020-03-07 01:40:03.486739+00', '2020-03-07 01:40:03.486739+00', 753, 4, 1296, '', 'X', '''The Braes of Mellinish'' is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', 'WFwyQ5kBbAo', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (6997, '2020-03-07 01:40:03.526811+00', '2020-03-07 01:40:03.526811+00', 5083, 1, 1296, '', 'X', '''On the Wings of the Morning'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'ghJJa9w5hyA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (6998, '2020-03-07 01:40:03.54477+00', '2020-03-07 01:40:03.54477+00', 14528, 2, 1296, '', 'X', '''Mairi''s Hangover'' is a 40 bar reel for 4 couples.', 1, 1, 'Y', '55vdDR_0F6I', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7005, '2020-03-08 01:40:04.16454+00', '2020-03-08 01:40:04.16454+00', 13464, 2, 1296, '', 'X', '''The Mountain Stream'' is a 32 bar reel for 2 couples.', 1, 1, 'Y', 'raMR3sunxQA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7006, '2020-03-08 01:40:04.201602+00', '2020-03-08 01:40:04.201602+00', 15695, 1, 1296, '', 'X', '''Olympic Treasure'' is a 48 bar strathspey for 4 couples.', 1, 1, 'Y', '8YxsuRKi1Bk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7001, '2020-03-07 16:38:11.936151+00', '2020-03-08 20:51:12.761538+00', 4185, 4, 1645, '', 'C', 'Good, with a few extra social diversions (through other sets).', 1, 1, 'Y', 'PUifxhRdWxk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7000, '2020-03-07 16:33:15.798824+00', '2020-03-08 20:51:19.01816+00', 4185, 3, 1645, '', 'B', '', 1, 1, 'Y', '2ycUAQwSuFI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7003, '2020-03-07 17:00:25.032262+00', '2020-03-08 20:51:31.97384+00', 4543, 1, 1645, '', 'C', 'This clip starts at the 3rd repeat (previously the camera was roving around). There are a couple of well recovered errors towards the end.', 1, 1, 'Y', 't0U_cHjkmKw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7002, '2020-03-07 16:46:47.655655+00', '2020-03-08 20:51:42.801171+00', 12777, 1, 1645, '', 'B', 'Four times, once each couple, with the former 1st couple slipping to the bottom down the centre as a new top couple starts.', 1, 1, 'Y', 'o4N59c1qsuY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7004, '2020-03-07 17:17:49.904229+00', '2020-03-08 20:51:52.446006+00', 19858, 1, 1645, '', 'B', '', 1, 1, 'Y', 'l0luUCQ6ygc', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6994, '2020-03-05 10:04:34.912293+00', '2020-03-08 20:52:08.590985+00', 17343, 1, 1645, '', 'C', 'Just over three times through (the figure of bars 9-16 is different each time).', 1, 1, 'Y', '7YwNksDMB2w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6999, '2020-03-07 15:43:59.312525+00', '2020-03-08 20:52:26.236207+00', 7090, 3, 1645, '', 'B', 'Three times, once each couple in 3 couple sets. After the RH across of bars 9-12, 1st couple should pass left shoulders, but here they pass right shoulder.', 1, 1, 'Y', 'ECFpevydC9c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7008, '2020-03-10 16:52:19.236469+00', '2020-03-10 18:43:21.096819+00', 5252, 1, 2586, '', 'C', 'The version of the dance being done here differs from the published version in both bars 1-8 and 25-28. Bars 1-8 are replaced by the men dancing as the women later do in bars 9-16 (instead of advance, retire and loop around partner). In bars 25-28 all set twice (instead of just 1st couple dancing back to back).', 1, 1, 'Y', 'n0LShyVJsDM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7012, '2020-03-11 12:00:26.452553+00', '2020-03-11 22:04:11.747409+00', 19884, 1, 197, '', 'C', 'one repeat only', 1, 1, 'Y', '2DtBC8qSrx8', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7010, '2020-03-11 11:49:39.007354+00', '2020-03-11 22:06:42.229666+00', 19864, 1, 197, '', 'B', '', 1, 1, 'Y', '0_TmA5ebbTw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7007, '2020-03-08 21:04:00.73403+00', '2020-03-11 22:07:12.349073+00', 8912, 1, 1645, '', 'D', '', 1, 1, 'Y', '_tbCYzamLqM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7017, '2020-03-14 08:22:12.304016+00', '2020-03-14 18:46:02.001826+00', 6707, 1, 1645, '', 'C', '', 1, 1, 'Y', '8ZUuve6XASo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7011, '2020-03-11 11:51:54.202806+00', '2020-03-11 22:31:05.094803+00', 19831, 1, 197, '', 'B', 'The dancers here do LH across 1 1/4 in strathspey but 3/4 in reel time leading to different progressions. A 3/4 LH across each time would cycle couples through all four places.', 1, 1, 'Y', 'cOnbh_41FjU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1946, '2015-02-18 18:24:53.21119+00', '2020-03-12 23:19:42.647173+00', 1758, 1, 1041, '', 'C', '', 1, 1, 'Y', 'fwQeHQBTroE', 22, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7015, '2020-03-14 08:07:44.551235+00', '2020-03-14 18:45:44.269972+00', 17745, 2, 1645, '', 'A', 'Twice through in two 3 couple sets as part of a longer demo. The 2nd repeat is inverted with 3rd couple being the dancing couple.', 1, 1, 'Y', 'gElRPmjhvbo', 108, 233, NULL);
INSERT INTO 'dancevideo' VALUES (7018, '2020-03-14 08:38:10.873417+00', '2020-03-14 18:45:50.869789+00', 15951, 1, 1645, '', 'C', '', 1, 1, 'Y', 'knF2nzsOMJQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7016, '2020-03-14 08:12:36.620519+00', '2020-03-14 18:45:56.484804+00', 16006, 1, 1645, '', 'A', 'Twice through in two 3 couple sets as part of a longer demo.', 1, 1, 'Y', 'gElRPmjhvbo', 232, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7014, '2020-03-14 07:59:56.608141+00', '2020-03-14 18:46:07.899796+00', 10169, 1, 1645, '', 'B', 'Twice through in 3 couple sets as part of a longer demo. The 2nd repeat is inverted using opposite hands in bars 1-16 and with bars 17-24 at the bottom of the set. The 1st repeat is the one to watch.', 1, 1, 'Y', 'gElRPmjhvbo', 34, 109, NULL);
INSERT INTO 'dancevideo' VALUES (7013, '2020-03-14 07:44:37.136962+00', '2020-03-14 18:46:13.678234+00', 6990, 1, 1645, '', 'X', '', 1, 1, 'Y', 'cpZVJ51hXCw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7021, '2020-03-15 19:28:23.111458+00', '2020-03-16 09:59:43.665995+00', 2642, 1, 1645, '', 'D', '', 1, 1, 'Y', 'azHu4uASft8', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7025, '2020-03-15 23:26:28.352676+00', '2020-03-16 10:00:21.751648+00', 1805, 1, 1645, '', 'A', '', 1, 1, 'Y', 'lAEreLI0h6U', 986, 1144, NULL);
INSERT INTO 'dancevideo' VALUES (7023, '2020-03-15 21:55:59.103291+00', '2020-03-16 09:59:21.239995+00', 9512, 1, 1645, '', 'A', '', 1, 1, 'Y', 'lAEreLI0h6U', 296, 431, NULL);
INSERT INTO 'dancevideo' VALUES (7019, '2020-03-15 16:42:19.064054+00', '2020-03-16 09:59:33.311934+00', 19890, 1, 1645, '', 'A', 'Twice through.', 1, 1, 'Y', 'ldSq3AJPS2c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7024, '2020-03-15 22:13:10.606939+00', '2020-03-16 09:59:56.498765+00', 1806, 1, 1645, '', 'A', 'Once through extract from a longer demonstration medley.', 1, 1, 'Y', 'lAEreLI0h6U', 729, 791, NULL);
INSERT INTO 'dancevideo' VALUES (7022, '2020-03-15 19:50:03.633042+00', '2020-03-16 10:00:34.962727+00', 14569, 1, 1645, '', 'A', 'Once through as part of a long demonstration, however the last 4 bars are adapted to lead into the next dance in the display medley.', 1, 1, 'Y', 'o1Tc9yQZcKM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7020, '2020-03-15 17:12:00.366839+00', '2020-03-16 10:00:47.100355+00', 10456, 2, 1645, '', 'A', 'Once through clip from a longer demo (which begins with a slightly modified version of this dance).', 1, 1, 'Y', 'hy8T4sX0xV0', 56, 100, NULL);
INSERT INTO 'dancevideo' VALUES (7028, '2020-03-17 12:43:35.564444+00', '2020-03-19 22:40:44.823227+00', 535, 3, 1645, '', 'B', 'Once through.', 1, 1, 'Y', '2Us4V2c7wJE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7029, '2020-03-17 19:35:01.982825+00', '2020-03-19 22:40:56.431601+00', 1521, 1, 1645, '', 'C', 'Once through: a little confusion at the start but clear thereafter.', 1, 1, 'Y', 'Z26Q-rJcUjQ', 124, 160, NULL);
INSERT INTO 'dancevideo' VALUES (7030, '2020-03-17 19:57:54.167855+00', '2020-03-19 22:41:42.268462+00', 9222, 1, 1645, '', 'C', 'Twice through in two 2 couple sets. The video starts around bar 2.', 1, 1, 'Y', 'TGAhxqeTVh4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7027, '2020-03-17 12:37:58.863515+00', '2020-03-19 22:42:03.423492+00', 16927, 1, 1645, '', 'B', '', 1, 1, 'Y', 'fjYfT2p9Sd0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7033, '2020-03-19 23:02:33.77441+00', '2020-03-20 21:14:03.392503+00', 13547, 2, 1645, '', 'C', 'Just the strathspey part.', 1, 1, 'Y', 'B5Ew3Ylpwxk', 77, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7035, '2020-03-20 09:51:36.357042+00', '2020-03-20 21:13:37.845911+00', 19613, 1, 1645, '', 'B', '', 1, 1, 'Y', '0NdkKxBGyAE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7038, '2020-03-20 12:07:43.95347+00', '2020-03-20 21:13:51.015347+00', 19895, 1, 1645, '', 'B', 'Three times through.', 1, 1, 'Y', 'IAhAXFbOGV8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7032, '2020-03-19 22:50:23.308859+00', '2020-03-20 21:13:57.902523+00', 13744, 1, 1645, '', 'C', 'Three times: once each couple in a 3 couple set.', 1, 1, 'Y', 'AzXPrMvfxfw', 50, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7042, '2020-03-20 21:41:49.196148+00', '2020-03-21 19:42:21.21111+00', 6035, 2, 1645, '', 'B', '', 1, 1, 'Y', 'o9ddPRBkjAg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7040, '2020-03-20 21:29:41.434434+00', '2020-03-21 19:50:13.485552+00', 1616, 3, 1645, '', 'B', '', 1, 1, 'Y', '2eTy_LuiAww', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7039, '2020-03-20 21:14:47.647475+00', '2020-03-21 23:11:52.507906+00', 2396, 1, 1645, '', 'B', '', 1, 1, 'Y', '1QEs2ZzTJiY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7041, '2020-03-20 21:36:07.243121+00', '2020-03-21 23:11:59.055791+00', 14686, 1, 1645, '', 'B', '', 1, 1, 'Y', 'iivs8HaRPqg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7043, '2020-03-22 14:14:14.736982+00', '2020-03-22 14:14:48.800018+00', 16018, 3, 160, '', 'A', '', 1, 1, 'V', '399631559', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7049, '2020-03-23 23:47:51.509122+00', '2020-03-23 23:49:45.768538+00', 16086, 3, 1645, '', 'X', '''The Fiddler''s Wife'' is a 32 bar strathspey for 3 couples.

', 1, 1, 'Y', 'x4TVmpSRv4c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7045, '2020-03-23 19:00:43.004953+00', '2020-03-24 00:39:01.836308+00', 5915, 7, 1645, '', 'A', '', 1, 1, 'Y', '2Y1hAVtO8eg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7044, '2020-03-23 17:48:21.618077+00', '2020-03-24 11:21:25.447435+00', 1244, 5, 1645, '', 'B', '', 1, 1, 'Y', 'oXlFxB3fKkQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7047, '2020-03-23 20:58:02.877255+00', '2020-03-24 11:21:33.031673+00', 3522, 1, 1645, '', 'D', '', 1, 1, 'Y', 'OinnqT9R4Yg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7046, '2020-03-23 20:45:08.970827+00', '2020-03-24 11:21:43.12748+00', 3763, 1, 1645, '', 'B', '', 1, 1, 'Y', 'LPOx76_eQds', 58, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7048, '2020-03-23 22:03:32.312415+00', '2020-03-24 11:21:49.950577+00', 5731, 1, 1645, '', 'D', 'NB in the original instructions the initial chase is supposed to be along the sides of a square (rather than circular).', 1, 1, 'Y', 'A2tnfX8k2MQ', 321, 615, NULL);
INSERT INTO 'dancevideo' VALUES (7050, '2020-03-24 13:24:17.109099+00', '2020-03-24 13:24:35.504301+00', 12020, 1, 106, '', 'D', '', 1, 1, 'Y', 'HTLhxYAVEgU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3507, '2018-04-16 07:53:20.10176+00', '2020-03-24 15:20:25.711754+00', 17922, 1, 513, '', 'C', '', 1, 1, 'Y', 'nSSkJKXFt84', 13, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7053, '2020-03-24 21:44:50.487877+00', '2020-03-24 22:27:09.718037+00', 11639, 1, 1645, '', 'B', '', 1, 1, 'Y', 'nPlcChqicZc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7057, '2020-03-24 22:20:19.712531+00', '2020-03-24 22:27:15.343669+00', 585, 1, 1645, '', 'B', '', 1, 1, 'Y', 'Nu1Xc01jx1A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7058, '2020-03-24 22:25:47.538784+00', '2020-03-24 22:27:20.491232+00', 8624, 1, 1645, '', 'B', '', 1, 1, 'Y', '5icx3OyJ6ZU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7056, '2020-03-24 22:14:17.203325+00', '2020-03-24 22:27:26.071672+00', 11633, 1, 1645, '', 'B', '', 1, 1, 'Y', '17akb4ZKVdI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7055, '2020-03-24 22:09:33.164794+00', '2020-03-24 22:27:31.026363+00', 19906, 1, 1645, '', 'B', '', 1, 1, 'Y', 'VCGgJH69_oI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7054, '2020-03-24 21:49:10.284197+00', '2020-03-24 22:27:35.936853+00', 11634, 1, 1645, '', 'B', '', 1, 1, 'Y', 's51dnq5-R8s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7052, '2020-03-24 21:41:11.888365+00', '2020-03-24 22:27:40.621776+00', 11636, 1, 1645, '', 'B', '', 1, 1, 'Y', 'duVbfCz7dLA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7051, '2020-03-24 15:00:53.068135+00', '2020-03-24 22:27:48.0684+00', 19577, 1, 1645, '', 'C', 'Fairly clear with a voice over (and a few missing turns and glitches in the reel).', 1, 1, 'Y', 'PzzT8TfMJig', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7071, '2020-03-27 19:52:39.905232+00', '2020-03-28 15:13:13.930734+00', 19085, 1, 1645, '', 'B', '', 1, 1, 'Y', 'HUBhKIr2STg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7059, '2020-03-26 09:04:30.279106+00', '2020-03-26 11:12:25.786103+00', 17391, 2, 2581, '', 'A', 'Twice without, then twice with the optional rights and lefts in bars 17-24.', 1, 1, 'Y', 'K3dzkUNvAp4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7070, '2020-03-27 19:48:19.847997+00', '2020-03-28 15:13:25.397844+00', 392, 1, 1645, '', 'C', 'Twice though in a 7 couple set as part of a longer demonstration.', 1, 1, 'Y', '6v7Z73GkstY', 154, 276, NULL);
INSERT INTO 'dancevideo' VALUES (7069, '2020-03-27 19:31:22.517417+00', '2020-03-28 15:13:36.09573+00', 8199, 1, 1645, '', 'B', 'After one repeat the camera roves a bit then returns to the better set.', 1, 1, 'Y', 'FiK3tx_kI9c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7068, '2020-03-27 19:24:33.534923+00', '2020-03-28 15:13:46.433988+00', 10909, 1, 1645, '', 'C', '', 1, 1, 'Y', '-KHtmuOjJ_M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7067, '2020-03-27 19:19:16.961746+00', '2020-03-28 15:13:54.798065+00', 8490, 1, 1645, '', 'B', '', 1, 1, 'Y', 'bnRKrzWXSU8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7064, '2020-03-27 19:03:02.468855+00', '2020-03-28 15:14:01.402843+00', 18359, 1, 1645, '', 'A', '', 1, 1, 'Y', '7q__3MvQ8Bg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7063, '2020-03-27 19:00:24.222522+00', '2020-03-28 15:14:16.160385+00', 1773, 1, 1645, '', 'D', 'Roving camera and plenty of errors.', 1, 1, 'Y', 'xqxzcJHgFU4', 0, 126, NULL);
INSERT INTO 'dancevideo' VALUES (7072, '2020-03-27 21:31:45.971278+00', '2020-03-28 15:14:34.796692+00', 11186, 1, 1645, '', 'D', 'Done in a class as part of a medley of other Scotia suite dances. Quite a few (recovered) errors and the last 8 bars are changed to prepare for the next dance.', 1, 1, 'Y', 'xgluNXZsr2M', 74, 266, NULL);
INSERT INTO 'dancevideo' VALUES (7065, '2020-03-27 19:08:58.70155+00', '2020-03-28 15:19:45.136166+00', 3594, 5, 1645, '', 'A', 'Twice through, in two back to back sets, as part of a longer demonstration. The last 12 bars of the 2nd repeat are adapted to lead into the next dance in the medley.', 1, 1, 'Y', 'ZtQtmWM-5fo', 45, 122, NULL);
INSERT INTO 'dancevideo' VALUES (7062, '2020-03-27 18:52:48.022008+00', '2020-03-28 15:20:21.006738+00', 5362, 1, 1645, '', 'C', '', 1, 1, 'Y', 'Thq3AyC6U_c', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7081, '2020-03-29 20:05:53.084586+00', '2020-11-07 14:12:17.875049+00', 19933, 2, 1645, '', 'B', 'Aberdeen RSCDS: first of two demonstrations of this dance on the same video.', 1, 1, 'Y', 'pCE2eqy3V-A', 167, 318, NULL);
INSERT INTO 'dancevideo' VALUES (7061, '2020-03-27 18:42:52.521901+00', '2020-03-28 15:20:31.623516+00', 16477, 1, 1645, '', 'C', '', 1, 1, 'Y', 'sH4romHvsg8', 351, 555, NULL);
INSERT INTO 'dancevideo' VALUES (7073, '2020-03-28 19:15:15.550661+00', '2020-03-28 20:45:24.095453+00', 11723, 1, 1645, '', 'A', 'Twice through as part of a longer demonstration. The final promenade of the 2nd repeat is changed to lead into the next dance in the medley.', 1, 1, 'Y', '2Ne1KM3vajg', 0, 76, NULL);
INSERT INTO 'dancevideo' VALUES (7077, '2020-03-29 19:08:00.207712+00', '2020-03-29 22:18:20.232812+00', 19932, 1, 1645, '', 'B', '', 1, 1, 'Y', 'yYElb1PUijQ', 21, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7075, '2020-03-29 18:41:40.853559+00', '2020-03-29 22:18:37.409984+00', 12005, 1, 1645, '', 'D', 'This video follows the version summarised in the MiniCrib (though with retire and advance instead of advance and retire). The SCDDB extra info notes that there seem to be other versions of this dance.', 1, 1, 'Y', 'ouh9W9mcwQk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7076, '2020-03-29 18:52:15.398185+00', '2020-03-29 22:18:47.999919+00', 10903, 1, 1645, '', 'D', 'The version done here finishes with 1 & 1/2 RH turns so matches the description in the SCDDB extra info notes more closely than the MiniCrib (which has half figure of eight).', 1, 1, 'Y', 'IW71VU7V220', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7078, '2020-03-29 19:23:30.641632+00', '2020-03-29 22:19:00.869252+00', 4026, 1, 1645, '', 'A', 'Twice through as part of a longer demonstration. The last 2 bars of the final rondel are adapted to lead into the next dance.', 1, 1, 'Y', '3IHD9juxZSw', 7, 135, NULL);
INSERT INTO 'dancevideo' VALUES (7083, '2020-03-30 20:37:34.360799+00', '2020-03-30 21:03:27.943553+00', 16025, 2, 1645, '', 'B', '', 1, 1, 'Y', 'GVTrhAmyCJ4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7084, '2020-03-30 20:40:21.992254+00', '2020-03-30 21:03:32.963071+00', 4046, 8, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'm1_eL9C7-Yo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7085, '2020-03-30 20:48:19.192585+00', '2020-03-30 21:03:38.162221+00', 542, 4, 1645, '', 'C', '', 1, 1, 'Y', '0pihMJerLdM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7088, '2020-03-30 21:28:04.405092+00', '2020-03-30 21:38:56.935129+00', 1559, 1, 1645, '', 'C', '', 1, 1, 'Y', '6RrwVSwb8nQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7087, '2020-03-30 21:18:34.713595+00', '2020-03-30 21:39:08.18876+00', 1858, 1, 1645, '', 'B', '', 1, 1, 'Y', 'AhIXp1R_jRY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7086, '2020-03-30 21:12:22.646356+00', '2020-03-30 21:39:15.16593+00', 7404, 1, 1645, '', 'C', '', 1, 1, 'Y', 'SStK6Bx-woI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4274, '2019-01-29 09:24:24.317237+00', '2020-03-31 10:09:47.17876+00', 4046, 7, 274, '', 'B', 'Burns Supper 2019, Budapest



The dancing is of demonstration quality, but as the music is (Irish) reels, instead of the expected jig time, the video has been downgraded to "good".', 1, 1, 'Y', '2M8RVwtNEwk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7090, '2020-04-01 00:40:03.640055+00', '2020-04-01 00:40:03.640055+00', 1405, 3, 1296, '', 'X', '''Cramond Bridge'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'RUTzI95BRYs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7091, '2020-04-01 00:40:03.670682+00', '2020-04-01 00:40:03.670682+00', 2203, 7, 1296, '', 'X', '''Fisherman''s Reel'' is a 32 bar reel for 5 couples.', 1, 1, 'Y', 'NACNDOCGoo4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7092, '2020-04-01 00:40:03.691475+00', '2020-04-01 00:40:03.691475+00', 2822, 5, 1296, '', 'X', '''The Hazel Tree'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'lusecRr7idY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7093, '2020-04-01 00:40:03.712048+00', '2020-04-01 00:40:03.712048+00', 3932, 6, 1296, '', 'X', '''Lord Elgin''s Reel'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'v6Gj5LC4PcQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7079, '2020-03-29 19:40:20.06626+00', '2022-04-17 22:46:40.930582+00', 13001, 1, 1645, '', 'B', 'Aberdeen RSCDS Tartan Week 2011.', 1, 1, 'Y', 'pCE2eqy3V-A', 319, 480, NULL);
INSERT INTO 'dancevideo' VALUES (7094, '2020-04-01 00:40:03.729245+00', '2020-04-01 00:40:03.729245+00', 5644, 2, 1296, '', 'X', '''The Rocks of Solitude'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'P8ae8pYGlJo', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7095, '2020-04-01 00:40:03.747181+00', '2020-04-01 00:40:03.747181+00', 14243, 3, 1296, '', 'X', '''Sandy''s Scotch Broth'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'gmbhemcGGf0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7096, '2020-04-01 21:26:59.468938+00', '2020-04-01 21:27:45.95979+00', 19941, 1, 1645, '', 'B', 'Performance of a dance devised to fit non-SCD music (the deviser is walking due to an injury). The dance starts with a 16 bar intro (no chord) followed by 4 repeats of 32 bars - featuring alternating tandem inveran reels.', 1, 1, 'Y', 'H3earPqGCCI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1088, '2013-08-18 10:47:54.934355+00', '2020-04-01 22:18:06.063626+00', 1473, 4, 1296, '', 'A', 'In this video, published by the RSCDS archives, Ann Dix tells in detail about the origin of this dance, its name and the music.  First small parts of the dance are shown.  The dance is shown in full twice, starting at 3:01 and 5:04.', 1, 1, 'Y', 'BQqnlSH4KUI', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7099, '2020-04-02 12:23:07.348955+00', '2020-04-02 12:30:33.876504+00', 2700, 1, 1645, '', 'A', 'Twice through in a two couple set.', 1, 1, 'Y', '4mDKhDoMHj4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7101, '2020-04-02 12:29:35.100025+00', '2020-04-02 12:30:38.514802+00', 3506, 3, 1645, '', 'A', 'Twice through in a two couple set.', 1, 1, 'Y', 'mdQJG2zbWeY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7098, '2020-04-02 12:18:49.681502+00', '2020-04-02 12:30:42.988876+00', 4499, 1, 1645, '', 'B', 'The family group here preferred to clap three times woman then three times man instead of alternating.', 1, 1, 'Y', 'aplHVKr9JJA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7100, '2020-04-02 12:25:49.005289+00', '2020-04-02 12:30:47.013332+00', 6915, 4, 1645, '', 'B', '', 1, 1, 'Y', 'Nl8i6J5xF1M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7106, '2020-04-02 14:46:49.280212+00', '2020-04-02 16:19:03.121045+00', 11772, 7, 1645, '', 'A', 'Three times in a two couple set.', 1, 1, 'Y', 'm4cliq5x8Fo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7105, '2020-04-02 14:39:35.033345+00', '2020-04-02 16:19:08.057372+00', 76, 2, 1645, '', 'B', 'Three times in a two couple set.', 1, 1, 'Y', 'XfPBEL33j7w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7109, '2020-04-02 15:02:39.491214+00', '2020-04-02 16:19:13.245987+00', 11375, 5, 1645, '', 'B', 'Three times in a two couple set.', 1, 1, 'Y', 'WN-apfA1Nlk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7102, '2020-04-02 14:26:27.442063+00', '2020-04-02 16:19:22.290711+00', 5310, 1, 1645, '', 'A', 'Twice through in a two couple set.', 1, 1, 'Y', 'z4_flEPHy1U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7103, '2020-04-02 14:30:11.728927+00', '2020-04-02 16:19:26.792012+00', 6471, 3, 1645, '', 'B', 'Twice through in a two couple set.', 1, 1, 'Y', '8GyxFiErrws', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7108, '2020-04-02 14:58:07.516049+00', '2020-04-02 16:19:30.991043+00', 17141, 5, 1645, '', 'B', 'Four times in a two couple set. In the last two repeats the men here dance round their partners right shoulder instead of left and follow with men''s chains instead of ladies chains.', 1, 1, 'Y', 'z6z7FznJhCw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7104, '2020-04-02 14:33:38.758546+00', '2020-04-02 16:19:35.123308+00', 6756, 5, 1645, '', 'B', '', 1, 1, 'Y', 'lxjr-y_EQOc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7107, '2020-04-02 14:50:24.412417+00', '2020-04-02 16:19:39.391549+00', 7061, 9, 1645, '', 'A', '', 1, 1, 'Y', 'hqekPo5q6z4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7111, '2020-04-02 22:45:56.294233+00', '2020-04-02 23:01:54.370845+00', 5723, 1, 1645, '', 'B', 'Twice through in a set with every 3rd couple dancing.', 1, 1, 'Y', 'A59b4aQQJaI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7112, '2020-04-02 23:20:36.180162+00', '2020-04-02 23:20:43.733158+00', 19942, 1, 1645, '', 'B', '', 1, 1, 'Y', 'YQudwbn8_wc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7113, '2020-04-03 11:07:40.512661+00', '2020-04-03 13:08:11.38349+00', 10539, 1, 1645, '', 'B', 'Once through.', 1, 1, 'Y', '1X-m-o7n9ho', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7116, '2020-04-03 15:23:31.143325+00', '2020-04-03 15:23:39.785289+00', 5543, 1, 1645, '', 'B', '', 1, 1, 'Y', 'gTL73ob7lNY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7114, '2020-04-03 13:16:59.429489+00', '2020-04-03 15:23:45.253106+00', 9165, 1, 1645, '', 'A', 'Three times in a 3 couple set as part of a longer demonstration. The 2nd time the set is inverted with the set and link figures starting at the top.', 1, 1, 'Y', '6NpvwWl5J7Y', 94, 286, NULL);
INSERT INTO 'dancevideo' VALUES (7115, '2020-04-03 13:25:02.20139+00', '2020-04-03 15:23:50.221274+00', 5198, 5, 1645, '', 'A', 'Three times in a 3 couple set as part of a longer demo. The 2nd time the set is inverted with the bottom couple dancing.', 1, 1, 'Y', '6NpvwWl5J7Y', 284, 418, NULL);
INSERT INTO 'dancevideo' VALUES (7117, '2020-04-04 15:17:48.512251+00', '2020-04-04 15:17:57.992155+00', 4309, 2, 1645, '', 'B', 'Danced twice in a 2 couple set. Since 1st couple start on opposite sides the last 4 bars of the 1st repeated are adapted to 3/4 rights and lefts instead of 1/2 so all start the next repeat on the correct sides. The 2nd time is done as expected.', 1, 1, 'Y', '3GBIW0k8BBM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7118, '2020-04-05 16:23:20.187864+00', '2020-04-05 16:23:29.291835+00', 2498, 6, 1645, '', 'B', 'Twice through in a 2 couple set. Since the couples start opposite each other and beside partner, the end of the final reels here are adapted to reorganise the set for the next repeat.', 1, 1, 'Y', 'BXbuLX7BkLY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7119, '2020-04-06 15:57:52.807693+00', '2020-04-06 15:58:09.437702+00', 5934, 2, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', 'cLuc69d7-bA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7120, '2020-04-06 20:56:10.93769+00', '2020-04-06 20:57:43.484741+00', 8753, 1, 1645, '', 'A', '', 1, 1, 'Y', 'WRDVitCi0bg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7122, '2020-04-06 20:57:28.1955+00', '2020-04-06 20:57:47.55676+00', 5459, 2, 1645, '', 'A', '', 1, 1, 'Y', 'EY2vyLAkjgs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7121, '2020-04-06 20:56:52.810446+00', '2020-04-06 20:57:52.442315+00', 2239, 1, 1645, '', 'A', '', 1, 1, 'Y', '7YSovSG40TU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7123, '2020-04-06 21:06:38.230046+00', '2020-04-07 14:41:09.086821+00', 10008, 4, 2586, '', 'A', 'One little choreography error: at the end of the 2nd repeat one of the half figures of 8 is danced up instead of down.', 1, 1, 'Y', '6eanW1l2mZs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7124, '2020-04-07 15:31:56.44424+00', '2020-04-07 15:34:39.741234+00', 5765, 1, 1645, '', 'A', 'Twice through in a 2 couple set.', 1, 1, 'Y', 'KeawdM7ENCE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7125, '2020-04-08 16:44:35.060986+00', '2020-04-08 16:44:48.628405+00', 1476, 1, 1645, '', 'A', 'Twice through in a 2 couple set.', 1, 1, 'Y', 'RPuEMx6Uz9o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7127, '2020-04-08 19:37:40.060591+00', '2020-04-08 19:59:05.56221+00', 8752, 1, 1645, '', 'A', '', 1, 1, 'Y', 'ueS6hDVTEyQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7126, '2020-04-08 19:35:52.191+00', '2020-04-08 19:59:10.075337+00', 8749, 2, 1645, '', 'A', '', 1, 1, 'Y', 'EDLpHqmoxpI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7131, '2020-04-09 16:48:04.399903+00', '2020-04-09 17:08:40.462536+00', 588, 4, 1645, '', 'B', 'Three times in a 4 couple set, starting with the middle couples.', 1, 1, 'Y', 'POG9V_gvdrw', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7132, '2020-04-09 16:53:29.312274+00', '2020-04-09 17:08:46.238352+00', 588, 5, 1645, '', 'B', 'Twice in a 4 couple set, starting with the middle couples.', 1, 1, 'Y', 'M3R_0aJJBWg', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7130, '2020-04-09 16:41:52.082621+00', '2020-04-09 17:08:52.205149+00', 14738, 5, 1645, '', 'B', '', 1, 1, 'Y', '9ozBtzyC7kU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7133, '2020-04-09 17:14:25.401918+00', '2020-04-09 17:14:34.276205+00', 159, 12, 1645, '', 'B', 'Twice in a 2 couple set, once with and once without 2nd couple looping into place on bars 15-16.', 1, 1, 'Y', 'p20iML9GSTo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7129, '2020-04-09 16:34:30.790332+00', '2020-04-09 22:08:53.922069+00', 19944, 1, 1645, '', 'B', 'This is a demonstration of a Scottish Country Dance by the Arkansas Scottish Country Dance Society, Little Rock, AR.  This was performed at the Little Rock "Greek Food Festival," May 17, 2014.  



Dancers at this event were: Ursula Chandler, Sandy Furrer, Nita Herrick, John Johnson, Bernadette Lange, Edith Miller, John Miller, Pat Pennington, David Peterson, Donna Peterson, Susan Posnar, Macy Purtle, and Mary Schlatterer.  Directed by Judy Robinson.', 1, 1, 'Y', 'PTAz97GHkGk', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7134, '2020-04-09 22:53:23.771961+00', '2020-04-09 22:53:59.945239+00', 5749, 2, 202, '', 'A', '', 1, 1, 'Y', 'pJAZaSaRWOM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7135, '2020-04-09 23:04:55.497092+00', '2020-04-09 23:05:27.767594+00', 5128, 2, 202, '', 'A', '', 1, 1, 'Y', 'UEUlueti0T4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7136, '2020-04-09 23:08:51.011137+00', '2020-04-09 23:09:15.55582+00', 3428, 1, 202, '', 'A', '', 1, 1, 'Y', '3MiID7ILtL0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7137, '2020-04-09 23:11:27.282637+00', '2020-04-09 23:11:59.89802+00', 3883, 1, 202, '', 'A', '', 1, 1, 'Y', 'dc4h_tmWeU0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7178, '2020-04-29 22:12:58.641187+00', '2020-04-29 22:13:09.415129+00', 9862, 7, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', 'dXFEtplDHc0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7138, '2020-04-10 09:33:41.991992+00', '2020-04-10 09:34:48.393147+00', 13357, 2, 1645, '', 'C', 'Once through (the clearest extract from a slightly longer video).', 1, 1, 'Y', 'oX8vEriqPzk', 41, 78, NULL);
INSERT INTO 'dancevideo' VALUES (7139, '2020-04-10 09:41:30.904825+00', '2020-04-10 16:25:35.251694+00', 8778, 2, 1645, '', 'B', '', 1, 1, 'Y', 'DTmAgqBGzNY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7140, '2020-04-10 10:22:24.475579+00', '2020-04-10 16:26:13.153816+00', 1453, 1, 1645, '', 'C', 'A good performance which substantially differs from the original instructions in several places:  

- Part 2 bars 1-2: 1st couple should turn both hands while advancing, here they just advance.  

- Part 2 bars 9-16: here done as two separate reels instead of one with all in promenade hold.  

- Part 2 bars 25-32: 1st couple here do not make the expected arch.  

- Part 3: the Celtic Brooch figure is here replaced with Schiehallion reels.  

Its nice to watch but not quite what John Drewry envisaged.', 1, 1, 'Y', '3b_XAUrsTAU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7141, '2020-04-10 16:25:26.156412+00', '2020-04-10 16:26:21.125415+00', 4959, 1, 1645, '', 'A', 'Twice through in a 2 couple set.', 1, 1, 'Y', 'LDPx5kdsFJo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2491, '2016-05-22 22:33:01.763804+00', '2020-04-11 17:04:48.091441+00', 3788, 1, 106, '', 'A', 'Part of a display.  Four 2-couple sets arranged in a square.  Twice through.  Final bars modified.  RSCDS London Branch Ball- Battersea 2502/1995', 1, 1, 'Y', '7poKsWw9N7g', 150, 278, NULL);
INSERT INTO 'dancevideo' VALUES (7142, '2020-04-11 17:13:57.969904+00', '2020-04-11 17:18:31.543482+00', 3788, 3, 1645, '', 'B', 'Twice through in a 2 couple set. 2nd couple seem to finish the reels a little early here compared to other interpretations of the dance.', 1, 1, 'Y', 'ik2kgyKNjN0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7143, '2020-04-11 17:18:16.605606+00', '2020-04-11 17:18:37.034315+00', 5006, 5, 1645, '', 'B', '', 1, 1, 'Y', 'I7hRtBJNvrI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7144, '2020-04-12 15:43:33.589705+00', '2020-04-12 15:43:46.10095+00', 3585, 1, 1645, '', 'A', 'Twice through in a 2 couple set.', 1, 1, 'Y', 'h3h5VIpAYc0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7156, '2020-04-17 15:46:53.886732+00', '2020-04-17 15:47:03.579658+00', 6061, 1, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'CJaptYycMKk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7145, '2020-04-12 20:43:56.905283+00', '2020-04-13 18:36:18.155561+00', 8489, 1, 1645, '', 'B', '', 1, 1, 'Y', 'hAVtYV5fYBM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7146, '2020-04-12 21:29:56.7236+00', '2020-04-13 18:36:26.870036+00', 19953, 1, 1645, '', 'D', 'This clip starts with the dancing, the whole video begins with walk through and recap.', 1, 1, 'Y', 'wqXASAuDPYQ', 188, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7148, '2020-04-12 21:54:07.499021+00', '2020-04-13 18:36:36.557917+00', 13458, 1, 1645, '', 'D', 'This clip shows just the last and best time through.', 1, 1, 'Y', 'MhQd8WT-4Uc', 137, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7147, '2020-04-12 21:39:57.632531+00', '2020-04-13 18:36:43.846526+00', 10749, 1, 1645, '', 'B', '', 1, 1, 'Y', 'aIn-9fUBSEY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7149, '2020-04-12 22:03:05.309797+00', '2020-04-13 18:36:54.145086+00', 5522, 1, 1645, '', 'D', 'This clip starts with the best two repeats by the set nearest the camera.', 1, 1, 'Y', 'MKOxmEl562s', 113, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7151, '2020-04-13 18:40:58.696896+00', '2020-04-13 18:41:06.838149+00', 19954, 1, 1645, '', 'B', '', 1, 1, 'Y', 'GMYWhfDwpLA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7157, '2020-04-18 17:00:07.748046+00', '2020-04-18 17:00:16.112381+00', 4830, 2, 1645, '', 'A', '', 1, 1, 'Y', 'Wli6rGN3A8Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7150, '2020-04-13 17:55:31.050664+00', '2020-04-14 12:07:18.860636+00', 5007, 2, 1645, '', 'A', 'Twice through in a 2 couple set.', 1, 1, 'Y', 'M08PUaT_pnE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7152, '2020-04-14 11:42:14.857909+00', '2020-04-14 16:34:02.055705+00', 10879, 1, 1645, '', 'C', 'This clip starts with the 2nd turn, the camera moving at the start, but then a clear view of one set for the rest of one complete turn.', 1, 1, 'Y', 'biZuxnse01Y', 45, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7153, '2020-04-14 16:33:48.149109+00', '2020-04-14 16:34:08.675468+00', 6368, 1, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'bfh_dg4yyZY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4845, '2019-06-11 12:26:02.850726+00', '2020-04-14 21:15:10.419347+00', 13648, 4, 513, '', 'C', 'Recorded at the Sunday evening dance during the 30th Anniversary Weekend of the RSCDS Vienna Branch in 2019.', 1, 1, 'Y', '0AFL1vjw0rg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7154, '2020-04-15 19:35:59.378762+00', '2020-04-15 19:36:16.360593+00', 19956, 1, 1645, '', 'A', '', 1, 1, 'Y', 'mPTYdwrB5RY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7066, '2020-03-27 19:14:08.16861+00', '2020-04-16 09:12:09.454514+00', 3594, 6, 1645, '', 'B', 'Twice through, in two back to back sets, as part of a longer demonstration. The last 8 bars of the 2nd repeat are adapted to lead into the next dance.', 1, 1, 'Y', 'mYKqt9nJR_s', 27, 99, NULL);
INSERT INTO 'dancevideo' VALUES (7155, '2020-04-16 17:19:38.995612+00', '2020-04-16 17:19:48.899524+00', 3235, 1, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'Qdzln5sNEc0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7158, '2020-04-20 16:32:05.46303+00', '2020-04-20 16:32:16.554483+00', 3526, 1, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'V1CG7dnvfWg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (286, '2012-10-01 07:45:59.167838+00', '2020-04-20 23:21:09.009039+00', 5982, 2, 513, '', 'D', 'Recorded on 29.09.2012 during the Dancetide SCD WE in Copenhagen', 1, 1, 'Y', 'q8stX7oOrVo', 116, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7159, '2020-04-22 09:54:24.834971+00', '2020-04-22 09:54:45.627337+00', 1210, 1, 1645, '', 'C', 'Circassian Circle is an old dance existing in many variations. This video shows 10 such variations, referred to as "Figures", each done once through. The dancing is excellent but as none of the variations demonstrated here are actually the one chosen by the RSCDS to include in Book 1 it is marked as "reasonable" due to the different choreography. Also, as it is intended as a round the room dance but is here done with two couples, they have to wheel round at the end of each figure to be ready for the next one. The comments attached to the <<https://youtu.be/ZHhcExp1iBg|youtube video>> provide more information (first in Italian, then in English).', 1, 1, 'Y', 'ZHhcExp1iBg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7160, '2020-04-22 16:54:45.070619+00', '2020-04-22 16:54:52.998263+00', 5497, 8, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', 'nkPr0JH6Wgk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7161, '2020-04-23 00:40:03.997526+00', '2020-04-23 00:40:03.997526+00', 1838, 5, 1296, '', 'X', '''The Dundee Whaler'' is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'ATsTJdA5d3Q', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7162, '2020-04-23 00:40:04.019696+00', '2020-04-23 00:40:04.019696+00', 2110, 5, 1296, '', 'X', '''Father Connelly''s Jig'' is a 64 bar jig for 4 couples.', 1, 1, 'Y', 'L19TZyutNXI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7163, '2020-04-23 00:40:04.039087+00', '2020-04-23 00:40:04.039087+00', 11773, 4, 1296, '', 'X', '''Festival Fling'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'l7vZg1D2asw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7164, '2020-04-23 00:40:04.069161+00', '2020-04-23 00:40:04.069161+00', 9636, 5, 1296, '', 'X', '''Inchmickery'' is a 32 bar jig for 5 couples.', 1, 1, 'Y', 'tgdpEe3Cn-g', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7166, '2020-04-23 16:40:47.081926+00', '2020-04-23 16:40:58.244254+00', 5520, 1, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', 'w49JU7RyZSU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7167, '2020-04-24 00:40:03.51683+00', '2020-04-24 00:40:03.51683+00', 4796, 4, 1296, '', 'X', '''Mrs Milne of Kinneff'' is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'nJtgOyBjgRY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7168, '2020-04-24 00:40:03.548074+00', '2020-04-24 00:40:03.548074+00', 10008, 5, 1296, '', 'X', '''The Recumbent Stone'' is a 48 bar reel for 5 couples.', 1, 1, 'Y', 'vB10Xn-2xpQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7165, '2020-04-23 00:40:04.091635+00', '2020-04-24 00:40:03.576574+00', 4365, 5, 1296, '', 'Z', '''Midnight Oil'' is a 48 bar jig for 5 couples.', 1, 1, 'Y', 'GcHXeW2ImHU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7169, '2020-04-24 00:40:03.582035+00', '2020-04-24 00:40:03.582035+00', 4365, 6, 1296, '', 'X', '''Midnight Oil'' is a 48 bar jig for 5 couples.', 1, 1, 'Y', 'TgF0N4uduyM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7170, '2020-04-24 13:12:11.87617+00', '2020-04-24 13:13:54.668176+00', 19958, 1, 202, '', 'C', 'First 8 bars have changed and ... no hands!', 1, 1, 'Y', 'VCi7dPj9IRI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7171, '2020-04-24 16:34:13.699463+00', '2020-04-24 16:34:29.710383+00', 2777, 3, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'hSf6O2ZGR5E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7172, '2020-04-25 18:31:51.961838+00', '2020-04-25 18:32:01.248843+00', 5239, 8, 1645, '', 'A', 'Demonstration in a 2 couple set of (1) the standard version with 1st couple only (2) with 1st and 2nd couples dancing in tandem and (3) both couples dancing in a diamond. NB there is no sound for part of the 2nd time through.', 1, 1, 'Y', 'HzUW7ROXKOE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7174, '2020-04-26 11:09:30.329563+00', '2020-04-26 11:09:45.840667+00', 19959, 1, 202, '', 'X', '', 1, 1, 'Y', 'BsQvyYm4d1k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7175, '2020-04-26 19:05:59.649293+00', '2020-04-26 19:06:08.353328+00', 4438, 1, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'L4dz85IoMe8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7176, '2020-04-27 17:58:44.955303+00', '2020-04-27 17:58:53.229294+00', 2010, 1, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', '8kCufYZJ_FU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7177, '2020-04-28 20:42:54.411507+00', '2020-04-28 20:43:06.5435+00', 109, 8, 1645, '', 'B', 'Twice in  a 2 couple set.', 1, 1, 'Y', 'jwa2PxajClg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7179, '2020-05-01 07:41:35.259109+00', '2020-05-01 07:41:47.740098+00', 15, 1, 1645, '', 'A', 'Twice in 2 couple set.', 1, 1, 'Y', '2rybazX9cDw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7180, '2020-05-02 00:04:46.842005+00', '2020-05-02 00:04:56.45453+00', 2501, 3, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', '_auZwdE2F7s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7181, '2020-05-02 19:20:31.495829+00', '2020-05-02 19:20:40.800045+00', 5754, 1, 1645, '', 'A', 'Three times in a 2 couple set.', 1, 1, 'Y', 'hRE5dM6Ef68', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7182, '2020-05-02 19:32:26.800734+00', '2020-05-02 21:09:50.967499+00', 9061, 3, 1144, '', 'A', 'A 32 bar Strathspey for 3 couples in  a longwise set (progression 312). Recorded at the Bristol RSCDS residential weekend, Dawlish Warren 2020.', 1, 1, 'Y', 'T8oyxa44C2s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7183, '2020-05-03 17:37:33.465458+00', '2020-05-03 17:37:41.39332+00', 4471, 1, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'm1D5IQOd2QM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7185, '2020-05-04 12:54:54.96717+00', '2020-05-04 19:58:52.833556+00', 2846, 5, 1645, '', 'A', '', 1, 1, 'Y', 'ElafzD_CZKA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7186, '2020-05-04 13:00:18.051998+00', '2020-05-04 19:58:59.035914+00', 5128, 3, 1645, '', 'B', '', 1, 1, 'Y', 'Su2Q2XrUaFw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7184, '2020-05-04 12:51:12.613911+00', '2020-05-04 19:59:04.751133+00', 14313, 2, 1645, '', 'A', '', 1, 1, 'Y', 'ObWEid69qTc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3872, '2018-10-01 22:07:53.700016+00', '2020-06-01 00:40:03.395186+00', 522, 3, 1296, '', 'Z', '"The Birks of Invermay" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'kCiGh0ZbUK8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7187, '2020-05-04 20:04:23.878372+00', '2020-05-04 20:04:36.079536+00', 19960, 1, 1645, '', 'C', 'Once through in a blend of  6 solo performances. More walked than danced for reasons given at the end of the video. The dancing starts about 20 seconds in after rather lengthy opening titles. There is more information in the closing titles and the comments on youtube.', 1, 1, 'Y', 'xwmoMop-Ycc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7188, '2020-05-04 20:19:10.485851+00', '2020-05-04 20:19:18.089801+00', 6489, 2, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'Wra_eh4zoGM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7189, '2020-05-05 00:40:03.425746+00', '2020-05-05 00:40:03.425746+00', 13586, 3, 1296, '', 'X', '''The Bonnie Tree'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'pERPQjhWN94', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7190, '2020-05-05 00:40:03.45889+00', '2020-05-05 00:40:03.45889+00', 1884, 6, 1296, '', 'X', '''The Earl of Mansfield'' is a 48 bar reel for 4 couples.', 1, 1, 'Y', 'Gmoojdn9rUY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7191, '2020-05-05 00:40:03.493865+00', '2020-05-05 00:40:03.493865+00', 3108, 8, 1296, '', 'X', '''Inverneill House'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'XOeEFBxMe-8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7192, '2020-05-05 00:40:03.518091+00', '2020-05-05 00:40:03.518091+00', 10794, 3, 1296, '', 'X', '''James Gray'' is a 32 bar jig for 4 couples.', 1, 1, 'Y', 'rZ3w2cKGNIw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7193, '2020-05-05 00:40:03.540982+00', '2020-05-05 00:40:03.540982+00', 3336, 7, 1296, '', 'X', '''Johnnie Walker'' is a 64 bar strathspey for 4 couples.', 1, 1, 'Y', 'ek4W4GY19Vw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (558, '2012-12-17 14:18:34.457026+00', '2020-05-05 16:21:05.772397+00', 3225, 1, 1296, '', 'A', 'Dancers (International Demonstration Team): Petra Dolata, Andrew McCausland, Fiona Mackie, Sergey Kargapoltsev, Tom McKinlay, Lindsay Wilkins

Musician: Jeremy Hill', 1, 1, 'Y', 'pdB63GNA1aQ', 94, 187, NULL);
INSERT INTO 'dancevideo' VALUES (7195, '2020-05-05 16:10:38.450909+00', '2020-05-05 16:44:33.144979+00', 441, 4, 1645, '', 'A', '', 1, 1, 'Y', 'eV4bilBddIY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7199, '2020-05-05 16:43:16.975697+00', '2020-05-05 16:44:40.786785+00', 633, 8, 1645, '', 'A', '', 1, 1, 'Y', 'Rg3ZINuBk6Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7194, '2020-05-05 16:01:35.446365+00', '2020-05-05 16:44:58.945203+00', 3680, 2, 1645, '', 'A', '', 1, 1, 'Y', 'EM_-ytipqHQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7196, '2020-05-05 16:15:34.993621+00', '2020-05-05 16:45:06.053295+00', 4282, 1, 1645, '', 'A', '', 1, 1, 'Y', 'rajK0M-DjAI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7198, '2020-05-05 16:40:20.069848+00', '2020-05-05 16:45:11.80935+00', 5707, 1, 1645, '', 'A', '', 1, 1, 'Y', 'RlI1gKs52oQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7200, '2020-05-05 16:57:09.930239+00', '2020-05-05 16:57:16.538803+00', 5982, 7, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'YE5pIFWCmdw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7201, '2020-05-05 20:38:17.647069+00', '2020-05-05 21:51:55.109366+00', 3487, 1, 2824, '', 'A', 'Danced by Kate Gentles with Adam Brady on piano at the RSCDS London Branch Day School 19 October 2019.', 1, 1, 'Y', '2ezVXzGwSIE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7204, '2020-05-07 08:49:20.904614+00', '2020-05-07 08:52:15.429125+00', 19971, 1, 1645, '', 'B', '', 1, 1, 'Y', 'hbCJqaD6ylY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7197, '2020-05-05 16:25:06.358629+00', '2020-05-05 22:58:39.447394+00', 3225, 3, 1645, '', 'A', '', 1, 1, 'Y', 'fIc7WbPLWcY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7202, '2020-05-06 11:18:00.897533+00', '2020-05-06 17:08:14.466514+00', 2600, 7, 1645, '', 'B', 'Three times.', 1, 1, 'Y', 'j5wJS-VRa5k', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7203, '2020-05-06 17:07:57.622824+00', '2020-05-06 17:08:22.547301+00', 5906, 2, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', 'USGZ-XI_85A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7205, '2020-05-07 09:00:19.506729+00', '2020-05-07 09:00:35.679237+00', 19687, 1, 1645, '', 'C', 'Starts with a good set then the camera moves on...', 1, 1, 'Y', 'bPGNct722y0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7206, '2020-05-07 17:07:15.035793+00', '2020-05-07 17:07:22.559723+00', 5734, 4, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', '3NefAFpIWnQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7207, '2020-05-07 18:27:14.173453+00', '2020-05-07 18:27:49.278456+00', 6813, 1, 1645, '', 'A', 'Once through as part of a longer demo. The last 4 bars are adapted to lead into the next dance in the medley.', 1, 1, 'Y', 'cy_9DdGDrSc', 193, 255, NULL);
INSERT INTO 'dancevideo' VALUES (7211, '2020-05-07 19:52:16.518048+00', '2020-05-07 20:41:44.088415+00', 441, 5, 1645, '', 'A', '', 1, 1, 'Y', 'tdffXtbFhVA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7209, '2020-05-07 19:16:27.717779+00', '2020-05-07 20:41:49.921846+00', 633, 9, 1645, '', 'A', '', 1, 1, 'Y', 'pztutHOvRS0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7210, '2020-05-07 19:36:19.666102+00', '2020-05-07 20:41:55.365091+00', 742, 2, 1645, '', 'A', '', 1, 1, 'Y', 'PFiG0AseMlE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7212, '2020-05-07 20:16:21.880802+00', '2020-05-07 20:42:01.821138+00', 1881, 2, 1645, '', 'A', '', 1, 1, 'Y', '12CQa1z9mBY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7208, '2020-05-07 18:42:27.022482+00', '2020-05-07 20:42:09.020434+00', 3651, 1, 1645, '', 'A', 'Twice through.', 1, 1, 'Y', '5cJv3YV6HDo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7213, '2020-05-07 20:40:34.527077+00', '2020-05-07 20:42:14.013636+00', 4271, 2, 1645, '', 'A', '', 1, 1, 'Y', 'POqi-5KafoU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7214, '2020-05-07 21:02:57.795297+00', '2020-05-07 21:44:21.562822+00', 4044, 2, 1645, '', 'A', '', 1, 1, 'Y', 'CUuV49aqq-M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7215, '2020-05-07 21:11:48.796339+00', '2020-05-07 21:44:27.710904+00', 4283, 1, 1645, '', 'A', '', 1, 1, 'Y', 'e7Dswfdof6U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7219, '2020-05-08 11:02:41.662206+00', '2020-05-08 11:13:48.406822+00', 805, 1, 1645, '', 'A', '', 1, 1, 'Y', 'Lxp-7lD0Uio', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7220, '2020-05-08 11:13:29.806153+00', '2020-05-08 11:13:53.236988+00', 3225, 4, 1645, '', 'A', '', 1, 1, 'Y', 'JypGysLME2Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7216, '2020-05-08 10:39:26.307555+00', '2020-05-08 11:13:58.802558+00', 4474, 2, 1645, '', 'A', '', 1, 1, 'Y', '3UM_FNa6bAo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7218, '2020-05-08 10:52:14.682867+00', '2020-05-08 11:14:03.937546+00', 6037, 8, 1645, '', 'A', '', 1, 1, 'Y', 'zi8r5nEEdUM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7217, '2020-05-08 10:47:38.357717+00', '2020-05-08 11:14:09.09726+00', 5807, 3, 1645, '', 'A', 'Twice through.', 1, 1, 'Y', 'cFNVBemCNt0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7221, '2020-05-08 13:39:22.667698+00', '2020-05-08 14:03:21.5113+00', 3777, 1, 1645, '', 'A', '', 1, 1, 'Y', 'PI3pAeZQUaQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7222, '2020-05-08 13:51:27.665993+00', '2020-05-08 14:03:26.744031+00', 4043, 2, 1645, '', 'A', '', 1, 1, 'Y', 'EpHhMNE6vhk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7223, '2020-05-08 14:00:51.649197+00', '2020-05-08 14:03:33.022796+00', 4680, 1, 1645, '', 'A', '', 1, 1, 'Y', 'XUhpzf_56VU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7226, '2020-05-08 15:56:11.413142+00', '2020-05-08 15:56:49.86216+00', 1789, 1, 1645, '', 'A', '', 1, 1, 'Y', 'i7cL1zQCpZU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7224, '2020-05-08 15:23:26.332159+00', '2020-05-08 15:56:54.59436+00', 5699, 1, 1645, '', 'A', '', 1, 1, 'Y', 'hxPToLHR-K8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7225, '2020-05-08 15:41:45.742017+00', '2020-05-08 15:56:59.409695+00', 5799, 1, 1645, '', 'A', 'The 16 bar figure in part A is here done twice rather than 4 times.', 1, 1, 'Y', 'Ht6_fE60daM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7227, '2020-05-08 17:15:25.694974+00', '2020-05-08 17:15:34.044922+00', 4506, 2, 1645, '', 'B', 'Twice in a 2 couple set. The youtube comments discuss the awkwardness of bar 16.', 1, 1, 'Y', 'yKwJ9PwQ5bs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7228, '2020-05-09 07:59:01.152071+00', '2020-05-09 07:59:35.344417+00', 633, 10, 1645, '', 'B', 'Excellent dancing though quite a few camera transitions so less useful for learning the dance.', 1, 1, 'Y', 'JInN-5637v0', 38, 142, NULL);
INSERT INTO 'dancevideo' VALUES (7229, '2020-05-09 20:22:02.595169+00', '2020-05-09 20:22:13.623891+00', 2807, 4, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', '2E0hVVLXtYg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7230, '2020-05-10 18:05:24.017162+00', '2020-05-10 18:05:31.767058+00', 8368, 3, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', 'RL4qC4rrokU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7231, '2020-05-11 11:34:14.057335+00', '2020-05-11 11:34:26.532142+00', 9431, 1, 202, '', 'D', '', 1, 1, 'Y', 'RjecB0zWK04', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7232, '2020-05-11 17:15:58.458924+00', '2020-05-11 17:16:09.246478+00', 3759, 7, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', 'hGvA4svqD9A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7233, '2020-05-11 19:10:45.28226+00', '2020-05-11 19:11:03.832009+00', 2126, 4, 202, '', 'D', '', 1, 1, 'Y', 'fewRbgHMRoQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7277, '2020-05-25 18:20:32.87809+00', '2020-05-26 20:25:22.430064+00', 9075, 1, 1645, '', 'D', 'Once through clip of the last repeat which mostly works though with some hesitation in the last 8 bars.', 1, 1, 'Y', 'Wij2wrqYLAI', 346, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7278, '2020-05-26 20:24:54.953299+00', '2020-05-26 20:25:28.031225+00', 2780, 1, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', '-Tince8JN6A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7497, '2020-07-26 09:17:12.061362+00', '2020-07-26 11:07:30.963518+00', 6800, 1, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 864, 976, NULL);
INSERT INTO 'dancevideo' VALUES (7234, '2020-05-12 17:19:55.375856+00', '2020-05-12 17:20:15.431424+00', 5921, 2, 1645, '', 'B', 'Twice in a 2 couple set. This is normally a round the room dance, but here after the first time the couples turn once round LH (instead of cross LH) to face each other again. After the second time they cross LH and end back to back in the expected progression.', 1, 1, 'Y', 'rdtBmm2T1ms', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7235, '2020-05-13 19:12:13.452147+00', '2020-05-13 19:12:21.809844+00', 753, 5, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', '6aKqNBQnk_o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7237, '2020-05-13 22:55:04.045492+00', '2020-05-13 22:57:43.496193+00', 17122, 6, 106, '', 'A', 'RSCDS Summer School Wk 2 Scottish Country Dancing Demonstration,  Book 52,  30 jul. 2018.  

First part of this display, twice through, final bars modified to link to next dance.', 1, 1, 'Y', 'y0f2TrKQbio', 36, 360, NULL);
INSERT INTO 'dancevideo' VALUES (7238, '2020-05-14 16:46:20.287623+00', '2020-05-14 16:46:28.239558+00', 2956, 5, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', '1GlbZKZhgrQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7239, '2020-05-15 16:46:05.490992+00', '2020-05-15 16:46:13.993175+00', 6885, 4, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', 'LXHgJ2tBUl4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7286, '2020-06-01 00:40:03.401198+00', '2020-06-01 00:40:03.401198+00', 522, 4, 1296, '', 'X', '''The Birks of Invermay'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '73C3rxPNtvg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7340, '2020-06-21 22:07:22.71706+00', '2020-06-22 19:10:03.612898+00', 1163, 4, 1645, '', 'A', 'Good view from above.', 1, 1, 'Y', '58RzNAVmPKM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7244, '2020-05-16 11:07:26.51529+00', '2020-05-18 22:33:48.296177+00', 11260, 1, 1645, '', 'D', 'Bellingham Scottish Country Dancers Spring Ceilidh, at the Littlefield Celtic Center, Mount Vernon WA.  April 30, 2017  



Music by Up In The Air. Jimie Gregory on fiddle, Beverly Porter on flute, John Borso on guitar, Pam Borso on guitar, and Tom Tonge on bass.   



https://bellinghamscd.org   



Video by Bob Olson

', 1, 1, 'Y', 'DbXSOAWH5L4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7128, '2020-04-09 15:20:41.921715+00', '2020-05-19 00:36:11.156663+00', 7087, 1, 1645, '', 'B', 'This is a demonstration of a Scottish Country Dance by the Arkansas Scottish Country Dance Society, Little Rock, AR.  This was performed at the Russellville, AR "Party in the Park" held on 23 April 2011.', 1, 1, 'Y', 'gph7sSvdk3Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7241, '2020-05-16 09:40:04.736281+00', '2020-05-16 17:49:02.872348+00', 9287, 1, 1645, '', 'C', 'Once through. The dance instructions specify 6 bars for the corners to chase half way round. The corners here tend to get ahead of this unusually extended allowance.', 1, 1, 'V', '79453442', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7242, '2020-05-16 10:37:09.612971+00', '2020-05-16 17:49:09.064765+00', 12518, 1, 1645, '', 'D', 'The phrasing of the hands across, round partner and hands across back in 8 bars (in 49-56 and 57-64) is evidently a challenging feature of this dance.', 1, 1, 'Y', 'QMqwRrJ-uVg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7243, '2020-05-16 11:02:31.910548+00', '2020-05-16 17:49:15.849365+00', 13353, 1, 1645, '', 'D', 'This clip starts at bar 33 (2s & 4s repeating bars 1-32) with some mishaps in the tandem reels. The whole video starts around bar 25.', 1, 1, 'Y', 'B8_rsuXA1Q4', 14, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7263, '2020-05-21 00:40:03.769467+00', '2020-05-21 00:40:03.769467+00', 17623, 3, 1296, '', 'X', '''Maple Grove, The '' is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'wJpFMDjBQ9I', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7245, '2020-05-16 11:18:09.240382+00', '2020-05-16 17:49:27.706655+00', 7358, 1, 1645, '', 'D', 'Once through.', 1, 1, 'Y', 'lkZBOw4BsGY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7240, '2020-05-16 09:21:21.718758+00', '2020-05-16 17:49:40.432979+00', 1783, 1, 1645, '', 'D', 'The set here is not doing the hands across and back in 3 bars each way so does not have time to cast before the rights and lefts.', 1, 1, 'Y', 'pMqIqnZBgdo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7246, '2020-05-16 11:28:54.275781+00', '2020-05-16 17:49:49.88319+00', 1843, 1, 1645, '', 'C', 'Once through clip from a longer compilation of ball highlights.', 1, 1, 'Y', 'BHeqK8SmPkQ', 132, 192, NULL);
INSERT INTO 'dancevideo' VALUES (7247, '2020-05-16 12:01:00.185318+00', '2020-05-16 17:49:56.624368+00', 11073, 1, 1645, '', 'D', '', 1, 1, 'Y', 'JK4pkf5p8Jo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7248, '2020-05-16 12:02:51.619335+00', '2020-05-16 17:50:01.814926+00', 11073, 2, 1645, '', 'X', '', 1, 1, 'Y', 'Wq-rtsKo3QY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7249, '2020-05-16 12:09:03.934399+00', '2020-05-16 17:50:06.444352+00', 3180, 1, 1645, '', 'D', 'Just the reel part (clip from longer compilation of ball highlights).', 1, 1, 'Y', 'BHeqK8SmPkQ', 192, 261, NULL);
INSERT INTO 'dancevideo' VALUES (7250, '2020-05-16 17:48:43.236526+00', '2020-05-16 17:50:18.144933+00', 19976, 1, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'ksyrd2UPWQ8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7251, '2020-05-17 20:10:08.517481+00', '2020-05-17 20:10:17.240417+00', 4103, 2, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', 'pzkeiYR7piE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1629, '2014-04-07 13:07:55.773862+00', '2020-05-18 16:05:27.14126+00', 1304, 1, 1041, '', 'B', 'Once through as part of a demonstration', 1, 1, 'Y', 'czbhrxiG8Y4', 117, 150, NULL);
INSERT INTO 'dancevideo' VALUES (7252, '2020-05-18 16:07:55.010601+00', '2020-05-18 16:08:08.148901+00', 1304, 2, 1645, '', 'B', 'Twice in a 2 couple set (round the room being across the camera view). The end of the first repeat is adapted so the two couples can dance together again. The end of the second repeat is done as expected for a round the room dance.', 1, 1, 'Y', 'BqqCCW7dhr0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7253, '2020-05-19 00:40:03.258903+00', '2020-05-19 00:40:03.258903+00', 594, 2, 1296, '', 'X', '''The Blue Mess Jacket'' is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'rB0k9qR4Wqk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7254, '2020-05-19 00:40:03.288956+00', '2020-05-19 00:40:03.288956+00', 1060, 3, 1296, '', 'X', '''The Cashmere Shawl'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'vkRqfzY5mKw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7258, '2020-05-19 16:21:35.484386+00', '2020-05-19 16:24:00.535796+00', 5441, 2, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'EfRJLV546jY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7260, '2020-05-20 00:40:03.043308+00', '2020-05-20 00:40:03.043308+00', 6380, 4, 1296, '', 'X', '''The Summer Assembly'' is a 88 bar reel for 4 couples.', 1, 1, 'Y', 'noQ393X3i3Y', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7261, '2020-05-20 00:40:03.067859+00', '2020-05-20 00:40:03.067859+00', 9561, 5, 1296, '', 'X', '''S-Locomotion'' is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'iLj-tr4h7xo', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7262, '2020-05-20 15:54:02.700079+00', '2020-05-20 15:54:39.731218+00', 4638, 1, 1645, '', 'A', 'Twice in a 2 couple set. The youtube comment states that as nothing is specified in the book or the manual *we decided to extend the reel with an extra loop (bars 31-32) to enter the lead down smoothly, the alternative would have been to cut the reel at bar 6 and we honestly did not like it.*', 1, 1, 'Y', 'UA3oPnjwBfw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7256, '2020-05-19 00:40:03.352164+00', '2020-05-21 00:40:03.798524+00', 3743, 3, 1296, '', 'Z', '''The Last of the Lairds'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'GU2HBPe3QpI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7264, '2020-05-21 00:40:03.810918+00', '2020-05-21 00:40:03.810918+00', 3743, 4, 1296, '', 'X', '''The Last of the Lairds'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', '89x8DnlgTJ8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7255, '2020-05-19 00:40:03.314597+00', '2020-05-21 00:40:03.835807+00', 3463, 3, 1296, '', 'Z', '''Kilkenny Castle'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'RLxTu06GfHU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7259, '2020-05-20 00:40:03.013551+00', '2020-05-21 00:40:03.840271+00', 3463, 4, 1296, '', 'Z', '''Kilkenny Castle'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '-YpdtVuCXz0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7265, '2020-05-21 00:40:03.845913+00', '2020-05-21 00:40:03.845913+00', 3463, 5, 1296, '', 'X', '''Kilkenny Castle'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '6RLx4tzdILQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7266, '2020-05-21 19:25:47.693144+00', '2020-05-21 19:25:55.465997+00', 6505, 1, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', 'mMsUTrZHbyw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7267, '2020-05-22 16:47:26.439837+00', '2020-05-22 16:47:50.62424+00', 2723, 2, 1645, '', 'C', 'Twice in a 2 couple set.



Note that, as explained in the youtube comments, this is danced to very slow pastoral music, much slower and harder to dance to than the normal strathspey tempo.', 1, 1, 'Y', 'QzQ0sYKYHwg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7268, '2020-05-23 06:46:00.086481+00', '2020-05-23 06:47:29.448223+00', 4629, 3, 202, '', 'A', '', 1, 1, 'Y', '-ryIQSt74NY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7269, '2020-05-23 06:49:56.89477+00', '2020-05-23 06:50:53.935446+00', 10381, 4, 202, '', 'A', '', 1, 1, 'Y', 'd3U4hANBubQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7270, '2020-05-23 06:57:00.7664+00', '2020-05-23 06:57:29.860078+00', 10535, 7, 202, '', 'A', '', 1, 1, 'Y', 'meTI0n-IK4s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7271, '2020-05-23 06:59:28.013609+00', '2020-05-23 07:00:41.66799+00', 6964, 8, 202, '', 'A', '', 1, 1, 'Y', 'll6lXxeB2fI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7272, '2020-05-23 07:02:17.424311+00', '2020-05-23 07:03:15.585163+00', 9093, 3, 202, '', 'A', '', 1, 1, 'Y', 'SWXLp8bDJAs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7273, '2020-05-23 07:05:25.56529+00', '2020-05-23 07:05:49.015657+00', 1473, 10, 202, '', 'A', '', 1, 1, 'Y', '8O4wI3M5gPs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7274, '2020-05-23 18:02:11.156979+00', '2020-05-23 18:02:19.026553+00', 1783, 2, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'U8RcV1ecDOE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7275, '2020-05-24 17:36:03.745468+00', '2020-05-24 17:36:11.660216+00', 4144, 1, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'ZuF6Ld2PTx4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7276, '2020-05-25 16:51:51.618774+00', '2020-05-25 16:52:02.846168+00', 3236, 1, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', '20799ujx6Co', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7279, '2020-05-27 14:00:30.915679+00', '2020-05-27 14:31:40.62351+00', 19979, 1, 197, '', 'B', 'Performed at the Gala dinner of the Law Society of Scotland in June 2019 for their 70th Anniversary.', 1, 1, 'V', '342017945', 8, 290, NULL);
INSERT INTO 'dancevideo' VALUES (7280, '2020-05-27 18:51:22.210233+00', '2020-05-27 18:51:29.783679+00', 4725, 1, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', 'LN1WMXxaPf8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7281, '2020-05-28 18:03:20.005759+00', '2020-05-28 18:04:31.335441+00', 984, 3, 1645, '', 'B', 'Twice in a 2 couple set. The end of the 1st repeat is adjusted with an extra loop to continue the dance in the small set. The 2nd repeat ends as expected in a round the room dance.', 1, 1, 'Y', 'U205DNQZ-9c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7282, '2020-05-29 18:32:20.658296+00', '2020-05-29 18:32:40.87561+00', 6739, 1, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', 'GoMhJwfSRM0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7283, '2020-05-30 18:49:09.326043+00', '2020-05-30 18:49:19.546756+00', 19983, 1, 1645, '', 'A', 'Twice in a 2 couple set. Although the dance is intended as a 32S+32R medley, the dedicatees of the dance here chose to do twice strathspey then twice reel.', 1, 1, 'Y', 'TEKlDgp51Gs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7284, '2020-05-31 19:15:31.439451+00', '2020-05-31 19:15:39.035723+00', 17137, 5, 1645, '', 'B', 'Twice in a 2 couple set. This is a round the room dance so they add an extra loop at the end of the 1st repeat in order to be able to dance it again. The 2nd repeat ends as expected.', 1, 1, 'Y', 'sQUoeMm5cBo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7285, '2020-06-01 00:40:03.362067+00', '2020-06-01 00:40:03.362067+00', 353, 2, 1296, '', 'X', '''Baldovan Reel'' is a 32 bar reel for 4 couples.', 1, 1, 'Y', 'xd54oxDtlpw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7287, '2020-06-01 00:40:03.429133+00', '2020-06-01 00:40:03.429133+00', 1223, 9, 1296, '', 'X', '''The Clansman'' is a 32 bar jig for 2 couples.', 1, 1, 'Y', 'zUQ39b89gIU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7288, '2020-06-01 18:04:58.992835+00', '2020-06-01 18:05:05.971954+00', 2812, 2, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'q3JMBwkic7I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7289, '2020-06-02 00:40:03.668864+00', '2020-06-02 00:40:03.668864+00', 3759, 8, 1296, '', 'X', '''The Lea Rig'' is a 32 bar strathspey for 2 couples.', 1, 1, 'Y', '_YI9Krx0ClQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7290, '2020-06-02 00:40:03.689405+00', '2020-06-02 00:40:03.689405+00', 8709, 3, 1296, '', 'X', '''Spiffin'''' is a 32 bar jig for 5 couples.', 1, 1, 'Y', '0I_XIxW09aw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7291, '2020-06-02 00:40:03.702932+00', '2020-06-02 00:40:03.702932+00', 7105, 4, 1296, '', 'X', '''The Whistling Wind'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'ob7KbpGBayM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7292, '2020-06-02 22:37:36.624794+00', '2020-06-02 22:37:43.504336+00', 899, 3, 1645, '', 'B', 'Twice in a 2 couple set. There is one small casting error in the 2nd repeat (turning in rather than out on the way back up).', 1, 1, 'Y', 'B5quR6aLQxs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7293, '2020-06-03 20:54:29.467012+00', '2020-06-03 20:54:38.196381+00', 3862, 4, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', 'Gs83O02Z6Os', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7310, '2020-06-10 21:37:39.482999+00', '2021-07-16 11:07:15.20032+00', 19986, 1, 1645, '', 'B', 'Demonstration at the 2019 Canberra Ball.', 1, 1, 'Y', 'zf2ArgGczcs', 21, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7296, '2020-06-04 17:41:55.092466+00', '2020-06-04 17:48:20.592687+00', 19900, 1, 1645, '', 'B', 'Once through in a very socially distanced set. 3rd man (at the top) momentarily starts to join in the final poussette which is danced by 1st and 2nd couples at the bottom.', 1, 1, 'Y', 'kkhHlFukf4s', 52, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7308, '2020-06-10 21:14:33.304663+00', '2020-06-10 21:38:11.790311+00', 2508, 1, 1645, '', 'D', 'Danced on location. The video starts around bar 5 (missing the opening half rights and lefts).', 1, 1, 'Y', '0lJM9_RsuwM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7297, '2020-06-05 16:49:45.879431+00', '2020-06-05 16:50:02.259029+00', 19980, 1, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'Ji6wFYdnSD0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7298, '2020-06-06 17:26:20.779461+00', '2020-06-06 17:26:27.965164+00', 3986, 4, 1645, '', 'B', 'Twice in 2  couple set.', 1, 1, 'Y', 'rVR_sYQli7o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7299, '2020-06-06 22:39:48.081198+00', '2020-06-06 22:40:03.964783+00', 20000, 1, 1645, '', 'C', 'Once through in a blend of 8 solo performances. More walked than danced for reasons given at the end of the video. The dancing starts about 20 seconds in after rather lengthy opening titles. There is more information in the comments on youtube.', 1, 1, 'Y', 'Te5QNFD8s48', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7300, '2020-06-07 16:01:32.175811+00', '2020-06-07 16:01:44.420964+00', 19901, 1, 1645, '', 'X', '', 1, 1, 'Y', 'BBFtvPoxeSU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7301, '2020-06-07 19:48:04.039666+00', '2020-06-07 20:04:07.355617+00', 132, 5, 1645, '', 'A', 'Twice in 2 couple set.', 1, 1, 'Y', '4BlLgfJErtU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7302, '2020-06-07 21:17:38.440363+00', '2020-06-07 21:17:56.420013+00', 2700, 2, 1645, '', 'A', 'Once though in two back to back 2 couple sets. An extract from an RSCDS documentary.', 1, 1, 'Y', 'LdtlT3WPRAc', 1130, 1175, NULL);
INSERT INTO 'dancevideo' VALUES (7303, '2020-06-08 19:55:54.926481+00', '2020-06-08 19:56:29.486002+00', 5362, 2, 1645, '', 'B', 'Twice in a 2 couple set. This is a round the room dance so they add an extra loop at the end of the 1st repeat in order to be able to dance it again. The 2nd repeat ends as expected.



', 1, 1, 'Y', 'RFmdOr7aCq4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7295, '2020-06-04 17:26:10.709908+00', '2020-06-08 21:31:06.326792+00', 17399, 1, 1645, '', 'B', 'Twice in a 2 couple set. In bars 9-12 they dance a flowing swirl all in skip-change whereas the instructions suggest a tighter turn in 2 bars and then setting for 2 bars”.', 1, 1, 'Y', 'Vdn1A3WTWmw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7304, '2020-06-09 16:44:33.01874+00', '2020-06-09 16:44:44.580331+00', 5702, 2, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'bRoJgW7rC3s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7305, '2020-06-10 18:39:10.779491+00', '2020-06-10 18:39:20.17207+00', 5688, 2, 1645, '', 'A', 'Twice in a 2 couple set. There have been long discussions about how much to turn in bars 1-16. Here the 1st repeat has longer turns to the midline and the 2nd repeat has half turns to opposite places. They hope everyone will be happy with at least one of these!', 1, 1, 'Y', 'm-QB4pCP1x4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7306, '2020-06-10 20:55:42.860076+00', '2020-06-10 20:55:49.578249+00', 3631, 1, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'x4xYp9LZZlg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7307, '2020-06-10 21:06:06.438604+00', '2020-06-10 21:06:17.414359+00', 2513, 1, 1645, '', 'C', '', 1, 1, 'Y', 'G7kjTZMcbdM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7309, '2020-06-10 21:34:25.265222+00', '2020-06-10 21:38:18.615508+00', 19733, 1, 1645, '', 'C', '', 1, 1, 'Y', 'kMHoUN-S07M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7311, '2020-06-11 18:33:03.590167+00', '2020-06-11 18:34:23.911147+00', 5658, 3, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'PKP99cfHOcM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7312, '2020-06-12 00:44:01.561594+00', '2020-06-12 09:25:56.231325+00', 3284, 1, 562, '', 'A', 'From the RSCDS video Scotland Dancing Again', 1, 1, 'Y', 'LdtlT3WPRAc', 1310, 1443, NULL);
INSERT INTO 'dancevideo' VALUES (7313, '2020-06-12 21:10:09.351223+00', '2020-06-12 21:10:17.744604+00', 1274, 1, 1645, '', 'B', 'Twice in a 2 couple set.', 1, 1, 'Y', 'jTtBFWbDcH8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7315, '2020-06-13 20:45:48.316955+00', '2020-06-13 20:46:44.152919+00', 1485, 1, 1645, '', 'A', 'Twice in a 2 couple set.', 1, 1, 'Y', 'vt6TZXFfQfY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7314, '2020-06-13 12:47:17.325637+00', '2020-06-14 13:06:35.227997+00', 998, 3, 1645, '', 'B', '', 1, 1, 'Y', 'Xk9CgjrzzvM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7316, '2020-06-14 13:03:03.876152+00', '2020-06-14 13:06:56.759553+00', 12511, 1, 1645, '', 'A', 'Twice through, with dance off, as part of a longer demo.', 1, 1, 'Y', 'u4oHEYZGCK8', 186, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7317, '2020-06-14 18:04:25.61789+00', '2020-06-14 22:47:19.877591+00', 3111, 1, 1645, '', 'B', 'Three times as the last part of a longer demonstration.', 1, 1, 'Y', 'l3_NaekV70o', 164, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7318, '2020-06-14 22:47:09.135921+00', '2020-06-14 22:47:27.671287+00', 20011, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'lwNxNARAwKQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7319, '2020-06-14 22:59:16.18029+00', '2020-06-14 22:59:22.808918+00', 12426, 7, 1645, '', 'B', 'Clear view and mostly good with a little coaching.', 1, 1, 'Y', 'PeiDQR0AKkI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7322, '2020-06-17 00:40:03.558023+00', '2020-06-17 00:40:03.558023+00', 2242, 3, 1296, '', 'X', '''The Flower o'' the Quern'' is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'gWUgEJjs3-Y', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7323, '2020-06-17 00:40:03.60288+00', '2020-06-17 00:40:03.60288+00', 3577, 3, 1296, '', 'X', '''The Ladies of Dunse'' is a 40 bar reel for 3 couples.', 1, 1, 'Y', 'lkxgXLLzgVc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7324, '2020-06-17 00:40:03.626998+00', '2020-06-17 00:40:03.626998+00', 10306, 4, 1296, '', 'X', '''The Lochalsh Reel'' is a 40 bar reel for 3 couples.', 1, 1, 'Y', 'V1Z8laqXjD8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7321, '2020-06-15 23:20:03.709433+00', '2020-06-17 23:28:14.268615+00', 683, 1, 1645, '', 'C', '', 1, 1, 'Y', 'rdkeJSOyNE4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7325, '2020-06-17 23:27:47.188534+00', '2020-06-17 23:28:20.648908+00', 20029, 1, 1645, '', 'B', 'Once each couple.', 1, 1, 'Y', 'GzhLrvkJPh0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7320, '2020-06-15 23:05:05.807239+00', '2020-06-17 23:28:04.012294+00', 15414, 1, 1645, '', 'D', 'This clip starts with a reasonably successful repeat.', 1, 1, 'Y', 'sE5Mca7jxxk', 108, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7328, '2020-06-19 22:46:11.090934+00', '2020-06-19 23:09:42.976553+00', 1793, 1, 1645, '', 'C', 'Danced on location. On bars 7-8 1st couple are supposed to cast up and into lines of three across. This is quite challenging and the dancers here are understandably often a bit late.', 1, 1, 'Y', '6laHyERmsgM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7327, '2020-06-19 22:36:12.563728+00', '2020-06-19 23:09:50.047748+00', 1848, 1, 1645, '', 'D', '', 1, 1, 'Y', 'TJCBOvh1j0s', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7326, '2020-06-19 22:28:04.017033+00', '2020-06-19 23:10:05.257034+00', 10883, 1, 1645, '', 'C', '', 1, 1, 'Y', 'wHzky7_QhCw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7329, '2020-06-19 23:09:34.902505+00', '2020-06-19 23:10:12.951994+00', 20031, 1, 1645, '', 'A', 'Twice through.', 1, 1, 'Y', 'bh6LB0TN6hw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7330, '2020-06-20 00:40:03.664007+00', '2020-06-20 00:40:03.664007+00', 9563, 2, 1296, '', 'X', '''The Roselath Cross'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'pphuVI6vA7k', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7331, '2020-06-20 00:40:03.695118+00', '2020-06-20 00:40:03.695118+00', 5927, 3, 1296, '', 'X', '''Scotch Mist'' is a 32 bar strathspey for 5 couples.', 1, 1, 'Y', 'JqlTtZ5NQjs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5161, '2019-09-24 11:13:12.063215+00', '2020-06-20 08:54:44.449491+00', 802, 1, 1645, '', 'C', 'Twice through, once each couple, in a three couple set as part of a longer display. The last few bars are adapted to get 1st couple to the bottom. According to the instructions 1st couple should half turn left hand in bars 3-4 but here they use the right hand.', 1, 1, 'Y', '6qVNTxx9QRw', 192, 319, NULL);
INSERT INTO 'dancevideo' VALUES (7350, '2020-06-22 09:43:17.961411+00', '2020-06-22 19:11:10.139408+00', 8729, 2, 1645, '', 'A', 'Good view from above.', 1, 1, 'Y', '40-dB95l_bs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7332, '2020-06-20 19:45:03.17743+00', '2020-06-20 20:10:53.745788+00', 4940, 1, 1645, '', 'D', 'The video starts a couple of bars into one turn.', 1, 1, 'Y', 'zUjnQ4PhRcA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7333, '2020-06-20 20:07:18.620693+00', '2020-06-20 20:10:59.378197+00', 4924, 1, 1645, '', 'A', 'Once through as part of a longer display. The last few bars are adapted to lead into the next dance.', 1, 1, 'Y', 'tUYl3BarZuA', 277, 312, NULL);
INSERT INTO 'dancevideo' VALUES (7341, '2020-06-21 22:13:05.13562+00', '2020-06-22 19:09:53.859613+00', 7284, 6, 1645, '', 'A', 'Good view from above.', 1, 1, 'Y', 'xQxhJZt_0ow', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7355, '2020-06-22 18:51:27.278639+00', '2020-06-22 19:09:59.011997+00', 11368, 2, 1645, '', 'A', 'Good view from above.', 1, 1, 'Y', '717Pl_fTT3Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7352, '2020-06-22 10:03:39.79997+00', '2020-06-22 19:10:08.491129+00', 2317, 7, 1645, '', 'A', 'Version with six dancers.', 1, 1, 'Y', 'uWNPrUU35nY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7357, '2020-06-22 19:03:02.883917+00', '2020-06-22 19:10:13.861548+00', 11770, 5, 1645, '', 'A', 'Two views of the dance: first from above and then at floor level.', 1, 1, 'Y', 'LUQtTJN4uYY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7361, '2020-06-27 18:32:35.767048+00', '2020-06-27 19:56:41.777151+00', 14241, 2, 3086, '', 'A', '', 1, 1, 'Y', 'LVKxB8LMJFI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7351, '2020-06-22 09:59:43.756284+00', '2020-06-22 19:10:38.250734+00', 8730, 2, 1645, '', 'A', 'Good view from above.', 1, 1, 'Y', 'F5BoaKyjyTs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7345, '2020-06-21 22:33:41.755677+00', '2020-06-22 19:10:46.126609+00', 4857, 5, 1645, '', 'A', 'Good view from above.', 1, 1, 'Y', '3CIWe69HM44', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7353, '2020-06-22 10:10:12.079641+00', '2020-06-22 19:10:54.35643+00', 7613, 1, 1645, '', 'A', 'Good view from above.', 1, 1, 'Y', '15Svfgk7JhA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7344, '2020-06-21 22:25:06.683556+00', '2020-06-22 19:11:03.00306+00', 4933, 2, 1645, '', 'A', 'Good view from above.', 1, 1, 'Y', '6Cx13sQUfcE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7356, '2020-06-22 18:55:30.323485+00', '2020-06-22 19:11:18.27106+00', 5209, 12, 1645, '', 'A', 'Good view from above.', 1, 1, 'Y', '1q5U5OYBpcA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7349, '2020-06-22 09:36:45.276973+00', '2020-06-22 19:11:28.681234+00', 6386, 6, 1645, '', 'A', 'Last two repeats of a demo. Good view from above.', 1, 1, 'Y', 'kffcL1o3HXw', 22, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7354, '2020-06-22 18:46:09.707342+00', '2020-06-22 19:11:37.881334+00', 11369, 5, 1645, '', 'A', 'Good view from above.', 1, 1, 'Y', 'lC5Ixq_M7tU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7343, '2020-06-21 22:21:04.573108+00', '2020-06-22 19:11:48.24702+00', 5637, 8, 1645, '', 'A', 'Good view from above.', 1, 1, 'Y', 'bmDWz0bVMzc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7346, '2020-06-21 22:38:34.363809+00', '2020-06-22 19:11:55.678333+00', 5204, 3, 1645, '', 'A', 'Good view from above.', 1, 1, 'Y', 'iVz-U5UccJg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7358, '2020-06-22 19:07:11.113211+00', '2020-06-27 19:56:52.054584+00', 15779, 1, 1645, '', 'A', 'Performance by Dave Hall at a ceilidh (starts part way through).', 1, 1, 'Y', 'xKA0oGOAlpg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7342, '2020-06-21 22:17:08.959402+00', '2020-06-22 22:26:46.851761+00', 7285, 5, 1645, '', 'A', 'Country Dance display from RSCDS Summer School 1996', 1, 1, 'Y', 'HIHODP6rndg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7339, '2020-06-21 22:02:57.210791+00', '2020-06-22 23:13:59.047617+00', 12454, 3, 1645, '', 'A', 'A closer and lighter view of the same performance as video 1. There is a small glitch in the figure of 8 at the start of the 4th repeat.   

Country Dance display from RSCDS Summer School 2005', 1, 1, 'Y', '_isARpo3kds', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4365, '2019-03-10 13:14:42.594333+00', '2020-06-24 12:26:47.89957+00', 15685, 1, 2697, '', 'C', 'Nicely danced with dancers clearly identified by coloured shirts. In the Espagnole the dancers crossing up should pass in front of those crossing down. However here they do it the other way round.', 1, 1, 'Y', 'Mi5c7C5omws', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7359, '2020-06-22 19:24:17.26854+00', '2020-06-27 19:56:59.846119+00', 2984, 1, 1645, '', 'C', '', 1, 1, 'Y', 'rrNXEyUnzV4', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7347, '2020-06-22 09:28:34.614644+00', '2020-06-27 19:57:06.550467+00', 3487, 3, 1645, '', 'A', '', 1, 1, 'Y', 'fAcwxUd3kpg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7336, '2020-06-20 20:44:09.239604+00', '2020-06-27 19:57:12.546417+00', 3487, 2, 1645, '', 'A', '', 1, 1, 'Y', 'eifZq1khn2U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7335, '2020-06-20 20:35:12.33288+00', '2020-06-27 19:57:19.115365+00', 14311, 2, 1645, '', 'A', '', 1, 1, 'Y', 'mhY6uwuLqoM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7334, '2020-06-20 20:24:19.269044+00', '2020-06-27 19:57:25.309176+00', 14312, 1, 1645, '', 'A', '', 1, 1, 'Y', 'PlEgr_tI8R8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7360, '2020-06-24 12:35:49.129793+00', '2020-06-27 19:57:32.425774+00', 6037, 9, 1645, '', 'A', '', 1, 1, 'Y', 'R6psmgqcbZA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7337, '2020-06-20 20:53:57.72314+00', '2020-06-27 19:57:38.554679+00', 14314, 2, 1645, '', 'A', '', 1, 1, 'Y', 'lAUzvgS7tLI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7338, '2020-06-20 20:59:06.34653+00', '2020-06-27 19:57:44.218151+00', 14315, 1, 1645, '', 'A', '', 1, 1, 'Y', 'MxxVZ8qXZaU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7348, '2020-06-22 09:31:05.253754+00', '2020-06-27 19:57:51.21562+00', 14315, 2, 1645, '', 'A', '', 1, 1, 'Y', 'Oz2Pl822G4U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7365, '2020-07-05 09:06:57.644088+00', '2020-07-05 10:03:03.980905+00', 2581, 2, 1645, '', 'B', ' RSCDS Sheffield', 1, 1, 'Y', 'FKE1ZnJLsCQ', 54, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7367, '2020-07-05 09:59:33.549435+00', '2020-07-05 10:03:09.332384+00', 20036, 1, 1645, '', 'A', 'Once through as part of a longer demonstration by the Red Thistle Dancers.', 1, 1, 'Y', 'JBSHkKaULqo', 132, 181, NULL);
INSERT INTO 'dancevideo' VALUES (7362, '2020-07-05 08:51:25.563273+00', '2020-07-05 10:03:14.877323+00', 12830, 1, 1645, '', 'D', '', 1, 1, 'Y', '41_Myy_0pxQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7364, '2020-07-05 09:01:36.863952+00', '2020-07-05 10:03:19.89038+00', 13533, 1, 1645, '', 'B', ' RSCDS Sheffield', 1, 1, 'Y', 'VOOXX-MgizM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7369, '2020-07-05 10:02:52.635243+00', '2020-07-05 10:03:24.336124+00', 20038, 1, 1645, '', 'A', 'Once through as part of a longer demonstration by the Red Thistle Dancers.', 1, 1, 'Y', 'JBSHkKaULqo', 245, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7363, '2020-07-05 08:54:35.706452+00', '2020-07-05 10:03:29.387536+00', 14318, 1, 1645, '', 'D', 'Last two repeats. Red Deer Scottish Country Dance Club - East Kilbride', 1, 1, 'Y', '6UNLX20u5XM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7368, '2020-07-05 10:01:43.276689+00', '2020-07-05 10:03:33.92036+00', 20037, 1, 1645, '', 'A', 'Once through as part of a longer demonstration by the Red Thistle Dancers. The end is adapted to lead into the followed square dance.', 1, 1, 'Y', 'JBSHkKaULqo', 180, 245, NULL);
INSERT INTO 'dancevideo' VALUES (7366, '2020-07-05 09:13:02.204621+00', '2020-07-05 10:03:39.270554+00', 3562, 1, 1645, '', 'C', '', 1, 1, 'Y', 'NE5RGgpKIVg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7374, '2020-07-06 14:28:29.281432+00', '2020-07-06 21:03:36.573206+00', 1201, 2, 1645, '', 'A', 'Twice through as the final part of a longer demo by Aberdeen "City Moves".', 1, 1, 'Y', '2mwrQbbmmMg', 277, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7371, '2020-07-06 12:26:32.611398+00', '2020-07-06 21:03:51.896009+00', 11642, 1, 1645, '', 'D', 'Extract from U3A christmas party video - with the camera constantly moving around.', 1, 1, 'Y', 'J6bGl5XaiGA', 317, 440, NULL);
INSERT INTO 'dancevideo' VALUES (7373, '2020-07-06 14:20:06.07155+00', '2020-07-06 21:04:03.682235+00', 2956, 6, 1645, '', 'A', 'Extract from a longer demo by Aberdeen "City Moves".', 1, 1, 'Y', '2mwrQbbmmMg', 46, 153, NULL);
INSERT INTO 'dancevideo' VALUES (7370, '2020-07-06 12:19:10.791832+00', '2020-07-06 21:04:12.831358+00', 11527, 1, 1645, '', 'D', 'From a U3A christmas party - with camera constantly moving between sets.', 1, 1, 'Y', 'J6bGl5XaiGA', 139, 235, NULL);
INSERT INTO 'dancevideo' VALUES (7372, '2020-07-06 12:31:49.749753+00', '2020-07-06 21:04:22.67301+00', 10701, 1, 1645, '', 'D', 'Extract from U3A christmas party video - with the camera constantly moving around.', 1, 1, 'Y', 'J6bGl5XaiGA', 440, 563, NULL);
INSERT INTO 'dancevideo' VALUES (7402, '2020-07-08 21:34:04.178458+00', '2020-07-08 21:45:41.131086+00', 20042, 1, 1645, '', 'A', '', 1, 1, 'Y', 'XT-BTbAY61Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7377, '2020-07-06 19:26:09.515957+00', '2020-07-06 21:03:25.500085+00', 20040, 1, 1645, '', 'B', 'Helensburgh RSCDS class.', 1, 1, 'Y', 't-bPczzdtas', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7375, '2020-07-06 18:46:00.947533+00', '2020-07-06 21:03:31.209533+00', 14301, 1, 1645, '', 'A', 'Demo from RSCDS summer school.', 1, 1, 'Y', '5ReWc6aSbsw', 32, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7382, '2020-07-06 20:42:17.724826+00', '2020-07-06 21:03:41.913335+00', 15650, 2, 1645, '', 'A', 'Part of a demo by Aberdeen "City Moves". Good view from the top.', 1, 1, 'Y', 'ulVzU-L5oYU', 12, 162, NULL);
INSERT INTO 'dancevideo' VALUES (7384, '2020-07-06 21:03:16.73144+00', '2020-07-06 21:03:46.961352+00', 1969, 3, 1645, '', 'A', 'Part of a demo by Aberdeen "City Moves". View from the top of the set.', 1, 1, 'Y', 'ulVzU-L5oYU', 565, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7378, '2020-07-06 19:38:52.424119+00', '2020-07-06 21:03:56.991007+00', 17500, 2, 1645, '', 'B', 'This extract from an RSCDS archive video shows two variations of the dance, each danced twice (with walking step rather than skip-change). The first with RH/LH across in bars 17-24, the second with back to back and turn partner (as described in the e-crib).', 1, 1, 'Y', 'o2UfaYpMhao', 5, 170, NULL);
INSERT INTO 'dancevideo' VALUES (7380, '2020-07-06 20:02:14.395833+00', '2020-07-06 21:04:08.122633+00', 3485, 1, 1645, '', 'C', '', 1, 1, 'Y', 'yk-Osjyt6-E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7381, '2020-07-06 20:29:14.86116+00', '2020-07-06 21:04:17.87236+00', 10882, 1, 1645, '', 'D', 'Short glitch with the sound at the start.', 1, 1, 'Y', '-VGqUNBtQwE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7376, '2020-07-06 19:00:17.876382+00', '2020-07-06 21:04:28.042068+00', 14244, 2, 1645, '', 'C', 'This video starts around bar 5 (missing the first set and cross).', 1, 1, 'Y', 'yywMzb6RXr0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7383, '2020-07-06 20:57:30.706545+00', '2020-07-06 21:04:32.42817+00', 15644, 4, 1645, '', 'A', 'Part of a demo by Aberdeen "City Moves".', 1, 1, 'Y', 'ulVzU-L5oYU', 414, 564, NULL);
INSERT INTO 'dancevideo' VALUES (7379, '2020-07-06 19:42:50.583731+00', '2020-07-06 21:04:36.855979+00', 6959, 2, 1645, '', 'B', 'Instructional video from RSCDS archives.', 1, 1, 'Y', 'o2UfaYpMhao', 171, 295, NULL);
INSERT INTO 'dancevideo' VALUES (7385, '2020-07-06 21:07:38.068328+00', '2020-07-06 21:08:36.012008+00', 15649, 2, 1645, '', 'A', 'Part of a demo by Aberdeen "City Moves". Good view from the top of the set.', 1, 1, 'Y', 'ulVzU-L5oYU', 164, 413, NULL);
INSERT INTO 'dancevideo' VALUES (7391, '2020-07-08 19:46:08.284523+00', '2020-07-08 21:45:36.642662+00', 11777, 1, 1645, '', 'D', 'This clip starts with the dancing. The whole video begins with an introduction and the background of the dance, walkthroughs and a recap.', 1, 1, 'Y', 'jBjHGT5N10M', 205, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7390, '2020-07-08 19:40:54.956758+00', '2020-07-08 21:45:46.142671+00', 11013, 1, 1645, '', 'D', 'This clip starts with dancing. The whole video begins with an introduction, walk through and recap.', 1, 1, 'Y', 'ZmO0Ar3v-9U', 127, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7401, '2020-07-08 21:22:58.338175+00', '2020-07-08 21:45:51.382048+00', 19970, 1, 1645, '', 'A', '', 1, 1, 'Y', '89ON_d2NCOg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7397, '2020-07-08 20:41:27.933006+00', '2020-07-08 21:45:56.147581+00', 2698, 1, 1645, '', 'D', 'Danced at a Christmas party. This clip starts a couple of repeats into the dance.', 1, 1, 'Y', 'IQpzuxcN85w', 218, 326, NULL);
INSERT INTO 'dancevideo' VALUES (7389, '2020-07-08 19:34:36.793365+00', '2020-07-08 21:46:01.190058+00', 16880, 1, 1645, '', 'D', 'This clip starts with the dancing. The video has introductions followed by a walk through (from 1:33) and a recap.', 1, 1, 'Y', 'Jywaw8yBzWo', 207, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7398, '2020-07-08 20:47:29.827963+00', '2020-07-08 21:46:06.253202+00', 19319, 1, 1645, '', 'D', 'Danced at a Christmas party. This clip shows one fairly successful repeat with the camera mostly on one set.', 1, 1, 'Y', 'IQpzuxcN85w', 380, 412, NULL);
INSERT INTO 'dancevideo' VALUES (7388, '2020-07-08 19:27:20.494291+00', '2020-07-08 21:46:11.52368+00', 16877, 1, 1645, '', 'D', 'This clip starts with the dancing. The video starts with an introduction with the background to the dance, a walk through and a recap.', 1, 1, 'Y', 'EccX4mbZON0', 130, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7393, '2020-07-08 20:04:15.68417+00', '2020-07-08 21:46:16.187005+00', 5291, 1, 1645, '', 'D', 'Danced on location. This clips starts at the 3rd repeat, the first two having a few more glitches.', 1, 1, 'Y', 'WoUlWWEFso4', 75, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7400, '2020-07-08 21:17:22.825669+00', '2020-07-08 21:46:20.860924+00', 5308, 6, 1645, '', 'A', 'Twice through extract from a longer demo.', 1, 1, 'Y', 'PAQn7wha-GY', 160, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7392, '2020-07-08 19:55:05.324279+00', '2020-07-08 21:46:27.208584+00', 14953, 1, 1645, '', 'C', 'Danced on location with the bridge in the background. This clip shows the last repeat which is the clearest. The whole video starts with more views of the bridge but then moves between three sets during the first three repeats.', 1, 1, 'Y', 'U_hDfKyfWTs', 212, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7394, '2020-07-08 20:09:32.532827+00', '2020-07-08 21:46:32.209+00', 17993, 1, 1645, '', 'D', 'Danced on location.', 1, 1, 'Y', 'K5csmC9hDcc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7395, '2020-07-08 20:14:58.552517+00', '2020-07-08 21:46:37.778409+00', 8106, 1, 1645, '', 'D', 'Danced on location in front of Floors Castle, seat of the dukes of Roxburghe.', 1, 1, 'Y', 'g-L0anYM3NI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7396, '2020-07-08 20:23:23.494745+00', '2020-07-08 21:46:44.261678+00', 8110, 1, 1645, '', 'C', 'Danced on location.



From the youtube comments:  *Originally a hunting lodge for the kings and queens of Scotland it has been lived in for over 900 years.  Traquair is Scotland''s Oldest Inhabited House and it is the home of Catherine Maxwell Stuart, 21st Lady of Traquair with her family in the house today.*', 1, 1, 'Y', 'pX4yUpVu7oI', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7403, '2020-07-08 21:44:24.965192+00', '2020-07-08 21:46:49.141094+00', 20043, 1, 1645, '', 'A', '', 1, 1, 'Y', 'T8CBQ9t0CLs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7387, '2020-07-08 19:15:57.402631+00', '2020-07-08 21:46:54.511575+00', 19320, 1, 1645, '', 'D', 'Starts with one couple, then others join in.', 1, 1, 'Y', '3KYmpIEy9n8', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7386, '2020-07-08 19:07:22.231814+00', '2020-07-08 21:46:59.515611+00', 19331, 1, 1645, '', 'D', 'Start with one couple, at the back, then others joining in.', 1, 1, 'Y', 'eUEaiZ0tq7Q', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7399, '2020-07-08 21:03:42.00618+00', '2020-07-08 21:47:04.180113+00', 8082, 1, 1645, '', 'D', 'Dundee Christmas party.', 1, 1, 'Y', 'IQpzuxcN85w', 720, 855, NULL);
INSERT INTO 'dancevideo' VALUES (7408, '2020-07-11 20:10:20.271188+00', '2020-07-11 21:08:34.627038+00', 644, 1, 1645, '', 'C', '', 1, 1, 'Y', 'VtzIcLu8-GI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7415, '2020-07-11 21:06:28.498302+00', '2020-07-11 21:08:40.407144+00', 859, 2, 1645, '', 'B', 'Hong Kong SCD group. Once through. The video starts about half way through the opening reels.', 1, 1, 'Y', 'DQdIshTfFck', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7416, '2020-07-11 21:06:49.895634+00', '2020-07-11 21:08:45.713862+00', 900, 1, 1645, '', 'B', 'Dancing in the park in Toronto.', 1, 1, 'Y', '5UFZRL2rXwc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7405, '2020-07-11 19:48:12.688676+00', '2020-07-11 21:08:50.530647+00', 17549, 1, 1645, '', 'D', '', 1, 1, 'Y', 'SFllBZOXyxM', 29, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7406, '2020-07-11 19:56:34.417274+00', '2020-07-11 21:09:21.458992+00', 15427, 1, 1645, '', 'C', 'With teaching voiceover.', 1, 1, 'V', '89725498', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7407, '2020-07-11 20:03:32.987004+00', '2020-07-11 21:09:30.160385+00', 12630, 1, 1645, '', 'D', 'This clip starts with the dancing. The whole video starts with a walk through.', 1, 1, 'Y', 'PmZf3UDcWZ4', 69, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7417, '2020-07-11 21:06:54.329839+00', '2020-07-11 21:09:36.088945+00', 1424, 1, 1645, '', 'B', 'The video starts just into the dance. After the second repeat there is a short musical interlude which some sets take advantage of and others wait out.', 1, 1, 'Y', 'vCojF77h5-8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7409, '2020-07-11 20:37:19.307095+00', '2020-07-11 21:09:41.896518+00', 11514, 1, 1645, '', 'D', 'This clips starts after a few repeats, after the initially roving camera view has settled down for a while, with the 1st couple starting again from second place.', 1, 1, 'Y', '7ZPEAjIcEQM', 2840, 3222, NULL);
INSERT INTO 'dancevideo' VALUES (7410, '2020-07-11 20:40:54.858453+00', '2020-07-11 21:09:49.884862+00', 12522, 1, 1645, '', 'D', '', 1, 1, 'Y', 'FrpuF_kOOfQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7411, '2020-07-11 20:43:36.541164+00', '2020-07-11 21:09:55.411176+00', 19324, 1, 1645, '', 'D', '', 1, 1, 'Y', 'oIo3shH_Tqg', 25, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7412, '2020-07-11 20:49:21.218415+00', '2020-07-11 21:10:01.51742+00', 2156, 1, 1645, '', 'B', '', 1, 1, 'Y', 'LvLKwFVb1fo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7404, '2020-07-11 19:26:15.346326+00', '2020-07-11 21:10:07.713317+00', 2250, 5, 1645, '', 'X', '', 1, 1, 'Y', 'zatP2QZcuV8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7413, '2020-07-11 20:55:58.97609+00', '2020-07-11 21:10:13.638106+00', 19508, 1, 1645, '', 'C', 'This clip starts with the dancing. The video begins with a recap.', 1, 1, 'Y', 'HbLHLc1m0q8', 54, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7414, '2020-07-11 21:03:45.382118+00', '2020-07-11 21:10:20.436049+00', 3152, 2, 1645, '', 'B', 'Hong Kong SCD group. This clip starts with the first complete repeat on the video (1st couple from 2nd place).', 1, 1, 'Y', 'wFzyLxLrm34', 23, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7455, '2020-07-17 17:46:23.803024+00', '2020-07-17 18:18:50.639048+00', 2494, 4, 1645, '', 'A', 'Vienna branch Book 23 video project. Twice through (and a bit) with view from above, then again with view at eye height.', 1, 1, 'Y', '8dXrgjTatN4', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7418, '2020-07-11 21:18:45.185552+00', '2020-07-11 21:18:52.972923+00', 9054, 1, 1645, '', 'B', 'Twice in a 3 couple set as part of a longer demo. The last 4 bars are changed (switching the full and one and a half turns) so that all end on opposite sides and the 2nd repeat starts from the other end of the set.', 1, 1, 'Y', 'D9DPhS36HPw', 61, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7434, '2020-07-12 16:44:18.428665+00', '2020-07-12 16:49:40.683213+00', 12426, 8, 1645, '', 'B', 'Twice through as part of a longer demonstration. The last 8 bars of the 2nd repeat are replaced with a dance off to lead into the next dance in the display.', 1, 1, 'Y', '6fsLWYwK-VQ', 735, 804, NULL);
INSERT INTO 'dancevideo' VALUES (7425, '2020-07-12 15:37:01.289899+00', '2020-07-12 16:49:49.794927+00', 700, 2, 1645, '', 'A', 'Twice through as part of a longer demonstration. The final 8 bars of the 2nd repeat is replaced by a dance off.', 1, 1, 'Y', '6fsLWYwK-VQ', 75, 144, NULL);
INSERT INTO 'dancevideo' VALUES (7424, '2020-07-12 15:32:40.850793+00', '2020-07-12 16:49:55.800084+00', 7653, 1, 1645, '', 'A', 'Twice through as part of a long demonstration. The final circle of the 2nd repeat is replaced to lead into the next dance.', 1, 1, 'Y', '6fsLWYwK-VQ', 6, 76, NULL);
INSERT INTO 'dancevideo' VALUES (7431, '2020-07-12 16:33:43.810041+00', '2020-07-12 16:50:03.857024+00', 1582, 11, 1645, '', 'B', 'Twice through in a 2 couple set as part of a longer demonstration. This is very clear but misses the 3rd couple for the circle. The end of 2nd repeat is changed to lead into the next dance in the display.', 1, 1, 'Y', '6fsLWYwK-VQ', 670, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7423, '2020-07-12 15:27:43.454185+00', '2020-07-12 16:50:09.610637+00', 8726, 2, 1645, '', 'A', 'Three times through as part of a longer demonstration. The end of the 3rd repeat is adapted for a dance off and return for the next part of the demo.', 1, 1, 'Y', '6fsLWYwK-VQ', 903, 1003, NULL);
INSERT INTO 'dancevideo' VALUES (7428, '2020-07-12 16:05:44.117695+00', '2020-07-12 16:50:14.286676+00', 2250, 6, 1645, '', 'B', 'Twice through in a 3 couple set as part of a longer demonstration - with a few extra twirls. The poussette at the end of the 2nd repeat is extended with more couples to lead into the next dance.', 1, 1, 'Y', '6fsLWYwK-VQ', 389, 456, NULL);
INSERT INTO 'dancevideo' VALUES (7433, '2020-07-12 16:40:28.35763+00', '2020-07-12 16:50:18.823881+00', 2267, 12, 1645, '', 'B', 'Twice through as part of a longer demonstration. The end of the 2nd repeat is changed into a dance off.', 1, 1, 'Y', '6fsLWYwK-VQ', 456, 526, NULL);
INSERT INTO 'dancevideo' VALUES (7420, '2020-07-12 12:15:39.997724+00', '2020-07-12 16:50:24.42657+00', 20030, 1, 1645, '', 'B', 'Here with just one lonesome dancer (Robert Lockhart).



The dance may be also done with additional dancers but they would need to follow curvier paths across the centre in bars 1-8 and 17-24 than is shown here in order to avoid each other: dancer(s) and ghost(s) should all pass left shoulder in the centre.', 1, 1, 'Y', 'cGTVnR3Ir0c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7429, '2020-07-12 16:18:19.705059+00', '2020-07-12 16:50:30.064297+00', 12837, 2, 1645, '', 'B', 'Twice through as part of a longer demonstration. It is here danced in a 7 couple set rather than a 5 couple set.', 1, 1, 'Y', '6fsLWYwK-VQ', 1003, 1069, NULL);
INSERT INTO 'dancevideo' VALUES (7432, '2020-07-12 16:37:31.095785+00', '2020-07-12 16:50:35.768249+00', 4411, 8, 1645, '', 'A', 'Twice through as part of a longer demonstration.', 1, 1, 'Y', '6fsLWYwK-VQ', 541, 666, NULL);
INSERT INTO 'dancevideo' VALUES (7430, '2020-07-12 16:27:11.892051+00', '2020-07-12 16:50:40.338427+00', 5239, 9, 1645, '', 'B', 'Twice through as the last part of a longer demonstration. The first repeat is standard, the second has both couples dancing throughout. The complete demonstration then ends with circles.', 1, 1, 'Y', '6fsLWYwK-VQ', 1075, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7426, '2020-07-12 15:45:08.096858+00', '2020-07-12 16:50:45.0553+00', 7935, 2, 1645, '', 'B', 'Twice through in two back to back sets, joined at the bottom as part of a longer demonstration. There is some extra progression (exchange of 4th couple) between the two repeats and the end of the 2nd repeat is replaced by a circle leading into the next dance in the demonstration,', 1, 1, 'Y', '6fsLWYwK-VQ', 152, 257, NULL);
INSERT INTO 'dancevideo' VALUES (7421, '2020-07-12 12:36:22.754788+00', '2020-07-12 16:50:49.526385+00', 20045, 1, 1645, '', 'B', '', 1, 1, 'Y', 'JfbEliJL9yE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7427, '2020-07-12 16:00:23.27966+00', '2020-07-12 16:50:57.653569+00', 15675, 1, 1645, '', 'A', 'Once through as part of a longer demonstration. This complete repeat is preceded by about 3/4 of the dance starting from 4:24 (missing the first 8 bars).', 1, 1, 'Y', '6fsLWYwK-VQ', 313, 377, NULL);
INSERT INTO 'dancevideo' VALUES (7422, '2020-07-12 14:52:06.166601+00', '2020-07-12 16:51:03.196156+00', 20047, 1, 1645, '', 'B', 'Twice through as part of a longer demonstration.', 1, 1, 'Y', '4cQ-vaS3Nsc', 79, 209, NULL);
INSERT INTO 'dancevideo' VALUES (7419, '2020-07-12 11:22:58.866863+00', '2020-07-12 16:51:09.835811+00', 12694, 1, 1645, '', 'C', 'Last two repeats (from Hamilton and Clydesdale Pitlochry Weekend).', 1, 1, 'Y', '7K48UW6AKXA', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7435, '2020-07-13 17:04:10.134317+00', '2020-07-13 17:04:21.540585+00', 14667, 1, 1645, '', 'X', 'NB  men are rectangles and women ovals.', 1, 1, 'Y', 'pI_AMyRAGdA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7439, '2020-07-13 21:20:41.709057+00', '2020-07-14 08:41:49.543854+00', 11678, 1, 1645, '', 'B', '', 1, 1, 'Y', 'cBT-AiOr6ug', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7440, '2020-07-13 21:34:10.658339+00', '2020-07-14 08:41:55.06584+00', 12253, 1, 1645, '', 'B', 'Clear, though one or two of the turns are with the unexpected hand.', 1, 1, 'Y', '1ibSnWO39TY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7438, '2020-07-13 21:06:59.984152+00', '2020-07-14 08:41:59.9756+00', 12882, 1, 1645, '', 'B', 'Last two repeats (the video starts a little into the first repeat). The reels in the second repeat (first in this clip) should be mirror reels as in the last repeat.', 1, 1, 'Y', 'cNglytMMtqE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7437, '2020-07-13 19:55:56.470618+00', '2020-07-14 08:42:04.649464+00', 4052, 1, 1645, '', 'D', '', 1, 1, 'Y', 'o6HkckkvLMI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7436, '2020-07-13 19:45:34.553254+00', '2020-07-14 08:42:09.117532+00', 8699, 1, 1645, '', 'C', '', 1, 1, 'Y', '8UVy_XACHlk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7441, '2020-07-13 22:16:55.89117+00', '2020-07-14 08:42:15.659638+00', 6029, 1, 1645, '', 'A', 'Demonstration at St Andrews summer school 1995. The video starts about 2 bars into the dance.', 1, 1, 'Y', 'USNYectlD0k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7445, '2020-07-14 20:47:34.070672+00', '2020-07-14 21:00:38.918541+00', 14738, 6, 1645, '', 'A', 'Once through as part of Newcastle RSCDS display at the 2019 Newcastle festival.', 1, 1, 'Y', '4Lx9rAcJ6RA', 199, 262, NULL);
INSERT INTO 'dancevideo' VALUES (7443, '2020-07-14 20:32:00.993665+00', '2020-07-14 21:00:44.007949+00', 9332, 2, 1645, '', 'A', 'Part of Newcastle RSCDS display at the 2019 Newcastle festival. The first 32 bars is done in a single set. The rest of the dance is continued with extra dancers reformed into two sets. The end of the final circle is adapted to lead into the next dance in the demo.', 1, 1, 'Y', '4Lx9rAcJ6RA', 37, 138, NULL);
INSERT INTO 'dancevideo' VALUES (7446, '2020-07-14 20:58:50.991784+00', '2020-07-14 21:00:48.550256+00', 14336, 1, 1645, '', 'A', 'Once through as part of Newcastle RSCDS display at the 2019 Newcastle festival. The last 4 bars are adapted to lead into the next dance in the demo.', 1, 1, 'Y', '4Lx9rAcJ6RA', 298, 333, NULL);
INSERT INTO 'dancevideo' VALUES (7442, '2020-07-14 19:46:22.107483+00', '2020-07-14 21:00:53.225793+00', 11284, 6, 1645, '', 'A', 'Newcastle festival 2017: Newcastle RSCDS.', 1, 1, 'Y', 'tmcE0ttJBoQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7444, '2020-07-14 20:43:08.918463+00', '2020-07-14 21:00:58.169617+00', 17700, 1, 1645, '', 'A', 'Once through as part of Newcastle RSCDS display at the 2019 Newcastle festival.', 1, 1, 'Y', '4Lx9rAcJ6RA', 137, 191, NULL);
INSERT INTO 'dancevideo' VALUES (7447, '2020-07-16 23:38:39.764076+00', '2020-07-16 23:40:15.994803+00', 20051, 1, 1645, '', 'C', 'Rosedale childrens'' workshop, Toronto.', 1, 1, 'Y', 'vNwUmaMwTXA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7448, '2020-07-16 23:39:29.429+00', '2020-07-16 23:40:21.140721+00', 20050, 1, 1645, '', 'A', '', 1, 1, 'Y', 'gxTTlofkvjQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7450, '2020-07-17 16:02:06.266062+00', '2020-07-17 18:18:36.304294+00', 1469, 4, 1645, '', 'A', 'Vienna branch video project. Twice through (and a bit to show progression into 3rd time) with view from above, then again with view at eye height.', 1, 1, 'Y', 'TCvf41yRc_I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7451, '2020-07-17 17:06:12.861687+00', '2020-07-17 18:19:13.035606+00', 11189, 13, 1645, '', 'B', 'Practise session for a demo (taught by Anselm Lingnau).', 1, 1, 'Y', 'Wab3nv1PjZU', 120, 214, NULL);
INSERT INTO 'dancevideo' VALUES (7502, '2020-07-26 09:49:26.426632+00', '2020-07-26 11:01:57.607335+00', 3788, 5, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 1600, 1815, NULL);
INSERT INTO 'dancevideo' VALUES (7498, '2020-07-26 09:24:09.81178+00', '2020-07-26 11:02:57.324353+00', 3862, 5, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 992, 1119, NULL);
INSERT INTO 'dancevideo' VALUES (7500, '2020-07-26 09:35:24.948654+00', '2020-07-26 11:03:46.67642+00', 4511, 5, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 1274, 1425, NULL);
INSERT INTO 'dancevideo' VALUES (7501, '2020-07-26 09:44:36.193262+00', '2020-07-26 11:04:29.684705+00', 4759, 3, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 1440, 1585, NULL);
INSERT INTO 'dancevideo' VALUES (7465, '2020-07-17 23:52:13.201733+00', '2020-07-18 12:32:26.611711+00', 195, 1, 1645, '', 'D', '', 1, 1, 'Y', 'yOJ0npXnDvk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7449, '2020-07-17 15:53:38.637054+00', '2020-07-17 18:18:31.043702+00', 289, 2, 1645, '', 'A', 'Vienna branch Book 23 video project. Complete dance with view from above, then repeat with view at eye height.', 1, 1, 'Y', '0KoWtn5X-6M', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7454, '2020-07-17 17:42:38.771493+00', '2020-07-17 18:18:40.677211+00', 1588, 2, 1645, '', 'A', 'Vienna branch Book 23 video project.  Twice through (and a bit) with view from above, then again with view at eye height.', 1, 1, 'Y', 'hpvLEnkiX0E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7461, '2020-07-17 18:09:34.853677+00', '2020-07-17 18:18:45.592326+00', 2158, 4, 1645, '', 'A', 'Vienna branch video project. Four times with view from above, then repeat with view at eye height.', 1, 1, 'Y', 'uJejhhRAQh4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7456, '2020-07-17 17:50:23.02725+00', '2020-07-17 18:18:55.402683+00', 2562, 5, 1645, '', 'A', 'Vienna branch Book 23 video project. Complete dance with view from above, then repeat with view at eye height.', 1, 1, 'Y', 'cnsxUn1DvhU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7462, '2020-07-17 18:15:08.974505+00', '2020-07-17 18:18:59.74991+00', 2868, 1, 1645, '', 'A', 'Vienna branch video project. Twice through (and a bit) with view from above, then again with view at eye height', 1, 1, 'Y', 'GlImLI8CEJ0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7457, '2020-07-17 17:54:27.636867+00', '2020-07-17 18:19:04.166557+00', 3788, 4, 1645, '', 'A', 'Vienna branch Book 23 video project. Twice through (and a bit) with view from above, then again with view at eye height.', 1, 1, 'Y', 'g-MNOlqFzvY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7459, '2020-07-17 18:02:01.746815+00', '2020-07-17 18:19:17.244712+00', 5543, 2, 1645, '', 'A', 'Vienna branch Book 23 video project. Twice through (and a bit) with view from above, then again with view at eye height.', 1, 1, 'Y', '9sXsdXbOkuU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7458, '2020-07-17 17:59:03.602285+00', '2020-07-17 18:19:22.67615+00', 5765, 2, 1645, '', 'A', 'Vienna branch Book 23 video project. Twice through (and a bit) with view from above, then again with view at eye height.', 1, 1, 'Y', 'MIdbOdiC_m4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7453, '2020-07-17 17:19:47.35792+00', '2020-07-17 18:19:27.563447+00', 13676, 1, 1645, '', 'B', 'Once through, here in 2 couple sets arranged round the room instead of longwise. Extract from a demo practise session in St Petersburg (taught by Anselm Lingnau). The final Knot is adapted to lead into the next dance (with some couples dancing off).', 1, 1, 'Y', 'Wab3nv1PjZU', 59, 120, NULL);
INSERT INTO 'dancevideo' VALUES (7463, '2020-07-17 18:18:23.649541+00', '2020-07-17 18:19:32.182203+00', 6271, 5, 1645, '', 'A', 'Vienna branch video project. Complete dance with view from above, then repeat with view at eye height.', 1, 1, 'Y', '9iQzHSfjnWs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7460, '2020-07-17 18:05:58.452976+00', '2020-07-17 18:19:36.296431+00', 6420, 4, 1645, '', 'A', 'Vienna branch Book 23 video project. Complete dance with view from above, then repeat with view at eye height.', 1, 1, 'Y', 'MOWSIBcAvVk', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7480, '2020-07-18 12:20:51.816784+00', '2020-07-18 12:32:35.776759+00', 753, 6, 1645, '', 'B', 'Urals Tatar Tartan 2018.', 1, 1, 'Y', 'GtQzbKRQj1g', 0, 199, NULL);
INSERT INTO 'dancevideo' VALUES (7476, '2020-07-18 11:34:46.755155+00', '2020-07-18 12:32:41.370369+00', 1315, 4, 1645, '', 'A', 'Urals Dream Team 2018. Three times in a 3 couple set.', 1, 1, 'Y', '6vz33dZ3X3Q', 0, 196, NULL);
INSERT INTO 'dancevideo' VALUES (7478, '2020-07-18 12:08:16.418616+00', '2020-07-18 12:32:45.617148+00', 14239, 2, 1645, '', 'B', 'Urals Lowland children 2018.', 1, 1, 'Y', 'Ej_lonRXPPQ', 221, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7473, '2020-07-18 11:00:08.120041+00', '2020-07-18 12:32:50.038063+00', 8047, 2, 1645, '', 'C', 'Urals 2018. Generlly good dancing albeit with a few hesitations. The camera is a bit close. The even numbered repeats are clearer.', 1, 1, 'Y', '1za6JK8vKjA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7475, '2020-07-18 11:11:47.613474+00', '2020-07-18 12:32:54.379999+00', 2388, 2, 1645, '', 'D', 'Urals 2018.', 1, 1, 'Y', 'TkQVObSdmsM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7467, '2020-07-18 00:06:52.599022+00', '2020-07-18 12:33:02.926743+00', 16211, 1, 1645, '', 'C', 'The first repeat is slightly out of the camera view but subsequent repeats are clearer.', 1, 1, 'Y', 'S9ETD7mstrg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7466, '2020-07-17 23:56:40.815233+00', '2020-07-18 12:33:07.085344+00', 3416, 2, 1645, '', 'D', '', 1, 1, 'Y', 'HPCjHI03cYE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7479, '2020-07-18 12:20:41.423028+00', '2020-07-18 12:33:13.443966+00', 3594, 7, 1645, '', 'B', 'Urals Tatar Tartan 2018.', 1, 1, 'Y', 'GtQzbKRQj1g', 213, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7469, '2020-07-18 09:54:45.078078+00', '2020-07-18 12:33:17.76066+00', 20052, 1, 1645, '', 'C', 'From a masterclass taught in Kazan, Russia by the deviser. There are a few glitches in the Inveran reels.', 1, 1, 'Y', '1OzYsfYHcLg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7477, '2020-07-18 12:07:33.255939+00', '2020-07-18 12:33:26.850793+00', 5889, 4, 1645, '', 'B', 'Urals Lowland children 2018.', 1, 1, 'Y', 'Ej_lonRXPPQ', 0, 197, NULL);
INSERT INTO 'dancevideo' VALUES (7468, '2020-07-18 09:40:33.532626+00', '2020-07-18 12:33:31.298433+00', 17893, 3, 1645, '', 'B', 'Danced by young Russians near the Urals. Good dancing but the camera view is between two lines of sets without a complete view of either.', 1, 1, 'Y', 'b3ZbSLXJ9-g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7470, '2020-07-18 10:18:39.792768+00', '2020-07-18 12:33:37.217289+00', 5934, 3, 1645, '', 'C', 'This clip starts at the 3rd time through. The final change of places on the side should be with the left hand but is often done right hand here.', 1, 1, 'Y', 'XBydRsz19ag', 69, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7472, '2020-07-18 10:39:49.441683+00', '2020-07-18 12:33:43.132989+00', 16508, 3, 1645, '', 'C', 'Good dancing but the camera view is between two lines of sets with neither of them completely in view so its not always easy to follow the dance.', 1, 1, 'Y', 'FabuzCHwWBo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7482, '2020-07-22 00:40:03.694691+00', '2020-07-22 00:40:03.694691+00', 56, 4, 1296, '', 'X', '''Airie Bennan'' is a 32 bar jig for 5 couples.', 1, 1, 'Y', 'trvK5foTY5M', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7483, '2020-07-22 00:40:03.737086+00', '2020-07-22 00:40:03.737086+00', 4291, 3, 1296, '', 'X', '''The Meeting of the Waters'' is a 48 bar reel for 3 couples.', 1, 1, 'Y', 'Ev_RdzF2Pmw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7484, '2020-07-22 00:40:03.761216+00', '2020-07-22 00:40:03.761216+00', 10653, 2, 1296, '', 'X', '''Mr Iain Stuart Robertson'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', '_2gNkQuga3w', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5543, '2019-12-26 11:04:02.51375+00', '2020-07-23 10:26:36.459194+00', 17420, 1, 274, '', 'A', 'RSCDS Vancouver Demonstration Team (twice through).



This is a 48 bar dance but the music used here seems to be three repeats of 32 bars.', 1, 1, 'Y', 'XdnCeTkPIdI', 0, 105, NULL);
INSERT INTO 'dancevideo' VALUES (7485, '2020-07-24 00:40:03.032412+00', '2020-07-24 00:40:03.032412+00', 5260, 4, 1296, '', 'X', '''The Pines of Pitlochry'' is a 48 bar jig for 3 couples.', 1, 1, 'Y', 'TsBRbCjDI5k', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7486, '2020-07-24 00:40:03.06165+00', '2020-07-24 00:40:03.06165+00', 5326, 5, 1296, '', 'X', '''Portnacraig'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'ej54w9OaDA4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7487, '2020-07-24 18:32:26.26697+00', '2020-07-24 18:32:51.491427+00', 20048, 1, 202, '', 'C', '', 1, 1, 'Y', '10d-S5vgH3c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7489, '2020-07-25 21:35:54.745367+00', '2020-07-25 22:24:42.268101+00', 14691, 1, 1645, '', 'D', 'Milan SCD ceilidh. A rather narrow view which switches between sets.', 1, 1, 'Y', 'QlT0urYBT9g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7490, '2020-07-25 22:14:24.57378+00', '2020-07-25 22:24:48.748487+00', 15428, 1, 1645, '', 'B', 'Teaching demo with voice over which helps maintain continuity when the camera view shifts.', 1, 1, 'V', '89725497', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7491, '2020-07-25 22:22:40.56816+00', '2020-07-25 22:25:04.387155+00', 3424, 1, 1645, '', 'B', 'Twice through.', 1, 1, 'Y', 'JnkQZ_SoOT8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7488, '2020-07-25 21:30:04.592381+00', '2020-07-25 22:27:00.376652+00', 6051, 3, 1645, '', 'C', 'This is a 5 couple dance normally danced 5 times but here it is done no less than 16 times in a 7 couple set by an enthusiastic Russian group (Pas de Côté club). Though only about 5 couples are in view at a time.', 1, 1, 'Y', '1_qr85yinM8', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7494, '2020-07-26 08:48:04.302196+00', '2020-07-26 10:56:45.199361+00', 2661, 3, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 418, 567, NULL);
INSERT INTO 'dancevideo' VALUES (7492, '2020-07-26 08:30:52.409821+00', '2020-07-26 10:56:53.244275+00', 2812, 3, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 25, 164, NULL);
INSERT INTO 'dancevideo' VALUES (7493, '2020-07-26 08:43:33.95904+00', '2020-07-26 10:58:50.126874+00', 3284, 2, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 180, 400, NULL);
INSERT INTO 'dancevideo' VALUES (7505, '2020-07-26 10:10:46.374424+00', '2020-07-26 10:30:54.466884+00', 1163, 5, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 2110, 2198, NULL);
INSERT INTO 'dancevideo' VALUES (7495, '2020-07-26 08:53:03.937999+00', '2020-07-26 10:54:12.627147+00', 2140, 1, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 584, 730, NULL);
INSERT INTO 'dancevideo' VALUES (7496, '2020-07-26 09:12:05.30606+00', '2020-07-26 10:55:01.920221+00', 2436, 1, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 748, 849, NULL);
INSERT INTO 'dancevideo' VALUES (7508, '2020-07-26 10:28:46.786034+00', '2020-07-26 10:55:09.798248+00', 2498, 7, 1645, '', 'A', '1996 RSCDS teaching video. Switches to a view from above at 44:41 and back down at 47:37.', 1, 1, 'Y', 'S6fvlgshpkA', 2483, 2983, NULL);
INSERT INTO 'dancevideo' VALUES (7499, '2020-07-26 09:27:58.76013+00', '2020-07-26 10:58:41.130997+00', 2962, 1, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 1134, 1260, NULL);
INSERT INTO 'dancevideo' VALUES (7504, '2020-07-26 10:07:33.407449+00', '2020-07-26 11:01:04.694198+00', 3685, 2, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 1949, 2094, NULL);
INSERT INTO 'dancevideo' VALUES (7503, '2020-07-26 10:03:41.402497+00', '2020-07-26 11:05:12.198073+00', 4767, 2, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 1830, 1926, NULL);
INSERT INTO 'dancevideo' VALUES (7507, '2020-07-26 10:17:53.377547+00', '2020-07-26 11:05:57.110977+00', 4803, 5, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 2379, 2470, NULL);
INSERT INTO 'dancevideo' VALUES (7506, '2020-07-26 10:14:20.919598+00', '2020-07-26 11:06:35.336032+00', 6116, 2, 1645, '', 'A', '1996 RSCDS teaching video.', 1, 1, 'Y', 'S6fvlgshpkA', 2212, 2363, NULL);
INSERT INTO 'dancevideo' VALUES (7519, '2020-07-26 19:44:41.406751+00', '2020-07-26 19:45:03.258196+00', 20055, 1, 1645, '', 'C', 'RSCDS Hamilton and Clydesdale winter dance.', 1, 1, 'Y', 'A2tnfX8k2MQ', 2480, 2617, NULL);
INSERT INTO 'dancevideo' VALUES (7520, '2020-07-27 11:19:07.380682+00', '2020-07-27 12:30:54.419569+00', 16803, 3, 2824, '', 'C', '', 1, 1, 'Y', '6zoLi_CIMf8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7521, '2020-07-27 11:22:53.052558+00', '2020-07-27 12:34:29.643212+00', 18383, 3, 2824, '', 'D', 'Paris Spring Fling 2019, 2 and a bit times through the dance', 1, 1, 'Y', '8JmOuwdRBd4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7522, '2020-07-27 12:21:59.53399+00', '2020-07-27 12:35:36.934741+00', 19166, 2, 2824, '', 'C', 'Paris Spring Fling 2019 - once through, last 4 bars missing', 1, 1, 'Y', 'v_9PAWPqu3Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7523, '2020-07-27 12:25:11.072926+00', '2020-07-27 12:37:06.298131+00', 9104, 2, 2824, '', 'D', 'Paris Spring Fling 2019 - 2 and a bit times through the dance', 1, 1, 'Y', 'WlyHRlVcncw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7513, '2020-07-26 11:48:43.315175+00', '2020-07-27 12:40:05.539848+00', 216, 1, 1645, '', 'A', 'Extract from a longer RSCDS archive compilation. This clip starts with a short introduction. The performance starts at 27:28', 1, 1, 'Y', 'z_uWUfIGZsY', 1629, 1827, NULL);
INSERT INTO 'dancevideo' VALUES (7510, '2020-07-26 11:31:19.5409+00', '2020-07-27 12:40:57.784805+00', 8753, 2, 1645, '', 'A', 'Danced by Janet Johnstone. Extract from a longer RSCDS archive compilation. This clip starts with a short introduction.', 1, 1, 'Y', 'z_uWUfIGZsY', 689, 857, NULL);
INSERT INTO 'dancevideo' VALUES (7517, '2020-07-26 12:03:24.720404+00', '2020-07-27 12:42:05.631197+00', 12177, 2, 1645, '', 'A', 'Danced by Derek Haynes. Extract from a longer RSCDS archive compilation. This clip starts with a short introduction. The dancing starts at 39:17.', 1, 1, 'Y', 'z_uWUfIGZsY', 2337, 2517, NULL);
INSERT INTO 'dancevideo' VALUES (7515, '2020-07-26 11:57:05.345758+00', '2020-07-27 12:42:53.760006+00', 5459, 3, 1645, '', 'A', 'Danced by John Wilkinson. Extract from a longer RSCDS archive compilation. This clip starts with a short introduction. The dancing starts at 34:26.', 1, 1, 'Y', 'z_uWUfIGZsY', 2040, 2202, NULL);
INSERT INTO 'dancevideo' VALUES (7514, '2020-07-26 11:53:55.333113+00', '2020-07-27 12:44:23.108028+00', 14303, 1, 1645, '', 'A', 'Danced by Janet Johnstone. Extract from a longer RSCDS archive compilation. This clip starts with a short introduction. The performance starts at 30:44 with a demonstration of the steps.', 1, 1, 'Y', 'z_uWUfIGZsY', 1829, 2039, NULL);
INSERT INTO 'dancevideo' VALUES (7526, '2020-07-27 20:49:22.424004+00', '2020-07-27 21:02:55.943244+00', 950, 2, 1645, '', 'A', 'Once through as part of the Newcastle RSCDS demo at the 2015 Newcastle festival. The last two bars are slightly adapted (advancing to the centre) to lead into the next dance. Sources seem to differ as to whether to touch hands during the reels.

', 1, 1, 'Y', 'uPCVWSMXLtQ', 213, 258, NULL);
INSERT INTO 'dancevideo' VALUES (7518, '2020-07-26 12:12:31.888926+00', '2020-07-27 12:44:48.336745+00', 2317, 8, 1645, '', 'A', 'Final extract from a longer RSCDS archive compilation. This clip starts with a short introduction, then a demonstration of various highland steps. The dance starts at 50:38.', 1, 1, 'Y', 'z_uWUfIGZsY', 2667, 3220, NULL);
INSERT INTO 'dancevideo' VALUES (7553, '2020-07-31 22:15:21.762798+00', '2020-07-31 23:19:14.066191+00', 4484, 8, 1645, '', 'D', 'Yokohama 2019. Charming family video with a very young girl being shepherded through the dance by other good dancers.', 1, 1, 'Y', 'lABdrZx46TM', 65, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7511, '2020-07-26 11:36:16.502993+00', '2020-07-27 12:47:11.184027+00', 2498, 8, 1645, '', 'A', 'Extract from a longer RSCDS archive compilation. Before the dance, from 14:31, there is a demonstration of a variety of possible highland steps.', 1, 1, 'Y', 'z_uWUfIGZsY', 1077, 1271, NULL);
INSERT INTO 'dancevideo' VALUES (7527, '2020-07-27 21:02:05.030988+00', '2020-07-27 21:03:09.403854+00', 11365, 1, 1645, '', 'B', 'Twice though as part of the Newcastle RSCDS demo at the 2015 Newcastle festival.  The first time as expected in a 5 couple set though the last 6 bars are adapted to repeat the dance in a 7 couple set on the other axis.', 1, 1, 'Y', 'uPCVWSMXLtQ', 276, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7512, '2020-07-26 11:43:19.245296+00', '2020-07-27 12:49:23.971613+00', 15779, 2, 1645, '', 'A', 'Danced by Derek Haynes. Extract from a longer RSCDS archive compilation. This clip starts with a short introduction. The dancing starts at 25:44.', 1, 1, 'Y', 'z_uWUfIGZsY', 1525, 1627, NULL);
INSERT INTO 'dancevideo' VALUES (7516, '2020-07-26 12:00:30.147983+00', '2020-07-27 12:50:03.34111+00', 8750, 1, 1645, '', 'A', 'Danced by Janet Johnstone. Extract from a longer RSCDS archive compilation. This clip starts with a short introduction. The dancing starts at 37:00.', 1, 1, 'Y', 'z_uWUfIGZsY', 2203, 2335, NULL);
INSERT INTO 'dancevideo' VALUES (7509, '2020-07-26 11:27:56.839109+00', '2020-07-27 12:50:27.359468+00', 8745, 1, 1645, '', 'A', 'Danced by Derek Haynes. Extract from a longer RSCDS archive compilation. This clip starts with a short introduction. The dancing starts at 9:56.', 1, 1, 'Y', 'z_uWUfIGZsY', 569, 688, NULL);
INSERT INTO 'dancevideo' VALUES (7525, '2020-07-27 20:35:24.708601+00', '2020-07-27 21:23:18.603268+00', 6196, 2, 1645, '', 'A', 'Once through as part of the Newcastle RSCDS demo at the 2015 Newcastle festival.', 1, 1, 'Y', 'uPCVWSMXLtQ', 137, 198, NULL);
INSERT INTO 'dancevideo' VALUES (7524, '2020-07-27 20:26:54.751158+00', '2020-07-27 21:22:02.699939+00', 4928, 2, 1645, '', 'A', 'Once through as part of the Newcastle RSCDS demo at the 2015 Newcastle festival. The top of the right hand set is out of view for the first couple of bars. To lead into the next dance 1st couple cross LH at the end instead of RH.', 1, 1, 'Y', 'uPCVWSMXLtQ', 75, 128, NULL);
INSERT INTO 'dancevideo' VALUES (7528, '2020-07-27 21:44:23.677572+00', '2020-07-27 21:44:57.340686+00', 2536, 1, 1645, '', 'B', 'Once through as part of the Newcastle RSCDS display at the 2017 Newcastle festival. 2nd man is here setting for all of 9-16 instead of just 21-24. The last 4 bars are adapted to lead into the next dance.', 1, 1, 'Y', 'o1Tc9yQZcKM', 234, 269, NULL);
INSERT INTO 'dancevideo' VALUES (7531, '2020-07-27 22:55:21.421483+00', '2020-07-28 23:12:14.135845+00', 2805, 1, 1645, '', 'C', 'Excellent dancing but this extract from the Airyhall display at the 2020 Newcastle festival only shows the first 24 bars of the dance - in two back to back 3 couple sets (joined in 3rd place). The left hand set dances a mirror version, turning LH into allemande hold for an inverted allemande the end of which is adapted to lead into the next dance. The last 8 bars are omitted.', 1, 1, 'Y', '7ECBpsRBR1I', 209, 236, NULL);
INSERT INTO 'dancevideo' VALUES (7534, '2020-07-28 21:20:47.63137+00', '2020-07-29 16:19:11.777628+00', 19903, 1, 1645, '', 'C', 'Deer O''Dale Dance School (Ufa, Russia). Last dance before lockdown. The deviser notes:

*In the first repeat, the transition from the fugue into the reel across is not really correct. Repeat 2 and repeat 3 (even more) show the correct transition. To make the entry into the reel easier for second lady, second couple should be ready to face in at the end of bar 16 being on the outside of the set.*', 1, 1, 'Y', 'o0Hz2b4XduA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7530, '2020-07-27 22:37:54.177117+00', '2020-07-28 23:13:40.961382+00', 9213, 1, 1645, '', 'B', 'Once through as part of the Airyhall display at the 2020 Newcastle festival. The end is adapted to lead into the next dance.', 1, 1, 'Y', '7ECBpsRBR1I', 144, 209, NULL);
INSERT INTO 'dancevideo' VALUES (7533, '2020-07-28 11:01:52.122704+00', '2020-07-28 21:22:20.470508+00', 3941, 7, 1645, '', 'A', 'Once through as part of the London branch display at the 2013 Newcastle festival.', 1, 1, 'Y', 'ukQgBPv9Nb0', 198, 243, NULL);
INSERT INTO 'dancevideo' VALUES (7532, '2020-07-28 10:57:48.359771+00', '2020-07-28 21:23:17.020409+00', 6143, 1, 1645, '', 'A', 'Once through as part of the London branch display at the 2013 Newcastle festival. The last 4 bars are adapted to lead into the next dance.', 1, 1, 'Y', 'ukQgBPv9Nb0', 162, 198, NULL);
INSERT INTO 'dancevideo' VALUES (7529, '2020-07-27 22:25:19.863273+00', '2020-07-28 23:10:58.815487+00', 11780, 1, 1645, '', 'C', 'Once through (in a modified version) as part of the Airyhall Display at the 2020 Newcastle festival. In bars 19-20 3rd couple cast off to 4th place instead of 5th place (underlined in the instructions!). The LH across of bars 29-32 is completely replaced by rearrangement of the 5 couple set into two 4 couple sets with extra dancers so the final circles are two 8 hands round and back instead of 10 hands. Excellent dancing but not so suitable for learning the dance.', 1, 1, 'Y', '7ECBpsRBR1I', 100, 146, NULL);
INSERT INTO 'dancevideo' VALUES (7537, '2020-07-28 22:20:12.376444+00', '2020-07-28 23:14:36.396434+00', 9224, 2, 1645, '', 'B', 'SCD group Hong Kong. Three times through, starting about bar 2.', 1, 1, 'Y', '12-WkD6jjOE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7536, '2020-07-28 22:16:18.339744+00', '2020-07-28 23:14:51.558034+00', 13360, 2, 1645, '', 'B', 'SCD group Hong Kong. Twice through.', 1, 1, 'Y', '0v15LCLC2zk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7538, '2020-07-28 22:41:13.832588+00', '2020-07-28 23:14:57.900288+00', 5731, 2, 1645, '', 'B', 'SCD group Hong Kong. Twice through, first time with just the centre couples.', 1, 1, 'Y', 'Qr_Btx2O9u4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7539, '2020-07-29 20:05:29.86273+00', '2020-07-29 22:13:51.18295+00', 20057, 1, 1645, '', 'A', 'The dancing, which starts at 2:45, is preceded by a short introduction.', 1, 1, 'Y', 'IhPlSw8k76c', 136, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7544, '2020-07-29 22:06:46.905331+00', '2020-07-29 22:13:58.764145+00', 1994, 1, 1645, '', 'A', 'Twice through as the first part of a display by the RSCDS London Demonstration Team at Porchester Hall in 1991.



The database entry for this dance describes it as for 4 couples but the video has 6 couple sets.', 1, 1, 'Y', '_4QeQHVuQGE', 18, 128, NULL);
INSERT INTO 'dancevideo' VALUES (7542, '2020-07-29 21:23:50.235173+00', '2020-07-29 22:14:05.322252+00', 2135, 2, 1645, '', 'A', 'Second part of a London Branch demo from 1992.', 1, 1, 'Y', '07J-KeOfRfs', 250, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7541, '2020-07-29 21:22:46.023491+00', '2020-07-29 22:14:15.449253+00', 2581, 3, 1645, '', 'A', 'First part of a London Branch demo from 1992.', 1, 1, 'Y', '07J-KeOfRfs', 59, 250, NULL);
INSERT INTO 'dancevideo' VALUES (7543, '2020-07-29 21:41:19.661661+00', '2020-07-29 22:14:24.197754+00', 15781, 1, 1645, '', 'A', 'London Branch Demonstration Team at Porchester Hall in 1990. The performance of McKenzie of Seaforth is immediately followed (at 5:08) by Wild Geese (once through).', 1, 1, 'Y', 'y6IwGHAVx-w', 15, 308, NULL);
INSERT INTO 'dancevideo' VALUES (7540, '2020-07-29 21:03:28.271962+00', '2020-07-29 22:14:34.973668+00', 5882, 2, 1645, '', 'A', 'London Branch Demonstration Team, Ladies Team at Slough Arts Festival 1992.', 1, 1, 'Y', 'iD_v0OIDfv0', 248, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7545, '2020-07-30 20:16:07.140276+00', '2020-07-30 21:42:15.785342+00', 9086, 2, 1645, '', 'C', 'Westbury (Bristol) 2012.', 1, 1, 'Y', 'DbpF64eS_IY', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7546, '2020-07-30 20:42:29.160158+00', '2020-07-30 21:42:20.601082+00', 3636, 2, 1645, '', 'C', 'Westbury Scottish Club (Bristol) 2012.', 1, 1, 'Y', 'zZKT_ApNpoA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7547, '2020-07-30 20:56:15.087994+00', '2020-07-30 21:42:30.639428+00', 4227, 3, 1645, '', 'C', 'TAC Summer School 2019.', 1, 1, 'Y', '8hKZJRJ24J8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7550, '2020-07-30 21:29:22.914021+00', '2020-07-30 21:42:45.050844+00', 4680, 2, 1645, '', 'A', 'Corryvrechan Scottish Dance Display Team', 1, 1, 'Y', 'HpmVYrhSM-U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7548, '2020-07-30 21:07:40.902415+00', '2020-07-30 21:42:52.277207+00', 13460, 2, 1645, '', 'B', 'Naramata SCD Burns Night 2020. Twice through as part of a longer medley. On the 2nd time the 5th couple turn by mistake on bars 5-8.', 1, 1, 'Y', '1udfMeZJdwU', 100, 173, NULL);
INSERT INTO 'dancevideo' VALUES (7549, '2020-07-30 21:14:03.356829+00', '2020-07-30 21:42:59.620633+00', 5927, 4, 1645, '', 'B', 'Naramata SCD Burns Night 2020. Three times through.', 1, 1, 'Y', 'EWMtKV5dLs0', 28, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7551, '2020-07-31 20:29:32.246052+00', '2020-07-31 20:30:09.130546+00', 20058, 1, 202, '', 'C', '', 1, 1, 'Y', 'O3raSnbu-rY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7555, '2020-07-31 22:36:14.555287+00', '2020-07-31 23:17:59.127711+00', 9047, 1, 1645, '', 'B', 'Twice through demo from a "YY family christmas party" in Yokohama 2016.', 1, 1, 'Y', 'i0DjMJl1X88', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7559, '2020-07-31 23:08:49.909641+00', '2020-07-31 23:18:20.381549+00', 886, 1, 1645, '', 'B', 'Twice through demo from a "YY family christmas party" in Yokohama 2019.', 1, 1, 'Y', 'CYZAF4uerqc', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7560, '2020-07-31 23:12:33.22003+00', '2020-07-31 23:18:37.585041+00', 7360, 1, 1645, '', 'B', 'Twice through demo from a "YY family christmas party" in Yokohama 2018. This clip starts with the dancing which is preceded by a walkthrough.', 1, 1, 'Y', 'd_KlEoz9k2E', 113, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7554, '2020-07-31 22:25:04.415622+00', '2020-07-31 23:18:56.304769+00', 15239, 2, 1645, '', 'B', 'Twice through demo from a "YY family party" in Yokohama 2013. This clip starts with the dancing which is preceded by a walk through.', 1, 1, 'Y', '3yI-mGnqgTk', 123, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7592, '2020-09-30 15:11:04.800209+00', '2020-09-30 22:38:50.547264+00', 20088, 1, 2586, '', 'A', 'RSCDS Western Australia Branch.', 1, 1, 'Y', 'aU0lqVgAXls', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7552, '2020-07-31 22:08:16.852081+00', '2020-07-31 23:19:29.704943+00', 10077, 1, 1645, '', 'B', 'Once through from a "YY family party" (Yokohama 2015). This clip starts with the dancing. The first part of the video has a quick walkthrough.', 1, 1, 'Y', 'K3wlzDJGW74', 53, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7557, '2020-07-31 22:53:00.981169+00', '2020-07-31 23:19:53.817699+00', 13798, 1, 1645, '', 'B', 'Twice through demo from a "YY family christmas party" in Yokohama 2017. The instructions request the final poussette be done symmetrically on the centre line as in <<ddd:New Park>> whereas here it looks, from the camera angle, as if it is being done in the usual diagonal style.', 1, 1, 'Y', 'uQg-kT3sJpw', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7556, '2020-07-31 22:40:59.207602+00', '2020-07-31 23:20:15.889238+00', 5122, 1, 1645, '', 'B', 'Twice through demo from a "YY family christmas party" in Yokohama 2016.', 1, 1, 'Y', 'i7Timp6naCE', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7558, '2020-07-31 23:00:24.626975+00', '2020-07-31 23:20:33.019608+00', 17469, 2, 1645, '', 'B', 'Twice through demo from a "YY family christmas party" in Yokohama 2018. This clip starts with the dancing which is preceded by a walkthrough.', 1, 1, 'Y', '8eDUuBRfyaI', 76, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7562, '2020-08-02 17:56:10.994341+00', '2020-08-02 17:56:59.032104+00', 20060, 1, 1645, '', 'B', 'YY Family Demonstration, Yokohama 2014. Once through.', 1, 1, 'Y', 'BxEf-UhqFmc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7561, '2020-08-02 00:05:03.639176+00', '2020-08-02 07:33:17.765846+00', 17921, 1, 202, '', 'B', '', 1, 1, 'Y', 'i6OVesjcQbM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4356, '2019-03-10 13:09:54.991021+00', '2020-08-06 12:10:00.881865+00', 2544, 1, 2697, '', 'C', 'In the original instructions, the advance and retire of bars 15-16 should be across the set, towards and away from partner, not up and down the set as is done here. (The dancers may have been following an earlier version of the MiniCrib).', 1, 1, 'Y', 'WrLW1kBMXyo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7567, '2020-08-06 22:57:01.993413+00', '2020-08-06 22:58:21.136935+00', 10570, 2, 1645, '', 'C', 'Omaha Scottish Country Dancers of Nebraska, September 2014. The dancers here set from side to side instead of a back-step.', 1, 1, 'Y', 'KOw0RPUV7n8', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7565, '2020-08-06 22:44:48.002899+00', '2020-08-06 22:57:54.584817+00', 2388, 3, 1645, '', 'B', 'Twice through as part of the Williamsburg Scottish Festival SCD Demo 2011. ', 1, 1, 'Y', 'LSNATmEBOn4', 51, 120, NULL);
INSERT INTO 'dancevideo' VALUES (7566, '2020-08-06 22:48:43.994725+00', '2020-08-06 22:58:01.208286+00', 4209, 2, 1645, '', 'C', 'Twice through as part of the Williamsburg Scottish Festival SCD Demo 2011. ', 1, 1, 'Y', 'LSNATmEBOn4', 120, 243, NULL);
INSERT INTO 'dancevideo' VALUES (7564, '2020-08-06 22:39:31.441712+00', '2020-08-06 22:58:16.034234+00', 10570, 1, 1645, '', 'B', 'Williamsburg Scottish Festival SCD Demo 2011. Here danced with three couples. Twice through. The dancers here circle round and back at the end whereas other arrangements have circle to the left only.', 1, 1, 'Y', 'LSNATmEBOn4', 708, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7812, '2021-02-04 11:31:58.100344+00', '2021-02-04 11:33:06.422808+00', 4144, 2, 202, '', 'A', '', 1, 1, 'Y', 'o2z9P8yi3kY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7901, '2021-04-06 20:13:05.151233+00', '2021-04-06 20:24:59.224025+00', 2651, 2, 1645, '', 'C', 'Novosibirsk 2018.', 1, 1, 'Y', 'P7cM31torqg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8053, '2021-08-31 22:54:00.310676+00', '2021-09-01 00:30:10.36324+00', 6373, 4, 1645, '', 'B', 'Aberdeen Festival 2016.', 1, 1, 'Y', 'Hph4rNstpPc', 15, 278, NULL);
INSERT INTO 'dancevideo' VALUES (8056, '2021-09-02 10:10:02.422584+00', '2021-09-02 10:46:33.387373+00', 20323, 1, 1645, '', 'C', 'Méaudre reel club 2021.', 1, 1, 'Y', '53Mvj5wuQXU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7563, '2020-08-06 22:35:21.872582+00', '2020-08-06 22:57:29.460459+00', 1033, 2, 1645, '', 'C', 'Williamsburg Scottish Festival SCD Demo 2011. Good dancing but, as the youtube comments admit, an extra 8 bars have been added at bar 9 (between 4 hands round and the ladies chain) to make it an 80 bar dance instead of the expected 72.', 1, 1, 'Y', 'LSNATmEBOn4', 555, 707, NULL);
INSERT INTO 'dancevideo' VALUES (7294, '2020-06-03 21:07:24.101777+00', '2020-08-08 23:41:34.209453+00', 19898, 1, 197, '', 'B', 'Deer O''Dale Dance School from Ufa, Russia.

Video shows only one repetition', 1, 1, 'Y', 'kkhHlFukf4s', 6, 46, NULL);
INSERT INTO 'dancevideo' VALUES (7570, '2020-08-09 08:39:33.877541+00', '2020-08-09 08:41:45.547218+00', 20056, 2, 1645, '', 'B', 'RSCDS Hunter Valley Branch instructional video with one couple and 3 pairs of chairs. This clip just shows once through the first turn of the dance with 1st couple ending on opposite sides. The whole video begins with detailed teaching and walkthroughs. The 2nd turn starts from opposite sides. This is described in detail from 8:21 and danced from 11:02.', 1, 1, 'Y', 'eIic49dkXmg', 431, 501, NULL);
INSERT INTO 'dancevideo' VALUES (7571, '2020-08-09 10:15:55.091115+00', '2020-08-09 10:16:37.35482+00', 11629, 3, 202, '', 'D', '', 1, 1, 'Y', '5W6LnvdDzH0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7572, '2020-08-09 10:17:59.086083+00', '2020-08-09 10:18:42.026524+00', 7795, 4, 202, '', 'D', '', 1, 1, 'Y', 'BYaQOf59izk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7573, '2020-08-09 10:24:52.517847+00', '2020-08-09 10:28:00.7376+00', 5691, 1, 202, '', 'D', '', 1, 1, 'Y', 'FtgIhGTf81U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7568, '2020-08-07 09:53:39.347667+00', '2020-08-22 22:04:15.923145+00', 3561, 2, 1645, '', 'D', 'Dufftown dance club 2015. The version done here differs somewhat from the cribs and also includes interaction between neighbouring sets up and down the hall. This clip starts with the dancing. There is a walkthrough/recap of this version starting around 0:44.', 1, 1, 'Y', 'Q2w0Wc9pgOA', 107, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7574, '2020-08-22 20:45:42.289453+00', '2020-08-22 22:04:24.8115+00', 20071, 1, 1645, '', 'B', 'Part of a display by the RSCDS London Demonstration Team at Porchester Hall in 1991. The dancing is clearly dem quality but the choreography has been changed quite a bit, especially the last 8 bars, so is classed as "good". The sets are joined in the centre and alternately inverted. The video at least gives a good impression of the dance.', 1, 1, 'Y', '_4QeQHVuQGE', 185, 245, NULL);
INSERT INTO 'dancevideo' VALUES (7575, '2020-08-22 22:03:47.234646+00', '2020-08-22 22:04:31.361925+00', 848, 2, 1645, '', 'B', 'This performance by RSCDS Aberdeen is of half the central part of the dance: only two women and two men do the solo part.', 1, 1, 'Y', '0VUxkd315x4', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3364, '2017-12-12 17:32:35.789519+00', '2020-08-23 21:21:12.320549+00', 6177, 1, 10532, '', 'B', 'This clip is once through, filmed from the bottom of the set.', 1, 1, 'Y', 'KJx-8kWIHsA', 32, 68, NULL);
INSERT INTO 'dancevideo' VALUES (7577, '2020-08-26 16:03:07.010824+00', '2020-08-26 16:56:15.321235+00', 2394, 6, 3086, '', 'A', '', 1, 1, 'Y', '1tQfzYeR-V8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7578, '2020-08-26 19:02:28.133945+00', '2020-08-30 20:44:08.585525+00', 2260, 5, 1645, '', 'A', 'RSCDS Edinburgh: twice through.', 1, 1, 'Y', 'dW6MmQmw_Ak', 0, 70, NULL);
INSERT INTO 'dancevideo' VALUES (7580, '2020-08-30 20:43:23.130877+00', '2020-08-30 20:44:21.369173+00', 20079, 1, 1645, '', 'A', 'Red Thistles demonstration dance. This clip starts with the dancing. The video has a short introduction by the deviser.', 1, 1, 'Y', 'PoPPm467DdA', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7581, '2020-08-31 00:40:03.28733+00', '2020-08-31 00:40:03.28733+00', 17891, 2, 1296, '', 'X', '''The Edinburgh Toy Shop'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'dfDFYCpsFm8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7582, '2020-08-31 00:40:03.318333+00', '2020-08-31 00:40:03.318333+00', 8482, 2, 1296, '', 'X', '''The Haar on Skye'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'g-IVF16L92I', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7583, '2020-08-31 00:40:03.358603+00', '2020-08-31 00:40:03.358603+00', 3165, 2, 1296, '', 'X', '''It''s Just For Fun'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'Sw110owV6KI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7584, '2020-09-01 00:40:03.718849+00', '2020-09-01 00:40:03.718849+00', 9102, 5, 1296, '', 'X', '''A Reel for Jeannie'' is a 32 bar reel for 4 couples.', 1, 1, 'Y', 'TYCLcZDI4Vg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7585, '2020-09-01 00:40:03.752275+00', '2020-09-01 00:40:03.752275+00', 11369, 6, 1296, '', 'X', '''The Royal Yacht Britannia'' is a 40 bar reel for 3 couples.', 1, 1, 'Y', 'ZBAtAkSv01Q', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7594, '2020-10-03 22:51:00.899403+00', '2020-10-03 22:57:44.419434+00', 20102, 1, 1645, '', 'B', 'Once through extract from a Red Thistles demonstration. The 1st couple here finish the Corner Partner Corner Partner with RH instead of LH as specified in the instructions.', 1, 1, 'Y', 'fhl2hodpMYg', 75, 140, NULL);
INSERT INTO 'dancevideo' VALUES (7595, '2020-10-03 22:57:17.76339+00', '2020-10-04 09:33:21.514159+00', 2992, 2, 1645, '', 'A', 'Twice through extract from a Red Thistles demonstration.', 1, 1, 'Y', 'fhl2hodpMYg', 1, 76, NULL);
INSERT INTO 'dancevideo' VALUES (7587, '2020-09-13 07:45:50.540126+00', '2020-09-13 07:54:50.170395+00', 4354, 4, 1645, '', 'A', 'Edinburgh University demo at the Aberdeen Festival 2017. Some of the turns towards the end are here done with birling.', 1, 1, 'Y', '78VJiCf0Eag', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7588, '2020-09-16 17:16:08.189098+00', '2020-09-16 17:16:20.973038+00', 17122, 7, 1645, '', 'A', 'Charlotte SCD Scociety.', 1, 1, 'Y', 'RciLq_L-Ums', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7589, '2020-09-17 20:57:09.861966+00', '2020-09-17 22:00:26.074359+00', 4995, 2, 2586, '', 'A', '', 1, 1, 'Y', 'CReAbB6IAPE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7591, '2020-09-30 14:26:08.488112+00', '2020-09-30 22:37:55.167441+00', 20087, 1, 1645, '', 'C', 'Teaching practice of a demonstration medley by the New Forest Scottish Country Dancers. The video starts a little way into the dancing.', 1, 1, 'Y', '7YUES6_KKQQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7593, '2020-10-01 12:25:42.767682+00', '2020-10-01 12:55:26.451042+00', 5500, 1, 3086, '', 'A', '', 1, 1, 'Y', 'M1Kgq81po_c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7601, '2020-10-04 21:14:13.494274+00', '2020-10-04 23:05:11.067384+00', 20105, 1, 1645, '', 'A', 'Twice through with dance off as part of a longer demo by the Red Thistle dancers at the 2015 Pleasanton highland games.', 1, 1, 'Y', 'OXy5VbexH1w', 273, 359, NULL);
INSERT INTO 'dancevideo' VALUES (7599, '2020-10-04 21:02:59.696953+00', '2020-10-04 23:01:36.176793+00', 20104, 1, 1645, '', 'A', 'Once through clip from a demo by the Red Thistle dancers at the 2015 Pleasanton highland games.', 1, 1, 'Y', 'pIj0ygtjwOs', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7603, '2020-10-04 21:27:33.279911+00', '2020-10-04 23:06:41.100935+00', 20111, 1, 1645, '', 'A', 'Demonstration of the medley of Jack''s Strathspey and Jack''s Jig by the Red Thistle dancers in 2016.', 1, 1, 'Y', 'BCn4Ymh-2e4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7596, '2020-10-04 15:17:59.355493+00', '2020-10-04 23:09:25.587752+00', 12476, 2, 1645, '', 'A', 'Twice through as first part of a demo by the Red Thistle dancers.', 1, 1, 'Y', 'GBH2-nbSGOY', 0, 155, NULL);
INSERT INTO 'dancevideo' VALUES (7604, '2020-10-04 21:44:22.551426+00', '2020-10-04 23:09:14.82404+00', 14640, 1, 1645, '', 'B', 'Once through as part of a longer demo by the Red Thistle dancers at the 2007 Pleasanton highland games. The circles of bars 5-8 and 13-16 ought to be 3/4 to change the orientation of the set but are here done just 1/2 way.', 1, 1, 'Y', 'jFIHP2xIVgc', 65, 104, NULL);
INSERT INTO 'dancevideo' VALUES (7602, '2020-10-04 21:21:12.211364+00', '2020-10-04 23:10:59.899494+00', 20057, 2, 1645, '', 'A', 'Final part (with slightly false start) of a longer demo by the Red Thistle dancers at the 2015 Pleasanton highland games.', 1, 1, 'Y', 'OXy5VbexH1w', 359, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7605, '2020-10-04 21:55:17.896706+00', '2020-10-04 23:11:59.837799+00', 20117, 1, 1645, '', 'B', 'Twice through (in one, then two sets) as part of a longer demo by the Red Thistle dancers at the 2007 Pleasanton highland games. There seems to be a small glitch near the start of the 1st repeat.', 1, 1, 'Y', 'jFIHP2xIVgc', 103, 226, NULL);
INSERT INTO 'dancevideo' VALUES (7598, '2020-10-04 20:53:17.36219+00', '2020-10-04 23:12:16.129421+00', 20115, 1, 1645, '', 'A', 'Demonstration of the three dances in the suite by the Red Thistle dancers.', 1, 1, 'Y', 'FaJApr1O7l0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7597, '2020-10-04 15:25:52.347963+00', '2020-10-04 23:12:25.811249+00', 20114, 1, 1645, '', 'A', 'Once through as the last part of a demo by the Red Thistle dancers.', 1, 1, 'Y', 'GBH2-nbSGOY', 154, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7813, '2021-02-04 11:34:12.804563+00', '2021-02-04 11:35:21.420097+00', 936, 1, 202, '', 'A', '', 1, 1, 'Y', 'BfoptWDuT1U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7817, '2021-02-05 19:38:58.420849+00', '2021-02-05 19:44:06.139823+00', 20215, 1, 963, '', 'X', '', 1, 1, 'Y', 'ia0tk-yoblg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7590, '2020-09-24 08:53:03.079942+00', '2021-03-05 10:14:46.40329+00', 20084, 1, 1645, '', 'A', 'RSCDS Western Australia Branch. The deviser starts as 1st man.', 1, 1, 'Y', 'pOucp7-_R0c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7902, '2021-04-06 20:17:22.269628+00', '2021-04-06 20:24:19.550055+00', 144, 4, 1645, '', 'C', 'Novosibirsk 2018.', 1, 1, 'Y', 'YCAK5E6MGVQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7600, '2020-10-04 21:08:37.891593+00', '2020-10-04 23:00:33.035665+00', 20104, 2, 1645, '', 'A', 'Twice through with dance off as part of a longer demo by the Red Thistles dancers at the 2015 Pleasanton highland games.', 1, 1, 'Y', 'OXy5VbexH1w', 53, 139, NULL);
INSERT INTO 'dancevideo' VALUES (7608, '2020-10-04 22:27:04.780679+00', '2020-10-04 23:03:24.035906+00', 1036, 1, 1645, '', 'B', 'Twice through as the last part of a longer demo by the Red Thistle dancers at the 2007 Pleasanton highland games. There is a little glitch towards the end of the 1st repeat.', 1, 1, 'Y', 'jFIHP2xIVgc', 1310, 1384, NULL);
INSERT INTO 'dancevideo' VALUES (7610, '2020-10-04 22:48:08.342649+00', '2020-10-04 23:03:33.248424+00', 20118, 1, 1645, '', 'A', 'Twice through as the first part of a longer demo by the Red Thistles dancers.', 1, 1, 'Y', 'b5KRA-RIrig', 0, 73, NULL);
INSERT INTO 'dancevideo' VALUES (7618, '2020-10-05 11:57:34.917554+00', '2020-10-05 18:02:10.430891+00', 20114, 2, 1645, '', 'A', 'Once through as the second part of a longer demo by the Red Thistles dancers (1988 Pacific Grove Concert).', 1, 1, 'Y', 'F8OORiTtq0o', 1000, 1080, NULL);
INSERT INTO 'dancevideo' VALUES (7607, '2020-10-04 22:18:40.107829+00', '2020-10-04 23:06:29.673479+00', 2935, 2, 1645, '', 'A', 'Twice through as part of a longer demo by the Red Thistle dancers at the 2007 Pleasanton highland games.', 1, 1, 'Y', 'jFIHP2xIVgc', 893, 966, NULL);
INSERT INTO 'dancevideo' VALUES (7609, '2020-10-04 22:31:16.082746+00', '2020-10-04 23:07:20.919005+00', 3422, 4, 1645, '', 'A', 'Three times through demo by the Red Thistle dancers at the 2007 Pleasanton highland games.', 1, 1, 'Y', 'jFIHP2xIVgc', 1513, 1642, NULL);
INSERT INTO 'dancevideo' VALUES (7611, '2020-10-04 22:53:22.26507+00', '2020-10-04 23:08:10.497871+00', 20102, 2, 1645, '', 'A', 'Twice through as part of a longer demo by the Red Thistles dancers. The last two bars of the 2nd repeat are adapted to lead into the next dance.', 1, 1, 'Y', 'b5KRA-RIrig', 72, 198, NULL);
INSERT INTO 'dancevideo' VALUES (7606, '2020-10-04 22:09:27.557263+00', '2020-10-04 23:13:49.62813+00', 9512, 2, 1645, '', 'A', 'Red Thistles dancers at the 2007 Pleasanton highland games.', 1, 1, 'Y', 'jFIHP2xIVgc', 372, 527, NULL);
INSERT INTO 'dancevideo' VALUES (7614, '2020-10-05 10:35:04.623855+00', '2020-10-05 10:57:07.523487+00', 11806, 2, 1645, '', 'B', 'Twice through as part of a longer demo by the Red Thistle dancers at the 2018 Pleasanton highland games. This clip starts with the start of the dance (which is preceded by an introductory sequence). There seems to have been a glitch with video and/or music for the circles at the end of each repeat.', 1, 1, 'Y', 'BYpeWYmI9eA', 65, 169, NULL);
INSERT INTO 'dancevideo' VALUES (7615, '2020-10-05 10:41:01.371783+00', '2020-10-05 10:57:58.147253+00', 20112, 1, 1645, '', 'A', 'Twice through as part of a longer demo by the Red Thistles dancers at the 2018 Pleasanton highland games.', 1, 1, 'Y', 'BYpeWYmI9eA', 168, 322, NULL);
INSERT INTO 'dancevideo' VALUES (7612, '2020-10-05 00:51:01.169391+00', '2020-10-05 10:59:32.384769+00', 6748, 4, 562, '', 'A', 'An excerpt from "Scotland Dancing Again" video produced by RSCDS', 1, 1, 'Y', 'LdtlT3WPRAc', 868, 928, NULL);
INSERT INTO 'dancevideo' VALUES (7613, '2020-10-05 00:58:14.82627+00', '2020-10-05 11:04:30.57757+00', 6756, 6, 562, '', 'A', 'Moscow Branch', 1, 1, 'Y', 'Kozan7azRLo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7616, '2020-10-05 10:49:32.506685+00', '2020-10-05 11:04:53.239873+00', 20119, 1, 1645, '', 'A', 'Twice through as the last part of a longer demo by the Red Thistles dancers at the 2018 Pleasanton highland games.', 1, 1, 'Y', 'BYpeWYmI9eA', 321, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7621, '2020-10-05 17:51:05.12139+00', '2020-10-05 18:00:08.804977+00', 20110, 1, 1645, '', 'A', 'Performance by the Red Thistles at Asilomar 2011.', 1, 1, 'Y', 'kjzXFRyyHT4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7617, '2020-10-05 11:48:52.800063+00', '2020-10-05 18:00:27.96148+00', 20112, 2, 1645, '', 'B', 'Extract from Red Thistle Dancers 1988 Pacific Grove Concert. Excellent dancing, but the version of the dance being done here differs in some details from the version published in <<ddpub:#1558>>. The published version has women dancing 4 hands round in bars 1-4 and the last 8 bars is also different. <<https://my.strathspey.org/dd/dancevideo/7615/|Video 1>> shows the published version.', 1, 1, 'Y', 'F8OORiTtq0o', 922, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7619, '2020-10-05 17:34:16.39994+00', '2020-10-05 18:01:29.545354+00', 20113, 1, 1645, '', 'A', 'Twice through as the first part of a longer demo by the Red Thistle dancers at Sequoias - Portola Valley in 2017. The end of the 2nd repeat is slightly adapted to lead into the next dance.', 1, 1, 'Y', 'NuY2ni5MDKw', 122, 220, NULL);
INSERT INTO 'dancevideo' VALUES (7620, '2020-10-05 17:44:23.774264+00', '2020-10-05 18:02:26.475861+00', 20116, 1, 1645, '', 'A', 'Demo by the Red Thistles dancers at the 2015 Pleasanton highland games. Here danced as a medley.', 1, 1, 'Y', 'RdBcElFeVGA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7622, '2020-10-06 00:40:04.291132+00', '2020-10-06 00:40:04.291132+00', 89, 6, 1296, '', 'X', '''Alison Rose'' is a 32 bar strathspey for 4 couples.', 1, 1, 'Y', 'GM5XuDJUT1U', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7623, '2020-10-06 00:40:04.327205+00', '2020-10-06 00:40:04.327205+00', 271, 2, 1296, '', 'X', '''The Atholl Reel'' is a 32 bar reel for 2 couples.', 1, 1, 'Y', 'Z_wRKqlPMyc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7624, '2020-10-08 00:40:03.347958+00', '2020-10-08 00:40:03.347958+00', 11587, 2, 1296, '', 'X', '''Beach Dancer'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'ISZjSwuonnQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7625, '2020-10-08 00:40:03.378906+00', '2020-10-08 00:40:03.378906+00', 17122, 8, 1296, '', 'X', '''Triple Happiness'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'cN63WaSX728', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7629, '2020-10-09 17:52:11.51753+00', '2020-10-09 17:53:55.664047+00', 20062, 1, 1645, '', 'X', '', 1, 1, 'Y', 'YnJUrjfWOEM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7452, '2020-07-17 17:13:39.363285+00', '2020-10-16 22:33:49.863824+00', 16072, 1, 1645, '', 'B', 'Once through in two back to back 3 couple sets. Extract from a demo practice session in St Petersburg (taught by Anselm Lingnau).', 1, 1, 'Y', 'Wab3nv1PjZU', 213, 279, NULL);
INSERT INTO 'dancevideo' VALUES (7628, '2020-10-09 09:05:38.525197+00', '2022-12-19 22:51:44.178125+00', 11587, 3, 35776, '', 'C', 'Tawa SCD Club Annual Dance 03 October 2020. Recorded by Aline Homes. Music by Aileen Logie, Hilary Ferral, and Jason Morris.', 1, 1, 'V', '464661020', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7627, '2020-10-09 09:02:26.060853+00', '2022-12-20 10:33:49.239931+00', 888, 4, 35776, '', 'C', 'Tawa SCD Club Annual Dance 03 October 2020. Recorded by Aline Homes. Music by Aileen Logie, Hilary Ferral, and Jason Morris.', 1, 1, 'V', '464662688', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7630, '2020-10-09 22:13:32.854109+00', '2020-10-17 14:14:15.543791+00', 14310, 1, 2586, '', 'Z', 'This is the "Over the Water to Charlie (New Way) 8x32 Jig" version, from  the RSCDS Book 34: the Scottish Country Dancing variant.



This was uploaded to the wrong dance. Rather than deleting, its left as blocked to avoid a repeat mistake.', 1, 1, 'Y', 'DFkkwgOmLU8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7632, '2020-10-17 13:34:30.25095+00', '2020-10-17 14:11:51.268182+00', 15307, 3, 1645, '', 'C', 'Class from 2017 Kazan SCD School (Russia).', 1, 1, 'Y', 'C7k41cLr_uU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7633, '2020-10-17 14:11:41.301147+00', '2020-10-17 14:12:00.443195+00', 17127, 1, 1645, '', 'B', 'Class from 2017 Kazan SCD School (Russia) taught by Malcolm Brown.', 1, 1, 'Y', '0htGPeOSj-Q', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7631, '2020-10-17 13:00:34.96042+00', '2020-10-17 14:12:11.402014+00', 12892, 2, 1645, '', 'C', 'Class from 2017 Kazan SCD School (Russia). This clips starts from the 2nd repeat (part of the 1st repeat is missing). Here danced in a 5 couple set.', 1, 1, 'Y', 'RPXRQ8o_8Rw', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7637, '2020-10-17 15:45:00.985021+00', '2020-10-17 15:46:08.735481+00', 5772, 1, 1645, '', 'D', 'Class from 2017 Kazan SCD School (Russia) taught by Malcolm Brown. The video starts with a recap however the two Weasel reels in this dance (up/down and across) and the transitions between them prove a challenge.', 1, 1, 'Y', '0XPd8jYwkrE', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7639, '2020-10-18 20:28:30.573014+00', '2020-10-18 20:29:15.343975+00', 1768, 2, 1645, '', 'A', 'German team at the 2020 Newcastle festival.', 1, 1, 'Y', 'xAFSBh56dQU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7636, '2020-10-17 15:01:03.284097+00', '2020-10-18 20:29:32.850974+00', 5093, 4, 1645, '', 'B', 'Gleneagles SCD club.', 1, 1, 'Y', 'jRkOfWC0mH0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7635, '2020-10-17 14:52:50.48413+00', '2020-10-18 20:29:38.810326+00', 11483, 4, 1645, '', 'B', 'Gleneagles SCD club.', 1, 1, 'Y', 'j2B3Pq3nu-w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7634, '2020-10-17 14:49:25.740208+00', '2020-10-18 20:29:44.07655+00', 14974, 3, 1645, '', 'B', 'Gleneagles SCD club.', 1, 1, 'Y', 'acBCceZTmxk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7640, '2020-10-19 22:35:55.854983+00', '2020-10-19 22:36:19.297756+00', 19789, 2, 1645, '', 'C', 'Tawa SCD club: twice through.', 1, 1, 'Y', 'MfIhJzCPKQQ', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7638, '2020-10-17 18:19:57.494235+00', '2020-10-19 22:37:12.749563+00', 14625, 1, 1645, '', 'C', 'Burnaby (Canada) Scottish Dance Club 2012. One selected repeat, with a reasonably clear view, from a complete video which often has somewhat obscured views or where the camera is dwelling on the orchestra.', 1, 1, 'Y', '47mTIpIiguw', 213, 248, NULL);
INSERT INTO 'dancevideo' VALUES (7641, '2020-10-19 22:45:41.757015+00', '2020-10-19 22:53:45.452328+00', 15402, 4, 1645, '', 'C', 'Tawa SCD club. One repeat with a clear view then the camera starts moving around.', 1, 1, 'Y', 'sHxkuO5XvH8', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7643, '2020-10-21 03:48:16.499574+00', '2020-10-21 09:10:35.726389+00', 20061, 2, 35795, '', 'A', 'RSCDS Western Australia Branch.', 1, 1, 'Y', 'h6TRa__LxCg', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7644, '2020-10-31 01:40:04.233745+00', '2020-10-31 01:40:04.233745+00', 2360, 4, 1296, '', 'X', '''Fugal Fergus'' is a 48 bar jig for 3 couples.', 1, 1, 'Y', 'tdBGM4xrIH8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7645, '2020-10-31 01:40:04.266712+00', '2020-10-31 01:40:04.266712+00', 7560, 2, 1296, '', 'X', '''Indian River Strathspey'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'gtmoEbmH-7w', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7646, '2020-10-31 01:40:04.303292+00', '2020-10-31 01:40:04.303292+00', 3105, 2, 1296, '', 'X', '''Invercauld''s Reel'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'xgUWXr7D_ls', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7647, '2020-11-02 01:40:03.641892+00', '2020-11-02 01:40:03.641892+00', 3636, 3, 1296, '', 'X', '''Lady Sophia Lindsay'' is a 32 bar reel for 4 couples.', 1, 1, 'Y', 'hHPld1_V9vc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7648, '2020-11-02 01:40:03.677348+00', '2020-11-02 01:40:03.677348+00', 4808, 3, 1296, '', 'X', '''Mrs Stuart Linnell'' is a 40 bar reel for 3 couples.', 1, 1, 'Y', 'Kaly3psD8j8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (3662, '2018-10-01 22:07:47.167061+00', '2020-11-02 01:40:03.705391+00', 7180, 8, 1296, '', 'Z', '"The Wind on Loch Fyne" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'Qvk5IT7m9kk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7649, '2020-11-02 01:40:03.71495+00', '2020-11-02 01:40:03.71495+00', 7180, 8, 1296, '', 'X', '''The Wind on Loch Fyne'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'XVKjDW_1-4o', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7650, '2020-11-02 10:31:39.57602+00', '2020-11-02 11:10:06.647362+00', 13587, 3, 35795, '', 'A', 'The reel from RSCDS Book 46 danced by members of the RSCDS Western Australia branch.



It should be noted that in this performance, arms are raised at the start of the allemande and not during the end of the previous right hand turn.  This is the preference of both the devisor, John Brenchley and of Barbara Boyd, for whom the dance was written.', 1, 1, 'Y', 'u46ZKQzbmsg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7651, '2020-11-02 18:00:05.50919+00', '2020-11-02 18:00:33.600436+00', 20136, 1, 202, '', 'C', '', 1, 1, 'Y', '-uJ3YIXlJhE', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7652, '2020-11-04 09:54:39.078617+00', '2020-11-04 10:47:11.681731+00', 16844, 1, 197, '', 'A', 'Video by Gaye Collin (deviser)

Music : CD Vintage Goldring track 4 Dancing On,

Demo Team Nicole & Iain, Lesley & Chris, Alison & Damon Collin, Diane & Murrey

Video shows just 3 repetitions of the dance.', 1, 1, 'Y', '7l1P_INRMB8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7653, '2020-11-04 10:02:50.170927+00', '2020-11-04 10:48:05.293068+00', 19139, 1, 197, '', 'A', 'Video by Gaye Collin (deviser)

Music: CD The Musicians'' Wedding track 11 A Little Bit of Monty

Demo Team Diane & Iain, Lesley & Damon Collin, Ann & Murrey, Alison & Chris

Video shows four repetitions of the dance.', 1, 1, 'Y', 'lWhUlt5zd9k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7655, '2020-11-04 10:36:03.404654+00', '2020-11-04 10:48:22.546328+00', 20138, 1, 197, '', 'A', 'Video by Gaye Collin (deviser)

Music: CD Dancing on Air track 6 Frans Fancy

Demo Team  Gaye & Damon Collin, Nicole & Chris,  Diane Murrey, Ann & Iain.

', 1, 1, 'Y', '7Z5zjY-aBkY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7654, '2020-11-04 10:15:05.954284+00', '2020-11-04 10:48:38.631618+00', 20137, 1, 197, '', 'A', 'Video by Gaye Collin (deviser)

Music: CD Moments in Time Track 5 Cardross House

Demo Team  Ann & Damon Collin, Lesley & Chris,  Gaye & Murrey,  Nicole & Iain.

Video shows four repetitions of the dance.', 1, 1, 'Y', 'pzgfk7Ij6Sg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7656, '2020-11-04 10:45:31.873913+00', '2020-11-04 11:04:57.732007+00', 20139, 1, 197, '', 'A', 'Video by Gaye Collin

Music: CD Moments in Time Track 5 Cardross House

Demo Team  Ann & Damon Collin, Lesley & Chris,  Gaye & Murrey,  Nicole & Iain

Video shows four repetitions.', 1, 1, 'Y', 'wBThWwXPrgg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7080, '2020-03-29 20:04:36.475582+00', '2020-11-07 14:12:49.305477+00', 19933, 1, 1645, '', 'B', 'Aberdeen RSCDS: second of two demonstrations of this dance on the same video.

Twice through (with a recovered little glitch in the reels the 2nd time).', 1, 1, 'Y', 'pCE2eqy3V-A', 494, 643, NULL);
INSERT INTO 'dancevideo' VALUES (7658, '2020-11-08 14:47:43.38646+00', '2020-11-08 14:47:54.488696+00', 20131, 1, 1645, '', 'X', '', 1, 1, 'Y', 'Rfr65qCJnY4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7659, '2020-11-16 10:13:43.725823+00', '2020-11-16 10:45:50.925303+00', 20148, 1, 35795, '', 'A', '', 1, 1, 'Y', 'JezIizkOGSQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (559, '2012-12-17 14:18:34.534204+00', '2020-11-23 13:06:45.676876+00', 3246, 1, 1296, '', 'B', 'This set dances the old version, using Rsh for both figures of 8 on bars 1-8.  ', 1, 1, 'Y', 'uCVyMDZX1Xw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7661, '2020-11-24 01:40:03.441734+00', '2020-11-24 01:40:03.441734+00', 140, 4, 1296, '', 'X', '''Anderson''s Rant'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'cRW5dwual9k', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7662, '2020-11-24 01:40:03.543962+00', '2020-11-24 01:40:03.543962+00', 3485, 2, 1296, '', 'X', '''Kinfauns Castle'' is a 32 bar strathspey for 5 couples.', 1, 1, 'Y', 'WuJmCLiKnXo', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7664, '2020-11-30 05:50:40.358343+00', '2020-11-30 11:21:32.768474+00', 13075, 1, 35795, '', 'A', 'A 3 couple strathspey devised by John Brenchley for Christine Farrell to celebrate a significant birthday, Perth, Western Australia, 2002.

Danced by members of the RSCDS, Western Australia Branch, November 2020.', 1, 1, 'Y', 'jdtWQcHfPLk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7665, '2020-12-01 01:40:03.854949+00', '2020-12-01 01:40:03.854949+00', 4968, 5, 1296, '', 'X', '''None So Pretty'' is a 40 bar reel for 3 couples.', 1, 1, 'Y', 'v6kugQrjIVQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7666, '2020-12-01 01:40:03.888279+00', '2020-12-01 01:40:03.888279+00', 6451, 3, 1296, '', 'X', '''Tambourine'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'sAhPnwQaPz4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2798, '2017-01-24 13:43:18.364251+00', '2020-12-01 17:21:42.448257+00', 13720, 1, 2824, '', 'B', 'Ball at 15th anniversary Berlin Hopalots weekend (26.11.2016)  

  

The written instructions for the dance say that on bars 15 - 16 (the last 2 steps of the allemande) 1 couple dance a full left hand turn to face their corners.  

This is not shown by the dancers in the posted video for this dance.  All the dancers slide past each other LS to their corners.   

   

Video shows occasional extra turn&twiddle



', 1, 1, 'Y', '2x8-HwDGYuk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7667, '2020-12-06 16:23:00.676144+00', '2020-12-06 21:11:03.391218+00', 3119, 6, 3086, '', 'A', 'RSCDS Edinburgh. One tiny glitch in the 4th repeat very neatly recovered at the start of the next repeat.', 1, 1, 'Y', 'm-5s4MqcqMQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7668, '2020-12-06 21:23:22.042183+00', '2020-12-06 21:23:40.039996+00', 3700, 3, 1645, '', 'C', 'RSCDS Sacramento: once through.', 1, 1, 'Y', 'QNEWrQ4ZAz8', 84, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7669, '2020-12-06 21:36:13.909026+00', '2020-12-06 21:36:21.586808+00', 9214, 1, 1645, '', 'C', 'Toronto Rosedale Youth group. Twice through in a 3 couple set.', 1, 1, 'Y', '15hFojPTfcI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7670, '2020-12-08 11:45:17.893861+00', '2020-12-08 11:45:42.252083+00', 20196, 1, 202, '', 'C', '', 1, 1, 'Y', 'gyaGIDj7uwA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7676, '2020-12-17 01:40:03.369947+00', '2020-12-17 01:40:03.369947+00', 13588, 8, 1296, '', 'X', '''Links with St Petersburg'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', '3xe33V_gLf4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7678, '2020-12-17 01:40:03.433743+00', '2020-12-17 01:40:03.433743+00', 13077, 2, 1296, '', 'X', '''Torridon Lassies'' is a 40 bar jig for 3 couples.', 1, 1, 'Y', '0LAoWh-KDZc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7672, '2020-12-16 23:58:53.408507+00', '2020-12-17 10:47:46.755267+00', 20064, 1, 35776, '', 'C', 'John Markham is 1st man in the far left set, with the blue shirt.', 1, 1, 'V', '491021371', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7675, '2020-12-17 00:07:24.456714+00', '2020-12-17 11:43:50.840003+00', 4679, 2, 35776, '', 'D', '', 1, 1, 'V', '491019517', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7673, '2020-12-17 00:03:52.004111+00', '2020-12-17 11:46:18.87646+00', 6748, 5, 35776, '', 'C', '', 1, 1, 'V', '491018690', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7674, '2020-12-17 00:05:21.225307+00', '2020-12-17 12:02:51.284105+00', 2024, 2, 35776, '', 'D', 'Video starts around bar 9.', 1, 1, 'V', '491022813', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5333, '2019-11-04 19:52:22.397042+00', '2020-12-18 17:05:59.903402+00', 1558, 2, 2586, '', 'A', 'Instructional Country Dance video performed by Turnham Green Scottish Dancers

In this video the dance is performed 4 times through to show the progression.  At a dance event it would be danced through 8 times, with each new 1st couple progressing down the set.', 1, 1, 'Y', 'LbS45MvsSoc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7679, '2020-12-19 01:40:03.787987+00', '2020-12-19 01:40:03.787987+00', 2781, 2, 1296, '', 'X', '''Happy Returns'' is a 32 bar reel for 3 couples.', 1, 1, 'Y', 'NP88hS5R9ns', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7680, '2020-12-19 01:40:03.848662+00', '2020-12-19 01:40:03.848662+00', 2222, 3, 1296, '', 'X', '''Flight of the Falcon'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'YTLnsOYhia8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7681, '2020-12-20 01:40:03.284305+00', '2020-12-20 01:40:03.284305+00', 4998, 9, 1296, '', 'X', '''Nottingham Lace'' is a 96 bar reel for 4 couples.', 1, 1, 'Y', 'nwd9DNfnaCw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7682, '2020-12-26 23:09:27.426601+00', '2020-12-27 00:12:25.123498+00', 20197, 1, 963, '', 'X', '', 1, 1, 'Y', 'RZQsYBB5CzU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7683, '2020-12-28 23:56:00.214699+00', '2020-12-29 00:01:25.448193+00', 8726, 3, 1645, '', 'C', 'Torino (Clivis) 2016 Ball', 1, 1, 'Y', 'yGB_UHCaVgU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7685, '2020-12-31 01:40:03.73399+00', '2020-12-31 01:40:03.73399+00', 10789, 2, 1296, '', 'X', '''May Yarker''s Strathspey'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', '_dcuGPh1wBs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7686, '2020-12-31 01:40:03.768092+00', '2020-12-31 01:40:03.768092+00', 4629, 4, 1296, '', 'X', '''Moment of Truth'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'AAL4MTIUEbw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7687, '2020-12-31 01:40:03.796393+00', '2020-12-31 01:40:03.796393+00', 4928, 3, 1296, '', 'X', '''The New Rigged Ship'' is a 48 bar jig for 3 couples.', 1, 1, 'Y', 'G8bc2F96NXc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7688, '2020-12-31 13:11:24.481314+00', '2020-12-31 13:11:34.853352+00', 4555, 6, 1645, '', 'X', 'Lego animation by Felix Hamelbeck (RSCDS Vienna branch).', 1, 1, 'Y', '0KQfYthmXPE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7690, '2021-01-01 01:40:04.022352+00', '2021-01-01 01:40:04.022352+00', 13730, 4, 1296, '', 'X', '''Welcome to Ayr'' is a 32 bar jig for 3 couples.', 1, 1, 'Y', 'YU-cIPI3c6c', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7689, '2021-01-01 01:40:03.983298+00', '2021-01-02 01:40:04.80418+00', 6104, 4, 1296, '', 'Z', '''The Singing Sands'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'iVLq_dsc9s8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7691, '2021-01-02 01:40:04.817193+00', '2021-01-02 01:40:04.817193+00', 6104, 5, 1296, '', 'X', '''The Singing Sands'' is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'I4NDJ-X-jS4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7692, '2021-01-03 21:09:22.296317+00', '2021-01-03 21:17:00.397739+00', 20203, 1, 1645, '', 'B', 'Ruary Laidlaw, Jane McIlroy and The Waikato Bay of Plenty dancers. All clear, with one little glitch in the reels towards the end of the video.', 1, 1, 'Y', 'o02LrOf6gJk', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7693, '2021-01-03 21:16:50.924568+00', '2021-01-03 21:17:09.302564+00', 20001, 1, 1645, '', 'B', 'Ruary Laidlaw, Jane McIlroy and the Waikato Bay of Plenty dancers.



This clip just shows the first two repeats which both worked well.', 1, 1, 'Y', 'aik7KccFovg', 10, 99, NULL);
INSERT INTO 'dancevideo' VALUES (7694, '2021-01-03 21:40:07.056147+00', '2021-01-03 21:44:39.079696+00', 2705, 1, 1645, '', 'C', 'Lawrence (NZ) SCD group annual dance. Once through, with a slightly restricted view of the set.', 1, 1, 'Y', 'BU6KfkubgNs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7695, '2021-01-03 22:04:47.03392+00', '2021-01-03 22:04:58.429851+00', 6221, 1, 1645, '', 'B', 'RSCDS Edinburgh dem team. This clip is part of a longer medley. It shows the first 80 bars of the dance. Then, from about 19:52, the last 16 bars (hands across & casting then circle) are replaced with other choreography to link into the next dance in the demonstration.', 1, 1, 'Y', 'FPuQiMBz91A', 1035, 1223, NULL);
INSERT INTO 'dancevideo' VALUES (7696, '2021-01-04 14:26:00.538476+00', '2021-01-04 14:27:12.243829+00', 3259, 1, 202, '', 'D', '', 1, 1, 'Y', '_8vxjaJBL9E', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7697, '2021-01-05 22:41:31.995056+00', '2021-01-05 22:41:46.324776+00', 4014, 4, 1645, '', 'A', 'RSCDS Edinburgh, here with six couples.', 1, 1, 'Y', '5F41CMAxWhg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7698, '2021-01-05 23:28:24.24335+00', '2021-01-05 23:36:32.152484+00', 14170, 1, 1645, '', 'B', 'MacLennan Scottish Group demonstration in 2016.



The dance is actually a 96 bar reel, but here the group dance the central 32 bars as strathspey to give some contrast in the demonstration.', 1, 1, 'Y', '8mSWEBLMTR0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7701, '2021-01-06 12:24:18.987764+00', '2021-01-21 19:22:43.369408+00', 16872, 1, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2007. Three times through.



NB the sound track is out of sync with the dancing.', 1, 1, 'Y', 'eDPEiicOfW0', 2636, 2763, NULL);
INSERT INTO 'dancevideo' VALUES (7705, '2021-01-06 17:29:18.23012+00', '2021-01-21 19:52:08.381946+00', 2962, 2, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2007. Three times through.



NB the sound track is out of sync with the dancing.', 1, 1, 'Y', 'eDPEiicOfW0', 4437, 4596, NULL);
INSERT INTO 'dancevideo' VALUES (7710, '2021-01-06 19:26:10.018532+00', '2021-01-21 19:40:43.624678+00', 6798, 5, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2007. Twice through as the second part of a longer demo.



NB the sound track is out of sync with the dancing.', 1, 1, 'Y', 'eDPEiicOfW0', 6304, 6376, NULL);
INSERT INTO 'dancevideo' VALUES (7709, '2021-01-06 19:10:28.491096+00', '2021-01-21 19:51:17.097358+00', 3165, 3, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2007. Once each couple in two 3 couple sets, with the former 1st couple stepping to 3rd place after each repeat.



NB the sound track is out of sync with the dancing.', 1, 1, 'Y', 'eDPEiicOfW0', 5720, 5829, NULL);
INSERT INTO 'dancevideo' VALUES (7707, '2021-01-06 18:10:34.816528+00', '2021-01-21 19:19:20.516615+00', 9406, 3, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2007. Danced once each couple in two 3 couple sets with 1st couple crossing down to 3rd place at the end.



NB the sound track is out of sync with the dancing.', 1, 1, 'Y', 'eDPEiicOfW0', 1087, 1203, NULL);
INSERT INTO 'dancevideo' VALUES (7702, '2021-01-06 15:05:30.780178+00', '2021-01-21 20:00:42.251268+00', 976, 2, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2007. Three times through, once each couple, 1st couple crossing down to 3rd place each time.



NB the sound track is out of sync with the dancing.', 1, 1, 'Y', 'eDPEiicOfW0', 2949, 3115, NULL);
INSERT INTO 'dancevideo' VALUES (7700, '2021-01-06 10:50:19.158827+00', '2021-01-21 19:48:24.387534+00', 5040, 4, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2007. Three times through.



NB the sound track is out of sync with the dancing.', 1, 1, 'Y', 'eDPEiicOfW0', 350, 458, NULL);
INSERT INTO 'dancevideo' VALUES (7815, '2021-02-04 12:09:48.524187+00', '2021-02-04 12:11:05.296633+00', 3236, 2, 202, '', 'A', '', 1, 1, 'Y', 'oMVfi6xgAPg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2720, '2016-11-21 21:47:37.196842+00', '2021-01-07 19:28:03.632325+00', 18, 1, 513, '', 'B', 'Advanced class at Kuckucksnest. Here La Baratte is done with partner up/down the sides rather than across the set.', 1, 1, 'Y', 'kJ-w43ZsamY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7708, '2021-01-06 18:41:18.542361+00', '2023-02-23 21:17:53.584254+00', 6637, 1, 1645, '', 'Z', 'RSCDS Edinburgh Dancing Forth 2007. Once each couple in two 3 couple sets with 1st couple casting to 3rd place each time. Good view from above for the 1st time, thereafter the camera zooms in on individual couples.



NB the sound track is out of sync with the dancing.



Edinburgh made another video (uploaded as video 2) with the sound track in sync. So this version is now blocked.', 1, 1, 'Y', 'eDPEiicOfW0', 5068, 5178, NULL);
INSERT INTO 'dancevideo' VALUES (7711, '2021-01-07 17:57:45.830254+00', '2021-01-07 19:53:34.295858+00', 3422, 5, 1645, '', 'A', 'RSCDS Edinburgh Strictly Scottish 1996. Four times through.', 1, 1, 'Y', 'R1JIqK5Ge2c', 5872, 6020, NULL);
INSERT INTO 'dancevideo' VALUES (7712, '2021-01-07 18:13:46.544335+00', '2021-01-07 19:55:02.960668+00', 8693, 1, 1645, '', 'A', 'RSCDS Edinburgh Strictly Scottish 1996. Mostly a good view of the set with occasional close ups.', 1, 1, 'Y', 'R1JIqK5Ge2c', 5208, 5472, NULL);
INSERT INTO 'dancevideo' VALUES (7714, '2021-01-07 18:43:12.950572+00', '2021-01-07 19:56:16.292832+00', 4044, 3, 1645, '', 'A', 'RSCDS Edinburgh Strictly Scottish 1996. Second part of a longer demonstration.', 1, 1, 'Y', 'R1JIqK5Ge2c', 4270, 4431, NULL);
INSERT INTO 'dancevideo' VALUES (7699, '2021-01-06 10:27:13.38477+00', '2021-01-21 19:15:40.727687+00', 3649, 1, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2007.



NB the sound track is out of sync with the dancing.', 1, 1, 'Y', 'eDPEiicOfW0', 589, 847, NULL);
INSERT INTO 'dancevideo' VALUES (7715, '2021-01-07 19:33:16.330594+00', '2021-01-07 20:02:42.999501+00', 18, 2, 1645, '', 'A', 'RSCDS Edinburgh Strictly Scottish 1996. Done three times rather than the recommended twice.', 1, 1, 'Y', 'R1JIqK5Ge2c', 3716, 3879, NULL);
INSERT INTO 'dancevideo' VALUES (7858, '2021-03-27 22:33:41.386636+00', '2021-03-27 22:54:03.479327+00', 17308, 2, 1645, '', 'B', 'Méaudre Reel Club 2018. Once through with a couple of minor glitches.', 1, 1, 'Y', 'fSeGos4eMnE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7903, '2021-04-06 20:17:39.711324+00', '2021-04-06 20:36:21.362494+00', 14976, 2, 2824, '', 'A', '', 1, 1, 'Y', 'tw129RdCg2A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7713, '2021-01-07 18:31:29.764541+00', '2021-01-07 19:57:24.145317+00', 3435, 6, 1645, '', 'A', 'RSCDS Edinburgh Strictly Scottish 1996. Three times in a six couple set with all starting. Clear view for most of the first two repeats, thereafter the camera switches to a close up.', 1, 1, 'Y', 'R1JIqK5Ge2c', 4588, 4702, NULL);
INSERT INTO 'dancevideo' VALUES (7716, '2021-01-07 19:46:02.055292+00', '2021-01-07 19:58:29.732804+00', 2353, 6, 1645, '', 'A', 'RSCDS Edinburgh Strictly Scottish 1996. Twice through in two back to back 3 couple sets with a little adaptation so the 1st couples start at the ends for the first repeat but from the centre for the 2nd repeat.', 1, 1, 'Y', 'R1JIqK5Ge2c', 3111, 3247, NULL);
INSERT INTO 'dancevideo' VALUES (7727, '2021-01-08 22:26:12.222177+00', '2021-01-08 23:01:21.904096+00', 1816, 2, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2009.  Three times as the last part of a longer demo. The final chase is slightly adapted to change the orientation of the sets between 2nd & 3rd repeats. 1st couple here choose not to take right hands when crossing down into the reels.', 1, 1, 'Y', 'wUMmpgWYY7E', 354, 488, NULL);
INSERT INTO 'dancevideo' VALUES (7717, '2021-01-07 20:47:12.918505+00', '2021-01-07 21:11:27.108535+00', 611, 2, 1645, '', 'B', 'Comhlan (Krakow, Poland). A clear demo, though it looks as though the dancers do not dance down for all of bars 9-12, perhaps due to restricted space.', 1, 1, 'Y', 'j8WgQOlePF8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7718, '2021-01-07 21:11:13.596383+00', '2021-01-07 21:12:16.980537+00', 19165, 1, 1645, '', 'A', 'Demonstration by Auld Comhlan (Krakow, Poland). Performed in formal gardens "in the time of coronavirus plague, 2020". The dance is recommended as a medley of 64 bars of minuet and 64 bars of jig. Here, after the 64 bars of minuet (to 2:34) they continue with the first 24 bars again as minuet.', 1, 1, 'Y', 'Jk4eBwlHIy4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7719, '2021-01-08 00:19:52.698969+00', '2021-01-08 00:47:03.840372+00', 4282, 2, 1645, '', 'C', 'RSCDS Edinburgh Strictly Scottish 1996. Performance version with several men successively replacing each other in the centre.', 1, 1, 'Y', 'R1JIqK5Ge2c', 2330, 2515, NULL);
INSERT INTO 'dancevideo' VALUES (7720, '2021-01-08 00:27:02.329821+00', '2021-01-08 00:47:27.417448+00', 5937, 1, 1645, '', 'A', 'RSCDS Edinburgh Strictly Scottish 1996. Second part of a longer demonstration. Three times in a 5 couple set (so dancing round some ghosts on the 2nd repeat).', 1, 1, 'Y', 'R1JIqK5Ge2c', 1971, 2085, NULL);
INSERT INTO 'dancevideo' VALUES (7721, '2021-01-08 00:40:38.288941+00', '2021-01-08 00:48:17.0374+00', 5141, 2, 1645, '', 'A', 'RSCDS Edinburgh Strictly Scottish 1996.', 1, 1, 'Y', 'R1JIqK5Ge2c', 731, 1025, NULL);
INSERT INTO 'dancevideo' VALUES (7725, '2021-01-08 22:02:38.428778+00', '2021-01-08 22:03:29.643163+00', 4894, 3, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2009. Twice through, once in each orientation, starting with a dance in rather than a chord and ending ready for the next dance in the demonstration. The turns in bars 9-24 are done twice (rather than once as per Book 34 instructions).', 1, 1, 'Y', 'wUMmpgWYY7E', 115, 229, NULL);
INSERT INTO 'dancevideo' VALUES (7728, '2021-01-08 22:37:28.573451+00', '2021-01-08 22:58:06.547459+00', 1358, 2, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2009. Three times as the first part of a longer demonstration, starting with a dance in. The orientation of the set is rotated at the start of the 3rd repeat.', 1, 1, 'Y', 'wUMmpgWYY7E', 1316, 1454, NULL);
INSERT INTO 'dancevideo' VALUES (7724, '2021-01-08 21:41:27.679761+00', '2021-01-08 22:59:17.139315+00', 1747, 1, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2009. Starts with an 8 bar dance in rather than a chord.', 1, 1, 'Y', 'DlRJyOHhlMY', 1410, 1575, NULL);
INSERT INTO 'dancevideo' VALUES (7729, '2021-01-08 22:45:25.293054+00', '2021-01-08 23:02:09.679747+00', 1907, 2, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2009. Twice through as part of a longer demonstration. The last 8 bars of the 2nd repeat (hello-goodbye setting) is adapted to lead into the next dance in the demo.', 1, 1, 'Y', 'wUMmpgWYY7E', 1454, 1596, NULL);
INSERT INTO 'dancevideo' VALUES (7726, '2021-01-08 22:13:01.840175+00', '2021-01-08 23:09:27.201338+00', 4073, 2, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2009.  Twice through in three 2 couple sets as part of a longer demo. The 2nd repeat is adapted from the end of the reel so the rondel is done across the set and ends leading in to the next dance in the demonstration.', 1, 1, 'Y', 'wUMmpgWYY7E', 229, 355, NULL);
INSERT INTO 'dancevideo' VALUES (7722, '2021-01-08 21:21:02.662508+00', '2021-01-08 23:04:59.065598+00', 2506, 5, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2009. Three times in three 2 couple sets (without progression). The end of the 3rd repeat is slightly adapted to lead into the next dance in the demonstration.', 1, 1, 'Y', 'DlRJyOHhlMY', 882, 993, NULL);
INSERT INTO 'dancevideo' VALUES (7723, '2021-01-08 21:30:05.73359+00', '2021-01-08 23:06:11.130474+00', 3336, 8, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2009.', 1, 1, 'Y', 'DlRJyOHhlMY', 992, 1203, NULL);
INSERT INTO 'dancevideo' VALUES (7736, '2021-01-09 18:58:43.659117+00', '2021-01-09 19:04:10.788483+00', 549, 5, 1645, '', 'B', 'RSCDS instructional video, danced once and walked once.', 1, 1, 'Y', 'o2UfaYpMhao', 1109, 1189, NULL);
INSERT INTO 'dancevideo' VALUES (7737, '2021-01-09 19:00:29.115983+00', '2021-01-09 19:06:16.210783+00', 549, 6, 1645, '', 'B', 'RSCDS Edinburgh Strictly Scottish 1993. Here done three times in a 7 couple set on an extremely dark video so its a little hard to make out whats going on.', 1, 1, 'Y', 'nSNRYbaFH5Y', 1152, 1269, NULL);
INSERT INTO 'dancevideo' VALUES (7738, '2021-01-10 14:15:11.738293+00', '2021-01-11 18:03:46.488386+00', 10580, 1, 1645, '', 'B', 'Flying Ghillies group at the World A''Fair 2013.', 1, 1, 'Y', 'eIzR9e0dYAc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7739, '2021-01-11 18:02:45.783225+00', '2021-01-11 18:19:58.783252+00', 4871, 2, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2009. Twice through in 3 couple sets as the last part of a longer demo.', 1, 1, 'Y', 'FPuQiMBz91A', 1222, 1300, NULL);
INSERT INTO 'dancevideo' VALUES (7810, '2021-02-04 11:24:12.294021+00', '2021-02-04 11:24:47.271608+00', 5800, 1, 202, '', 'B', '', 1, 1, 'Y', 'hkYo2FlCXgQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7735, '2021-01-09 18:14:01.400281+00', '2022-06-19 09:38:15.886562+00', 805, 2, 1645, '', 'A', 'RSCDS Edinburgh Strictly Scottish 1993. Rather dark video, sometimes with only a partial view of the set. 1st couple is furthest from the camera.

', 1, 1, 'Y', 'MUd8Ng5nGAM', 2532, 2723, NULL);
INSERT INTO 'dancevideo' VALUES (7734, '2021-01-09 17:53:21.321474+00', '2022-06-19 09:48:16.239585+00', 1274, 2, 1645, '', 'A', 'RSCDS Edinburgh Strictly Scottish 1993. Four times through in a rather dark video. The orientation of the 2 couple sets is rotated for the 2nd repeat.', 1, 1, 'Y', 'MUd8Ng5nGAM', 2973, 3089, NULL);
INSERT INTO 'dancevideo' VALUES (7733, '2021-01-09 17:44:03.376499+00', '2022-06-19 09:46:57.977476+00', 4256, 1, 1645, '', 'A', 'RSCDS Edinburgh Strictly Scottish 1993. Part of a longer demonstration on a rather dark video. The last couple of bars are adapted to lead into the next dance and there are one or two minor setting glitches en route.', 1, 1, 'Y', 'MUd8Ng5nGAM', 2821, 2974, NULL);
INSERT INTO 'dancevideo' VALUES (7731, '2021-01-09 12:37:17.879973+00', '2022-06-19 10:01:55.922479+00', 1624, 2, 1645, '', 'A', 'RSCDS Edinburgh Strictly Scottish 1993. Three times through in a rather dark video.', 1, 1, 'Y', 'MUd8Ng5nGAM', 1140, 1278, NULL);
INSERT INTO 'dancevideo' VALUES (7741, '2021-01-11 18:15:09.723708+00', '2021-01-11 18:21:50.045787+00', 899, 4, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2009. Twice through in two 2 couple sets as part of a longer demonstration. Good view from above.', 1, 1, 'Y', 'FPuQiMBz91A', 1572, 1701, NULL);
INSERT INTO 'dancevideo' VALUES (7742, '2021-01-11 18:19:01.972512+00', '2021-01-11 18:25:59.304593+00', 7282, 6, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2009. Twice through in a 3 couple set as the last part of a longer demo (a 4th couple dances off at the start). Good view from above.', 1, 1, 'Y', 'FPuQiMBz91A', 1699, 1775, NULL);
INSERT INTO 'dancevideo' VALUES (7740, '2021-01-11 18:09:43.67379+00', '2021-01-11 18:24:58.467052+00', 5407, 7, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2009. Twice through in two 3 couple sets as the first part of a longer demonstration.  1st couple cross down to the bottom at the end of the 1st repeat. The end of the 2nd repeat is adapted to lead into the next dance in the demo. Good view from above.', 1, 1, 'Y', 'FPuQiMBz91A', 1496, 1572, NULL);
INSERT INTO 'dancevideo' VALUES (7816, '2021-02-04 12:12:27.84288+00', '2021-02-04 12:13:33.826004+00', 2916, 2, 202, '', 'A', '', 1, 1, 'Y', 'TEx-3v4tpUw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7904, '2021-04-06 20:21:13.520194+00', '2021-04-06 20:39:57.905727+00', 14346, 3, 2824, '', 'B', '', 1, 1, 'Y', 'FlfoNmPvCAE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8058, '2021-09-02 10:31:51.367217+00', '2021-09-02 10:47:04.527786+00', 20452, 1, 1645, '', 'C', 'Méaudre reel club 2021.', 1, 1, 'Y', '8EaDI1R7ns8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7743, '2021-01-11 21:12:13.956602+00', '2021-01-11 21:30:53.14476+00', 11483, 5, 1645, '', 'C', '8cento (Bologna) demo from 2014. Good dancing, but showing, once through, a variation with 6 couples instead of 4 (two longer sides of the "square").', 1, 1, 'Y', 'E0IK6FbhT7g', 35, 74, NULL);
INSERT INTO 'dancevideo' VALUES (7753, '2021-01-12 19:38:41.076145+00', '2021-01-14 21:01:58.0763+00', 20204, 1, 1645, '', 'A', 'RSCDS Edinburgh. This video from 1994 begins with an explanation of the dance which starts around 1:03.', 1, 1, 'Y', 'wqocAN9Z-Ec', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7744, '2021-01-11 21:17:54.115445+00', '2021-01-11 21:33:10.892127+00', 13462, 1, 1645, '', 'B', '8cento (Bologna) demo from 2014. Good dancing, but showing, once through, a variation with six couples instead of the expected four. Bars 17-24 are adapted with three couples dancing down & up to progressed places instead of just 1st couple.', 1, 1, 'Y', 'E0IK6FbhT7g', 73, 111, NULL);
INSERT INTO 'dancevideo' VALUES (7745, '2021-01-11 21:28:08.720247+00', '2021-01-11 21:34:10.898375+00', 8792, 1, 1645, '', 'B', '8cento (Bologna) demo from 2014. Once through. The two foreground sets are joined at the top of each set; the set in the background has the top nearest the camera.', 1, 1, 'Y', 'E0IK6FbhT7g', 111, 143, NULL);
INSERT INTO 'dancevideo' VALUES (7747, '2021-01-11 21:47:16.204934+00', '2021-01-11 21:49:59.723807+00', 8104, 2, 1645, '', 'B', '8cento (Bologna) demo from 2014. Once through excerpt from a longer video.', 1, 1, 'Y', 'E0IK6FbhT7g', 207, 249, NULL);
INSERT INTO 'dancevideo' VALUES (7746, '2021-01-11 21:39:36.073168+00', '2021-01-11 21:50:32.70512+00', 9816, 2, 1645, '', 'B', '8cento (Bologna) demo from 2014. Once through.', 1, 1, 'Y', 'E0IK6FbhT7g', 143, 207, NULL);
INSERT INTO 'dancevideo' VALUES (7748, '2021-01-11 22:21:01.320127+00', '2021-01-12 17:20:18.855147+00', 2409, 5, 1645, '', 'B', '8cento (Bologna) 2018. Once through clip with good view from above, starting around bar 2.', 1, 1, 'Y', '-L2jfVP0ITc', 71, 123, NULL);
INSERT INTO 'dancevideo' VALUES (7768, '2021-01-15 20:12:52.3576+00', '2021-01-15 20:28:34.730138+00', 1075, 2, 1645, '', 'A', 'RSCDS Edinburgh at Newcastle 2017. Twice through as part of a longer display. The dance would normally be done in longwise sets but is here done as a round the room dance. The end of the 2nd repeat is slightly adapted to lead into the next dance in the demo.', 1, 1, 'Y', 'DSW8JJe-kHc', 193, 323, NULL);
INSERT INTO 'dancevideo' VALUES (7767, '2021-01-15 20:09:04.992818+00', '2021-01-15 20:30:15.34912+00', 2777, 5, 1645, '', 'A', 'RSCDS Edinburgh at Newcastle 2017. Once through as part of a longer display (the video continues with a slightly adapted repeat).', 1, 1, 'Y', 'DSW8JJe-kHc', 120, 156, NULL);
INSERT INTO 'dancevideo' VALUES (7771, '2021-01-15 20:26:44.622633+00', '2021-01-15 20:30:51.484409+00', 2198, 3, 1645, '', 'A', 'RSCDS Edinburgh at Newcastle 2017. The last part of a longer display.', 1, 1, 'Y', 'DSW8JJe-kHc', 323, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7773, '2021-01-16 18:32:45.673928+00', '2021-01-16 18:33:10.317552+00', 9169, 4, 1645, '', 'A', 'RSCDS Vancouver Burns Night 2009. Twice through display variation of the dance involving three staggered and inverted sets.', 1, 1, 'Y', 'Dpk7hwkDt_w', 102, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7772, '2021-01-16 00:19:18.73288+00', '2021-01-16 18:34:18.620379+00', 13391, 3, 1645, '', 'C', 'Kelowna Scottish Country Dancers 2017. Once through.', 1, 1, 'Y', 'tWy3ffnmvXI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7774, '2021-01-16 19:06:46.310522+00', '2021-01-16 23:31:09.369635+00', 20205, 1, 1645, '', 'B', 'Demo at the Pleasanton Games 2011.', 1, 1, 'Y', 'PHNM3P8HVR0', 8, 85, NULL);
INSERT INTO 'dancevideo' VALUES (7777, '2021-01-17 00:41:58.000076+00', '2021-01-17 01:10:37.64489+00', 13357, 3, 1645, '', 'D', 'Stone Mountain Highland Games.', 1, 1, 'Y', 'EYsMDS9aJas', 84, 363, NULL);
INSERT INTO 'dancevideo' VALUES (7776, '2021-01-17 00:32:02.381978+00', '2021-01-17 01:09:08.745401+00', 9103, 5, 1645, '', 'C', 'Stone Mountain Highland Games. Four times through.', 1, 1, 'Y', 'W6Dbu3zX1O0', 422, 563, NULL);
INSERT INTO 'dancevideo' VALUES (7770, '2021-01-15 20:25:02.57597+00', '2022-01-27 22:42:05.042824+00', 2198, 2, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2010. Part of a longer demonstration.', 1, 1, 'Y', 'A3zVbjl5Ljo', 6773, 6905, NULL);
INSERT INTO 'dancevideo' VALUES (7757, '2021-01-14 21:07:04.004012+00', '2022-01-27 20:24:46.66644+00', 5749, 3, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2010.', 1, 1, 'Y', 'A3zVbjl5Ljo', 765, 900, NULL);
INSERT INTO 'dancevideo' VALUES (7756, '2021-01-14 20:58:44.453446+00', '2022-01-27 20:19:47.431795+00', 1162, 1, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2010. Twice through as the last part of a longer demonstration.



In the setting to corners in bars 9-16 the dancers here use the opposite hands from those suggested in the instructions - though it looks very natural.', 1, 1, 'Y', 'A3zVbjl5Ljo', 318, 397, NULL);
INSERT INTO 'dancevideo' VALUES (7758, '2021-01-14 21:13:53.833095+00', '2022-01-27 20:28:57.897632+00', 684, 3, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2010. First part of a longer demonstration. The final promenade is adapted to end in a longwise set ready for the next dance in the demo.', 1, 1, 'Y', 'A3zVbjl5Ljo', 1210, 1335, NULL);
INSERT INTO 'dancevideo' VALUES (7759, '2021-01-14 21:20:47.816816+00', '2022-01-27 20:32:43.158873+00', 6311, 1, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2010. Twice through as part of a longer demonstration.', 1, 1, 'Y', 'A3zVbjl5Ljo', 1335, 1455, NULL);
INSERT INTO 'dancevideo' VALUES (7760, '2021-01-14 21:30:04.954489+00', '2022-01-27 20:36:37.775233+00', 1763, 1, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2010. Three times as the last part of a longer demonstration. The last 8 bars of the 3rd time are replaced by a dance off.', 1, 1, 'Y', 'A3zVbjl5Ljo', 1454, 1558, NULL);
INSERT INTO 'dancevideo' VALUES (7766, '2021-01-15 19:21:35.519565+00', '2022-01-27 21:35:41.912789+00', 14679, 2, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2010. Last part of a longer demonstration. Here the dancers set twice to partners and turn for 4 bars rather than swing for 8 bars.', 1, 1, 'Y', 'A3zVbjl5Ljo', 3280, 3355, NULL);
INSERT INTO 'dancevideo' VALUES (7761, '2021-01-15 18:51:45.387559+00', '2022-01-27 21:01:31.375417+00', 1786, 7, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2010. Twice through as the first part of a longer demonstration. The last 4 bars of the 2nd repeat are changed to RH turn (instead of completing the rights & lefts).', 1, 1, 'Y', 'A3zVbjl5Ljo', 2376, 2434, NULL);
INSERT INTO 'dancevideo' VALUES (7762, '2021-01-15 19:00:12.849041+00', '2022-01-27 21:08:29.017234+00', 1773, 2, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2010. Twice through as part of a longer demonstration. In the 2nd repeat the allemande is adapted (to 3 couples and crossing) in preparation for the next dance in the demo which starts on opposite sides.', 1, 1, 'Y', 'A3zVbjl5Ljo', 2433, 2551, NULL);
INSERT INTO 'dancevideo' VALUES (7763, '2021-01-15 19:06:59.50298+00', '2022-01-27 21:13:03.47266+00', 6010, 5, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2010. Twice through as the last part of a longer demonstration.', 1, 1, 'Y', 'A3zVbjl5Ljo', 2551, 2685, NULL);
INSERT INTO 'dancevideo' VALUES (7764, '2021-01-15 19:16:13.122739+00', '2022-01-27 21:32:08.283776+00', 7554, 8, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2010. First part of a longer demonstration.', 1, 1, 'Y', 'A3zVbjl5Ljo', 3154, 3280, NULL);
INSERT INTO 'dancevideo' VALUES (7752, '2021-01-12 19:10:46.223875+00', '2022-06-19 10:22:47.34603+00', 7866, 1, 1645, '', 'Z', 'RSCDS Edinburgh Dancing Forth 2009. Once through with dance on and off, the dance starts at 24:08.



Original video no longer available. Parts 1-3 of the Dancing Forth 2009 set were replaced by new youtube videos but seemingly not this one.', 1, 1, 'Y', 'o3dR4QF0hQQ', 1439, 1530, NULL);
INSERT INTO 'dancevideo' VALUES (7751, '2021-01-12 18:57:45.158427+00', '2022-06-19 10:23:41.91472+00', 13579, 3, 1645, '', 'Z', 'RSCDS Edinburgh Dancing Forth 2009. Twice through. Good view from above.



Original video no longer available. Parts 1-3 of the Dancing Forth 2009 set were replaced by new youtube videos but seemingly not this one.', 1, 1, 'Y', 'o3dR4QF0hQQ', 720, 800, NULL);
INSERT INTO 'dancevideo' VALUES (7859, '2021-03-27 22:37:40.844164+00', '2021-03-27 22:54:14.171893+00', 9896, 2, 1645, '', 'C', 'Méaudre Reel Club: children and adolescents christmas ceilidh 2018.', 1, 1, 'Y', 'cXggvyh7Uc4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7775, '2021-01-17 00:27:34.70365+00', '2021-01-17 01:12:45.434427+00', 17563, 1, 1645, '', 'C', 'Stone Mountain Highland Games.', 1, 1, 'Y', 'W6Dbu3zX1O0', 91, 377, NULL);
INSERT INTO 'dancevideo' VALUES (7780, '2021-01-17 01:07:30.038604+00', '2021-01-17 01:28:15.918049+00', 15644, 5, 1645, '', 'A', 'Edinburgh RSCDS. Once through as the last part of a longer demonstration.', 1, 1, 'Y', 'm1SDrk-wtNM', 149, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7778, '2021-01-17 01:00:23.920571+00', '2021-01-17 01:29:24.647924+00', 15648, 3, 1645, '', 'A', 'Edinburgh RSCDS. Twice through as part of a longer demonstration.', 1, 1, 'Y', 'm1SDrk-wtNM', 16, 85, NULL);
INSERT INTO 'dancevideo' VALUES (8057, '2021-09-02 10:18:36.012849+00', '2021-09-02 10:47:54.992371+00', 20332, 2, 1645, '', 'D', 'Méaudre reel club class 2021.', 1, 1, 'Y', 'sXpjU5LymU0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7779, '2021-01-17 01:04:30.566728+00', '2021-01-17 01:26:57.502732+00', 15649, 3, 1645, '', 'A', 'Edinburgh RSCDS. Once through as part of a longer demonstration. The last 4 bars are adapted to turn into a square set for the next dance in the demo.', 1, 1, 'Y', 'm1SDrk-wtNM', 86, 149, NULL);
INSERT INTO 'dancevideo' VALUES (7794, '2021-01-18 20:18:22.963946+00', '2021-01-18 20:42:57.67031+00', 13315, 1, 3086, '', 'A', 'Extract from Edinburgh RSCDS Dancing Forth 2007.', 1, 1, 'Y', 'IWGB6UpJgks', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7785, '2021-01-17 10:04:41.730136+00', '2021-01-17 11:57:26.887875+00', 12426, 9, 35776, '', 'C', '', 1, 1, 'V', '498779085', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7786, '2021-01-17 10:06:56.695497+00', '2021-01-17 11:59:52.586438+00', 7147, 8, 35776, '', 'C', '', 1, 1, 'V', '498772911', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7787, '2021-01-17 12:28:17.434638+00', '2021-01-17 12:29:14.638766+00', 1001, 1, 1645, '', 'X', '', 1, 1, 'Y', 'GfME8y2X5Uw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (116, '2012-07-22 17:41:32.269905+00', '2021-01-20 23:38:37.160774+00', 4565, 1, 1041, '', 'B', 'Part of the overview of a grand ball.  Only once through, poor lighting. 



On the video the dancers join nearer hands during "lead down the middle and up".', 1, 1, 'Y', 'QhJQG6hvKc0', 209, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7792, '2021-01-17 23:29:55.278746+00', '2021-01-17 23:35:00.990566+00', 17901, 2, 1645, '', 'X', 'George Williams animation.



Men are here represented by rectangles and women by ovals (roughly the opposite of the usual SCD diagram convention). The video shows several repeats of the dance. The first one in slow motion, the rest faster.', 1, 1, 'Y', 'tKE8oHUDWHY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7793, '2021-01-17 23:34:50.006632+00', '2021-01-17 23:35:30.180462+00', 15440, 2, 1645, '', 'X', 'George Williams animation.



Men are here represented by rectangles and women by ovals (roughly the opposite of the usual SCD diagram convention). The video shows several repeats of the dance. The first one in slow motion, the rest faster.



There are a few minor infelicities in depiction of casts and stepping down, but the overall form of the dance is clear.', 1, 1, 'Y', 'tGLZ5t1IXic', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7704, '2021-01-06 16:17:49.754695+00', '2021-01-21 19:25:03.230778+00', 7210, 2, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2007. Three times though, once each couple in two three couple sets with the last 4 bars slightly adapted to get 1st couple to 3rd place.



NB the sound track is out of sync with the dancing.', 1, 1, 'Y', 'eDPEiicOfW0', 4130, 4320, NULL);
INSERT INTO 'dancevideo' VALUES (7703, '2021-01-06 15:28:59.179656+00', '2021-01-21 19:49:55.589143+00', 3474, 1, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2007. Three times in a slightly adapted version. The dance is for 4 couples in a longwise set but here there are two extra couples who dance the 2nd repeat oriented across. The last 4 bars of each repeat should be a slow RH cross with partner but is here changed to switch the orientation.



NB the sound track is out of sync with the dancing.', 1, 1, 'Y', 'eDPEiicOfW0', 3227, 3340, NULL);
INSERT INTO 'dancevideo' VALUES (1537, '2013-12-25 17:33:26.637837+00', '2021-01-22 21:47:59.532714+00', 5527, 1, 106, '', 'Z', 'This good video is actually for a different dance of the same name devised by Charlie Inglis (previously not known to the database). This blocked entry is kept to avoid it being accidentally added back to the wrong dance entry.', 1, 1, 'Y', 'CxMMMX1NkLc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7795, '2021-01-22 21:50:00.266454+00', '2021-01-22 21:50:14.23149+00', 20208, 1, 1645, '', 'B', '', 1, 1, 'Y', 'CxMMMX1NkLc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7800, '2021-01-25 12:15:21.907026+00', '2021-01-25 12:30:00.85503+00', 6965, 2, 3086, '', 'A', 'RSCDS Edinburgh. Twice through.', 1, 1, 'Y', '3kHV9O0xuGg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7801, '2021-01-27 02:20:52.774151+00', '2021-01-27 02:39:03.581887+00', 16536, 5, 35805, '', 'A', '', 1, 1, 'Y', 'QZKev-vM7KU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7796, '2021-01-25 10:00:24.067947+00', '2021-01-31 10:27:53.277504+00', 20209, 1, 197, '', 'A', 'RSCDS London Branch video.', 1, 1, 'Y', 'RiiHG9ga5P4', 143, 259, NULL);
INSERT INTO 'dancevideo' VALUES (7797, '2021-01-25 10:10:34.490185+00', '2021-01-31 10:28:41.851215+00', 20209, 2, 197, '', 'C', 'Stage Méaudre,, May 2016', 1, 1, 'Y', '12aOSwMyeWM', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7798, '2021-01-25 10:17:18.020798+00', '2021-01-31 10:29:41.352311+00', 20209, 3, 197, '', 'A', 'Stage Méaudre, May 2017', 1, 1, 'Y', 'nmB_Ghu0Wsw', 3, 139, NULL);
INSERT INTO 'dancevideo' VALUES (7803, '2021-01-31 11:00:10.703531+00', '2021-01-31 11:00:35.646399+00', 2302, 1, 1645, '', 'D', 'Dundee U3A Party.', 1, 1, 'Y', 'av2CIEb5ne8', 173, 334, NULL);
INSERT INTO 'dancevideo' VALUES (7802, '2021-01-31 10:50:04.826512+00', '2021-01-31 11:00:46.327166+00', 19194, 2, 1645, '', 'C', 'Performance by the Méaudre Reel club, France. This clip starts with the dancing. The video has an introduction about the dance (in French). In both this and the other video of the dance, 1st couple turn or birl before entering the reels (which is not actually in the instructions).', 1, 1, 'Y', 'fUMBhbmhlBw', 58, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7799, '2021-01-25 10:30:30.336801+00', '2021-01-31 11:01:03.562824+00', 14313, 3, 197, '', 'A', 'RSCDS London Branch', 1, 1, 'Y', '91eTGi3aYt0', 0, 195, NULL);
INSERT INTO 'dancevideo' VALUES (7569, '2020-08-07 20:44:12.237837+00', '2021-01-31 11:17:06.096003+00', 3729, 1, 1645, '', 'D', 'Silent and shaky extract from 1930s film, by Ion Jamieson, of dances from the borders. The <<https://youtu.be/hJvoYB6QL1E|youtube comments>> have lots of additional information.



Unfortunately this video can only be played directly on youtube, so you will need to click "watch on youtube". This dance starts at 2:27 into the video.', 1, 1, 'Y', 'hJvoYB6QL1E', 147, 215, NULL);
INSERT INTO 'dancevideo' VALUES (3285, '2017-10-17 11:05:54.329889+00', '2021-01-31 11:25:22.261999+00', 3475, 1, 1056, '', 'C', '', 1, 1, 'Y', 'U_CFhGn1Zb8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7807, '2021-02-04 11:15:36.80182+00', '2021-02-04 11:16:00.545501+00', 3762, 1, 202, '', 'B', '', 1, 1, 'Y', 'h-WdRYAh-qA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7808, '2021-02-04 11:18:24.997777+00', '2021-02-04 11:19:24.007057+00', 1579, 1, 202, '', 'B', '', 1, 1, 'Y', 'MMN9fyrNIFU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7809, '2021-02-04 11:20:55.850299+00', '2021-02-04 11:21:49.710474+00', 3763, 2, 202, '', 'B', '', 1, 1, 'Y', 'Kg79Aq7Dcok', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7783, '2021-01-17 02:00:35.74605+00', '2022-01-27 21:49:31.359104+00', 5243, 3, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2010. Three times through as the last part of a longer demonstration.', 1, 1, 'Y', 'A3zVbjl5Ljo', 4362, 4469, NULL);
INSERT INTO 'dancevideo' VALUES (7784, '2021-01-17 02:06:26.270093+00', '2022-01-27 21:56:51.488871+00', 4781, 1, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2010.', 1, 1, 'Y', 'A3zVbjl5Ljo', 4784, 4990, NULL);
INSERT INTO 'dancevideo' VALUES (7788, '2021-01-17 15:48:45.338909+00', '2022-01-27 22:09:38.392642+00', 4808, 4, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2010. Three times in two back to back sets as the first part of a longer demonstration, starting with a dance on. Dem quality dancing, but in the 1st and 3rd repeats the 4 couples in each set (in the centre) are doing a 2 couple variation of the dance.', 1, 1, 'Y', 'A3zVbjl5Ljo', 5466, 5612, NULL);
INSERT INTO 'dancevideo' VALUES (7789, '2021-01-17 15:56:30.734516+00', '2022-01-27 22:15:03.568584+00', 3114, 1, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2010. Last part of a longer demonstration. The final knot is adapted into a dance off.', 1, 1, 'Y', 'A3zVbjl5Ljo', 5612, 5710, NULL);
INSERT INTO 'dancevideo' VALUES (7790, '2021-01-17 16:05:29.767449+00', '2022-01-27 22:19:42.080862+00', 658, 4, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2010. First part of a longer demonstration. The final circles are adapted to end in longwise sets for the next dance in the demo.', 1, 1, 'Y', 'A3zVbjl5Ljo', 5973, 6097, NULL);
INSERT INTO 'dancevideo' VALUES (8167, '2021-12-05 10:44:34.953619+00', '2022-03-12 18:39:35.624786+00', 20565, 1, 1645, '', 'B', 'Kuckucksnest Germany, November 2021. On the last time through the deviser dances a variation (taking the lead for the first 8 bars).', 1, 1, 'Y', 'hndOWkWvawc', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7791, '2021-01-17 16:49:04.746825+00', '2022-01-27 22:25:34.016705+00', 153, 7, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2010. Once through as part of a longer demo.', 1, 1, 'Y', 'A3zVbjl5Ljo', 6097, 6177, NULL);
INSERT INTO 'dancevideo' VALUES (7811, '2021-02-04 11:26:34.950154+00', '2021-02-04 11:29:57.64919+00', 5765, 3, 202, '', 'A', '', 1, 1, 'Y', 'w9h9-bcfTUk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7805, '2021-01-31 11:33:31.570477+00', '2021-02-05 21:24:43.496537+00', 2801, 2, 1645, '', 'C', 'Tomsk SCD Festival, Russia.', 1, 1, 'Y', '79KR6EF39Dk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7804, '2021-01-31 11:24:09.243619+00', '2021-02-05 21:25:01.146659+00', 3475, 2, 1645, '', 'C', 'Tomsk SCD Festival, Russia.', 1, 1, 'Y', 'nHmGqTga8Qc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7814, '2021-02-04 12:08:03.251423+00', '2021-02-05 21:26:00.198516+00', 3342, 1, 202, '', 'A', '', 1, 1, 'Y', 'ZvLYDYgll70', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7834, '2021-03-11 19:04:43.466252+00', '2021-03-12 23:21:20.751778+00', 20259, 1, 513, '', 'A', 'Filmed at the Glasgow 95th anniversary celebrations held in Carmichael Hall, East Renfrewshire. The deviser is the man in the left hand trio.', 1, 1, 'Y', 'wPMZRyqQm_M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7819, '2021-02-06 15:08:52.530186+00', '2021-02-06 15:20:19.759933+00', 20082, 3, 223, '', 'B', '', 1, 1, 'Y', 'kmIwusJh5JA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (488, '2012-12-17 14:18:12.070816+00', '2021-02-09 15:50:56.122122+00', 1931, 2, 1296, '', 'D', 'Social situations.  Good dancers, taking some liberty with the figures by adding "embellishments",  good, clear images.  ', 1, 1, 'Y', 'qDMI2dxZvtA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7820, '2021-02-11 18:25:43.35695+00', '2021-02-11 18:29:39.018536+00', 2469, 2, 1645, '', 'A', 'Aberdeen RSDCS at the 2019 Newcastle Festival.', 1, 1, 'Y', 'LjBDIKhuMt4', 258, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7821, '2021-02-12 05:44:37.255099+00', '2021-02-12 05:44:58.367899+00', 11709, 1, 202, '', 'D', '', 1, 1, 'Y', '9RIt6-M59eE', 25, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7822, '2021-02-20 21:27:04.936937+00', '2021-02-20 21:29:15.125331+00', 20221, 1, 1645, '', 'D', '', 1, 1, 'Y', 'F3eej5oFh5I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7823, '2021-02-20 21:28:29.871741+00', '2021-02-20 21:29:31.070192+00', 20221, 2, 1645, '', 'D', 'The dancing starts at bar 17.', 1, 1, 'Y', 'qlSGt7_plGA', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7824, '2021-02-27 01:37:05.950752+00', '2021-02-27 09:12:28.449605+00', 7189, 2, 562, '', 'C', '''The Winding Road'' was danced at the AWEsome dance in Lower Hutt, New Zealand, on October 3, 2015.', 1, 1, 'Y', 'pMMrBefvVQs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7825, '2021-02-28 15:23:35.778031+00', '2021-02-28 15:24:50.953465+00', 10279, 1, 202, '', 'B', '', 1, 1, 'Y', 'I75DPgjvgkk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7826, '2021-02-28 17:02:11.371389+00', '2021-02-28 17:02:24.898994+00', 1473, 11, 202, '', 'B', '', 1, 1, 'Y', 'RP-nGPxVcPA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7827, '2021-02-28 17:05:02.07397+00', '2021-02-28 17:05:13.922571+00', 2321, 2, 202, '', 'B', '', 1, 1, 'Y', 'meTnph5gMtU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7828, '2021-02-28 17:06:35.454202+00', '2021-02-28 17:06:47.553908+00', 3594, 8, 202, '', 'B', '', 1, 1, 'Y', 'UZj7sUR0abo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7829, '2021-02-28 17:11:01.850397+00', '2021-02-28 17:11:27.287436+00', 445, 13, 202, '', 'B', '', 1, 1, 'Y', 'OsPjU5q7L38', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7830, '2021-02-28 17:38:00.184975+00', '2021-02-28 17:38:10.078679+00', 4032, 6, 202, '', 'B', '', 1, 1, 'Y', 'Zgfuc2DSkuw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7831, '2021-02-28 22:58:09.941024+00', '2021-03-01 00:25:46.65433+00', 4781, 2, 3086, '', 'A', '', 1, 1, 'Y', 'uUw7_0tIURY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7832, '2021-03-01 02:30:24.734276+00', '2021-03-01 11:14:02.586727+00', 14363, 1, 35795, '', 'A', 'An 8 x 32 bar reel devised by John Brenchley to celebrate the joint 50th birthdays of Audrey and Robin Emmett in March 2010, Perth, Western Australia', 1, 1, 'Y', 'ioWZum6uYRY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7833, '2021-03-03 12:28:21.221962+00', '2021-03-03 13:31:11.693517+00', 1001, 2, 3086, '', 'A', '', 1, 1, 'Y', 'T_nVLCJHp0o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7835, '2021-03-12 01:40:03.088391+00', '2021-03-12 01:40:03.088391+00', 107, 1, 1296, '', 'X', '''Allt An Duin'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'KHSQ_sO__5U', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7836, '2021-03-12 01:40:03.118287+00', '2021-03-12 01:40:03.118287+00', 6995, 2, 1296, '', 'X', '''Wee Cooper O'' Fife, The'' is a 40 bar jig for 2 couples in a 4 couple set.', 1, 1, 'Y', 'DiyvWBJtkqA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7837, '2021-03-12 01:40:03.141399+00', '2021-03-12 01:40:03.141399+00', 10548, 4, 1296, '', 'X', '''Waternish Tangle, The'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'Fn_plNwQv5I', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7838, '2021-03-12 23:33:30.58141+00', '2021-03-12 23:35:30.939643+00', 5209, 12, 197, '', 'A', 'Video of the Ochil Scottish Country Dancers, June 2017  at St Ninian''s Church Hall, Stirling, Scotland. 

Video shows 2x32 bars only with 1st couple dancing from 1st and 2nd places.', 1, 1, 'Y', '12tADZYCXi0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7839, '2021-03-13 01:40:03.377459+00', '2021-03-13 01:40:03.377459+00', 904, 2, 1296, '', 'X', '''Cabrach, The'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', '_BA81KtRYJI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7840, '2021-03-13 01:40:03.421952+00', '2021-03-13 01:40:03.421952+00', 1758, 2, 1296, '', 'X', '''Drumelzier'' is a 32 bar strathspey for 4 couples in a 4 couple set.', 1, 1, 'Y', '-6GwSxoaMCg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7841, '2021-03-14 16:59:49.479011+00', '2021-03-14 17:03:52.109507+00', 4015, 5, 342, '', 'X', '', 1, 1, 'Y', 'SdVFpwhqBXI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7843, '2021-03-20 21:59:07.229506+00', '2021-03-21 00:10:02.063418+00', 6585, 1, 562, '', 'A', 'Dunedin Dancers (Edinburgh) dancing in Stirling 2011.', 1, 1, 'Y', 'A4gUkumiZTU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7844, '2021-03-20 21:59:46.085746+00', '2021-03-21 00:18:56.950681+00', 6585, 2, 562, '', 'A', 'RSCDS Newcastle at the Morpeth Gathering.', 1, 1, 'Y', 'ZMsJ_J15JRw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7845, '2021-03-22 16:45:02.731643+00', '2021-03-22 16:58:12.428894+00', 16012, 1, 1645, '', 'C', 'Santa Cruz group from San Francisco RSCDS. Good dancing but rather limited view. Twice through in a 3 couple set with 1st couple turning to the bottom between chain progression and circle.', 1, 1, 'Y', 'a42G9iRlBoM', 0, 70, NULL);
INSERT INTO 'dancevideo' VALUES (7846, '2021-03-22 16:51:19.695012+00', '2021-03-22 16:59:53.031399+00', 9922, 1, 1645, '', 'C', 'Santa Cruz group from San Francisco RSCDS. Good dancing but rather limited view. Twice through in a 3 couple set.', 1, 1, 'Y', 'a42G9iRlBoM', 193, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7847, '2021-03-26 16:39:05.494264+00', '2021-03-26 18:38:43.14455+00', 8453, 1, 2824, '', 'X', '(Contrary to standard diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', '9yeunMx_qbk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7848, '2021-03-26 16:42:56.791484+00', '2021-03-26 18:40:43.932676+00', 9638, 9, 2824, '', 'X', '(Contrary to standard diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', 'wOmNxk1CYQo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7849, '2021-03-26 16:44:20.660965+00', '2021-03-26 18:42:44.271199+00', 11586, 2, 2824, '', 'X', '(Contrary to standard diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', 'alw4j6tusvU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7850, '2021-03-26 16:48:20.635408+00', '2021-03-26 18:44:51.017473+00', 2365, 1, 2824, '', 'X', '(Contrary to standard diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', '14Liy9P1o1w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7851, '2021-03-26 16:54:14.011175+00', '2021-03-26 18:46:37.211406+00', 13394, 1, 2824, '', 'X', '(Contrary to standard diagram notation the men are represented by rectangles, the ladies by oval-ish shapes)', 1, 1, 'Y', 'g2szI1DkoQA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7852, '2021-03-26 16:57:37.993885+00', '2021-03-26 18:48:25.054319+00', 13852, 1, 2824, '', 'X', '(Contrary to standard diagram notation the men are represented by rectangles, the ladies by oval-ish shapes)', 1, 1, 'Y', 'E-bG3TC4bi4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7853, '2021-03-26 17:05:03.117944+00', '2021-03-26 18:50:09.929931+00', 3705, 1, 2824, '', 'X', '(Contrary to standard diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', 'xkKHmzTYARo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7854, '2021-03-27 20:17:56.996574+00', '2021-03-27 20:20:29.864543+00', 20147, 1, 1645, '', 'B', 'Auckland NZ. Danced to the recommended (non-SCD) music...', 1, 1, 'Y', '5Bz3LtdDFgU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7856, '2021-03-27 20:42:45.529992+00', '2021-03-27 20:43:00.84632+00', 20234, 1, 1645, '', 'C', 'Waikato group (Auckland, NZ).', 1, 1, 'Y', 'RA8K-BnqEZE', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7855, '2021-03-27 20:37:15.20517+00', '2021-03-27 20:44:03.354252+00', 20285, 1, 1645, '', 'B', 'Demonstration by the Lapa group in Lisbon 2015.', 1, 1, 'Y', '3Zzjnh9o7Dw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7857, '2021-03-27 22:27:04.341252+00', '2021-03-27 22:54:08.945329+00', 14655, 1, 1645, '', 'C', 'Méaudre ball 2019.', 1, 1, 'Y', 'aXkVVtXjo30', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7899, '2021-04-06 20:06:31.86656+00', '2021-04-06 20:27:54.47874+00', 9104, 4, 1645, '', 'B', 'Novosibirsk 2018.', 1, 1, 'Y', '-htkG9J0j2Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7871, '2021-03-31 19:34:49.45123+00', '2021-04-01 19:46:39.367133+00', 7284, 7, 1645, '', 'B', 'Twice through extract as the first part of the women''s demo at the St Andew''s Society of Singapore Ball 2015.', 1, 1, 'Y', 'XjwhlwnohFc', 34, 164, NULL);
INSERT INTO 'dancevideo' VALUES (7860, '2021-03-29 06:10:07.215498+00', '2021-03-29 13:57:27.759391+00', 542, 5, 35822, '', 'B', 'Note:  Danced twice through in a 2C set, one time for each couple.  In a social dance context however, the 1st couple would dance again from second place, and then third place to finish at the foot of the set.  



Excellent dancing (from Canberra) though using "See You Down Under" rather than the recommended music.', 1, 1, 'Y', 'd4VrPZ6Dzms', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7879, '2021-03-31 22:53:10.898936+00', '2021-04-01 19:59:45.514771+00', 5122, 2, 1645, '', 'B', 'Demonstration by the Girls Team at the St Andrews Society of Singapore 2012.', 1, 1, 'Y', 'TNZy5iWI6zk', 17, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7861, '2021-03-30 11:48:41.987502+00', '2021-03-30 11:52:28.743084+00', 20287, 1, 1645, '', 'A', 'Red Thistle Dancers demo (2018).', 1, 1, 'Y', 'fmN0dQpsRKk', 529, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7862, '2021-03-30 11:50:52.101398+00', '2021-03-30 11:53:01.220127+00', 20287, 2, 1645, '', 'A', 'Red Thistle Dancers demo at the 2019 Pleasanton Highland Games. This clip starts with the dancing. The whole video has a short introduction.', 1, 1, 'Y', 'Lt93HZqIebc', 25, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7863, '2021-03-30 19:58:12.077295+00', '2021-03-30 20:07:55.143387+00', 20288, 1, 1645, '', 'C', 'Burns Night 2018 at Deer O''Dale Dance School (Ufa, Russia).', 1, 1, 'Y', 'CJmzsAutTK4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7864, '2021-03-30 21:50:59.713608+00', '2021-03-30 21:56:35.443981+00', 20290, 1, 1645, '', 'B', 'Danced in a small space during the 2020 pandemic.', 1, 1, 'Y', 'mQtA_d8acpY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1337, '2013-08-18 10:55:54.749335+00', '2021-03-31 17:40:38.140805+00', 5529, 9, 1296, '', 'B', 'Silver State Scottish Dancers at the Reno Celtic Celebration 2012.', 1, 1, 'Y', 'NOexJkLtaPg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7865, '2021-03-31 17:46:38.132076+00', '2021-03-31 18:42:37.928518+00', 16645, 1, 963, '', 'C', 'The ''celebration'' should be on bar 28 and the chase should start on bar 29 so the men can get home.', 1, 1, 'Y', 'uNPvRLnAqKM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7875, '2021-03-31 21:37:03.006268+00', '2021-04-01 19:48:55.254736+00', 8211, 1, 1645, '', 'B', 'Demonstration by the Girls Dance Team 2 (8 yrs) at the St Andrews Society of Singapore 2007.', 1, 1, 'Y', 'LU11h-S4-Mk', 18, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7880, '2021-04-01 17:05:51.752427+00', '2021-04-01 17:07:39.306527+00', 19938, 3, 1645, '', 'B', 'Demonstration of a dance for Ward Fleri presented at the San Diego Branch 45th anniversary in March 2020. Danced to the newly composed tune, Ward Fleri of San Diego.



This clip shows one complete repeat of the dance (the video starts part way through an earlier one).', 1, 1, 'Y', 'XdqsvOr3THc', 28, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7874, '2021-03-31 21:13:14.886795+00', '2021-04-01 19:50:14.150827+00', 20291, 1, 1645, '', 'A', 'Demonstration dance from the St Andrews Society of Singapore Ball 2007.', 1, 1, 'Y', 'dNnuRrZR5vc', 38, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7867, '2021-03-31 18:06:27.094481+00', '2021-04-01 20:01:12.438806+00', 5525, 23, 1645, '', 'B', 'All male demo with highland style setting at the Singapore ball 2015. Six times through in a three couple set.', 1, 1, 'Y', 'NaC3nWINHSU', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7876, '2021-03-31 22:04:19.666817+00', '2021-04-01 19:51:23.849376+00', 12952, 1, 1645, '', 'B', 'Demonstration by the Girls Dance Team 1 (10 yrs) at the St Andrews Society of Singapore 2007.', 1, 1, 'Y', 'd9MpCM2fJZU', 18, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7872, '2021-03-31 19:46:35.008947+00', '2021-04-01 19:52:59.400922+00', 13247, 1, 1645, '', 'B', 'Ladies'' Dance Team demonstration at the St Andrews Society of Singapore Ball 2014.', 1, 1, 'Y', 'FazsNawZk0E', 60, 214, NULL);
INSERT INTO 'dancevideo' VALUES (7866, '2021-03-31 17:54:26.015881+00', '2021-04-01 19:53:30.935687+00', 4282, 3, 1645, '', 'B', 'Stage performance at the Highland Gathering in Jakarta 2012.', 1, 1, 'Y', 'VbVuanN8fls', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7878, '2021-03-31 22:44:16.398935+00', '2021-04-01 19:54:07.007823+00', 4282, 4, 1645, '', 'B', 'Demonstration by the "Ladies'' Dance Team + one" at the St Andrews Society of Singapore Ball 2008. Excellent dancing though in the reel section here the women are doing rather more than in the instructions.', 1, 1, 'Y', '3k9Z6LWITRM', 40, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7877, '2021-03-31 22:24:00.547209+00', '2021-04-01 19:54:33.79464+00', 4782, 4, 1645, '', 'C', 'Demonstration by the Childrens Mixed Dance Team at the St Andrews Society of Singapore 2005.', 1, 1, 'Y', 'RiX8o37HQUo', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7869, '2021-03-31 19:29:57.083549+00', '2021-04-01 19:55:33.521917+00', 4844, 6, 1645, '', 'B', 'Twice through extract as part of the women''s demo at the St Andew''s Society of Singapore Ball 2015.', 1, 1, 'Y', 'XjwhlwnohFc', 233, 304, NULL);
INSERT INTO 'dancevideo' VALUES (7870, '2021-03-31 19:32:05.486665+00', '2021-04-01 19:56:03.220433+00', 5326, 6, 1645, '', 'B', 'Twice through extract as part of the women''s demo at the St Andew''s Society of Singapore Ball 2015.', 1, 1, 'Y', 'XjwhlwnohFc', 163, 234, NULL);
INSERT INTO 'dancevideo' VALUES (7873, '2021-03-31 19:55:14.014771+00', '2021-04-01 20:02:40.677941+00', 6185, 1, 1645, '', 'A', 'Ladies'' Dance Team demonstration at the St Andrews Society of Singapore Ball 2013.', 1, 1, 'Y', 'qxPUt6XZ5rY', 29, 255, NULL);
INSERT INTO 'dancevideo' VALUES (7868, '2021-03-31 18:52:13.692063+00', '2021-04-01 19:58:51.128225+00', 5800, 2, 1645, '', 'A', 'Twice through extract as the last part of the women''s demo at the St Andew''s Society of Singapore Ball 2015.', 1, 1, 'Y', 'XjwhlwnohFc', 303, 380, NULL);
INSERT INTO 'dancevideo' VALUES (1243, '2013-08-18 10:55:37.202316+00', '2021-04-01 22:47:30.136591+00', 4046, 5, 1296, '', 'Z', 'Poor image quality (not sharp).



Video now marked as private.', 1, 1, 'Y', 'upR99JiTFQQ', 118, 260, NULL);
INSERT INTO 'dancevideo' VALUES (7886, '2021-04-02 10:41:30.742146+00', '2021-04-02 10:42:35.417091+00', 7139, 4, 1645, '', 'B', 'San Jose social class at the Pleasanton Scottish Games 2011. Twice through as the last part of a longer demonstration.', 1, 1, 'Y', 'mxo9M-e0RpQ', 261, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7885, '2021-04-02 10:34:27.113166+00', '2021-04-02 10:44:13.485679+00', 2453, 3, 1645, '', 'B', 'San Jose social class at the Pleasanton Scottish Games 2011. Twice through as the first part of a longer demonstration. The end of the second repeat is slightly adjusted to lead into the next dance.', 1, 1, 'Y', 'mxo9M-e0RpQ', 58, 134, NULL);
INSERT INTO 'dancevideo' VALUES (7883, '2021-04-01 22:58:15.906812+00', '2021-04-02 10:44:59.091159+00', 13771, 3, 1645, '', 'B', 'Warwick 2017. Rather narrow view.', 1, 1, 'Y', 'ZfGACw2Ypn4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7882, '2021-04-01 22:41:41.92247+00', '2021-04-02 10:45:24.220762+00', 3119, 7, 1645, '', 'B', 'Aurora Scottish Dance and Music (Aberdeen) in 2018.', 1, 1, 'Y', 'xyvI9nSSxOA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7881, '2021-04-01 22:38:04.554678+00', '2021-04-02 10:46:16.991621+00', 5080, 3, 1645, '', 'C', 'New Haven. A bit less than twice through. The video starts around bar 4 of one repeat and ends before the closing rights & lefts of the second repeat but is a pretty clear rendition.', 1, 1, 'Y', 'n7RajlYOqc0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7887, '2021-04-02 11:25:54.199633+00', '2021-04-03 10:23:06.489751+00', 7465, 4, 1645, '', 'C', 'Summer School in Nelson, New Zealand 2018.', 1, 1, 'Y', 'jjLKHuSZ1mw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7892, '2021-04-03 15:58:52.26723+00', '2021-04-03 15:59:17.442821+00', 19307, 2, 1645, '', 'B', 'Lapa group in Lisbon in 2019. Twice through as the last part of a longer demo.', 1, 1, 'Y', 'QvavTcdiX64', 71, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7891, '2021-04-03 15:58:14.819823+00', '2021-04-03 15:59:48.496553+00', 2228, 4, 1645, '', 'B', 'Lapa group in Lisbon in 2019. Twice through as the first part of a longer demo.', 1, 1, 'Y', 'QvavTcdiX64', 0, 72, NULL);
INSERT INTO 'dancevideo' VALUES (7890, '2021-04-03 12:46:33.597575+00', '2021-04-03 16:00:19.712941+00', 19231, 1, 1645, '', 'C', 'Lapa group in Lisbon 2014. A good demo with occasional "variations".', 1, 1, 'Y', 'SM9R4CQpUyE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7884, '2021-04-02 09:54:35.959987+00', '2021-04-03 16:00:32.665564+00', 5471, 1, 1645, '', 'D', 'Baton Rouge 2008. A bit less than twice through in a dark setting. The video starts around bar 9.', 1, 1, 'Y', 'IWDiwaiZwiU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7888, '2021-04-03 10:49:28.418821+00', '2021-04-03 16:00:44.831713+00', 9800, 6, 1645, '', 'B', 'Charlotte N.Carolina. Twice through.', 1, 1, 'Y', 'Dpw1VZHVoi8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7889, '2021-04-03 10:50:39.035603+00', '2021-04-03 16:01:13.487281+00', 9800, 7, 1645, '', 'B', 'Summer School 2018/19 in Nelson New Zealand.', 1, 1, 'Y', 'dy76lWCJJSs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7893, '2021-04-03 16:07:09.146785+00', '2021-04-03 16:07:44.060178+00', 549, 7, 1645, '', 'B', 'Island Bay Scottish Country Dance Club, New Zealand 2017.', 1, 1, 'Y', 'fiWqbbGUUFE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7894, '2021-04-03 21:35:40.578497+00', '2021-04-03 21:37:42.019138+00', 6734, 6, 1645, '', 'A', 'German mixed team at the 2019 Newcastle Festival.', 1, 1, 'Y', 'smyR_maJydY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7895, '2021-04-04 10:36:04.757254+00', '2021-04-06 20:28:20.767771+00', 6585, 3, 1645, '', 'A', 'Festival Interceltique de Lorient 2007.', 1, 1, 'Y', 'nbGanaws0t0', 239, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7896, '2021-04-06 20:04:01.622372+00', '2021-04-06 20:34:16.676833+00', 14685, 3, 2824, '', 'A', '', 1, 1, 'Y', '_UtCa6JWkqg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7898, '2021-04-06 20:05:49.117959+00', '2021-04-06 20:32:57.079698+00', 10232, 6, 2824, '', 'A', '', 1, 1, 'Y', 'NY5mOqU54uc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7897, '2021-04-06 20:05:35.413637+00', '2021-04-06 20:26:59.935277+00', 9104, 3, 1645, '', 'C', 'Deer O''Dance School in Ufa, Russia 2018. The video starts one or two bars into the dance.', 1, 1, 'Y', 'Ir5HyFdvoA4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7907, '2021-04-07 11:34:12.259526+00', '2021-04-07 11:54:52.625094+00', 11371, 2, 2824, '', 'A', 'Twice through; dem at Younger Hall.', 1, 1, 'Y', 'Z50I63dx-p4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7908, '2021-04-07 20:25:47.8821+00', '2021-04-07 20:27:20.187283+00', 2632, 2, 1645, '', 'B', 'Bellingham Scottish Country Dancers Demonstration Team. Skagit Valley Highland Games & Celtic Festival, July 8, 2017. Twice through, starting around bar 2.', 1, 1, 'Y', 'cI6iOymJcsY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7910, '2021-04-07 21:50:22.975991+00', '2021-04-07 21:58:27.959738+00', 570, 2, 1645, '', 'B', 'Berkhamsted 2019 tribute to Derek and Maureen Haynes. Twice through as the middle part of a longer demo.', 1, 1, 'Y', 'l2m_bWMlGNc', 75, 199, NULL);
INSERT INTO 'dancevideo' VALUES (7909, '2021-04-07 21:43:22.271172+00', '2021-04-07 21:59:45.5351+00', 708, 2, 1645, '', 'B', 'Berkhamsted 2019 tribute to Derek and Maureen Haynes. Twice through as the first part of a longer demo.', 1, 1, 'Y', 'l2m_bWMlGNc', 4, 76, NULL);
INSERT INTO 'dancevideo' VALUES (7911, '2021-04-07 21:53:12.891742+00', '2021-04-07 21:59:59.841778+00', 4236, 2, 1645, '', 'B', 'Berkhamsted 2019 tribute to Derek and Maureen Haynes. Twice through as the last part of a longer demo.', 1, 1, 'Y', 'l2m_bWMlGNc', 198, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7906, '2021-04-06 21:38:29.719107+00', '2021-04-07 22:01:10.958077+00', 20306, 1, 1645, '', 'D', 'Bellingham Scottish Country Dancers (Washington State, USA) 2017.', 1, 1, 'Y', 'RyPv-5kbRYk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7912, '2021-04-07 23:38:51.446924+00', '2021-04-07 23:42:26.314388+00', 20307, 1, 1645, '', 'B', 'Demonstration at the Oxford Cambridge Highland Ball 2019. Twice through as part of a longer demo. The last 8 bars of the 1st repeat are adapted to change the orientation of the set and the end of the 2nd repeat is also changed to lead into the next dance in the demo.', 1, 1, 'Y', 'zpuE_3w6YRk', 101, 191, NULL);
INSERT INTO 'dancevideo' VALUES (7913, '2021-04-10 23:12:42.359479+00', '2021-04-10 23:15:28.147343+00', 1931, 12, 1, '', 'R', 'At the Ghillies Ball at Balmoral, featuring the royal family. Unlike some others, the Queen is visibly enjoying herself, and the Princess Royal is positively exuberant towards the end.', 1, 1, 'Y', 'uyVZCiPGeYQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7914, '2021-04-12 00:40:03.240436+00', '2021-04-12 00:40:03.240436+00', 2263, 3, 1296, '', 'X', '''Flying Spur, The'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'vSy2ea0dwWE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7915, '2021-04-12 00:40:03.271957+00', '2021-04-12 00:40:03.271957+00', 822, 5, 1296, '', 'X', '''Broadford Bay'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', '6z3_IDGW3VQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7916, '2021-04-13 00:40:06.760947+00', '2021-04-13 00:40:06.760947+00', 2332, 3, 1296, '', 'X', '''Fraser''s Favourite'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'x6nAI-vXY6o', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7917, '2021-04-13 00:40:06.795896+00', '2021-04-13 00:40:06.795896+00', 5480, 3, 1296, '', 'X', '''Ray Milbourne'' is a 32 bar reel for 4 couples in a 4 couple set.', 1, 1, 'Y', '4HA9uY2FsNY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7918, '2021-04-13 15:08:59.198845+00', '2021-04-13 20:31:50.299853+00', 1066, 3, 2824, '', 'D', '', 1, 1, 'Y', 'PzTVKXN-_8Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7919, '2021-04-13 15:25:31.568244+00', '2021-04-13 20:33:38.233788+00', 13847, 5, 2824, '', 'D', '', 1, 1, 'Y', 'U4-xTWe7HBg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7920, '2021-04-13 15:41:09.556628+00', '2021-04-13 20:35:30.025758+00', 19737, 1, 2824, '', 'D', 'Once through (camera angle is a bit too low and close to the set)', 1, 1, 'Y', 'IvU2Rr1C3uc', 285, 322, NULL);
INSERT INTO 'dancevideo' VALUES (7921, '2021-04-13 15:59:48.276943+00', '2021-04-13 20:44:05.659744+00', 5703, 5, 2824, '', 'B', 'Twice through; the video contains audio and on screen instructions.', 1, 1, 'Y', 'tQGd-X9UKCM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7922, '2021-04-13 16:04:53.255676+00', '2021-04-13 20:45:21.847231+00', 11524, 3, 2824, '', 'B', 'Twice through. Video contains audio and on screen instructions.', 1, 1, 'Y', 'hMLD7rrAPHE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7923, '2021-04-13 16:09:22.292419+00', '2021-04-13 20:46:49.528258+00', 17897, 4, 2824, '', 'B', 'Twice through. Video contains audio and on screen instructions.', 1, 1, 'Y', 'uWy4E3gSP6A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7924, '2021-04-13 16:13:28.390365+00', '2021-04-13 20:48:27.541341+00', 2924, 5, 2824, '', 'B', 'Twice through. Video contains audio and on screen instructions.', 1, 1, 'Y', 'YxIW5HHHHAs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7925, '2021-04-13 16:19:54.011464+00', '2021-04-13 20:51:00.756103+00', 4782, 5, 2824, '', 'B', 'Twice through. Video contains audio and on screen instructions.', 1, 1, 'Y', 'sksDXlYQH00', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7926, '2021-04-13 16:22:53.015559+00', '2021-04-13 20:54:45.175573+00', 522, 5, 2824, '', 'B', 'Twice through. Video contains audio and on screen instructions.', 1, 1, 'Y', 'ubjCFEWasCo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7927, '2021-04-13 17:25:05.992431+00', '2021-04-13 20:58:18.28185+00', 5964, 4, 2824, '', 'A', 'Twice through. Video contains audio and on screen instructions. Demonstration by RSCDS Stirling  Branch at Princes St Gardens, Edinburgh on 22 June 2009.', 1, 1, 'Y', 'XDNDtKj_-k8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7928, '2021-04-13 17:29:52.264171+00', '2021-04-13 21:00:18.228587+00', 3963, 2, 2824, '', 'A', 'Twice through. Video contains audio and on screen instructions. Demonstration by RSCDS Stirling Branch at Princes St Gardens on 22 June 2009.', 1, 1, 'Y', 'NxTGD-iE9V4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7929, '2021-04-13 17:34:31.811146+00', '2021-04-13 21:02:23.49254+00', 11773, 5, 2824, '', 'A', 'Twice through. Video contains audio and on screen instructions. Demonstration by the RSCDS Stirling Branch at Princes Street Gardens /Edinburgh. ', 1, 1, 'Y', 'Ccql9ivrQlA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7930, '2021-04-13 17:50:11.861236+00', '2021-04-13 21:05:03.751176+00', 4796, 5, 2824, '', 'A', '', 1, 1, 'Y', '9pVpJxilS9I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7931, '2021-04-15 01:10:44.781719+00', '2021-04-15 08:25:17.62996+00', 19938, 2, 562, '', 'B', '', 1, 1, 'Y', 'KYZARWsde50', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7935, '2021-04-21 09:00:21.679087+00', '2021-04-21 20:45:31.620664+00', 5688, 3, 35776, '', 'D', 'Johnsonville Club Tartan Night 19 April 2021

The first few bars were not recorded

(the video starts around bar 8).', 1, 1, 'V', '539476109', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7932, '2021-04-16 23:01:32.82126+00', '2021-04-17 18:07:03.700623+00', 19192, 1, 202, '', 'D', '', 1, 1, 'Y', 'rjlfy2MSpT0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7933, '2021-04-18 12:38:59.096425+00', '2021-04-21 20:36:44.189058+00', 4862, 3, 2824, '', 'D', 'Compilation video of smaller and larger groups of dancers participating in the 4th Robert Burns online flash mob to connect dancers on the occasion of Burns Night 2021 (organised by Moscow Branch and Saratov Club ''Falcor'').', 1, 1, 'Y', 'XlJJI40PqWQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7937, '2021-04-21 09:05:36.221582+00', '2021-04-21 20:39:43.645678+00', 19286, 1, 35776, '', 'D', 'Johnsonville Club Tartan Night 19 April 2021', 1, 1, 'V', '539482804', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7936, '2021-04-21 09:02:53.558618+00', '2021-04-21 20:41:34.319119+00', 13617, 2, 35776, '', 'D', 'Johnsonville Club Tartan Night 19 April 2021', 1, 1, 'V', '539479790', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7939, '2021-04-25 19:37:15.168509+00', '2021-04-26 08:40:09.964322+00', 3937, 1, 3086, '', 'A', 'RSCDS Edinburgh. Three times through demonstration with adaptations of the final circle to switch from one 4 couple set to two 3 couple sets and then to change the orientation of those. The camera angle also switches between different views.', 1, 1, 'Y', 'hvGT8Zonqzk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7934, '2021-04-21 02:09:45.061766+00', '2021-04-21 20:51:27.104995+00', 13892, 1, 35822, '', 'B', '', 1, 1, 'Y', 'yxQYQTiWW4E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7938, '2021-04-23 09:19:34.349238+00', '2021-04-23 09:21:26.154077+00', 8112, 1, 1645, '', 'B', 'Capital City club, Wellington, New Zealand 2021. Four times through.', 1, 1, 'Y', 'B8bMMRKpuSQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7940, '2021-04-28 12:01:40.990941+00', '2021-04-28 12:01:56.166942+00', 6811, 1, 202, '', 'A', '', 1, 1, 'Y', 'ieDEmpuuCh0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7941, '2021-04-28 12:04:00.439828+00', '2021-04-28 12:04:13.72899+00', 11369, 7, 202, '', 'A', '', 1, 1, 'Y', 'mJXzDbvQwys', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7942, '2021-05-01 06:12:59.920317+00', '2021-05-01 06:16:38.400285+00', 20325, 1, 202, '', 'D', '', 1, 1, 'Y', 'avxVhQiHQeI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7943, '2021-05-01 23:15:59.86307+00', '2021-05-01 23:16:10.980439+00', 3614, 1, 1645, '', 'A', 'Ladies step display at RSCDS Summer School 2001.', 1, 1, 'Y', '5c-sVwTrG3c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7944, '2021-05-04 16:18:26.93062+00', '2021-05-04 16:21:49.030061+00', 17462, 2, 106, '', 'C', 'In a 5 couple set.  understandably, nearly every chase finishes late, but the set always recovers.', 1, 1, 'Y', 'uXohUAKtSN0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7946, '2021-05-04 16:29:07.616702+00', '2021-05-04 16:31:26.08966+00', 11828, 1, 1645, '', 'C', 'Unigarka Sole Dance (Omsk, Russia). Demo in a bar with roving camera so rarely showing the whole set. The back to back is often just two bars after extra setting.', 1, 1, 'Y', '9KOTM12AP4Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3287, '2017-10-20 22:00:36.827213+00', '2021-05-06 23:30:10.776206+00', 16885, 1, 1645, '', 'C', 'View from the top of the set. Twice through.

The tricky bars 17-24 were causing a little confusion here and there.

', 1, 1, 'Y', 'Gu9Wu4DrL1w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7947, '2021-05-07 23:46:07.958514+00', '2021-05-08 00:16:47.586659+00', 1562, 9, 562, '', 'A', 'Instructional/demonstration video

The Dashing White Sergeant - learn the steps with Robbie Shepherd', 1, 1, 'Y', 'Wm_5l_bs-6Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3624, '2018-09-08 19:28:23.127573+00', '2021-05-14 09:37:59.22802+00', 18272, 1, 954, '', 'B', 'This is the fourth dance of a dïsplay. The first 8 bars have been modified as they are part of the linkage to the preceding 3C dance.  The final bars of once through are cut off by the next transition.



Excellent dancing but graded as Good because of all the choreography changes.', 1, 1, 'Y', 'bx3_Wzp_4Uc', 262, 297, NULL);
INSERT INTO 'dancevideo' VALUES (7948, '2021-05-09 19:13:00.645746+00', '2021-05-09 19:49:16.710895+00', 20331, 1, 202, '', 'C', ' sophie marchand    10 abonnées



Thoughts of Romance est une danse crée par les ados du Méaudre Reel pendant cette période de COVID où nous ne pouvions pas danser. Elle est à retrouver dans le "Dancing in Vercors, Book 1"





Nous avons pu re danser ce samedi 8 mai 2021 en extérieur devant nos montagnes, et tester nos danses. Malgré les gestes barrières, nous avons pris beaucoup de plaisir et le sourire était derrière.', 1, 1, 'Y', 'PBLI-evZTNw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7950, '2021-05-10 20:40:07.159935+00', '2021-05-10 20:41:21.33664+00', 14723, 2, 1645, '', 'B', 'Oxford Highland Ball 2017. The camera is a bit too close to see the whole set. Twice through.', 1, 1, 'Y', 'BxrUvO3maYc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7953, '2021-05-12 21:24:39.930083+00', '2021-05-13 19:32:14.920576+00', 17250, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', 'GUJvGtH_1Jc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7954, '2021-05-12 21:27:34.798507+00', '2021-05-13 19:32:19.612716+00', 6964, 9, 1645, '', 'X', '(Contrary to standard diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', 'yPak-l7qQDg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7951, '2021-05-12 21:11:32.863517+00', '2021-05-13 19:32:26.76486+00', 11587, 4, 1645, '', 'C', 'Lower Hutt Musicians Tea Dance October 2020. Good view of one set twice through then the camera moves to and from the musicians.', 1, 1, 'Y', 'fWYSl_gorGs', 9, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7970, '2021-05-14 19:48:08.529572+00', '2021-05-14 19:48:39.475649+00', 14903, 3, 1645, '', 'A', 'Charlotte, North Carolina, 2018. Twice through.', 1, 1, 'Y', 'B6h9iyUHlP8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7958, '2021-05-13 21:40:22.758625+00', '2021-05-14 19:48:56.780491+00', 16767, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', 'Yk9WdyLwbGs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7961, '2021-05-13 22:01:24.7918+00', '2021-05-14 19:49:03.80383+00', 1038, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', 'b6yi2FmUkIc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7962, '2021-05-13 22:07:43.51715+00', '2021-05-14 19:49:13.764201+00', 1038, 2, 1645, '', 'C', 'Ojai, California 2019. Danced to music on a CD by Steve Wyrick in memory of him.



The camera angle is rather close so the full set is not in view.', 1, 1, 'Y', '3p7ehMzCXnU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7963, '2021-05-13 22:14:52.806034+00', '2021-05-14 19:50:05.845362+00', 8045, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes)

', 1, 1, 'Y', '3vYQ6Uz8O40', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7956, '2021-05-13 20:09:18.663419+00', '2021-05-14 19:49:54.723743+00', 14552, 4, 1645, '', 'B', 'Méaudre Reel under 16s at Newcastle Festival 2018.', 1, 1, 'Y', 'Ip7lejZEMWs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7957, '2021-05-13 21:36:58.625387+00', '2021-05-14 19:50:11.135618+00', 15358, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', 'YtTTJUImOPE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7966, '2021-05-13 22:39:16.314374+00', '2021-05-14 19:50:31.55239+00', 10505, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes)



At one point the voiceover mentions "turn half" whereas the text (and instructions) have full turn.', 1, 1, 'Y', 'SoKWc_sKCCI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7967, '2021-05-13 22:49:47.875014+00', '2021-05-14 19:50:43.488622+00', 12594, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes)



In the turn corner partner figure (bars 9-16) the video has a left hand pass in bars 11-12 instead of a one and a quarter turn.', 1, 1, 'Y', 'dkYsXFuZw48', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7968, '2021-05-13 22:53:22.843876+00', '2021-05-14 19:50:48.453312+00', 17255, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', '8uMwooIi9ks', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7960, '2021-05-13 21:57:42.318+00', '2021-05-14 19:50:58.345408+00', 5963, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes).



The set to and turn corners of bars 17-24 is here shown with 1st couple on opposite sidelines and turning right hand rather than the usual expectation of facing corners and turning with both hands in strathspey.', 1, 1, 'Y', 'lTwoYlFkMIc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7959, '2021-05-13 21:44:59.137132+00', '2021-05-14 19:51:03.587589+00', 20041, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', 'q-Ob0KX8rl0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7969, '2021-05-13 22:57:31.324147+00', '2021-05-14 19:51:09.459673+00', 16384, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', 'qIWGGVwIyhM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7971, '2021-05-14 19:58:55.008082+00', '2021-05-14 19:59:08.828532+00', 14903, 4, 1645, '', 'B', 'Demo from RSCDS summer school 2018. Superb dancing but here it is slightly adapted as a five couple dance. Twice through ending with a flourish.', 1, 1, 'Y', 'uKrIlEnca7I', 271, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7972, '2021-05-18 08:26:49.488263+00', '2021-05-18 08:35:36.233443+00', 3441, 2, 2824, '', 'B', 'RSCDS Holburn Westies at Aberdeen festival 2017', 1, 1, 'Y', 'GbgVDjaU3lk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7973, '2021-05-18 08:38:16.138617+00', '2021-05-18 08:46:45.537435+00', 4461, 3, 2824, '', 'A', 'Aberdeen Festival 2019', 1, 1, 'Y', 'G0oktPGpTyQ', 265, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7977, '2021-05-18 09:05:57.431279+00', '2021-05-18 10:22:30.386066+00', 6621, 1, 2824, '', 'B', 'Bramble Brae School at Aberdeen Festival 2018', 1, 1, 'Y', 'm8h5Qd7dz44', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3392, '2018-01-08 14:29:15.080511+00', '2021-05-18 16:46:07.961801+00', 1223, 8, 106, '', 'B', '', 1, 1, 'Y', 'tvHNVDP11lY', 128, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7975, '2021-05-18 08:49:19.874757+00', '2021-05-18 10:30:31.557077+00', 4555, 7, 2824, '', 'A', 'Airyhall Dancers at Aberdeen Festival 2019', 1, 1, 'Y', 'lLg8na_i7mM', 3, 259, NULL);
INSERT INTO 'dancevideo' VALUES (7974, '2021-05-18 08:44:11.421883+00', '2021-05-18 10:32:47.063668+00', 9109, 3, 2824, '', 'A', 'Airyhall Dancers at Aberdeen Festival 2019', 1, 1, 'Y', 'lLg8na_i7mM', 260, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7976, '2021-05-18 09:00:04.687877+00', '2021-05-18 10:36:28.222943+00', 9563, 3, 2824, '', 'A', 'Aberdeen University Scottish Dance Society at Aberdeen Festival 2019', 1, 1, 'Y', 'x9UdkVVxQ0w', 4, 154, NULL);
INSERT INTO 'dancevideo' VALUES (7110, '2020-04-02 16:18:50.737211+00', '2021-05-18 16:48:10.909511+00', 1223, 8, 1645, '', 'A', 'Twice through in a two couple set.', 1, 1, 'Y', 'cD9sPPhvOQI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8012, '2021-07-16 10:30:24.124858+00', '2021-07-16 11:02:54.682139+00', 16110, 1, 35822, '', 'B', 'Canberra 2021. Once through.', 1, 1, 'Y', 'QvvP8mrXtPc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8011, '2021-07-16 10:28:08.582298+00', '2021-07-16 15:09:21.317836+00', 9087, 5, 35822, '', 'B', 'Canberra 2021. Twice through in a 2 couple set.', 1, 1, 'Y', '7sHGqfHoQds', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8014, '2021-07-18 20:45:22.299122+00', '2021-07-18 21:07:32.267611+00', 4325, 1, 20350, '', 'D', 'Johnsonville SCD Club, Wellington NZ, 2021. This clip starts with the dance. The whole video starts with a recap.', 1, 1, 'Y', 'DhhiDN57DjM', 40, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7978, '2021-05-18 09:18:52.096508+00', '2021-05-18 17:53:04.692456+00', 19923, 1, 2824, '', 'D', 'Highly roaming camera angle (literally wandering through the room and between sets, also showing the band in between)  

RSCDS Chicago Tea Dance 2020



The instructions say bars 1-8 and 9-16 are a modified Helix with half RHA in 5-6 and cross RH in 7-8. Here they are doing the original Helix with half RH turn first then half RHA.', 1, 1, 'Y', '2nMrx-F-mtI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7818, '2021-02-05 21:23:59.353954+00', '2021-05-19 17:55:01.73846+00', 18662, 1, 1645, '', 'X', 'A rather surreal attempt at an animation using top hats for the men and teapots for the women (inspired by the Wonderland theme). 



It seemed too odd to have upside down teapots, so the images are always facing the same way, rather than turning round. This unfortunately makes it harder to follow which way a dancer would really be facing - though normally they face the way they are moving, except when setting in the Bourrel. The twirl (cast) away after the first two hand turn in the Bourrel is replaced by a kind of funny turn video effect. Hopefully the subtitles help to make the choreography clear.



The attempt to synchronise animation with music resulted in a not very smoothly flowing movement.', 1, 1, 'Y', 'QT9HGKgZwLg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7965, '2021-05-13 22:34:01.240396+00', '2022-01-14 22:52:19.411131+00', 16408, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', 'M8nrQPkRvTs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7952, '2021-05-12 21:19:54.704685+00', '2022-01-23 16:56:14.980573+00', 17247, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes and some of the terminology is not standard SCD)



Bars 9-16 should be "dance" (nearer hands joined) not "lead" with right hands joined.', 1, 1, 'Y', '4ZqHzl3nTFo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7955, '2021-05-13 20:05:36.008513+00', '2022-08-11 18:05:07.31378+00', 14552, 3, 1645, '', 'Z', 'Bellingham Scottish Country Dancers Demonstration Team at the 23rd Annual Skagit Valley Highland Games & Celtic Festival, 2017.



Was considered Good but now unavailable.', 1, 1, 'Y', '5ohI941AIhk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7979, '2021-05-24 14:36:18.794418+00', '2021-05-24 16:10:48.257113+00', 11877, 2, 2824, '', 'A', '(When the camera angle switches to close-up briefly for a couple of times not the full set is in view)', 1, 1, 'Y', 'W4nj0X8Prug', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7980, '2021-05-27 23:31:29.284291+00', '2021-05-27 23:32:20.328853+00', 12532, 2, 1645, '', 'B', 'Lisbon Lapa group 2017. Once through.', 1, 1, 'Y', 'PS-kZoBggYM', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7981, '2021-05-30 07:53:33.966281+00', '2021-05-30 07:54:38.044177+00', 20327, 1, 202, '', 'D', '', 1, 1, 'Y', 'fcQKT8lZcwQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7992, '2021-06-27 06:03:10.303822+00', '2021-06-27 11:38:08.991261+00', 3231, 4, 2824, '', 'B', 'Atholl SCDC Christmas Party 2019', 1, 1, 'Y', 'fH37DOlp3A8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7982, '2021-06-07 13:13:48.969068+00', '2021-06-07 15:57:49.038842+00', 6720, 3, 2824, '', 'B', 'Danced in 3 couple sets at the Kelburn SCD 60th Anniversary (2019) in Wellington, New Zealand.', 1, 1, 'Y', 'j6RwgMb0UZQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7983, '2021-06-07 16:15:01.374732+00', '2021-06-07 16:15:15.32685+00', 20349, 1, 1645, '', 'C', 'Ngaio Town Hall, Wellington, New Zealand 2021. Generally clear, with a few glitches when setting in double triangle position and which of 3rd couple joins which 5 hands across.', 1, 1, 'Y', 'mKwK0FGn2oU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7984, '2021-06-12 08:52:44.83803+00', '2021-06-12 08:52:59.258703+00', 1966, 2, 1645, '', 'D', 'RSCDS Hamilton & Clydesdale, 2016.', 1, 1, 'Y', 'jjvA8KXFzRo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7995, '2021-06-27 09:04:08.66116+00', '2021-06-27 11:39:01.569676+00', 3788, 6, 1645, '', 'A', 'St Andrews Summer School demos 2009. Twice through.', 1, 1, 'Y', 'ex-ApSTJ2AU', 73, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7985, '2021-06-14 04:31:39.838032+00', '2021-06-14 08:13:19.514535+00', 11553, 1, 2941, '', 'A', 'New World Scottish Dancers at the Woodland Highland Games 2008. Twice through in a 2 couple set.', 1, 1, 'Y', '2Nj6cIVhoeo', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7986, '2021-06-14 08:24:03.600229+00', '2021-06-14 08:25:17.611883+00', 19648, 1, 1645, '', 'B', 'New World Scottish Dancers at the Mother Lode Highland Games 2018. Three times through in a 2 couple set.', 1, 1, 'Y', 'YrHhTf0JkX4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7987, '2021-06-14 10:14:09.990259+00', '2021-06-14 10:15:21.832698+00', 1607, 2, 1645, '', 'B', 'New World Scottish Dancers  at the Mother Lode Highland Games 2018. One couple dancing beautifully to what sounds like non-traditional music.', 1, 1, 'Y', 'Cl4ipximRJU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7988, '2021-06-19 10:48:14.9595+00', '2021-06-19 14:18:24.192144+00', 3553, 2, 3086, '', 'A', '', 1, 1, 'Y', 'PL3uo1rAkGQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7989, '2021-06-22 09:09:38.756397+00', '2021-06-22 09:10:28.057139+00', 18279, 1, 1645, '', 'C', 'Kelburn Scottish Country Dancing Club, Wellington, New Zealand, 2021. Twice through.', 1, 1, 'Y', 'sfrR_pSjALw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7990, '2021-06-24 06:30:49.947363+00', '2021-06-24 08:45:04.212679+00', 3678, 3, 2824, '', 'B', 'Ngaio SCD Club, New Zealand, 2018. Danced in 3 couple sets.', 1, 1, 'Y', 'DiKLJjV7VHI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7991, '2021-06-27 05:57:49.033403+00', '2021-06-27 08:30:43.235303+00', 1060, 4, 2824, '', 'A', 'Atholl SCD Club 2018. Once through the dance.', 1, 1, 'Y', 'O9NAzvokEU0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7994, '2021-06-27 08:50:33.927444+00', '2021-06-27 08:52:21.504965+00', 5807, 4, 1645, '', 'A', 'St Andrews Summer School demos 2009. Once through. The final poussette is slightly adapted to end as a longwise set.', 1, 1, 'Y', 'ex-ApSTJ2AU', 14, 72, NULL);
INSERT INTO 'dancevideo' VALUES (7993, '2021-06-27 08:33:50.84467+00', '2021-06-27 11:37:18.137581+00', 2063, 7, 1645, '', 'C', 'Atholl SCD Club, 2018.', 1, 1, 'Y', 'P8yAKPDKBvI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7996, '2021-06-27 09:24:22.545865+00', '2021-06-27 11:39:52.80664+00', 6037, 10, 1645, '', 'B', 'Lughnasad at the Forpost festival 2013. A slightly adapted version as part of a theatrical display.', 1, 1, 'Y', 'CJu6ijdlz80', 224, 365, NULL);
INSERT INTO 'dancevideo' VALUES (7997, '2021-06-27 12:51:15.836853+00', '2021-06-27 12:58:36.190621+00', 19240, 1, 197, '', 'C', 'Minor error at 58s: 2M and 3W drop hands too early in left hand turn at bars 27-30', 1, 1, 'Y', 'bRdtn0f4hAE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7998, '2021-07-02 14:36:20.912388+00', '2021-07-02 14:36:40.598795+00', 1087, 9, 1645, '', 'B', 'Oslo Scottish Country Dance Group 2013. About six times through.', 1, 1, 'Y', 'YNO82treE9U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7999, '2021-07-02 14:56:13.524338+00', '2021-07-02 14:57:36.347926+00', 3723, 1, 1645, '', 'C', 'St Andrews 2001. Once through view of social dancing in the Younger Hall.', 1, 1, 'Y', 'W_zZNcERs1s', 180, 246, NULL);
INSERT INTO 'dancevideo' VALUES (8000, '2021-07-02 16:03:18.700301+00', '2021-07-02 16:03:32.898087+00', 20362, 1, 1645, '', 'B', 'SCD Group Hong Kong 2017.', 1, 1, 'Y', 'qiYExQiTpbA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3469, '2018-03-10 17:48:47.223485+00', '2021-07-04 08:28:22.723209+00', 15323, 2, 2220, '', 'B', 'The late Greg Reznick, a gem of the San Francisco branch, is dancing as first man.', 1, 1, 'Y', 'VID0nyTkULI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8001, '2021-07-11 02:35:23.281346+00', '2021-07-11 02:35:37.232167+00', 4411, 9, 202, '', 'C', '', 1, 1, 'Y', 'Ih3itdscX9c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8002, '2021-07-11 02:40:47.086303+00', '2021-07-11 19:33:21.246022+00', 4014, 5, 202, '', 'B', 'Toronto Rosedale Youth 2012. Here slightly adapted for three adjacent 2 couple sets instead of 4 couple sets (the  opening reels of 4 on the sides are here done as reels of three between the sets).', 1, 1, 'Y', 'Q42huWEj-SY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8003, '2021-07-13 06:56:49.771503+00', '2021-07-13 08:13:25.025882+00', 5926, 1, 2824, '', 'A', '', 1, 1, 'Y', 'P6gERBbpW5Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8004, '2021-07-15 04:54:30.018801+00', '2021-07-15 07:45:01.280831+00', 11703, 1, 2824, '', 'B', 'Once through. Levin Scottish Country Dancing Club''s annual dance, NZL, 10.07.2021', 1, 1, 'Y', 'Yz3LqgIyLyM', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8005, '2021-07-15 05:18:49.292573+00', '2021-07-15 07:47:20.574736+00', 14977, 9, 35776, '', 'D', 'Johnsonville Club Tartan Night 12 July 2021

Recorded by Aline Homes', 1, 1, 'V', '574702061', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8006, '2021-07-15 05:22:43.05433+00', '2021-07-15 07:47:34.382303+00', 16534, 8, 35776, '', 'C', 'Johnsonville Club Tartan Night 12 July 2021

Recorded by Aline Homes', 1, 1, 'V', '574707130', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8007, '2021-07-15 05:25:44.689957+00', '2021-07-15 07:54:49.907671+00', 3980, 7, 35776, '', 'C', 'Johnsonville Club Tartan Night 12 July 2021

Recorded by Aline Homes', 1, 1, 'V', '574724189', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8008, '2021-07-15 07:38:42.510429+00', '2021-07-15 08:29:22.375729+00', 13797, 1, 2824, '', 'B', 'Danced at the ''tartan'' night of Johnsonville SCD Club on July 12, 2021

The dance was written for longstanding Johnsonville club members John and Aline Homes, who are dancing as first couple in the set in the middle of the hall nearest the band.', 1, 1, 'Y', 'Zp5XAQmklmo', 9, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8009, '2021-07-15 09:13:13.361141+00', '2021-07-15 10:26:40.473841+00', 19271, 1, 2824, '', 'C', 'Danced at the Gainesville Scottish Country Dance Weekend, 6 - 8 March 2020', 1, 1, 'Y', '-ElT_uqIkYk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8010, '2021-07-15 22:49:08.619624+00', '2021-07-15 22:50:04.545979+00', 13681, 1, 1645, '', 'A', 'Badenoch Dancers (of Frimley Green, Surrey) shown dancing in 2016 on a video of the BHS Borders Branch online musicians workshop in March 2021.', 1, 1, 'Y', 'oADzBQy1Svc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8013, '2021-07-16 10:31:40.25792+00', '2021-07-16 11:07:37.081253+00', 19986, 2, 35822, '', 'B', '', 1, 1, 'Y', 'qnw25jQIVAU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5229, '2019-10-08 21:22:30.846587+00', '2021-07-19 16:57:31.787322+00', 18096, 2, 1645, '', 'B', 'Deep Cove SCD Club, 2017. Twice through.', 1, 1, 'Y', 'GB1jBXbDFnY', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8015, '2021-07-19 21:49:37.860309+00', '2021-07-19 22:02:00.022937+00', 20033, 1, 10819, '', 'B', 'Due to Corona restrictions, the dance shows no hands even though there are hands required. See the official description. The devisor is part of the dancing crew, so all basics of the dance are shown correctly. ', 1, 1, 'Y', 'erTPQwmyGOM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8033, '2021-08-07 11:40:05.322481+00', '2021-08-07 12:28:06.190799+00', 17791, 1, 1645, '', 'Z', 'Cogsmill Hall (Hawick, Scottish Borders) 2020.



Blocked because it cannot be played on the SCDDB video page. Otherwise OK as social/informal.', 1, 1, 'Y', 'FJpe_RZpWAQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8016, '2021-07-22 22:30:00.409386+00', '2021-07-22 22:37:20.68578+00', 12825, 1, 1645, '', 'C', 'Class in Cheboksary, Russia, 2021. A few hesitations but clear dancing. The instructions say the corners should continue setting as 1st couple petronella in bars 27-28, but here the corners stand.', 1, 1, 'Y', 'eibzDsn_8xQ', 0, 376, NULL);
INSERT INTO 'dancevideo' VALUES (8017, '2021-07-22 22:50:47.787921+00', '2021-07-22 22:52:58.522557+00', 6336, 1, 1645, '', 'C', 'Class in Cheboksary, Russia, 2021. The first repeat is very good, later there are a few hiccups.', 1, 1, 'Y', '2GL31lMCVYY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2153, '2015-08-29 20:16:45.750648+00', '2021-07-22 23:11:39.041027+00', 7219, 2, 106, '', 'Z', 'Demonstration for RSCDS Teaching Certificate: Unit 2 Dances.



No longer public. Would be nice to have it back even if this is no longer one of the Unit 2 dances.', 1, 1, 'Y', 'hRVTTnwxH6M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8851, '2022-06-23 05:28:48.492626+00', '2022-06-23 11:34:46.55974+00', 20875, 2, 645, '', 'A', 'May 2022', 1, 1, 'Y', 'ZMLA9OBqn20', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8018, '2021-07-22 23:12:55.173217+00', '2021-07-22 23:50:47.87419+00', 7219, 3, 1645, '', 'B', 'Demonstration at the Spring Scottish Dance School in Yaroslavl, Russia, 2016.', 1, 1, 'Y', 'pmH7cF2OSMU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8019, '2021-07-22 23:22:39.49549+00', '2021-07-22 23:50:53.820528+00', 5885, 13, 1645, '', 'B', 'Demonstration at the Spring Scottish Dance School in Yaroslavl, Russia, 2016. Excellent dancing though not to the suggested tune.', 1, 1, 'Y', 'klZE7BfeMPY', 27, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8037, '2021-08-07 12:18:42.333994+00', '2021-08-07 12:28:54.875942+00', 20426, 2, 1645, '', 'A', '', 1, 1, 'Y', 'N9YDFuLXWQk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8036, '2021-08-07 12:16:26.323375+00', '2021-08-07 12:29:06.209886+00', 20426, 1, 1645, '', 'A', 'Demonstration dance on Parliament Hill, Ottawa, 2011.', 1, 1, 'Y', '-6oWhQc5M2M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8020, '2021-07-27 12:08:55.574457+00', '2021-07-27 12:10:06.384666+00', 20325, 2, 202, '', 'D', '', 1, 1, 'Y', 'On1f3YI_CGk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8021, '2021-07-27 12:12:30.232761+00', '2021-07-27 12:12:42.942746+00', 20333, 1, 202, '', 'D', '', 1, 1, 'Y', 'aR0ZBEMWshc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8022, '2021-07-27 12:16:22.80203+00', '2021-07-27 12:17:08.058535+00', 20331, 2, 202, '', 'B', '', 1, 1, 'Y', 'KngGiNM0N5Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8023, '2021-07-27 12:21:00.862895+00', '2021-07-27 12:21:14.077263+00', 20326, 1, 202, '', 'D', '', 1, 1, 'Y', 'v03itGSnUVo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8024, '2021-07-27 12:23:37.172213+00', '2021-07-27 12:23:53.449748+00', 20332, 1, 202, '', 'D', '', 1, 1, 'Y', '41IRucW8FTw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8025, '2021-07-27 12:26:11.276232+00', '2021-07-27 12:26:24.286453+00', 20327, 2, 202, '', 'D', '', 1, 1, 'Y', '4qZ8vCYdn88', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8026, '2021-07-27 20:57:11.587408+00', '2021-07-27 21:17:01.471691+00', 20394, 1, 10819, '', 'B', 'The devisor is dancing as first man. This video simply shows one couple dancing twice to demonstrate how the dance works. ', 1, 1, 'Y', 'APZMd4Qhyr0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8028, '2021-08-04 00:40:02.888001+00', '2021-08-04 00:40:02.888001+00', 10663, 11, 1296, '', 'X', '''Alan J Smith'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'y2turlOy8sI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8029, '2021-08-04 00:40:02.920735+00', '2021-08-04 00:40:02.920735+00', 1480, 5, 1296, '', 'X', '''Cumbrae Reel, The'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'cq2_4bQAYec', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8030, '2021-08-04 00:40:02.94928+00', '2021-08-04 00:40:02.94928+00', 1543, 4, 1296, '', 'X', '''Dancing Man, The'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'b--bMbnmXfo', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8031, '2021-08-05 00:40:04.188202+00', '2021-08-05 00:40:04.188202+00', 5204, 4, 1296, '', 'X', '''Peggy Dewar'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'oO1J5AlvFOg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8032, '2021-08-05 00:40:04.217094+00', '2021-08-05 00:40:04.217094+00', 13544, 4, 1296, '', 'X', '''Fireworks Reel, The'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'LA-mLFk2Boo', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8035, '2021-08-07 11:52:50.040199+00', '2021-08-07 12:24:42.431627+00', 2063, 8, 1645, '', 'D', 'Outdoor dancing in Princes Street, Edinburgh, 2018 to music by Ewan Galloway & his SDB.', 1, 1, 'Y', 'Nm3ZLbhpQ9M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8038, '2021-08-07 12:24:28.398746+00', '2021-08-07 12:30:44.015279+00', 20425, 1, 1645, '', 'B', 'Upper Hutt, Wellington, New Zealand, 2021. Demonstration for the 50th anniversary of the club.', 1, 1, 'Y', 'xI_wcSY42d0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8034, '2021-08-07 11:47:17.646781+00', '2021-08-07 12:27:16.863238+00', 6161, 2, 1645, '', 'Z', 'Glendouglas Hall, Scottish Borders, 2016. Social dance with voiceover coaching.



Blocked because it cannot be played on the SCDDB video page. Otherwise OK as social/informal.', 1, 1, 'Y', 'LMs5kUyu5w8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8039, '2021-08-09 04:53:08.234287+00', '2021-08-09 08:10:36.445138+00', 7548, 2, 2824, '', 'A', 'Shown by dancers from the Moscow Scottish Dance School "Shady Glen".', 1, 1, 'Y', '3QWZF1mGsfU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1841, '2014-09-21 22:53:02.196059+00', '2021-08-10 19:17:00.249352+00', 11814, 1, 106, '', 'Z', 'Recorded at "Hommage de Paris à Ann Dix - Bal du 11 Janvier 2014"



A good video from above - but sadly no longer available, probably when youtube made older unlisted videos private. Blocked so its not shown to users but kept in case it becomes available again.', 1, 1, 'Y', 'Gwbo-Pxt2LE', 110, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8040, '2021-08-10 19:13:08.331301+00', '2021-08-10 19:17:21.798755+00', 11814, 2, 1645, '', 'B', 'From the welcome dance at the Paris Spring Fling 2019. This clip shows the last time through the dance with the dedicatees starting as 4th couple. The whole video starts around bar 21 of the previous repeat.', 1, 1, 'Y', 'Ytfu3ZsxXcA', 24, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8041, '2021-08-10 19:15:10.703629+00', '2021-08-10 19:17:30.314148+00', 11814, 3, 1645, '', 'C', 'Toronto Family Christmas Dance 2015.', 1, 1, 'Y', '8bwRjsv1IgY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8042, '2021-08-10 20:08:20.780586+00', '2021-08-10 20:11:51.019988+00', 13139, 2, 1645, '', 'C', 'Hong Kong SCD group 2018.', 1, 1, 'Y', 'zsYOvfhZdok', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8043, '2021-08-10 20:10:14.750244+00', '2021-08-10 20:12:06.932448+00', 13139, 3, 1645, '', 'D', 'Hamilton and Clydesdale RSCDS Spring Dance 2019.', 1, 1, 'Y', 'OLFXAzoDwH0', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8044, '2021-08-10 21:25:40.983695+00', '2021-08-10 21:27:05.316977+00', 6824, 1, 1645, '', 'D', 'From St Andrews Summer School 2001 social dancing. This clip starts around bar 5 of the last two repeats.', 1, 1, 'Y', 'joh4-xuQYVQ', 680, 746, NULL);
INSERT INTO 'dancevideo' VALUES (3035, '2017-05-10 07:30:41.693224+00', '2021-08-11 20:26:45.487239+00', 16494, 1, 106, '', 'B', '', 1, 1, 'Y', 'E5E9UqRCaEc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8046, '2021-08-20 13:12:44.795574+00', '2021-08-20 13:12:57.111285+00', 413, 9, 202, '', 'C', '', 1, 1, 'Y', 'Vax2yxi6Fng', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8047, '2021-08-20 15:22:46.848116+00', '2021-08-20 15:27:43.641185+00', 20449, 1, 1332, '', 'B', 'Lapa SCD group, Lisbon, 2021. 3x32 S', 1, 1, 'Y', 'FLQMYTQSlrU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8045, '2021-08-15 03:48:36.923462+00', '2021-08-15 21:36:33.134413+00', 14991, 1, 2220, '', 'C', 'Lafayette CA class Aug 12 2021



Danced in a 5-couple set. 



The video starts at the end of the first time through.  The first couple (1M is a lady wearing red) then continues from second place with 3rd and 4th couples.', 1, 1, 'Y', 'imufjOG_wic', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8048, '2021-08-23 23:06:44.179449+00', '2021-08-23 23:11:53.25907+00', 20450, 1, 1645, '', 'B', 'TAC Summer School 2016. Introduced by the deviser who is then playing the music he composed for the dance. There seem to be a couple of unexpected shoulder passes in the mirror reels.', 1, 1, 'Y', 'QIO7hggYwuc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8049, '2021-08-27 20:16:25.663904+00', '2021-08-27 20:25:20.901635+00', 20327, 3, 202, '', 'C', '', 1, 1, 'Y', 's2OUf3uJNiA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8051, '2021-08-27 20:21:18.091341+00', '2021-08-27 20:25:35.463573+00', 20330, 1, 202, '', 'D', '', 1, 1, 'Y', 'C6o2U3NoDHk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8050, '2021-08-27 20:19:09.393499+00', '2021-08-27 20:26:04.961687+00', 20329, 1, 202, '', 'C', '', 1, 1, 'Y', 'Jn8x5b7Nbsk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8052, '2021-08-27 20:24:50.736147+00', '2021-08-27 20:26:26.981573+00', 20333, 2, 202, '', 'C', '', 1, 1, 'Y', 'oQnKT1jhww0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (750, '2012-12-17 14:19:45.615175+00', '2021-08-31 14:26:15.18061+00', 8161, 2, 1296, '', 'B', '', 1, 1, 'Y', 'AUNhF793uqA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2079, '2015-05-04 22:09:19.082524+00', '2021-08-31 15:37:23.203766+00', 10920, 6, 1957, '', 'A', 'Filmed on 1st October 2014 in the Non-subscribing Church Hall, Holywood, Co. Down.', 1, 1, 'Y', 'cpriy9LmCzE', 21, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8054, '2021-08-31 22:55:11.284011+00', '2021-08-31 23:07:40.850978+00', 16527, 5, 1645, '', 'A', 'Aberdeen Festival 2016.', 1, 1, 'Y', 'Hph4rNstpPc', 280, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8055, '2021-08-31 23:05:09.855628+00', '2021-08-31 23:10:21.398704+00', 19516, 1, 1645, '', 'B', 'RSCDS Summer School week 2 (2019). Once through.', 1, 1, 'Y', 'D91HmF3B9sY', 63, 115, NULL);
INSERT INTO 'dancevideo' VALUES (3715, '2018-10-01 22:07:48.645499+00', '2021-09-01 00:29:07.544316+00', 6373, 1, 1296, '', 'X', '"Sugar Candie" is a 32 bar strathspey for 3 couples.', 1, 1, 'Y', 'zohBWotKKzE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8059, '2021-09-02 10:57:09.679073+00', '2021-09-02 11:31:44.961465+00', 14654, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes)', 1, 1, 'Y', 'G8B4Qjl8dGQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8060, '2021-09-02 17:27:09.669637+00', '2021-09-02 17:27:25.029957+00', 19194, 3, 202, '', 'C', '', 1, 1, 'Y', 'ibZW_MqQLSI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8061, '2021-09-06 23:43:41.530722+00', '2021-09-07 08:32:38.435186+00', 17399, 2, 2220, '', 'B', 'The video begins on bar 17 of the first of three times through the dance.  At the end the standing out couple joins for the final turn.  Otherwise the dance is very much as envisioned by the devisor. Recorded at the 2021 Highland Games in Pleasanton CA USA', 1, 1, 'Y', 'CPPEBPnJVcY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8063, '2021-09-07 00:00:55.943955+00', '2021-09-07 08:34:48.120958+00', 17399, 3, 2220, '', 'A', 'Three times through view taken from ground level.  Very similar as other video with these dancers, but complete and with better view and from a different performance.', 1, 1, 'Y', 'Nngj14y726A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8062, '2021-09-06 23:57:04.728309+00', '2021-09-07 08:37:27.090147+00', 15177, 4, 963, '', 'B', 'First time dancing in person in a long time.', 1, 1, 'Y', '23xJI-G_lVI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8064, '2021-09-15 00:44:25.203377+00', '2021-09-15 07:53:11.891736+00', 13071, 1, 35795, '', 'A', 'RSCDS Western Australia branch 2021.', 1, 1, 'Y', 'xLi6EHTIlH8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8065, '2021-09-17 23:11:51.883271+00', '2021-09-17 23:25:16.980841+00', 19934, 1, 1645, '', 'C', 'SCD group Hong Kong. Just less than once through, starting from bar 3 (missing the first two bars where 1s & 2s set).', 1, 1, 'Y', 'LhePUvoGQTA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8066, '2021-09-17 23:24:29.745139+00', '2021-09-17 23:25:41.541353+00', 9896, 3, 1645, '', 'C', 'SCD group Hong Kong. Just less than twice through (starting at bar 3, missing the setting on bars 1-2).', 1, 1, 'Y', 'XzezxnWn2AM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8067, '2021-09-20 14:40:06.362633+00', '2021-09-21 22:34:16.013611+00', 14481, 1, 274, '', 'B', 'Performed by Budapest Scottish Dance Club, 2021, Siófok, Hungary

', 1, 1, 'Y', '9MP0Y0Fk9KQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6960, '2020-02-25 21:08:39.473912+00', '2021-09-24 16:42:53.686921+00', 8165, 3, 1645, '', 'Z', 'Twice through extract from a longer demo in two back to back sets (initially with the top at each end).



This video is now unavailable - probably was Unlisted and changed to Private in a youtube policy change. ', 1, 1, 'Y', 'hYe0lIfqp8w', 683, 756, NULL);
INSERT INTO 'dancevideo' VALUES (8068, '2021-09-26 12:07:11.050111+00', '2021-09-26 12:10:41.015763+00', 20495, 1, 1645, '', 'B', 'Danced, to live music from Marian Anderson and her band, by participants at the Dawlish Warren dancing holiday organised by the deviser, Amanda Peart, in September 2021.

', 1, 1, 'Y', 'OZxwoA1Q_jk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (985, '2013-08-08 23:21:31.492441+00', '2021-09-27 10:21:16.669558+00', 9083, 2, 961, '', 'C', 'Naramata Scottish Country Dancers, 2013. The dancers have a tendency to arrive a little early for the next phrase. The first 1st couple loop above 3rd couple instead of the expected 2nd couple in bars 25-32. The viewpoint obscures some of the action.



The video on youtube has the erroneous header "Craven Reel" but is correctly introduced by the MC as Craven Jig. ', 1, 1, 'Y', 'pSBlUpjr4Ts', 0, 180, NULL);
INSERT INTO 'dancevideo' VALUES (8069, '2021-09-27 14:12:35.170782+00', '2021-09-27 16:57:13.707064+00', 13744, 2, 274, '', 'B', 'Budapest SCD Weekend 2021 - Welcome Dance - surprising music

Once to the bottom

', 1, 1, 'Y', '1IW6tRqZs44', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8070, '2021-09-27 17:19:07.83268+00', '2021-09-27 17:28:40.002634+00', 20496, 1, 1645, '', 'C', 'Kalamazoo Scottish Country Dancers 2018. This clip starts with the dancing. There is some walking but the choreography is clear. The whole video starts with a slightly muffled introduction.', 1, 1, 'Y', 'hv_YZtDSEc4', 45, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4368, '2019-03-10 13:15:59.207221+00', '2021-10-01 20:43:45.886326+00', 9085, 3, 2697, '', 'C', 'RSCDS Moscow Branch 2019. A clear performance, though in bars 9-24 the corners are mostly dancing 2 bars in each turn whereas the instructions say they dance 4 bars.', 1, 1, 'Y', 'Og5Qh4Y2N90', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8071, '2021-09-27 18:48:17.85332+00', '2021-10-02 14:51:49.235914+00', 20492, 1, 10761, '', 'B', 'The music in the video is not the original tune for the dance as this was composed after this video was recorded.', 1, 1, 'Y', 'HQ3q4L1u4oU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8073, '2021-10-09 23:15:01.336769+00', '2021-10-09 23:16:01.394185+00', 15136, 1, 1645, '', 'C', 'Bluebonnet Ball (San Antonio, Texas) 2012.', 1, 1, 'Y', 'BIt_SUsl9EU', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8074, '2021-10-12 13:07:47.920685+00', '2021-10-12 13:08:22.703648+00', 5658, 4, 202, '', 'D', '', 1, 1, 'Y', 'QvTC2ppM52Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8076, '2021-10-12 19:13:58.885178+00', '2021-10-12 19:14:34.029303+00', 5637, 9, 202, '', 'C', '', 1, 1, 'Y', 'lxV6dBsPQ1I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8072, '2021-10-03 22:03:14.889085+00', '2021-10-14 23:29:37.060941+00', 19237, 3, 197, '', 'C', 'Clan McBedoin SCD group at Association day in Carpentras, France, 2018. The deviser, Erika Ritzau, is dancing as first lady.', 1, 1, 'Y', 'XT2_6MkDix8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8077, '2021-10-18 21:52:41.74658+00', '2021-10-18 22:59:29.026575+00', 13796, 1, 20354, '', 'C', '', 1, 1, 'Y', 'lVDznqf_qcI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8081, '2021-10-28 15:22:48.821129+00', '2021-10-28 15:23:46.754911+00', 16833, 4, 202, '', 'D', '', 1, 1, 'Y', 'z6ocGp_FgjM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8082, '2021-10-28 15:30:32.286901+00', '2021-10-28 15:30:55.772396+00', 20537, 1, 202, '', 'C', '', 1, 1, 'Y', 'ERfbGF13WtY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8079, '2021-10-27 11:12:01.253779+00', '2021-10-28 22:14:13.76718+00', 16188, 1, 1645, '', 'B', 'Generally very clear with a couple of minor glitches.', 1, 1, 'Y', 'g93WVXabSLY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8080, '2021-10-27 11:22:17.216166+00', '2021-10-28 22:14:34.780081+00', 16202, 1, 1645, '', 'B', 'In the <<ddpub:Potters Pairs#1247>> book this is described as a reel, but is here danced as a jig.', 1, 1, 'Y', 'sQeyhfYZXxQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8078, '2021-10-27 11:01:55.318815+00', '2021-10-28 22:15:04.165201+00', 13645, 1, 1645, '', 'B', '', 1, 1, 'Y', 'teefvwlKxqU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (920, '2013-04-22 12:20:12.522389+00', '2021-10-29 14:10:55.510727+00', 8986, 1, 513, '', 'Z', 'Now private (previously graded as Reasonable).', 1, 1, 'Y', 'J6GFhQNKIOg', 0, 191, NULL);
INSERT INTO 'dancevideo' VALUES (8084, '2021-11-06 17:22:12.452071+00', '2021-11-06 17:43:21.571493+00', 20539, 1, 1645, '', 'A', 'Lower Hutt Club, Wellington, New Zealand 2021.', 1, 1, 'Y', 'tOu0S1kbFp8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8085, '2021-11-06 17:27:08.076498+00', '2021-11-06 17:44:39.322712+00', 20540, 1, 1645, '', 'A', 'Lower Hutt Club, Wellington, New Zealand 2021.', 1, 1, 'Y', 'ZvSeFnQfYng', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8083, '2021-11-06 17:15:10.317542+00', '2021-11-06 17:45:10.68352+00', 20541, 1, 1645, '', 'A', 'Lower Hutt Club, Wellington, New Zealand 2021.', 1, 1, 'Y', 'neT9mfTRUII', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8086, '2021-11-06 17:31:27.586537+00', '2021-11-06 17:45:32.966929+00', 20542, 1, 1645, '', 'A', 'Lower Hutt Club, Wellington, New Zealand 2021.', 1, 1, 'Y', 'd2bbMAvx0N4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8087, '2021-11-06 17:36:44.614993+00', '2021-11-06 17:46:43.397518+00', 20543, 1, 1645, '', 'A', 'Lower Hutt Club, Wellington, New Zealand 2021.', 1, 1, 'Y', 'jBrBe8qvO8c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8088, '2021-11-06 17:42:36.610256+00', '2021-11-06 17:47:12.921546+00', 17239, 1, 1645, '', 'A', 'Lower Hutt Club, Wellington, New Zealand 2021.', 1, 1, 'Y', 'XSTDTe7aieI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8089, '2021-11-06 18:08:19.824152+00', '2021-11-06 18:11:28.071804+00', 20553, 1, 1645, '', 'D', 'Johnsonville Club, Wellington, New Zealand 2021. Once through (on a halloween theme night).', 1, 1, 'Y', 'pmMfNLfAOKU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8090, '2021-11-06 18:10:54.345084+00', '2021-11-06 18:12:18.479266+00', 16961, 1, 1645, '', 'D', 'Johnsonville Club, Wellington, New Zealand 2021 (on a halloween theme night). This clip starts with the dancing. The whole video has an introduction by the deviser.

', 1, 1, 'Y', 'RK6CACEPr3E', 43, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8091, '2021-11-08 23:53:04.203105+00', '2021-11-08 23:53:29.748891+00', 1782, 8, 202, '', 'C', '', 1, 1, 'Y', 'Jp3LcycxfAI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8093, '2021-11-10 19:52:25.690331+00', '2021-11-10 23:51:07.089591+00', 20149, 2, 963, '', 'C', '', 1, 1, 'Y', 'FKVoFCMaJgc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8094, '2021-11-10 21:25:23.892825+00', '2021-11-11 00:00:19.227399+00', 20131, 3, 963, '', 'C', 'This clip shows two complete repeats. The video starts part way through an earlier repeat (from about bar 9). Danced in a 3 couple set with 1s stepping to the foot each time.', 1, 1, 'Y', 'piQPCtwj36Y', 45, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8095, '2021-11-11 02:08:39.44632+00', '2021-11-11 10:18:31.523932+00', 20457, 1, 963, '', 'C', 'The music is quite faint for the first minute or so of the video, its better for the third repeat starting from 1:15.', 1, 1, 'Y', '_cJUxavrwk0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8096, '2021-11-15 02:39:29.571201+00', '2021-11-15 10:20:56.612835+00', 20197, 2, 963, '', 'C', 'Danced by real people instead of stop motion dolls.', 1, 1, 'Y', 'AXLgPKTNq1g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5281, '2019-10-15 21:38:37.596152+00', '2021-11-15 12:52:29.27642+00', 11498, 1, 1645, '', 'D', 'Beginners are being gently coached through this dance.



Note that the first 16 bars as done here are different from the original instructions. Those have 1W & 2W dancing figures of 8 on the M side in bars 1-8 then 1M & 2M repeat on the women''s side.

', 1, 1, 'Y', 'unDjmFqmaGk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8097, '2021-11-15 16:47:57.28194+00', '2021-11-15 16:55:38.771839+00', 20558, 1, 963, '', 'C', 'This is 3 couples in a (4 couple) longwise set - there is a 3 couple variation with 25-32 being 6 hands round and back.', 1, 1, 'Y', 'rdsl474fwS0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8098, '2021-11-15 19:45:29.092909+00', '2021-11-15 22:48:47.487987+00', 20554, 1, 963, '', 'B', '', 1, 1, 'Y', 'b2dlJ4T7-2Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8102, '2021-11-21 17:19:26.582242+00', '2021-11-21 22:28:35.379933+00', 3172, 7, 2269, '', 'B', 'FOR LEARNING.  Dancers wear coloured and numbered vests.  On [17-32] the corner dancers set to the new partner {2}. and do not follow the traditional set to old partner {1}, new partner {1}.  Spoken text all through/', 1, 1, 'Y', 'wczvNE6ET0s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8101, '2021-11-21 02:05:02.150429+00', '2021-11-22 00:43:16.064136+00', 20215, 2, 963, '', 'C', 'A few errors but it isn''t such an easy dance.  ', 1, 1, 'Y', '-uxqTwVTgxo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8103, '2021-11-21 17:22:26.541435+00', '2021-11-22 11:14:58.764956+00', 4365, 7, 2269, '', 'B', 'Teaching video: first time in slow motion.', 1, 1, 'Y', 'UXQH2-bt-AI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8100, '2021-11-17 18:20:09.097841+00', '2021-11-22 11:17:10.912359+00', 20559, 1, 963, '', 'C', '', 1, 1, 'Y', '2QzbLkF3ebQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8107, '2021-11-21 21:54:06.359899+00', '2021-11-22 11:20:48.587582+00', 11189, 14, 2269, '', 'B', 'Good elevated viewing position.  The camera swaps sets part way through the dance', 1, 1, 'Y', 'XtHFfa-rK6I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1848, '2014-09-22 15:27:09.895196+00', '2022-03-14 00:19:28.15347+00', 9759, 1, 106, '', 'C', '', 1, 1, 'Y', '6IOQ2aOfbz8', 25, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8099, '2021-11-17 06:59:05.274792+00', '2021-11-22 11:22:35.548091+00', 5960, 1, 20350, '', 'C', 'The Tuesday afternoon ''general'' Scottish country dancing group, Johnsonville, Wellington, New Zealand. November 16, 2021, Live music by Mary McDonald and Lynne Scott.', 1, 1, 'Y', 'iuRRrV3pH2k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8104, '2021-11-21 20:01:09.293321+00', '2021-11-22 11:24:23.152285+00', 10920, 9, 2269, '', 'B', '', 1, 1, 'Y', 'DhE0LHERekE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8106, '2021-11-21 21:22:59.738889+00', '2021-11-22 11:42:42.754076+00', 5802, 6, 2269, '', 'B', '', 1, 1, 'Y', '4xf3VXrnYYc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8108, '2021-11-24 20:34:46.361566+00', '2021-11-24 23:05:00.53513+00', 373, 5, 2269, '', 'C', '', 1, 1, 'Y', 'NdnKwxCXssE', 19, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8105, '2021-11-21 21:19:35.178087+00', '2021-11-25 10:34:05.646015+00', 5802, 5, 2269, '', 'Z', 'Although an excellent dem quality video, one of the dancers (Jacmel Dent) asked us to take it down from the site as she suffered a serious injury while dancing and finds this clip a distressing reminder of a very bad experience. Although she struggled on for the following two dances in the medley this is the only one she objects to.', 1, 1, 'Y', 'V7bw_jhNyPk', 0, 76, NULL);
INSERT INTO 'dancevideo' VALUES (8114, '2021-11-29 18:03:01.388055+00', '2021-11-29 23:58:28.942352+00', 742, 3, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011.', 1, 1, 'Y', 'rsn1YSwNVew', 895, 1145, NULL);
INSERT INTO 'dancevideo' VALUES (8110, '2021-11-28 15:50:33.709633+00', '2021-11-28 23:07:56.6577+00', 16657, 1, 963, '', 'C', '', 1, 1, 'Y', 'qgAC_0g8f0s', 35, 447, NULL);
INSERT INTO 'dancevideo' VALUES (8111, '2021-11-29 17:36:43.150928+00', '2021-11-29 17:47:07.542099+00', 6995, 3, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Twice through as part of a longer display.', 1, 1, 'Y', 'rsn1YSwNVew', 121, 211, NULL);
INSERT INTO 'dancevideo' VALUES (8116, '2021-11-29 18:22:26.049958+00', '2021-11-29 23:59:21.765932+00', 887, 6, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Twice through as part of a longer demo. The end of the 2nd time is adapted to lead into the next dance.', 1, 1, 'Y', 'rsn1YSwNVew', 1239, 1361, NULL);
INSERT INTO 'dancevideo' VALUES (8112, '2021-11-29 17:48:34.691625+00', '2021-11-29 17:55:13.853959+00', 5460, 2, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Middle part of a longer display. Twice through in three 2 couple sets. Here done with the ending preferred by the deviser (as published in the Oriole Book).', 1, 1, 'Y', 'rsn1YSwNVew', 210, 333, NULL);
INSERT INTO 'dancevideo' VALUES (8113, '2021-11-29 17:54:02.627182+00', '2021-11-29 17:55:46.974978+00', 4888, 2, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Last part of a longer display. Twice through in three 2 couple sets.', 1, 1, 'Y', 'rsn1YSwNVew', 332, 414, NULL);
INSERT INTO 'dancevideo' VALUES (8118, '2021-11-29 18:39:29.207331+00', '2021-11-30 00:00:21.525898+00', 2799, 1, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Twice through as part of a longer demo. The end of the 2nd time is adapted to change the orientation of the set for the next dance in the display.

', 1, 1, 'Y', 'rsn1YSwNVew', 2053, 2181, NULL);
INSERT INTO 'dancevideo' VALUES (8115, '2021-11-29 18:17:52.970775+00', '2021-11-30 00:01:07.076488+00', 9926, 2, 1645, '', 'A', 'RSCDS Edinburth Dancing Forth 2011. Twice through as part of a longer demo. The end of the 2nd time is adapted to lead into the next dance.', 1, 1, 'Y', 'rsn1YSwNVew', 1153, 1240, NULL);
INSERT INTO 'dancevideo' VALUES (8117, '2021-11-29 18:33:14.118155+00', '2021-11-30 00:01:53.613482+00', 6205, 3, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Twice through as the last part of a longer demo.', 1, 1, 'Y', 'rsn1YSwNVew', 1360, 1471, NULL);
INSERT INTO 'dancevideo' VALUES (8121, '2021-11-30 00:51:11.735736+00', '2021-11-30 01:18:20.526699+00', 56, 5, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Three times through as the last part of a longer demo.', 1, 1, 'Y', 'rsn1YSwNVew', 2602, 2722, NULL);
INSERT INTO 'dancevideo' VALUES (8120, '2021-11-30 00:46:05.151347+00', '2021-11-30 01:19:18.535081+00', 2203, 8, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2011. Twice through as part of a longer demo. Excellent dancing but both the start of the 1st time and end of the 2nd time are altered. The display starts with a dance on instead of the opening circle and the end is adapted to lead into the next dance.', 1, 1, 'Y', 'rsn1YSwNVew', 2522, 2603, NULL);
INSERT INTO 'dancevideo' VALUES (8123, '2021-11-30 01:15:49.300446+00', '2021-11-30 01:20:00.422954+00', 2222, 4, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Twice through, once each couple, in two 3 couple sets, as part of a longer demo. The last 4 bars of the 2nd time are adapted to lead into the next part of the display.', 1, 1, 'Y', 'rsn1YSwNVew', 3435, 3505, NULL);
INSERT INTO 'dancevideo' VALUES (8119, '2021-11-30 00:33:53.21332+00', '2021-11-30 01:21:12.777069+00', 2846, 6, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2011.', 1, 1, 'Y', 'rsn1YSwNVew', 2187, 2319, NULL);
INSERT INTO 'dancevideo' VALUES (8122, '2021-11-30 00:59:24.97976+00', '2021-11-30 01:21:56.422529+00', 6420, 5, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Twice through as the first part of a longer demo. The last 8 bars of the 2nd time is significantly altered to lead into the next dance.', 1, 1, 'Y', 'rsn1YSwNVew', 3355, 3436, NULL);
INSERT INTO 'dancevideo' VALUES (8124, '2021-11-30 10:49:31.006609+00', '2021-11-30 10:49:47.379924+00', 16961, 2, 202, '', 'D', '', 1, 1, 'Y', '-RFdUpDMPT4', 22, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8125, '2021-11-30 11:23:44.038105+00', '2021-11-30 11:25:26.282412+00', 20439, 1, 1645, '', 'B', 'SCD group Hong Kong 2021. The video starts at bar 2.', 1, 1, 'Y', 'nbK_jEYCLFU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8128, '2021-11-30 14:15:38.442381+00', '2021-11-30 17:15:16.816324+00', 5555, 4, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Three times through as the last part of a longer demo.', 1, 1, 'Y', 'rsn1YSwNVew', 3803, 3913, NULL);
INSERT INTO 'dancevideo' VALUES (8133, '2021-11-30 15:22:51.65014+00', '2021-11-30 17:13:53.504343+00', 12631, 1, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Twice through in two 3 couple sets as part of a longer demo.', 1, 1, 'Y', 'rsn1YSwNVew', 5808, 5931, NULL);
INSERT INTO 'dancevideo' VALUES (8126, '2021-11-30 14:06:22.379018+00', '2021-11-30 17:16:11.303458+00', 4046, 9, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. This clip just shows once through as part of a longer demo.', 1, 1, 'Y', 'rsn1YSwNVew', 3603, 3640, NULL);
INSERT INTO 'dancevideo' VALUES (8127, '2021-11-30 14:10:19.96618+00', '2021-11-30 17:16:57.030721+00', 4759, 4, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Twice through as part of a longer demo.', 1, 1, 'Y', 'rsn1YSwNVew', 3674, 3803, NULL);
INSERT INTO 'dancevideo' VALUES (8130, '2021-11-30 14:30:14.372129+00', '2021-11-30 17:18:53.743266+00', 4803, 6, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Twice through, in two head to head 3 couple sets, as the last part of a longer demo.', 1, 1, 'Y', 'rsn1YSwNVew', 4432, 4514, NULL);
INSERT INTO 'dancevideo' VALUES (8132, '2021-11-30 15:13:02.37561+00', '2021-11-30 17:20:55.958738+00', 10787, 12, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Three times, once each couple, in two 3 couple sets, with 1st couple crossing down to the end each time. Part of a longer display.', 1, 1, 'Y', 'rsn1YSwNVew', 5700, 5810, NULL);
INSERT INTO 'dancevideo' VALUES (518, '2012-12-17 14:18:24.056237+00', '2021-11-30 16:04:19.093246+00', 7546, 1, 1296, '', 'Z', 'This is a video of teaching this dance in class.  Very clear, useful for teaching. But sadly now unavailable?', 1, 1, 'Y', 'P53f7a5WeOY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8131, '2021-11-30 14:45:20.204265+00', '2021-11-30 17:11:54.332287+00', 705, 2, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011.', 1, 1, 'Y', 'rsn1YSwNVew', 4518, 4670, NULL);
INSERT INTO 'dancevideo' VALUES (8129, '2021-11-30 14:24:23.360379+00', '2021-11-30 17:17:50.044187+00', 4484, 9, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Twice through as part of a longer demo. The last 4 bars of the 2nd time are adapted to lead into the next dance in the display.', 1, 1, 'Y', 'rsn1YSwNVew', 4311, 4433, NULL);
INSERT INTO 'dancevideo' VALUES (8134, '2021-11-30 15:28:52.450959+00', '2021-11-30 17:23:09.354947+00', 2158, 5, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Three times, once each couple, in two 3 couple sets as the last part of a longer demo. It is danced twice from the top, then once from the bottom, followed by a dance off.', 1, 1, 'Y', 'rsn1YSwNVew', 5929, 6050, NULL);
INSERT INTO 'dancevideo' VALUES (8141, '2021-11-30 20:55:02.821347+00', '2021-11-30 21:18:14.978337+00', 547, 1, 274, '', 'B', 'Budapest Scottish Dance Club, 30-11-2021', 1, 1, 'Y', 'UOsdLg0jIYU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8140, '2021-11-30 20:52:57.093763+00', '2021-11-30 21:22:29.305022+00', 20563, 1, 274, '', 'B', 'Budapest Scottish Dance Club, 30-11-2021

', 1, 1, 'Y', 'OzWOOt_5yAc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8109, '2021-11-28 09:33:56.375524+00', '2021-12-01 23:12:28.413396+00', 20564, 1, 1645, '', 'B', 'Berkhamsted Strathspey & Reel Club 2021. Dance in memory of former club member Stuart Anderson. Danced three times to music by Ken Martlew.



NB the piano in the hall was being played for the first time since the end of lockdown and was in need of tuning.', 1, 1, 'Y', 'VUJrWYJ89G8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8136, '2021-11-30 15:57:09.353724+00', '2021-12-02 18:36:58.886379+00', 1907, 3, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Twice through in two 3 couple sets as the middle part of a longer demo. The last two bars of the 2nd time are adapted to lead into the next dance.', 1, 1, 'Y', 'rsn1YSwNVew', 6746, 6869, NULL);
INSERT INTO 'dancevideo' VALUES (8135, '2021-11-30 15:49:05.512113+00', '2021-12-02 18:38:35.919157+00', 5128, 4, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2011. Top quality dancing, but here slightly adapted for six couples instead of four.', 1, 1, 'Y', 'rsn1YSwNVew', 6620, 6748, NULL);
INSERT INTO 'dancevideo' VALUES (4984, '2019-08-20 20:52:07.785302+00', '2022-06-23 14:45:34.45069+00', 18378, 1, 202, '', 'D', '', 1, 1, 'Y', 'NAFo8-EcRNY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8989, '2022-08-13 15:57:25.821853+00', '2022-08-13 16:03:29.233204+00', 6373, 7, 202, '', 'C', '', 1, 1, 'Y', 'p7cGj1fqyuM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8144, '2021-12-02 18:20:25.794217+00', '2021-12-02 18:42:13.883553+00', 289, 3, 1645, '', 'C', 'Kuckucksnest Germany, November 2021. A few small glitches here and there but generally good.', 1, 1, 'Y', 'TxMTta1O0uQ', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8143, '2021-12-02 18:12:17.140385+00', '2021-12-02 18:43:24.609867+00', 6143, 2, 1645, '', 'C', 'Kuckucksnest Germany, November 2021. 2nd & 3rd times through.', 1, 1, 'Y', '_PY3yT9PKKY', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8145, '2021-12-02 18:24:29.606849+00', '2021-12-02 18:44:58.003543+00', 3408, 1, 1645, '', 'B', 'Kuckucksnest Germany, November 2021.  Just the last time through. One small passing error at the end of the reel figures neatly corrected at the end of the final circle.', 1, 1, 'Y', 'MuWEYeU99Rk', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8138, '2021-11-30 18:39:40.454027+00', '2021-12-02 18:46:06.618588+00', 13847, 6, 1645, '', 'A', 'St Andrews Summer School 2019 Week 1 Demos. Twice through as part of a longer display.', 1, 1, 'Y', 'V7bw_jhNyPk', 76, 193, NULL);
INSERT INTO 'dancevideo' VALUES (8139, '2021-11-30 18:45:12.549556+00', '2021-12-02 18:46:53.180869+00', 4102, 14, 1645, '', 'A', 'St Andrews Summer School 2019 Week 1 Demos. Twice through as the last part of a longer display.', 1, 1, 'Y', 'V7bw_jhNyPk', 208, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8137, '2021-11-30 16:16:57.007164+00', '2021-12-02 18:47:54.312291+00', 7546, 6, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2011. Just twice through to close the whole display.', 1, 1, 'Y', 'rsn1YSwNVew', 6958, 7002, NULL);
INSERT INTO 'dancevideo' VALUES (8146, '2021-12-02 18:29:44.198404+00', '2021-12-02 18:59:53.330175+00', 3094, 1, 1645, '', 'B', 'Kuckucksnest Germany, November 2021.', 1, 1, 'Y', 'px3AkxpC8yw', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8147, '2021-12-02 18:35:20.785617+00', '2021-12-02 19:00:35.4545+00', 5316, 1, 1645, '', 'A', 'Kuckucksnest Germany, November 2021.', 1, 1, 'Y', 'tyR4Z_uTxyE', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6826, '2020-01-24 20:44:58.242542+00', '2021-12-03 21:51:37.112296+00', 4075, 1, 1645, '', 'Z', 'There are two variants given for the last 8 bars: either all turn RH then LH or all circle 12 hands round and back. Here the team does their own variation: three lots of RH across and back.



No longer available (was Good).', 1, 1, 'Y', '4pQPTP1MzBk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8162, '2021-12-03 23:51:49.585301+00', '2021-12-04 23:49:31.525613+00', 40, 7, 1645, '', 'B', 'Ochil Scottish Country Dancers. Teaching video with subtitles and voiceover.', 1, 1, 'Y', 'ZHuFac1h5ik', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8150, '2021-12-03 23:01:09.225786+00', '2021-12-04 23:50:32.627564+00', 20063, 1, 1645, '', 'C', 'Johnsonville, Wellington, New Zealand 2021.', 1, 1, 'Y', 'p-4fdwVG7R4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8161, '2021-12-03 23:48:41.657344+00', '2021-12-04 23:51:02.482147+00', 377, 4, 1645, '', 'B', 'Ochil Scottish Country Dancers. Teaching video with subtitles and voiceover.', 1, 1, 'Y', 'HCa00pThmP0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8160, '2021-12-03 23:46:19.502167+00', '2021-12-04 23:51:24.063586+00', 984, 4, 1645, '', 'B', 'Ochil Scottish Country Dancers. Teaching video with subtitles and voiceover.', 1, 1, 'Y', 'EvX84yAPq-I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8158, '2021-12-03 23:43:03.341155+00', '2021-12-04 23:51:48.614593+00', 1783, 3, 1645, '', 'B', 'Ochil Scottish Country Dancers. Teaching video with subtitles and voiceover.', 1, 1, 'Y', 'NliuxW7ohZU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8151, '2021-12-03 23:09:43.537241+00', '2021-12-04 23:53:01.08368+00', 19503, 1, 1645, '', 'D', 'Johnsonville, Wellington, NZ 2021. This clip starts with the dancing (the whole video has a little intro by the deviser). Its best to watch the top right set.', 1, 1, 'Y', 'lruOkJcoPfE', 49, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8159, '2021-12-03 23:44:01.852206+00', '2021-12-04 23:53:23.052696+00', 2956, 7, 1645, '', 'B', 'Ochil Scottish Country Dancers. Teaching video with subtitles and voiceover.', 1, 1, 'Y', 'rxI_ftiORTI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8153, '2021-12-03 23:31:31.100318+00', '2021-12-04 23:53:41.867933+00', 3038, 1, 1645, '', 'B', 'Ochil Scottish Country Dancers. Teaching video with subtitles and voiceover.', 1, 1, 'Y', '99B1igKnC7A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8152, '2021-12-03 23:14:31.057082+00', '2021-12-04 23:54:29.895395+00', 11603, 1, 1645, '', 'C', 'Johnsonville, Wellington, NZ 2021.', 1, 1, 'Y', 'aud0r-cidjs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8157, '2021-12-03 23:41:45.519032+00', '2021-12-04 23:57:27.531464+00', 4103, 3, 1645, '', 'B', 'Ochil Scottish Country Dancers. Teaching video with subtitles and voiceover.', 1, 1, 'Y', 'TaNkqg8e6Kk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8149, '2021-12-03 21:57:24.617159+00', '2021-12-04 23:57:06.370869+00', 4075, 2, 1645, '', 'B', 'Caledonian Club at the 2007 Sychrov Highland Games. The last 8 bars are here done in the original version (all turn RH, then LH). The instructions suggest the women should go first, but here the men start each time.', 1, 1, 'Y', '5ULSt8bfRz0', 0, 217, NULL);
INSERT INTO 'dancevideo' VALUES (8156, '2021-12-03 23:40:25.22174+00', '2021-12-04 23:58:18.451822+00', 5040, 5, 1645, '', 'B', 'Ochil Scottish Country Dancers. Teaching video with subtitles and voiceover.', 1, 1, 'Y', '7uXvjasOgvI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8154, '2021-12-03 23:33:48.122177+00', '2021-12-04 23:58:35.0894+00', 5794, 8, 1645, '', 'B', 'Ochil Scottish Country Dancers. Teaching video with subtitles and voiceover.', 1, 1, 'Y', 'ujrZYw3mgS8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8155, '2021-12-03 23:35:28.333859+00', '2021-12-04 23:58:52.546347+00', 5921, 3, 1645, '', 'B', 'Ochil Scottish Country Dancers. Teaching video with subtitles and voiceover.', 1, 1, 'Y', 'm7WjUApwAQw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8164, '2021-12-04 18:22:25.434872+00', '2021-12-05 00:00:01.165273+00', 20456, 1, 1645, '', 'C', 'Most of one repeat, starting around bar 5.', 1, 1, 'Y', '4tchngw-B3g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8148, '2021-12-03 21:44:40.773834+00', '2021-12-05 00:00:54.686707+00', 5525, 24, 1645, '', 'A', 'RSCDS Edinburgh Strictly Scottish 2001. Here danced three times in a 5 couple all male set.', 1, 1, 'Y', 'DV87CLexQO4', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8163, '2021-12-04 17:44:48.489771+00', '2021-12-05 00:02:10.008293+00', 4929, 2, 1645, '', 'A', 'RSCDS Edinburgh Fancy 1987. Two sets at different orientations.', 1, 1, 'Y', 'OTla4kmnHHg', 5, 130, NULL);
INSERT INTO 'dancevideo' VALUES (8165, '2021-12-04 23:41:11.561746+00', '2021-12-05 00:02:58.612815+00', 2394, 7, 1645, '', 'A', 'Airyhall Ladies (Aberdeen) at the 2018 Newcastle Festival . Four times through.', 1, 1, 'Y', 'XuOdMrcN70k', 3, 264, NULL);
INSERT INTO 'dancevideo' VALUES (8166, '2021-12-04 23:47:03.132912+00', '2021-12-05 00:03:34.27293+00', 5529, 13, 1645, '', 'A', 'Airyhall Ladies (Aberdeen) at the 2018 Newcastle Festival . Four times through.', 1, 1, 'Y', 'XuOdMrcN70k', 265, 422, NULL);
INSERT INTO 'dancevideo' VALUES (8168, '2021-12-05 10:45:52.960665+00', '2021-12-05 11:08:26.566433+00', 20562, 1, 1645, '', 'B', 'Kuckucksnest Germany, November 2021. Twice through.', 1, 1, 'Y', 'iHtOO2pEfG4', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8169, '2021-12-07 22:09:02.472302+00', '2021-12-07 22:15:41.623052+00', 20563, 3, 1645, '', 'B', 'Nizhniy Novgorod, Russia, 2021. Excellent dancing with a few little glitches. The instructions suggest 2nd & 3rd couples step up together on bars 23-24 but here 2nd couple step up earlier.', 1, 1, 'Y', 'vGK0N2Gad4A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8170, '2021-12-07 22:53:57.492309+00', '2021-12-07 23:29:57.399863+00', 20064, 2, 1645, '', 'C', 'Capital City Scottish Country Dance Club, NZ, 2021.', 1, 1, 'Y', 'TyuCBfjQpKk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8172, '2021-12-07 23:25:52.514662+00', '2021-12-07 23:31:36.694775+00', 5671, 5, 1645, '', 'B', 'Naramata Scottish Country Dancers 2021.

', 1, 1, 'Y', 'ka2Dt-FbK1A', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8177, '2021-12-08 15:06:56.206188+00', '2021-12-08 15:07:23.532074+00', 20574, 1, 202, '', 'B', '', 1, 1, 'Y', 'byZht3IF2sQ', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8178, '2021-12-09 03:17:33.924514+00', '2021-12-09 03:17:33.924514+00', 20560, 1, 586, 'dd/dance/video/upload/Cailin_Rua.m4v', 'B', 'Dave Wiesler on piano. Music starts with original tune Katydid by David Knight.  ', 0, 0, 'I', '', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8179, '2021-12-09 16:42:28.2169+00', '2021-12-09 16:42:42.560582+00', 20532, 1, 202, '', 'D', '', 1, 1, 'Y', 'DM52cF0y39w', 60, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8171, '2021-12-07 23:24:03.473339+00', '2021-12-09 21:10:22.745243+00', 5529, 14, 1645, '', 'B', 'Naramata Scottish Country Dancers 2021. Seven couple set.', 1, 1, 'Y', 'M-Vab-geGOQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8173, '2021-12-07 23:28:19.593847+00', '2021-12-09 21:11:16.602655+00', 5927, 5, 1645, '', 'B', 'Naramata Scottish Country Dancers 2020. This clip starts with the dancing. The whole video has an introduction to the demonstration.', 1, 1, 'Y', 'UqF5YpQ1Og0', 68, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8174, '2021-12-08 00:08:57.824335+00', '2021-12-09 21:12:03.418738+00', 17327, 3, 1645, '', 'A', 'Leicester RSCDS at the ASCDS Festival 2009. Once through as the first part of a longer display.', 1, 1, 'Y', 'hmal-Sr2Fq0', 41, 89, NULL);
INSERT INTO 'dancevideo' VALUES (8176, '2021-12-08 10:35:45.536701+00', '2021-12-09 21:14:03.710361+00', 20442, 1, 1645, '', 'B', 'SCD group Hong Kong, 2021. This clip just shows the last time through. The whole video starts about 8 bars into the previous repeat.', 1, 1, 'Y', 'H18Xvh06BuA', 60, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8175, '2021-12-08 00:11:45.684535+00', '2021-12-09 21:15:20.934274+00', 6569, 2, 1645, '', 'A', 'Leicester RSCDS at the ASCDS Festival 2009. Once through as part of a longer display.', 1, 1, 'Y', 'hmal-Sr2Fq0', 97, 160, NULL);
INSERT INTO 'dancevideo' VALUES (8180, '2021-12-10 10:51:56.04738+00', '2021-12-11 23:33:39.012635+00', 769, 7, 1645, '', 'B', '51st Annual Tartan Ball in Toronto, 2014.', 1, 1, 'Y', '5_aXqeB035I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8181, '2021-12-11 20:08:08.112715+00', '2021-12-11 23:32:15.139182+00', 6048, 11, 2269, '', 'B', 'Stirling RSCDS. On screen and spoken instructions to the dance', 1, 1, 'Y', 'ALYjgWpCa4U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8990, '2022-08-13 15:59:22.796443+00', '2022-08-13 16:02:40.370519+00', 16522, 5, 202, '', 'C', '', 1, 1, 'Y', 'DaIT8Hmqlo8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8183, '2021-12-11 20:40:56.095799+00', '2021-12-11 23:25:16.165098+00', 14535, 9, 2269, '', 'A', 'RSCDS demonstration for the Teaching Certificate Unit 2 dances.', 1, 1, 'Y', 'oaRABRzdZAM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (287, '2012-10-04 07:21:42.398167+00', '2021-12-11 23:26:20.979028+00', 14535, 2, 513, '', 'Z', 'Was informal/social but no longer available.', 1, 1, 'Y', '2RJT8M6vpIs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1767, '2014-08-23 20:23:02.997404+00', '2021-12-11 23:27:15.361055+00', 5330, 8, 106, '', 'Z', 'Wad Good, now unavailable.', 1, 1, 'Y', 'yAEHxkLcC4Q', 322, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8182, '2021-12-11 20:23:28.921376+00', '2021-12-11 23:29:18.038152+00', 5330, 13, 2269, '', 'C', 'RSCDS Toronto, Youth Ball, 2017 ~ lively dancing', 1, 1, 'Y', 'j6-3YK2VUtQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1287, '2013-08-18 10:55:44.063742+00', '2021-12-12 01:56:53.985652+00', 4827, 4, 1296, '', 'C', 'Vancouver Island Scottish Country Dance Society  

Christmas dance 2012', 1, 1, 'Y', 'IihKY0T2zZw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4794, '2019-05-13 22:50:26.239515+00', '2021-12-12 09:47:20.909367+00', 2170, 2, 1645, '', 'A', '', 1, 1, 'Y', 'Y4d-GlXG4Xs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8184, '2021-12-12 11:20:20.600753+00', '2021-12-12 12:05:34.453571+00', 16191, 1, 223, '', 'C', '', 1, 1, 'Y', 'gwZFio4GHUQ', 9, 324, NULL);
INSERT INTO 'dancevideo' VALUES (8186, '2021-12-12 21:10:14.669704+00', '2021-12-12 21:32:24.945913+00', 1582, 13, 2269, '', 'B', 'RSCDS Edinburgh Branch Demonstration Team, Dancing Forth, 2009.  An impressive display which gives the flavour of the dance but is NOT suitable to learn the dance (the figures are variously done in three 2-couple sets and two 3-couple sets).', 1, 1, 'Y', 'DlRJyOHhlMY', 349, 456, NULL);
INSERT INTO 'dancevideo' VALUES (8187, '2021-12-12 21:29:53.663804+00', '2021-12-12 21:38:11.080168+00', 10433, 13, 2269, '', 'B', 'Ochil Scottish Country Dancers, Stirling 2019. Instructional video with subtitles and voiceover.', 1, 1, 'Y', 'jndlZpFOHqk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8185, '2021-12-12 21:04:59.975905+00', '2021-12-12 21:39:36.199049+00', 1582, 12, 2269, '', 'B', 'Ochil Scottish Country Dancers, Stirling 2016. Instructional video with subtitles and voiceover.', 1, 1, 'Y', 'vkXC9shBnYk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8190, '2021-12-13 21:56:56.445392+00', '2021-12-14 00:14:28.74079+00', 12542, 7, 2269, '', 'A', 'RSCDS Aberdeen Branch, 2020.', 1, 1, 'Y', '70dCVTmUlw4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8189, '2021-12-13 21:38:20.475886+00', '2021-12-14 00:16:37.893313+00', 4805, 11, 2269, '', 'B', 'Ochil Scottish Country Dancers, Stirling 2018. Spoken and written dance instructions on screen.', 1, 1, 'Y', 'eXND4galeaQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8192, '2021-12-13 22:23:12.369465+00', '2021-12-14 00:19:07.350845+00', 6701, 7, 2269, '', 'A', 'Charlotte (NC) Scottish Country Dance Society (CSCDS), 2017.', 1, 1, 'Y', '2wRRfhrMrkQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8191, '2021-12-13 22:20:11.801572+00', '2021-12-14 00:20:41.409459+00', 6701, 6, 2269, '', 'A', 'German Team Mixed, Newcastle RSCDS Festival, 2015.', 1, 1, 'Y', 'BNA9GtM_oiQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8188, '2021-12-13 21:25:49.724147+00', '2021-12-14 00:22:19.973028+00', 10433, 14, 2269, '', 'B', 'RSCDS Edinburgh Branch Demonstration Team, Dancing Forth, 2007.  Elevated camera position.  Excellent dancing, but the beginning is adapted with the first few bars being used to rearrange the dancers from the previous dance in the set.', 1, 1, 'Y', 'dEUUKZlsM9I', 108, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8195, '2021-12-14 15:03:38.006055+00', '2021-12-14 15:56:25.261655+00', 12426, 10, 2269, '', 'A', 'German Team Mixed 2, Newcastle SCD Festival, 2017.', 1, 1, 'Y', 'rNpCDzgk7K8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8196, '2021-12-14 15:21:46.561212+00', '2021-12-14 15:57:02.250311+00', 12426, 11, 2269, '', 'B', 'Ochil Scottish Country Dancers, 2016.  Spoken and on-screen dance instructions.  Slow motion segment on first time through.', 1, 1, 'Y', 'eJbSOXcQAzo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8194, '2021-12-14 14:46:11.795289+00', '2021-12-14 15:58:53.434383+00', 7180, 10, 2269, '', 'B', 'Dance Scottish Of San Diego, National Tartan Day, Balboa Park, 2017.', 1, 1, 'Y', '2bhKIEYg6u4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8193, '2021-12-14 14:37:27.901437+00', '2021-12-14 16:00:13.143349+00', 7180, 9, 2269, '', 'A', 'Budapest Scottish Dance Club, Burns Supper, 2015.  Part of a larger set of dances.  Fully once through with the second repeat modified to flow into the next dance.', 1, 1, 'Y', 'Pua0N0lAYoI', 104, 169, NULL);
INSERT INTO 'dancevideo' VALUES (8197, '2021-12-14 15:49:51.324963+00', '2021-12-14 16:01:52.483255+00', 4641, 8, 2269, '', 'B', 'RSCDS Stirling Branch, Drummond Castle Gardens, 2004.  Spoken and on-screen dance instructions.  The camera pans away briefly when the new first couple begins.', 1, 1, 'Y', 'KWbqsa9B2y8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8198, '2021-12-14 15:59:26.708783+00', '2021-12-14 16:03:37.025629+00', 4641, 9, 2269, '', 'C', 'Kloster Frenswegen Ceilidh, 2018.  3-couple set - fast and furious.', 1, 1, 'Y', 'B56PtTMlfYM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8199, '2021-12-14 16:38:02.276423+00', '2021-12-14 20:15:18.953675+00', 4102, 15, 2269, '', 'B', 'Glasgow University Scottish Country Dance Club, 2017.  Adapted for 3 couples with the popular variation of right shoulder passes in the centre and much embellished after the first repeat.', 1, 1, 'Y', 'l6O_8Xf2G8c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8200, '2021-12-15 11:07:43.241431+00', '2021-12-15 11:48:39.21215+00', 2924, 6, 2269, '', 'C', 'RSCDS Toronto, Youth Ball, 2017.', 1, 1, 'Y', 'euhNguh7oIY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8205, '2021-12-15 15:58:58.102922+00', '2021-12-15 16:13:39.604518+00', 4484, 10, 2269, '', 'A', 'Spring School Of Scottish Dance Festival 2016. Quick Scotch Demonstration Team (NIzhny Novgorod).  A variation is danced - the first couple instead of stepping to the foot at the end of their second time through, change places with the fourth couple by dancing again the first 16 bars of the dance.', 1, 1, 'Y', 'm6iSf7sUqhY', 29, 294, NULL);
INSERT INTO 'dancevideo' VALUES (8207, '2021-12-15 17:03:26.852774+00', '2021-12-15 17:07:54.610271+00', 4155, 10, 2269, '', 'A', 'Lyon Mixed, Newcastle Festival, 2014.', 1, 1, 'Y', 'z_ECnDvw5v0', 0, 261, NULL);
INSERT INTO 'dancevideo' VALUES (8202, '2021-12-15 11:58:32.706195+00', '2021-12-15 20:01:19.569418+00', 1544, 8, 2269, '', 'A', 'Airyhall Dancers, Aberdeen Festival 2017.', 1, 1, 'Y', 'AykpXan7Jw4', 0, 114, NULL);
INSERT INTO 'dancevideo' VALUES (8203, '2021-12-15 12:26:41.187985+00', '2021-12-15 20:02:26.968401+00', 1544, 9, 2269, '', 'A', 'Nottingham RSCDS at the ASCDS Festival on 07 May 2016.', 1, 1, 'Y', 'B8fNSF3wUgA', 43, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8210, '2021-12-15 19:59:43.960651+00', '2021-12-15 20:12:10.756668+00', 5794, 9, 2269, '', 'C', 'The Sailor (reprise) - RSCDS Toronto Family Christmas Dance, 2015.', 1, 1, 'Y', 'R5y_ypvAlto', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8209, '2021-12-15 18:07:25.668824+00', '2021-12-15 20:17:18.300884+00', 13847, 7, 2269, '', 'A', 'Charlotte Scottish Country Dance Society Inc. (CSCDS Inc.), 2019.', 1, 1, 'Y', '8t3cdSXjr38', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8206, '2021-12-15 16:51:48.740991+00', '2021-12-16 11:04:58.355428+00', 4155, 9, 2269, '', 'A', 'Newcastle RSCDS Mixed Team - Newcastle Festival 2019.', 1, 1, 'Y', 'GWoTAFTIOno', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8201, '2021-12-15 11:29:51.818009+00', '2021-12-16 11:01:49.661502+00', 2924, 7, 2269, '', 'D', 'Charleston Royal Scottish Country Dancers.  Picture quality rather fuzzy.  Dancers obviously enjoy themselves and the dance includes some freestyle flourishes.', 1, 1, 'Y', '6nb5co19V7w', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8208, '2021-12-15 17:17:33.052655+00', '2021-12-16 11:05:57.036329+00', 4155, 11, 2269, '', 'B', 'Ochil Scottish Country Dancers, 2019.  Spoken and on-screen dance instructions. ', 1, 1, 'Y', 'gMtvSghTBsg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8213, '2021-12-16 09:50:21.413718+00', '2021-12-16 11:07:45.564747+00', 20440, 1, 2630, '', 'B', 'Demo Dandy Dancers by Dancers from Ribble Valley RSCDS.   The instructions for bars 21 -24 state 1st lady and 4th man turn 1 1/2 times R hand while 1st man and 4th lady turn 1 1/2 times L hand. In this video the dancers birl', 1, 1, 'Y', 'dK70PGzVbME', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8212, '2021-12-16 09:36:48.513391+00', '2021-12-16 11:10:23.36286+00', 20445, 1, 2630, '', 'B', 'Last Orders by dancers from the Ribble Valley RSCDS. Once through.', 1, 1, 'Y', 'FgT6DwyEbo0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8216, '2021-12-16 12:50:34.122932+00', '2021-12-16 12:53:39.782133+00', 6461, 3, 1645, '', 'A', 'Cambridge University Strathspey & Reel Club 75th Birthday 2021. The last part of a longer display. Dancers are sometimes outside the camera view.

', 1, 1, 'Y', 'snuv9TeWGRY', 246, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8211, '2021-12-16 02:33:01.364081+00', '2021-12-18 09:06:30.581646+00', 20441, 1, 2630, '', 'B', 'Da Trowie Reel by dancers from the Ribble Valley RSCDS', 1, 1, 'Y', '0Nmy42Bqo80', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8214, '2021-12-16 12:37:22.897732+00', '2021-12-16 12:52:06.134752+00', 5759, 1, 1645, '', 'A', 'Cambridge University Strathspey & Reel Club 75th Birthday 2021. Twice through as the first part of a longer display. The first repeat starts with just two couples for the first 8 bars. The second repeat has the expected three couples throughout. Dancers are sometimes outside the camera view.', 1, 1, 'Y', 'snuv9TeWGRY', 0, 125, NULL);
INSERT INTO 'dancevideo' VALUES (8215, '2021-12-16 12:44:37.50165+00', '2021-12-16 12:52:49.4494+00', 1384, 1, 1645, '', 'B', 'Cambridge University Strathspey & Reel Club 75th Birthday 2021. Twice through as part of a longer display. Excellent dancing but in both repeats the final rights and lefts is adapted to change the orientation of the set or to end in a square set. Dancers are sometimes outside the camera view.

', 1, 1, 'Y', 'snuv9TeWGRY', 124, 247, NULL);
INSERT INTO 'dancevideo' VALUES (8217, '2021-12-16 13:23:33.338615+00', '2021-12-16 19:57:10.939765+00', 10794, 4, 2269, '', 'B', 'RSCDS Chicago Branch Demonstration Team, Chicago Highland Games, Itasca, Illinois, USA, 2015.', 1, 1, 'Y', 'irCzagu5QCk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8218, '2021-12-17 19:02:08.600487+00', '2021-12-18 09:41:13.557398+00', 20442, 2, 2630, '', 'B', 'Stagger Dream danced at ''An evening of Scottish Music and Dance'' in Preston', 1, 1, 'Y', 'pVgj8p3-Ixs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8850, '2022-06-23 05:27:47.110329+00', '2022-06-23 07:38:51.094375+00', 20887, 2, 645, '', 'B', 'June 2022', 1, 1, 'Y', 'CbJ7JksX9JA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8220, '2021-12-19 12:30:04.345424+00', '2021-12-19 12:30:57.119398+00', 20575, 1, 1645, '', 'D', 'RSCDS Belfast: Virtual Festival 2021. Once through in two 2 couple sets.', 1, 1, 'Y', '1-547Eos8r8', 99, 138, NULL);
INSERT INTO 'dancevideo' VALUES (8221, '2021-12-19 13:00:24.048224+00', '2021-12-19 13:07:10.969922+00', 20563, 3, 1645, '', 'A', 'Saratov, Russia, 2021.', 1, 1, 'Y', 'lX6lr-XoeJQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8226, '2021-12-21 20:25:13.008966+00', '2021-12-21 21:50:11.878583+00', 20578, 1, 197, '', 'C', '', 1, 1, 'Y', 'CgJ11C9BvXQ', 9, 159, NULL);
INSERT INTO 'dancevideo' VALUES (8223, '2021-12-20 14:49:37.434856+00', '2021-12-23 22:31:00.648758+00', 14043, 1, 1645, '', 'D', 'Scottish dance festival in Saratov, Russia, 2019. This clip shows the last two repeats from a longer video (at a cracking pace). Even by this point there are problems with the unusual sequence of LH across followed by RH across in the last 8 bars. The camera view does not completely cover the nearest set.', 1, 1, 'Y', 'NzTF-uATomY', 193, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8225, '2021-12-20 15:09:13.865063+00', '2021-12-23 22:31:22.638815+00', 3759, 9, 1645, '', 'B', 'Old City Club, Saratov, Russia, 2021.', 1, 1, 'Y', '3uknTr-LOyk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8224, '2021-12-20 15:04:37.787842+00', '2021-12-23 22:32:22.588495+00', 4862, 4, 1645, '', 'B', 'Old City Club, Saratov, Russia 2021. Here danced in a 5 couple set. The dancers change places right hands rather than just passing.', 1, 1, 'Y', 'Rx12ZKEX3lY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8222, '2021-12-20 12:18:31.399412+00', '2021-12-23 22:33:38.916021+00', 18954, 1, 1645, '', 'C', 'Scottish dance festival in Saratov, Russia, 2019. This clip just shows the last two repeats from the complete video. The camera view does not quite include the whole of the nearer set.', 1, 1, 'Y', 'Xhh2ut8Rppo', 370, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8075, '2021-10-12 13:10:47.731479+00', '2021-12-24 02:01:04.880477+00', 7068, 2, 202, '', 'D', 'Recorded on 09.10.2021 during the RSCDS Paris Branch Autumn Weekend.    

This was the 1st workshop/social dance after a 18 months COVIS-19 hiatus.', 1, 1, 'Y', 'p0Cdyo0z_24', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8229, '2022-01-02 18:30:17.866479+00', '2022-01-02 18:31:07.618325+00', 301, 5, 202, '', 'A', '', 1, 1, 'Y', 'iUH1xWCAZoI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8228, '2022-01-02 18:26:40.361684+00', '2022-01-02 18:56:17.54431+00', 12848, 2, 202, '', 'D', '', 1, 1, 'Y', 'rtkOE8BrHKI', 35, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8219, '2021-12-18 13:25:16.166205+00', '2022-05-24 21:45:41.020893+00', 16191, 2, 223, '', 'B', 'Four times, once each couple. The instructions say the dancers who set turning as two others change places around them should be keeping their arms raised.', 1, 1, 'Y', 'lSX12ty_bWA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8230, '2022-01-03 07:08:59.822206+00', '2022-01-03 07:09:19.953734+00', 2030, 5, 202, '', 'D', '', 1, 1, 'Y', 'M9UBTjJ1dDQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8232, '2022-01-07 19:13:42.221005+00', '2022-01-07 19:54:48.382484+00', 6449, 2, 1645, '', 'B', 'Quick Scotch class in Nizhniy Novgorod, Russia, 2021. Danced in a longwise set with end couples standing in alternate repeats. The two hand turns are here done just with right hand.', 1, 1, 'Y', 'IlF8EvUnRe8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8231, '2022-01-04 19:16:20.824727+00', '2022-01-07 19:57:23.341158+00', 4565, 3, 2269, '', 'A', 'German Mixed Team, Newcastle RSCDS Festival, 2014.', 1, 1, 'Y', '9oPdIyczboE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8233, '2022-01-08 11:59:52.902101+00', '2022-01-08 12:01:02.867521+00', 1884, 7, 1645, '', 'B', 'Dancing outside at the RSCDS Summer School 2014. This clip just shows the last repeat. The whole video starts part way through the previous turn.', 1, 1, 'Y', 'Z9qNNTk9O1M', 33, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8234, '2022-01-08 12:03:17.125988+00', '2022-01-08 12:13:20.70238+00', 20605, 1, 1645, '', 'B', 'Quick Scotch dancers in Nizhniy Novgorod, Russia, 2021. Twice through.', 1, 1, 'Y', 'SfxRVZfuGhs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8238, '2022-01-09 02:40:03.264965+00', '2022-01-09 02:40:03.264965+00', 442, 2, 1296, '', 'X', '''Bedrule'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', 'cdjjCsPim1Q', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8239, '2022-01-09 02:40:03.281387+00', '2022-01-09 02:40:03.281387+00', 13367, 1, 1296, '', 'X', '''Engine Room, The'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'WLHsJe_t8Pk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8240, '2022-01-09 02:40:03.292515+00', '2022-01-09 02:40:03.292515+00', 2004, 2, 1296, '', 'X', '''Espie McNabb'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', '8GR_jhHNiW0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8241, '2022-01-09 17:36:17.34906+00', '2022-01-09 17:37:11.677988+00', 2934, 3, 1645, '', 'X', '''The Highlandman kissed his Mother'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'uHrmPS3oQYE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6958, '2020-02-25 20:40:15.163997+00', '2022-01-11 18:09:36.323179+00', 3941, 6, 1645, '', 'Z', 'Twice through as part of a longer demo. The last 8 bars of the 2nd repeat are adapted (with both 1st and 3rd couples dancing) to lead into the next dance in the medley.



Video now unavailable?', 1, 1, 'Y', 'hYe0lIfqp8w', 195, 290, NULL);
INSERT INTO 'dancevideo' VALUES (8235, '2022-01-08 21:00:38.476952+00', '2022-01-11 18:57:05.965819+00', 7210, 3, 2269, '', 'A', 'Men''s Open, Edinburgh Scottish Dancers, 2018.', 1, 1, 'Y', '77GdeETR69U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8237, '2022-01-08 21:39:08.096549+00', '2022-01-11 22:22:57.651865+00', 1501, 8, 2269, '', 'A', 'Lyon, Men''s Open, Newcastle Festival, 2020.', 1, 1, 'Y', 'hKB577TXP50', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8242, '2022-01-11 17:46:49.645213+00', '2022-01-11 18:58:05.44642+00', 20563, 4, 1645, '', 'B', 'Deer O'' Dale dance school, Ufa, Russia, 2021.', 1, 1, 'Y', 'QzINOIUQBRk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8236, '2022-01-08 21:11:10.359248+00', '2022-01-11 22:21:00.421858+00', 3802, 5, 2269, '', 'A', 'Scottish Games, Pleasanton, California, 2015.', 1, 1, 'Y', 'sGSOBUn3HiA', 30, 100, NULL);
INSERT INTO 'dancevideo' VALUES (8243, '2022-01-11 18:03:26.253294+00', '2022-01-11 22:23:32.176077+00', 1098, 1, 1645, '', 'C', 'SCD group Hong Kong 2021. This clip shows three times through, starting with a repeat from 2nd place. 3rd couple wait a couple of bars before starting their reels.', 1, 1, 'Y', '1WfbKpJvw04', 19, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8246, '2022-01-14 16:12:08.314645+00', '2022-01-14 16:36:44.339608+00', 1087, 11, 2269, '', 'C', 'RSCDS Toronto Youth Ball, 2017.  A couple of the dancers are a little unsure of what formation comes next.', 1, 1, 'Y', 'LD0vRs99hzU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8247, '2022-01-14 16:32:41.578774+00', '2022-01-14 16:38:42.810904+00', 6010, 6, 2269, '', 'C', 'Upper Hutt SCD Club, 2017.  Some of the dancers cast up to begin the reels of three which is incorrect.', 1, 1, 'Y', 'uEnZK3MG1Zo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8245, '2022-01-14 16:00:19.587651+00', '2022-01-14 18:17:24.044115+00', 1087, 10, 2269, '', 'B', 'RSCDS Stirling Branch, Princes St Gardens, Edinburgh, 2007.  Spoken and on-screen dance instructions.', 1, 1, 'Y', '7nFAIFm0R0o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7964, '2021-05-13 22:24:57.014113+00', '2022-01-14 22:27:47.769579+00', 10504, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes)



The "gypsy" turns in the instructions (a term considered offensive by some) are here referred to as "right shoulder round" - though the video looks as though hands may be taken?

', 1, 1, 'Y', 'y8Hn562TlCk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8250, '2022-01-14 22:41:06.363822+00', '2022-01-14 22:55:55.884245+00', 6710, 1, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes).', 1, 1, 'Y', 'LW1KfQaGL18', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8244, '2022-01-13 10:54:02.650832+00', '2022-01-14 22:56:04.042664+00', 5885, 14, 1645, '', 'B', 'Budapest Scottish Dance Club. Beautifully danced twice through (to different music).', 1, 1, 'Y', '847evYeRiEQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8227, '2022-01-02 18:23:23.879398+00', '2022-01-17 15:27:17.412069+00', 7239, 3, 202, '', 'C', '', 1, 1, 'Y', 'xcsDXwaIc20', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8855, '2022-06-23 18:28:35.339167+00', '2022-06-23 19:21:15.387619+00', 323, 1, 1645, '', 'C', 'Leeds, 2018.', 1, 1, 'Y', '8m4qkLoty6o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8249, '2022-01-14 22:35:12.125481+00', '2022-01-14 22:55:43.11338+00', 2700, 3, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes).', 1, 1, 'Y', '3GnzYMTfaes', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8251, '2022-01-14 22:47:05.58078+00', '2022-01-14 22:55:49.408798+00', 17304, 3, 1645, '', 'X', '(Contrary to standard SCD diagram notation men are represented by rectangles, women as oval-ish shapes).



The final petronalla turns are here shown as dance to sides without turning.', 1, 1, 'Y', 'OtAr5nvIHPM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8253, '2022-01-14 23:05:06.829771+00', '2022-01-14 23:19:47.605832+00', 10650, 4, 1645, '', 'C', 'Helensburg, 2014.', 1, 1, 'Y', 'NhOaMBs024Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8252, '2022-01-14 23:01:12.734805+00', '2022-01-14 23:20:08.135932+00', 16535, 6, 1645, '', 'C', 'Scottish Highland Games in Enumclaw, Washington, 2018. Three times through.', 1, 1, 'Y', 'Muv_BXYXvNo', 0, 105, NULL);
INSERT INTO 'dancevideo' VALUES (8271, '2022-01-15 22:28:46.00368+00', '2022-01-22 00:19:09.005455+00', 6373, 5, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS  Archive

', 1, 1, 'Y', 'iF-QZqMxb20', 2797, 2928, NULL);
INSERT INTO 'dancevideo' VALUES (8254, '2022-01-14 23:10:02.514068+00', '2022-01-14 23:20:54.95798+00', 17800, 2, 1645, '', 'B', 'Thistle Scottish Country Dancers at Windsor, Nova Scotia, 2012.', 1, 1, 'Y', 'RyFpM3nDpHE', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8255, '2022-01-14 23:19:23.640085+00', '2022-01-14 23:22:59.719527+00', 11969, 1, 1645, '', 'D', 'Northern Italy Scottish Country Dancers, 2012. A class being coached through the dance. The first half circle is here danced to the right rather than to the left. And the meanwhile figure in bars 57-72 (half reels and turns) goes a little awry.', 1, 1, 'Y', 'zkSjlktuwK0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8256, '2022-01-14 23:45:13.870972+00', '2022-01-14 23:58:34.686041+00', 5904, 6, 1645, '', 'B', 'Rosedale Youth Group, Toronto, 2019. Twice through in a 2 couple set.', 1, 1, 'Y', 'Cy5E0S0ybcY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8258, '2022-01-14 23:58:21.216657+00', '2022-01-14 23:58:57.701636+00', 2030, 7, 1645, '', 'B', 'Stirling RSCDS, 2019. With voice over and on screen instructions.', 1, 1, 'Y', 'kKtjXlA5q1U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8268, '2022-01-15 21:41:44.412785+00', '2022-01-22 00:20:34.28539+00', 7147, 9, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS  Archive

', 1, 1, 'Y', 'iF-QZqMxb20', 2545, 2625, NULL);
INSERT INTO 'dancevideo' VALUES (8264, '2022-01-15 21:34:18.305483+00', '2022-01-22 00:22:56.240278+00', 2745, 2, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS  Archive

', 1, 1, 'Y', 'iF-QZqMxb20', 2085, 2163, NULL);
INSERT INTO 'dancevideo' VALUES (7754, '2021-01-14 20:36:03.449778+00', '2022-01-27 20:04:33.207093+00', 2777, 4, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2010. Twice through as part of a longer demonstration. The last 10 bars of the 2nd repeat are heavily adapted to lead into the next dance in the demo.', 1, 1, 'Y', 'A3zVbjl5Ljo', 127, 197, NULL);
INSERT INTO 'dancevideo' VALUES (8265, '2022-01-15 21:35:56.95167+00', '2022-01-22 00:26:20.740057+00', 2979, 5, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS  Archive

', 1, 1, 'Y', 'iF-QZqMxb20', 2165, 2242, NULL);
INSERT INTO 'dancevideo' VALUES (8266, '2022-01-15 21:37:27.920619+00', '2022-01-22 00:27:09.369128+00', 4032, 7, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS  Archive

', 1, 1, 'Y', 'iF-QZqMxb20', 2245, 2322, NULL);
INSERT INTO 'dancevideo' VALUES (8269, '2022-01-15 22:24:35.0447+00', '2022-01-22 00:27:58.105929+00', 1582, 14, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS  Archive

', 1, 1, 'Y', 'iF-QZqMxb20', 2627, 2710, NULL);
INSERT INTO 'dancevideo' VALUES (8272, '2022-01-15 22:31:22.651294+00', '2022-01-22 00:29:03.327607+00', 2250, 7, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS  Archive

', 1, 1, 'Y', 'iF-QZqMxb20', 3044, 3127, NULL);
INSERT INTO 'dancevideo' VALUES (8280, '2022-01-18 22:25:45.323314+00', '2022-01-21 23:57:38.925171+00', 6957, 4, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999

', 1, 1, 'Y', 'iF-QZqMxb20', 4415, 4530, NULL);
INSERT INTO 'dancevideo' VALUES (8276, '2022-01-18 07:36:06.214475+00', '2022-01-22 00:29:42.049702+00', 1210, 2, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999

', 1, 1, 'Y', 'iF-QZqMxb20', 3213, 3298, NULL);
INSERT INTO 'dancevideo' VALUES (8257, '2022-01-14 23:55:21.102012+00', '2022-01-15 23:47:13.295613+00', 2030, 6, 1645, '', 'B', 'Urals "teapot" festival, Russia, 2018. Dancers from Ekaterinburg. Four times.', 1, 1, 'Y', 'OFM4OAqp2fI', 0, 258, NULL);
INSERT INTO 'dancevideo' VALUES (8262, '2022-01-15 00:20:56.785939+00', '2022-01-15 23:47:35.732732+00', 2437, 8, 1645, '', 'A', 'Quick Scotch team at the 2015 Spring School in Nizhniy Novgorod, Russia.', 1, 1, 'Y', 'UheSalfFUIw', 28, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8261, '2022-01-15 00:20:50.09436+00', '2022-01-15 23:48:21.715925+00', 5904, 7, 1645, '', 'B', 'Urals "teapot" festival, Russia, 2018. Dancers from Ekaterinburg.', 1, 1, 'Y', 'A-bp0TdiVG0', 0, 195, NULL);
INSERT INTO 'dancevideo' VALUES (8259, '2022-01-15 00:10:18.65896+00', '2022-01-15 23:48:45.687776+00', 6848, 4, 1645, '', 'A', 'International Team at the Newcastle Festival 2017.', 1, 1, 'Y', 'MQeakUnDpaE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8260, '2022-01-15 00:16:36.983183+00', '2022-01-15 23:49:30.79929+00', 6848, 5, 1645, '', 'A', 'Sinn Araon team from Krasnodar at the 2015 Spring School in Nizhniy Novogorod, Russia.', 1, 1, 'Y', '0Ft3t_rs0zM', 41, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8277, '2022-01-18 15:19:39.310213+00', '2022-01-18 15:32:00.90999+00', 20635, 1, 202, '', 'C', '', 1, 1, 'Y', '5a8mblOduUo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8275, '2022-01-18 07:34:06.847664+00', '2022-01-22 00:30:25.521365+00', 5239, 10, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999

', 1, 1, 'Y', 'iF-QZqMxb20', 3129, 3211, NULL);
INSERT INTO 'dancevideo' VALUES (8278, '2022-01-18 19:11:08.449462+00', '2022-01-18 19:46:41.232847+00', 13362, 4, 963, '', 'B', 'Black Watch Military Tattoo 2017.', 1, 1, 'Y', '-C7PG6dEy44', 129, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8274, '2022-01-18 07:30:37.167608+00', '2022-01-22 00:31:09.606921+00', 5713, 7, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999

', 1, 1, 'Y', 'iF-QZqMxb20', 2932, 3042, NULL);
INSERT INTO 'dancevideo' VALUES (8263, '2022-01-15 21:32:56.012976+00', '2022-01-25 00:47:26.234173+00', 1786, 8, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS  Archive', 1, 1, 'Y', 'iF-QZqMxb20', 2005, 2082, NULL);
INSERT INTO 'dancevideo' VALUES (8279, '2022-01-18 20:49:32.25765+00', '2022-01-18 20:51:11.288899+00', 17777, 1, 1645, '', 'C', 'Dancers from Oldenburg.



Note that this video was recorded before the dance name and choreography was finalised (on youtube its just called "Judith''s Dance"). In particular the video shows two half circles separated by set and cross whereas the final version has circle and back without interruption with all the setting & crossing before and after. Hence marked as "Reasonable" despite the good dancing.', 1, 1, 'Y', 'CDrlYpJXG_I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8283, '2022-01-19 01:06:33.459506+00', '2022-01-19 01:11:24.247885+00', 20636, 1, 1645, '', 'B', 'Plateau Scottish Country Dancers at Enumclaw Highland Games.

', 1, 1, 'Y', '-dGNTSvBQmc', 480, 730, NULL);
INSERT INTO 'dancevideo' VALUES (8281, '2022-01-18 22:57:00.167324+00', '2022-01-19 01:12:55.704323+00', 2415, 4, 562, '', 'A', 'Newcastle Festival 2020 - Mixed Open - German Team', 1, 1, 'Y', 'knVfGw7txvs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8267, '2022-01-15 21:40:18.908494+00', '2022-01-22 00:21:28.856205+00', 6048, 12, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS  Archive

', 1, 1, 'Y', 'iF-QZqMxb20', 2465, 2544, NULL);
INSERT INTO 'dancevideo' VALUES (8284, '2022-01-19 01:16:03.120322+00', '2022-01-19 01:18:12.976431+00', 6264, 1, 1645, '', 'B', 'RSCDS Twin Cities Branch workshop 2016.', 1, 1, 'Y', 'ExobJdjMZZo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8287, '2022-01-20 02:40:03.310714+00', '2022-01-20 02:40:03.310714+00', 12793, 8, 1296, '', 'X', '''Eileen Watt''s Reel'' is a 32 bar reel for 3 couples in a 3 couple set.', 1, 1, 'Y', 'jk1jiitAav4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8285, '2022-01-19 13:02:07.547166+00', '2022-01-19 13:03:25.309948+00', 15683, 1, 1645, '', 'C', 'NZ Branch Otago Region Easter School 2021. Once through clip from classes.', 1, 1, 'Y', 'kTgmKYYoNE0', 204, 243, NULL);
INSERT INTO 'dancevideo' VALUES (8286, '2022-01-19 13:26:04.394512+00', '2022-01-19 13:26:30.122256+00', 18581, 1, 1645, '', 'B', 'Telheiras SCD group, Lisbon. Once through to music composed by the dance deviser, then twice through to another recording.', 1, 1, 'Y', 'CvWIH5lCHd4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8282, '2022-01-19 01:04:22.091903+00', '2022-01-19 18:14:41.944327+00', 20637, 1, 1645, '', 'B', 'Plateau Scottish Country Dancers at Enumclaw Highland Games.', 1, 1, 'Y', '-dGNTSvBQmc', 322, 468, NULL);
INSERT INTO 'dancevideo' VALUES (8288, '2022-01-20 02:40:03.335265+00', '2022-01-20 02:40:03.335265+00', 2321, 3, 1296, '', 'X', '''Foxhill Court'' is a 32 bar strathspey for 3 couples in a 3 couple set.', 1, 1, 'Y', 'L5MTpIDxJKs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8289, '2022-01-20 02:40:03.359565+00', '2022-01-20 02:40:03.359565+00', 13579, 4, 1296, '', 'X', '''Homecoming Dance, The'' is a 32 bar reel for 4 couples in a 4 couple set.', 1, 1, 'Y', 'wUbsKQu5RYg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8290, '2022-01-20 02:40:03.379994+00', '2022-01-20 02:40:03.379994+00', 3338, 5, 1296, '', 'X', '''Johnnie''s Welcome Hame'' is a 40 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'SFpaOGtM4es', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8291, '2022-01-20 02:40:03.400855+00', '2022-01-20 02:40:03.400855+00', 14548, 5, 1296, '', 'X', '''Rutland Reel, The'' is a 40 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'Vib7j0E2hnE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8292, '2022-01-20 19:14:53.911835+00', '2022-01-20 20:25:26.91594+00', 462, 7, 2269, '', 'B', 'Ochil Scottish Country Dancers, St Ninian''s Church Hall, Stirling, Scotland, 2017.  Spoken and on-screen dancing instructions.', 1, 1, 'Y', 'SY0RODdClGo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8300, '2022-01-21 00:27:21.210557+00', '2022-01-21 01:40:10.090746+00', 2125, 5, 1645, '', 'B', 'Scottish Flowers (Hildesheim) at the Peine Highland Gathering, 2014.', 1, 1, 'Y', 'a1hEPeszccg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8299, '2022-01-21 00:09:00.407791+00', '2022-01-21 01:45:05.991004+00', 50, 2, 1645, '', 'D', 'Curia Weekend, Portugal, 2016.', 1, 1, 'Y', '5_Cfwtc-t9Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8298, '2022-01-21 00:04:11.832192+00', '2022-01-21 01:48:48.756939+00', 7019, 3, 1645, '', 'C', 'Curia Weekend, Portugal, 2016. Last four times through.', 1, 1, 'Y', 'jPQmX54CUIc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8297, '2022-01-20 23:56:32.317673+00', '2022-01-21 01:55:15.975383+00', 5262, 5, 1645, '', 'C', 'Saturday class at the Curia Weekend, Portugal, 2016. Once through view from the bottom of the set, then the camera starts roving.', 1, 1, 'Y', '_oFHkUypODg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8296, '2022-01-20 23:51:24.48239+00', '2022-01-21 01:56:46.863999+00', 3601, 2, 1645, '', 'C', 'Curia Weekend, Portugal, 2016.', 1, 1, 'Y', '1aoxVlQ9ZSY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8295, '2022-01-20 23:15:51.708823+00', '2022-01-21 01:59:21.786486+00', 16894, 2, 1645, '', 'C', 'Curia Weekend, Portugal, 2016. Once through.', 1, 1, 'Y', 'TDeOZ9AblVU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8301, '2022-01-21 09:50:31.953463+00', '2022-01-21 09:54:19.450127+00', 4411, 10, 2269, '', 'A', 'Scottish Country Dancers, Karlsruhe, Folkloria, 2017.', 1, 1, 'Y', 'OP4BuoaqKsw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8314, '2022-01-21 19:25:54.801998+00', '2022-01-21 21:39:49.709461+00', 2604, 8, 2269, '', 'B', 'Peterborough Scottish Dance Society, 2017. The music is out of sync with the dancing.', 1, 1, 'Y', '050xMqienpM', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8303, '2022-01-21 10:07:21.353404+00', '2022-01-21 10:27:17.569964+00', 13588, 9, 2269, '', 'B', 'RSCDS Recycled Teenagers, Aberdeen Festival, 2018.', 1, 1, 'Y', 'YbZLzd7D9bY', 266, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8293, '2022-01-20 20:39:32.946195+00', '2022-01-21 10:43:01.486405+00', 7105, 5, 1645, '', 'B', 'Telheiras SCD group, Lisbon, 2015. Once each couple.', 1, 1, 'Y', 'zop8vCxT3g0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8294, '2022-01-20 23:09:20.88566+00', '2022-01-21 10:43:23.946881+00', 15712, 1, 1645, '', 'C', 'Madrid Iberian Weekend 2015. The strathspey section goes well, but the reel section is more of a challenge, especially the interesting "Iberian Knot" figure.', 1, 1, 'Y', 'ESGXuGYkmEE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8302, '2022-01-21 09:59:31.049268+00', '2022-01-21 10:44:02.930763+00', 2196, 1, 1645, '', 'B', 'Saturday class at the Curia Weekend, Portugal, 2016. Twice through view from the bottom of the set.', 1, 1, 'Y', 'whB3xCJUnJY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8320, '2022-01-22 12:30:22.386339+00', '2022-01-22 21:38:26.855827+00', 1562, 10, 2269, '', 'C', 'Scottish Party At The Festival "The Breath Of Siberia", Tomsk, Russia, 2017.', 1, 1, 'Y', '9l9_Lyt8ENw', 19, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8307, '2022-01-21 12:00:27.615152+00', '2022-01-21 21:32:25.951297+00', 2437, 10, 2269, '', 'B', 'RSCDS Recycled Teenagers, Aberdeen Festival, 2018.', 1, 1, 'Y', 'YbZLzd7D9bY', 0, 263, NULL);
INSERT INTO 'dancevideo' VALUES (8306, '2022-01-21 10:59:44.877716+00', '2022-01-21 21:33:36.039003+00', 2437, 9, 2269, '', 'B', 'RSCDS Stirling, 2018.  Spoken and on-screen dancing instructions.', 1, 1, 'Y', 'wISlZapEwdQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8312, '2022-01-21 19:10:34.213248+00', '2022-01-21 21:35:26.05061+00', 2604, 6, 2269, '', 'B', 'Ochil Scottish Country Dancers, St Ninian''s Church Hall, Stirling, Scotland, 2018.  Spoken and on-screen dancing instructions.', 1, 1, 'Y', 'i3lOxpSeezE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8313, '2022-01-21 19:19:57.133042+00', '2022-01-21 21:38:35.047974+00', 2604, 7, 2269, '', 'A', 'Glasgow University Scottish Country Dance Club, 2018.  Danced with energy in a 3-couple set.', 1, 1, 'Y', 'TH_cwNJONwo', 6, 113, NULL);
INSERT INTO 'dancevideo' VALUES (8305, '2022-01-21 10:55:20.530242+00', '2022-01-21 21:51:33.893639+00', 20634, 1, 1645, '', 'C', 'Glasgow Branch at Mugdock Park, 2007.', 1, 1, 'Y', 'AEbbTCGtcRw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8310, '2022-01-21 16:03:32.814335+00', '2022-01-21 21:57:01.006999+00', 4641, 11, 2269, '', 'A', 'Members and Friends of RSCDS Sterling Branch, Guildhall, Sterling, Scotland, 2020.', 1, 1, 'Y', 'iF-QZqMxb20', 2717, 2795, NULL);
INSERT INTO 'dancevideo' VALUES (8304, '2022-01-21 10:50:11.26778+00', '2022-01-21 21:58:39.312061+00', 9102, 6, 1645, '', 'A', 'Glasgow Branch Demonstration Team.', 1, 1, 'Y', '9JEoBwpsch4', 129, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8308, '2022-01-21 12:59:20.784732+00', '2022-01-21 22:01:32.506198+00', 3057, 8, 2269, '', 'B', 'Berkhamsted Strathspey And Reel Club Demonstration Team, 2013.', 1, 1, 'Y', 'zfDiXmfmcrk', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8309, '2022-01-21 15:48:25.115669+00', '2022-01-21 22:03:19.73197+00', 3057, 9, 2269, '', 'A', 'Aberdeen RSCDS Branch Team, Duthie Park, 2015.', 1, 1, 'Y', 'oxwXlXegR4c', 427, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8317, '2022-01-21 22:32:24.139233+00', '2022-01-22 21:41:51.316901+00', 10433, 15, 2269, '', 'A', 'RSCDS Canberra Branch, National Folk Festival, Canberra, Australia, 2014.', 1, 1, 'Y', 'StxWejOB0B0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4802, '2019-05-16 20:10:08.748233+00', '2022-01-22 00:14:38.720759+00', 2077, 1, 274, '', 'A', 'RSCDS London Branch - picnic dance. Last part of a longer demonstration (from an old video). ', 1, 1, 'Y', 'NrhtBxJtgw0', 228, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2322, '2016-01-31 10:00:19.819252+00', '2022-01-22 00:15:35.661187+00', 5708, 1, 2219, '', 'B', 'RSCDS London Branch Demonstration Team 04 July 1998 - part of a display comprising Foursome, Joie de Vivre, The Royal Wedding, and Roundabout Hullachan.', 1, 1, 'Y', 'd6HzorTmjC8', 228, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5536, '2019-12-26 10:44:02.58239+00', '2022-01-22 00:16:52.399392+00', 19770, 2, 274, '', 'A', 'STRICTLY SCOTTISH Vancouver Demonstration Team ', 1, 1, 'Y', 'D-Cie_7Sp54', 18, 205, NULL);
INSERT INTO 'dancevideo' VALUES (8321, '2022-01-22 14:12:30.578442+00', '2022-01-22 14:13:02.958091+00', 20635, 2, 202, '', 'C', '', 1, 1, 'Y', '2eapTSCn5OQ', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8318, '2022-01-21 22:34:41.274225+00', '2022-01-22 21:33:45.554924+00', 1934, 5, 1645, '', 'B', 'Vancouver RSCDS in Stanley Park 2019. Twice through as the second part of a medley, ending with chase and dance off.', 1, 1, 'Y', 'rBfKLxHC-Sk', 141, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8315, '2022-01-21 19:39:56.300916+00', '2022-01-22 21:34:30.992194+00', 3786, 4, 1645, '', 'B', 'SCD group Hong Kong 2007. Twice through as part of a longer demo. Excellent dancing though not to the suggested music.', 1, 1, 'Y', 'VxaLGDHpgko', 4, 75, NULL);
INSERT INTO 'dancevideo' VALUES (8316, '2022-01-21 19:40:05.382419+00', '2022-01-22 21:34:45.853193+00', 5330, 14, 1645, '', 'A', 'SCD group Hong Kong 2007. Twice through as the last part of a longer demo.', 1, 1, 'Y', 'VxaLGDHpgko', 75, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8322, '2022-01-22 14:20:56.827703+00', '2022-01-22 21:36:17.598935+00', 10920, 10, 2269, '', 'B', 'Telheiras Scottish Country Dance Group, Casa De Goa, Lisbon, 2013.', 1, 1, 'Y', 'XbmUy7maQko', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8323, '2022-01-22 20:51:33.300721+00', '2022-01-23 14:33:44.752664+00', 6406, 2, 1645, '', 'A', 'Edinburgh Scottish Dancers at the 2019 Newcastle Festival. A slighter closer view than video 1.', 1, 1, 'Y', 'WSOJGcK7zYc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8319, '2022-01-22 10:32:27.521549+00', '2022-01-22 21:45:53.060121+00', 10433, 16, 2269, '', 'B', '54th Tartan Ball, Toronto, 2017.  The band does not play the recognised tune which is a shame as the music makes the dance.', 1, 1, 'Y', '9_mLTY8zHQU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (436, '2012-12-17 14:17:56.257319+00', '2022-01-22 21:53:47.797588+00', 14679, 1, 1296, '', 'A', 'The dance was entered into the database based only on this demo; no other source was known to the editor. 



The version done here starts with circle to the left & back. Other versions have advance and retire twice instead.', 1, 1, 'Y', 'olG9idagzmo', 65, 129, NULL);
INSERT INTO 'dancevideo' VALUES (8324, '2022-01-23 12:26:35.186195+00', '2022-01-23 14:10:14.746683+00', 594, 3, 2586, '', 'A', 'Turnham Green Dancers 2022.', 1, 1, 'Y', '9xwK8ZUp7UQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8987, '2022-08-13 15:51:56.001234+00', '2022-08-13 16:02:28.600741+00', 3418, 5, 202, '', 'C', '', 1, 1, 'Y', 'ZC6zRabfdgs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4828, '2019-06-06 16:10:47.104831+00', '2022-01-24 10:57:57.776667+00', 10638, 1, 4804, '', 'B', 'Kirov, Russia, 2019. Four times through.', 1, 1, 'Y', 'p9cUiuTjdio', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8326, '2022-01-23 18:14:19.611994+00', '2022-01-24 17:57:08.503208+00', 13766, 2, 1645, '', 'A', 'Edinburgh University New Scotland Country Dancers at the 2015 Newcastle Festival. Four times through. Excellent with one minor hiccup: at the end of the 3rd time the top couple make a false start.', 1, 1, 'Y', 'vZQC_GJr-jg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8325, '2022-01-23 14:20:24.595948+00', '2022-01-24 22:39:16.743178+00', 594, 4, 1645, '', 'B', 'SCD group Hong Kong, 2015. Very well danced, though not to the suggested music.', 1, 1, 'Y', 'xkSJKm4KYPI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8330, '2022-01-24 14:33:32.352463+00', '2022-01-24 15:59:47.243128+00', 5407, 8, 2269, '', 'B', 'Budapest Scottish Dance Club, 2014.', 1, 1, 'Y', '9pxSrd8QtOw', 0, 139, NULL);
INSERT INTO 'dancevideo' VALUES (8329, '2022-01-24 13:54:30.220316+00', '2022-01-24 16:03:51.123802+00', 4239, 8, 2269, '', 'B', ' Ochil Scottish Country Dancers, St Ninian''s Church Hall, Stirling, Scotland, 2017.', 1, 1, 'Y', '3HcFAMFK7B8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8327, '2022-01-24 10:57:00.724322+00', '2022-01-24 17:55:44.83049+00', 20639, 1, 1645, '', 'C', 'Buenos Aires Scottish Country Dancers 2020. Once through in a very socially distanced set.', 1, 1, 'Y', 'uAxp-Nv3ViU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8332, '2022-01-24 17:31:14.652986+00', '2022-01-24 17:59:49.581814+00', 3172, 8, 2269, '', 'A', 'Members And Friends Of RSCDS Stirling Branch, Guildhall, Stirling, Scotland, 2020.', 1, 1, 'Y', 'iF-QZqMxb20', 3685, 3763, NULL);
INSERT INTO 'dancevideo' VALUES (8331, '2022-01-24 17:20:26.737899+00', '2022-01-24 18:10:00.32144+00', 12669, 3, 2269, '', 'C', 'Fanwood, New Jersey, 2015.  For one couple the Half Figs of Eight go to the right instead of the left, which is incorrect.', 1, 1, 'V', '125104708', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2287, '2015-12-08 16:39:28.692181+00', '2022-01-24 18:16:09.293881+00', 8165, 2, 1041, '', 'B', '', 1, 1, 'Y', 'bb0oY6syarI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8338, '2022-01-25 12:20:22.92653+00', '2022-01-26 23:05:19.605412+00', 1792, 11, 2269, '', 'B', 'Ochil Scottish Country Dancers, St Ninian''s Church Hall, Stirling, Scotland, 2019.   Spoken and on-screen dancing instructions.', 1, 1, 'Y', 'dLHAJjzarSY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3564, '2018-06-06 14:24:39.422584+00', '2022-01-25 00:44:39.992414+00', 301, 5, 2824, '', 'A', '4 times through.

Newcastle Festival 2018, Russian team', 1, 1, 'Y', 'VJJeWlQgJhc', 33, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1891, '2014-11-19 23:16:22.267009+00', '2022-01-25 00:46:01.061368+00', 10008, 3, 1240, '', 'D', '', 1, 1, 'Y', 'IAF0ilmzDD0', 67, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8340, '2022-01-26 12:32:04.734852+00', '2022-01-26 23:07:28.090274+00', 11284, 7, 2269, '', 'B', 'Ochil Scottish Country Dancers, St Ninian''s Church Hall, Stirling, Scotland, 2016.  Spoken and on-screen dancing instructions.', 1, 1, 'Y', 'JJ1WwhlgZx0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8335, '2022-01-25 10:08:46.940531+00', '2022-01-25 11:05:04.840528+00', 5209, 13, 2269, '', 'B', 'RSCDS Stirling, Macrobert Arts Centre, Stirling, Scotland, 2001.



Once through, with a bar or two lost at the very end.  Camera switches between a close up of the dancing couple and a wider view of the whole set.  This does not interrupt the flow of the dance.', 1, 1, 'Y', 'LdtlT3WPRAc', 3370, 3407, NULL);
INSERT INTO 'dancevideo' VALUES (8337, '2022-01-25 12:05:30.084354+00', '2022-01-26 23:09:19.122925+00', 5713, 9, 2269, '', 'A', 'Northesk Junior Scottish Country Dancers, Macrobert Arts Centre, Stirling, Scotland, 2001.', 1, 1, 'Y', 'LdtlT3WPRAc', 2934, 3036, NULL);
INSERT INTO 'dancevideo' VALUES (8333, '2022-01-24 18:03:25.359484+00', '2022-01-25 11:27:18.348579+00', 8165, 4, 2269, '', 'A', 'Dance Scottish for Pudsey A Medley of Dances.  RSCDS Youth Team, 2010.



The later half of the video follows the dancing couple using a closeup shot and consequently, the other dancers tend to go out of view.  However, the oblique camera position affords a good view of the dancers and the dance can be followed reasonably well.', 1, 1, 'Y', 'ap7yn5OUPkU', 125, 210, NULL);
INSERT INTO 'dancevideo' VALUES (8336, '2022-01-25 11:44:07.496783+00', '2022-01-25 16:31:05.423692+00', 5713, 8, 2269, '', 'B', 'Ochil Scottish Country Dancers, St Ninian''s Church Hall, Stirling, Scotland, 2019.', 1, 1, 'Y', '6l7-H7YKCnk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8339, '2022-01-26 09:10:53.924046+00', '2022-01-26 09:11:57.082023+00', 20641, 1, 202, '', 'C', '', 1, 1, 'Y', 'FhX--7KPvQY', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8341, '2022-01-26 20:52:51.947958+00', '2022-01-26 23:03:09.639112+00', 3310, 4, 562, '', 'A', 'There are on screen and audio instructions for the first 2 of 4 times through. The dancers are from the Stirling Branch of RSCDS and they were dancing at Drummond Castle  on 1 August 2004.', 1, 1, 'Y', 'Z_S5Rq-brNo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7782, '2021-01-17 01:52:38.568103+00', '2022-01-27 21:46:13.352897+00', 1398, 1, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2010. Twice through as part of a longer demonstration. The 1st time has some minor glitches, the 2nd time is better. The two adjoining sets take hands during the double figures of eight.', 1, 1, 'Y', 'A3zVbjl5Ljo', 4237, 4362, NULL);
INSERT INTO 'dancevideo' VALUES (8342, '2022-01-26 23:21:49.861687+00', '2022-01-27 19:46:21.711112+00', 3154, 1, 1645, '', 'B', 'South West Scotland Dancers 2021. This clip shows the dance twice through as part of a longer instructional video by Moira Stacey.



However you will need to watch this via the youtube site. The performance of The Isle starts at 5:49.', 1, 1, 'Y', 'imyCy67x4dQ', 349, 422, NULL);
INSERT INTO 'dancevideo' VALUES (8343, '2022-01-26 23:31:57.222822+00', '2022-01-27 19:46:55.169642+00', 11790, 1, 1645, '', 'C', 'Méaudre Reel club, 2022.', 1, 1, 'Y', 'sIcVBbKyvVs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8344, '2022-01-27 18:36:01.444462+00', '2022-01-27 19:48:43.787222+00', 20642, 1, 963, '', 'B', 'The video goes 8 times through but the last couple dance it well with only a few minor errors by the supporting corners. ', 1, 1, 'Y', 'H4vDqxX0cs8', 270, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7755, '2021-01-14 20:50:07.029363+00', '2022-01-27 20:09:48.72784+00', 1075, 1, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2010. Twice through as part of a longer demonstration. The dance would normally be done in longwise sets but is here done as a round the room dance. The end of the 2nd repeat is slightly adapted to lead into the next dance in the demo.', 1, 1, 'Y', 'A3zVbjl5Ljo', 197, 318, NULL);
INSERT INTO 'dancevideo' VALUES (7781, '2021-01-17 01:39:09.498786+00', '2022-01-27 21:43:01.897966+00', 12219, 3, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2010. Three times through, starting with a dance on, as the first part of a longer demonstration. The last few bars of the 3rd time are adapted to lead into the next dance.', 1, 1, 'Y', 'A3zVbjl5Ljo', 4125, 4238, NULL);
INSERT INTO 'dancevideo' VALUES (8348, '2022-01-30 02:40:03.213762+00', '2022-01-30 02:40:03.213762+00', 11543, 4, 1296, '', 'X', '''51st Travellers, The'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'OGLgZi9jJZ4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8349, '2022-01-30 02:40:03.23956+00', '2022-01-30 02:40:03.23956+00', 9138, 2, 1296, '', 'X', '''Auchinellan Jig'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'n-4fJRnYatk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8350, '2022-01-30 02:40:03.260549+00', '2022-01-30 02:40:03.260549+00', 13078, 2, 1296, '', 'X', '''Glengarry Homestead, The'' is a 32 bar strathspey for 4 couples in a 4 couple set.', 1, 1, 'Y', 'LVZqLtiyHeM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8351, '2022-01-30 02:40:03.291164+00', '2022-01-30 02:40:03.291164+00', 3690, 3, 1296, '', 'X', '''Land of the Heather Hills'' is a 32 bar strathspey for 4 couples in a 4 couple set.', 1, 1, 'Y', 'fIbayDFtYKc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8352, '2022-01-30 02:40:03.314184+00', '2022-01-30 02:40:03.314184+00', 6161, 3, 1296, '', 'X', '''Snake Pass, The'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', '2sakq1YJcLQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8345, '2022-01-28 14:55:12.047038+00', '2022-01-30 20:40:22.227841+00', 11284, 8, 2269, '', 'A', 'RSCDS Gleneagles Scottish Country Dance Club, West Vancouver, British Columbia, Canada, 2020.', 1, 1, 'Y', 'WQkAnOvwxeQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8353, '2022-01-30 20:47:18.339977+00', '2022-01-30 20:47:57.311265+00', 12792, 6, 1645, '', 'A', 'RSCDS Aberdeen Branch, Aberdeen Festival, 2018.', 1, 1, 'Y', '6LuK2hMb438', 5, 157, NULL);
INSERT INTO 'dancevideo' VALUES (8346, '2022-01-28 15:23:12.56927+00', '2022-01-30 20:48:03.60435+00', 11284, 9, 2269, '', 'A', 'RSCDS Aberdeen Branch, Aberdeen Festival, 2018.', 1, 1, 'Y', '6LuK2hMb438', 158, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8354, '2022-02-01 12:32:22.367926+00', '2022-02-01 13:29:17.996289+00', 13077, 4, 2269, '', 'D', 'Extreme Location Dancers, at Torridon, 2016.  A mishap occurs the first time through when in bars 33-40, the 1st lady should dance right shoulder around 2nd corners & 1/2 figure-of-eight up.', 1, 1, 'Y', 'rHfoagPBYDU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8355, '2022-02-01 13:34:59.521735+00', '2022-02-01 14:07:56.998775+00', 3129, 8, 2269, '', 'B', 'Ochil Scottish Country Dancers, Princes St Gardens, Edinburgh, 2018.  Dance down (bars 1-4) is customary nearer hands, also for the half-diagonal reels it is usual to pass left shoulder in the middle. ', 1, 1, 'Y', 'GQC8WQawW_g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8357, '2022-02-01 20:16:31.172355+00', '2022-02-01 21:02:10.957627+00', 13588, 10, 2269, '', 'A', 'Alba Clyde Team, Newcastle Festival, 2015.', 1, 1, 'Y', 'CjpLuiXkv0s', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8356, '2022-02-01 20:10:19.861708+00', '2022-02-01 21:45:57.858+00', 761, 2, 1645, '', 'B', 'Budapest Burns Supper 2022. Twice through as part of a long demo. The last few bars of the 2nd time are adapted to lead into the next dance.', 1, 1, 'Y', 'iVcFTBN_lPc', 97, 165, NULL);
INSERT INTO 'dancevideo' VALUES (8358, '2022-02-01 20:32:01.591607+00', '2022-02-01 20:38:45.292165+00', 389, 1, 1645, '', 'B', 'Budapest Burns Supper 2022. Twice through in two back to back 2 couple sets as part of a longer demo. There is  some interaction between the two sets for the lead down & up of bars 17-24.', 1, 1, 'Y', 'iVcFTBN_lPc', 165, 234, NULL);
INSERT INTO 'dancevideo' VALUES (8359, '2022-02-01 20:33:59.032694+00', '2022-02-01 21:03:28.977169+00', 1176, 4, 2269, '', 'C', 'Royal Scottish Country Dancers, Ottawa, 2014.  On the first time through the 1st lady almost misses the RH across, by initially going the wrong way', 1, 1, 'Y', 'IIuiAbgTdxs', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8366, '2022-02-01 21:29:13.376347+00', '2022-02-02 23:55:12.193341+00', 153, 7, 1645, '', 'B', 'Ottawa RSCDS 2013. Danced here first time with all the women in the centre, then second time with all the men.', 1, 1, 'Y', 'VnprqUWb3w4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8362, '2022-02-01 20:52:14.796205+00', '2022-02-01 21:47:07.775321+00', 18390, 2, 1645, '', 'A', 'Budapest Burns Supper 2022. Twice through in two 2 couple sets as the last part of a longer demo.', 1, 1, 'Y', 'iVcFTBN_lPc', 432, 505, NULL);
INSERT INTO 'dancevideo' VALUES (8360, '2022-02-01 20:37:34.582755+00', '2022-02-01 21:48:04.814633+00', 9548, 1, 1645, '', 'B', 'Budapest Burns Supper 2022. Twice through in two back to back 2 couple sets as the last part of a longer demo.', 1, 1, 'Y', 'iVcFTBN_lPc', 234, 308, NULL);
INSERT INTO 'dancevideo' VALUES (8363, '2022-02-01 21:00:06.977087+00', '2022-02-01 21:48:32.015314+00', 6449, 3, 1645, '', 'B', 'Budapest Scottish Dance Club 2022. Here danced in a longwise set rather than round the room. Also the two hand turns of bars 9-12 are here done with the right hand.', 1, 1, 'Y', 'EsfKieeCj2A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8365, '2022-02-01 21:14:08.805067+00', '2022-02-02 23:56:02.085251+00', 2506, 6, 1645, '', 'C', 'Ottawa RSCDS 2013. Twice through as the last part of a longer demo.', 1, 1, 'Y', '4oWSSWc9w6E', 126, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8370, '2022-02-02 23:09:15.849786+00', '2022-02-03 17:55:58.475597+00', 6800, 3, 1645, '', 'B', 'Auld Comhlan, Krakow, Poland, 2022. With spoken instructions (in Polish) and highlighted display of the diagram. This clip starts with the dancing. The whole video has a longer introduction.', 1, 1, 'Y', 'oUZ8uRyOGz8', 45, 136, NULL);
INSERT INTO 'dancevideo' VALUES (8361, '2022-02-01 20:48:38.310718+00', '2022-02-01 21:50:29.312958+00', 9862, 8, 1645, '', 'A', 'Budapest Burns Supper 2022. Twice through in two 2 couple sets as the first part of a longer demo.', 1, 1, 'Y', 'iVcFTBN_lPc', 308, 433, NULL);
INSERT INTO 'dancevideo' VALUES (8368, '2022-02-02 10:37:48.745096+00', '2022-02-02 10:38:37.913315+00', 2682, 1, 1645, '', 'B', 'Auld Comhlan, Krakow, Poland 2022. With spoken commentary (in Polish).', 1, 1, 'Y', 'anCXgi4XEvE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8367, '2022-02-01 21:41:08.317089+00', '2022-02-02 17:36:51.564534+00', 7972, 1, 1645, '', 'C', 'Saint-Petersburg Lermontov Ball  2014. View from directly above but with dancers often out of the camera frame.', 1, 1, 'Y', 'HcbqSnz6Ljs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8364, '2022-02-01 21:13:07.812516+00', '2022-02-02 23:57:18.80068+00', 9862, 9, 1645, '', 'B', 'Ottawa RSCDS 2013. Twice through as the first part of a longer demo.', 1, 1, 'Y', '4oWSSWc9w6E', 0, 126, NULL);
INSERT INTO 'dancevideo' VALUES (8380, '2022-02-03 16:39:10.086955+00', '2022-02-04 00:11:29.360891+00', 8577, 3, 2269, '', 'B', 'RSCDS San Francisco, Mountain View Class, Cupid''s Bow Party, 2017.  Danced in two-couple sets once through, video starts 1-bar late.', 1, 1, 'Y', 'neO7FKo1vYI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8373, '2022-02-02 23:28:24.595945+00', '2022-02-03 17:50:01.622594+00', 3152, 3, 1645, '', 'B', 'Auld Comhlan, Krakow, Poland, 2022. Twice through, once each couple, with spoken instructions (in Polish) and highlighted display of the diagram. This clip starts with the dancing. The whole video has a longer introduction.', 1, 1, 'Y', 'qQHio3JbLCQ', 48, 122, NULL);
INSERT INTO 'dancevideo' VALUES (8369, '2022-02-02 17:37:38.922046+00', '2022-02-03 17:52:44.726528+00', 3774, 1, 1645, '', 'B', 'Auld Comhlan, Krakow, Poland 2022. With spoken commentary (in Polish). The arch on bars 9-12 is here made just with one hand rather than two hands.', 1, 1, 'Y', 'iDL8RZny3t8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8371, '2022-02-02 23:14:08.046843+00', '2022-02-03 17:53:37.562584+00', 4728, 4, 1645, '', 'B', 'Auld Comhlan, Krakow, Poland, 2022. Twice through with spoken instructions (in Polish) and highlighted display of the diagram. This clip starts with the dancing. The whole video has a longer introduction.', 1, 1, 'Y', 'GI2q5V1DeXs', 45, 124, NULL);
INSERT INTO 'dancevideo' VALUES (8372, '2022-02-02 23:21:09.965557+00', '2022-02-03 17:54:49.588868+00', 5007, 3, 1645, '', 'B', 'Auld Comhlan, Krakow, Poland, 2022. With spoken instructions (in Polish) and highlighted display of the diagram. This clip starts with the dancing. The whole video has a longer introduction. The 2nd couples are not stepping in before the poussettes.', 1, 1, 'Y', 'UIh6hRKJr-o', 48, 136, NULL);
INSERT INTO 'dancevideo' VALUES (8375, '2022-02-02 23:37:10.050612+00', '2022-02-03 17:56:54.48898+00', 7068, 3, 1645, '', 'B', 'Auld Comhlan, Krakow, Poland, 2022. Twice through with spoken instructions (in Polish) and highlighted display of the diagram. This clip starts with the dancing. The whole video has a longer introduction.', 1, 1, 'Y', 'VlwVQ21_Gas', 44, 121, NULL);
INSERT INTO 'dancevideo' VALUES (8374, '2022-02-02 23:33:43.086391+00', '2022-02-03 17:58:01.309574+00', 7109, 6, 1645, '', 'B', 'Auld Comhlan, Krakow, Poland, 2022. Twice through with spoken instructions (in Polish) and highlighted display of the diagram. This clip starts with the dancing. The whole video has a longer introduction.', 1, 1, 'Y', '08yhSPyodbk', 48, 123, NULL);
INSERT INTO 'dancevideo' VALUES (8381, '2022-02-03 17:23:20.979042+00', '2022-02-03 17:59:51.796233+00', 14741, 4, 2269, '', 'B', 'The Swan And The Tay - 2014.  Corners Pass and Turn (bars 17-20), some dancers turn both hands whereas the instructions have turn right.  Good view from above.', 1, 1, 'Y', '59LUnOe9GKQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8382, '2022-02-03 23:56:48.298046+00', '2022-02-04 00:07:08.449715+00', 20659, 1, 1645, '', 'C', 'Te Awamutu Club, New Zealand, 1999. Once through.', 1, 1, 'Y', '6cYox6TvmRA', 19, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8379, '2022-02-03 14:40:31.957711+00', '2022-02-04 00:07:56.989893+00', 7111, 7, 2269, '', 'D', 'Dufftown Dance Club, 2017.  ''Fast and Furious'', with flourishes.  At the end the band barely pauses and then reprises the dance.', 1, 1, 'Y', 'RSyskfoM1qE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8378, '2022-02-03 13:46:12.981503+00', '2022-02-04 00:08:57.941096+00', 7111, 6, 2269, '', 'C', 'Houston RSCDS, Twelfth Night Masked Ball, Galveston, Texas, Ashton Villa, 2013.  After the Reel of Four across (bars 9-16), the dancers should pass right shoulder; the first couple actually pass left shoulder.', 1, 1, 'Y', '5J-m8TxaLm0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8376, '2022-02-02 23:54:38.723004+00', '2022-02-04 00:16:17.222579+00', 8732, 3, 1645, '', 'C', 'Auld Comhlan, Krakow, Poland 2021. Costumed demo which is good to watch, but constant cutting between camera views makes it hard to follow the choreography. The last RH turn is changed to end with half RH across to swap couples between two adjoining sets.', 1, 1, 'Y', 'gQp3XZu2TGg', 43, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8386, '2022-02-04 10:42:10.481466+00', '2022-02-04 19:42:08.364096+00', 6287, 8, 2269, '', 'A', 'Spring School Of Scottish Dance Festival Demonstration Team, Quick Scotch, 2016.', 1, 1, 'Y', 'Bz1nelAuoPo', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8389, '2022-02-04 14:17:25.221887+00', '2022-02-04 19:43:34.749252+00', 10787, 13, 2269, '', 'A', 'University Of St Andrews Celtic Society Mixed Team, Newcastle Festival, 2014.', 1, 1, 'Y', 'OXVL-rex5oU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8377, '2022-02-03 13:05:11.58698+00', '2022-07-12 16:14:22.447184+00', 7111, 5, 2269, '', 'A', 'RSCDS Stirling Branch, Guildhall, Stirling, Scotland, 1999.', 1, 1, 'Y', 'iF-QZqMxb20', 4719, 4814, NULL);
INSERT INTO 'dancevideo' VALUES (8387, '2022-02-04 10:58:18.831077+00', '2022-02-04 19:45:58.597132+00', 6048, 13, 2269, '', 'B', 'RSCDS Country Dancers, RSCDS Archives, 2019.  Scotland''s Social Dances Part 2, Instructional DVD.  Second time through the pace slows to walking pace.', 1, 1, 'Y', 'o2UfaYpMhao', 705, 785, NULL);
INSERT INTO 'dancevideo' VALUES (8385, '2022-02-04 10:24:57.564061+00', '2022-02-04 19:47:10.034133+00', 6287, 7, 2269, '', 'A', 'RSCDS Summer School, 2020.', 1, 1, 'Y', 'ZxOJb8f__fU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8384, '2022-02-04 09:55:04.821874+00', '2022-02-04 19:47:55.610597+00', 6287, 6, 2269, '', 'B', 'RSCDS Stirling Branch, Princes Street Gardens, 2009.  Spoken and on-screen dancing instructions.', 1, 1, 'Y', 'yln_FshvlOU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8388, '2022-02-04 11:38:28.578193+00', '2022-02-05 10:58:58.515582+00', 5525, 25, 2269, '', 'A', 'RSCDS Stirling Branch, Guildhall, Stirling, Scotland (from "Reel Scottish Dancing" in the RSCDS Archive, 1999).', 1, 1, 'Y', 'iF-QZqMxb20', 3603, 3683, NULL);
INSERT INTO 'dancevideo' VALUES (8383, '2022-02-04 09:40:00.200052+00', '2022-02-04 19:40:42.092115+00', 14741, 5, 2269, '', 'B', 'The Swan And The Tay - Russia, 2018.  This clip shows the 2nd & 3rd times (the 1st time has some distracting persons in front of the camera).  The camera position gives a clear view - only the first lady''s position is out of shot.', 1, 1, 'Y', 'LQlzWYgpfOA', 66, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8391, '2022-02-04 16:29:51.729919+00', '2022-02-04 19:49:34.596098+00', 20443, 1, 2630, '', 'B', 'The 2am Jig danced by dancers from the Ribble Valley RSCDS', 1, 1, 'Y', 'PyIKofQEjB0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8394, '2022-02-04 16:39:06.283447+00', '2022-02-04 19:50:54.148497+00', 20436, 1, 2630, '', 'B', 'The Barmaid''s Jig danced by dancers from the Ribble Valley.  Though written as a 5 couple dance, this dance is best learnt in a 3 couple set.', 1, 1, 'Y', 'XCvc1LXGzFc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8393, '2022-02-04 16:36:13.234299+00', '2022-02-04 19:56:24.200007+00', 20437, 1, 2630, '', 'B', 'The ''Inn'' Strathspey danced by dancers from the Ribble Valley RSCDS', 1, 1, 'Y', 'A5td4SIV07w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8390, '2022-02-04 16:27:49.303703+00', '2022-02-04 19:57:18.366361+00', 20435, 1, 2630, '', 'B', '''The Young Accordion Man'' danced by dancers from the Ribble Valley RSCDS', 1, 1, 'Y', 'x7o7phZBrqs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8403, '2022-02-04 23:02:19.227874+00', '2022-02-05 15:31:26.990517+00', 6748, 6, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999

', 1, 1, 'Y', 'iF-QZqMxb20', 4130, 4195, NULL);
INSERT INTO 'dancevideo' VALUES (8392, '2022-02-04 16:31:35.171236+00', '2022-02-04 19:58:10.99002+00', 20439, 2, 2630, '', 'C', '''Ewan''s Midnight Medley'' danced by dancers from the Ribble Valley RSCDS', 1, 1, 'Y', 'iy3OoJwBGow', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8405, '2022-02-05 10:46:58.268046+00', '2022-02-05 15:34:54.373823+00', 769, 8, 2269, '', 'C', 'RSCDS Helensburgh Weekend Dance, 2017.  Camera positioned at the foot of the dance.', 1, 1, 'Y', '9LeJ4oAYKHQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8395, '2022-02-04 20:09:00.574303+00', '2022-02-04 23:02:23.432982+00', 3422, 6, 1645, '', 'B', 'Russian ball, 2017. With swirling ball gowns (and one quickly corrected mishap the 2nd time through).', 1, 1, 'Y', 'xjt61RwKdZI', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8396, '2022-02-04 22:48:57.622343+00', '2022-02-05 11:18:24.352564+00', 3759, 10, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999', 1, 1, 'Y', 'iF-QZqMxb20', 3301, 3433, NULL);
INSERT INTO 'dancevideo' VALUES (8404, '2022-02-04 23:04:07.557688+00', '2022-02-05 15:15:50.735479+00', 1792, 12, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999

', 1, 1, 'Y', 'iF-QZqMxb20', 4199, 4278, NULL);
INSERT INTO 'dancevideo' VALUES (8406, '2022-02-05 17:00:59.296783+00', '2022-02-05 17:04:10.749437+00', 2935, 3, 1645, '', 'A', 'Berkhamsted Strathspey & Reel Club 2017. Twice through as the last part of a longer demo.', 1, 1, 'Y', '3IHD9juxZSw', 268, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8402, '2022-02-04 23:00:40.10755+00', '2022-02-05 15:18:49.983779+00', 4782, 6, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999

', 1, 1, 'Y', 'iF-QZqMxb20', 4044, 4128, NULL);
INSERT INTO 'dancevideo' VALUES (8400, '2022-02-04 22:57:53.603993+00', '2022-02-05 15:21:38.51658+00', 4890, 6, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999

', 1, 1, 'Y', 'iF-QZqMxb20', 3768, 3899, NULL);
INSERT INTO 'dancevideo' VALUES (8328, '2022-01-24 11:30:53.461196+00', '2022-02-05 15:23:14.213768+00', 4239, 7, 2269, '', 'A', 'Members And Friends Of RSCDS Stirling Branch, Guildhall, Stirling, Scotland (from "Reel Scottish Dancing" in the RSCDS Archive, 1999).  Since the revised edition of Book 18 dance down between the 3s (bars 25-26) should be with nearer hands. This video shows the earlier version with right hands joined.  ', 1, 1, 'Y', 'iF-QZqMxb20', 3520, 3601, NULL);
INSERT INTO 'dancevideo' VALUES (853, '2013-02-14 15:38:11.395843+00', '2022-02-06 10:34:10.953207+00', 11770, 1, 274, '', 'A', 'International team (Ladies) at the Newcastle Festival 2013', 1, 1, 'Y', 'k1CBo9UuWtg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8401, '2022-02-04 22:59:21.140563+00', '2022-02-05 15:26:14.122024+00', 5330, 15, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999

', 1, 1, 'Y', 'iF-QZqMxb20', 3902, 4043, NULL);
INSERT INTO 'dancevideo' VALUES (8397, '2022-02-04 22:51:11.262491+00', '2022-02-05 15:28:40.553711+00', 5794, 10, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999', 1, 1, 'Y', 'iF-QZqMxb20', 3434, 3518, NULL);
INSERT INTO 'dancevideo' VALUES (981, '2013-08-06 14:26:22.02213+00', '2022-02-06 10:36:24.593586+00', 14685, 1, 513, '', 'A', 'Week 3 dem at the RSCDS Summer School 2013.', 1, 1, 'Y', '8sMxXNxJM6E', 20, 292, NULL);
INSERT INTO 'dancevideo' VALUES (5022, '2019-09-02 23:52:49.598348+00', '2022-02-06 10:47:31.493172+00', 3108, 6, 1645, '', 'A', 'Edinburgh University New Scotland Country Dancers 2018', 1, 1, 'Y', 'WXxwNQDf2FY', 0, 156, NULL);
INSERT INTO 'dancevideo' VALUES (5021, '2019-09-02 23:46:04.577712+00', '2022-02-06 10:50:47.218046+00', 40, 5, 1645, '', 'A', 'Edinburgh University New Scotland Country Dancers 2018', 1, 1, 'Y', 'WXxwNQDf2FY', 157, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8416, '2022-02-07 22:54:53.749477+00', '2022-02-07 22:54:53.749477+00', 20078, 1, 31370, 'dd/dance/video/upload/ChristmasAtBleecker.mp4', 'D', 'Members of the Mystic Scottish Country Dancers, dancing at Nauset Beach on Cape Cod, Massachusetts,  December 2020

Danced once through', 0, 0, 'I', '', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8415, '2022-02-07 21:23:42.525497+00', '2022-02-08 00:07:24.917234+00', 1792, 14, 2269, '', 'B', 'RSCDS Country Dancers, RSCDS Archives, 2019.  Instructional video danced first at normal speed; second time through at walking pace.', 1, 1, 'Y', 'o2UfaYpMhao', 946, 1026, NULL);
INSERT INTO 'dancevideo' VALUES (8414, '2022-02-07 21:13:13.33937+00', '2022-02-08 00:09:59.580601+00', 1792, 13, 2269, '', 'A', 'RSCDS Edinburgh Branch Demonstration Team, Dancing Forth, 2010.  Dancers make use of the elbow grip in the Corner-Partner.



Excellent dancing - but this is a modified version with 3-couples dancing: instead of reeling on the opposite side, reels across are employed.  On the third time through, the ending is modified to lead into the next dance in the sequence.', 1, 1, 'Y', 'A3zVbjl5Ljo', 6668, 6774, NULL);
INSERT INTO 'dancevideo' VALUES (8413, '2022-02-07 20:52:44.659626+00', '2022-02-08 00:15:39.521992+00', 6712, 13, 2269, '', 'A', 'Members And Friends Of RSCDS Stirling Branch, Guildhall, Stirling, Scotland.  RSCDS Archive 1999.', 1, 1, 'Y', 'iF-QZqMxb20', 5039, 5122, NULL);
INSERT INTO 'dancevideo' VALUES (8408, '2022-02-07 11:18:37.513158+00', '2022-02-08 00:16:17.38513+00', 17659, 1, 1645, '', 'B', 'Inverness, 2019.', 1, 1, 'Y', 'eVfzl0Gzfmo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8412, '2022-02-07 11:37:01.005085+00', '2022-02-08 00:17:32.547835+00', 17898, 4, 1645, '', 'B', 'San Diego, 2018. Danced in a 3 couple set.', 1, 1, 'Y', 'GDsTXbWwp_Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8410, '2022-02-07 11:28:37.678768+00', '2022-02-08 00:18:06.886632+00', 13448, 1, 1645, '', 'C', 'Inverness class, 2019. Three times through.', 1, 1, 'Y', 'gNZ_xYGLnMk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8409, '2022-02-07 11:23:31.866833+00', '2022-02-08 00:20:58.904856+00', 19551, 1, 1645, '', 'B', 'Inverness, 2019. The video shows the dance three times through twice.', 1, 1, 'Y', 'ugK78Y8Xsek', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8411, '2022-02-07 11:32:09.045518+00', '2022-02-08 00:21:34.100765+00', 7035, 1, 1645, '', 'D', 'Inverness, 2019.', 1, 1, 'Y', 'sdzsKpeLlDw', 28, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8420, '2022-02-08 13:52:03.812548+00', '2022-02-08 18:22:08.053825+00', 584, 6, 2269, '', 'C', '55th Tartan Ball, Toronto, 2018.', 1, 1, 'Y', 'geJ5-lxPJwQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8417, '2022-02-08 11:42:10.553175+00', '2022-02-08 18:25:44.212275+00', 13621, 4, 2269, '', 'B', 'RSCDS NZ Branch, Christchurch Summer School, 2016. View from the bottom of the set.', 1, 1, 'Y', '1XVsfESmwoE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8419, '2022-02-08 12:44:23.102275+00', '2022-02-08 18:27:25.764861+00', 4484, 11, 2269, '', 'A', 'Charlotte (NC) Scottish Country Dance Society (CSCDS), 2017.', 1, 1, 'Y', 'w7G0MFyzVNQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8421, '2022-02-08 16:49:43.661222+00', '2022-02-08 18:30:04.948637+00', 1087, 12, 2269, '', 'B', 'Scottish Party At The Festival "The Breath Of Siberia", Tomsk, Russia, 2017.



Just a minor loss of concentration near the end of the last repeat, which was quickly remedied.  Rather charming – the ladies had handkerchiefs to wave at the gentlemen in the top set.', 1, 1, 'Y', 'Anf7Ibo3Ld4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8424, '2022-02-09 11:01:01.293333+00', '2022-02-10 21:03:13.195504+00', 1223, 11, 2269, '', 'B', 'RSCDS Stirling, 2019.  Spoken and on-screen dancing instructions.  First time through there''s a slow motion segment for the targe.', 1, 1, 'Y', 'egKI4oKMucU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8418, '2022-02-08 11:53:28.727687+00', '2022-08-01 21:37:56.851377+00', 413, 10, 2269, '', 'Z', 'Budapest Skót Táncklub (Scottish Dance Club), St. Andrew''s Day Ceilidh, 2014.  Dancing is excellent –Music is the correct tune but is somewhat indistinct.



Was dem quality, but now gone?', 1, 1, 'Y', 'Mqx0WycGxKk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8427, '2022-02-09 13:57:21.852439+00', '2022-02-09 23:02:24.987237+00', 17898, 5, 2269, '', 'C', 'Performance Of New Year Jig - Hogmanay, Knox Church hall, Lower Hutt, Wellington, New Zealand, 2020.  Video shows the dance the final two times through.', 1, 1, 'Y', 'Fpk9Ar7hLUk', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (3369, '2017-12-20 09:09:02.723225+00', '2022-02-10 20:22:53.167597+00', 10650, 2, 2482, '', 'B', 'Tay Dancers, 2017. Clear demo, though the dancers here turn about immediately after passing through arches in bars 27-28 whereas the instructions suggest turning about while setting in bars 29-30 (as in <<https://my.strathspey.org/dd/dancevideo/8436/|video 5>>).', 1, 1, 'Y', 'VbcLLZI--yY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8430, '2022-02-09 16:29:10.743821+00', '2022-02-10 20:59:03.797392+00', 9110, 7, 2269, '', 'C', 'Russia, 2018.  There is excellent dancing with a lot of flight, but can only be rated as reasonable due to the number of times dancers take a wrong turn passing out between the 3s at various times throughout the dance.  Occasionally, spectators with cameras come into view, particularly at the start.', 1, 1, 'Y', 'F5XtB_Fp9e4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8431, '2022-02-09 17:38:18.518102+00', '2022-02-09 23:11:12.060584+00', 19224, 1, 1144, '', 'A', 'Bristol RSCDS, 2022.', 1, 1, 'Y', 'u8uGcDANYBo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8434, '2022-02-09 17:52:05.220946+00', '2022-02-09 23:11:34.371861+00', 10653, 3, 1144, '', 'B', 'Bristol RSCDS, 2022.', 1, 1, 'Y', 'uWB9sEAz454', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8436, '2022-02-09 17:56:52.674865+00', '2022-02-09 23:11:51.582517+00', 10650, 5, 1144, '', 'B', 'Bristol RSCDS, 2022.', 1, 1, 'Y', 'hdb47vYlH1U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8423, '2022-02-09 09:57:56.604603+00', '2022-02-10 21:02:13.160369+00', 1223, 10, 2269, '', 'B', 'Carpe Diem Team (From St. Petersburg, Novoisbirsk And Hadera), Russian Festival Of SCD, Kazan, 2019.  Danced as a 3-couple set, starting from 2nd position.  Danced to demonstration quality standard, but a minor slip of forgetting the targe in the 3rd and final repeat, quickly corrected, down grades the dance.', 1, 1, 'Y', 'oR3-o_AL_4Y', 207, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8433, '2022-02-09 17:50:13.3921+00', '2022-02-09 23:15:42.771994+00', 10367, 2, 1144, '', 'A', 'Bristol RSCDS, 2022.', 1, 1, 'Y', '7Gii7AK_9ZA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8432, '2022-02-09 17:42:12.506474+00', '2022-02-09 23:18:43.757487+00', 2822, 6, 1144, '', 'B', 'Bristol RSCDS, 2022.', 1, 1, 'Y', 'xPvefFAuO4g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8435, '2022-02-09 17:54:39.091408+00', '2022-02-09 23:40:39.695001+00', 10659, 1, 1144, '', 'B', 'Bristol RSCDS, 2022.', 1, 1, 'Y', 'lPy4hkJ-tR8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8422, '2022-02-08 21:55:45.290111+00', '2022-02-09 23:47:58.41031+00', 12309, 3, 1645, '', 'C', 'Russia, 2009. Lively rendition by young dancers with a few errors in the half reels.', 1, 1, 'Y', 'YE2Uzk7wrTg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8440, '2022-02-09 20:20:01.895944+00', '2022-02-09 23:52:43.916971+00', 20452, 2, 202, '', 'C', '', 1, 1, 'Y', '7t2r81gKSdU', 0, 10, NULL);
INSERT INTO 'dancevideo' VALUES (6949, '2020-02-20 19:46:19.193191+00', '2022-02-10 00:14:36.372114+00', 2229, 1, 1645, '', 'C', 'Twice through as part of a longer demo (with one small omission from the RH across in the 2nd repeat).



This demo differs significantly from the official dance:   

-  It is danced in a doubled two-couple set ; officially it is a 3C dance in a 4C set.   

-  In bars 1-16 the men dance first, then the W.  It should be W first, M next.   

-  Bars 29-32 are totally different: all turn P RH instead of 1c lead down and cast up.   



Because of these changes this video is not so useful for learning the expected choreography of the dance though does give a flavour of it.', 1, 1, 'Y', 'D-S9mNPsyKE', 53, 128, NULL);
INSERT INTO 'dancevideo' VALUES (8441, '2022-02-10 09:58:42.501686+00', '2022-02-10 09:59:18.939173+00', 20663, 1, 202, '', 'C', '', 1, 1, 'Y', 'L7gm5Rjhckw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8428, '2022-02-09 15:35:16.329054+00', '2022-02-10 21:08:24.810652+00', 3435, 7, 2269, '', 'C', 'RSCDS Montreal branch, 2016.  Once through in 4-couple set with all dancers dancing together.', 1, 1, 'Y', 'lpmdsPeb23k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8442, '2022-02-10 10:25:07.547945+00', '2022-02-10 21:09:32.060507+00', 8670, 1, 1645, '', 'C', 'Chorin Workshop, Germany, 2018. This clip shows the last two times through (slightly unexpected by the dancers). The first two times, at the start of the whole video, have minor errors.', 1, 1, 'Y', 'mpvPoBeFAGk', 208, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8429, '2022-02-09 15:48:04.559132+00', '2022-02-10 21:12:05.845975+00', 3463, 6, 2269, '', 'C', 'Broadlands Sunday Afternoon Class, 2016.  Danced only four times through, the nearest set being 3-couples, so couples drop to the bottom as needed.', 1, 1, 'Y', '2pUed6sTsc4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8426, '2022-02-09 13:13:00.264539+00', '2022-02-10 21:14:44.435361+00', 5802, 8, 2269, '', 'C', 'Upper Hutt Scottish Country Dance Club, New Zealand, 2015.', 1, 1, 'Y', '0XDDcF0_VFA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8425, '2022-02-09 11:54:14.076924+00', '2022-02-10 21:21:13.929228+00', 5802, 7, 2269, '', 'B', '55th Tartan Ball, Toronto, 2018.  ', 1, 1, 'Y', 'tgzMelCUlEM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8443, '2022-02-10 11:57:41.128253+00', '2022-02-13 19:31:44.424088+00', 13586, 5, 2269, '', 'B', 'Russia, 2018.  The dancing is generally to a demonstration standard, but on a couple of occasions dancers travel too far down the set in bars 1-8 and then there is a scramble to reach 2nd place for the half-turn and twirl.', 1, 1, 'Y', 'R-PB5w-kUMw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8448, '2022-02-10 15:33:37.078283+00', '2022-02-11 11:12:37.344095+00', 9157, 7, 2269, '', 'A', 'RSCDS Newcastle Festival, International Team Display, 2017.  Once through only.', 1, 1, 'Y', 'sfBGs68h8tQ', 22, 60, NULL);
INSERT INTO 'dancevideo' VALUES (8445, '2022-02-10 13:22:48.981443+00', '2022-02-11 11:16:31.529667+00', 5860, 11, 2269, '', 'B', 'RSCDS Stirling Branch, Princes St Gardens, Edinburgh, 2009.  Spoken and on-screen dancing instructions.', 1, 1, 'Y', 'dJ5MYM8tlrQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8452, '2022-02-10 17:30:05.995395+00', '2022-02-11 11:14:43.373112+00', 13544, 5, 2269, '', 'A', 'Ladies Alba SCD Kelvin (Glasgow), Newcastle RSCDS Festival, 2018.', 1, 1, 'Y', 'YnCDGomlTRo', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8451, '2022-02-10 17:20:20.55621+00', '2022-02-11 11:19:34.824882+00', 16524, 9, 2269, '', 'A', 'Edinburgh University, Aberdeen Festival, 2017.', 1, 1, 'Y', 'Lt0Kmon3qtE', 149, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8457, '2022-02-11 19:12:16.39492+00', '2022-02-11 19:19:13.311979+00', 19964, 1, 202, '', 'D', '', 1, 1, 'Y', 'HicMxE-CH5Y', 5, 210, NULL);
INSERT INTO 'dancevideo' VALUES (8455, '2022-02-11 18:13:59.87801+00', '2022-02-11 22:07:38.064803+00', 3326, 9, 2269, '', 'B', 'Ochil Scottish Country Dancers, St Ninian''s Church Hall, Stirling, Scotland, 2016.  Spoken and on-screen dancing instructions.', 1, 1, 'Y', 'C2u90sMsEwc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8456, '2022-02-11 18:27:11.096382+00', '2022-02-12 00:25:34.09247+00', 14903, 5, 2269, '', 'B', 'Méaudre Reel Club, Under 12, Newcastle Festival, 2020.  Well danced with vigour and enthusiasm, but the footwork and positioning are not yet up to demonstration level.', 1, 1, 'Y', 'sSu9IiR7On0', 180, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8454, '2022-02-11 18:01:56.18731+00', '2022-02-13 19:12:21.889391+00', 13582, 5, 2269, '', 'A', 'German Team Mixed 2, Newcastle SCD Festival, 2017.', 1, 1, 'Y', 'mfnLR--Az9E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8453, '2022-02-11 11:06:38.814519+00', '2022-02-13 19:16:07.907898+00', 20664, 1, 1645, '', 'B', 'Dallas, 2019. Good, with one little mishap in the tournee 2nd time through.', 1, 1, 'Y', '88CdCb-Dyxg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8446, '2022-02-10 13:29:34.065965+00', '2022-02-13 19:21:46.597577+00', 5860, 12, 2269, '', 'A', 'Newcastle RSCDS Festival, German Ladies Team, 2014.  ', 1, 1, 'Y', '9SuDtomdBrg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8450, '2022-02-10 16:09:24.511935+00', '2022-02-13 19:23:00.706507+00', 4102, 16, 2269, '', 'A', 'Members And Friends Of RSCDS Stirling Branch, Guildhall, Stirling, Scotland.  RSCDS Archive 1999.', 1, 1, 'Y', 'iF-QZqMxb20', 4533, 4631, NULL);
INSERT INTO 'dancevideo' VALUES (8449, '2022-02-10 15:44:53.405398+00', '2022-02-13 19:27:03.877078+00', 9157, 8, 2269, '', 'B', 'Kloster Frenswegen Ceilidh, 2018.  Danced with high energy (once and to the bottom in a three couple set).', 1, 1, 'Y', 'u8qnAMfJDXc', 0, 208, NULL);
INSERT INTO 'dancevideo' VALUES (8447, '2022-02-10 15:09:59.477193+00', '2022-02-13 19:46:36.490325+00', 5860, 13, 2269, '', 'A', 'Edinburgh University, New Scotland Country Dancers, Aberdeen Festival, 2018.', 1, 1, 'Y', 'hhOwaRFw4aQ', 0, 156, NULL);
INSERT INTO 'dancevideo' VALUES (8439, '2022-02-09 18:16:19.890407+00', '2022-02-13 19:59:20.395933+00', 13586, 4, 2269, '', 'C', 'Scottish Party At The Festival "The Breath Of Siberia", Tomsk, Russia, 2017.  Some minor mistakes / variations, including turning two hands all the way around instead of half-way.', 1, 1, 'Y', 'NXFQaS1mOnE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8493, '2022-02-16 21:02:47.092252+00', '2022-02-17 20:38:20.404644+00', 4805, 13, 2269, '', 'C', 'Katharine Barber Country Dancers, Kirkcudbright''s Harbour Square, 2018.', 1, 1, 'Y', 'HgRPXGM2g0w', 46, 193, NULL);
INSERT INTO 'dancevideo' VALUES (8495, '2022-02-18 09:47:11.224447+00', '2022-02-18 18:13:24.301302+00', 18408, 5, 2269, '', 'A', 'Charlotte (NC) Scottish Country Dance Society (CSCDS), 2018.  Twice through.', 1, 1, 'Y', '75jhK-lBKDc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8991, '2022-08-13 16:01:40.34757+00', '2022-08-13 16:02:52.99148+00', 11189, 16, 202, '', 'C', '', 1, 1, 'Y', 'bdWh7MVsP4I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8459, '2022-02-11 20:33:05.388501+00', '2022-02-11 22:02:06.312766+00', 1786, 10, 2269, '', 'A', 'Moscow School Of Scottish Dance, Speech School Team "Lights Beltayna", 2015.



Modified 3-couple set, beginning with the 2s and 3s dancing at the start.', 1, 1, 'Y', 'oTSCNdtICj8', 12, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8460, '2022-02-11 20:38:04.846358+00', '2022-02-11 22:03:58.217767+00', 1786, 11, 2269, '', 'A', 'RSCDS Moscow Branch, Russian Festival Of Scottish Country Dancing, Vladimir, 2014.', 1, 1, 'Y', 'izPiuC9itU0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8458, '2022-02-11 20:09:16.855422+00', '2022-02-11 22:05:50.752964+00', 1786, 9, 2269, '', 'A', 'RSCDS Edinburgh Branch Demonstration Team, Dancing Forth, 2010.



Danced twice through in a 6-couple set with everyone dancing.  Modified ending to lead into the next dance – the rights & lefts are not completed and the dancers turn right instead.', 1, 1, 'Y', '_NUjfS8fpLs', 0, 75, NULL);
INSERT INTO 'dancevideo' VALUES (8472, '2022-02-13 23:27:42.563631+00', '2022-02-13 23:48:46.718566+00', 20446, 1, 2630, '', 'B', '''Staggering Hame'' danced by dancers from the Ribble Valley RSCDC', 1, 1, 'Y', 'BTKGPiC_9hg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8463, '2022-02-12 10:44:56.633351+00', '2022-02-13 19:15:38.355984+00', 17122, 9, 2269, '', 'A', 'RSCDS Summer School 2018, Week Three Demonstration. The end of the 2nd time leads into the next dance in the demo.', 1, 1, 'Y', 'uKrIlEnca7I', 109, 236, NULL);
INSERT INTO 'dancevideo' VALUES (8470, '2022-02-12 16:46:50.506577+00', '2022-02-13 19:17:29.905662+00', 373, 6, 2269, '', 'C', 'Lower Hutt Scottish Country Dance Club, Beginners Scottish Country Dance, 2014.', 1, 1, 'Y', 'C3W6L8f9fGk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8464, '2022-02-12 10:56:55.064532+00', '2022-02-13 19:19:56.730468+00', 10787, 14, 2269, '', 'A', 'German Mixed Team 2, Newcastle RSCDS Festival, 2014.', 1, 1, 'Y', 'FqOEZsW4MP8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8465, '2022-02-12 11:13:24.588068+00', '2022-02-13 19:33:30.740655+00', 5330, 16, 2269, '', 'B', 'RSCDS Country Dancers, RSCDS Archives, 1999.  Instructional video; danced first through and second time walked.', 1, 1, 'Y', 'o2UfaYpMhao', 869, 944, NULL);
INSERT INTO 'dancevideo' VALUES (8468, '2022-02-12 15:52:09.418642+00', '2022-02-13 19:35:34.050517+00', 16523, 5, 2269, '', 'B', 'RSCDS Recycled Teenagers, Aberdeen Festival, 2017.', 1, 1, 'Y', '_hwZ4_r_jMo', 286, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8466, '2022-02-12 14:56:44.335132+00', '2022-02-13 19:37:57.438221+00', 2030, 8, 2269, '', 'C', 'RSCDS New Zealand Branch, Christchurch Summer School, 2017.', 1, 1, 'Y', 'X5kl-HnyVS0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2518, '2016-06-07 09:50:46.666634+00', '2022-02-14 17:43:31.703003+00', 3397, 1, 1041, '', 'A', '', 1, 1, 'Y', '968aGEVDhNU', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8467, '2022-02-12 15:07:30.781722+00', '2022-02-13 19:41:49.160417+00', 8577, 4, 2269, '', 'C', 'RSCDS San Francisco, Mountain View Class, 2017.  Twice through recorded, after the first repeat the camera shifts to a new set.', 1, 1, 'Y', 'eqbXYOGTqJA', 2, 73, NULL);
INSERT INTO 'dancevideo' VALUES (8480, '2022-02-15 16:16:19.23782+00', '2022-02-16 11:22:41.889951+00', 1223, 12, 2269, '', 'A', 'Newcastle 2020 - Airyhall Young Dancers, 2020.', 1, 1, 'Y', 'cQw0c9f2lQs', 257, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8469, '2022-02-12 16:12:05.630158+00', '2022-02-13 19:53:39.26341+00', 16523, 6, 2269, '', 'B', 'RSCDS Toronto, 2019.  About halfway through, a slide show in mid-screen obscures the dancing.  The last time through the dancers swap over so the man becomes the lady, while his lady becomes a man.', 1, 1, 'Y', 'bwlaXtbBSjY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8479, '2022-02-15 15:48:21.219268+00', '2022-02-15 23:51:52.662542+00', 6972, 6, 2269, '', 'A', 'City Moves at the RSCDS Aberdeen Spring Dance, 2019. Excellent - with one tiny, quickly recovered, false start part way through.', 1, 1, 'Y', 'vc7erpa9q2s', 271, 427, NULL);
INSERT INTO 'dancevideo' VALUES (135, '2012-08-19 18:59:31.938121+00', '2022-02-13 22:57:53.950321+00', 13609, 1, 513, '', 'Z', 'Reasonable video - but now private?', 1, 1, 'Y', 'falgJilIq2c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1774, '2014-08-24 12:30:57.631782+00', '2022-02-13 23:04:48.848109+00', 10052, 1, 106, '', 'C', 'Ceilidh in the Common Room, Summer School 2013.  twice through, new ghost each time.', 1, 1, 'Y', 'LJP6WMFT66o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8471, '2022-02-13 23:25:46.330313+00', '2022-02-13 23:45:49.560025+00', 20432, 1, 2630, '', 'B', '''Welcome to the Stagger Inn'' danced by dancers from the Ribble Valley Branch RSCDS.  This is a round the room dance with music for 6 times through and is an excellent starter and warm up dance. Here danced just over once through.', 1, 1, 'Y', 'fYVTMAXbi1M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8474, '2022-02-15 10:12:46.547684+00', '2022-02-16 11:07:50.891052+00', 894, 6, 2269, '', 'C', 'Ngaio SCD Club''s Annual Dance, 2017.', 1, 1, 'Y', 'WKfHR1R6xWU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8461, '2022-02-11 22:32:10.793063+00', '2022-02-14 23:20:03.03948+00', 2203, 9, 2269, '', 'B', 'Scottish Party at the Festival "The Breath Of Siberia", Tomsk, Russia, 2017.



A shaky start with a baby in arms being carried as the dance began, once the baby had been rescued, then the dance proceeded in a more assured way.', 1, 1, 'Y', 'Zx2ZK18jN1g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8478, '2022-02-15 14:38:29.542537+00', '2022-02-15 18:29:39.844807+00', 11814, 4, 2269, '', 'B', 'Paris Branch, 2014.  Danielle and Jerry Reinstein for whom the dance was devised, dancing as 4th couple.', 1, 1, 'Y', 'Gwbo-Pxt2LE', 110, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8481, '2022-02-15 16:45:20.726777+00', '2022-02-16 11:24:34.695634+00', 2394, 8, 2269, '', 'B', 'Ochil Scottish Country Dancers, St Ninian''s Church Hall, Stirling, Scotland, 2017.  Spoken and on-screen dancing instructions.', 1, 1, 'Y', 'cWOYAnntDRM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8483, '2022-02-15 17:20:25.72507+00', '2022-02-16 11:12:20.775631+00', 6010, 7, 2269, '', 'Z', 'RSCDS Edinburgh Branch Demonstration Team, Dancing Forth, 2010.  Danced in an 8-couple set, with 1s and 5s starting.



Excellent, but already in SCDDB as extract from video 5 (https://my.strathspey.org/dd/dancevideo/7763/). This entry is left in case the other video disappears some day.', 1, 1, 'Y', '_NUjfS8fpLs', 193, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8475, '2022-02-15 12:19:52.725066+00', '2022-02-16 11:15:48.167625+00', 4365, 8, 2269, '', 'C', 'Deer O''Dale Dance School, 2017.  Spirited dancing, a few times dancers loose track and end slightly behind the music, but all missteps are quickly corrected.', 1, 1, 'Y', '3piQw752zus', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8476, '2022-02-15 14:23:45.234473+00', '2022-02-16 11:29:20.344739+00', 1544, 10, 2269, '', 'B', 'Scottish Country Dancing display at Reel Club freshers'' ceilidh, 2015.  Good clear view from above.', 1, 1, 'Y', 'oqWj9kOaoNk', 36, 146, NULL);
INSERT INTO 'dancevideo' VALUES (8482, '2022-02-15 17:05:56.627856+00', '2022-02-16 11:33:05.970954+00', 2394, 9, 2269, '', 'A', 'City Moves, RSCDS Christmas Dance, 2019. Twice through as part of a longer demo.', 1, 1, 'Y', '2mwrQbbmmMg', 153, 278, NULL);
INSERT INTO 'dancevideo' VALUES (8484, '2022-02-16 15:39:39.748479+00', '2022-02-16 15:59:37.789577+00', 6972, 7, 2269, '', 'B', 'Red Thistle Dancers, Pleasanton Highland Games, 2011.', 1, 1, 'Y', 'JmcelyNN1yU', 520, 594, NULL);
INSERT INTO 'dancevideo' VALUES (8488, '2022-02-16 19:50:19.665381+00', '2022-02-16 20:12:29.189305+00', 11483, 6, 2269, '', 'C', 'RSCDS Summer School, Younger Hall, St. Andrews, 2017.', 1, 1, 'Y', 'wX-bVERUxGo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8489, '2022-02-16 19:52:32.601652+00', '2022-02-16 20:13:59.697123+00', 11483, 7, 2269, '', 'C', 'SCD Group, Hong Kong, 2014.', 1, 1, 'Y', 'RLmHDVx3Q_c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8491, '2022-02-16 20:31:28.777514+00', '2022-02-16 20:33:23.999834+00', 1473, 12, 2269, '', 'B', 'RSCDS Stirling Branch, Princes St Gardens, Edinburgh, Scotland, 2004.  Spoken and on-screen dancing instructions.', 1, 1, 'Y', 'TAKAsutGMAw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1434, '2013-10-04 10:07:07.870917+00', '2022-02-18 01:05:18.181463+00', 7457, 1, 513, '', 'Z', 'Now private on youtube (was graded Reasonable)', 1, 1, 'Y', 'V45MnjwXPxE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8486, '2022-02-16 16:35:45.563174+00', '2022-02-16 23:48:22.493631+00', 3418, 4, 2269, '', 'C', 'RSCDS Toronto, Beginners'' Night, 2018.  Reprise – once each couple.', 1, 1, 'Y', 'pf94mJVdy5M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8485, '2022-02-16 16:16:54.282998+00', '2022-02-16 23:50:08.244737+00', 4641, 11, 2269, '', 'C', 'Tawa SCD Club Dance, 2015.', 1, 1, 'Y', '_gZruTGvzcs', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8487, '2022-02-16 16:47:53.36142+00', '2022-02-16 23:57:18.259586+00', 5308, 7, 2269, '', 'B', 'Naramata Scottish Country Dancers, Club Burns Night, 2020.', 1, 1, 'Y', '1udfMeZJdwU', 172, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8494, '2022-02-17 00:09:06.01326+00', '2022-02-17 00:11:52.999+00', 20666, 1, 1645, '', 'B', 'RSCDS Leicester 2021.', 1, 1, 'Y', 'VbSukio3aq4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2355, '2016-02-20 00:35:43.835151+00', '2022-02-17 12:07:56.780533+00', 10327, 10, 106, '', 'Z', '175th anniversary of Willunga Town, 2014-09-19



Now unavailable (was informal/social)', 1, 1, 'Y', 'rqtu3xDfYho', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8490, '2022-02-16 20:23:10.438048+00', '2022-02-17 20:11:23.071691+00', 11773, 6, 2269, '', 'B', 'Ruhrball 2018.  Danced with vigour.', 1, 1, 'Y', 'h185gvEWbrg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8593, '2022-03-14 17:24:31.750638+00', '2022-03-15 14:24:03.131525+00', 5555, 6, 2269, '', 'A', 'Airyhall Young Dancers, Newcastle International Festival, 2018.', 1, 1, 'Y', 'yIQSTa8steg', 5, 160, NULL);
INSERT INTO 'dancevideo' VALUES (9037, '2022-09-17 22:55:50.387078+00', '2022-09-17 22:56:31.56383+00', 5703, 6, 202, '', 'D', '', 1, 1, 'Y', 'uolc-NKsY4M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9190, '2023-01-05 18:36:42.323033+00', '2023-01-05 18:42:14.651399+00', 17698, 1, 1645, '', 'B', 'SCD group Hong Kong, 2022. Clear (with a few hesitations).', 1, 1, 'Y', '3IYyoOLJeDo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7684, '2020-12-29 00:01:08.674198+00', '2022-02-18 10:37:24.039692+00', 13077, 3, 1645, '', 'Z', 'Torino (Clivis) 2016 SCD Ball. Three repeats. The video starts about 2 bars into the first repeat.



Now private in youtube (was graded Reasonable)', 1, 1, 'Y', 'OWa8aRC6UUM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8496, '2022-02-18 10:38:05.817192+00', '2022-02-18 10:38:26.084208+00', 6957, 5, 1645, '', 'X', '''Waverley or Fergus McIver'' is a 48 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'GFoeI-EcA-Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8506, '2022-02-18 14:50:23.495685+00', '2022-02-18 18:11:50.397098+00', 4032, 8, 2269, '', 'B', 'Rotorua SCD Club''s Queen''s Birthday Weekend School, New Zealand, 2017.', 1, 1, 'Y', '6TyG6-UXTu4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8499, '2022-02-18 12:54:18.324861+00', '2022-02-18 18:16:40.368909+00', 1777, 5, 2269, '', 'A', 'Members And Friends Of RSCDS Stirling Branch, Guildhall, Stirling, Scotland.  RSCDS Archives 1999.', 1, 1, 'Y', 'iF-QZqMxb20', 5208, 5337, NULL);
INSERT INTO 'dancevideo' VALUES (8501, '2022-02-18 13:22:39.070251+00', '2022-02-18 18:19:10.309645+00', 16537, 7, 2269, '', 'A', 'RSCDS Aberdeen Branch, Aberdeen Festival, 2017.', 1, 1, 'Y', '6n_j0TtPBtY', 0, 151, NULL);
INSERT INTO 'dancevideo' VALUES (8502, '2022-02-18 13:45:01.546217+00', '2022-02-18 18:19:52.51045+00', 16537, 8, 2269, '', 'A', 'RSCDS Newcastle Festival, International Team White, 2017.', 1, 1, 'Y', 'KZnEW60IwRo', 0, 157, NULL);
INSERT INTO 'dancevideo' VALUES (8498, '2022-02-18 11:06:45.547795+00', '2022-02-18 18:28:29.655591+00', 13270, 4, 2269, '', 'B', 'Colchester Scottish Dance And Ceilidh Club, 2016.  Twice through in a 3 couple set. Both times the final 8 bars are changed with the final half figure of 8 being danced before all turn partner RH (the instructions have the turn first). The 2nd time the ending is also modified slightly to lead into next dance.', 1, 1, 'Y', 'qX2gRrs2o8A', 77, 147, NULL);
INSERT INTO 'dancevideo' VALUES (8510, '2022-02-18 16:09:17.7951+00', '2022-02-18 18:31:16.092768+00', 1647, 8, 2269, '', 'A', 'Edinburgh RSCDS Demonstration Team, Edinburgh Castle, 2012.  One complete turn through (plus a bit).', 1, 1, 'Y', 'i7OviG_RpIY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8512, '2022-02-18 16:31:19.212726+00', '2022-02-18 18:33:58.003188+00', 1647, 10, 2269, '', 'A', 'Dunedin Dancers, Edinburgh, Stirling, Scotland, 2011.  Modified ending to lead into the next dance.', 1, 1, 'Y', 'dj_dToiSTSI', 0, 71, NULL);
INSERT INTO 'dancevideo' VALUES (8511, '2022-02-18 16:22:38.408707+00', '2022-02-18 18:36:04.180508+00', 1647, 9, 2269, '', 'B', 'Glenview Social Group, Hogmanay, 2013.', 1, 1, 'Y', 'lePJ7inWDTE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8497, '2022-02-18 10:57:54.51696+00', '2022-02-18 18:36:28.291495+00', 2686, 2, 1645, '', 'B', 'Shasta Scottish Country Dancers, 2012.', 1, 1, 'Y', '1NVlgU03Ccs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8507, '2022-02-18 15:25:03.814217+00', '2022-02-18 18:37:23.316951+00', 588, 6, 2269, '', 'C', 'Kalamazoo Royal Scottish Country Dancers, 2014.', 1, 1, 'Y', 'IGSE0tm5BLQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8503, '2022-02-18 14:10:24.101493+00', '2022-02-18 18:40:03.901525+00', 16536, 6, 2269, '', 'B', 'Aberdeen University Scottish Dance Society, Aberdeen Festival, 2017.', 1, 1, 'Y', 'Y1YK4lHepJs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8505, '2022-02-18 14:22:55.409367+00', '2022-02-18 18:41:59.95847+00', 16536, 8, 2269, '', 'A', 'Red Thistle Dancers, 152nd Highland Games, Pleasanton, 2017.', 1, 1, 'Y', 't20NH8Kb9k8', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8504, '2022-02-18 14:16:46.036358+00', '2022-02-18 18:43:39.845556+00', 16536, 7, 2269, '', 'B', 'Scottish Flowers, Highland Gathering, Peine, Germany, 2016.', 1, 1, 'Y', 'U8dC3PPBLjI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8513, '2022-02-20 00:16:22.064295+00', '2022-02-20 00:17:52.497175+00', 2169, 1, 1645, '', 'B', 'RSCDS Leeds at the White Rose Festival 2012. This clip shows the last two repeats (earlier ones are not quite as clear with some minor false starts). The dancers here chose the option of turning LH twice before the final reels.', 1, 1, 'Y', '9HoZbRozwng', 99, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8500, '2022-02-18 13:11:23.405105+00', '2022-02-18 18:49:53.864912+00', 16525, 8, 2269, '', 'X', 'Dance Animation By George Williams. NB men are rectangles and women ovals. The opening "dance" down (nearer hands joined) is here described as "lead" down which commonly indicates right hands joined.', 1, 1, 'Y', 'psqZHwCukw4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8508, '2022-02-18 15:46:13.134558+00', '2022-02-18 18:52:34.502508+00', 588, 7, 2269, '', 'D', '15th Annual Bluebonnet Ball, San Antonio, Texas, 2012.', 1, 1, 'Y', 'w5JNHZu7rYs', 42, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8509, '2022-02-18 15:53:11.801564+00', '2022-02-18 18:53:45.192125+00', 588, 8, 2269, '', 'C', 'Johnsonville SCD Club, Ngaio Town Hall, Wellington, New Zealand, 2020.', 1, 1, 'Y', 'KbpnLgqnuzo', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8492, '2022-02-16 20:55:56.226116+00', '2022-02-18 19:02:59.531035+00', 4805, 12, 2269, '', 'C', 'Deer O''Dale Dance School, 2019.  Good dancing with a few missteps rapidly corrected. The instructions have the 2nd couple stepping up on bars 7-8 but here they step up earlier.', 1, 1, 'Y', 'y5zdUntSmPw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8514, '2022-02-20 00:28:22.66974+00', '2022-02-20 00:28:44.382013+00', 213, 1, 1645, '', 'B', 'RSCDS Leeds and Sheffield branches at the Leeds White Rose Festival 2016. After the first time through the music on the video is slightly out of synch.', 1, 1, 'Y', 'EU8r_JNLdbI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5162, '2019-09-24 11:19:16.645798+00', '2022-02-20 20:58:41.932411+00', 1960, 1, 1645, '', 'D', 'Three times through, once each couple, in a three couple set with the last few bars adapted to get the 1st couple to the bottom. This causes some confusion restarting with double figures of 8 at the top (which do not start with setting). There are also some troubles getting into the hands across at the end of the reels. The last part of a longer display. ', 1, 1, 'Y', '6qVNTxx9QRw', 319, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8515, '2022-02-20 23:45:21.824117+00', '2022-02-20 23:45:51.229895+00', 20669, 1, 1645, '', 'B', 'Berkhamsted Strathspey and Reel Club, 2022.', 1, 1, 'Y', 'dV0qBTptgMk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8518, '2022-02-21 18:20:25.82037+00', '2022-02-21 22:42:18.979972+00', 11486, 1, 1645, '', 'A', 'RSCDS Leicester at the 2003 ASCDS festival. Once through in three 2 couple sets as part of a longer display.', 1, 1, 'Y', 'pd3XXuLhC_s', 87, 124, NULL);
INSERT INTO 'dancevideo' VALUES (8520, '2022-02-21 20:09:22.947501+00', '2022-02-21 22:42:49.213206+00', 11483, 8, 1645, '', 'A', 'RSCDS Leicester at the 2003 ASCDS festival. Twice through as the last part of a longer display ending with a big circle and dance off.', 1, 1, 'Y', 'pd3XXuLhC_s', 217, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8521, '2022-02-21 20:15:33.761456+00', '2022-02-21 22:43:55.123358+00', 9947, 1, 1645, '', 'A', 'RSCDS Leicester at the 2004 ASCDS festival. Twice through as the first part of a longer display. The end of the 2nd repeat is adapted to lead into the next dance.', 1, 1, 'Y', '2UrNSpNWR7A', 53, 166, NULL);
INSERT INTO 'dancevideo' VALUES (8525, '2022-02-21 21:07:33.834189+00', '2022-02-21 22:44:45.374193+00', 4383, 1, 1645, '', 'A', 'RSCDS Leicester at the 2005 ASCDS festival. Once through in 3 couple sets as part of a longer display with 1st couple casting to the bottom at the end.

', 1, 1, 'Y', '8yEy2VAHfjc', 225, 262, NULL);
INSERT INTO 'dancevideo' VALUES (8523, '2022-02-21 20:37:10.429012+00', '2022-02-21 22:46:12.196201+00', 11487, 1, 1645, '', 'A', 'RSCDS Leicester at the 2004 ASCDS festival. The last dance in a longer display (the video continues with other choreography for a dance off).', 1, 1, 'Y', '2UrNSpNWR7A', 239, 397, NULL);
INSERT INTO 'dancevideo' VALUES (8519, '2022-02-21 20:04:55.666929+00', '2022-02-21 22:47:40.975529+00', 11484, 1, 1645, '', 'A', 'RSCDS Leicester at the 2003 ASCDS festival. This clip shows once through the dance in two 4 couple sets as part of a longer display. [NB the video continues with an 8 bar transition into the next dance but this is not part of Silver Threads which ends with the Tournee].', 1, 1, 'Y', 'pd3XXuLhC_s', 124, 201, NULL);
INSERT INTO 'dancevideo' VALUES (8517, '2022-02-21 18:16:57.642901+00', '2022-02-21 22:54:43.004289+00', 11480, 2, 1645, '', 'A', 'RSCDS Leicester at the 2003 ASCDS festival. Once through as the first part of a longer display. The two sets start on the diagonal to the camera but end curving into one line ready for the next part of the demo.', 1, 1, 'Y', 'pd3XXuLhC_s', 5, 87, NULL);
INSERT INTO 'dancevideo' VALUES (8516, '2022-02-21 11:37:01.328287+00', '2022-02-21 22:53:01.31035+00', 6237, 1, 1645, '', 'A', 'RSCDS Leicester at the ASCDS Festival 2007. Clear display (with a couple of minor glitches).', 1, 1, 'Y', '3Ew3yHAPYcA', 13, 186, NULL);
INSERT INTO 'dancevideo' VALUES (8522, '2022-02-21 20:23:11.763783+00', '2022-02-21 22:55:25.927522+00', 11479, 1, 1645, '', 'B', 'RSCDS Leicester at the 2003 ASCDS festival. This clip shows the dance once through in two 3 couple sets as part of a longer display. The last 2 bars are slightly adapted with 1st couple crossing to the bottom. The video continues with a 2nd repeat but this is more heavily adapted to lead into the next dance in the demo.', 1, 1, 'Y', '2UrNSpNWR7A', 166, 204, NULL);
INSERT INTO 'dancevideo' VALUES (8556, '2022-03-04 19:48:33.953933+00', '2022-03-04 21:24:53.434921+00', 4844, 7, 2269, '', 'A', 'RSCDS Stirling, Macrobert Arts Centre, Stirling, Scotland.  RSCDS Archive 2019.  Once through (wth the camera switching to and from close ups).', 1, 1, 'Y', 'LdtlT3WPRAc', 3095, 3134, NULL);
INSERT INTO 'dancevideo' VALUES (8524, '2022-02-21 20:45:51.072428+00', '2022-02-21 22:39:36.139048+00', 559, 1, 1645, '', 'A', 'RSCDS Leicester at the 2005 ASCDS festival. The first part of a longer display. Here danced in two 3 couple sets with the end slightly adapted to lead into the next dance.

', 1, 1, 'Y', '8yEy2VAHfjc', 5, 61, NULL);
INSERT INTO 'dancevideo' VALUES (8526, '2022-02-21 21:29:48.181522+00', '2022-02-21 22:41:29.557399+00', 1179, 1, 1645, '', 'A', 'RSCDS Leicester at the 2005 ASCDS festival. This clip shows once through in four 2 couple sets as part of a longer display (the video continues with part of a 2nd repeat which is adapted to lead into the next dance).

', 1, 1, 'Y', '8yEy2VAHfjc', 271, 338, NULL);
INSERT INTO 'dancevideo' VALUES (8529, '2022-02-22 18:43:49.047012+00', '2022-02-23 18:28:23.956628+00', 8580, 1, 1645, '', 'A', 'RSCDS Leicester at the 2006 ASCDS festival. Twice through as part of a longer display. The end of the 2nd time is adapted to lead into the next dance in the demo.', 1, 1, 'Y', '_0IhDkjKk0E', 0, 124, NULL);
INSERT INTO 'dancevideo' VALUES (8531, '2022-02-22 19:03:57.484992+00', '2022-02-23 18:29:23.633626+00', 559, 2, 1645, '', 'A', 'RSCDS Leicester at the 2008 ASCDS festival. Twice through as the last part of a longer display. Here danced in three 3 couple sets with 1st couple casting to the bottom each time.', 1, 1, 'Y', 'SHqW7TPvtHg', 123, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8528, '2022-02-22 18:40:26.622802+00', '2022-02-23 18:29:47.56329+00', 12166, 1, 1645, '', 'A', 'RSCDS Leicester at the 2006 ASCDS festival. This is the 2nd part of a longer display.', 1, 1, 'Y', '_0IhDkjKk0E', 123, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8539, '2022-02-24 20:27:10.657403+00', '2022-02-24 20:28:04.19745+00', 6229, 1, 1645, '', 'A', 'Leicester RSCDS at the ASCDS Festival 2018. The last part of a longer display. Other dancers from the display join in the final circle.', 1, 1, 'Y', 'TNhLDHVED2A', 149, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8532, '2022-02-22 20:02:27.138649+00', '2022-02-23 18:31:18.614855+00', 999, 3, 1645, '', 'A', 'RSCDS Leicester at the 2013 ASCDS festival. This clip shows the dance once through as the first part of a longer display.', 1, 1, 'Y', 'cbD-00jNIz0', 15, 53, NULL);
INSERT INTO 'dancevideo' VALUES (8530, '2022-02-22 18:59:59.924775+00', '2022-02-23 18:31:54.068769+00', 1508, 1, 1645, '', 'A', 'RSCDS Leicester at the 2008 ASCDS festival. This clip shows the dance once through as the first part of a longer display.', 1, 1, 'Y', 'SHqW7TPvtHg', 0, 79, NULL);
INSERT INTO 'dancevideo' VALUES (8533, '2022-02-22 20:06:56.435528+00', '2022-02-23 18:34:31.426058+00', 4087, 1, 1645, '', 'B', 'RSCDS Leicester at the 2013 ASCDS festival. This clip shows once through the dance as part of a longer display.', 1, 1, 'Y', 'cbD-00jNIz0', 87, 149, NULL);
INSERT INTO 'dancevideo' VALUES (8534, '2022-02-22 20:14:38.776809+00', '2022-02-23 18:35:02.801137+00', 12980, 1, 1645, '', 'B', 'RSCDS Leicester at the 2013 ASCDS festival. Once through as the last part of a longer display.', 1, 1, 'Y', 'cbD-00jNIz0', 209, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5172, '2019-09-26 11:05:33.331497+00', '2022-02-24 17:15:34.028814+00', 3021, 4, 1645, '', 'B', 'Leicester RSCDS at the 2019 ASCDS festival. Once through clip from a longer display. The video continues with another repeat of this dance but the end is modified to lead into the next dance.', 1, 1, 'Y', '5cq7_TKdne8', 50, 88, NULL);
INSERT INTO 'dancevideo' VALUES (5174, '2019-09-26 11:20:36.186066+00', '2022-02-24 17:17:14.087817+00', 11367, 1, 1645, '', 'B', 'Leicester RSCDS at the 2019 ASCDS festival. Once through (final part of a longer display). 3rd and 4th couples are unobtrusively starting on opposite sides.', 1, 1, 'Y', '5cq7_TKdne8', 241, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1021, '2013-08-18 00:51:50.648615+00', '2022-02-24 17:21:56.43826+00', 428, 2, 1296, '', 'B', 'Shasta Scottish Country Dancers, 2011. Danced 3 times in a 3c set.', 1, 1, 'Y', 'wyGslpvxj18', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8535, '2022-02-24 19:07:03.4075+00', '2022-02-24 19:21:36.676835+00', 3323, 3, 1645, '', 'B', 'Caper Ducks at the Grass Valley Celtic Festival 2014. Twice through.', 1, 1, 'Y', 'MsSf1w14Pmg', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8536, '2022-02-24 19:12:21.28452+00', '2022-02-24 19:22:18.736429+00', 3323, 4, 1645, '', 'B', 'Seattle Scottish Country Dance, 2012. Twice through, once each 1st couple.', 1, 1, 'Y', 'oPL7RzejsFg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8537, '2022-02-24 19:20:46.348168+00', '2022-02-24 19:23:41.725255+00', 3323, 5, 1645, '', 'B', 'Lyon Branch Weekend 2016. Three times in 3 couple sets with coaching by the teacher. 1st couple step to the bottom each time.', 1, 1, 'Y', 'A89ka9hZgSY', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8538, '2022-02-24 20:20:54.734801+00', '2022-02-24 20:27:51.673314+00', 16527, 6, 1645, '', 'B', 'Leicester RSCDS at the ASCDS Festival 2018. Twice through in 3 couple sets as the first part of a longer display. The end of the 2nd time is slightly adapted to lead into the next dance in the demo.', 1, 1, 'Y', 'TNhLDHVED2A', 0, 74, NULL);
INSERT INTO 'dancevideo' VALUES (8543, '2022-02-24 21:13:30.786443+00', '2022-02-26 11:24:06.880855+00', 16465, 4, 562, '', 'C', 'Weihnachtsball Münster 2016', 1, 1, 'Y', '2G3FuNvk22A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8540, '2022-02-24 20:32:25.286395+00', '2022-02-26 11:24:59.471877+00', 2506, 7, 1645, '', 'A', 'Leicester RSCDS at the 2015 ASCDS festival. Twice through in two 2 couple sets with the end of the 2nd time adapted to lead into the next dance.', 1, 1, 'Y', 'l0DJAhooKBc', 59, 133, NULL);
INSERT INTO 'dancevideo' VALUES (8541, '2022-02-24 20:43:57.080868+00', '2022-02-26 11:26:12.544403+00', 2723, 3, 1645, '', 'B', 'Leicester RSCDS at the 2015 ASCDS festival. Twice through in 2 couple sets as part of a longer display. The end of the 2nd time is adapted to lead into the next dance in the demo.', 1, 1, 'Y', 'l0DJAhooKBc', 133, 259, NULL);
INSERT INTO 'dancevideo' VALUES (8542, '2022-02-24 20:54:47.829743+00', '2022-02-26 11:52:17.556994+00', 5678, 1, 1645, '', 'B', 'Leicester RSCDS at the 2015 ASCDS festival. Once through as the last part of a longer display finishing with a big circle of the two 4 couple sets.', 1, 1, 'Y', 'l0DJAhooKBc', 259, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8544, '2022-02-28 19:55:07.244866+00', '2022-02-28 23:18:07.13438+00', 20335, 1, 963, '', 'X', '', 1, 1, 'Y', 'i-9ON_YSHm4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8550, '2022-03-01 19:23:03.275729+00', '2022-03-01 20:55:00.380654+00', 2250, 8, 2269, '', 'B', 'RSCDS Toronto Beginners'' Night, 2017.  Good footwork and lots of flight from most of the dancers.', 1, 1, 'Y', '2mvenlpWItk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8546, '2022-03-01 10:06:45.886975+00', '2022-03-01 21:02:44.042662+00', 2616, 10, 2269, '', 'C', 'Méaudre Reel Club, Children And Teenagers (level 3), Vercors, France, 2018.  Highland setting steps, with slightly modified ending. Twice through as part of a longer demo, starting from 2nd place, then repeated with a new couple from 1st place.', 1, 1, 'Y', 'HNbnTBFts0w', 138, 208, NULL);
INSERT INTO 'dancevideo' VALUES (8547, '2022-03-01 10:41:06.358778+00', '2022-03-01 21:06:34.464763+00', 13727, 4, 2269, '', 'C', 'Wellington Scottish Country Dancers, Old Government Buildings Lawn, Wellington, New Zealand, 2021.  The music is a little faint and there is some background noise.  The camera pans away from the dancers briefly.', 1, 1, 'Y', 'QEU4yKFrVAY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8545, '2022-03-01 09:55:56.617443+00', '2022-03-01 21:04:06.44367+00', 2616, 9, 2269, '', 'A', 'Men Alba SCD Glasgow, Newcastle Festival, 2018.', 1, 1, 'Y', 'hguSSAEFIJk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8549, '2022-03-01 19:06:38.174974+00', '2022-03-01 21:05:29.350335+00', 2777, 6, 2269, '', 'B', 'RSCDS Stirling Branch, St Ninian''s Parish Church Hall, Stirling, Scotland, 2019.  Spoken and on-screen dancing instructions.', 1, 1, 'Y', 'cENkkFya2EA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8548, '2022-03-01 10:54:00.203172+00', '2022-03-01 21:09:35.569356+00', 13727, 5, 2269, '', 'C', 'Upper Hutt Scottish Country Dance Club, 2015. The video starts about 1 bar into the dance.', 1, 1, 'Y', 'rFNTtjqZPME', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8552, '2022-03-03 00:47:56.448566+00', '2022-03-03 00:50:24.474918+00', 20676, 1, 1645, '', 'B', 'Quick Scotch class, Nizhniy Novgorod, Russia, 2022. This clip shows one repeat. The video also has 12 bars of the previous repeat.', 1, 1, 'Y', 'PJxJTSD4imU', 16, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8551, '2022-03-03 00:45:27.264764+00', '2022-03-03 00:54:41.436665+00', 20675, 1, 1645, '', 'C', 'Quick Scotch class, Nizhniy Novgorod, Russia, 2022. The view is cutting between dancers and musician so it can be hard to follow the choreography. A fairly complete repeat starts at 2:11.', 1, 1, 'Y', 'SfsY6ZMgT7Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5097, '2019-09-14 08:16:58.22974+00', '2022-03-04 09:52:32.831701+00', 18096, 1, 1645, '', 'B', 'Well danced, though to reel music rather than the expected jig.', 1, 1, 'Y', 'ECIfGqNOXKs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8553, '2022-03-04 12:31:38.804815+00', '2022-03-04 23:44:38.944447+00', 17891, 3, 2269, '', 'A', 'Julie Young Dancers Team B, Aberdeen Festival, 2018.', 1, 1, 'Y', 'gflVgdxzLIc', 0, 296, NULL);
INSERT INTO 'dancevideo' VALUES (8554, '2022-03-04 12:40:51.725679+00', '2022-03-04 23:49:01.984018+00', 17891, 4, 2269, '', 'C', 'St Clements'' Christmas Treat Dance, 2017.  The set mostly in view dances with 4s and 5s doing it once only.', 1, 1, 'Y', '9AJGRoXqUJU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9077, '2022-10-23 13:32:53.609582+00', '2022-10-23 22:55:01.512654+00', 13852, 2, 2755, '', 'A', '', 1, 1, 'Y', 'OlINrxEI01Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1289, '2013-08-18 10:55:44.303477+00', '2022-03-04 21:22:27.249806+00', 4844, 4, 1296, '', 'B', 'Scottish Flowers, 2nd "Schottentag" in Gronau, Germany, 2010. Danced in a 3C set; the old 1c and 3c use bars 1-4 to dance to their new places.

', 1, 1, 'Y', 'M43YJ4twPz8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1948, '2015-02-21 21:51:55.610192+00', '2022-03-04 21:30:37.689121+00', 10166, 1, 1041, '', 'B', 'Chiswick 2015. Twice through completely, part of third time through. The instructions suggest the 1st couple may turn once or twice in bars 13-16 and here both options are shown.', 1, 1, 'Y', 'lsacUIL30ok', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8562, '2022-03-04 23:33:19.724483+00', '2022-03-04 23:36:49.689582+00', 445, 14, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999

', 1, 1, 'Y', 'iF-QZqMxb20', 5123, 5205, NULL);
INSERT INTO 'dancevideo' VALUES (8559, '2022-03-04 23:26:35.076587+00', '2022-03-04 23:38:17.372037+00', 1280, 11, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999

', 1, 1, 'Y', 'iF-QZqMxb20', 4634, 4716, NULL);
INSERT INTO 'dancevideo' VALUES (8555, '2022-03-04 13:13:46.637572+00', '2022-03-04 23:40:19.372567+00', 17134, 4, 2269, '', 'A', 'RSCDS Summer School, Week Three Demonstrations, 2016.', 1, 1, 'Y', 'TlGXCWLiWVI', 0, 215, NULL);
INSERT INTO 'dancevideo' VALUES (8561, '2022-03-04 23:31:07.218787+00', '2022-03-04 23:56:28.848331+00', 2428, 9, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999

', 1, 1, 'Y', 'iF-QZqMxb20', 4953, 5037, NULL);
INSERT INTO 'dancevideo' VALUES (8560, '2022-03-04 23:29:00.07497+00', '2022-03-04 23:58:03.685136+00', 4555, 8, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999

', 1, 1, 'Y', 'iF-QZqMxb20', 4817, 4951, NULL);
INSERT INTO 'dancevideo' VALUES (8574, '2022-03-08 16:48:15.226954+00', '2022-03-08 19:29:35.102497+00', 13730, 7, 2269, '', 'C', 'SCD Group, Hong Kong, 2014.', 1, 1, 'Y', 'jatmvZLksic', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8558, '2022-03-04 23:22:59.456239+00', '2022-03-04 23:59:45.742706+00', 6091, 7, 562, '', 'A', 'From "Reel Scottish Dancing" in the RSCDS Archive, 1999

', 1, 1, 'Y', 'iF-QZqMxb20', 4282, 4412, NULL);
INSERT INTO 'dancevideo' VALUES (8563, '2022-03-05 12:14:30.010718+00', '2022-03-06 20:46:53.576849+00', 13621, 5, 2269, '', 'C', 'RSCDS Seattle, University District Class Party, 2014.  A spirited performance.  Last time through; missing the first four bars.', 1, 1, 'Y', 'jP1z3ztLZpw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8565, '2022-03-05 12:57:59.917828+00', '2022-03-06 20:49:33.697283+00', 2935, 4, 2269, '', 'C', 'Russia, 2018.  First man and third man cross ahead of second man and fourth man in the instructions, in the video they take turns.', 1, 1, 'Y', 'YJg-iL7F_X8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8575, '2022-03-08 22:09:03.38871+00', '2022-03-09 17:17:07.992557+00', 17460, 7, 2269, '', 'A', 'Russian Festival of Scottish Country Dancing, Kazan, 2019.  For the purposes of this demonstration both 1s & 2s and 3s & 4s set and link at the start of the 3rd time through (rather than just 1s & 2s).  Around this time one of the ladies is a bit slow in returning to her own side at the end of the snake pass.', 1, 1, 'Y', 'q4Tfu_YhxXM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8566, '2022-03-05 13:12:43.315159+00', '2022-03-06 20:52:34.947519+00', 2935, 5, 2269, '', 'D', 'Krakow, Poland, 2015.  It is a bit fluid who crossed the set first – sometimes the first man, and sometimes the second.  The dance floor is crowded and the view is partly interrupted in the first 16 bars.', 1, 1, 'Y', 'BdKgTqZZLzg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8567, '2022-03-05 14:48:47.832332+00', '2022-03-06 20:54:31.356253+00', 6373, 6, 2269, '', 'C', 'Méaudre Reel Club, Vercors, France, 2022.  The young children are beginners – so expect a few errors which are quickly corrected.', 1, 1, 'Y', 'fWzpU3gdZcs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8564, '2022-03-05 12:28:16.914023+00', '2022-03-06 20:56:14.547007+00', 8743, 2, 2269, '', 'C', 'Fanwood, New Jersey, 2013.  Almost four-time through.', 1, 1, 'V', '77193354', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8568, '2022-03-07 02:40:02.740676+00', '2022-03-07 02:40:02.740676+00', 343, 2, 1296, '', 'X', '''Bailey''s Irish Cream'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', '6VjTPzZU3QM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8569, '2022-03-07 02:40:02.764318+00', '2022-03-07 02:40:02.764318+00', 827, 1, 1296, '', 'X', '''Brodie Castle'' is a 32 bar jig for 4 couples in a 4 couple set.', 1, 1, 'Y', 'cwzSyWXzGio', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8570, '2022-03-07 02:40:02.811575+00', '2022-03-07 02:40:02.811575+00', 10016, 2, 1296, '', 'X', '''Daffodil, The'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', 'dsl9-QbEUhk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8571, '2022-03-07 02:40:02.828302+00', '2022-03-07 02:40:02.828302+00', 7189, 3, 1296, '', 'X', '''Winding Road, The'' is a 32 bar strathspey for 4 couples in a 4 couple set.', 1, 1, 'Y', 'YHPpziaCjvk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (836, '2013-02-12 10:57:33.393749+00', '2022-03-08 19:22:29.343615+00', 13730, 1, 513, '', 'C', 'Recorded at Kuckucksnest, Schluechtern, Germany, 2013 (RSCDS Central Germany Branch Carnival Weekend).



Danced in a 7-couple set, with borrowing from the set below.', 1, 1, 'Y', 'IWlnwALJTqI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8572, '2022-03-08 15:47:03.666158+00', '2022-03-08 19:28:21.12112+00', 13730, 5, 2269, '', 'B', 'RSCDS Gleneagles Scottish Country Dance Club, West Vancouver, British Columbia, Canada, 2020.  Three times through with alternate view.  Dancing couples have matching coloured shirts, which makes following the dance easier. The group here do not take nearer hands when dancing down on bar 12.', 1, 1, 'Y', 'D3dKpB5VViw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8578, '2022-03-10 15:56:43.045709+00', '2022-03-10 22:06:00.949016+00', 17460, 9, 2269, '', 'A', 'Deer O''Dale Dance School, Russia, 2019.  The dancing is of demonstrating quality, however, towards the end of the dance there are some lapses of concentration and general arm waving.', 1, 1, 'Y', 's4FZ03YP6ts', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8579, '2022-03-10 16:14:50.150291+00', '2022-03-10 20:12:16.606809+00', 15044, 3, 2269, '', 'B', 'SCD Group, Hong Kong, 2019.  Once through.', 1, 1, 'Y', 'I3_6U4DydDw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8576, '2022-03-10 11:16:38.561526+00', '2022-03-10 20:14:04.031857+00', 4827, 9, 2269, '', 'B', 'Clivis Country Scottish Dance Association, Turin, 2014.  Generally, 3-couple Poussettes are used as a progression.  Some close-up shots are employed and at one point, towards the end of the dance, the camera shifts about erratically before the shot stabilises.', 1, 1, 'Y', 'y9wdVmTmyUM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8577, '2022-03-10 15:28:04.007892+00', '2022-03-10 22:03:27.722806+00', 17460, 8, 2269, '', 'B', 'Studio Of Old And Folk Dance, Beltane Lights, Anniversary Dance Evening, 2019.  This clip starts with the dancing (at the start there is a short movie sequence).  Emphasis is on having fun and some theatre.  There is a bit of a false start in bars 9-16 but thereafter the dancers overcome their nerves and the dancing improves.  Mostly the dancers pass the correct shoulder ( bars 9-16 ) and this becomes more consistent later in the dance.', 1, 1, 'Y', '3AJjykCKJEM', 14, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8580, '2022-03-12 11:35:41.425147+00', '2022-03-12 11:39:43.406388+00', 20632, 1, 2015, '', 'B', 'Performed by Geneva Scottish Dance Club to help attendees at the Geneva Spring Ball 2022', 1, 1, 'Y', 'Uw7aaa0qUjA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8581, '2022-03-12 11:37:50.22791+00', '2022-03-12 11:45:25.947862+00', 16517, 1, 2015, '', 'B', 'Performed by the Geneva Scottish Country Dance Club to help attendees at the Geneva Spring Ball in 2022', 1, 1, 'Y', 'yT7VQfqmuY4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8582, '2022-03-12 11:39:55.288729+00', '2022-03-12 11:48:04.776725+00', 20633, 1, 2015, '', 'B', 'Performed by the Geneva Scottish Country Dance Club for attendees at the Geneva Spring Ball in 2022', 1, 1, 'Y', 'Dj1QG5g4X8Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8584, '2022-03-12 21:37:47.928905+00', '2022-03-13 23:09:00.764145+00', 16187, 2, 1645, '', 'B', 'Potters Pairs, 2021. Twice through.', 1, 1, 'Y', 'jy5ElIeXoBg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8583, '2022-03-12 21:28:26.549771+00', '2022-03-13 23:10:42.804494+00', 20719, 1, 1645, '', 'B', 'Kalamazoo Royal Scottish Country Dancers, Michigan, 2014. The choreography seems clear though walked rather than danced in some cases.', 1, 1, 'Y', 'wf3JBcvyIiI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1849, '2014-09-22 15:37:24.713608+00', '2022-03-14 00:17:20.121558+00', 13139, 1, 106, '', 'C', '', 1, 1, 'Y', 'xy46YYVDBrQ', 22, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8585, '2022-03-14 08:51:57.516174+00', '2022-03-15 00:12:51.367388+00', 14401, 7, 2269, '', 'B', 'Méaudre Reel Club, Children/Teens Level 3, Vercors, France, 2019.', 1, 1, 'Y', 'zKrh89yw2_w', 71, 138, NULL);
INSERT INTO 'dancevideo' VALUES (8587, '2022-03-14 09:23:38.211515+00', '2022-03-15 00:32:52.966996+00', 10166, 3, 2269, '', 'C', 'Ramadan-ce Encore Lyon, 2019.  Once each couple. The camera position is close to the set and parts of the set are out of view.', 1, 1, 'Y', 'oCf5NrGBhf8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8586, '2022-03-14 09:03:49.104094+00', '2022-03-15 14:26:48.435005+00', 14401, 8, 2269, '', 'X', 'Dance Animation By George Williams, 2020.  Contrary to the usual shapes for men and woman, the video represents the ladies as a modified oval, the men as a modified rectangle.', 1, 1, 'Y', 'fIcDsYN4EI0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8590, '2022-03-14 14:14:41.900569+00', '2022-03-15 00:09:35.714055+00', 5529, 15, 2269, '', 'A', 'Dancing School ''Shady Glen'' From Moscow, Russian Festival Of Scottish Country Dancing, Vladimir, 2014. Here the corners are dancing only for 2 bars in bars 17-24.', 1, 1, 'Y', 'QydQybJFJLc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8588, '2022-03-14 13:43:16.156175+00', '2022-03-15 00:11:27.571898+00', 312, 6, 2269, '', 'B', 'Russia, 2018.  The camera is fairly close to the dancers and off to the men''s side so some of the dancing is out of shot.', 1, 1, 'Y', 'oYJ6wMJsw5g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8591, '2022-03-14 15:31:14.445465+00', '2022-03-15 00:14:39.903297+00', 713, 4, 2269, '', 'D', 'RSCDS Seattle, Fall Ceilidh 2014.', 1, 1, 'Y', 'QF9AgIa9yE4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8598, '2022-03-14 20:43:19.036191+00', '2022-03-15 00:16:30.9869+00', 2484, 8, 2269, '', 'B', '2019 Queen''s Birthday Weekend School in Katikati by a group of Waikato and Bay of Plenty dancers.  



According to the original instructions, only the Women set on bars 27-28 and 31-32. However, a variant description exists that says "All Set".  That is the version used in this video.  That is why this video is not classified as "demonstration quality".', 1, 1, 'Y', 'zNPO_2I6w2E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8597, '2022-03-14 19:18:08.421125+00', '2022-03-15 00:18:07.797418+00', 1280, 13, 2269, '', 'A', 'Charlotte (NC) Scottish Country Dance Society (CSCDS), 2017.  Youngsters twice through.', 1, 1, 'Y', 'lWdVGM2_cgA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8596, '2022-03-14 18:17:03.111045+00', '2022-03-15 00:20:19.747244+00', 1280, 12, 2269, '', 'A', 'Moscow School Of Scottish Dance, Speech School Team "Sinn Araon", 2015.', 1, 1, 'Y', 'VhwijEw1T6U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8592, '2022-03-14 16:30:57.835149+00', '2022-03-15 00:25:20.735539+00', 5555, 5, 2269, '', 'A', 'Airyhall Ladies, Aberdeen Festival, 2018.', 1, 1, 'Y', 'evwD90Vp3g8', 0, 157, NULL);
INSERT INTO 'dancevideo' VALUES (8599, '2022-03-15 00:29:30.43981+00', '2022-03-15 00:38:15.525125+00', 5982, 8, 1645, '', 'A', 'Airyhall Ladies at the Aberdeen Festival 2018.', 1, 1, 'Y', 'evwD90Vp3g8', 159, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8595, '2022-03-14 18:01:50.84811+00', '2022-03-15 14:11:09.826451+00', 1244, 6, 2269, '', 'C', 'Russia, 2018. The camera shows only a partial view of the nearest set.', 1, 1, 'Y', 'Re_3sAYFMBk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8594, '2022-03-14 17:36:08.170522+00', '2022-03-15 14:12:44.964718+00', 2745, 3, 2269, '', 'C', 'Hamilton House, London Reels, 2015.  Teaching video, with spoken and on-screen dancing instructions and a slow motion segment.  There is a tracker at the top of the screen following the progress of the dance.', 1, 1, 'Y', 'fv08FQ9XvZU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8589, '2022-03-14 14:02:38.317647+00', '2022-03-15 14:27:48.646349+00', 7147, 10, 2269, '', 'B', 'Ochil Scottish Country Dancers, St Ninian''s Church Hall, Stirling, Scotland, 2022.  Spoken and on-screen dancing instructions.', 1, 1, 'Y', '8j_35GrjVFg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8600, '2022-03-19 02:40:03.798892+00', '2022-03-19 02:40:03.798892+00', 7161, 1, 1296, '', 'X', '''William Elphinstone'' is a 32 bar strathspey for 5 couples in a 5 couple set.', 1, 1, 'Y', 'QLDMuYF_VZc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8601, '2022-03-19 02:40:03.825159+00', '2022-03-19 02:40:03.825159+00', 7039, 1, 1296, '', 'X', '''Well Met'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', 'nbjz7GDxm6w', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8602, '2022-03-19 02:40:03.871659+00', '2022-03-19 02:40:03.871659+00', 15411, 2, 1296, '', 'X', '''Friendships'' is a 32 bar strathspey for 4 couples in a 4 couple set.', 1, 1, 'Y', 'EsZXtHOec0s', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (2762, '2016-12-18 19:33:08.798032+00', '2022-03-21 22:18:57.441666+00', 13206, 1, 513, '', 'C', 'Münster Christmas Ball, 2016. The instructions for this dance say it may be done as strathspey or reel. Here its done as a strathspey.', 1, 1, 'Y', 'J6tjwDNyoqE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8611, '2022-03-21 20:02:05.63342+00', '2022-03-21 20:39:16.131436+00', 20726, 1, 963, '', 'B', 'Montreal, 2022. Once through.



', 1, 1, 'Y', '3OOkA5blQvc', 0, 62, NULL);
INSERT INTO 'dancevideo' VALUES (8612, '2022-03-21 22:05:51.557618+00', '2022-03-21 22:09:18.445389+00', 20728, 1, 1645, '', 'B', 'RSCDS Leicester at the ASCDS festival 2005. This is part of a longer demo. The last 8 bars (starting at 3:35), which should be a circle and back, are here replaced with promenading to reform for the next dance in the display.', 1, 1, 'Y', '8yEy2VAHfjc', 70, 226, NULL);
INSERT INTO 'dancevideo' VALUES (8613, '2022-03-22 11:26:15.144242+00', '2022-03-22 11:57:45.146683+00', 13132, 1, 1645, '', 'B', 'Tayside Dancers, 2022.', 1, 1, 'Y', 'eGFSI6SzNFs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8614, '2022-03-22 11:33:14.689472+00', '2022-03-22 11:58:18.648401+00', 8931, 1, 1645, '', 'B', 'Tay Dancers, 2022. The original instructions suggest "birl" right hand in bars 21-24. The dancers here do a standard right hand turn.', 1, 1, 'Y', 'LPqQhq5JlGY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8605, '2022-03-19 12:22:24.894223+00', '2022-03-22 19:21:04.637899+00', 5885, 15, 2269, '', 'B', 'RSCDS Helensburgh Weekend Dance, 2017.  Twice through.', 1, 1, 'Y', '06K-hKxbd1o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8606, '2022-03-19 14:33:19.420916+00', '2022-03-22 19:23:29.716418+00', 340, 6, 2269, '', 'A', 'Aberdeen University Scottish Dance Society, Aberdeen Festival, 2018.', 1, 1, 'Y', 'kqwavq-JXgk', 0, 156, NULL);
INSERT INTO 'dancevideo' VALUES (8609, '2022-03-19 15:11:16.869872+00', '2022-03-22 19:25:10.094686+00', 340, 9, 2269, '', 'B', 'Katharine Barber Country Dancers, Kirkcudbright''s Harbour Square, 2018.', 1, 1, 'Y', 'HgRPXGM2g0w', 203, 347, NULL);
INSERT INTO 'dancevideo' VALUES (8610, '2022-03-21 13:00:29.339083+00', '2022-03-22 19:49:30.753315+00', 9800, 8, 2269, '', 'A', 'RSCDS Summer School, Week Three, 2018.  Danced in 3-couple set twice through.  



On the second repeat, as the 1st couple go around each other (bars 21-24), the set chases around half-way in preparation for the next dance in the set.', 1, 1, 'Y', 'uKrIlEnca7I', 10, 109, NULL);
INSERT INTO 'dancevideo' VALUES (8607, '2022-03-19 14:39:11.994169+00', '2022-03-22 19:51:02.123612+00', 340, 7, 2269, '', 'A', 'Glasgow University Mixed Team, Newcastle, 2017.', 1, 1, 'Y', 'xdPWV03pI6M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8608, '2022-03-19 14:45:51.027216+00', '2022-03-22 19:55:59.058308+00', 340, 8, 2269, '', 'A', 'German Team Ladies, Newcastle SCD Festival, 2019.  Minor mishap due to lack of concentration.', 1, 1, 'Y', 'S8A0bNb4Ofc', 0, 148, NULL);
INSERT INTO 'dancevideo' VALUES (8603, '2022-03-19 11:34:07.432484+00', '2022-03-22 19:59:05.606711+00', 4555, 9, 2269, '', 'A', 'RSCDS Stirling, Macrobert Arts Centre, Stirling, Scotland, 2001.  Twice through.', 1, 1, 'Y', 'LdtlT3WPRAc', 225, 355, NULL);
INSERT INTO 'dancevideo' VALUES (8604, '2022-03-19 11:50:44.2944+00', '2022-03-22 23:45:00.341357+00', 4555, 10, 2269, '', 'A', 'Airyhall Girls, Aberdeen Festival, 2018.', 1, 1, 'Y', 'wmjL5175aMc', 0, 273, NULL);
INSERT INTO 'dancevideo' VALUES (8617, '2022-03-22 23:47:52.224355+00', '2022-03-22 23:50:08.546154+00', 9559, 2, 1645, '', 'A', 'Airyhall Girls, Aberdeen Festival, 2018.', 1, 1, 'Y', 'wmjL5175aMc', 275, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8618, '2022-03-24 10:11:45.755013+00', '2022-03-24 10:49:08.481616+00', 17449, 1, 2213, '', 'C', 'Chard Scottish Country Dancers, 2022.', 1, 1, 'Y', 'c-z_3NSJ4vU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8616, '2022-03-22 23:47:06.388225+00', '2022-03-23 00:07:42.536306+00', 20674, 1, 2821, '', 'B', 'Danced by members of the Newark Scottish Country Dance Society on 22 March 2022', 1, 1, 'Y', 'WjlrFvHBcGU', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8615, '2022-03-22 20:23:28.125458+00', '2022-03-23 00:09:58.273248+00', 16838, 3, 2269, '', 'A', 'Charlotte (NC) Scottish Country Dance Society (CSCDS), 2018.  Twice in Strathspey time and once in Reel time.', 1, 1, 'Y', 'cNE06pRJ9R8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7806, '2021-01-31 17:27:01.487142+00', '2022-03-24 22:06:03.569578+00', 17244, 1, 1645, '', 'B', 'Teenagers from the Méaudre Reel Club, France. Twice through. Here the dancers pass right shoulder on bars 7-8 instead of half turning right hand. On the last two bars of the 2nd time the team  change places on the sides instead of setting.', 1, 1, 'Y', 'wfxPeNXvx_8', 253, 319, NULL);
INSERT INTO 'dancevideo' VALUES (8620, '2022-03-26 17:00:15.587845+00', '2022-03-26 23:42:50.728383+00', 20661, 1, 2581, '', 'A', 'Dancing to an upublished CD by Muriel Johnstone. The tunes are :

Barbara''s Favourites - Muriel Johnstone

The Dean Bridge of Edinburgh - Traditional

The Ceilidh Umbrella - Muriel Johnstone

Atholl Palace - Muriel Johnstone



Video made at Winter School 2022 in the Bow Lounge', 1, 1, 'Y', 'I1JR7Kjyatk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8621, '2022-03-28 08:48:03.806063+00', '2022-03-28 08:49:13.750892+00', 1864, 2, 1645, '', 'C', '"Dancers Having fun at the AGM in Glasgow", 2011. Good dancing but constant switching of camera view may make it hard to follow.', 1, 1, 'Y', '2_6PVCGYPrM', 21, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8622, '2022-03-29 11:25:00.073783+00', '2022-03-29 19:52:05.130838+00', 5637, 10, 2269, '', 'B', 'RSCDS NZ Branch, Christchurch Summer School, 2016.  Camera position remains in close shot.', 1, 1, 'Y', 'EGdpYlskjmU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8624, '2022-03-30 20:44:35.92005+00', '2022-03-30 20:48:35.368714+00', 19423, 3, 1645, '', 'C', 'RSCDS Hamiton and Clydesdale, Pitlochry Weekend 2019.', 1, 1, 'Y', 'W-L-DgJlAi4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (6821, '2020-01-24 10:43:51.012292+00', '2022-03-30 20:46:54.009209+00', 19423, 1, 1645, '', 'Z', '[Previously considered] A good demo followed by everyone dancing...

[But now marked Private in youtube].', 1, 1, 'Y', 'pdWskx1RzIo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8623, '2022-03-30 20:43:52.182517+00', '2022-03-30 20:47:39.732854+00', 19423, 2, 1645, '', 'C', 'Hamilton and Clydesdale RSCDS, Pitlochry Weekend 2019.', 1, 1, 'Y', 'S09_Zz9XcJw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8625, '2022-03-30 20:45:59.676534+00', '2022-03-30 20:50:34.279809+00', 19423, 4, 1645, '', 'C', 'Edelwood Dancers Class, Hamilton. Dance being taught at a class. Walked once through with spoken instructions, then danced.', 1, 1, 'Y', 'C90Ejkq5Pcc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8626, '2022-04-03 17:21:19.194843+00', '2022-04-03 17:49:10.167651+00', 20673, 1, 1645, '', 'B', 'Geneva Spring Dance Workshop, Switzerland, 2022. Danced in class: the choreography is clear with one or two little hesitations in places.', 1, 1, 'Y', 'sY6PW-8Mwv0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8648, '2022-04-10 10:57:46.97156+00', '2022-04-10 10:58:32.446385+00', 20321, 1, 202, '', 'B', '', 1, 1, 'Y', 'C2UunVGHoaw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8633, '2022-04-03 18:57:18.54052+00', '2022-04-03 20:28:32.67688+00', 20749, 1, 1645, '', 'B', 'Atholl SCD Club, 2022.', 1, 1, 'Y', 'fG-Odg6RWXw', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8635, '2022-04-03 20:26:20.328728+00', '2022-04-03 20:33:59.069536+00', 424, 1, 1645, '', 'C', 'Geneva Spring Dance Workshop, Switzerland, 2022. The phrasing in this dance is a challenge.', 1, 1, 'Y', 'LGu0gW4Awhw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8632, '2022-04-03 18:16:43.756554+00', '2022-04-05 08:44:42.746144+00', 1445, 1, 1645, '', 'X', '', 1, 1, 'Y', 'USjEGCc34oY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8631, '2022-04-03 18:07:20.241524+00', '2022-04-05 08:45:08.330288+00', 20671, 1, 1645, '', 'C', 'Méaudre Reels, France, 2021. Some troubles with the espagnoles and rondels...', 1, 1, 'Y', 'd6BlIx3Kh14', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8636, '2022-04-05 08:44:27.171907+00', '2022-04-05 08:45:17.001564+00', 20721, 1, 1645, '', 'X', '', 1, 1, 'Y', 'KOakRR5NUSs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8630, '2022-04-03 17:57:47.268139+00', '2022-04-05 08:46:04.946247+00', 14993, 1, 1645, '', 'C', 'Pinewoods, USA, 2014. Last 3 times.', 1, 1, 'Y', 'ZfPDhrf5uCo', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8634, '2022-04-03 20:16:39.313207+00', '2022-04-05 08:47:41.215171+00', 16925, 1, 1645, '', 'C', 'North Kessock, 2017. With lots of birling in the corner chains.', 1, 1, 'Y', 'u4lN88sFxeI', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8629, '2022-04-03 17:48:30.037975+00', '2022-04-05 08:49:16.612851+00', 20673, 3, 1645, '', 'C', 'Méaudre Reel, France, 2021.', 1, 1, 'Y', 'rfZ58PNgPw4', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8627, '2022-04-03 17:30:33.023019+00', '2022-04-05 08:49:39.305211+00', 20673, 2, 1645, '', 'C', 'Méaudre Reels, France, 2022. Some problems at the beginning, improving towards the end.', 1, 1, 'Y', 'RrXPZ38SDa8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8628, '2022-04-03 17:35:21.368578+00', '2022-04-05 08:50:12.572705+00', 20672, 1, 1645, '', 'C', 'Méaudre Reels, France, 2021.', 1, 1, 'Y', 'NP_U-ifNNXE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8639, '2022-04-09 00:40:02.71948+00', '2022-04-09 00:40:02.71948+00', 16526, 4, 1296, '', 'X', '''Miss Eleanor'' is a 32 bar strathspey for 3 couples in a 3 couple set.', 1, 1, 'Y', 'QSucF7dCKlE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8641, '2022-04-09 00:40:02.776107+00', '2022-04-09 00:40:02.776107+00', 5444, 1, 1296, '', 'X', '''Quincentenary Reel, The'' is a 32 bar reel for 4 couples in a 4 couple set.', 1, 1, 'Y', 'ezo53w3dDbM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8642, '2022-04-09 00:40:02.796077+00', '2022-04-09 00:40:02.796077+00', 13582, 6, 1296, '', 'X', '''Valentine, The'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', 'NkC0IQeefbY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8643, '2022-04-09 00:40:02.824968+00', '2022-04-09 00:40:02.824968+00', 12635, 3, 1296, '', 'X', '''We''ve Nae Electric'' is a 32 bar reel for 5 couples in a 5 couple set.', 1, 1, 'Y', 'wJm-YCkWznA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8645, '2022-04-09 09:43:15.487241+00', '2022-04-09 09:44:45.424536+00', 5252, 2, 1645, '', 'X', '', 1, 1, 'Y', 'xNL3l4wtZqs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8638, '2022-04-08 12:44:07.678756+00', '2022-04-09 09:46:14.223181+00', 6375, 1, 274, '', 'B', 'Budapest Scottish Dance Club, 07.04.2022', 1, 1, 'Y', 'mnRoGXAt0UE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8649, '2022-04-10 11:00:24.220651+00', '2022-04-10 11:00:41.82569+00', 848, 3, 202, '', 'C', '', 1, 1, 'Y', 'Fjt_RnDPiJo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8637, '2022-04-05 18:19:00.861487+00', '2022-04-09 09:49:37.28721+00', 4890, 7, 2269, '', 'B', 'Hood Canal Highland Celtic Festival, Belfair WA ~ RSCDS Southwest Washington State Branch, 2014. Well danced but less good audio quality.', 1, 1, 'Y', 'L4DODtiSn-o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8644, '2022-04-09 09:36:09.036654+00', '2022-04-09 09:49:54.001053+00', 12696, 1, 1645, '', 'B', 'Méaudre Reel (children, level 3) 2021. Clear performance most of the way through.', 1, 1, 'Y', 'vZeK3eeou7E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8640, '2022-04-09 00:40:02.751102+00', '2022-04-10 00:40:03.250861+00', 4565, 4, 1296, '', 'Z', '''Miss Ogilvie''s Fancy'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', 'P02_shjV6t4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8647, '2022-04-10 00:40:03.25922+00', '2022-04-10 00:40:03.25922+00', 4565, 5, 1296, '', 'X', '''Miss Ogilvie''s Fancy'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', 'C2YD2-jYKQQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8651, '2022-04-10 11:05:30.210369+00', '2022-04-10 11:07:09.180952+00', 16046, 2, 202, '', 'C', '', 1, 1, 'Y', 'fb9Fv7xlz00', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8650, '2022-04-10 11:04:19.1737+00', '2022-04-10 11:07:23.459142+00', 19307, 3, 202, '', 'C', '', 1, 1, 'Y', 'Fm_1NRaD_2U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8652, '2022-04-10 11:06:45.555778+00', '2022-04-10 11:07:42.319222+00', 19803, 1, 202, '', 'C', '', 1, 1, 'Y', '9176wvkyz9g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8653, '2022-04-10 11:09:20.450266+00', '2022-04-10 11:09:32.990394+00', 5239, 11, 202, '', 'C', '', 1, 1, 'Y', 'sn4etkvLL00', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1662, '2014-05-06 19:58:18.955431+00', '2022-04-10 17:20:29.828386+00', 14598, 1, 1041, '', 'B', 'Berkhamsted Strathspey & Reel Club. This 4x40 strathspey was here danced twice through to represent George’s Eightieth birthday.



Filmed by Pete Williamson in Potten End Village Hall on 24th April 2012. The dancers taking part were:  

First couple: Keith Anderson & Joan Desborough  

Second couple: Stephen Webb (deviser) & Patricia Steed  

Third couple: Brian & Jane Rose  

Fourth couple: Ken & Jan Halse

', 1, 1, 'Y', '83w6RmFoYMU', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8646, '2022-04-09 10:05:30.054131+00', '2022-04-12 19:20:34.645477+00', 20513, 1, 1645, '', 'D', 'Méaudre Reel 2021. Shows the revised version of the dance. There are some problems with the Rose and transitions, also a few short cuts here and there.', 1, 1, 'Y', '7VKCUTnGTtI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8654, '2022-04-12 15:24:56.956327+00', '2022-04-12 19:24:49.912233+00', 18307, 1, 3097, '', 'A', 'South East Herts Scottish Country Dance Society Spring Dance 2022.  Dancing to Chris Oxtoby of Strathallan.', 1, 1, 'Y', 'ZtbrDz49qmM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8657, '2022-04-15 20:50:55.467478+00', '2022-04-15 20:50:55.467478+00', 1843, 2, 2220, 'dd/dance/video/upload/Dunfermline_Glen.mp4', 'B', 'San Francisco Class April 2022', 0, 0, 'I', '', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8655, '2022-04-13 09:11:50.400662+00', '2022-04-17 23:01:11.923459+00', 13581, 8, 2269, '', 'A', 'Alba Kelvin Team, Newcastle Festival, 2015.', 1, 1, 'Y', 'R0g4K6nW5tQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8659, '2022-04-17 22:47:49.005438+00', '2022-04-17 23:02:30.440541+00', 13001, 2, 1645, '', 'B', 'Aberdeen RSCDS Tartan Week 2011.', 1, 1, 'Y', 'pCE2eqy3V-A', 1089, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8658, '2022-04-17 21:23:52.430239+00', '2022-04-18 07:44:07.984244+00', 17975, 1, 963, '', 'B', 'Middle of three repeats. The camera leaves for a couple of bars to show the musicians (Heather Cameron on fiddle, Kathy Fraser-Collins on piano and Fred Collins on drums).', 1, 1, 'Y', 'AGHY3Ejg-3Q', 240, 330, NULL);
INSERT INTO 'dancevideo' VALUES (2112, '2015-07-04 20:02:23.565063+00', '2022-04-18 21:52:26.38979+00', 5065, 2, 1041, '', 'Z', 'Was classed Reasonable, now seems to be unavailable.', 1, 1, 'Y', 'GNEzAz8kths', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8660, '2022-04-17 22:59:35.292178+00', '2022-04-18 22:06:05.287462+00', 9817, 2, 1645, '', 'B', 'Aberdeen RSCDS Tartan Week 2011. Twice through as the first part of a longer display.', 1, 1, 'Y', 'pCE2eqy3V-A', 817, 889, NULL);
INSERT INTO 'dancevideo' VALUES (8662, '2022-04-18 21:51:02.265869+00', '2022-04-18 22:06:32.816523+00', 9986, 1, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', '9NIGBiEZfQ8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8665, '2022-04-18 22:05:17.05189+00', '2022-04-18 22:06:43.55501+00', 11538, 1, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'WRzWiK5SAGw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8664, '2022-04-18 22:02:19.697063+00', '2022-04-18 22:07:05.011878+00', 12669, 4, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', '8sGPl0Fsm0c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8663, '2022-04-18 21:57:06.232769+00', '2022-04-18 22:07:24.294748+00', 5065, 4, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'SRr8QdYIIy0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8666, '2022-04-19 00:40:03.343204+00', '2022-04-19 00:40:03.343204+00', 428, 4, 1296, '', 'X', '''Bauldy Bain''s Fiddle'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'xCG_Pq1EJnI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8667, '2022-04-19 00:40:03.361071+00', '2022-04-19 00:40:03.361071+00', 2501, 4, 1296, '', 'X', '''Glasgow Lasses'' is a 32 bar strathspey for 2 couples in a 4 couple set.', 1, 1, 'Y', '96IpLo7GhsE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8668, '2022-04-19 00:40:03.374591+00', '2022-04-19 00:40:03.374591+00', 4931, 2, 1296, '', 'X', '''New Scotland Strathspey, The'' is a 40 bar strathspey for 4 couples in a 4 couple set.', 1, 1, 'Y', 'gjLHPpJRW7s', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8669, '2022-04-19 00:40:03.388792+00', '2022-04-19 00:40:03.388792+00', 6964, 10, 1296, '', 'X', '''Silver Strathspey, The'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', 'ZpjEq_SHLaQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8670, '2022-04-19 00:40:03.403009+00', '2022-04-19 00:40:03.403009+00', 7019, 4, 1296, '', 'X', '''Welcome to Dufftown'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', '864ez249RMQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8671, '2022-04-26 07:55:28.598565+00', '2022-04-28 15:07:20.877331+00', 6585, 4, 1645, '', 'A', 'Deer O''Dale Dance School, Ufa, 2022.', 1, 1, 'Y', 'b9U975z4PW8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8680, '2022-04-27 20:33:02.045662+00', '2022-04-28 15:09:36.540799+00', 4796, 6, 2269, '', 'A', 'Airyhall Ladies, Newcastle RSCDS Festival, 2017.', 1, 1, 'Y', 'zxSIg2-jgWw', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8681, '2022-04-27 20:40:35.447851+00', '2022-04-28 15:11:18.668929+00', 4796, 7, 2269, '', 'B', 'RSCDS Stirling, 2018.  On-screen and spoken dancing instructions.  Slow-motion segment.', 1, 1, 'Y', 'qCGsdIAN_Xg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8677, '2022-04-27 13:06:44.336363+00', '2022-04-28 15:14:44.218418+00', 10306, 5, 2269, '', 'C', 'RSCDS Hamilton And Clydesdale, Winter Dance, 2017.', 1, 1, 'Y', 'A2tnfX8k2MQ', 2037, 2170, NULL);
INSERT INTO 'dancevideo' VALUES (8675, '2022-04-27 10:56:09.144+00', '2022-04-28 15:20:50.095948+00', 19362, 1, 1330, '', 'A', 'The dance would normally be danced three times through, but here it is danced four times through because of the music used to make the video. (The deviser''s suggested lead tune of Loch Lomond was not available as a S3x40 recording)', 1, 1, 'Y', 'k0x7TqHFDMo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8682, '2022-04-28 08:50:44.904575+00', '2022-04-28 21:55:47.768396+00', 10788, 2, 2269, '', 'D', 'OTTB, Ruhr, Germany, 2019.  The music is fast and the dancers have fun – the fourth  couple swap sides in the Poussette on the first time through.', 1, 1, 'Y', 'Ky7lN6xsX38', 0, 150, NULL);
INSERT INTO 'dancevideo' VALUES (8661, '2022-04-18 21:27:03.944846+00', '2022-04-29 16:57:10.895834+00', 20772, 1, 1645, '', 'C', 'Dundee U3A Scottish Dance Class, 2022.', 1, 1, 'Y', 'niqshYOhOA0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8679, '2022-04-27 15:07:30.658602+00', '2022-04-30 09:49:23.947181+00', 1426, 3, 2269, '', 'D', 'RSCDS Twin Cities, Minnesota Renaissance Festival (Preview Event), 2014.  Crom Alltered.  Note: that bars 9-16 are modified to make the progression suitable for a 3-couple repeat in a 3-couple set.  The dancing is pretty good, but the video is downgraded due to the previous comment.', 1, 1, 'Y', 'aCtz0WMXexU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8678, '2022-04-27 14:48:28.269796+00', '2022-04-30 09:54:14.267671+00', 9084, 8, 2269, '', 'B', 'Scottish Party At The Festival "The Breath Of Siberia", Tomsk, Russia, 2017.', 1, 1, 'Y', 'DFWISxUItP4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8673, '2022-04-27 08:55:58.442494+00', '2022-04-30 09:56:15.128139+00', 2979, 6, 2269, '', 'D', 'RSCDS NZ Branch Christchurch Summer School 2016/17.  The mid-section descends into a bit of a muddle – there''s not much thinking time.  When the 4th couple dance bars 1-16 the give hands when they cross, the instruction just say cross – no mention of taking hands.', 1, 1, 'Y', '4f9otw9OEnM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8674, '2022-04-27 09:09:28.214523+00', '2022-04-30 09:57:26.227849+00', 2979, 7, 2269, '', 'B', 'RSCDS Toronto''s Volunteer Appreciation Dance, 2017.  One very small mis-step, quickly corrected right at the end of the dance', 1, 1, 'Y', 'da3y6mgwhCQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8676, '2022-04-27 12:51:27.708457+00', '2022-04-30 09:59:06.961109+00', 2979, 8, 2269, '', 'B', 'Wellington, New Zealand, 2016.', 1, 1, 'Y', 'cxhau6JlYzI', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8684, '2022-05-02 10:19:05.17652+00', '2022-05-07 08:20:50.712862+00', 819, 2, 2269, '', 'C', 'Katharine Barber Country Dancers, Kirkcudbright Scottish Night, 2018.  Danced in a 5-couple set, with modification to permit the dancing couple to dance to the foot.  On bars 9-16 the dancers take nearer hands, whereas the instructions have lead back up.', 1, 1, 'Y', 'ipJwy4KGIak', 174, 313, NULL);
INSERT INTO 'dancevideo' VALUES (8686, '2022-05-06 09:35:35.733712+00', '2022-05-07 08:24:58.371987+00', 819, 3, 2824, '', 'C', 'St Giles SCD club, 2018.', 1, 1, 'Y', 'RvVRC1kSY0k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8685, '2022-05-05 14:05:56.709788+00', '2022-05-07 08:27:56.602858+00', 19875, 1, 963, '', 'B', '', 1, 1, 'Y', '84YZYUCL67E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8683, '2022-04-30 09:52:27.624987+00', '2022-05-07 08:29:18.259291+00', 373, 7, 1645, '', 'C', 'RSCDS Twin Cities Fàilte Ball, 2015.', 1, 1, 'Y', '9sBq6mOWA9Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8691, '2022-05-08 21:05:07.933754+00', '2022-05-08 22:35:57.453084+00', 14991, 4, 2220, '', 'B', 'Danced in San Francisco April 2022.Start Your Engines was devised in 2012 by Ellen Ternes of Frederick, Maryland, commemorating the life and career of world-famous Scottish race-car driver Dario Franchitti.  It is published in a 2015 book named StrathsBabes which includes dances of hers and fellow deviser Pam Stephens, the latter whose Memories of Mary Ann (S32) was published by the RSCDS in its 2013 Book 47.  The SCDDB lists eleven dances by her, the majority in the aforementioned publication.

 

Dario Franchitti was born in 1973 in Bathgate, West Lothian, (today somewhat an Edinburgh outer suburb, pop. 23,600, just a twenty-mile drive to the west from its city center).  He is a former race-car driver and now a motor-sports commentator, four-time IndyCar Series champion (2007-2011 except 2008), three-time Indianapolis 500 winner, and the 2008 winner of the "24 Hours of Daytona."  He was married to American actress Ashley Judd from 2001 to 2013 and now married to Englishwoman Eleanor Robb, and they have two young daughters born in 2015 and 2019.  Dario Franchitti may now use the suffix MBE with his name having been named a Member of the Order of the British Empire by Queen Elizabeth among her Birthday Honours of 2014....



In this performance only 1st couple turn RH in bars 21-24 though the instructions suggest all three couples should turn.

 ', 1, 1, 'Y', 'E90GS6fXmRo', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8690, '2022-05-08 13:13:30.039507+00', '2022-05-08 22:41:56.668023+00', 2722, 2, 2821, '', 'A', 'Members of the Waltham Scottish Country Dance Group dancing at the 40th ASCDS Dance Festival in Retford, 07 May 2022.', 1, 1, 'Y', 'EQYrAUqQTfM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8688, '2022-05-07 18:09:16.355921+00', '2022-05-08 22:43:17.159312+00', 13465, 3, 2269, '', 'C', 'Manawatu SCD Club, NZ, May 2015.', 1, 1, 'Y', 'yC3kvRPJbns', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8689, '2022-05-07 18:25:15.62749+00', '2022-05-08 22:44:17.071074+00', 3365, 8, 2269, '', 'A', 'Edinburgh Scottish Country Dancers, 2018.', 1, 1, 'Y', '2hut7QDit7M', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8687, '2022-05-07 08:20:32.668296+00', '2022-05-08 22:45:22.867647+00', 3980, 8, 1645, '', 'B', 'Katharine Barber Country Dancers, Kirkudbright, 2018. Four times through (here danced in a 5 couple set).', 1, 1, 'Y', 'ipJwy4KGIak', 25, 165, NULL);
INSERT INTO 'dancevideo' VALUES (8692, '2022-05-08 22:48:40.699034+00', '2022-05-08 22:54:39.223249+00', 20780, 1, 1330, '', 'B', 'One person (a relative beginner) makes a mistake in the fourth repetition of the dance during the Rights and Lefts, but no-one panics and the dance just flows on - brilliant! ', 1, 1, 'Y', 'puBnWa2EnLY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8693, '2022-05-09 18:45:39.265838+00', '2022-05-09 21:13:19.364055+00', 1615, 6, 2269, '', 'A', 'Lyon Ladies 2, Newcastle Festival, 2017.  ', 1, 1, 'Y', '0UN3N_hsX5w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8695, '2022-05-10 19:29:06.580284+00', '2022-05-11 22:11:55.451578+00', 20800, 1, 2630, '', 'C', 'Bars 13 - 16  1s and 3s both turn, or birl to place', 1, 1, 'Y', 'K9u-5h-3jps', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8696, '2022-05-10 19:31:32.190375+00', '2022-05-11 22:14:20.643123+00', 20797, 1, 2630, '', 'B', 'This clip shows once through (though the whole video continues for another few bars).', 1, 1, 'Y', 'XOkUyVQyqX0', 0, 39, NULL);
INSERT INTO 'dancevideo' VALUES (8697, '2022-05-10 19:37:10.508535+00', '2022-05-11 22:18:54.157777+00', 20798, 1, 2630, '', 'B', '', 1, 1, 'Y', 'qivIU7cP2xI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8699, '2022-05-10 19:39:41.956306+00', '2022-05-11 22:20:42.78801+00', 20801, 1, 2630, '', 'B', 'Twice through.', 1, 1, 'Y', 'apCy8hxQ2Jo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8698, '2022-05-10 19:38:14.376666+00', '2022-05-11 22:23:34.91435+00', 20799, 1, 2630, '', 'B', 'Twice through.', 1, 1, 'Y', 'scsRud_U4mE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8700, '2022-05-11 08:35:25.903564+00', '2022-05-11 22:26:35.414241+00', 19188, 1, 1330, '', 'B', 'Danced once through. Note that the music used in this video (being music for the dance, The Quaich, played by  Hanneke  Kassel and Dave Wiesler) is not the suggested music.

', 1, 1, 'Y', 'ISkJSTQq0HQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8739, '2022-05-21 17:20:14.672576+00', '2022-05-23 07:50:21.763807+00', 9106, 7, 2269, '', 'C', 'Russia, 2018.', 1, 1, 'Y', 'iD5Y__WtkwQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8702, '2022-05-11 18:47:12.486477+00', '2022-05-24 21:40:38.788954+00', 16191, 3, 223, '', 'A', 'Potters Pairs Weekend in Oberlethe 2022. Twice through, just once each couple so two couples are dancing to the bottom at the start instead of just one.', 1, 1, 'Y', 'c8ikdnt_e1k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9080, '2022-10-23 23:07:13.202403+00', '2022-10-23 23:07:30.313387+00', 21149, 1, 1645, '', 'B', 'London Gay Gordons & Friends, 2022.', 1, 1, 'Y', 'G8C-0BZ1hf8', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9191, '2023-01-05 18:37:42.740268+00', '2023-01-05 18:43:38.060228+00', 13365, 2, 1645, '', 'B', 'SCD group Hong Kong, 2022. Once through.', 1, 1, 'Y', 'qtuQDkXmV2Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8694, '2022-05-10 18:58:56.47385+00', '2022-05-11 22:16:32.60191+00', 12793, 9, 274, '', 'C', 'Budapest Scottish Dance Club

Caledonian Pub, Burns Night, Budapest, Jan 26, 2014

Live music: Greenfields band

', 1, 1, 'Y', 'LI3Iku0B62M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8704, '2022-05-12 19:14:00.906668+00', '2022-05-12 21:53:51.837239+00', 10380, 1, 2954, '', 'A', '', 1, 1, 'Y', 'ev6dVriO_mQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8708, '2022-05-14 08:32:45.485814+00', '2022-05-15 08:33:52.959313+00', 674, 5, 2824, '', 'D', 'Social Dance by Deepdene Scottish Country Dancers/Melbourne on 14.12.2019', 1, 1, 'Y', 'cXdBOW2Uusw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8703, '2022-05-12 16:34:13.464559+00', '2022-05-15 08:37:45.289971+00', 4424, 4, 2269, '', 'A', 'Airyhall Dancers Display Team, Newcastle RSCDS Festival, 2014.', 1, 1, 'Y', 'ZVmx3qNLulg', 110, 146, NULL);
INSERT INTO 'dancevideo' VALUES (8706, '2022-05-13 15:22:43.27038+00', '2022-05-15 08:39:46.192947+00', 11189, 15, 2269, '', 'B', 'Singapore St Andrew''s Society, Girls'' Team 2 (Younger), 2008.', 1, 1, 'Y', 'm1foFW7eAVE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8705, '2022-05-13 14:32:40.107173+00', '2022-05-15 08:41:35.718251+00', 6734, 7, 2269, '', 'B', 'RSCDS Edinburgh Branch Demonstration Team, Dancing Forth, 2009.  Two sets back-to-back.  Once through (with the end of the allemande adapted to lead into the next dance in the demonstration).



Dancing is Demonstration quality, however video downgraded, since in bars 17-24 the dancers pass right shoulder in the middle, while the instructions have left shoulder.', 1, 1, 'Y', 'FPuQiMBz91A', 992, 1035, NULL);
INSERT INTO 'dancevideo' VALUES (8711, '2022-05-15 12:03:40.112341+00', '2022-05-15 13:05:06.819119+00', 4424, 5, 2269, '', 'B', 'RSCDS Spring Fling, Bonn, 2017.  Almost twice through (last 4 bars missing).', 1, 1, 'Y', 'tceD3pslIyM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8713, '2022-05-15 14:05:25.611575+00', '2022-05-15 14:06:01.878923+00', 5209, 14, 202, '', 'C', '', 1, 1, 'Y', 'AijKuPfXXZA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8712, '2022-05-15 12:19:06.602555+00', '2022-05-15 17:48:34.546768+00', 4424, 6, 2269, '', 'A', 'RSCDS Edinburgh Branch Demonstration Team, Dancing Forth, 2011.  Modified lead-in to the dance and adaptions for 3-couple set.  Two sets back-to-back and the sets swirl around to position the sets across rather than length-wise prior to the next dance in the set.', 1, 1, 'Y', '24nV-BONEV8', 0, 108, NULL);
INSERT INTO 'dancevideo' VALUES (8619, '2022-03-25 18:42:46.739532+00', '2022-05-15 18:37:04.21998+00', 20049, 1, 105, '', 'B', 'Kathy''s Fascinator is a Scottish Country Dance devised by Lydia Hedge to celebrate Kathy Warren''s love of dance and friendship. It''s a jig and is danced here by some of Kathy''s friends in the RSCDS Nova Scotia branch in Halifax. The wonderful music is by Muriel Johnstone. The tunes are called "Kathy''s Fascinator" and "The Halifax Treasure".', 1, 1, 'Y', 'Cjk94RQyk2o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8715, '2022-05-15 18:30:40.451913+00', '2022-05-15 23:07:48.776185+00', 12516, 1, 105, '', 'B', 'Sharon’s Strathspey is a Scottish Country Dance devised by John Drewry for Sharon Brannon. It was first published in New Dances by John Drewry 2005, and reprinted in Spark O’ Water, Dances of Nova Scotia in 2017. The tunes by Muriel Johnstone are Mira River; Eric’s Return to Tine; The Iceberg; Anne Carter’s Fancy. The dance was performed by the Thistle Scottish Country Dancers in Halifax, Nova Scotia, in May 2022.', 1, 1, 'Y', '9bFfMBVnKm4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8722, '2022-05-17 13:33:06.517047+00', '2022-05-17 15:54:36.595154+00', 1492, 5, 2269, '', 'B', 'Oxford And Cambridge Highland Ball, Cambridge, 2018. 

Music By Keith Smith And Anne-Laure La Tour.', 1, 1, 'Y', 'vEr4KMsLdy0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8721, '2022-05-17 13:05:43.774161+00', '2022-05-17 15:57:22.077419+00', 1492, 4, 2269, '', 'C', '15th Annual Bluebonnet Ball, San Antonio, Texas, 2012.  The music is fast and the dancers mostly keep up.  Sometime dancers take right hand in right hand, when the instructions have nearer hands.  Good elevated camera position.  Last dance on the programme.', 1, 1, 'Y', '-iaWUrGDIHg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8716, '2022-05-16 08:39:54.560165+00', '2022-05-18 22:36:04.098481+00', 2267, 13, 2269, '', 'A', 'RSCDS Belfast, 2016.  Camera in a good elevated position.  Clothing worn by dancers makes for easy identification of the couples.', 1, 1, 'Y', 'FuxJF3UV4bY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8717, '2022-05-16 12:04:01.225459+00', '2022-05-18 22:37:24.908632+00', 3323, 6, 2269, '', 'C', 'Toronto RSCDS''s Happy And Glorious Tea Dance, 2016.', 1, 1, 'Y', 'JGzII_P-PUI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8720, '2022-05-17 08:43:51.648805+00', '2022-05-18 22:39:17.567631+00', 5006, 8, 2269, '', 'A', 'Airyhall Dancers, Newcastle, 2020.  Same dance as Video 4, closer perspective.', 1, 1, 'Y', 'rZ93lWXfmb4', 337, 491, NULL);
INSERT INTO 'dancevideo' VALUES (8718, '2022-05-17 07:43:21.001535+00', '2022-05-18 22:39:59.263583+00', 5006, 6, 2269, '', 'A', 'Airyhall Ladies, Newcastle SCD Festival, 2017.', 1, 1, 'Y', 'iNeSKpMpRaY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8723, '2022-05-17 15:46:54.757441+00', '2022-05-18 22:41:17.711911+00', 6152, 5, 2269, '', 'B', 'Red Thistle Dancers, Pleasanton Highland games, 2018.  Dancing is demonstration quality, video is downgrade as danced twice through in a 3-couple set, with the ending, first time through, modified to cater for the 3-couple set.', 1, 1, 'Y', 'JoLIQMCBeYc', 250, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8719, '2022-05-17 08:30:00.839629+00', '2022-05-18 22:42:02.200022+00', 5006, 7, 2269, '', 'A', 'Newcastle RSCDS Ladies, Newcastle SCD Festival, 2017.', 1, 1, 'Y', '02OzTWpuj2U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8725, '2022-05-18 09:46:18.849024+00', '2022-05-18 22:42:21.554683+00', 11763, 1, 1645, '', 'A', 'Strictly Scottish (RSCDS Vancouver) , 2022. Twice through.', 1, 1, 'Y', '0x7CDhzbGWc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8726, '2022-05-18 09:49:13.840811+00', '2022-05-18 22:42:58.0252+00', 15587, 2, 1645, '', 'A', 'Strictly Scottish (RSCDS Vancouver), 2022. Twice through.', 1, 1, 'Y', 'i1oWS3_eBRA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8727, '2022-05-18 09:52:26.295959+00', '2022-05-18 22:43:28.430234+00', 10066, 1, 1645, '', 'A', 'Strictly Scottish (RSCDS Vancouver) , 2022. Twice through.', 1, 1, 'Y', 'I_CiBNm1DB8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8724, '2022-05-18 09:41:44.984681+00', '2022-05-18 22:43:58.77248+00', 12450, 2, 1645, '', 'A', 'Strictly Scottish (RSCDS Vancouver) , 2022. Twice through.', 1, 1, 'Y', 'O2TwurqIFiU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8728, '2022-05-19 12:55:30.631532+00', '2022-05-19 22:48:06.39255+00', 14350, 1, 105, '', 'B', 'Spice It Up is a Scottish Country Dance devised by Merrill Heubach. It was first published in Eight by 32, and reprinted in Spark O’ Water, Dances of Nova Scotia in 2017. The music is by Muriel Johnstone and Keith Smith. The tunes are The Nova Scotia; Anselm Lingnau; The Three Bernadettes. The dance was performed by the Thistle Scottish Country Dancers in Halifax, Nova Scotia, in May 2022.', 1, 1, 'Y', '2tQRZ7Ca0j8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8730, '2022-05-19 22:41:30.189354+00', '2022-05-19 22:48:28.6605+00', 16525, 9, 1645, '', 'A', 'Nottingham RSCDS at the ASCDS Festival 2022. The last part of a longer demo.', 1, 1, 'Y', 'C7ofVMUFcQo', 175, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8729, '2022-05-19 22:39:15.813604+00', '2022-05-19 22:49:02.193118+00', 13766, 3, 1645, '', 'A', 'Nottingham RSCDS at the ASCDS Festival 2022. Twice through as the first part of a longer demo.', 1, 1, 'Y', 'C7ofVMUFcQo', 51, 175, NULL);
INSERT INTO 'dancevideo' VALUES (8731, '2022-05-19 22:46:40.268699+00', '2022-05-19 22:49:57.982559+00', 19929, 1, 1645, '', 'B', 'Hong Kong SCD group 2022. Twice through.', 1, 1, 'Y', 'EXl1MGun4IE', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8733, '2022-05-20 18:23:07.500369+00', '2022-05-20 18:23:24.580928+00', 20733, 1, 202, '', 'D', '', 1, 1, 'Y', 'tKMtyfr4oxs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8737, '2022-05-20 21:41:08.921123+00', '2022-05-20 21:47:04.617519+00', 20390, 1, 1645, '', 'B', 'Stonnington Scottish Country Dancers, Melbourne, Australia 2022. Danced five times, then from 3:00 once again with subtitle instructions. The youtube video comments give the full instructions.', 1, 1, 'Y', 'LevT8F2TXpM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8734, '2022-05-20 20:00:54.973012+00', '2022-05-21 07:42:57.720876+00', 19806, 1, 1645, '', 'C', 'Nottingham Scottish Association at the ASCDS Festival 2022. Four times through.', 1, 1, 'Y', 'B4DTzv2L2uo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8736, '2022-05-20 21:30:20.35863+00', '2022-05-21 07:46:50.007607+00', 20862, 1, 1645, '', 'B', 'Leicester RSCDS at the ASCDS Festival, 2022. Twice through as the last part of a longer display.', 1, 1, 'Y', '3HHXF02_QaA', 149, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8735, '2022-05-20 21:30:15.367466+00', '2022-05-21 07:45:59.856888+00', 20861, 1, 1645, '', 'B', 'Leicester RSCDS at the ASCDS Festival, 2022. Twice through as the first part of a longer display with a slight adaptation to end in a longwise set.', 1, 1, 'Y', '3HHXF02_QaA', 0, 150, NULL);
INSERT INTO 'dancevideo' VALUES (8738, '2022-05-21 13:12:18.223368+00', '2022-05-23 07:56:10.606382+00', 9106, 6, 2269, '', 'A', 'RSCDS Stirling, 2001. Once through with the last bar adapted to end in a square set.', 1, 1, 'Y', 'LdtlT3WPRAc', 3407, 3471, NULL);
INSERT INTO 'dancevideo' VALUES (8707, '2022-05-13 15:58:28.640904+00', '2023-01-21 13:14:38.955948+00', 445, 15, 2269, '', 'Z', 'Russia, 2018.  Dancing with flourish.  Minor confusion near the end corrected.



Was Good, now unavailable.', 1, 1, 'Y', 'OCwGVlRB7O4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8743, '2022-05-23 04:47:29.73465+00', '2022-05-23 04:53:16.923632+00', 10247, 1, 202, '', 'D', '', 1, 1, 'Y', 'kyyl5_oxJeg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8744, '2022-05-23 04:50:20.64384+00', '2022-05-23 04:53:50.613273+00', 10791, 1, 202, '', 'D', '', 1, 1, 'Y', 'JF5qrjTGR7M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8741, '2022-05-23 01:12:15.540681+00', '2022-05-23 07:43:50.053184+00', 1961, 2, 30508, '', 'B', '2 repetitions

Northern Virginia Branch Snowdrop Dance, April 2, 2022

Musicians:  Terpsichore - Elke Baker, fiddle and Liz Donaldson, piano

Ellie''s Jig by Murray Shoolbraid

Miss Ann Monro by Robert Mackintosh

All the Rage by Larry Unger (a small bit at the end of the video)', 1, 1, 'Y', 'Z9UjTiI1ikk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8732, '2022-05-19 23:07:11.202441+00', '2022-05-23 07:46:00.763581+00', 10820, 3, 1645, '', 'B', '"Reflection" Dance School, 2022. Eight times through! Clear view from above. For the advance and retire the couples here take nearer hands rather than promenade hold.', 1, 1, 'Y', 'ckl4aDL8_rM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8742, '2022-05-23 01:12:36.146225+00', '2022-05-23 07:48:39.879952+00', 19138, 2, 30508, '', 'B', 'Northern Virginia Branch Snowdrop Dance, April 2, 2022

Musicians:  Terpsichore - Elke Baker, fiddle and Liz Donaldson, piano

Tunes: 

Panmure Gardens by Marian Anderson

Peter Barnes'' Trip to Skye by Barbara McOwen

Calum''s Road by Donald Shaw', 1, 1, 'Y', 'lSafdf-9tkM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8740, '2022-05-21 17:44:54.691881+00', '2022-05-23 07:57:22.115335+00', 9559, 3, 2269, '', 'C', '55th Tartan Ball, Toronto, 2018.  Reprise of the dance – once through each couple.', 1, 1, 'Y', 'dyHXRiHVYbA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8745, '2022-05-23 08:20:59.672933+00', '2022-05-23 08:22:16.937064+00', 3133, 1, 1645, '', 'B', 'SCD group Hong Kong, 2022. Once through with both top two and bottom two couples dancing.', 1, 1, 'Y', 'phm3696MvYY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8746, '2022-05-23 13:00:54.939553+00', '2022-05-23 17:44:40.794738+00', 1843, 3, 2824, '', 'B', 'Video clip shows the dance three times through, danced in a 4cpl. set', 1, 1, 'Y', 'x5Tju9xpM7A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1428, '2013-09-25 08:50:46.291489+00', '2022-05-23 17:56:55.12075+00', 6712, 6, 274, '', 'Z', 'St. Andrew''s Day Ceilidh, Budapest, 2012;

Performed by the Budapest Scottish Dance Club



First few bars missing. Four times through.



Now removed or private, was DemQuality.', 1, 1, 'Y', '3bXI78THD3I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8747, '2022-05-24 12:50:38.715986+00', '2022-05-24 17:57:56.877977+00', 14679, 4, 2269, '', 'A', 'Budapest Scottish Dance Club, St Andrew''s Day Ceilidh, 2014.  The men progress by dancing right hand 3/4 to face a new lady, which is not in the original instructions.', 1, 1, 'Y', 'vk7rPZ9v--Y', 39, 140, NULL);
INSERT INTO 'dancevideo' VALUES (8748, '2022-05-24 13:01:02.289208+00', '2022-05-24 17:59:00.877871+00', 14679, 5, 2269, '', 'C', 'RSCDS Toronto, 2019.  A simple variation on a traditional dance, Orkney style.', 1, 1, 'Y', 'VGvpv-1-dxo', 21, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8750, '2022-05-25 13:32:15.936958+00', '2022-05-25 17:22:29.215125+00', 17802, 1, 105, '', 'B', 'Bill and Rajeev’s Wedding Jig is a Scottish Country Dance devised by Suzanne Lajoie. It was published in Spark O’ Water, Dances of Nova Scotia in 2017. The tunes are The Island of Mull; Dougal Campbell Esq. of Ballinby’s Jig; Dr. James Hamilton’s Reel. The dance was performed by the Thistle Scottish Country Dancers in Halifax, Nova Scotia, in May 2022.

', 1, 1, 'Y', 'cfaf4jvYifc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8749, '2022-05-25 13:31:12.100517+00', '2022-05-25 17:25:59.686801+00', 5696, 1, 105, '', 'B', 'The Rossington Strathspey is a Scottish Country Dance devised by Bill Libby in honour of Mrs. Ethel Mary Moss. The tune, composed by James C. Aulenbach, also bears her name. The dance was first published in Island Games, then reprinted in Spark O’ Water, Dances of Nova Scotia in 2017. It was performed by the Thistle Scottish Country Dancers in Halifax, Nova Scotia, in May 2022.', 1, 1, 'Y', '5fgBhgK3k9g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8751, '2022-05-25 13:33:33.520761+00', '2022-05-25 17:28:18.491867+00', 16384, 2, 105, '', 'B', 'Spark O’ Water is a Scottish Country Dance devised by Duncan and Maggie Keppie. The dance was first published in Haliburton School of the Arts SCD Book #3, then reprinted in Spark O’ Water, Dances of Nova Scotia in 2017. Muriel Johnstone composed the tunes: Mira River; Eric’s Return to Tine; The Iceberg; Anne Carter’s Fancy. The dance was performed by the Thistle Scottish Country Dancers in Halifax, Nova Scotia, in May 2022.', 1, 1, 'Y', '8ujAn0ejZHA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8752, '2022-05-28 09:22:07.599024+00', '2022-05-28 09:44:26.731695+00', 13618, 3, 2269, '', 'C', 'RSCDS Toronto Dancing In The Park 2019 – Rosedale Youth Group.  Danced with energy.', 1, 1, 'Y', 'niWPVtHDveA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8766, '2022-05-30 00:40:03.703513+00', '2022-05-30 00:40:03.703513+00', 13584, 3, 1296, '', 'X', '''Christine M Phillips'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'ImLvrTcZ9s4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8768, '2022-05-30 00:40:03.73205+00', '2022-05-30 00:40:03.73205+00', 10166, 4, 1296, '', 'X', '''Ramadan-ce'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'VsUyM3mz53c', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8753, '2022-05-28 09:39:07.20359+00', '2022-05-28 09:50:39.540627+00', 13618, 4, 2269, '', 'A', 'Airyhall Dancers, Newcastle RSCDS Festival, 2014.  Once through as part of a longer demo. There seems to be a small video glitch in the first few bars.', 1, 1, 'Y', 'ZVmx3qNLulg', 405, 440, NULL);
INSERT INTO 'dancevideo' VALUES (8754, '2022-05-28 09:45:46.619836+00', '2022-05-28 09:52:14.019605+00', 13618, 5, 2269, '', 'D', 'Wellington, NZ, regional young dancers, 2014.', 1, 1, 'Y', 'Ln1FKl8fi2Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8769, '2022-05-30 00:40:03.7439+00', '2022-05-30 00:40:03.7439+00', 10066, 2, 1296, '', 'X', '''Royal Deeside'' is a 32 bar strathspey for 4 couples in a 4 couple set.', 1, 1, 'Y', 'QWmln2mZT4s', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8770, '2022-05-30 00:40:03.760486+00', '2022-05-30 00:40:03.760486+00', 5936, 3, 1296, '', 'X', '''Scotland''s Gardens'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', '1Z9_crqXIuU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8773, '2022-05-31 00:32:06.123367+00', '2022-05-31 08:18:19.238276+00', 458, 4, 2824, '', 'A', 'Demonstration at Ron Nedderman''s Memorial Tea Dance (30 April 2022).', 1, 1, 'Y', 'vufs6AmDQz0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8757, '2022-05-29 08:28:41.621717+00', '2022-05-31 17:45:04.579214+00', 20863, 1, 1645, '', 'B', 'SCD Muenster 2018. Twice through (once from each end).', 1, 1, 'Y', 'oLfFJEVQ3ec', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8760, '2022-05-29 08:35:58.014542+00', '2022-05-31 17:45:30.533358+00', 1426, 4, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'Mbd_Ju5F-58', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8756, '2022-05-28 10:29:09.626997+00', '2022-05-31 17:46:35.559936+00', 1478, 7, 2269, '', 'D', '20th Anniversary Ceilidh, 2011.', 1, 1, 'Y', 'Tkek5SufLE0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8755, '2022-05-28 10:12:16.345432+00', '2022-05-31 17:50:25.430045+00', 5693, 2, 2269, '', 'D', 'South American Piping Association Ceilidh, Buenos Aires, Argentina, 2018.  Tight shot.  Bystanders momentarily pass the camera.', 1, 1, 'Y', 'm8YUhSJYyGs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8762, '2022-05-29 08:42:44.403305+00', '2022-05-31 17:52:40.737738+00', 2484, 9, 1645, '', 'B', 'May day dance in the Britzer Garten, Berlin,  2022.', 1, 1, 'Y', 'kthadPYl4Tg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8774, '2022-05-31 09:30:33.946944+00', '2022-05-31 17:57:29.828259+00', 5982, 9, 2269, '', 'A', 'Airyhall Young Dancers, Newcastle International Festival, 2018.', 1, 1, 'Y', 'yIQSTa8steg', 162, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8771, '2022-05-30 15:02:01.20797+00', '2022-05-31 18:10:32.018264+00', 17795, 1, 2824, '', 'B', 'SCD group Hong Kong, 2022.', 1, 1, 'Y', 'jnhweAvD_b0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8761, '2022-05-29 08:38:51.843996+00', '2022-05-31 18:12:21.486114+00', 20643, 1, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'x_x9rySGqPk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8759, '2022-05-29 08:34:24.482186+00', '2022-05-31 18:19:23.824991+00', 20806, 1, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'T9IOBiYpoos', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8764, '2022-05-29 09:40:54.125272+00', '2022-05-31 18:21:47.095008+00', 15460, 2, 2269, '', 'C', 'Toronto RSCDS, Happy And Glorious Tea Dance, 2016.  Dancing begins at 59 seconds in.', 1, 1, 'Y', 't0p47_Um_1Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8758, '2022-05-29 08:31:45.822693+00', '2022-05-31 18:22:22.536903+00', 3672, 2, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'VbUv7vcxmyw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8811, '2022-06-13 17:54:41.763952+00', '2022-06-13 19:20:34.882705+00', 13577, 7, 2269, '', 'B', 'RSCDS Toronto, 2016.', 1, 1, 'Y', 'rl5CLyYCG5k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8858, '2022-06-23 19:17:37.049374+00', '2022-06-23 19:22:15.46901+00', 20904, 1, 1645, '', 'B', 'Leeds, 2022. Once through, starting just into the first bar.', 1, 1, 'Y', 'MlmVmekwclg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9079, '2022-10-23 23:06:26.419879+00', '2022-10-23 23:07:22.724955+00', 20873, 1, 1645, '', 'B', 'London Gay Gordons & Friends, 2022.', 1, 1, 'Y', 'AwbkD0BxJr0', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9237, '2023-01-20 23:56:11.508899+00', '2023-01-21 00:13:57.054026+00', 21313, 1, 1645, '', 'B', 'Once through. Excellent dancing (to Mrs MacPherson of Inveran).', 1, 1, 'Y', 'g5YdFCiyu6M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8765, '2022-05-29 10:08:02.210139+00', '2022-05-31 17:48:00.182403+00', 1782, 9, 2269, '', 'B', 'Johnsonville SCD Club''s final night for the year, 2017.   Last dance on the programme. This clips starts with the dancing, the video starts with a recap.', 1, 1, 'Y', 'uo7m_A_ZsDw', 33, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8775, '2022-05-31 10:58:33.157989+00', '2022-05-31 17:55:30.826252+00', 5982, 10, 2269, '', 'D', 'Bluebonnet Scottish Country Dancers, San Antonio, Texas, 2013. Danced in a 3-couple set.  On bars 17-24, some couples dance down nearer hands and turn both hands which is not in the dancing instructions', 1, 1, 'Y', '_BCT10pD9JA', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8776, '2022-05-31 11:33:42.528745+00', '2022-05-31 18:14:22.851646+00', 7283, 8, 2269, '', 'C', 'Toronto RSCDS Demo Pool, Christmas Market, Toronto''s Distillery District, 2015.  Danced once each couple.', 1, 1, 'Y', 'bV50ll1bXBs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8780, '2022-05-31 18:08:24.214629+00', '2022-05-31 18:23:06.82445+00', 2228, 5, 1645, '', 'B', 'SCD group Hong Kong, 2022. Twice through.', 1, 1, 'Y', 'Ooxi8IQPd0M', 0, 75, NULL);
INSERT INTO 'dancevideo' VALUES (8779, '2022-05-31 18:05:25.916111+00', '2022-05-31 18:23:25.376032+00', 20390, 2, 1645, '', 'B', 'SCD group Hong Kong, 2022.', 1, 1, 'Y', 'eOx3un_B1yo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8778, '2022-05-31 12:56:01.867306+00', '2022-05-31 18:26:10.575828+00', 695, 4, 2269, '', 'A', 'Red Thistle Dancers, Pleasanton Highland Games, 2011.  Danced as a 3-couple set, once from the top and once from the foot.', 1, 1, 'Y', 'JmcelyNN1yU', 77, 150, NULL);
INSERT INTO 'dancevideo' VALUES (8783, '2022-06-01 14:43:44.926116+00', '2022-06-03 09:16:13.195362+00', 2777, 9, 2269, '', 'C', 'RSCDS Toronto''s Beginners'' Night, March 2017.  There''s a brief video glitch a little before the 3 minute mark. ', 1, 1, 'Y', 'EKWiM8z9D6A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8781, '2022-06-01 07:44:04.591361+00', '2022-06-03 09:24:33.389403+00', 2777, 7, 2269, '', 'B', 'Colchester Scottish Dance And Ceilidh Club, 2015.  Danced twice through in a 2-couple set.', 1, 1, 'Y', 'GCIDX_yOYUI', 22, 93, NULL);
INSERT INTO 'dancevideo' VALUES (8784, '2022-06-04 13:46:30.453837+00', '2022-06-04 16:14:43.951928+00', 1036, 2, 513, '', 'C', 'Munich Scottish Association Whitsun SCD weekend 2022.', 1, 1, 'Y', 'H1JL_5MyYlQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8785, '2022-06-06 09:19:39.666869+00', '2022-06-06 21:20:15.923474+00', 2924, 8, 2269, '', 'C', 'RSCDS St Andrews Branch, 2018.', 1, 1, 'Y', 'sAseGBzunJ4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8786, '2022-06-07 08:45:03.271965+00', '2022-06-07 09:21:58.771654+00', 16338, 2, 513, '', 'D', 'Munich Scottish Association Whitsun SCD weekend 2022. Here done as a warmup dance.', 1, 1, 'Y', 'NdJxUQRjUvE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8787, '2022-06-07 08:47:35.930715+00', '2022-06-07 09:24:07.084502+00', 13621, 6, 513, '', 'C', 'Munich Scottish Association Whitsun SCD weekend 2022.', 1, 1, 'Y', 'gRpR6Yup52Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8789, '2022-06-07 18:39:07.270592+00', '2022-06-07 18:59:29.707104+00', 17485, 1, 2824, '', 'B', 'Dancers of the Munich Scottish Association, 2022. The deviser and dedicatee start as 1st couple and the music is played by the composer of the original tune.

(Camera angle very close to the set, consequently only part of the set is visible/dancers are "beheaded" at numerous times during the video.)', 1, 1, 'Y', 'kKLyHN0aFdQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8788, '2022-06-07 15:10:43.302121+00', '2022-06-07 19:58:53.907573+00', 15437, 3, 513, '', 'C', '', 1, 1, 'Y', 'TLuq5CoAscE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8795, '2022-06-08 23:09:03.293103+00', '2022-06-08 23:09:59.11268+00', 16461, 4, 1645, '', 'B', 'SCD group Hong Kong, 2022. Last three times through.', 1, 1, 'Y', 'RTiHBIem79Y', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1141, '2013-08-18 10:48:02.812563+00', '2022-06-11 16:21:04.519077+00', 2129, 4, 1296, '', 'B', 'Telheiras SCD Group, Lisbon, 2012.', 1, 1, 'Y', 'cYaStXha20o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8797, '2022-06-09 12:51:13.850008+00', '2022-06-12 17:39:01.971189+00', 9157, 10, 2269, '', 'B', 'RSCDS Demonstration Team, Scottish Fest, Rockville, 2012.', 1, 1, 'Y', 'JEUM33Zbz-k', 180, 217, NULL);
INSERT INTO 'dancevideo' VALUES (8796, '2022-06-09 12:44:26.384789+00', '2022-06-12 17:41:44.863127+00', 9157, 9, 2269, '', 'B', 'Arkansas Scottish Country Dance Society, Little Rock, Arkansas, 2014.', 1, 1, 'Y', 'LU8zp1xgLwM', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8793, '2022-06-08 15:01:45.055296+00', '2022-06-12 17:44:53.899946+00', 18272, 6, 2269, '', 'Z', 'RSCDS Summer School in St. Andrews, week 4, 2018.  Once through, with modified beginning and end :- during the first 8 bars, the other dancers swirl into place; the last four bars are modified to lead into the next dance.



The dancing is excellent but given the modifications and the availability of other good videos its probably best to block this one.', 1, 1, 'Y', 'VWsxd-FFr2Q', 246, 279, NULL);
INSERT INTO 'dancevideo' VALUES (8790, '2022-06-08 07:17:44.663945+00', '2022-06-12 17:46:53.329183+00', 3834, 8, 2269, '', 'B', 'Colchester Scottish Dance And Ceilidh Club, 2015.  Danced as a single 2-couple set with modifications :-  Circle and back, dancers add a twirl.  Both couples dance out and back (and with nearer hands joined, not right hands).', 1, 1, 'Y', 'GCIDX_yOYUI', 419, 495, NULL);
INSERT INTO 'dancevideo' VALUES (8798, '2022-06-09 13:43:44.298252+00', '2022-06-12 17:50:47.071243+00', 7180, 11, 2269, '', 'C', 'Scottish Party At The Festival "The Breath Of Siberia", Tomsk, Russia, 2017.  At the end of the first 8 bars the 3s make a full RH turn, rather than a half turn.  The 3M becomes a lady for the interlocking reels.  Swapping back occurs with the RH turn at the end of bar 16. The music is on the slow side.', 1, 1, 'Y', '-rfC-msB-04', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8791, '2022-06-08 11:15:14.717898+00', '2022-06-12 17:56:02.551913+00', 9800, 9, 2269, '', 'A', 'RSCDS Summer School in St. Andrews, week 4, 2018.  Danced twice in a 3-couple set.  Second time through ( bars 21-24 ), supporting couples chase halfway around the set.', 1, 1, 'Y', 'VWsxd-FFr2Q', 23, 120, NULL);
INSERT INTO 'dancevideo' VALUES (8792, '2022-06-08 14:45:44.720487+00', '2022-06-12 17:57:59.24311+00', 17122, 10, 2269, '', 'A', 'RSCDS Summer School in St. Andrews, week 4, 2018.  Twice through.', 1, 1, 'Y', 'VWsxd-FFr2Q', 120, 246, NULL);
INSERT INTO 'dancevideo' VALUES (8794, '2022-06-08 15:19:59.982636+00', '2022-06-12 17:59:55.191197+00', 14903, 6, 2269, '', 'B', 'RSCDS Summer School in St. Andrews, week 4, 2018.  Dancing is excellent, but video is downgraded due to departure from the original instructions.  Five-couple version, with 1s and 3s dancing :- Right hands across in the centre and at the ends; modified corners pass & turn; Double Triangles at both ends; big circle.  On the second time through – special ending.', 1, 1, 'Y', 'VWsxd-FFr2Q', 283, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8802, '2022-06-13 06:11:43.378315+00', '2022-06-13 06:12:12.240104+00', 1544, 11, 202, '', 'C', '', 1, 1, 'Y', '4qoLfltbEJc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8803, '2022-06-13 06:16:34.05735+00', '2022-06-13 06:16:52.452177+00', 15275, 2, 202, '', 'D', '', 1, 1, 'Y', 'T4hfuwQYzUo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8804, '2022-06-13 06:22:09.85183+00', '2022-06-13 06:22:24.587599+00', 1544, 12, 202, '', 'C', '', 1, 1, 'Y', 'RtPIkbOQNgk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5133, '2019-09-18 12:41:30.64551+00', '2022-06-13 08:34:43.980719+00', 13732, 1, 1645, '', 'B', 'Norfolk Broads Hornpipe 8x32 bar Scottish Country Dance for three couples in a four couple set.  

Performed by members of the Woodbridge Scottish Country Dance Group on 14th August 2019 at Bredfield Village Hall, Suffolk UK.  

Dance is from RSCDS Norwich Branch 50th Anniversay Book, and music is Captain McBride''s Hornpipe played by Green Ginger.', 1, 1, 'Y', 'T5dhj3NhEbs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8810, '2022-06-13 17:44:05.187669+00', '2022-06-13 19:55:26.192667+00', 13577, 6, 2269, '', 'A', 'German Mixed Team, Newcastle SCD Festival, 2019.', 1, 1, 'Y', 'Glvoe6djEG4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8800, '2022-06-12 18:23:29.313033+00', '2022-06-13 19:56:50.139389+00', 20807, 1, 1645, '', 'C', 'Méaudre Reel SCD course 2022. The set on the left is clearer.', 1, 1, 'Y', 'wyndcOtmqVA', 96, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8801, '2022-06-12 18:28:14.586471+00', '2022-06-13 19:57:51.349182+00', 17037, 1, 1645, '', 'D', 'Danced by all the dancers under 25 at the Méaudre Reel SCD course 2022.', 1, 1, 'Y', 'C50RQPjy1lI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8805, '2022-06-13 10:57:00.314912+00', '2022-06-13 19:59:18.695498+00', 3338, 6, 2269, '', 'A', 'NewScotland Mixed, Newcastle RSCDS Festival, 2015.  ', 1, 1, 'Y', 'KzC0lG5G4_c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8808, '2022-06-13 14:21:40.539001+00', '2022-06-13 20:04:20.446075+00', 3932, 7, 2269, '', 'A', 'Alba Kelvin Team, Newcastle Festival, 2015.', 1, 1, 'Y', 'zwTeuzw5GsY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8806, '2022-06-13 13:21:51.305463+00', '2022-06-13 20:12:49.448465+00', 4291, 4, 2269, '', 'B', 'Trinity Club Night, Edinburgh, 2016.  Good dancing, but with the occasional lapse of concentration.', 1, 1, 'Y', 'LCt25FmD4Ro', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8799, '2022-06-09 15:05:04.292326+00', '2023-01-21 12:02:20.640956+00', 14989, 1, 106, '', 'B', 'This video has two dances.  The first is the strathspey "Groundhog Day".  The second dance was subsequently withdrawn.', 1, 1, 'Y', 'dgZcPnEslrI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8829, '2022-06-18 22:18:35.507124+00', '2022-06-19 01:31:36.870379+00', 20315, 1, 513, '', 'D', '', 1, 1, 'Y', 'tqJEQN3wiX0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8814, '2022-06-13 19:51:26.829895+00', '2022-06-13 19:53:14.25537+00', 6431, 1, 1645, '', 'B', 'Gleneagles Scottish Country Dance Club at the 2022 Bridge Festival (West Vancouver). Twice through. Generally clear with a few glitches in the circles and turns.', 1, 1, 'Y', 'iQHchm0iJ-8', 18, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8809, '2022-06-13 16:32:58.059883+00', '2022-06-13 19:54:02.38334+00', 13577, 5, 2269, '', 'B', 'RSCDS Gleneagles Scottish Country Dance Club, West Vancouver, British Columbia, Canada, 2020.  Alternate views: elevated camera position and level views.', 1, 1, 'Y', 'SdSd7eQkLWo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8807, '2022-06-13 13:44:47.610139+00', '2022-06-13 20:10:24.1459+00', 4291, 5, 2269, '', 'B', 'Thistle Scottish Country Dancers, 2012.  Danced as a 4-couple dance (instead of 3-couples in a 4-couple set). Bars 25-40 are danced with 3rd and 4th couples rather than 2nd and 3rd couples.', 1, 1, 'Y', 'uGXt8nh-1qg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8812, '2022-06-13 19:36:29.720465+00', '2022-06-13 20:13:13.116782+00', 4990, 2, 1645, '', 'B', ' Gleneagles Scottish Country Dance Club at the 2022 Bridge Festival (West Vancouver).', 1, 1, 'Y', 'SzMxjVOKJsE', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8813, '2022-06-13 19:44:36.555082+00', '2022-06-13 20:13:55.042071+00', 7109, 7, 1645, '', 'B', ' Gleneagles Scottish Country Dance Club at the 2022 Bridge Festival (West Vancouver). Here done once and to the bottom, also with all four couples taking part in the setting and crossing at the start.', 1, 1, 'Y', 'UHgn1LYNovA', 13, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8815, '2022-06-13 20:28:44.030474+00', '2022-06-14 22:21:28.734854+00', 14964, 3, 1645, '', 'A', 'Youth Demonstration team at the RSCDS AGM 2018. Twice through in two back to back sets as part of a longer display (viewed from afar). The last 8 bars are adapted to lead into the next dance.', 1, 1, 'Y', 'Z9Vr563H-vU', 77, 204, NULL);
INSERT INTO 'dancevideo' VALUES (8820, '2022-06-14 22:54:48.710239+00', '2022-06-16 00:51:56.460156+00', 17768, 2, 1645, '', 'A', 'Russian Spring School, 2022. Four times through. After their second time, the first 1st couple dance the first few bars again to end in 4th place.', 1, 1, 'Y', 'EtZIbIaGyz0', 290, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8816, '2022-06-14 22:27:08.427312+00', '2022-06-16 09:03:56.635423+00', 7564, 1, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'MbRRSZd2SxI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8818, '2022-06-14 22:35:59.643632+00', '2022-06-16 09:04:21.197652+00', 2323, 1, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'EFNcx-m3eXk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8817, '2022-06-14 22:32:00.313664+00', '2022-06-16 09:05:17.036291+00', 18208, 2, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'tyVo2Qk0nd4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8819, '2022-06-14 22:47:55.28761+00', '2022-06-16 09:06:47.03051+00', 17988, 2, 1645, '', 'A', 'Russian Spring School, 2022.', 1, 1, 'Y', 'EtZIbIaGyz0', 0, 272, NULL);
INSERT INTO 'dancevideo' VALUES (8821, '2022-06-14 23:42:23.656292+00', '2022-06-16 18:26:24.479681+00', 20679, 1, 1645, '', 'A', 'Russian Summer School, 2022. Once through as the first part of a longer display with the last 4 bars adapted to end in a square set for the next dance.', 1, 1, 'Y', 'fVy3lFnh7X4', 5, 45, NULL);
INSERT INTO 'dancevideo' VALUES (8822, '2022-06-14 23:54:44.038673+00', '2022-06-16 18:27:24.560983+00', 20676, 2, 1645, '', 'A', 'Russian Summer School, 2022. Once through as part of a longer display. The last 4 bars are adapted to end in a longwise set for the next dance (half figures of 8 instead of turning partner RH).', 1, 1, 'Y', 'fVy3lFnh7X4', 45, 79, NULL);
INSERT INTO 'dancevideo' VALUES (8823, '2022-06-16 18:20:46.527559+00', '2022-06-16 18:28:41.519356+00', 20682, 1, 1645, '', 'A', 'Russian Summer School, 2022. Once through as part of a longer display.', 1, 1, 'Y', 'fVy3lFnh7X4', 79, 140, NULL);
INSERT INTO 'dancevideo' VALUES (8824, '2022-06-16 18:24:57.061997+00', '2022-06-16 18:29:37.851448+00', 20100, 1, 1645, '', 'A', 'Russian Summer School, 2022. Once through as the last part of a longer display. The end is slightly adapted for a final bow.', 1, 1, 'Y', 'fVy3lFnh7X4', 140, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8825, '2022-06-17 16:36:14.008654+00', '2022-06-17 16:43:21.768739+00', 20895, 1, 602, '', 'B', '', 1, 1, 'Y', 'Yr4wG7Ga8IE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8848, '2022-06-23 05:25:41.509599+00', '2022-06-23 11:31:48.228015+00', 20877, 2, 645, '', 'A', 'June 2022', 1, 1, 'Y', 'KsGbZTm9PjA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8831, '2022-06-19 08:44:22.833442+00', '2022-06-19 08:44:47.911634+00', 8526, 2, 202, '', 'C', '', 1, 1, 'Y', 'l9_2CEuRqTQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8830, '2022-06-19 07:05:32.665344+00', '2022-06-19 08:48:50.667686+00', 14597, 5, 2824, '', 'A', 'Dem by The Red Thistle Dancers, 2022 Travel & Adventure Show', 1, 1, 'Y', 'LhpplR8jXGo', 78, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7732, '2021-01-09 17:26:39.549905+00', '2022-06-19 09:43:47.217082+00', 6800, 2, 1645, '', 'Z', 'RSCDS Edinburgh Strictly Scottish 1993. Twice through as part of a longer demonstration. The end of the 2nd repeat is slightly adapted to lead into the next dance. Good demonstration but rather dark video.



Original video was replaced by another youtube upload. But probably best to keep this blocked as its really too dark to follow and there are other videos.', 1, 1, 'Y', 'MUd8Ng5nGAM', 2735, 2822, NULL);
INSERT INTO 'dancevideo' VALUES (8833, '2022-06-19 09:31:14.60686+00', '2022-06-19 10:09:29.123426+00', 805, 3, 1645, '', 'A', 'RSCDS Edinburgh, Dancing Forth show 2009.', 1, 1, 'Y', 'FPuQiMBz91A', 247, 453, NULL);
INSERT INTO 'dancevideo' VALUES (7750, '2021-01-12 18:52:45.477509+00', '2022-06-19 10:25:16.441806+00', 13282, 4, 1645, '', 'Z', 'RSCDS Edinburgh Dancing Forth 2009.  Twice through. Good view from above.



Original video no longer available. Parts 1-3 of the Dancing Forth 2009 set were replaced by new youtube videos but seemingly not this one.', 1, 1, 'Y', 'o3dR4QF0hQQ', 595, 721, NULL);
INSERT INTO 'dancevideo' VALUES (8849, '2022-06-23 05:26:52.846113+00', '2022-06-23 07:51:01.103319+00', 20886, 2, 645, '', 'B', 'June 2022', 1, 1, 'Y', '2ls-THEC0JU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8835, '2022-06-19 14:30:25.806856+00', '2022-06-19 18:07:03.516354+00', 4019, 1, 1645, '', 'A', 'RSCDS Edinburgh, Strictly Scottish 1994. Twice through.', 1, 1, 'Y', '5kgqp2zMOeQ', 543, 682, NULL);
INSERT INTO 'dancevideo' VALUES (8837, '2022-06-19 15:03:26.496494+00', '2022-06-19 18:04:13.17898+00', 849, 2, 1645, '', 'A', 'RSCDS Edinburgh. Strictly Scottish 1994. Three times, starting with just two couples, then with additional couples.', 1, 1, 'Y', '5kgqp2zMOeQ', 2474, 2582, NULL);
INSERT INTO 'dancevideo' VALUES (8840, '2022-06-19 16:14:55.392682+00', '2022-06-19 18:05:35.373948+00', 1881, 3, 1645, '', 'A', 'RSCDS Edinburgh. Strictly Scottish 1994. Some of the handing is altered in part 3 of the dance.', 1, 1, 'Y', '5kgqp2zMOeQ', 4232, 4457, NULL);
INSERT INTO 'dancevideo' VALUES (8834, '2022-06-19 10:15:36.264897+00', '2022-06-19 18:07:58.422687+00', 4354, 5, 1645, '', 'A', 'RSCDS Edinburgh, Dancing Forth show 2009.', 1, 1, 'Y', 'FPuQiMBz91A', 621, 733, NULL);
INSERT INTO 'dancevideo' VALUES (8838, '2022-06-19 15:24:41.682408+00', '2022-06-19 18:08:52.194895+00', 5623, 3, 1645, '', 'A', 'RSCDS Edinburgh. Strictly Scottish 1994. This clip shows twice through the standard version. In the full video this is preceded (from 57:07) by a slightly modified version where each couple dances on in turn for the fugal part.', 1, 1, 'Y', '5kgqp2zMOeQ', 3465, 3538, NULL);
INSERT INTO 'dancevideo' VALUES (8839, '2022-06-19 15:37:04.197064+00', '2022-06-19 18:09:50.263789+00', 6675, 1, 1645, '', 'A', 'RSCDS Edinburgh. Strictly Scottish 1994. Three times, here danced in a three couple set with 1st couple casting to the bottom each time.', 1, 1, 'Y', '5kgqp2zMOeQ', 3538, 3731, NULL);
INSERT INTO 'dancevideo' VALUES (8836, '2022-06-19 14:43:42.12821+00', '2022-06-19 18:11:01.919551+00', 6849, 1, 1645, '', 'A', 'RSCDS Edinburgh, Strictly Scottish 1994. Three times through.', 1, 1, 'Y', '5kgqp2zMOeQ', 1623, 1744, NULL);
INSERT INTO 'dancevideo' VALUES (8832, '2022-06-19 08:49:37.491009+00', '2022-06-20 05:45:03.228858+00', 20897, 1, 202, '', 'C', '', 1, 1, 'Y', 'k5NNyZg7DFo', 50, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8845, '2022-06-21 16:58:45.803064+00', '2022-06-21 17:37:32.31137+00', 12186, 1, 2213, '', 'B', 'Chard Scottish Country Dancers, 2022.', 1, 1, 'Y', '2TRRAhOyVjQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8841, '2022-06-21 08:59:33.468846+00', '2022-06-21 18:31:06.935745+00', 6712, 14, 2269, '', 'B', 'SCD Workshop, Méaudre Reel Club, Vercors, France, 2022.  Combine adult and youth dancing.', 1, 1, 'Y', 'CZU41IKnQP4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8844, '2022-06-21 16:10:40.334448+00', '2022-06-21 18:32:37.403508+00', 9008, 5, 2269, '', 'B', 'Scottish Dance Group ART, Feira Da Luz, Carnide, Lisbon, 2015.  Danced from 2nd place and then again from 1st place.', 1, 1, 'Y', 'e6Mlpdk8J5U', 0, 74, NULL);
INSERT INTO 'dancevideo' VALUES (8843, '2022-06-21 13:47:01.41328+00', '2022-06-21 18:34:35.623648+00', 13070, 4, 2269, '', 'C', 'OTTB 2019.  Dancers having fun so sometimes minor changes to choreography.', 1, 1, 'Y', 'olO3n1C7VeI', 0, 295, NULL);
INSERT INTO 'dancevideo' VALUES (8842, '2022-06-21 10:15:39.120923+00', '2022-06-21 18:36:34.722064+00', 13847, 8, 2269, '', 'C', 'RSCDS Toronto Gala Day, 2012.  A minor hesitation second time through.', 1, 1, 'Y', '7Zj_Q8NoI3k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8852, '2022-06-23 05:31:11.377751+00', '2022-06-23 12:10:02.82628+00', 20874, 1, 645, '', 'A', 'May 2022', 1, 1, 'Y', 'TbxqqKNpGlU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8853, '2022-06-23 12:21:27.993008+00', '2022-06-23 12:21:46.098997+00', 4411, 11, 202, '', 'B', '', 1, 1, 'Y', 'Gl6HHwfVxuk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8854, '2022-06-23 13:37:49.776843+00', '2022-06-23 19:18:28.859277+00', 16522, 4, 2269, '', 'B', 'RSCDS Toronto Family Ceilidh, 2015.  Dancing is demonstration quality, only rated as good as the dance has been adapted for a 3-couple set.  The last 4-bars modified to turn right and cast.', 1, 1, 'Y', 'dcHVeG2SWJI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8856, '2022-06-23 18:32:09.086936+00', '2022-06-23 19:21:55.38178+00', 14538, 1, 1645, '', 'B', 'Leeds branch team, 2019 White Rose Festival.', 1, 1, 'Y', 'g9VvitP1QFo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8859, '2022-06-23 21:31:44.160609+00', '2022-06-23 21:43:10.525894+00', 20879, 1, 645, '', 'A', 'September 2020

*Social Distancing Version (No hands)', 1, 1, 'Y', 'tI7PJPVkZ_0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8857, '2022-06-23 19:12:06.238694+00', '2022-06-23 22:36:37.889588+00', 20901, 1, 1645, '', 'B', 'Leeds, 2022. Once through.



This video follows the original version of the dance, before Rod changed the way the third and fourth couples started the double figure of eight.   The change was made to allow third couple to enter the Rose Progression more easily.', 1, 1, 'Y', 'DeJ2nL5czy0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8860, '2022-06-24 05:23:11.620181+00', '2022-06-24 05:24:12.492399+00', 20663, 2, 202, '', 'C', '', 1, 1, 'Y', 'taPLe04RPMo', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8861, '2022-06-24 05:25:06.976914+00', '2022-06-24 05:25:58.174958+00', 20578, 2, 202, '', 'C', '', 1, 1, 'Y', 'LzdEgYIguWo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8862, '2022-06-24 05:28:29.457183+00', '2022-06-24 05:29:04.778792+00', 20671, 2, 202, '', 'C', '', 1, 1, 'Y', '3YckN6Qoi58', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8863, '2022-06-24 05:30:32.599071+00', '2022-06-24 05:32:27.170484+00', 20635, 3, 202, '', 'C', '', 1, 1, 'Y', 'oWjpc6EitS0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8864, '2022-06-24 05:34:24.263887+00', '2022-06-24 05:34:38.036321+00', 9108, 2, 202, '', 'D', '', 1, 1, 'Y', 'QQRSG95m7LY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7706, '2021-01-06 17:34:58.630971+00', '2022-07-04 08:31:10.885645+00', 2415, 2, 1645, '', 'B', 'RSCDS Edinburgh Dancing Forth 2007. Danced once each couple in two 3 couple sets, on and off stage with different orientations and the camera switching between them. The final turns are adapted to get 1st couple to 3rd place.



As is traditional in Edinburgh, the two hand turns are here done with skip change rather than pas de basque.



NB the sound track is out of sync with the dancing.', 1, 1, 'Y', 'eDPEiicOfW0', 3351, 3470, NULL);
INSERT INTO 'dancevideo' VALUES (8865, '2022-06-25 12:15:51.026937+00', '2022-06-26 09:00:25.767525+00', 2910, 5, 2269, '', 'A', 'RSCDS Stirling Branch, Guildhall, Stirling, 1993.', 1, 1, 'Y', 'IfZHXhxDmZM', 3313, 3458, NULL);
INSERT INTO 'dancevideo' VALUES (8866, '2022-06-25 13:07:36.753155+00', '2022-06-26 09:02:12.07069+00', 3980, 9, 2269, '', 'B', 'RSCDS Stirling, 2018.  On-screen and spoken dancing instructions.  Slow motion segment during first time through.', 1, 1, 'Y', 'OkBka50_2e0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8867, '2022-06-26 15:01:54.498064+00', '2022-06-27 08:52:55.63328+00', 16656, 1, 963, '', 'C', '1st woman forgets how to dance under her partner''s arm to change sides and some corners are a little hesitant in the corner pass and twirl.', 1, 1, 'Y', 'u6UOmcHEpyg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8868, '2022-06-28 16:42:27.169041+00', '2022-06-28 16:42:46.349158+00', 12863, 1, 202, '', 'D', '', 1, 1, 'Y', 'zsyUKD4FcyE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8876, '2022-07-03 08:12:38.257414+00', '2022-07-03 08:53:23.929217+00', 20734, 1, 202, '', 'D', '', 1, 1, 'Y', 'XeBgryOdp1U', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8877, '2022-07-03 09:04:28.693746+00', '2022-07-03 09:04:46.077187+00', 3972, 1, 202, '', 'D', '', 1, 1, 'Y', 'iSjLdoMLTyA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8874, '2022-07-02 19:28:35.560815+00', '2022-07-03 20:59:59.285496+00', 7055, 4, 2269, '', 'C', 'RSCDS Helensburgh''s 40th Annual Weekend, 2018.', 1, 1, 'Y', 'MvhyL_gBMHU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7730, '2021-01-08 22:56:56.082582+00', '2022-07-04 08:32:32.817858+00', 2415, 3, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2009. Three times as the last part of a longer demo. There are a few minor adaptations for demonstration purposes. The 1st repeat ends with a slow RH cross instead of full RH turns to switch the top and bottom of the set, the 2nd repeat has some diagonal turns, the last repeat ends facing the audience. Clear view from above.



As is traditional in Edinburgh, the two hand turns are here done with skip change rather than pas de basque.

', 1, 1, 'Y', 'wUMmpgWYY7E', 1595, 1703, NULL);
INSERT INTO 'dancevideo' VALUES (8875, '2022-07-02 19:35:43.972423+00', '2022-07-03 21:00:24.808045+00', 7055, 5, 2269, '', 'D', 'Chiswick Scottish Country Dance, Midsummer Magic Dance, 2015.', 1, 1, 'Y', 'hcS3M1ZzgKo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8873, '2022-07-02 19:12:28.796752+00', '2022-07-03 21:01:43.71017+00', 9561, 6, 2269, '', 'C', 'Russia, 2018.  The view is briefly obscured towards the end of the video.', 1, 1, 'Y', 'GiK67oGE4ME', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8872, '2022-07-02 19:02:05.185002+00', '2022-07-03 21:03:03.780388+00', 9561, 5, 2269, '', 'A', 'Lyon''s Under-16 Team, Newcastle Festival, 2018.', 1, 1, 'Y', 'vaLzNalhlgs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8884, '2022-07-04 09:06:03.453292+00', '2022-07-04 10:40:40.628973+00', 11193, 1, 1645, '', 'C', 'SCD group Hong Kong, 2022.', 1, 1, 'Y', 'tXc3QrSqdls', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8879, '2022-07-03 21:46:15.58592+00', '2022-07-03 21:46:48.252215+00', 3832, 1, 202, '', 'A', '', 1, 1, 'Y', 'paYnVjK2cn4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8881, '2022-07-03 21:52:54.399756+00', '2022-07-03 21:53:15.408597+00', 4444, 4, 202, '', 'A', '', 1, 1, 'Y', 'ZWL3OQy4_Ug', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8882, '2022-07-03 21:58:52.067988+00', '2022-07-03 21:59:07.742498+00', 3727, 1, 202, '', 'A', '', 1, 1, 'Y', 'YkfdzgmSZE0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8883, '2022-07-03 22:01:45.982769+00', '2022-07-03 22:01:59.772211+00', 4205, 1, 202, '', 'A', '', 1, 1, 'Y', 'fo45xwLFV8c', 18, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8878, '2022-07-03 21:32:13.151212+00', '2022-07-04 08:23:13.619334+00', 15425, 1, 1332, '', 'B', 'SCD Lapa Lisbon Group, 2022.', 1, 1, 'Y', 'qfPvdnm-oQk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8869, '2022-07-02 18:26:05.766084+00', '2022-07-04 10:42:56.571949+00', 4106, 6, 2269, '', 'B', 'RSCDS Stirling Branch, Princes St Gardens, 2010.  On-screen and spoken dancing instructions.', 1, 1, 'Y', '2MqAwjDbMoI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8870, '2022-07-02 18:36:51.803559+00', '2022-07-04 10:43:53.002541+00', 4106, 7, 2269, '', 'A', 'RSCDS Archive, 2019.  Once through.', 1, 1, 'Y', 'LdtlT3WPRAc', 2705, 2750, NULL);
INSERT INTO 'dancevideo' VALUES (8871, '2022-07-02 18:45:09.535735+00', '2022-07-04 10:45:43.413969+00', 4106, 8, 2269, '', 'A', 'RSCDS City Moves, Aberdeen Festival, 2018.', 1, 1, 'Y', 'W8reuMm6k7E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8886, '2022-07-05 07:50:12.624256+00', '2022-07-05 07:50:30.782025+00', 4256, 2, 202, '', 'A', '', 1, 1, 'Y', 'hM7rrPq3Wz8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8885, '2022-07-04 14:55:20.575968+00', '2022-07-05 07:51:51.757029+00', 5296, 6, 2269, '', 'C', 'RSCDS Hamilton and Clydesdale - Spring Dance, 2017.  One minor mistake noted, in one case ( bars 17-24 ), 1M goes down instead of up, dancing with the 4s instead of the 2s.  The music is good, the camera position is elevated and the dancers are easily identifiable. ', 1, 1, 'Y', '3SS-ihpLqoI', 0, 284, NULL);
INSERT INTO 'dancevideo' VALUES (8887, '2022-07-06 00:40:03.084025+00', '2022-07-06 00:40:03.084025+00', 3001, 1, 1296, '', 'X', '''Howe o'' Fife, The'' is a 32 bar strathspey for 3 couples in a 3 couple set.', 1, 1, 'Y', 'ftjWVrjI4JU', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8888, '2022-07-06 00:40:03.130905+00', '2022-07-06 00:40:03.130905+00', 4359, 2, 1296, '', 'X', '''Middling Thank You'' is a 40 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'qRK9InEk0SI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8889, '2022-07-06 00:40:03.147099+00', '2022-07-06 00:40:03.147099+00', 18409, 4, 1296, '', 'X', '''Ullapool Ferry, The'' is a 32 bar reel for 4 couples in a 4 couple set.', 1, 1, 'Y', 'y2IRdkVVwhw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8890, '2022-07-06 00:40:03.16117+00', '2022-07-06 00:40:03.16117+00', 5937, 2, 1296, '', 'X', '''Scots Bonnet, The'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'hj3LwH1eO60', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8891, '2022-07-07 23:27:26.805727+00', '2022-07-08 00:00:36.148648+00', 20938, 1, 1645, '', 'A', 'Demonstration at the Spring School, Russia, 2022.', 1, 1, 'Y', 'kDsNYXk6rvk', 18, 285, NULL);
INSERT INTO 'dancevideo' VALUES (8892, '2022-07-07 23:35:01.460608+00', '2022-07-08 00:02:42.30931+00', 20941, 1, 1645, '', 'A', 'Demonstration at the Spring School, Russia, 2022. Four times through.

', 1, 1, 'Y', 'kDsNYXk6rvk', 295, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8895, '2022-07-09 09:59:30.268619+00', '2022-07-09 09:59:49.742581+00', 3471, 1, 202, '', 'A', 'Devised specifically for the 1987 RSCDS Toronto Gala Day. Danced by Emmerson''s University of Western Ontario Scottish country dancers.', 1, 1, 'Y', 'vev82QTbxHw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8896, '2022-07-09 10:02:36.186008+00', '2022-07-09 10:02:53.098303+00', 4728, 5, 202, '', 'A', '', 1, 1, 'Y', '28n-KgiAifY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8894, '2022-07-08 13:23:53.930253+00', '2022-07-09 10:03:56.836131+00', 4491, 8, 2269, '', 'C', 'Katharine Barber And Her Country Dancers, Harbour Square, Kirkcudbright, 2016.  Danced in two 3-couple sets.  Initially, the camera is in long shot, then the camera zooms in on one set for a while before switching to the other, then the camera settles on a long shot containing both sets.', 1, 1, 'Y', '_6UOQeRyDSY', 43, 182, NULL);
INSERT INTO 'dancevideo' VALUES (9192, '2023-01-05 18:39:18.354155+00', '2023-01-05 18:44:07.378574+00', 13773, 1, 1645, '', 'B', 'SCD group Hong Kong, 2022. Twice through.', 1, 1, 'Y', 'N4Sr4plGrwU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9196, '2023-01-05 19:16:57.736734+00', '2023-01-05 19:43:15.459612+00', 3105, 3, 1645, '', 'C', 'Johnsonville SCD Club, NZ, 2022. Four times.', 1, 1, 'Y', 'lncliTe75QA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9239, '2023-01-21 00:06:35.68592+00', '2023-01-21 00:09:19.520954+00', 21315, 1, 1645, '', 'B', 'Once through.', 1, 1, 'Y', 'kHk3_BcqJ8Y', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8893, '2022-07-08 12:54:03.134729+00', '2022-07-09 10:03:37.755197+00', 4491, 7, 2269, '', 'B', 'Ochil Scottish Country Dancers, St Ninian''s Church Hall, Stirling, Scotland, 2017.  On-screen and spoken dancing instructions.  Does not completely conform to the instructions, which have the 1s on the second time through casting to 4th place, giving a neater ending.', 1, 1, 'Y', 'D11b8uBB_dY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8897, '2022-07-09 10:05:45.644718+00', '2023-02-02 17:54:31.498173+00', 3934, 2, 202, '', 'A', 'Strictly Scottish (RSCDS Vancouver), 2022. Twice through.', 1, 1, 'Y', 'n21yYRSZ1qQ', 0, 240, NULL);
INSERT INTO 'dancevideo' VALUES (8899, '2022-07-09 10:10:27.710257+00', '2022-07-09 10:11:08.355056+00', 2593, 3, 202, '', 'A', '', 1, 1, 'Y', 'wbLs4AYxjJc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8900, '2022-07-09 10:12:07.061415+00', '2022-07-09 10:13:07.702081+00', 899, 5, 202, '', 'A', '', 1, 1, 'Y', 'L5pHslLzD_o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8901, '2022-07-09 10:16:50.654483+00', '2022-07-09 10:19:31.071364+00', 1786, 12, 202, '', 'B', '', 1, 1, 'Y', 'GRyB8VIIL5o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8902, '2022-07-09 10:18:55.852141+00', '2022-07-09 10:19:40.636655+00', 2153, 2, 202, '', 'A', '', 1, 1, 'Y', 'UJbIRiExfh0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8903, '2022-07-09 10:24:10.474684+00', '2022-07-09 10:24:20.393843+00', 3608, 3, 202, '', 'A', '', 1, 1, 'Y', 'pDwMvE_cHwA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8904, '2022-07-10 09:52:39.709994+00', '2022-07-10 09:53:06.963591+00', 20531, 1, 202, '', 'B', '', 1, 1, 'Y', 'hxig9fRfndE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8905, '2022-07-11 05:59:13.961937+00', '2022-07-11 08:21:12.773937+00', 15813, 1, 2824, '', 'A', '', 1, 1, 'Y', 'cfLmFn89imM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8924, '2022-07-16 00:40:02.979898+00', '2022-07-16 00:40:02.979898+00', 1790, 3, 1296, '', 'X', '''Duke of Hamilton''s Reel'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', '64-btAWnsRc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8906, '2022-07-11 08:31:54.927558+00', '2022-07-11 08:37:04.053641+00', 1142, 1, 1645, '', 'A', 'Erin Mills group at the RSCDS Toronto Gala Day 1987. This clip shows once through the dance as part of a longer demo. Excellent dancing but constant cutting between camera angles makes it hard to follow.', 1, 1, 'Y', 'LvahthgfClY', 66, 121, NULL);
INSERT INTO 'dancevideo' VALUES (8921, '2022-07-16 00:40:02.929935+00', '2022-07-16 00:40:02.991246+00', 8932, 5, 1296, '', 'Z', '''Hyperactive Reel, The'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'MwSiXX2J9Uo', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8907, '2022-07-11 08:34:54.395288+00', '2022-07-11 08:38:24.309196+00', 5142, 1, 1645, '', 'A', 'Erin Mills group at the RSCDS Toronto Gala Day 1987. Once through the dance as part of a longer demo. ', 1, 1, 'Y', 'LvahthgfClY', 121, 154, NULL);
INSERT INTO 'dancevideo' VALUES (8908, '2022-07-12 00:40:03.320629+00', '2022-07-12 00:40:03.320629+00', 18500, 1, 1296, '', 'X', '''Golden Hornpipe, The'' is a 32 bar reel for 4 couples in a 4 couple set.', 1, 1, 'Y', '0zqn58RvEXw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8909, '2022-07-12 00:40:03.343489+00', '2022-07-12 00:40:03.343489+00', 10316, 1, 1296, '', 'X', '''Maple Leaf Rant'' is a 40 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', '-WWX_mjPf5I', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8910, '2022-07-12 00:40:03.367843+00', '2022-07-12 00:40:03.367843+00', 4894, 4, 1296, '', 'X', '''Niel Gow''s Farewell to Whisky'' is a 48 bar reel for 4 couples in a 4 couple set.', 1, 1, 'Y', 'AZS2IiCneSQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8911, '2022-07-12 00:40:03.3953+00', '2022-07-12 00:40:03.3953+00', 12695, 1, 1296, '', 'X', '''Yorkshire Lasses'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'iEP7hLpYf58', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8912, '2022-07-12 00:40:03.41445+00', '2022-07-12 00:40:03.41445+00', 19083, 2, 1296, '', 'X', '''Countess of Elgin, The'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'lfiPGP1_jtg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8914, '2022-07-12 15:38:50.854114+00', '2022-07-12 15:41:06.238971+00', 522, 6, 202, '', 'A', '', 1, 1, 'Y', 'JBjFYIW2YGs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8915, '2022-07-12 15:40:44.127338+00', '2022-07-12 15:41:16.23677+00', 6634, 3, 202, '', 'A', '', 1, 1, 'Y', 'iUBlStMnWkA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8913, '2022-07-12 15:37:23.545401+00', '2022-07-12 15:41:24.290739+00', 936, 2, 202, '', 'A', '', 1, 1, 'Y', 'j-LNrAbt3Bw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8917, '2022-07-13 14:45:38.113881+00', '2022-07-13 15:41:10.61544+00', 549, 8, 2269, '', 'C', 'Westbury Scottish Club, Bristol, 2014.', 1, 1, 'Y', 'abG0O_Vx260', 0, 181, NULL);
INSERT INTO 'dancevideo' VALUES (8925, '2022-07-16 00:40:02.993843+00', '2022-07-16 00:40:02.993843+00', 8932, 6, 1296, '', 'X', '''Hyperactive Reel, The'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'IdIO8CxgTjQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8918, '2022-07-13 14:54:16.686957+00', '2022-07-13 15:43:24.383437+00', 549, 9, 2269, '', 'C', 'Ruhrball, 2016.  Once through.  Danced with energy.', 1, 1, 'Y', 'BHeqK8SmPkQ', 484, 517, NULL);
INSERT INTO 'dancevideo' VALUES (8916, '2022-07-13 13:00:42.193089+00', '2022-07-13 15:46:14.402186+00', 18288, 2, 2269, '', 'B', 'Spring Dance, Genève, 2019.  Dedicated to Vanessa de Schoene who has been faithfully caring for the Scottish Country Dance group in Lausanne almost since time immemorial.', 1, 1, 'Y', 'cU7eosHzkMU', 2, 195, NULL);
INSERT INTO 'dancevideo' VALUES (8922, '2022-07-16 00:40:02.94776+00', '2022-07-16 00:40:02.94776+00', 4924, 2, 1296, '', 'X', '''New Opera, The'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'E5F3YYpJ1QI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8923, '2022-07-16 00:40:02.962522+00', '2022-07-16 00:40:02.962522+00', 14741, 6, 1296, '', 'X', '''Swan and the Tay, The'' is a 32 bar strathspey for 3 couples in a 3 couple set.', 1, 1, 'Y', 'RM6n1ZAVKxE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8919, '2022-07-16 00:40:02.872817+00', '2022-07-16 00:40:02.97691+00', 1790, 2, 1296, '', 'Z', '''Duke of Hamilton''s Reel'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', 'ec2JzrqT15M', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8920, '2022-07-16 00:40:02.909684+00', '2022-07-16 00:40:03.007697+00', 250, 3, 1296, '', 'Z', '''Glenalmond Gamekeeper, The'' is a 40 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', '2lAZjjbxwq8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8926, '2022-07-16 00:40:03.011145+00', '2022-07-16 00:40:03.011145+00', 250, 4, 1296, '', 'X', '''Glenalmond Gamekeeper, The'' is a 40 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'FwqYGjSYIdI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (8927, '2022-07-16 01:19:48.393308+00', '2022-07-16 08:45:00.813041+00', 7180, 12, 202, '', 'B', 'One of the dancers goes wrong on time 1.42. but corrects it elegantly.  The bright windows in the background and the low camera position make it difficult to follow the dancers clearly.  Eric', 1, 1, 'Y', 'NTPn6GQMg54', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8928, '2022-07-16 20:20:03.933583+00', '2022-07-16 22:35:41.76077+00', 6051, 4, 2269, '', 'C', 'Scottish Party At The Festival "The Breath Of Siberia", Tomsk, Russia, 2017.  Animated dancing.  At one point a dancer sitting out, suddenly races across and joins in the reel at the top.', 1, 1, 'Y', 'Kgc2Y4bUIkA', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8929, '2022-07-16 20:25:21.239399+00', '2022-07-16 22:35:57.644177+00', 6051, 5, 2269, '', 'B', 'Russia, 2018.  Lively dancing.', 1, 1, 'Y', 'cwvIEdONMWI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8930, '2022-07-16 22:35:21.423097+00', '2022-07-16 22:36:11.495595+00', 20957, 1, 202, '', 'D', '', 1, 1, 'Y', 'mD7MOn8Ka2w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8931, '2022-07-17 15:18:34.285243+00', '2022-07-17 15:21:28.795603+00', 6380, 5, 2269, '', 'A', 'Julie Young Dancers, Aberdeen Festival, 2018.  The camera position is rather low and the view is partially obscured by spectators.  The lighting is good and the spectators are in the dark so present minimal distraction.', 1, 1, 'Y', 'tzJ-cFkz-M4', 256, 364, NULL);
INSERT INTO 'dancevideo' VALUES (8933, '2022-07-17 21:38:52.438189+00', '2022-07-17 21:39:58.74597+00', 4239, 9, 202, '', 'D', '', 1, 1, 'Y', 't_TwjbnR84s', 25, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8935, '2022-07-18 10:38:46.545749+00', '2022-07-18 14:49:04.329141+00', 2822, 7, 2269, '', 'B', 'RSCDS Stirling Branch, Drummond Castle, Perthshire, Scotland, 2006.  On-screen and spoken dancing instructions.', 1, 1, 'Y', 'GBcXl1a5FUA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8934, '2022-07-17 21:43:50.310071+00', '2022-07-17 21:45:17.530046+00', 8068, 2, 202, '', 'C', '', 1, 1, 'Y', 'n-8hInj-5KE', 43, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8932, '2022-07-17 16:56:34.193089+00', '2022-07-17 21:45:27.926213+00', 6380, 6, 2269, '', 'B', 'RSCDS Stirling Branch, Drummond Castle, 2004.  On-screen and spoken dancing instructions.', 1, 1, 'Y', 'NA9r2n7ATp4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8936, '2022-07-18 12:17:03.278131+00', '2022-07-18 14:52:01.420549+00', 2822, 8, 2269, '', 'B', 'Ruhrball, 2019.  Danced with gusto.', 1, 1, 'Y', 'F33jPbrvqZ4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8937, '2022-07-20 09:05:10.768251+00', '2022-07-20 09:06:00.925785+00', 1792, 15, 202, '', 'D', '', 1, 1, 'Y', 'cNfFrV17Gnw', 20, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8938, '2022-07-21 09:15:03.567938+00', '2022-07-21 09:15:13.982241+00', 4354, 6, 202, '', 'B', '', 1, 1, 'Y', 'WPFi2DL9Q24', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8939, '2022-07-21 09:33:18.15626+00', '2022-07-21 09:34:44.259996+00', 20958, 1, 202, '', 'D', '', 1, 1, 'Y', 'eKoGWLIsyb8', 27, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8940, '2022-07-22 15:45:35.66402+00', '2022-07-22 22:52:37.096697+00', 1758, 3, 2269, '', 'A', 'Red Thistle Dancers, Campbell Games, 2002. Twice through as part of a longer display.', 1, 1, 'Y', '9j6dz4RX_98', 1165, 1285, NULL);
INSERT INTO 'dancevideo' VALUES (8941, '2022-07-22 23:06:16.409952+00', '2022-07-22 23:17:12.515892+00', 776, 2, 1645, '', 'A', 'Red Thistle Dancers at the 2002 Campbell Games. Twice through as the last part of a longer display.', 1, 1, 'Y', '9j6dz4RX_98', 833, 904, NULL);
INSERT INTO 'dancevideo' VALUES (8942, '2022-07-24 09:08:14.347994+00', '2022-07-25 16:55:41.1534+00', 10881, 1, 1645, '', 'C', 'Lochiel SCD Club 2022.', 1, 1, 'Y', 'cM2ZyD9oTBo', 15, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8898, '2022-07-09 10:08:27.641352+00', '2023-02-02 17:50:59.436485+00', 6362, 2, 202, '', 'A', 'Strictly Scottish (RSCDS Vancouver), 2022. Twice through.', 1, 1, 'Y', 'ULwZTwNnufE', 0, 92, NULL);
INSERT INTO 'dancevideo' VALUES (8946, '2022-07-24 17:51:17.096315+00', '2022-07-24 17:51:33.707236+00', 5366, 2, 202, '', 'A', '', 1, 1, 'Y', 'ktHaCjyUWDY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8963, '2022-07-27 22:16:02.868535+00', '2022-07-27 23:23:05.523492+00', 20872, 1, 1645, '', 'B', 'London Gay Gordons & friends, 2022.', 1, 1, 'Y', 'pqHwcUHCAEs', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8947, '2022-07-24 17:58:30.813743+00', '2022-07-24 17:59:23.338001+00', 358, 7, 202, '', 'A', '', 1, 1, 'Y', 'L0VMvAcGI0k', 31, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8943, '2022-07-24 09:12:49.911031+00', '2022-07-25 16:54:30.018138+00', 10880, 2, 1645, '', 'D', 'Cambridge, New Zealand, 60th anniversary ball, 2015.', 1, 1, 'Y', 'Lran5lQA2J0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8944, '2022-07-24 15:11:15.405345+00', '2022-07-25 17:01:09.832959+00', 6380, 7, 2269, '', 'A', 'RSCDS Stirling, Macrobert Arts Centre, Stirling, Scotland, RSCDS Archive, 1999. Starts and ends with a dance on and off.', 1, 1, 'Y', 'LdtlT3WPRAc', 2133, 2250, NULL);
INSERT INTO 'dancevideo' VALUES (8945, '2022-07-24 15:24:53.413381+00', '2022-07-25 17:06:27.124616+00', 4931, 3, 2269, '', 'C', 'Upper Hutt Scottish Country Dance Club Annual Tea Dance, 2014.  This clip skips over the first repeat which should Just be regarded as the practice, reels ( bars 9-16 ), there are some mistakes.  After that, the dancers settle down.', 1, 1, 'Y', 'AiQ9xUBJXYA', 78, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8950, '2022-07-25 15:54:13.811373+00', '2022-07-25 17:10:50.79375+00', 4046, 12, 2269, '', 'B', 'Budapest Scottish Dance Club, St Andrew''s Day Ceilidh Demonstration Dance, Scottish Mission Church, 2019. Excellent dancing but not to the original music.', 1, 1, 'Y', 'alMjKTiz6YQ', 2, 138, NULL);
INSERT INTO 'dancevideo' VALUES (8949, '2022-07-25 15:44:48.810594+00', '2022-07-25 17:12:04.079431+00', 4046, 11, 2269, '', 'A', 'RSCDS Stirling, Macrobert Arts Centre, Stirling, Scotland, RSCDS Archive, 1999.  Once through.', 1, 1, 'Y', 'LdtlT3WPRAc', 2605, 2643, NULL);
INSERT INTO 'dancevideo' VALUES (8948, '2022-07-25 15:38:49.271282+00', '2022-07-25 17:13:46.633788+00', 4046, 10, 2269, '', 'A', 'RSCDS Stirling Branch, Princes St Gardens, 2013.  On-screen dancing instructions.', 1, 1, 'Y', 'fPGNVFvL0t4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8951, '2022-07-26 02:05:26.87926+00', '2022-07-26 02:05:48.579512+00', 16803, 4, 202, '', 'D', '', 1, 1, 'Y', '-9QHT-x_Suc', 30, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8952, '2022-07-27 12:16:26.09815+00', '2022-07-27 12:16:40.724308+00', 4239, 10, 202, '', 'D', '', 1, 1, 'Y', 'L3vJAVn2gM8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8953, '2022-07-27 12:18:11.754936+00', '2022-07-27 12:18:22.18248+00', 14964, 4, 202, '', 'D', '', 1, 1, 'Y', '1Exe8-aHQHU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8954, '2022-07-27 15:44:51.223017+00', '2022-07-27 21:13:59.01118+00', 8709, 4, 2269, '', 'C', 'Naramata Scottish Country Dancers, Penticton Scottish Festival, British Columbia, Canada, 2018.', 1, 1, 'Y', 'E9yyoGSN9Ek', 34, 209, NULL);
INSERT INTO 'dancevideo' VALUES (8955, '2022-07-27 17:02:48.147386+00', '2022-07-27 21:16:07.144022+00', 8709, 5, 2269, '', 'B', 'Oxford University Scottish Dance Society, BBC Country File Live, Blenheim Palace, 2017.  This clip is once through.', 1, 1, 'Y', 'ydR37w4T3rc', 1259, 1296, NULL);
INSERT INTO 'dancevideo' VALUES (8958, '2022-07-27 21:32:20.827774+00', '2022-07-27 21:40:08.992448+00', 695, 4, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'RbTmWk-9DTg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8959, '2022-07-27 21:35:11.027296+00', '2022-07-27 21:40:14.717976+00', 20035, 1, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', '4a-SvspihnA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8960, '2022-07-27 21:39:54.423172+00', '2022-07-27 21:40:23.962387+00', 14281, 1, 1645, '', 'B', 'Tay Dancers, 2022. The team here are adding some extra polite turns in the rights and lefts.', 1, 1, 'Y', 'kTGFlS__Vlg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8957, '2022-07-27 21:30:38.929806+00', '2022-07-27 21:40:29.118308+00', 6592, 1, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'af_cU33HBis', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8956, '2022-07-27 21:28:08.293938+00', '2022-07-27 21:40:34.865249+00', 7182, 3, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'zwrjJepzy_g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8961, '2022-07-27 22:13:00.357602+00', '2022-07-27 22:18:38.552249+00', 20864, 1, 1645, '', 'B', 'London Gay Gordons & friends, 2022.', 1, 1, 'Y', 'jD0e4tiaKNM', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8962, '2022-07-27 22:15:04.69827+00', '2022-07-27 22:20:36.76206+00', 20871, 1, 1645, '', 'B', 'London Gay Gordons & friends, 2022.', 1, 1, 'Y', 'caMi8awmpmU', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8975, '2022-08-01 21:52:26.74866+00', '2022-08-04 19:07:16.116401+00', 3475, 3, 1645, '', 'B', 'Port Adelaide Caledonian Society: Birthday Celebration 2011. Twice through as the second part of a longer demo. This is only viewable directly on the youtube site.', 1, 1, 'Y', 'zhRfKQFUf5k', 72, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8965, '2022-07-27 22:18:10.482755+00', '2022-07-28 09:30:25.550845+00', 20959, 1, 1645, '', 'B', 'London Gay Gordons & friends, 2022. Fine apart from one quickly corrected momentary lapse in the 4th repeat.', 1, 1, 'Y', 'uv5XgR4lFZc', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8968, '2022-07-28 08:41:48.785946+00', '2022-07-28 11:41:16.995696+00', 20881, 1, 645, '', 'A', 'July 2022', 1, 1, 'Y', 'NJ3WBzFSK0c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8972, '2022-08-01 21:23:32.05812+00', '2022-08-04 19:07:49.306943+00', 8356, 1, 1645, '', 'A', 'Port Adelaide Caledonian Society: Birthday Celebration 2011.', 1, 1, 'Y', '48Wk0eQPK0Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8967, '2022-07-28 08:40:31.909232+00', '2022-07-28 11:42:41.569556+00', 20884, 1, 645, '', 'A', 'July 2022', 1, 1, 'Y', 'Enkl2BxW7D8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8973, '2022-08-01 21:25:38.03459+00', '2022-08-04 19:08:20.460559+00', 14243, 4, 1645, '', 'A', 'Port Adelaide Caledonian Society: Birthday Celebration 2011. Twice through.', 1, 1, 'Y', '53UHRGIWvTM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8966, '2022-07-28 08:39:10.978843+00', '2022-07-28 11:44:19.686998+00', 20880, 1, 645, '', 'A', 'July 2022', 1, 1, 'Y', 'Knhhj3XYBtg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8969, '2022-07-30 23:12:19.245931+00', '2022-07-30 23:12:53.619337+00', 16566, 7, 1645, '', 'B', 'Buenos Aires, 2022. Once through.', 1, 1, 'Y', 'UY_FSPHAmn0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8970, '2022-07-30 23:28:44.102445+00', '2022-07-30 23:44:16.297856+00', 20965, 1, 1645, '', 'C', 'Scottish BlueBell Club Ichikawa, Japan, 2022. Twice through: 7 adults and one little girl.', 1, 1, 'Y', 'mpIOTXbUmz0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8977, '2022-08-05 21:05:18.852469+00', '2022-08-05 22:33:36.778605+00', 20955, 1, 963, '', 'C', '', 1, 1, 'Y', 'NsbGDAiPuBc', 1, 70, NULL);
INSERT INTO 'dancevideo' VALUES (8976, '2022-08-03 12:50:11.780024+00', '2022-08-04 19:04:12.187587+00', 89, 7, 2269, '', 'C', 'Russia, 2018.', 1, 1, 'Y', '4gQQUgsGWI4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8971, '2022-07-30 23:40:20.872272+00', '2022-08-04 19:09:40.971575+00', 20934, 1, 1645, '', 'A', 'Deer O'' Dale Dance School, 2022. Twice through.', 1, 1, 'Y', '5kYyJTZ93kI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (4139, '2018-12-11 19:12:52.241109+00', '2022-08-10 19:02:45.399435+00', 19114, 1, 513, '', 'A', 'The video starts part way through the first repeat (around bar 17 of 48).', 1, 1, 'Y', '6AK4dZX2y9I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8974, '2022-08-01 21:40:36.427461+00', '2022-08-05 11:09:15.825738+00', 413, 11, 1645, '', 'C', 'Port Adelaide Caledonian Society: Birthday Celebration 2011. The first part of a longer demonstration. Only visible on youtube.



Although the dancing is good, this is a cut down version of the dance omitting bars 17-48 and using RH in bars 49-64.', 1, 1, 'Y', 'zhRfKQFUf5k', 0, 64, NULL);
INSERT INTO 'dancevideo' VALUES (443, '2012-12-17 14:17:57.134001+00', '2022-08-11 18:03:42.855299+00', 14552, 1, 1296, '', 'B', 'Houston RSCDS 2011. Good, though on the 1st time, one of the 2nd corners crosses rather than turns (and recovers after the circle).', 1, 1, 'Y', 'jIOHpGSwvcw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8979, '2022-08-11 21:00:53.69494+00', '2022-08-11 21:01:11.064004+00', 18408, 6, 202, '', 'D', '', 1, 1, 'Y', 'Ec7n1BtHZdg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8980, '2022-08-11 21:02:43.166641+00', '2022-08-11 21:02:53.732013+00', 13577, 8, 202, '', 'D', '', 1, 1, 'Y', '12SfwG2WPNw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8981, '2022-08-11 21:05:48.580963+00', '2022-08-11 21:05:58.647821+00', 549, 10, 202, '', 'D', '', 1, 1, 'Y', 'zcg3AVavvoY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8982, '2022-08-11 21:08:14.754394+00', '2022-08-11 21:08:26.127584+00', 549, 11, 202, '', 'D', '', 1, 1, 'Y', 'haG1MRdPv_I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8978, '2022-08-11 20:58:35.947668+00', '2022-08-12 02:19:09.844101+00', 4015, 6, 202, '', 'C', '', 1, 1, 'Y', 'pjyY9qElhcA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7074, '2020-03-28 19:29:43.386551+00', '2022-08-12 17:58:47.790681+00', 1345, 1, 1645, '', 'B', 'Twice through, as the final part of a longer demonstration, in four sets arranged in a cross shape. Dem quality dancing, but in the last 2 bars of the poussette the instructions have turn RH while the dancers here set to partners. The 2nd repeat, in a cross shape, has other variations (switching sets in the reels) to finish the demo.', 1, 1, 'Y', '2Ne1KM3vajg', 235, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8983, '2022-08-13 14:52:36.325028+00', '2022-08-13 15:07:55.80333+00', 13506, 3, 1645, '', 'B', 'Detroit Branch at the Highland Games in Alma Michigan in 2010.', 1, 1, 'Y', 'FoKgsVZli3c', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8985, '2022-08-13 15:02:17.295168+00', '2022-08-13 15:09:39.025275+00', 13500, 2, 1645, '', 'B', 'Detroit Branch at the Highland Games in Alma Michigan in 2011.', 1, 1, 'Y', 'Qyn-3EaZ9Q0', 43, 165, NULL);
INSERT INTO 'dancevideo' VALUES (8984, '2022-08-13 14:59:28.473094+00', '2022-08-13 15:14:40.353815+00', 9807, 1, 1645, '', 'B', 'Detroit Branch at the Highland Games in Alma Michigan in 2007.', 1, 1, 'Y', 'p5XbnfppgP0', 2, 267, NULL);
INSERT INTO 'dancevideo' VALUES (8988, '2022-08-13 15:55:02.056832+00', '2022-08-13 16:03:19.820166+00', 5529, 17, 202, '', 'C', '', 1, 1, 'Y', 'Fjq8aBhbhoE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8986, '2022-08-13 15:50:38.540021+00', '2022-08-13 16:03:06.925631+00', 5529, 16, 202, '', 'C', '', 1, 1, 'Y', 'gNTh3xeYuwI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9193, '2023-01-05 18:42:01.711687+00', '2023-01-05 18:45:46.152618+00', 2811, 1, 1645, '', 'B', 'SCD group Hong Kong, 2022. Twice through.', 1, 1, 'Y', 'Ju4vfX46jSU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9385, '2023-02-22 00:39:18.041965+00', '2023-02-22 09:35:38.776343+00', 21345, 1, 1645, '', 'A', 'Cheboksary, Russia, 2023.', 1, 1, 'Y', 'G4pJwXUbFZQ', 17, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8964, '2022-07-27 22:17:33.96153+00', '2022-08-13 17:51:37.294069+00', 20718, 1, 1645, '', 'B', 'London Gay Gordons & friends, 2022.



This shows the original version of the dance with 3rd couple crossing RH in bars 23-24. Subsequently it was suggested they should half turn with both hands.', 1, 1, 'Y', '2vRT6vj7WYA', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8992, '2022-08-15 12:11:26.025076+00', '2022-08-15 12:11:44.514382+00', 15411, 3, 202, '', 'C', '', 1, 1, 'Y', 'Jt4lUyP1Lws', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8993, '2022-08-15 12:16:17.23343+00', '2022-08-15 12:16:40.258425+00', 17122, 11, 202, '', 'C', '', 1, 1, 'Y', '8KQEmlWr0-A', 33, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8994, '2022-08-15 12:16:17.423299+00', '2022-08-15 12:23:21.873414+00', 4646, 8, 202, '', 'C', '', 1, 1, 'Y', 'oxs410qkEs4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8995, '2022-08-22 22:05:46.063879+00', '2022-08-22 22:21:11.741389+00', 2233, 1, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'F2VETeZ8KPQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8997, '2022-08-22 22:15:39.283022+00', '2022-08-22 22:21:20.120366+00', 11523, 2, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'ezzllDtgHz0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8998, '2022-08-22 22:20:50.872827+00', '2022-08-22 22:21:25.460318+00', 13070, 4, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'IoIGD0baya4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8996, '2022-08-22 22:11:41.603679+00', '2022-08-22 22:21:30.981031+00', 12001, 1, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', '266D-tkZ2n8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9000, '2022-08-22 22:22:12.431921+00', '2022-08-22 22:24:48.884668+00', 7339, 2, 202, '', 'C', '', 1, 1, 'Y', 'mnXhMqvn6yg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9022, '2022-09-03 22:48:52.621915+00', '2022-09-03 22:49:20.408189+00', 11372, 3, 1645, '', 'A', 'Airyhall Girls at the 2017 Aberdeen Festival.', 1, 1, 'Y', 'GPltilBwDBc', 261, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8999, '2022-08-22 22:20:51.35542+00', '2022-08-22 22:25:34.371372+00', 6057, 4, 202, '', 'C', '', 1, 1, 'Y', 'f3cWOPmv9l0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9002, '2022-08-23 07:22:34.423943+00', '2022-08-23 07:22:45.993127+00', 10884, 1, 1645, '', 'B', 'Waikato Bay of Plenty Region, New Zealand, 2022.', 1, 1, 'Y', 'apoDT215XmQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9003, '2022-08-24 16:26:09.881504+00', '2022-08-25 06:41:15.637418+00', 4799, 4, 963, '', 'C', 'From the Blue Ridge Scottish Dance School July 2022

live music by Mara Shea, Liz Donaldson, Terry Traub', 1, 1, 'Y', 'hgL1JR8n93M', 2595, 2921, NULL);
INSERT INTO 'dancevideo' VALUES (9004, '2022-08-25 06:40:50.674531+00', '2022-08-25 06:42:13.799598+00', 20531, 2, 202, '', 'D', '', 1, 1, 'Y', 'bKxLB-MJyB4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9005, '2022-08-25 06:52:13.659948+00', '2022-08-25 06:52:36.011325+00', 9022, 2, 202, '', 'D', '', 1, 1, 'Y', 'JD0kROWrZ1c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9006, '2022-08-26 07:36:38.553105+00', '2022-08-26 07:40:26.452815+00', 20807, 2, 202, '', 'D', '', 1, 1, 'Y', 'E07shAgdNos', 45, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9007, '2022-08-26 07:43:40.915691+00', '2022-08-26 07:44:20.570624+00', 7694, 1, 202, '', 'D', '', 1, 1, 'Y', 'bfpWW7GRkYQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9008, '2022-08-26 08:05:34.206664+00', '2022-08-26 08:06:40.97656+00', 20432, 2, 2824, '', 'C', 'Forres RSCDS summer social, August 2022', 1, 1, 'Y', '4QaeWibgkbk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9009, '2022-08-30 17:04:18.285184+00', '2022-08-30 17:06:23.677485+00', 20997, 1, 1645, '', 'B', 'London Gay Gordons & friends, 2022.', 1, 1, 'Y', 'KOg3RhnDmes', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9012, '2022-08-30 17:14:14.940065+00', '2022-08-30 17:22:49.451576+00', 20998, 1, 1645, '', 'B', 'London Gay Gordons & friends, 2022.', 1, 1, 'Y', 'VqyZQzMuA4Q', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9010, '2022-08-30 17:09:27.755458+00', '2022-08-30 17:23:13.234993+00', 21001, 1, 1645, '', 'B', 'London Gay Gordons & friends, 2022. Once through with just three couples.', 1, 1, 'Y', 'gnCKrsO_3rI', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9011, '2022-08-30 17:13:22.48345+00', '2022-08-30 17:33:22.814366+00', 21000, 1, 1645, '', 'B', 'London Gay Gordons & friends, 2022.', 1, 1, 'Y', '54wKGe3zWCg', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9014, '2022-08-30 17:20:16.170859+00', '2022-08-30 17:46:51.321951+00', 20999, 1, 1645, '', 'B', 'London Gay Gordons & friends, 2022.', 1, 1, 'Y', 'VKq1JOj2NWI', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9021, '2022-09-03 22:43:18.351601+00', '2022-09-03 22:50:13.055029+00', 9561, 7, 1645, '', 'A', 'Airyhall Girls at the 2017 Aberdeen Festival.', 1, 1, 'Y', 'GPltilBwDBc', 2, 262, NULL);
INSERT INTO 'dancevideo' VALUES (9016, '2022-09-03 22:22:43.770222+00', '2022-09-03 22:51:42.594939+00', 1677, 4, 1645, '', 'A', 'St Andrews Summer School 2022, Week 3 Demonstration. Twice through as part of a longer display.', 1, 1, 'Y', 'sLfN4-vA5Dw', 162, 287, NULL);
INSERT INTO 'dancevideo' VALUES (9019, '2022-09-03 22:31:58.386447+00', '2022-09-03 22:52:24.519459+00', 1677, 5, 1645, '', 'A', 'St Andrews Summer School 2022, Week 3 Demonstration. Twice through as part of a longer display.', 1, 1, 'Y', 'AQI6uisMnNw', 152, 275, NULL);
INSERT INTO 'dancevideo' VALUES (9017, '2022-09-03 22:26:53.488041+00', '2022-09-03 22:53:16.812881+00', 3986, 6, 1645, '', 'A', 'St Andrews Summer School 2022, Week 3 Demonstration. Three times as the last part of a longer display.', 1, 1, 'Y', 'sLfN4-vA5Dw', 285, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9015, '2022-09-03 22:20:36.119829+00', '2022-09-03 22:57:58.657495+00', 6711, 1, 1645, '', 'A', 'St Andrews Summer School 2022, Week 3 Demonstration. Three times as the first part of a longer display.', 1, 1, 'Y', 'sLfN4-vA5Dw', 54, 163, NULL);
INSERT INTO 'dancevideo' VALUES (9020, '2022-09-03 22:33:46.31978+00', '2022-09-03 22:58:53.639771+00', 3986, 7, 1645, '', 'A', 'St Andrews Summer School 2022, Week 3 Demonstration. Three times as the last part of a longer display.', 1, 1, 'Y', 'AQI6uisMnNw', 274, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9018, '2022-09-03 22:29:44.523701+00', '2022-09-03 22:59:41.174365+00', 6711, 2, 1645, '', 'A', 'St Andrews Summer School 2022, Week 3 Demonstration. Three times as the first part of a longer display.', 1, 1, 'Y', 'AQI6uisMnNw', 43, 152, NULL);
INSERT INTO 'dancevideo' VALUES (9023, '2022-09-04 08:14:30.833739+00', '2022-09-04 09:08:37.298169+00', 21096, 1, 1645, '', 'D', 'First performance of the dance at the St Andrews Summer School. The deviser and his wife Szilvia start as 1st couple. Some early repeats collapse during the figure of eight grand chain but later they get the hang of it.', 1, 1, 'Y', 'IPg620O4YYM', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9024, '2022-09-05 11:15:24.880537+00', '2022-09-05 11:56:17.042231+00', 10007, 4, 1645, '', 'A', 'Aberdeen, 2018. Twice through as the last part of a longer demo.', 1, 1, 'Y', '6NUjAcVVncQ', 231, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9025, '2022-09-05 11:17:42.521676+00', '2022-09-05 11:57:24.601604+00', 10007, 5, 1645, '', 'A', 'Aurora, 2018. This clip shows just once through of the full dance.', 1, 1, 'Y', 'FQVfk5e56X8', 25, 66, NULL);
INSERT INTO 'dancevideo' VALUES (9026, '2022-09-05 11:32:20.245871+00', '2022-09-05 12:01:05.584472+00', 18528, 1, 1645, '', 'B', 'Aurora at their 2018 festival. Twice through as part of a longer demonstration, here adapted for a 6 couple set instead of the expected 4 couple set. The final allemande is also changed to lead into the next dance in the display.', 1, 1, 'Y', 'D3t06FpVj-k', 384, 512, NULL);
INSERT INTO 'dancevideo' VALUES (9027, '2022-09-05 11:42:14.429707+00', '2022-09-05 12:02:02.73726+00', 10590, 1, 1645, '', 'A', 'Once through (with the deviser as 1st man).', 1, 1, 'Y', 'ajfP_ELv3r8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9029, '2022-09-05 13:55:39.283384+00', '2022-09-05 22:08:40.156264+00', 20878, 1, 645, '', 'B', 'August 2022. Once through.', 1, 1, 'Y', 'LTZP7j22SaI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9030, '2022-09-05 13:56:20.898651+00', '2022-09-05 22:10:00.6539+00', 20882, 1, 645, '', 'B', 'August 2022. Once through.', 1, 1, 'Y', 'T0bg_RP4Qfw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9028, '2022-09-05 13:54:38.619219+00', '2022-09-05 22:11:16.400922+00', 20885, 1, 645, '', 'B', 'August 2022. Once through.', 1, 1, 'Y', 'KNaZdrYIA9k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9031, '2022-09-06 13:18:23.260643+00', '2022-09-07 06:20:39.267592+00', 20222, 1, 2361, '', 'D', 'The video was taken in Portugal after a Scottish dem. ', 1, 1, 'Y', 'TnaK1y8pmtI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9032, '2022-09-08 09:28:36.010049+00', '2022-09-08 09:31:39.029399+00', 1087, 13, 35776, '', 'C', 'Johnsonville/Capital City Combined Annual Dance 2022

Music by Strings Attached

Video by Aline Homes

Due to a camera problem, last three repeats only', 1, 1, 'V', '747135576', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9033, '2022-09-10 19:34:08.88033+00', '2022-09-10 19:34:33.257382+00', 909, 6, 1645, '', 'A', 'International team at the Newcastle Festival 2018.', 1, 1, 'Y', 'u949A-9aGgA', 4, 0, NULL);
INSERT INTO 'dancevideo' VALUES (871, '2013-02-18 22:31:49.585554+00', '2022-09-10 19:37:59.677428+00', 909, 3, 106, '', 'A', 'Edinburgh RSCDS mens team at the 2013 Newcastle Festival.

Here 1st couple dance the variation used in some areas and end back on own sides at the end of bar 8.', 1, 1, 'Y', 'H-P9E56PHuc', 145, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1057, '2013-08-18 10:47:49.618454+00', '2022-09-10 19:38:48.323686+00', 909, 4, 1296, '', 'A', 'Newcastle 2013, Edinburgh Men''s team. View from the side.

Here 1st couple dance the variation used in some areas and end back on own sides at the end of bar 8.', 1, 1, 'Y', 'EZbihVCTTR4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1562, '2014-02-18 04:21:05.343092+00', '2022-09-10 19:40:24.470102+00', 909, 5, 513, '', 'A', 'Edinburgh RSCDS mens team at the 2014 Newcastle Festival.

Here 1st couple dance the variation used in some areas and end back on own sides at the end of bar 8.', 1, 1, 'Y', 'vvSXnxiX-oc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9034, '2022-09-13 09:21:11.034473+00', '2022-09-13 22:59:57.902732+00', 2535, 1, 248, '', 'B', 'Adapted for a three-couple set', 1, 1, 'Y', 'sNaTMwQQ1jA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9035, '2022-09-16 01:41:11.748073+00', '2022-09-16 08:36:29.253889+00', 20956, 1, 963, '', 'B', 'One small error at the end - recovered.', 1, 1, 'Y', 'zuEsKwtj1BQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9036, '2022-09-17 22:52:56.069075+00', '2022-09-17 22:53:29.984473+00', 13621, 7, 202, '', 'C', '', 1, 1, 'Y', 'uVD-9XYfRfg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9038, '2022-09-17 23:40:57.862203+00', '2022-09-18 07:21:25.149207+00', 2349, 3, 35776, '', 'D', 'Johnsonville/Capital City Combined Annual Dance 2022.  

Music by Strings Attached. Recording by Aline Homes.  

The video starts around bar 17.', 1, 1, 'V', '750632653', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9039, '2022-09-18 07:32:56.416398+00', '2022-09-18 07:41:41.297797+00', 21103, 1, 1645, '', 'B', 'Mid Argyll RSCDS, 2014.', 1, 1, 'Y', '9dL00EyJR5M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9040, '2022-09-18 23:18:51.216389+00', '2022-09-19 04:15:30.954283+00', 20310, 1, 1332, '', 'B', 'Lisbon, 2022. Here danced in a 3 couple set.', 1, 1, 'Y', 'nz_z-OZbffE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9041, '2022-09-19 19:37:10.025688+00', '2022-09-19 20:18:09.328802+00', 12577, 1, 1645, '', 'C', 'Mickel Scottish Country Dancing Club, 2022. The instructions suggest 1st couple should turn right hand between the two reels but all possibilities are explored here.', 1, 1, 'Y', '8G5of05WM08', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9043, '2022-09-19 20:11:14.178488+00', '2022-09-19 20:18:58.065804+00', 21110, 1, 1645, '', 'A', 'Red Thistle Dancers, 2022. Once through as part of a longer demo.', 1, 1, 'Y', 'MObhB5LQt24', 37, 98, NULL);
INSERT INTO 'dancevideo' VALUES (9042, '2022-09-19 19:48:48.503654+00', '2022-09-19 20:19:16.401459+00', 6798, 6, 1645, '', 'A', 'Red Thistle Dancers, 2022. Three times.', 1, 1, 'Y', 'BToNyWIKr9g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9044, '2022-09-20 02:39:29.27616+00', '2022-09-20 06:46:08.465952+00', 19943, 1, 2372, '', 'A', 'Kitchener-Waterloo RSCDS, 2022. Twice through.', 1, 1, 'Y', 'HTTecR6C59E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7481, '2020-07-18 12:32:18.207051+00', '2022-09-20 06:50:36.053155+00', 18219, 2, 1645, '', 'Z', 'Kirov Winter Social 2018 demonstration. Was good, but sadly the youtube account is terminated.', 1, 1, 'Y', '0BgTyyKS4Vo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9045, '2022-09-26 07:18:55.459484+00', '2022-09-26 07:19:18.256379+00', 2631, 3, 1645, '', 'A', 'Stirling branch at Princes St Gardens, Edinburgh, 2007. Twice though with voiceover and subtitles.', 1, 1, 'Y', 'zgrV55NSxsg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9046, '2022-09-26 09:29:02.576118+00', '2022-09-26 09:29:18.644311+00', 10908, 1, 1645, '', 'B', 'Lochiel SCD, 2022. Danced in class with a little voiceover coaching resulting in a clear demonstration of the dance.', 1, 1, 'Y', 'fYacnQuVlWo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9047, '2022-09-27 01:25:37.710857+00', '2022-09-27 01:25:56.240275+00', 12892, 3, 202, '', 'D', '', 1, 1, 'Y', 'CddzdrhuwWc', 40, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9048, '2022-09-27 10:57:05.758987+00', '2022-09-27 10:57:19.685883+00', 790, 1, 1645, '', 'B', 'Lochiel SCD club, 2022. Danced in class to the recommended recording (without a chord).', 1, 1, 'Y', 'Tw3_gejlmXE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9049, '2022-09-27 11:10:14.731102+00', '2022-09-27 11:10:28.259858+00', 21111, 1, 202, '', 'B', '', 1, 1, 'Y', 'saJUgizTcBw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5241, '2019-10-10 19:17:03.933517+00', '2022-09-28 00:07:35.825478+00', 1131, 1, 1645, '', 'C', 'SCD group Hong Kong, 2018. Twice through (almost). 1st place is not always in view. Good dancing but some differences from the instructions, eg 1st & 3rd couples ought to end the reels with nearer hands joined for petronella in tandem. Here the dancers petronella into the corners rather than staying together.', 1, 1, 'Y', 'bO3RmxirvVI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9050, '2022-09-28 00:08:39.61108+00', '2022-09-28 00:10:51.508182+00', 9487, 1, 1645, '', 'B', 'SCD group Hong Kong, 2022.', 1, 1, 'Y', 'LOfBFNKI7uo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9052, '2022-09-28 00:39:42.102446+00', '2022-09-28 00:41:36.275124+00', 16884, 1, 1645, '', 'C', 'SCD group Hong Kong, 2022. Nicely danced (with a few hesitations) though with a couple of variations from the original instructions. In bars 5-8 the dancers here do two left hands across (at each end) rather than one in the middle. And in the final mirror set and links, the central two couples dance through the middle rather than casting to the ends. The first variation works well but the second looks slightly more awkward than was intended.', 1, 1, 'Y', 'r0lWaMKS83k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9051, '2022-09-28 00:20:35.222808+00', '2022-09-28 00:41:54.333277+00', 20959, 2, 1645, '', 'B', 'SCD group Hong Kong, 2022. Twice through. Ideally 1st couple should pass right shoulders both times when turning corners.', 1, 1, 'Y', 'T8hsNSaBbEE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9053, '2022-09-28 00:51:35.956221+00', '2022-09-28 01:04:42.411043+00', 14231, 1, 1645, '', 'B', 'SCD group Hong Kong, 2014. The first part of a longer demonstration medley with the final circle changed to lead into the next dance in the display. The clip starts with the dancing. The whole video has a longer introduction about the group.', 1, 1, 'Y', 'VXSf9MgChKE', 78, 176, NULL);
INSERT INTO 'dancevideo' VALUES (9054, '2022-09-28 01:00:21.853904+00', '2022-09-28 01:06:01.032841+00', 3921, 1, 1645, '', 'B', 'SCD group Hong Kong, 2014. The second part of a lovely demonstration - though the slow crossing RH and back at the start of the reel section are here replaced by quicker turns, perhaps to make a livelier display.', 1, 1, 'Y', 'VXSf9MgChKE', 175, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9057, '2022-09-30 16:55:26.585765+00', '2022-09-30 17:04:21.968979+00', 1535, 5, 1645, '', 'B', 'Ochil Scottish Country Dancers, 2016. With spoken commentary and subtitles.', 1, 1, 'Y', 'Ry5bvvyR0g4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9056, '2022-09-30 16:52:47.524815+00', '2022-09-30 17:04:37.410863+00', 1535, 4, 1645, '', 'X', '', 1, 1, 'Y', 'KCmNzGYaBz0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9058, '2022-09-30 17:10:09.176388+00', '2022-09-30 17:10:28.136718+00', 1535, 6, 1645, '', 'C', '', 1, 1, 'Y', 'BDXUTs3Ohz4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9055, '2022-09-29 20:25:20.831607+00', '2022-09-30 17:10:35.743522+00', 20781, 1, 1645, '', 'C', 'Buenos Aires, 2022. Most of two repeats, the 2nd one looking better.', 1, 1, 'Y', '_U5xuLs7bgM', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2039, '2015-03-15 15:43:54.917207+00', '2022-10-03 22:12:48.664449+00', 16159, 1, 197, '', 'Z', 'Was considered Good. Now made private on youtube.', 1, 1, 'Y', 'Omwx0I-iHi8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9059, '2022-10-04 10:07:30.607187+00', '2022-10-04 10:08:18.877315+00', 9638, 11, 202, '', 'D', '', 1, 1, 'Y', 'KxTmmbeHPv8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9060, '2022-10-10 21:14:09.599762+00', '2022-10-10 21:14:28.181908+00', 13622, 1, 202, '', 'C', '', 1, 1, 'Y', '_HH_ZT7qJNQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9061, '2022-10-10 21:19:12.347818+00', '2022-10-10 21:19:23.897431+00', 1582, 15, 202, '', 'D', '', 1, 1, 'Y', 'EqShm5XeKMA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9062, '2022-10-11 20:43:46.106619+00', '2022-10-11 20:43:57.525229+00', 20402, 1, 202, '', 'C', '', 1, 1, 'Y', 'Fvc4eSPrVaI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2467, '2016-04-21 22:20:49.156354+00', '2022-10-11 21:51:24.847016+00', 16857, 1, 1645, '', 'B', 'Geneva Spring Dance (in Dardagny), 2016. A few hesitations but otherwise choreographically fine.



The selected video clip starts with the dancing. The complete video starts with a walkthrough and the band playing the tunes by Muriel Johnstone.', 1, 1, 'Y', 'Mn3E55dmj4w', 265, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9063, '2022-10-12 10:42:31.449502+00', '2022-10-12 10:44:09.01472+00', 13351, 2, 202, '', 'C', '', 1, 1, 'Y', 'dF0oLLVM1cg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9064, '2022-10-12 10:47:44.521987+00', '2022-10-12 10:48:03.292107+00', 4175, 2, 202, '', 'C', '', 1, 1, 'Y', 'CTrcJ9yYL8M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9065, '2022-10-12 19:43:16.461624+00', '2022-10-12 19:43:16.461624+00', 19399, 1, 2220, 'dd/dance/video/upload/Lady_McGowans_Nightmare.mp4', 'B', 'The Berkeley class October 2022.  We had been working on dances with Tournees, this is one of at least three published dances where the figure starts in promenade hold from the sidelines -- a nice entry.', 0, 0, 'I', '', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9067, '2022-10-17 07:31:43.263433+00', '2022-10-17 07:32:38.878963+00', 10906, 1, 1645, '', 'C', 'Waikato Bay of Plenty Dancers, 2022.', 1, 1, 'Y', '4G9dqKUe0zA', 11, 268, NULL);
INSERT INTO 'dancevideo' VALUES (9066, '2022-10-16 22:45:08.440645+00', '2022-10-16 22:47:17.118394+00', 20625, 1, 1645, '', 'B', 'Thistle Club, Wing, 2022. This clip shows once through the dance. The whole video starts with a walk through by the deviser.', 1, 1, 'Y', '0epA6fvkW1k', 89, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9068, '2022-10-17 23:01:14.73505+00', '2022-10-17 23:01:58.714623+00', 7575, 1, 1645, '', 'B', 'St John''s SCD Club, 2022. Twice through.', 1, 1, 'Y', 'XlcSEENWyu4', 14, 104, NULL);
INSERT INTO 'dancevideo' VALUES (9069, '2022-10-17 23:16:21.839816+00', '2022-10-17 23:17:50.263238+00', 20824, 1, 1645, '', 'C', 'St John''s SCD Club, 2022. Twice through.', 1, 1, 'Y', '25f6OFyziQ4', 10, 82, NULL);
INSERT INTO 'dancevideo' VALUES (9071, '2022-10-18 20:53:11.199895+00', '2022-10-19 13:59:36.357623+00', 15672, 1, 1993, '', 'B', 'Jacqui''s Lib. 4x32J by Morton Jay, danced at Southern Fling, Sydney Oct 2022, music by The Black Bear Duo.', 1, 1, 'Y', 'zkmEMGGG6zc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9073, '2022-10-22 14:29:02.669812+00', '2022-10-22 14:29:51.050799+00', 5831, 1, 202, '', 'B', '', 1, 1, 'Y', 'mP-Oi5hYGv4', 10, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9078, '2022-10-23 22:51:06.943471+00', '2022-10-23 22:56:43.337761+00', 21150, 1, 1645, '', 'B', 'London Gay Gordons & Friends, 2022.', 1, 1, 'Y', '3SeB8CZyrBI', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9076, '2022-10-23 13:31:33.619135+00', '2022-10-23 23:01:38.93645+00', 4865, 1, 2755, '', 'A', '', 1, 1, 'Y', 'Wmklg04qzdg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9074, '2022-10-23 13:29:12.81715+00', '2022-10-23 23:03:20.911877+00', 6824, 2, 2755, '', 'A', '', 1, 1, 'Y', 'fErZRPq8TJs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9075, '2022-10-23 13:30:47.29557+00', '2022-10-23 23:05:11.710097+00', 7055, 6, 2755, '', 'A', '', 1, 1, 'Y', 'eWieZIdoBq4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9072, '2022-10-21 13:20:23.64925+00', '2022-10-24 08:37:43.765432+00', 6098, 1, 586, '', 'C', 'Delaware Valley Branch RSCDS Friday class in Moylan PA, USA. Music by Mara Shea and Dave Wiesler, Album Heather Hills 909 - SCDDB



Very good dancing. The instructions for bars 25-32 include a turn with both hands between dancing out each side and casting round. That is omitted here.', 1, 1, 'Y', '0ew1ynB-PHY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9081, '2022-10-24 09:28:20.865225+00', '2022-10-24 09:29:07.256528+00', 9735, 1, 202, '', 'B', '', 1, 1, 'Y', '8T2c6pkSH9o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9082, '2022-10-24 22:34:39.651312+00', '2022-10-24 22:35:16.937047+00', 21151, 1, 1645, '', 'B', 'London Gay Gordons & Friends, 2022. There are some hesitations and missed shoulder passes here and there but generally the choreography of the weasel reels is correct.', 1, 1, 'Y', 'uY9UvnyrH2U', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9083, '2022-10-25 23:08:50.104996+00', '2022-10-25 23:15:37.740182+00', 21153, 1, 1645, '', 'A', 'Richmond (North Yorkshire) 2022.', 1, 1, 'Y', 'SK8gIrSRt5k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9084, '2022-10-27 21:26:21.475741+00', '2022-10-28 08:08:12.706957+00', 14967, 1, 1957, '', 'D', 'Danced at a party to celebrate the birthday of the deviser, Ruth Beattie (1st Woman).   1st couple dance twice through but the other three couples just dance once each and the progression was changed.  There was little space but great fun at a very happy event.', 1, 1, 'Y', 'IrFCQOK1ooU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9085, '2022-10-30 13:55:32.966398+00', '2022-10-30 14:17:36.66347+00', 20883, 1, 645, '', 'A', 'September 2022', 1, 1, 'Y', 'h42qJEC4SQo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9086, '2022-10-30 13:56:25.736102+00', '2022-10-30 14:19:33.128593+00', 20879, 2, 645, '', 'A', 'September 2022', 1, 1, 'Y', 'FxNR1Lp4uRo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9087, '2022-10-31 01:40:03.211571+00', '2022-10-31 01:40:03.211571+00', 13589, 8, 1296, '', 'X', '''Peggy Spouse MBE'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', '1uGjtVghhBY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9088, '2022-10-31 01:40:03.24521+00', '2022-10-31 01:40:03.24521+00', 480, 2, 1296, '', 'X', '''Berwick Johnnie'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', '3V7lvVt8tdE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9089, '2022-10-31 01:40:03.266429+00', '2022-10-31 01:40:03.266429+00', 11498, 2, 1296, '', 'X', '''Thor''s Hammer'' is a 32 bar jig for 2 couples in a 4 couple set.', 1, 1, 'Y', 'e4pf1tLFcdg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9090, '2022-10-31 01:40:03.277852+00', '2022-10-31 01:40:03.277852+00', 2600, 8, 1296, '', 'X', '''Golden Wedding Strathspey'' is a 40 bar strathspey for 4 couples in a 4 couple set.', 1, 1, 'Y', 'w7GOV5URO2U', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9091, '2022-10-31 01:40:03.289155+00', '2022-10-31 01:40:03.289155+00', 12586, 1, 1296, '', 'X', '''Fyrefly Reel'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'xE9PCHuLyEI', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9092, '2022-10-31 23:18:17.782046+00', '2022-10-31 23:18:37.843624+00', 21090, 1, 1645, '', 'B', 'Lower Hutt Club, NZ, 2022. This clip skips the first time through which has some mishaps. From the 2nd time onwards its clear.', 1, 1, 'Y', 'Kz5uypa2vYY', 65, 0, NULL);
INSERT INTO 'dancevideo' VALUES (8462, '2022-02-12 09:54:41.097078+00', '2022-10-31 23:31:33.962968+00', 9638, 10, 2269, '', 'Z', 'Russia, 2018.  Dancing is good.  The camera position is between two sets making it more difficult to follow the formations.



No longer available.', 1, 1, 'Y', '9t8ahQ2DKCk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9093, '2022-11-01 22:14:46.098974+00', '2022-11-01 22:17:30.457978+00', 20070, 3, 31370, '', 'D', 'Celebrating Christmas Eve at Paul''s on Bleecker Street, 2018', 1, 1, 'Y', 'mFL8aQkUUYc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9094, '2022-11-02 00:05:29.30537+00', '2022-11-02 07:09:04.14683+00', 20078, 2, 31370, '', 'D', 'The Mystic Scottish Country Dancers on Nauset Beach, Cape Cod, Massachusetts, December 2020.

Danced one time through. The progression is not accurate. (wind noise in the audio)', 1, 1, 'Y', '6GptpuyX2nI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9100, '2022-11-17 00:24:48.660804+00', '2022-11-17 00:27:58.569675+00', 21144, 1, 1645, '', 'B', 'Nizhniy Novgorod, 2022. This clip shows once through in reel time, then twice in strathspey.', 1, 1, 'Y', '0efcc70R9rk', 17, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9095, '2022-11-08 06:21:49.27335+00', '2022-11-08 06:43:18.333836+00', 16909, 1, 202, '', 'B', '', 1, 1, 'Y', '1ACMDV6r7xo', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5420, '2019-11-25 09:23:19.650257+00', '2022-11-08 10:04:06.262451+00', 10548, 3, 513, '', 'B', 'The first 8 bars are missing!', 1, 1, 'Y', 'UMtpeyyNvEM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9096, '2022-11-10 07:50:28.695406+00', '2022-11-10 07:51:04.038409+00', 20625, 2, 202, '', 'B', '', 1, 1, 'Y', '8nHCFiLTD_I', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9097, '2022-11-10 08:45:30.022097+00', '2022-11-10 08:46:26.871591+00', 14688, 8, 1645, '', 'B', 'Buenos Aires, 2022. The video starts at the 2nd chord as 3rd & 4th couples are crossing over.', 1, 1, 'Y', 'HD9oE-aaUy0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9098, '2022-11-11 21:46:16.97066+00', '2022-11-11 22:47:11.114111+00', 19165, 2, 105, '', 'B', 'Very beginning was missed.', 1, 1, 'Y', 'E8n_kzxD60k', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (5037, '2019-09-05 12:06:56.949912+00', '2022-11-13 18:55:05.227686+00', 5915, 6, 1645, '', 'Z', 'Excellent set at the 2017 spring fling in a close up view with some dancers out of view at times.



Was considered Good but now unavailable.', 1, 1, 'Y', 'zW61sP440Lg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9099, '2022-11-14 18:41:11.99566+00', '2022-11-14 18:41:11.99566+00', 18248, 1, 595, 'dd/dance/video/upload/trim.FC5EB01D-E5FE-4F27-8607-FFD7173606E9.MOV', 'B', 'Danced at Headington 60th Anniversary Dance on 12 November 2022. Music played by Sandy Nixon & Keith Anderson. The first tune is the tune “A Jig for Jessie” written by Vincent McCourt. ', 0, 0, 'I', '', 136, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9101, '2022-11-17 00:25:02.123183+00', '2022-11-17 00:28:13.097622+00', 20287, 3, 1645, '', 'A', 'Red Thistle Dancers at the Asilomar Weekend, 2022.', 1, 1, 'Y', '54Ljv6SN3j0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9102, '2022-11-17 10:54:48.767048+00', '2022-11-17 11:03:27.362369+00', 2814, 1, 1645, '', 'B', 'RSCDS Edinburgh, Halloween 2022. Excellent dancing but this 4 couple dance is here adapted slightly for 6 couples so not quite the original choreography. Its generally best to watch the top four couples.', 1, 1, 'Y', 'M32Tyoefq9M', 10, 138, NULL);
INSERT INTO 'dancevideo' VALUES (9103, '2022-11-17 11:00:52.282827+00', '2022-11-17 11:05:32.341444+00', 10052, 2, 1645, '', 'A', 'RSCDS Edinburgh, Halloween 2022. Here danced in two 3 couple sets each each with their own ghost.', 1, 1, 'Y', 'M32Tyoefq9M', 138, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9105, '2022-11-17 11:22:53.967598+00', '2022-11-17 11:26:15.10639+00', 5829, 4, 1645, '', 'C', 'Melbourne Colonial Dancers, November 2017. With calling throughout the first couple of times.', 1, 1, 'Y', 'EaecNX1nEVA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9104, '2022-11-17 11:10:46.841385+00', '2022-11-17 11:26:35.435655+00', 2394, 10, 1645, '', 'A', 'RSCDS Leeds at the 2005 Newcastle Festival.', 1, 1, 'Y', 'G9b91h-bijw', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9106, '2022-11-18 00:08:26.713157+00', '2022-11-18 00:08:50.383389+00', 21090, 2, 1645, '', 'B', 'Capital City SCD Club, NZ, 2022.', 1, 1, 'Y', 'KhmqkHmUuP4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9107, '2022-11-18 00:16:33.054223+00', '2022-11-18 00:19:48.716979+00', 20897, 2, 1645, '', 'C', 'Kelburn SCD Club, 2022.', 1, 1, 'V', '722857770', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9108, '2022-11-18 23:11:50.142194+00', '2022-11-18 23:32:05.920733+00', 14695, 1, 1645, '', 'C', 'Gleneagles Scottish Country Dance Club, 2022.', 1, 1, 'Y', 'hwOaCd_Tbos', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9109, '2022-11-18 23:24:31.24848+00', '2022-11-18 23:32:54.458551+00', 2260, 6, 1645, '', 'C', 'RSCDS SW Washington State Branch, 2022. Danced outside with a backdrop of the Multnomah Falls (Oregon) in a 4 couple set with each 1st couple ending in 4th place. The dancing starts around 0:20 after a view of the waterfalls.', 1, 1, 'Y', 'b4CU8o7c6Rs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9110, '2022-11-20 21:40:00.523953+00', '2022-11-20 23:35:36.105098+00', 1888, 1, 1645, '', 'A', 'Cincinatti RSCDS 2007. Danced to bagpipes.', 1, 1, 'Y', 'eMYm9RZ6cUo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9111, '2022-11-20 23:30:28.499207+00', '2022-11-21 00:04:00.307776+00', 21167, 1, 10819, '', 'A', 'Deviser says: "Only minor glitches, hardly visible. Deviser dances as fourth man. Video shows first repeat, then fades out."', 1, 1, 'Y', 'FEjbmRYAFio', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9112, '2022-11-21 10:00:41.882141+00', '2022-11-21 10:40:27.374451+00', 20032, 1, 10819, '', 'A', 'Deviser says: "Only minor glitches during first repeat during the ''Mystic Knot'' central figure - strictly one step in, change partner and then one step out to the sides makes the figure work in perfection. Deviser dances as first man."', 1, 1, 'Y', 'M7Yt6nidzPo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9113, '2022-11-21 18:12:20.167786+00', '2022-11-21 20:31:58.434826+00', 21169, 1, 10819, '', 'A', 'Deviser says: "Only minor glitches at some twirls and occasional hesitations during the ''Mixer Chain''. Deviser dances as fifth man in the center." ', 1, 1, 'Y', '3AGd7LaEIR8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9186, '2022-12-25 01:40:03.446161+00', '2022-12-25 01:40:03.446161+00', 12019, 2, 1296, '', 'X', '''Swirling Snow'' is a 32 bar strathspey for 3 couples in a 3 couple set.', 1, 1, 'Y', '5p1Xo418Mj0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9187, '2022-12-27 01:40:02.900825+00', '2022-12-27 01:40:02.900825+00', 841, 2, 1296, '', 'X', '''Brownie of Blednoch, The'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', '6d2diDtjnFg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9114, '2022-11-21 18:27:15.153331+00', '2022-11-21 20:32:11.849675+00', 21170, 1, 10819, '', 'A', 'Deviser says: "Two quite perfect repeats before the video fades out. Dance is shown in an alternative 3 couple setup, but originally meant to be danced in a 4 couple set, eight times through. Deviser dances as first man."', 1, 1, 'Y', 'q1P241-HM_g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9118, '2022-11-23 19:54:28.513995+00', '2022-11-23 19:57:35.549335+00', 12902, 1, 106, '', 'B', 'Danced on 20 november 2022', 1, 1, 'Y', 'yF6yNUZprKo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9123, '2022-11-23 23:37:15.429232+00', '2022-11-23 23:43:51.278566+00', 3364, 3, 1645, '', 'B', 'Crieff Hydro Weekend Demonstration. Once through with slight adaptation at the end to lead into the next dance in the display. The camera veers off to show the audience for part of the dance. So not ideal for learning the dance.', 1, 1, 'Y', 'G3lbwyF91AA', 109, 172, NULL);
INSERT INTO 'dancevideo' VALUES (9117, '2022-11-23 10:06:32.661171+00', '2022-11-23 23:44:15.815764+00', 21171, 1, 1645, '', 'C', 'Méaudre Reel course, 2022. With voiceover (in french).', 1, 1, 'Y', '-GO-FD4eXH0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9120, '2022-11-23 23:15:20.77133+00', '2022-11-23 23:44:40.346674+00', 4911, 2, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'zahE2YEP-9w', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9119, '2022-11-23 23:10:26.795024+00', '2022-11-23 23:45:05.437967+00', 12532, 3, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'qQTau1jGk6g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9121, '2022-11-23 23:23:37.651668+00', '2022-11-23 23:45:49.188523+00', 9476, 1, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'IVUejRr0Jr4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9122, '2022-11-23 23:30:01.594554+00', '2022-11-23 23:46:22.582915+00', 3365, 9, 1645, '', 'B', 'Crieff Hydro Weekend Demonstration. Twice through.', 1, 1, 'Y', 'G3lbwyF91AA', 37, 110, NULL);
INSERT INTO 'dancevideo' VALUES (9124, '2022-11-23 23:42:39.443117+00', '2022-11-23 23:47:41.510231+00', 9869, 1, 1645, '', 'A', 'Crieff Hydro Weekend Demonstration.', 1, 1, 'Y', 'G3lbwyF91AA', 171, 278, NULL);
INSERT INTO 'dancevideo' VALUES (468, '2012-12-17 14:18:04.804369+00', '2022-11-24 19:15:55.160594+00', 1582, 4, 1296, '', 'D', 'Very well danced - with lots of exuberant variations, eg couples dancing poussettes instead of allemande, etc.', 1, 1, 'Y', 'Ql15qg4egtQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9125, '2022-11-26 06:37:54.214111+00', '2022-11-26 08:58:48.907563+00', 20736, 1, 20350, '', 'B', 'Carterton SCD Club, NZ, 2022. Twice through.', 1, 1, 'Y', 'unidg5IOJhw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9134, '2022-12-05 16:44:09.108714+00', '2022-12-05 17:04:46.077285+00', 11438, 2, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'QbM_iDJKxrg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9129, '2022-11-26 15:49:47.39418+00', '2022-11-27 00:09:20.869606+00', 13758, 1, 2755, '', 'A', 'Belfast Branch, 2022. Twice through.', 1, 1, 'Y', 'zpOVkt9fVDI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9126, '2022-11-26 15:46:07.82258+00', '2022-11-27 00:09:43.301589+00', 17430, 1, 2755, '', 'A', 'Belfast Branch, 2022. Twice through.', 1, 1, 'Y', 'lzsi7UEwnFU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9127, '2022-11-26 15:46:55.570124+00', '2022-11-27 00:11:59.635923+00', 3174, 1, 2755, '', 'A', 'Belfast Branch, 2022. Twice through.', 1, 1, 'Y', 'ADupHluuhTM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9128, '2022-11-26 15:48:58.488078+00', '2022-11-27 00:16:54.811227+00', 13727, 6, 2755, '', 'A', 'Belfast Branch, 2022.', 1, 1, 'Y', '-Bi_XSGWMQU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9130, '2022-11-27 13:33:19.999838+00', '2022-11-27 19:01:17.118001+00', 20893, 1, 24698, '', 'B', 'RSCDS Paris, 2022.



To finish the Reel of 3 in second place, 1c makes a loop (Rsh back for 1st man as in the video but a big loop Lsh back for 1st woman), before starting dancing the figure of love.', 1, 1, 'Y', 'PxMbhzGICPI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9132, '2022-11-27 20:30:41.008224+00', '2022-11-27 21:08:21.204775+00', 3684, 1, 36088, '', 'C', '', 1, 1, 'Y', 'mHNlt9Fr21A', 138, 412, NULL);
INSERT INTO 'dancevideo' VALUES (9133, '2022-11-29 16:03:58.896115+00', '2022-11-29 21:10:08.274455+00', 8162, 3, 2794, '', 'B', 'Pas-de-Basque step is used by some dancers in the 2-hand turn (bars 17-20).', 1, 1, 'Y', 'tW_uLzGWWdY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1643, '2014-05-05 19:20:38.05394+00', '2022-12-01 17:50:36.254802+00', 8162, 1, 1041, '', 'Z', 'Click on the link to play this video on VIMEO: the automatic link is disabled.



Educational video to help everyone to take the floor and participate in the commonwealth ceilidh on the 21st June 2014



Previously classed as Reasonable, now unavailable on Vimeo.', 1, 1, 'V', '89897918', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9137, '2022-12-05 17:03:07.48166+00', '2022-12-05 17:03:32.475714+00', 11777, 2, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'EYOJmT-dWyo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9136, '2022-12-05 16:55:46.119432+00', '2022-12-05 17:03:56.484476+00', 13442, 1, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'pd6v4TRkdeM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9135, '2022-12-05 16:49:51.819137+00', '2022-12-05 17:04:16.968752+00', 2575, 1, 1645, '', 'B', 'Tay Dancers, 2022.', 1, 1, 'Y', 'd71WLcKm34g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9142, '2022-12-05 23:59:18.48287+00', '2022-12-06 00:02:18.325165+00', 20780, 2, 1645, '', 'B', 'Méaudre Reel, 2022. Lively performance, generally good though with a few hesitations in the first repeat and a false start later on.', 1, 1, 'Y', 'MkD_63xFDMs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9143, '2022-12-07 01:40:03.071483+00', '2022-12-07 01:40:03.071483+00', 14974, 4, 1296, '', 'X', '''Aging Gracefully'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', 'XC6DRGjqLjA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9144, '2022-12-07 01:40:03.092749+00', '2022-12-07 01:40:03.092749+00', 2391, 1, 1296, '', 'X', '''Galloway Tale, A'' is a 32 bar reel for 4 couples in a 4 couple set.', 1, 1, 'Y', 'vHyKtmh5ZwA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9146, '2022-12-07 01:40:03.126851+00', '2022-12-07 01:40:03.126851+00', 615, 2, 1296, '', 'X', '''Bobby Brown''s Canadian Breakdown'' is a 32 bar reel for 4 couples in a 4 couple set.', 1, 1, 'Y', 'J8DApx8m3Kc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (5454, '2019-11-29 18:59:40.507668+00', '2022-12-08 11:08:14.750648+00', 6571, 1, 1645, '', 'B', 'Little Rock, Arkansas, 2011. Once each couple in a 4 couple set with 1st couple casting off to the bottom at the end of the promenade as Drewry recommends.', 1, 1, 'Y', 'pe4TnvPbAnQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9147, '2022-12-07 23:29:04.294743+00', '2022-12-08 10:25:54.053759+00', 8161, 3, 2361, '', 'K', '', 1, 1, 'Y', 'QGe4qc-s5Zk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9148, '2022-12-08 21:32:36.2619+00', '2022-12-09 10:21:35.053005+00', 21164, 1, 2475, '', 'B', 'Danced at the Atholl SCD Club, Edinburgh, December 2022', 1, 1, 'Y', 'd3ftP5zhKpc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9166, '2022-12-16 01:40:03.990149+00', '2022-12-16 01:40:03.990149+00', 19034, 2, 1296, '', 'X', '''Pilot''s Delight'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'MUUCC6VBgRk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9150, '2022-12-09 01:40:03.373534+00', '2022-12-09 01:40:03.373534+00', 2704, 3, 1296, '', 'X', '''Gumboot Rant, The'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'Dj41ox_kXpg', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9152, '2022-12-09 15:03:10.229089+00', '2022-12-09 15:38:47.257238+00', 21155, 1, 2475, '', 'B', 'Danced at the Atholl SCD Club, Edinburgh, April 2022, in a five-couple set (though the dance is intended for a four couple set). The dance devisor is dancing first lady.', 1, 1, 'Y', 'zoIFwWDv_5M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9151, '2022-12-09 13:34:51.164283+00', '2022-12-09 15:40:55.426313+00', 9882, 2, 2630, '', 'B', '', 1, 1, 'Y', 'ZIzWsVSevOQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9153, '2022-12-12 09:24:16.593737+00', '2022-12-12 11:26:19.332146+00', 20572, 2, 3069, '', 'B', 'The challenge comes from the frequent changing of feet and is where most mistakes occured.

The Rechberg dancers learnt both the Waltz Hold Poussette and Dances on the morning of the video.



Here danced, 3 times, in the original 24 bar version.', 1, 1, 'Y', 'SF2GV92EPZA', 0, 84, NULL);
INSERT INTO 'dancevideo' VALUES (1498, '2013-12-08 16:22:09.822391+00', '2022-12-16 18:13:53.430144+00', 2260, 3, 274, '', 'D', 'Budapest, Scottish Dance House for Beginners, 2013. XII.



Instead of returning to 2nd place, the dancing couples stops in 3pl on bar 24', 1, 1, 'Y', '0eUPvjo3sqs', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9156, '2022-12-12 09:37:38.181472+00', '2022-12-12 11:40:46.502011+00', 20569, 2, 3069, '', 'B', 'The challenge comes from the frequent changing of feet and is where most mistakes occured.

The Rechberg dancers learnt both the Waltz Hold Poussette and Dances on the morning of the video. 

PDB is used not SCS.', 1, 1, 'Y', '482EAyL_qwc', 0, 114, NULL);
INSERT INTO 'dancevideo' VALUES (9155, '2022-12-12 09:30:16.360547+00', '2022-12-12 11:43:11.849295+00', 20573, 2, 3069, '', 'B', 'The challenge comes from the frequent changing of feet and is where most mistakes occured.

The Rechberg dancers learnt both the Waltz Hold Poussette and Dances on the morning of the video. 

PDB is used and not SCS.



Here danced, 3 times, in the default 24 bar version.', 1, 1, 'Y', 'oMot8bXjfmg', 0, 84, NULL);
INSERT INTO 'dancevideo' VALUES (9154, '2022-12-12 09:28:17.80708+00', '2022-12-12 11:45:52.608189+00', 20568, 2, 3069, '', 'B', 'The challenge comes from the frequent changing of feet and is where most mistakes occured.

The Rechberg dancers learnt both the Waltz Hold Poussette and Dances on the morning of the video. ', 1, 1, 'Y', 'rUreNZcm5cs', 0, 109, NULL);
INSERT INTO 'dancevideo' VALUES (2689, '2016-10-17 11:48:51.083369+00', '2022-12-12 11:58:04.734404+00', 5808, 1, 1022, '', 'A', 'Two sets, once through only.  Part of a longer display of the International Team, Newcastle 2013.', 1, 1, 'Y', 'wLFsCs0TAB4', 12, 47, NULL);
INSERT INTO 'dancevideo' VALUES (9158, '2022-12-12 12:07:20.447699+00', '2022-12-13 10:25:22.340186+00', 5808, 3, 1645, '', 'B', 'Excellent dancing but to sung music with an extra two bars at the end of each repeat (the end couples make additional turns while the central couple set - neither of which is part of the original instructions).', 1, 1, 'Y', '5nhaE4DmQGM', 174, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9157, '2022-12-12 11:56:25.945761+00', '2022-12-13 10:25:44.842735+00', 9088, 2, 1645, '', 'B', 'Excellent dancing but here the corners are setting all the time when not otherwise involved which is not part of the original instructions.', 1, 1, 'Y', '5nhaE4DmQGM', 22, 168, NULL);
INSERT INTO 'dancevideo' VALUES (7626, '2020-10-09 08:58:54.99876+00', '2022-12-19 22:49:19.424643+00', 7149, 2, 35776, '', 'C', 'Tawa SCD Club Annual dance 03 October 2020. Recorded by Aline Homes. Music by Aileen Logie, Hilary Ferral, and Jason Morris.', 1, 1, 'V', '464658893', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9160, '2022-12-14 00:47:38.455703+00', '2022-12-14 00:48:48.814015+00', 20531, 3, 202, '', 'D', '', 1, 1, 'Y', 'O9xCIW_mKcs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9161, '2022-12-14 09:49:07.854986+00', '2022-12-14 09:49:30.966331+00', 9896, 4, 10819, '', 'D', '', 1, 1, 'Y', 'J9oXoNPx5rw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9162, '2022-12-15 01:40:02.910165+00', '2022-12-15 01:40:02.910165+00', 6143, 3, 1296, '', 'X', '''Skylark''s Reel, The'' is a 32 bar reel for 3 couples in a 3 couple set.', 1, 1, 'Y', 'KNBf8J4sR2U', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9164, '2022-12-15 01:40:02.964738+00', '2022-12-15 01:40:02.964738+00', 12508, 4, 1296, '', 'X', '''Deer Friends'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', 'UxeQR8CEq7U', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9165, '2022-12-15 01:40:02.991447+00', '2022-12-15 01:40:02.991447+00', 358, 8, 1296, '', 'X', '''Balgeddie Reel'' is a 32 bar reel for 5 couples in a 5 couple set.', 1, 1, 'Y', 'ItLij8D56pM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (7657, '2020-11-07 05:33:10.79618+00', '2022-12-19 22:50:47.997601+00', 6048, 10, 35776, '', 'C', 'Tawa SCD Club Annual Dance 03 October 2020 (near Wellington, NZ). Music by Aileen Logie, Hilary Ferral, and Jason Morris.', 1, 1, 'V', '476537986', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7586, '2020-09-05 09:40:39.547971+00', '2022-12-22 17:47:21.373298+00', 3986, 5, 1645, '', 'Z', 'Demo by "Dream Team" from the "Ural Teapot" SCD festival in Russia. This is the second dance in their display and starts from 2nd and 3rd places.



Was Dem Quality, now blocked by youtube.', 1, 1, 'Y', '6vz33dZ3X3Q', 230, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9167, '2022-12-21 08:31:13.721652+00', '2022-12-21 15:13:56.52074+00', 21215, 1, 274, '', 'B', 'Birthday party december 2022, Budapest.



Tunes played (by Phill Jones) included:

My Nannie O,

Humours of Castle Comer,

A Land for All Seasons (R Cass / R Climies),

Mrs Nanie McKay,

Peace and Plenty (Brian McNeil),

Cleveland Park (Ivan Drever),', 1, 1, 'Y', 'd4qWXXJl0x8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9168, '2022-12-22 13:14:49.738432+00', '2022-12-22 13:18:59.964285+00', 301, 6, 1645, '', 'A', 'Aberdeen RSCDS at the Aberdeen Festival, 2018.', 1, 1, 'Y', 'XuKoDPN-ebo', 156, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9169, '2022-12-22 13:15:36.018191+00', '2022-12-22 13:19:47.404052+00', 15403, 4, 1645, '', 'A', 'Aberdeen RSCDS at the Aberdeen Festival, 2018.', 1, 1, 'Y', 'XuKoDPN-ebo', 2, 155, NULL);
INSERT INTO 'dancevideo' VALUES (9170, '2022-12-22 13:18:06.786043+00', '2022-12-22 13:20:16.632935+00', 15403, 5, 1645, '', 'A', 'German Ladies Team, Newcastle Festival 2018.', 1, 1, 'Y', 'uInNpbu1m7E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9180, '2022-12-22 23:34:01.064175+00', '2022-12-22 23:50:00.089068+00', 14665, 1, 248, '', 'A', 'Danced by members of the San Gabriel Valley, Los Angeles, and Orange County Branches in Southern California', 1, 1, 'Y', 'ptwO_thTRCA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9181, '2022-12-22 23:36:00.43977+00', '2022-12-22 23:54:40.844835+00', 14665, 2, 248, '', 'B', 'Danced by members of the San Gabriel Valley, Los Angeles, and Orange County Branches in Southern California', 1, 1, 'Y', 'WgSHOkmCDWE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9176, '2022-12-22 14:12:21.08012+00', '2022-12-22 23:56:00.687533+00', 14214, 1, 1645, '', 'B', 'Gleneagles SCD Club 2022. Twice through viewed from the top, then again from above.', 1, 1, 'Y', '8tGyHcyzCig', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9177, '2022-12-22 14:17:27.317566+00', '2022-12-22 23:58:09.106533+00', 14219, 1, 1645, '', 'B', 'Gleneagles SCD Club 2022. Twice through viewed from the top, then again from above.', 1, 1, 'Y', 'SgXs9th1Mhg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9178, '2022-12-22 14:21:22.298243+00', '2022-12-22 23:59:00.469207+00', 16738, 2, 1645, '', 'B', 'Gleneagles SCD Club 2022. Twice through viewed from the top, then again from above.', 1, 1, 'Y', 'N5TffKzhCzs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9175, '2022-12-22 14:08:48.829645+00', '2022-12-23 00:00:02.033108+00', 14625, 2, 1645, '', 'B', 'Gleneagles SCD Club 2022. Twice through viewed from the top, then again from above.', 1, 1, 'Y', '3JxOZ9bBsoI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9174, '2022-12-22 14:00:55.069634+00', '2022-12-23 16:11:22.873057+00', 364, 1, 1645, '', 'X', '', 1, 1, 'Y', '3f900eWFHhA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9173, '2022-12-22 13:59:32.79058+00', '2022-12-23 16:11:31.826037+00', 16687, 1, 1645, '', 'X', '', 1, 1, 'Y', 'dql4rqr9djQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9179, '2022-12-22 17:17:08.409665+00', '2022-12-23 16:12:20.993482+00', 4043, 3, 1645, '', 'B', 'Eglington Assembly dancers at the Hamilton Gala Day in 1986. The dancing is really demonstration quality but the video quality is unfortunately not nearly of comparable standard so overall graded as Good.', 1, 1, 'Y', 'CKeNpav-Pns', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9172, '2022-12-22 13:56:34.808301+00', '2022-12-23 16:13:12.969895+00', 21207, 1, 1645, '', 'B', 'Duns and District Branch, 2022.', 1, 1, 'Y', '2H8si5usblM', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9171, '2022-12-22 13:52:12.634551+00', '2022-12-23 16:13:47.99912+00', 696, 1, 1645, '', 'B', 'Duns and District Branch, 2022. Twice through.', 1, 1, 'Y', '0UXJTermDzc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9182, '2022-12-23 21:15:59.409954+00', '2022-12-23 21:28:42.29566+00', 19811, 1, 1645, '', 'B', 'Kitchener Waterloo RSCDS, 2022. Danced once each couple in a 3 couple set.', 1, 1, 'Y', 'HwOJF70tV7A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9183, '2022-12-25 01:40:03.32009+00', '2022-12-25 01:40:03.32009+00', 853, 1, 1296, '', 'X', '''Buckie Jig, The'' is a 32 bar jig for 2 couples in a 4 couple set.', 1, 1, 'Y', 'iLTVmvHYi9Q', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9184, '2022-12-25 01:40:03.385984+00', '2022-12-25 01:40:03.385984+00', 10708, 1, 1296, '', 'X', '''Sister Blanche of St Andrews'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'c3EMTgxs6T4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9188, '2022-12-30 21:19:06.668319+00', '2022-12-31 16:47:12.035736+00', 2924, 9, 963, '', 'C', '', 1, 1, 'Y', 'xhqTKLZmxiU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9195, '2023-01-05 19:11:06.314117+00', '2023-01-05 19:39:07.847276+00', 20780, 3, 1645, '', 'B', 'Méaudre Reel 2022.', 1, 1, 'Y', 'GTD4fz7L7tQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9197, '2023-01-05 19:35:50.904787+00', '2023-01-05 19:41:06.876979+00', 18379, 2, 1645, '', 'C', 'Méaudre Reel, 2022. Generally clear though with some errors here and there (eg in the first tourbillon, neatly corrected in the subsequent poussette).', 1, 1, 'Y', 'Px0hO8zn7GQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9194, '2023-01-05 19:04:17.057114+00', '2023-01-05 19:44:26.54259+00', 644, 2, 1645, '', 'X', '', 1, 1, 'Y', 'Kv9iefZkYK0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9198, '2023-01-05 19:42:01.241662+00', '2023-01-05 19:47:05.925834+00', 17247, 2, 1645, '', 'C', 'Orange County Christmas Ball, 2022.', 1, 1, 'Y', 'geQC3yU9-ig', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9200, '2023-01-05 21:42:26.951022+00', '2023-01-05 22:54:18.713131+00', 17253, 1, 1645, '', 'B', 'RSCDS Los Angeles 2023.', 1, 1, 'Y', 'zlFy_Xg8sHw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9201, '2023-01-05 21:44:28.588629+00', '2023-01-05 22:55:19.247256+00', 17253, 2, 1645, '', 'C', 'RSCDS Los Angeles St Andrews Ball, 2022.', 1, 1, 'Y', 'mxdlk4K26Z0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9199, '2023-01-05 20:00:51.83672+00', '2023-01-05 22:56:39.270498+00', 17247, 3, 1645, '', 'B', 'RSCDS Los Angeles. This clip starts from the 3rd repeat.', 1, 1, 'Y', 'tWUqNRdHYK8', 73, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9206, '2023-01-05 22:50:56.714571+00', '2023-01-05 22:58:20.758902+00', 8775, 1, 1645, '', 'B', 'RSCDS Los Angeles, 2022. Here danced in a three couple set.', 1, 1, 'Y', 'hU4KTYB5eCs', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9204, '2023-01-05 22:32:33.776153+00', '2023-01-05 22:59:32.127114+00', 10401, 1, 1645, '', 'C', 'RSCDS Los Angeles, 2022. There is a little glitch in the last 8 bars of the central Hoopers Jig section.', 1, 1, 'Y', 'EgduSMdxXM0', 50, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9205, '2023-01-05 22:43:49.562308+00', '2023-01-05 23:03:09.302748+00', 1453, 2, 1645, '', 'B', 'RSCDS Los Angeles, 2022. There are a few glitches but this video (unlike Video 1) does follow the expected choreography.', 1, 1, 'Y', 'K1w0fEgtCwE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9202, '2023-01-05 22:02:29.864941+00', '2023-01-05 23:04:31.538946+00', 15708, 1, 1645, '', 'C', 'RSCDS Los Angeles St Andrews Ball 2022.', 1, 1, 'Y', 'BPZ-5FHXuBc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9203, '2023-01-05 22:20:25.506651+00', '2023-01-05 23:06:23.180041+00', 627, 1, 1645, '', 'B', 'RSCDS Los Angeles, 2022. Danced once each couple in a 3 couple set. This clip shows the last two repeats.', 1, 1, 'Y', 'CUKFuLoZS1E', 59, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9207, '2023-01-05 23:15:50.190055+00', '2023-01-06 11:25:20.997176+00', 17673, 1, 1645, '', 'C', 'RSCDS Los Angeles, 2022. The youtube video title is "Laich of Moray" but it actually seems to be the adaption of that dance by Mary Shoolbraid Brandon called "The Mormaer of Moray". The strathspey part is fine but there are a few mishaps in the reel section.', 1, 1, 'Y', 'Sp6ft9Uyu_g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9208, '2023-01-05 23:43:01.308501+00', '2023-01-06 11:27:53.362435+00', 11185, 2, 1645, '', 'C', 'RSCDS Los Angeles, 2022. Here danced once each couple in a three couple set.', 1, 1, 'Y', '3e14Y5bQPio', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9209, '2023-01-06 11:09:38.739258+00', '2023-01-06 11:30:21.051415+00', 7182, 4, 1645, '', 'C', 'Johnsonville SCD Club, NZ, 2022. Twice through. This clip just shows the dancing. The whole video starts with a recap.', 1, 1, 'Y', 'IclVwCxmUZg', 32, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9210, '2023-01-06 16:01:37.373206+00', '2023-01-06 16:11:21.875599+00', 10023, 5, 602, '', 'B', '', 1, 1, 'Y', 'XNagxpc5unw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9212, '2023-01-09 23:27:55.483955+00', '2023-01-09 23:42:50.046258+00', 479, 1, 1645, '', 'B', 'Tay Dancers, 2023.', 1, 1, 'Y', 'I6r7oU0T0qc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9214, '2023-01-09 23:42:10.863842+00', '2023-01-09 23:43:23.014848+00', 2786, 2, 1645, '', 'B', 'Tay Dancers, 2023.', 1, 1, 'Y', 'F3xuXERru9A', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9213, '2023-01-09 23:33:11.583091+00', '2023-01-09 23:43:50.692243+00', 13615, 2, 1645, '', 'B', 'Tay Dancers, 2023.', 1, 1, 'Y', 'c0gBUH6t09c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9215, '2023-01-10 01:40:03.243736+00', '2023-01-10 01:40:03.243736+00', 5403, 2, 1296, '', 'X', '''Quaich, The'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', 'MhgfbTnlNog', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9216, '2023-01-10 01:40:03.264852+00', '2023-01-10 01:40:03.264852+00', 1085, 1, 1296, '', 'X', '''Catch as Catch Can'' is a 32 bar reel for 4 couples in a 4 couple set.', 1, 1, 'Y', 'lWFKMFX4AHQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9217, '2023-01-10 01:40:03.282336+00', '2023-01-10 01:40:03.282336+00', 5755, 5, 1296, '', 'X', '''Royal Wedding, The'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', 'IvVOQbZ4Jj4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9218, '2023-01-10 01:40:03.300389+00', '2023-01-10 01:40:03.300389+00', 1414, 1, 1296, '', 'X', '''Crieff Jig, The'' is a 32 bar jig for 2 couples in a 4 couple set.', 1, 1, 'Y', 'sxFRQ_S9zx8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9219, '2023-01-10 01:40:03.318293+00', '2023-01-10 01:40:03.318293+00', 9770, 5, 1296, '', 'X', '''Tri-Mariner, The'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'm5yoMzQrtLc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9228, '2023-01-12 19:57:38.615617+00', '2023-01-12 19:59:16.96133+00', 21297, 1, 10819, '', 'A', 'The deviser and a companion showing this dance in an instructional video.', 1, 1, 'V', '122226293', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9222, '2023-01-10 19:59:08.213947+00', '2023-01-10 21:56:05.007817+00', 18248, 2, 595, '', 'B', 'The dance is being danced to the original tune, written by Vincent McCourt at a dance on 12 November 2022 to celebrate 60 years of the Headington SCD class. The dance deviser, Lesley McCourt is dancing as 1st Lady in the second set.



This clip starts with the dancing. The whole video has an introduction to the history and a recap.', 1, 1, 'Y', 'lqgKYAyN8ng', 135, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7905, '2021-04-06 20:23:25.143827+00', '2023-01-14 23:38:43.524537+00', 4917, 1, 1645, '', 'Z', 'Novisibirsk 2018. Some mishaps, especially in the first grand chain, but generally improving as the dance continues.



Was Reasonable: now unavailable (youtube account terminated).', 1, 1, 'Y', 'iH2dIk5UbII', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9221, '2023-01-10 14:44:39.364168+00', '2023-01-10 23:04:37.132543+00', 21279, 1, 1332, '', 'B', 'Once through.



Lisbon Lapa group, 2023.', 1, 1, 'Y', 'tL8k7V7fWHA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9220, '2023-01-10 14:43:42.749673+00', '2023-01-10 23:05:05.615897+00', 20320, 1, 1332, '', 'B', 'Once through.



Lisbon Lapa group, 2023.', 1, 1, 'Y', 'hD_51_6BeGg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9223, '2023-01-11 01:40:03.49407+00', '2023-01-11 01:40:03.49407+00', 3786, 6, 1296, '', 'X', '''Let''s Have a Ceilidh'' is a 32 bar reel for 4 couples in a 4 couple set.', 1, 1, 'Y', 'zkcClDkOG8Y', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9226, '2023-01-12 19:53:20.790419+00', '2023-01-12 19:58:57.450397+00', 21300, 1, 10819, '', 'B', '', 1, 1, 'Y', 'Gk54Lgo39eU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9227, '2023-01-12 19:54:42.444029+00', '2023-01-12 19:59:10.043983+00', 21300, 2, 10819, '', 'A', 'The deviser and a companion showing the dance in an instructional video.', 1, 1, 'V', '122226292', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9230, '2023-01-16 14:29:23.398627+00', '2023-01-16 14:42:39.215257+00', 1894, 1, 274, '', 'C', 'Dance house for Beginners, Budapest, 14.01.2023', 1, 1, 'Y', 'ARGCc1K4YhM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9229, '2023-01-16 01:40:07.06398+00', '2023-01-16 20:57:06.017993+00', 20034, 1, 1296, '', 'X', '"Cocktails at Hogmanay", a 5×40 Jig, devised by Viktor Lehmann. Animation & Video Production by Viktor Lehmann, 15 Jan 2023, using "Dance Animations" by Keith Wood.

This animated version gives a first impression of the dance.

Full dance description can be found here: 
https://www.scd-germany.de/de/schottentanzen-in-deutschland/publikationen/

Minicrib version can be found in the SCD Dance Database (SCDDB):
https://my.strathspey.org/dd/dance/20034/

Follow me on YouTube for more SCD Videos:
https://www.youtube.com/@viktorlehmann', 1, 1, 'Y', 'NOmhUcfIW0A', 0, 0, 3);
INSERT INTO 'dancevideo' VALUES (9232, '2023-01-17 20:27:56.944569+00', '2023-01-17 20:40:12.538808+00', 18711, 2, 2220, '', 'B', 'Berkeley, California, 2023. Twice through in two 3 couple sets, once each couple.', 1, 1, 'Y', '3SxLsgDd2Tw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9231, '2023-01-17 20:26:54.252048+00', '2023-01-17 20:42:21.090166+00', 13572, 2, 2220, '', 'B', 'Berkeley, California, 2023. Once through, danced in a 3 couple set.', 1, 1, 'Y', 'K2YdTsHYTq0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9233, '2023-01-18 18:19:18.507946+00', '2023-01-18 18:54:17.764384+00', 20197, 3, 1645, '', 'B', 'Montreal Branch, Hogmanay 2022. The video starts about 3 or 4 bars into the first repeat. Ckear, albeit with some brief hesitations here and there.', 1, 1, 'Y', '65IzoIoYIRs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9234, '2023-01-19 13:34:09.426343+00', '2023-01-19 13:38:47.525966+00', 4917, 2, 274, '', 'C', 'Budapest, Dance house for beginners, 14.01.2023

mistake: 2 bars/hand instead of 1 bar/hand

Two times through...', 1, 1, 'Y', 'dVhqrTHAKDU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9236, '2023-01-20 23:35:04.899509+00', '2023-01-21 00:15:19.843763+00', 21312, 1, 1645, '', 'B', 'Shows three variations of the dance, each once through. First the basic dance, then with a 4th couple active at the bottom, then at the top.', 1, 1, 'Y', 'vc0134ml4Vw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9238, '2023-01-21 00:00:55.648524+00', '2023-01-21 00:16:47.24759+00', 21314, 1, 1645, '', 'A', 'NZ Summer School 2022-2023. Twice through, starting with middle couples, then all four couples. This clip starts with the dancing. The whole video also has an introduction to the dance. This explains the symbolism of passing a flag across the strait between north and south islands.', 1, 1, 'Y', 'IlnV1tFNVqw', 84, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9240, '2023-01-21 10:11:17.753915+00', '2023-01-21 14:15:12.168712+00', 21316, 1, 1645, '', 'B', 'RSCDS Forres, June 2022.', 1, 1, 'Y', 'HaW73ny9M3c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9235, '2023-01-20 23:08:18.324828+00', '2023-01-21 18:32:32.155526+00', 17246, 1, 1645, '', 'B', 'LA Branch Dem Team 2023.', 1, 1, 'Y', 'RXCk-8T8MUA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9241, '2023-01-21 21:21:52.679258+00', '2023-01-22 18:57:50.166053+00', 21317, 1, 1645, '', 'B', 'Seattle - University District Class, 2023. Twice through.', 1, 1, 'Y', 'QlqLF2TvRcA', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7471, '2020-07-18 10:29:40.19921+00', '2023-01-22 20:01:20.145637+00', 11681, 1, 1645, '', 'Z', 'Kirov Winter Social 2018. Good dancing but the camera view is between two lines of sets with neither of them completely in view so its not always easy to follow the dance.



Was Reasonable, now unavailable.', 1, 1, 'Y', 'EgZ92GeITWA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9243, '2023-01-23 01:40:03.229223+00', '2023-01-23 01:40:03.229223+00', 3672, 3, 1296, '', 'X', '''Lamb Skinnet'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'O7JyafbsEtc', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9244, '2023-01-23 01:40:03.252631+00', '2023-01-23 01:40:03.252631+00', 816, 4, 1296, '', 'X', '''Brisk Young Lad, The'' is a 48 bar jig for 5 couples in a 5 couple set.', 1, 1, 'Y', 'E7n31mdpXwY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9245, '2023-01-23 01:40:03.268542+00', '2023-01-23 01:40:03.268542+00', 223, 6, 1296, '', 'X', '''Argyll''s Fancy'' is a 48 bar jig for 4 couples in a 4 couple set.', 1, 1, 'Y', 'B1yv98uPUJs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9246, '2023-01-23 01:40:03.289951+00', '2023-01-23 01:40:03.289951+00', 2260, 7, 1296, '', 'X', '''Flying Scotsman, The'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'LQfIBpC3JE4', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9250, '2023-01-23 23:24:04.767923+00', '2023-01-24 07:36:02.422055+00', 8360, 1, 1645, '', 'B', 'Danze Ottocentesche, Italy, 2014. Twice through with 3rd & 4th couples starting on opposite sides.', 1, 1, 'Y', '5UvAShPDVLM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9248, '2023-01-23 18:02:29.883061+00', '2023-01-24 07:37:43.212786+00', 17626, 2, 1645, '', 'A', 'NZ Summer School 2015/16. Three times through, once each couple (thanks to the 312 progression).', 1, 1, 'Y', 'eOpjRIttz0Q', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9242, '2023-01-21 21:27:08.411115+00', '2023-01-24 07:39:10.617709+00', 4461, 4, 1645, '', 'B', 'Verona Christmas 2022. This clip shows the dance once through, to music from a pipe band. The demo continues with two repeats of Pelorus Jack, then returns to Miss Dumbreck to finish (from 1:54).', 1, 1, 'Y', '8SSP_eSXzgM', 6, 50, NULL);
INSERT INTO 'dancevideo' VALUES (9247, '2023-01-23 17:43:38.909217+00', '2023-01-24 07:40:28.805595+00', 3915, 1, 1645, '', 'B', 'St Andrew''s Ball instructional video, 2015. This clip starts with the dancing. The video has a walk through with voice over.', 1, 1, 'Y', 'O5RO2_50Tlw', 54, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9249, '2023-01-23 18:15:13.817498+00', '2023-01-24 07:41:30.941687+00', 15272, 2, 1645, '', 'D', 'RSCDS Seattle at Fort Worden, 2011. This clip just shows the first repeat. After that the camera moves to close ups of other sets, the band, etc.', 1, 1, 'Y', 'oNM0l97qbrc', 0, 38, NULL);
INSERT INTO 'dancevideo' VALUES (9252, '2023-01-24 14:41:10.038167+00', '2023-01-25 10:43:00.105824+00', 8154, 2, 2219, '', 'A', 'Thanks for maintaining the database and server, Stuart', 1, 1, 'Y', 'y6HmXvC_tSA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9251, '2023-01-24 14:06:55.202211+00', '2023-01-25 10:45:26.927413+00', 20216, 1, 1645, '', 'C', 'Scottish Festival in Cheboksary, Russia, 2020. This clip shows twice through (the first repeat on the video starts a few bars into the dance). The camera is close up so some dancers are out of view at times.', 1, 1, 'Y', '9FogfpwYKh0', 34, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9255, '2023-01-25 18:46:36.923946+00', '2023-01-26 10:59:55.626887+00', 11790, 2, 1645, '', 'B', 'RSCDS Lyon Branch Burns night, 2022. A few hesitations but generally very clear.', 1, 1, 'Y', 'NsO4ltaVkwk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9256, '2023-01-25 23:24:38.147166+00', '2023-01-26 11:01:36.517114+00', 4325, 2, 1645, '', 'C', 'Lochiel SCD and Waikato Bay of Planety Dancers, NZ, 2023. Twice through, dancing on grass.', 1, 1, 'Y', 'j0mVHuELxIo', 5, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9267, '2023-01-29 11:18:38.33551+00', '2023-01-31 22:14:13.074239+00', 6748, 7, 1645, '', 'A', 'Budapest, 2017. Twice through in a two couple set.', 1, 1, 'Y', 'Zw53OdXXrHk', 117, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9254, '2023-01-25 18:10:09.135218+00', '2023-01-26 16:19:23.095527+00', 17384, 2, 1645, '', 'B', 'RSCDS Central Germany Branch Ball 2019.', 1, 1, 'Y', 'P6c1RelIpPY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9253, '2023-01-25 17:54:04.293205+00', '2023-01-26 16:24:06.536613+00', 6393, 2, 1645, '', 'B', 'Glenview social group, Toronto, 2016. The turns in bars 9-10 are here done with both hands (instead of right hands as per the original instructions).', 1, 1, 'Y', 'GmkO5j7AbAA', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9260, '2023-01-26 10:51:08.823846+00', '2023-01-26 16:24:45.285304+00', 11189, 16, 1645, '', 'X', '', 1, 1, 'Y', 'KCgbiQfxfWA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9259, '2023-01-26 10:20:18.079666+00', '2023-01-26 18:23:32.502933+00', 20541, 2, 1645, '', 'B', 'Adelaide Scottish Country Dancing and Social Club, 2022. To make the progression work for a 3 cpl dance in 3 cpl set, bars 21-22 have been slightly altered.', 1, 1, 'Y', 'SxVge8TSszM', 52, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9264, '2023-01-26 17:11:01.519654+00', '2023-01-26 21:17:32.44382+00', 21159, 4, 602, '', 'B', 'Here danced as a reel (the dance may also be done as jig or strathspey). The first 2 bars are missing.', 1, 1, 'Y', 'OQdl-BJbKD8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9262, '2023-01-26 15:56:21.514728+00', '2023-01-26 21:18:38.428201+00', 21159, 2, 2821, '', 'B', 'Newark''s Welcome, a 32 dance for three couples in a three couple set devised by Chris Ronald.  It can be danced as a reel, jig or strathspey.  Chris dances as second man in this strathspey version.', 1, 1, 'Y', 'uPxCLlKT9fM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9257, '2023-01-25 23:31:00.126074+00', '2023-01-26 21:53:48.083896+00', 11001, 2, 1645, '', 'C', 'Toronto beginners night, 2018.', 1, 1, 'Y', 'aRm9JR5Q0YY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9258, '2023-01-25 23:39:14.349053+00', '2023-01-26 21:54:20.059801+00', 14447, 2, 1645, '', 'B', 'Berkhamsted, 2015. Twice through.', 1, 1, 'Y', 'q5IYemnu9LU', 1, 119, NULL);
INSERT INTO 'dancevideo' VALUES (9268, '2023-01-31 14:25:26.342209+00', '2023-01-31 14:26:53.211077+00', 21318, 1, 202, '', 'B', '', 1, 1, 'Y', '4WqxmI3_Cxs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9271, '2023-01-31 21:55:19.966308+00', '2023-01-31 22:16:40.035106+00', 7553, 4, 1645, '', 'B', 'Budapest Scottish Dance Club, Burns Night, 2023. Here done twice, as part of a longer demo.', 1, 1, 'Y', 'RMHUEemJfK8', 142, 177, NULL);
INSERT INTO 'dancevideo' VALUES (9265, '2023-01-29 10:59:58.543982+00', '2023-01-31 22:13:29.323147+00', 59, 2, 1645, '', 'C', 'Méaudre Reel children, 2021. Bars 13-16 (expected to be set and cross down LH) are here replaced by cast and cross LH. The children get ahead of the music from time to time.', 1, 1, 'Y', 'yzR-DBxL-IQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9266, '2023-01-29 11:16:01.540895+00', '2023-01-31 22:13:50.577462+00', 159, 13, 1645, '', 'A', 'Budapest, 2017. Twice through in a two couple set.', 1, 1, 'Y', 'Zw53OdXXrHk', 0, 117, NULL);
INSERT INTO 'dancevideo' VALUES (9269, '2023-01-31 21:29:42.044827+00', '2023-01-31 22:14:36.576159+00', 17244, 2, 1645, '', 'B', 'Los Angeles, Burns Night, 2023. Done best by the set on the right.', 1, 1, 'Y', 'TGIP1PmtuTE', 0, 152, NULL);
INSERT INTO 'dancevideo' VALUES (9272, '2023-01-31 22:06:18.554828+00', '2023-01-31 22:15:15.218856+00', 498, 4, 1645, '', 'B', 'Budapest Scottish Dance Club, Burns Night, 2023. Here done twice, as the last part of a longer demo. The group are doing a 32 bar version of the dance omitting the final grand chain.', 1, 1, 'Y', 'RMHUEemJfK8', 209, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9270, '2023-01-31 21:52:09.410248+00', '2023-01-31 22:21:13.947094+00', 1345, 2, 1645, '', 'A', 'Budapest Scottish Dance Club, Burns Night, 2023. Here done twice, as part of a longer demo, in three 2 couple sets which join in a triangular star for the balance in line.', 1, 1, 'Y', 'RMHUEemJfK8', 42, 109, NULL);
INSERT INTO 'dancevideo' VALUES (9273, '2023-01-31 22:13:03.423511+00', '2023-01-31 22:21:36.119455+00', 5451, 2, 1645, '', 'A', 'Budapest Scottish Dance Club, Burns Night, 2023.', 1, 1, 'Y', '3bY5IjbdUs8', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9277, '2023-02-01 14:51:22.313047+00', '2023-02-01 23:36:01.029686+00', 5755, 6, 1645, '', 'A', 'Edinburgh University at the 2017 Aberdeen Festival.', 1, 1, 'Y', 'ibW6DOFyxHQ', 151, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9274, '2023-02-01 14:34:45.875331+00', '2023-02-02 18:40:06.494922+00', 7087, 2, 1645, '', 'B', 'Arkansas SCD Society, Little Rock, USA, 2014.', 1, 1, 'Y', 'J3F4YJSSXpw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9275, '2023-02-01 14:38:34.299529+00', '2023-02-02 18:41:27.174171+00', 15574, 2, 1645, '', 'B', 'SCD group Hong Kong, 2013. Once through.', 1, 1, 'Y', 'RY5VxHfsAZM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9288, '2023-02-02 20:14:20.987287+00', '2023-02-03 13:09:00.052382+00', 9087, 6, 1645, '', 'A', 'Scottish Dance School Schiehallion, 2021. Three times in a 3 couple set, starting from 2nd & 3rd places.', 1, 1, 'Y', 'v85FRhSGYBI', 207, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9280, '2023-02-01 23:15:00.417637+00', '2023-02-01 23:30:59.195344+00', 2713, 2, 1645, '', 'A', 'Budapest Scottish Dance Club, 2023. Twice through in three 2 couple sets in different orientations as part of a longer demo.', 1, 1, 'Y', '9cqi4IGypC4', 2, 75, NULL);
INSERT INTO 'dancevideo' VALUES (9282, '2023-02-01 23:25:20.554801+00', '2023-02-01 23:33:12.671397+00', 4804, 2, 1645, '', 'B', 'Budapest Scottish Dance Club, 2023. Twice through in three 2 couple sets in different orientations as the last part of a longer demo. Here the dancers add an extra cross before and after the allemande which is done starting "down".', 1, 1, 'Y', '9cqi4IGypC4', 208, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9281, '2023-02-01 23:19:22.963454+00', '2023-02-01 23:35:01.923542+00', 4888, 3, 1645, '', 'A', 'Budapest Scottish Dance Club, 2023. Twice through in three 2 couple sets in different orientations as part of a longer demo.', 1, 1, 'Y', '9cqi4IGypC4', 75, 142, NULL);
INSERT INTO 'dancevideo' VALUES (9276, '2023-02-01 14:50:17.282451+00', '2023-02-01 23:35:44.622983+00', 15401, 2, 1645, '', 'A', 'Edinburgh University at the 2017 Aberdeen Festival.', 1, 1, 'Y', 'ibW6DOFyxHQ', 0, 150, NULL);
INSERT INTO 'dancevideo' VALUES (3111, '2017-06-29 21:55:02.317318+00', '2023-02-02 17:46:09.573423+00', 6362, 1, 2220, '', 'Z', 'The Berkeley CA adjudication Team led by Bruce Herbold performing Struan Robertson''s Reel at the Pleasanton Highland Games 2012 Greg Wilcox, Madge Tsang, Gary Knox, Witsie MacElvey, Bex Clark, Amanda Whitehead, Paula Buell, Jane Samuelson.



Was Reasonable, now unavailable (private on youtube).', 1, 1, 'Y', 'clj32P-mrbs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9278, '2023-02-01 23:01:47.735346+00', '2023-02-02 18:45:57.193973+00', 9169, 5, 1645, '', 'B', 'Naramata Scottish Country Dancers, 2023. Danced in 2 couple sets, the one nearest the camera dancing up & down rather than down & up. This clip starts with the first time through the dance (after an introductory dance on).', 1, 1, 'Y', '3BGnuQ1WWs8', 42, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9285, '2023-02-02 18:29:10.654785+00', '2023-02-02 18:48:24.684272+00', 9385, 3, 1645, '', 'A', 'RSCDS Chicago Branch Demo Team, 2015. Three times through.', 1, 1, 'Y', 'bIR8YTKyvsc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9284, '2023-02-02 18:08:55.458973+00', '2023-02-02 18:49:43.254964+00', 3678, 4, 1645, '', 'B', 'Nottingham Scottish Association, ASCDS Festival 2018. The last 3 repeats.', 1, 1, 'Y', 'lXIB5mgQcag', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9279, '2023-02-01 23:09:04.153403+00', '2023-02-02 18:51:41.681885+00', 18099, 3, 1645, '', 'B', 'Naramata Scottish Country Dancers, 2023. Danced once each couple in 3 couple sets.', 1, 1, 'Y', '9SXKpVQ5o3c', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9283, '2023-02-02 17:44:33.937599+00', '2023-02-02 18:58:00.42484+00', 15317, 2, 1645, '', 'C', 'Partial view of two sets, filmed from floor level so hard to see whats going on, but looks lively!', 1, 1, 'Y', 'gagTDRNOmyo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9286, '2023-02-02 18:58:33.243118+00', '2023-02-02 19:12:19.253117+00', 2644, 2, 1645, '', 'A', 'RSCDS Edinburgh Strictly Scottish 1996. This clip shows the dance just once through in two back to back 3 couple sets. The 1st place in each set (at the ends) is out of view for the first few bars. The demo continued with a variation of the dance for 4 couples.', 1, 1, 'Y', 'R1JIqK5Ge2c', 2793, 2849, NULL);
INSERT INTO 'dancevideo' VALUES (9292, '2023-02-03 15:04:12.64581+00', '2023-02-04 10:48:38.382096+00', 19250, 1, 1645, '', 'A', 'Newcastle Festival 2020 Demonstrations. Twice through as the last part of a longer medley. The end of the 2nd time is adapted for the final bow.', 1, 1, 'Y', 'CEXidDat5ws', 281, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9290, '2023-02-03 12:47:53.504894+00', '2023-02-03 13:05:16.816738+00', 13149, 11, 1645, '', 'A', 'Glasgow University at the Newcastle Festival 2018.', 1, 1, 'Y', 'Vi-23j95Jjc', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9289, '2023-02-03 12:45:29.60692+00', '2023-02-03 13:06:19.95049+00', 480, 3, 1645, '', 'C', 'Summer school 2019. The video starts about 2 bars into the dance (after the first setting).', 1, 1, 'Y', 'RaHflth8-cs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9287, '2023-02-02 20:10:09.445644+00', '2023-02-03 13:08:01.231907+00', 1485, 2, 1645, '', 'A', 'Scottish Dance School Schiehallion, 2021. Three times in a 3 couple set.', 1, 1, 'Y', 'v85FRhSGYBI', 9, 204, NULL);
INSERT INTO 'dancevideo' VALUES (9291, '2023-02-03 13:26:31.345317+00', '2023-02-04 10:50:41.31225+00', 9660, 1, 1645, '', 'B', 'Newcastle Festival 2020 Demonstrations. This clip shows an adapted first half of the dance as part of a longer demonstation medley. It is roughly the first 48 bars but passing right shoulder and clockwise in bars 33-48 instead of left shoulder and anticlockwise (and then leads into a circle). At least it gives a flavour of the dance.', 1, 1, 'Y', 'CEXidDat5ws', 230, 282, NULL);
INSERT INTO 'dancevideo' VALUES (9293, '2023-02-04 10:48:20.231399+00', '2023-02-04 10:51:37.41458+00', 541, 2, 1645, '', 'B', 'Newcastle Festival 2020 Demonstrations. Nearly once through as the first part of an excellent longer display. However the last few bars are adapted to lead into the next dance as extra couples dance in.', 1, 1, 'Y', 'CEXidDat5ws', 7, 43, NULL);
INSERT INTO 'dancevideo' VALUES (9295, '2023-02-04 11:32:06.26435+00', '2023-02-04 11:39:30.507845+00', 21115, 1, 1645, '', 'B', 'Gay Gordons & Friends, 2023. Just once through (to the original tune played by the composer),', 1, 1, 'Y', 'dcL_YH0nhrw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9294, '2023-02-04 11:30:52.670867+00', '2023-02-04 11:41:21.413294+00', 21213, 1, 1645, '', 'B', 'Gay Gordons & Friends, 2023. Just the last two repeats.', 1, 1, 'Y', 'KRBifqq9hbg', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9296, '2023-02-04 11:35:43.164454+00', '2023-02-04 11:44:51.268488+00', 18334, 1, 1645, '', 'B', 'Gay Gordons & Friends 2023. The happily together Alan and Hamish start as 1st couple.', 1, 1, 'Y', 'DEHTNw6PSHA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9297, '2023-02-04 11:36:31.75865+00', '2023-02-04 11:46:55.079533+00', 21336, 1, 1645, '', 'B', 'Gay Gordons & Friends, 2023.', 1, 1, 'Y', 'ibP9nAazO7Q', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9298, '2023-02-04 11:37:20.020464+00', '2023-02-04 11:50:39.05603+00', 21191, 1, 1645, '', 'B', 'Gay Gordons & Friends, 2023.', 1, 1, 'Y', 'umwn1jV5nFw', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9308, '2023-02-07 01:40:03.545404+00', '2023-02-07 01:40:03.545404+00', 3300, 2, 1296, '', 'X', '''Trip to Gatlinburg'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'lpPv8tON5zs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9309, '2023-02-07 01:40:03.576197+00', '2023-02-07 01:40:03.576197+00', 9836, 8, 1296, '', 'X', '''Inimitable Derek, The'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'JSj3adlH3QA', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9310, '2023-02-07 01:40:03.597283+00', '2023-02-07 01:40:03.597283+00', 2518, 1, 1296, '', 'X', '''Glen, The'' is a 32 bar jig for 2 couples in a 4 couple set.', 1, 1, 'Y', '_7h6_paAnbs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9311, '2023-02-07 01:40:03.617161+00', '2023-02-07 01:40:03.617161+00', 2955, 1, 1296, '', 'X', '''Holland Park'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'fSRxZaJfeJk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9306, '2023-02-05 21:08:50.075116+00', '2023-02-07 10:03:21.912936+00', 9340, 2, 274, '', 'C', 'Budapest Scottish Dance Club, dance house for  beginners, 2023. 

Twice through, part of a larger video

Bar 19: 1C cast to the 3rd place (3 couple set)', 1, 1, 'Y', 'XSYdQRMCafY', 427, 490, NULL);
INSERT INTO 'dancevideo' VALUES (9303, '2023-02-05 20:55:00.84616+00', '2023-02-07 10:23:33.532517+00', 20228, 1, 274, '', 'C', 'Budapest Scottish Dance Club, dance house for  beginners, 2023. 

One time through, part of a larger video

', 1, 1, 'Y', 'XSYdQRMCafY', 60, 78, NULL);
INSERT INTO 'dancevideo' VALUES (9300, '2023-02-05 20:43:00.802137+00', '2023-02-07 10:33:43.455016+00', 18020, 2, 274, '', 'C', 'Budapest Scottish Dance Club, dance house for  beginners, 2023. 

Twice through, part of a larger video', 1, 1, 'Y', 'XSYdQRMCafY', 26, 60, NULL);
INSERT INTO 'dancevideo' VALUES (9302, '2023-02-05 20:51:46.023064+00', '2023-02-07 10:27:07.648219+00', 8144, 4, 274, '', 'C', 'Budapest Scottish Dance Club, dance house for  beginners, 2023. 

Twice through, part of a larger video

', 1, 1, 'Y', 'XSYdQRMCafY', 81, 150, NULL);
INSERT INTO 'dancevideo' VALUES (9304, '2023-02-05 20:57:05.749072+00', '2023-02-07 10:29:48.814006+00', 11527, 2, 274, '', 'C', 'Budapest Scottish Dance Club, dance house for  beginners, 2023. 

Twice through, part of a larger video', 1, 1, 'Y', 'XSYdQRMCafY', 150, 213, NULL);
INSERT INTO 'dancevideo' VALUES (9305, '2023-02-05 20:59:33.868085+00', '2023-02-07 10:32:49.484954+00', 2931, 3, 274, '', 'C', 'Budapest Scottish Dance Club, dance house for  beginners, 2023. 

Twice through, part of a larger video', 1, 1, 'Y', 'XSYdQRMCafY', 213, 272, NULL);
INSERT INTO 'dancevideo' VALUES (9307, '2023-02-07 01:40:03.518757+00', '2023-02-09 01:40:03.681654+00', 11524, 4, 1296, '', 'Z', '''Liquid Assets'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'FpY5YCh8QbM', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9299, '2023-02-05 16:21:51.727442+00', '2023-02-07 09:59:52.492238+00', 4998, 10, 2269, '', 'A', 'RSCDS Country Dancers, RSCDS Archives, 2006.  Alternates between close-up and a view of the entire set.  The dance is shown twice, normally at first and walked in rhythm the second time.', 1, 1, 'Y', 'o2UfaYpMhao', 1190, 1432, NULL);
INSERT INTO 'dancevideo' VALUES (9325, '2023-02-08 23:52:50.803983+00', '2023-02-09 09:57:00.70963+00', 12692, 1, 1645, '', 'B', 'Berkeley RSCDS at the Pleasanton Games, 2013. Twice through in a 3 couple set.', 1, 1, 'Y', 'otTyo4yxsQg', 105, 243, NULL);
INSERT INTO 'dancevideo' VALUES (9326, '2023-02-08 23:57:46.901781+00', '2023-02-09 09:58:49.556115+00', 7068, 4, 1645, '', 'B', 'Berkeley RSCDS at the Pleasanton Games, 2013. Twice through in a 3 couple set.', 1, 1, 'Y', 'otTyo4yxsQg', 257, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9323, '2023-02-08 16:27:21.855342+00', '2023-02-09 18:27:16.644266+00', 3616, 3, 1645, '', 'D', 'Berkeley RSCDS level 2 dancers. Rather close view, adapted for once each couple in a 3 couple set.', 1, 1, 'Y', 'nfy9rnOWeR0', 53, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9328, '2023-02-09 10:28:50.170738+00', '2023-02-09 18:28:49.038712+00', 13894, 3, 1645, '', 'A', 'Newcastle RSCDS, 2012. Once through as part of a longer display.', 1, 1, 'Y', 'AMVhkllL1Co', 92, 165, NULL);
INSERT INTO 'dancevideo' VALUES (9313, '2023-02-07 12:53:12.809376+00', '2023-02-08 11:37:00.111512+00', 2914, 1, 1645, '', 'B', 'Cheboksary Festival of Scottish Culture, 2022.

', 1, 1, 'Y', 'UK1e87c_Qew', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9312, '2023-02-07 12:33:13.435824+00', '2023-02-08 11:37:18.962159+00', 4411, 12, 1645, '', 'B', 'Cheboksary Festival of Scottish Culture, 2022.', 1, 1, 'Y', 'cgaaXmYJTtQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9316, '2023-02-07 13:50:46.97928+00', '2023-02-08 11:37:50.280096+00', 6029, 2, 1645, '', 'B', 'Cheboksary Festival of Scottish Culture, 2023. Four selected repeats.', 1, 1, 'Y', 'BbMvDZ5c7mE', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9315, '2023-02-07 13:45:30.738427+00', '2023-02-08 11:39:15.236545+00', 6449, 4, 1645, '', 'B', 'Cheboksary Festival of Scottish Culture, 2023. As in many other videos, in bars 9-12 all turn right hand rather than both hands (which are mentioned in the instructions).

', 1, 1, 'Y', 'K0YQmjeU69A', 7, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9314, '2023-02-07 13:22:34.897228+00', '2023-02-08 11:40:27.083746+00', 7204, 7, 1645, '', 'B', 'Chekboksary Festival of Scottish Culture, 2022. One or two minor glitches, but impressive continuation to spontaneous clapping and singing when the recorded music suddenly fails towards the end.

', 1, 1, 'Y', 'a50Xrg7xlZM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (1220, '2013-08-18 10:55:33.869965+00', '2023-02-08 16:14:06.367332+00', 3616, 2, 1296, '', 'Z', 'Was Reasonable, now unavailable.', 1, 1, 'Y', 'RHmKqsH2LyE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9327, '2023-02-09 01:40:03.685296+00', '2023-02-09 01:40:03.685296+00', 11524, 5, 1296, '', 'X', '''Liquid Assets'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'bzDcJvKBQ1g', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9317, '2023-02-08 12:01:14.672051+00', '2023-02-09 09:47:40.954497+00', 11365, 2, 1645, '', 'B', 'Tay Dancers, 2023.', 1, 1, 'Y', 'Y8gUHGe-RXM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9318, '2023-02-08 12:13:53.721131+00', '2023-02-09 09:47:50.446617+00', 14200, 2, 1645, '', 'B', 'Tay Dancers, 2023. As is commonly danced in Mairi''s Wedding, the team here pass right shoulders between all the half diagonal reels, though the instructions specify left shoulder.', 1, 1, 'Y', 'wUEucMjEktA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9319, '2023-02-08 15:33:08.010336+00', '2023-02-09 09:48:21.053301+00', 10428, 2, 1645, '', 'B', 'Tay Dancers, 2016.', 1, 1, 'Y', '5goY6tj9Nmo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9320, '2023-02-08 15:39:14.132575+00', '2023-02-09 09:49:15.032337+00', 8912, 2, 1645, '', 'C', 'Lyon Burns Night, 2022.', 1, 1, 'Y', 'HVe8cLQAjLE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9321, '2023-02-08 15:51:36.781882+00', '2023-02-09 09:50:23.470043+00', 6205, 4, 1645, '', 'B', 'Banchory SCD Club at the Aberdeen Festival, 2018. Lively!', 1, 1, 'Y', '5b_hscsahXg', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9322, '2023-02-08 15:57:34.280562+00', '2023-02-09 09:52:04.861736+00', 11190, 3, 1645, '', 'A', 'Lyon mixed team at the Newcastle Festival, 2014.', 1, 1, 'Y', 'DlWq8Q07rU8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9324, '2023-02-08 23:46:07.676067+00', '2023-02-09 09:52:50.388938+00', 11111, 1, 1645, '', 'C', 'Berkeley RSCDS at the Pleasanton Games, 2013. Twice through, once each couple in a 3 couple set. Very good dancing but after turning corners 1st couple consistently do their half figure of 8 found the same couple rather than at the other end.', 1, 1, 'Y', 'otTyo4yxsQg', 15, 95, NULL);
INSERT INTO 'dancevideo' VALUES (8763, '2022-05-29 08:46:14.563107+00', '2023-02-12 21:49:08.631329+00', 20819, 1, 1645, '', 'A', 'From 2022. The video starts about two bars into the dance. It is here done as a jig (originally the dance was intended as a strathspey).', 1, 1, 'Y', '3N1i7kGZ1oY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9329, '2023-02-09 21:49:56.065914+00', '2023-02-13 09:21:18.617134+00', 13891, 1, 1645, '', 'A', 'Newcastle RSCDS at the 2012 Newcastle Festival. Nearly twice through as the last part of a longer display.', 1, 1, 'Y', 'AMVhkllL1Co', 383, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9330, '2023-02-10 12:41:34.364781+00', '2023-02-13 09:21:38.212366+00', 535, 4, 1645, '', 'B', 'Danze Ottocentesche, Italy, 2014. Twice through.', 1, 1, 'Y', 'WcwJmB0ZKa4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9331, '2023-02-10 12:47:09.296612+00', '2023-02-13 09:22:09.427584+00', 535, 5, 1645, '', 'B', 'Richmond SCD Halloween 2013. Three times.', 1, 1, 'Y', '-fCb97NXpEo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9334, '2023-02-13 10:14:13.26387+00', '2023-02-13 10:16:16.636206+00', 6182, 1, 1645, '', 'C', 'Comhlan, Krakow, 2023. Three times.', 1, 1, 'Y', 'SvYP6KTgCsA', 0, 103, NULL);
INSERT INTO 'dancevideo' VALUES (9332, '2023-02-12 21:44:42.457598+00', '2023-02-13 10:16:34.411255+00', 20819, 2, 1645, '', 'C', 'Montreal, 2017. This clip shows last two repeats. Here danced as a strathspey as originally intended (it may also be danced as a jig).', 1, 1, 'Y', 'v4FKQVq6r3g', 58, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9333, '2023-02-12 22:18:57.527448+00', '2023-02-13 10:17:05.92347+00', 12803, 3, 1645, '', 'B', 'Bloorlea SCD group, Toronto, 2010.', 1, 1, 'Y', 'U1qViJEKIZM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9338, '2023-02-13 14:54:22.986272+00', '2023-02-14 12:00:24.330532+00', 1480, 6, 513, '', 'A', 'Edinburgh Scottish Dancers Men''s Team, Newcastle Festival, 2023.', 1, 1, 'Y', 'yA-1E9WKayU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9335, '2023-02-13 14:52:14.578035+00', '2023-02-13 17:43:38.511032+00', 4563, 4, 513, '', 'A', 'East Scotland Dancers Ladies Team, Newcastle Festival, 2023', 1, 1, 'Y', 'DsvQTb8gans', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (2053, '2015-03-30 22:54:06.820868+00', '2023-02-14 16:14:14.930664+00', 11569, 1, 238, '', 'C', 'Scottish Flowers, Hildesheim. The version in the video has been adapted for 3 couples. This clip shows the last two repeats (the video starts part way through the first one).', 1, 1, 'Y', '1o8ySmm6sWw', 36, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9340, '2023-02-13 14:55:56.880118+00', '2023-02-13 17:49:19.91856+00', 3791, 8, 513, '', 'A', 'East Scotland Dancers Ladies Team, Newcastle Festival, 2023.', 1, 1, 'Y', '8yp4t6ItFiA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (7474, '2020-07-18 11:08:00.041691+00', '2023-02-14 17:31:24.895145+00', 8674, 2, 1645, '', 'Z', 'Urals 2018.



Was informal, now unavailable (account terminated).', 1, 1, 'Y', 'XsM8ocBMKTA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9336, '2023-02-13 14:52:59.640638+00', '2023-02-13 18:11:34.465528+00', 4968, 6, 513, '', 'A', 'Edinburgh Scottish Dancers Mixed Team, Newcastle Festival, 2023.', 1, 1, 'Y', 'yH_58_Omy2g', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9337, '2023-02-13 14:53:43.487137+00', '2023-02-13 18:32:50.583503+00', 1768, 3, 513, '', 'A', 'Edinburgh Scottish Dancers Mixed Team, Newcastle Festival, 2023.', 1, 1, 'Y', '6293pwdb4AE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9339, '2023-02-13 14:55:07.338558+00', '2023-02-14 11:56:33.503513+00', 15411, 4, 513, '', 'A', 'Edinburgh Scottish Dancers Men''s Team, Newcastle Festival, 2023.', 1, 1, 'Y', 'w9NfpXufAS8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9346, '2023-02-15 16:57:27.967348+00', '2023-02-15 17:09:33.984016+00', 4679, 3, 1645, '', 'A', 'Red Thistle Dancers, 2018 Pleasanton Games. Twice through as the first part of a longer display. Here danced in 3 couple sets with 1st couple crossing to the bottom at the end of the reels.', 1, 1, 'Y', 'JoLIQMCBeYc', 52, 126, NULL);
INSERT INTO 'dancevideo' VALUES (9341, '2023-02-15 11:59:26.081181+00', '2023-02-15 17:05:59.909695+00', 9333, 1, 1645, '', 'C', 'Séné workshop, Brittany, France, 2023. The video starts about 2 bars into the dance.', 1, 1, 'Y', 'Cn0MbHdr3iU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9342, '2023-02-15 16:33:50.573852+00', '2023-02-15 17:06:32.579889+00', 9015, 2, 1645, '', 'B', 'Kuckucksnest, Germany, 2017.', 1, 1, 'Y', 'gQqmIbIGIXo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9343, '2023-02-15 16:36:20.870211+00', '2023-02-15 17:06:59.827765+00', 11569, 2, 1645, '', 'B', 'Scottish Flowers, Hildesheim, 2015. Here danced in a 3 couple set.', 1, 1, 'Y', '-nmIf6s_aBo', 1, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9344, '2023-02-15 16:43:30.979865+00', '2023-02-15 17:08:03.671258+00', 15565, 2, 1645, '', 'B', 'Vancouver, USA, 2012.', 1, 1, 'Y', '-stPXIMuUqg', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9347, '2023-02-15 17:05:40.456801+00', '2023-02-16 18:56:10.390386+00', 15579, 2, 1645, '', 'B', 'Tay Dancers, 2018.', 1, 1, 'Y', 'bP_ooyIDM6o', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9349, '2023-02-16 13:48:17.516162+00', '2023-02-16 18:56:41.286105+00', 5980, 3, 1645, '', 'B', 'Ruhrball demo, 2018.', 1, 1, 'Y', 'zDo0LzgEUvE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9345, '2023-02-15 16:46:17.680044+00', '2023-02-16 18:56:54.852032+00', 15565, 3, 1645, '', 'B', 'Vancouver, USA, 2012. Alternate view of same performance as video 2.', 1, 1, 'Y', 'jVVYvHxbIrM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9350, '2023-02-16 18:41:10.127915+00', '2023-02-16 18:53:51.751895+00', 20070, 2, 963, '', 'C', 'The set in the middle dances without errors.  There are some creative reels in the other visible sets.', 1, 1, 'Y', 'zFTQ3QtrA2o', 24, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9348, '2023-02-16 13:48:00.871058+00', '2023-02-16 18:54:32.192225+00', 16962, 2, 1645, '', 'A', 'Once through demonstration by two couples with the deviser as 1st man. The video starts about one bar into the dance.', 1, 1, 'Y', '8mHnRemJnGI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9354, '2023-02-17 22:13:12.549208+00', '2023-02-17 22:49:16.78303+00', 3300, 3, 1645, '', 'B', 'Thistle and Ghillies Scottish Country Dancers, Idaho, 2016. Once through.', 1, 1, 'Y', '9GnUnu6Zd4E', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9351, '2023-02-17 21:27:49.304393+00', '2023-02-17 22:49:44.790743+00', 15145, 1, 1645, '', 'C', 'Orange County, California, 2023. Three times through with a few hesitations, starting just into bar 1.', 1, 1, 'Y', 'SXs5c5nDHiA', 0, 148, NULL);
INSERT INTO 'dancevideo' VALUES (9352, '2023-02-17 21:38:27.58351+00', '2023-02-17 22:51:30.286556+00', 21342, 1, 1645, '', 'C', 'Seaforth SCD, Nova Scotia, 2023. Danced with one additional very young dancer in the set.



Unfortunately you can only watch this directly on youtube.', 1, 1, 'Y', 'J4DDl6vyvWE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9353, '2023-02-17 21:49:06.141773+00', '2023-02-17 22:52:03.951641+00', 13206, 2, 1645, '', 'B', 'SCD Münster Christmas Ball, 2016.', 1, 1, 'Y', 'rJJTPnwoIDQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9363, '2023-02-18 12:28:01.926312+00', '2023-02-18 12:38:13.254141+00', 9426, 1, 1645, '', 'C', 'Senior JAMs (Jigs and More) at Matamata, New Zealand, 2016. Once through (last time).', 1, 1, 'Y', 'BdwiUSo9I-8', 29, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9356, '2023-02-18 09:54:45.302377+00', '2023-02-18 12:39:56.861353+00', 16682, 2, 1645, '', 'A', 'Red Thistle Dancers at the 2017 Pleasanton Games. Once through as the first part of a longer display. They also repeat it at the end of the video (from 1:59).', 1, 1, 'Y', 'rXnf8Bu23cE', 3, 43, NULL);
INSERT INTO 'dancevideo' VALUES (9357, '2023-02-18 09:57:40.344964+00', '2023-02-18 12:40:46.644012+00', 20112, 3, 1645, '', 'A', 'Red Thistle Dancers at the 2017 Pleasanton Games. Once through as the middle part of a longer display.', 1, 1, 'Y', 'rXnf8Bu23cE', 42, 120, NULL);
INSERT INTO 'dancevideo' VALUES (9355, '2023-02-17 22:24:24.622577+00', '2023-02-18 18:23:17.556434+00', 4227, 4, 1645, '', 'C', 'Thistle and Ghillies Scottish Country Dancers, Idaho, 2016. Once through.', 1, 1, 'Y', 'TQVFSWhHXew', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9358, '2023-02-18 10:29:00.705495+00', '2023-02-18 18:24:08.544185+00', 7351, 2, 1645, '', 'A', 'Airyhall Girls at the Newcastle Festival, 2020.', 1, 1, 'Y', 'FU0T9zRce4Q', 1, 255, NULL);
INSERT INTO 'dancevideo' VALUES (9359, '2023-02-18 10:29:06.880388+00', '2023-02-18 18:25:05.976654+00', 3225, 5, 1645, '', 'A', 'Airyhall Girls at the Newcastle Festival, 2020.', 1, 1, 'Y', 'FU0T9zRce4Q', 256, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9360, '2023-02-18 10:35:26.612847+00', '2023-02-18 18:25:31.292917+00', 6380, 8, 1645, '', 'A', 'City Moves Team at the Aberdeen Festival, 2018.', 1, 1, 'Y', '8nsvoYCJ9gk', 263, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9361, '2023-02-18 10:35:59.838179+00', '2023-02-18 18:26:17.381333+00', 7351, 3, 1645, '', 'A', 'City Moves Team at the Aberdeen Festival, 2018.', 1, 1, 'Y', '8nsvoYCJ9gk', 2, 262, NULL);
INSERT INTO 'dancevideo' VALUES (9362, '2023-02-18 10:41:05.806533+00', '2023-02-18 18:26:52.40802+00', 7351, 4, 1645, '', 'A', 'Julie Young Dancers at the Aberdeen Festival, 2018.', 1, 1, 'Y', 'tzJ-cFkz-M4', 0, 256, NULL);
INSERT INTO 'dancevideo' VALUES (9368, '2023-02-19 16:37:32.986742+00', '2023-02-19 16:38:08.376228+00', 13385, 3, 202, '', 'D', '', 1, 1, 'Y', 'uz1XafLQzwI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9370, '2023-02-19 23:37:31.032955+00', '2023-02-20 05:35:33.710022+00', 1034, 1, 2824, '', 'A', 'St. Andrews and Glasgow Dancers - Newcastle Festival 2023', 1, 1, 'Y', 'Bzqpvk2dts4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9369, '2023-02-19 23:33:44.84127+00', '2023-02-20 05:58:37.20071+00', 13077, 5, 2824, '', 'A', 'St. Andrews and Glasgow Dancers - Newcastle Festival 2023', 1, 1, 'Y', 'ZeQNGkjPgwI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9366, '2023-02-19 10:58:16.438246+00', '2023-02-20 09:03:37.674341+00', 1483, 3, 1645, '', 'B', 'Clark County Fair, Washington, 2015.', 1, 1, 'Y', 'DSaW4G0qbM0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9374, '2023-02-20 12:28:12.190326+00', '2023-02-20 12:28:31.883152+00', 5555, 7, 1645, '', 'A', 'International Team Men, Newcastle Festival, 2017. Minor hesitation stepping in for the poussette.', 1, 1, 'Y', 'HC4sBNkPEn8', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9371, '2023-02-20 11:05:58.500006+00', '2023-02-20 12:28:37.414206+00', 7284, 8, 1645, '', 'A', 'International Team, Newcastle Festival, 2017.', 1, 1, 'Y', '7558YeHHzwQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9372, '2023-02-20 12:07:21.185756+00', '2023-02-20 12:28:45.365379+00', 21344, 1, 1645, '', 'C', 'Naramata Scottish Dancers, 2022. First try of a new dance. The 3rd couples sometimes forget to join in the final turns.', 1, 1, 'Y', 'Vsq4clq3m5M', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9373, '2023-02-20 12:23:18.328833+00', '2023-02-20 12:31:50.430979+00', 4126, 2, 1645, '', 'A', 'International Team Men, Newcastle Festival, 2017.', 1, 1, 'Y', 'XjIuRq-SQK4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9367, '2023-02-19 11:12:25.060757+00', '2023-02-20 12:32:36.363136+00', 19964, 2, 1645, '', 'C', 'Méaudre Reel, France 2022.', 1, 1, 'Y', 'qZjW3XEFXiU', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9365, '2023-02-19 10:27:05.884047+00', '2023-02-20 12:32:57.218259+00', 1483, 2, 1645, '', 'D', 'SCD Münster Christmas Ball, 2016. This clip shows the last few times.', 1, 1, 'Y', 'o7_b6WZgluc', 148, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9364, '2023-02-19 10:09:43.996157+00', '2023-02-20 12:34:42.147175+00', 1283, 2, 1645, '', 'C', 'Fanwood, New Jersey, 2017. Danced in a 3 couple set. Twice through.', 1, 1, 'V', '207228319', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9375, '2023-02-21 01:40:03.552612+00', '2023-02-21 01:40:03.552612+00', 3963, 3, 1296, '', 'X', '''Lothian Lads'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'NCvGNBKMFaw', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9376, '2023-02-21 01:40:03.576461+00', '2023-02-21 01:40:03.576461+00', 9109, 4, 1296, '', 'X', '''Airyhall Delight'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'MXfjbtmE9h8', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9377, '2023-02-21 01:40:03.595216+00', '2023-02-21 01:40:03.595216+00', 11771, 2, 1296, '', 'X', '''Cocket Hat, The'' is a 40 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', '2MwunAEDaUs', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9378, '2023-02-21 01:40:03.614654+00', '2023-02-21 01:40:03.614654+00', 9780, 1, 1296, '', 'X', '''Laura''s Ceilidh'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'OLFj-dElYSQ', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9379, '2023-02-21 01:40:03.642232+00', '2023-02-21 01:40:03.642232+00', 1465, 3, 1296, '', 'X', '''Cuckoo Clock, The'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', 'js1EKU780bY', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9384, '2023-02-21 20:24:33.847896+00', '2023-02-21 22:10:31.127182+00', 5641, 2, 2824, '', 'A', 'Twice through as part of a longer display.

St. Andrews and Glasgow Dancers, Newcastle Festival 2023

(Slightly unfortunate camera angle in that the set fully in view is the one at the far end of the hall.)', 1, 1, 'Y', 'VtpEVw4zYuw', 229, 297, NULL);
INSERT INTO 'dancevideo' VALUES (9380, '2023-02-21 09:35:18.139547+00', '2023-02-21 22:10:45.692913+00', 5812, 2, 1645, '', 'A', '', 1, 1, 'Y', '4Dj5rlckd1w', 8, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9381, '2023-02-21 09:37:40.262303+00', '2023-02-21 22:11:07.192308+00', 7105, 6, 1645, '', 'A', 'Gorky Team at the Kazan SCD Festival, 2019', 1, 1, 'Y', 'g04v0KPynA4', 6, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9382, '2023-02-21 09:42:07.737942+00', '2023-02-21 22:11:40.038027+00', 16460, 2, 1645, '', 'C', 'Youth Ball, Toronto, 2018.', 1, 1, 'Y', 'PfOlzZAaYts', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9383, '2023-02-21 20:14:41.641143+00', '2023-02-22 00:44:33.833979+00', 5612, 1, 2824, '', 'A', 'Once through as part of a longer display.

St. Andrews and Glasgow Dancers, Newcastle Festival 2023', 1, 1, 'Y', 'VtpEVw4zYuw', 314, 373, NULL);
INSERT INTO 'dancevideo' VALUES (9388, '2023-02-22 01:46:00.996115+00', '2023-02-22 02:16:57.933112+00', 8155, 1, 31996, '', 'D', 'Video begins with an instructive "walk" thru, then it is danced twice with a walking step and three times with skip change to a jig set played by Dave Mullen on fiddle. A small Mardi Gras party dance in Milwaukee, Wisconsin.', 1, 1, 'Y', 'ol9ZqJQvJqI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9386, '2023-02-22 00:42:05.348616+00', '2023-02-22 09:35:57.241183+00', 21346, 1, 1645, '', 'A', 'Cheboksary Festival of Scottish Culture, 2023. Twice through as the first part of a longer demo.', 1, 1, 'Y', 'ebQ1LZGNo_M', 30, 155, NULL);
INSERT INTO 'dancevideo' VALUES (9387, '2023-02-22 00:44:19.81871+00', '2023-02-22 09:36:15.527192+00', 21347, 1, 1645, '', 'A', 'Cheboksary Festival of Scottish Culture, 2023. Twice through as the second part of a longer demo.', 1, 1, 'Y', 'ebQ1LZGNo_M', 155, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9389, '2023-02-22 09:08:32.185276+00', '2023-02-22 22:52:54.032593+00', 14534, 5, 513, '', 'A', '', 1, 1, 'Y', '-nlWqrKXfZY', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9390, '2023-02-22 09:09:16.763643+00', '2023-02-22 22:53:58.977624+00', 1034, 2, 513, '', 'A', '', 1, 1, 'Y', 'Bzqpvk2dts4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9392, '2023-02-22 09:21:14.955138+00', '2023-02-22 23:00:14.529521+00', 301, 7, 513, '', 'A', '', 1, 1, 'Y', 'm7Ftr6OP9UQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9396, '2023-02-22 09:24:34.74751+00', '2023-02-22 23:11:27.755969+00', 4857, 6, 513, '', 'A', '', 1, 1, 'Y', 'pSWs6xEPMiE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9393, '2023-02-22 09:21:53.656533+00', '2023-02-22 23:13:59.494656+00', 2600, 9, 513, '', 'A', '', 1, 1, 'Y', 'i4U8hgdkoZs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9394, '2023-02-22 09:22:45.570344+00', '2023-02-23 10:27:44.159407+00', 16527, 7, 513, '', 'A', '', 1, 1, 'Y', 'mpe3FVJH9PQ', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9395, '2023-02-22 09:23:51.948826+00', '2023-02-23 10:30:30.966463+00', 16537, 9, 513, '', 'A', '', 1, 1, 'Y', 'BC3atxdVux4', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9398, '2023-02-22 16:39:12.833453+00', '2023-02-23 10:33:28.078276+00', 1250, 1, 963, '', 'C', 'Montreal, 2023. The video starts about 1 bar into the dance.', 1, 1, 'Y', 'G9gxfk690TE', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9391, '2023-02-22 09:12:44.026458+00', '2023-02-22 22:56:12.012822+00', 4720, 4, 513, '', 'A', '', 1, 1, 'Y', 'OKjXTECQGKo', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9397, '2023-02-22 09:25:21.233366+00', '2023-02-22 23:02:23.887083+00', 10790, 5, 513, '', 'A', '', 1, 1, 'Y', 'JYC3WUSwYXA', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9399, '2023-02-22 16:48:10.05157+00', '2023-02-23 00:12:51.758064+00', 17973, 1, 963, '', 'D', 'I, the devisor, was teaching this from a crib on scddatabase (had several beginners and needed an easy RR dance).  The crib was not correct and I adlibbed.  Thus the first 16 bars of the video do not follow the original instructions.  The crib has now been corrected to match the original instructions.  I am adding the video for two reasons.  One: dancing the way I adlibbed it works well.  Two: the last 8 bars are easier to ''see'' than to describe and they are done correctly in the video.  Permission granted to dance it either way !', 1, 1, 'Y', 'QiH65xO5fQk', 24, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9400, '2023-02-22 16:54:20.364159+00', '2023-02-23 10:34:55.554338+00', 17962, 1, 963, '', 'C', 'This video starts part way through the dance but I left it because everyone finishes in the correct position at the end of that one but on the last one the dancers overshoot their places and don''t end correctly.', 1, 1, 'Y', '7jeKDg1XKgk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9401, '2023-02-23 06:21:59.366687+00', '2023-02-23 10:37:11.761467+00', 17538, 2, 2824, '', 'C', 'Naramata Scottish Country Dancers 2023', 1, 1, 'Y', '0wzJx2xE3I0', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9402, '2023-02-23 15:03:04.268389+00', '2023-02-23 17:26:18.384297+00', 13381, 1, 645, '', 'B', 'January 2023 - Tokyo 



"To Be A Wind" (J32-5C) devised by Masako Okada Naitoh.

It is published in "To Be A Wind" book, the 25th anniversary book of Tokyo Scottish Bluebell Club.



This is to clarify the complicated part, bars 1-14, a series of various half reels on own sides: 

half reels of three in tandem(5 dancers)/half reels of four/half reels of three/half turn(2 bars)', 1, 1, 'Y', 'DnJ1Pb3eAmM', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9403, '2023-02-23 20:35:16.791838+00', '2023-02-23 21:11:13.459951+00', 10937, 2, 1645, '', 'B', 'Paris Spring Fling, 2019. This clip just shows one clear repeat. The top is on the right.', 1, 1, 'Y', 'kxNjTY_Faps', 39, 76, NULL);
INSERT INTO 'dancevideo' VALUES (9406, '2023-02-23 20:59:19.778636+00', '2023-02-23 21:12:21.710055+00', 9000, 3, 1645, '', 'B', 'Deer o'' Dale Dance School, Ufa, 2018.', 1, 1, 'Y', 'nIObI3i5ajk', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9404, '2023-02-23 20:39:35.579893+00', '2023-02-23 21:13:48.928966+00', 6637, 2, 1645, '', 'A', 'RSCDS Edinburgh Dancing Forth 2007. Once each couple in two 3 couple sets with 1st couple casting to 3rd place each time. The first part of a longer display. Good view from above for the 1st time, thereafter the camera zooms in on individual couples.', 1, 1, 'Y', 'dEUUKZlsM9I', 1, 108, NULL);
INSERT INTO 'dancevideo' VALUES (9405, '2023-02-23 20:53:05.242459+00', '2023-02-23 21:15:01.489112+00', 5843, 4, 1645, '', 'B', 'Otago Region, NZ Branch, 2017. Generally clear with a little guidance here and there.', 1, 1, 'Y', 'H4RbiJniKUs', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9407, '2023-02-23 21:15:52.157432+00', '2023-02-25 18:11:47.108119+00', 4441, 2, 1645, '', 'C', 'Helensburgh RSCDS, 2017.', 1, 1, 'Y', 'p_dtn7868wY', 36, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9408, '2023-02-24 17:31:42.896017+00', '2023-02-25 18:12:28.249905+00', 8088, 2, 1645, '', 'B', 'Toronto Workshop Tea Dance, 2016. Once each couple. A slightly dark and distant view but the choreography is clear.', 1, 1, 'Y', 'T9c2bZ6IOpA', 11, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9409, '2023-02-24 18:03:13.424391+00', '2023-02-25 18:13:18.156568+00', 3829, 2, 1645, '', 'A', 'Edinburgh RSCDS, Dancing Forth 2009. Twice through as the last part of a longer display (the previous dance had a sixth couple who dance off at the start here).', 1, 1, 'Y', 'DlRJyOHhlMY', 579, 685, NULL);
INSERT INTO 'dancevideo' VALUES (9410, '2023-02-24 18:41:04.941344+00', '2023-02-25 18:14:45.229368+00', 1304, 3, 1645, '', 'A', 'Instructional video by RSCDS Stirling, 1993. Once through demo with two couples, repeated with more couples.', 1, 1, 'Y', 'IfZHXhxDmZM', 3462, 3664, NULL);
INSERT INTO 'dancevideo' VALUES (9411, '2023-02-27 10:19:49.298521+00', '2023-02-27 17:37:27.924139+00', 4929, 3, 1645, '', 'A', 'Stirling, 1994.', 1, 1, 'Y', 'Yoa_lJvXXGY', 2004, 2116, NULL);
INSERT INTO 'dancevideo' VALUES (9412, '2023-02-27 10:19:53.578475+00', '2023-02-27 17:38:10.314028+00', 776, 3, 1645, '', 'C', 'SW Washington State at Clark County Fair, 2011. Once each couple, mixture of dancing and walking.', 1, 1, 'Y', 'QtrwkCGy5y4', 285, 400, NULL);
INSERT INTO 'dancevideo' VALUES (9413, '2023-02-27 10:33:44.48987+00', '2023-02-27 17:38:28.862417+00', 3803, 2, 1645, '', 'C', '', 1, 1, 'Y', '8wTyr8XrCYM', 3, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9414, '2023-02-27 11:08:05.527487+00', '2023-02-27 17:38:54.517151+00', 8058, 2, 1645, '', 'C', 'Telheiras SCD, 2009. Once through as part of a longer demo with the end adapted to lead into a square set.', 1, 1, 'Y', 'QZITJttK_Vc', 9, 50, NULL);
INSERT INTO 'dancevideo' VALUES (9415, '2023-02-27 17:28:00.896773+00', '2023-02-27 17:39:34.240372+00', 2260, 8, 1645, '', 'C', 'RSCDS Centenary 2023. Montage of very brief clips of many groups around the world doing the dance. A fun celebratory video - but not for learning the dance!', 1, 1, 'Y', 'sbNQBgkk3SI', 0, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9416, '2023-02-27 17:35:57.63673+00', '2023-02-27 17:40:40.840296+00', 2260, 9, 1645, '', 'B', 'RSCDS Richmond Branch and Mowden Junior Dancers, 2023. Youngsters doing the dance (with sound effects and only a few minor hesitations) in front of a steam locomotive as part of the RSCDS Centenary celebrations.', 1, 1, 'Y', '4TnlOJg00JA', 2, 0, NULL);
INSERT INTO 'dancevideo' VALUES (9417, '2023-02-28 01:40:03.103054+00', '2023-02-28 01:40:03.103054+00', 2745, 4, 1296, '', 'X', '''Hamilton House'' is a 32 bar jig for 3 couples in a 4 couple set.', 1, 1, 'Y', 'XVtcUxKrmVE', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9418, '2023-02-28 01:40:03.133511+00', '2023-02-28 01:40:03.133511+00', 6972, 8, 1296, '', 'X', '''Weathercock, The'' is a 32 bar reel for 4 couples in a 4 couple set.', 1, 1, 'Y', 'gf0PMY-rRa0', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9419, '2023-02-28 01:40:03.159799+00', '2023-02-28 01:40:03.159799+00', 2631, 4, 1296, '', 'X', '''Gramachie'' is a 32 bar strathspey for 3 couples in a 4 couple set.', 1, 1, 'Y', 'KS9_KNMmzmk', 0, 0, 1);
INSERT INTO 'dancevideo' VALUES (9420, '2023-02-28 01:40:03.172266+00', '2023-02-28 01:40:03.172266+00', 13270, 5, 1296, '', 'X', '''City of Stirling Reel'' is a 32 bar reel for 3 couples in a 4 couple set.', 1, 1, 'Y', '95wnWQblgdg', 0, 0, 1);


--
INSERT INTO 'formation' VALUES (1, NULL, '2012-01-20 12:55:59.358677+00', 'A&R2', 'Advance and Retire', 'ADVRET;2S;', '');
INSERT INTO 'formation' VALUES (22, NULL, '2012-01-20 12:55:59.411345+00', 'CHAIN6', 'Grand Chain for 6', 'GCHAIN;6P;', '');
INSERT INTO 'formation' VALUES (3, NULL, '2012-01-20 12:55:59.364311+00', 'A&TRN', 'Advance and Turn', 'ADVTRN', '');
INSERT INTO 'formation' VALUES (4, NULL, '2012-01-20 12:55:59.366921+00', 'ALL2C', 'Allemande for 2 couples', 'ALLMND;2C;', '');
INSERT INTO 'formation' VALUES (23, NULL, '2012-01-20 12:55:59.414011+00', 'CHASE', 'Chase', 'CHASE', '');
INSERT INTO 'formation' VALUES (5, NULL, '2012-01-20 12:55:59.369581+00', 'ALL3C', 'Allemande for 3 couples', 'ALLMND;3C;', '');
INSERT INTO 'formation' VALUES (6, NULL, '2012-01-20 12:55:59.372305+00', 'ALL4C', 'Allemande for 4 couples', 'ALLMND;4C;', '');
INSERT INTO 'formation' VALUES (24, NULL, '2012-01-20 12:55:59.416586+00', 'CROWN', 'Crown Triangles', 'CROWN', '');
INSERT INTO 'formation' VALUES (7, NULL, '2012-01-20 12:55:59.374897+00', 'ARCH', 'Arches', 'ARCHES', '');
INSERT INTO 'formation' VALUES (8, NULL, '2012-01-20 12:55:59.377489+00', 'B-T-B', 'Back to Back', 'BKTOBK', '');
INSERT INTO 'formation' VALUES (25, NULL, '2012-01-20 12:55:59.419167+00', 'D-TRI', 'Double Triangles', 'DBLTRI', '');
INSERT INTO 'formation' VALUES (9, NULL, '2012-01-20 12:55:59.380067+00', 'BAL', 'Balance in Line', 'BALNCE', '');
INSERT INTO 'formation' VALUES (10, NULL, '2012-01-20 12:55:59.38265+00', 'BARAT', 'Baratte, La', 'BARAT', '');
INSERT INTO 'formation' VALUES (26, NULL, '2012-01-20 12:55:59.421736+00', 'ESPAN', 'Espagnole', 'ESPAN', '');
INSERT INTO 'formation' VALUES (12, NULL, '2012-01-20 12:55:59.387803+00', 'C-BAL', 'Balance with Corners', 'BALNCE;CRNRS;', '');
INSERT INTO 'formation' VALUES (27, NULL, '2012-01-20 12:55:59.424308+00', 'FIG8', 'Figure of Eight', 'FIG8;1C;', '');
INSERT INTO 'formation' VALUES (13, NULL, '2012-01-20 12:55:59.390382+00', 'C-D&S', 'Dance to Corners and Set', 'C-D&S', '');
INSERT INTO 'formation' VALUES (16, NULL, '2012-01-20 12:55:59.395673+00', 'C-S&T', 'Set to and turn Corners', 'S&T;CRNRS;', '');
INSERT INTO 'formation' VALUES (17, NULL, '2012-01-20 12:55:59.398251+00', 'C-SCP', 'Set to Corners and Partner', 'C-SCP', '');
INSERT INTO 'formation' VALUES (29, NULL, '2012-01-20 12:55:59.43075+00', 'FIG8H', 'Figure of Eight - half', 'FIG8;1C;HALF;', '');
INSERT INTO 'formation' VALUES (18, NULL, '2012-01-20 12:55:59.400819+00', 'C-SET', 'Set to Corners', 'C-SET', '');
INSERT INTO 'formation' VALUES (19, NULL, '2012-01-20 12:55:59.403404+00', 'C-TCP', 'Turn Corners and Partner', 'CPCP', '');
INSERT INTO 'formation' VALUES (30, NULL, '2012-01-20 12:55:59.433446+00', 'HR3', 'Hands round - 3', 'HR;3P;', '');
INSERT INTO 'formation' VALUES (20, NULL, '2012-01-20 12:55:59.405985+00', 'C-TRN', 'Turn Corners', 'C-TRN', '');
INSERT INTO 'formation' VALUES (31, NULL, '2012-01-20 12:55:59.436273+00', 'HR3-S', 'Hands round - 3 - with setting', 'HR;3P;SET;', '');
INSERT INTO 'formation' VALUES (32, NULL, '2012-01-20 12:55:59.439052+00', 'HR4', 'Hands round - 4', 'HR;4P;', '');
INSERT INTO 'formation' VALUES (33, NULL, '2012-01-20 12:55:59.441622+00', 'HR4-H', 'Hands round - 4 - half', 'HR;4P;HALF;', '');
INSERT INTO 'formation' VALUES (34, NULL, '2012-01-20 12:55:59.444182+00', 'HR4-S', 'Hands round - 4 - with setting', 'HR;4P;SET;', '');
INSERT INTO 'formation' VALUES (36, NULL, '2012-01-20 12:55:59.449574+00', 'HR6-H', 'Hands round - 6 - half', 'HR;6P;HALF;', '');
INSERT INTO 'formation' VALUES (37, NULL, '2012-01-20 12:55:59.452438+00', 'HR6-S', 'Hands round - 6 - with setting', 'HR;6P;SET;', '');
INSERT INTO 'formation' VALUES (38, NULL, '2012-01-20 12:55:59.455097+00', 'HR8', 'Hands round - 8', 'HR;8P;', '');
INSERT INTO 'formation' VALUES (39, NULL, '2012-01-20 12:55:59.457674+00', 'HR8-H', 'Hands round - 8 - half', 'HR;8P;HALF;', '');
INSERT INTO 'formation' VALUES (40, NULL, '2012-01-20 12:55:59.460243+00', 'HRPRO', 'Reel Progression (Dalradian)', 'HFRPR', '');
INSERT INTO 'formation' VALUES (371, '2018-04-26 16:06:17.121948+00', '2018-04-26 16:06:17.121948+00', '  ', 'Hands Round - 16', 'HR;16P;', '');
INSERT INTO 'formation' VALUES (42, NULL, '2012-01-20 12:55:59.465386+00', 'HX3', 'Hands across - 3', 'HX;3P;', '');
INSERT INTO 'formation' VALUES (43, NULL, '2012-01-20 12:55:59.46795+00', 'HX4', 'Hands across - 4', 'HX;4P;', '');
INSERT INTO 'formation' VALUES (45, NULL, '2012-01-20 12:55:59.470306+00', 'HX4-S', 'Hands across - 4 - with setting', 'HX;4P;SET;', '');
INSERT INTO 'formation' VALUES (46, NULL, '2012-01-20 12:55:59.472355+00', 'HX6', 'Hands across - 6', 'HX;6P;', '');
INSERT INTO 'formation' VALUES (47, NULL, '2012-01-20 12:55:59.47643+00', 'HX6-S', 'Hands across - 6 - with setting', 'HX;6P;SET;', '');
INSERT INTO 'formation' VALUES (49, NULL, '2012-01-20 12:55:59.480979+00', 'KNOT3', 'Knot 3 couples', 'KNOT;3C;', '');
INSERT INTO 'formation' VALUES (50, NULL, '2012-01-20 12:55:59.483007+00', 'KNOT4', 'Knot 4 couples', 'KNOT;4C;', '');
INSERT INTO 'formation' VALUES (51, NULL, '2012-01-20 12:55:59.485005+00', 'L&R', 'Lefts and rights', 'L&R', '');
INSERT INTO 'formation' VALUES (70, NULL, '2012-01-20 12:55:59.52415+00', 'R&L-3', 'Rights and Lefts for 3 couples', 'R&L;3C;', '');
INSERT INTO 'formation' VALUES (52, NULL, '2012-01-20 12:55:59.487026+00', 'LADC', 'Ladies'' Chain', 'LCHAIN', '');
INSERT INTO 'formation' VALUES (53, NULL, '2012-01-20 12:55:59.489028+00', 'MENC', 'Men''s Chain', 'MCHAIN', '');
INSERT INTO 'formation' VALUES (71, NULL, '2012-01-20 12:55:59.526188+00', 'R&L-D', 'Rights and Lefts - diagonal', 'R&L;DIAG;', '');
INSERT INTO 'formation' VALUES (72, NULL, '2012-01-20 12:55:59.530631+00', 'R&L-H', 'Rights and Lefts - half', 'R&L;HALF;', '');
INSERT INTO 'formation' VALUES (57, NULL, '2012-01-20 12:55:59.497366+00', 'PHILA', 'Philabeg', 'PHILA', '');
INSERT INTO 'formation' VALUES (73, NULL, '2012-01-20 12:55:59.532853+00', 'R&L-S', 'Rights and Lefts with Setting', 'R&L;SET;', '');
INSERT INTO 'formation' VALUES (58, NULL, '2012-01-20 12:55:59.499376+00', 'POUH', 'Poussette - half', 'POUSS;HALF;', '');
INSERT INTO 'formation' VALUES (60, NULL, '2012-01-20 12:55:59.503435+00', 'POURR', 'Poussette right round - quicktime', 'POUSS;RR;', '');
INSERT INTO 'formation' VALUES (61, NULL, '2012-01-20 12:55:59.505599+00', 'POUS2', 'Poussette - standard', 'POUSS;PV;', '');
INSERT INTO 'formation' VALUES (75, NULL, '2012-01-20 12:55:59.536893+00', 'R3-IN', 'Reel of three - crossing (Inveran)', 'REEL;CRSING;R3;', '');
INSERT INTO 'formation' VALUES (62, NULL, '2012-01-20 12:55:59.50766+00', 'POUS3', 'Poussette 3 couples', 'POUSS;3C;', '');
INSERT INTO 'formation' VALUES (63, NULL, '2012-01-20 12:55:59.509673+00', 'POUS4', 'Poussette 4 couples', 'POUSS;4C;', '');
INSERT INTO 'formation' VALUES (76, NULL, '2012-01-20 12:55:59.539376+00', 'R3ACR', 'Reel of three - across', 'REEL;ACROSS;R3;', '');
INSERT INTO 'formation' VALUES (64, NULL, '2012-01-20 12:55:59.511675+00', 'PROM2', 'Promenade 2 couples', 'PROM;2C;', '');
INSERT INTO 'formation' VALUES (65, NULL, '2012-01-20 12:55:59.513761+00', 'PROM3', 'Promenade 3 couples', 'PROM;3C;', '');
INSERT INTO 'formation' VALUES (77, NULL, '2012-01-20 12:55:59.541554+00', 'R3CNR', 'Reel of three - with corners', 'REEL;CRNRS;DOUBLE;R3;', '');
INSERT INTO 'formation' VALUES (66, NULL, '2012-01-20 12:55:59.515889+00', 'PROM4', 'Promenade 4 couples', 'PROM;4C;', '');
INSERT INTO 'formation' VALUES (67, NULL, '2012-01-20 12:55:59.517949+00', 'R&A', 'Retire and advance', 'RETADV', '');
INSERT INTO 'formation' VALUES (78, NULL, '2012-01-20 12:55:59.543628+00', 'R3CRO', 'Reel of three - crossing', 'REEL;CRSING;R3;', '');
INSERT INTO 'formation' VALUES (68, NULL, '2012-01-20 12:55:59.520061+00', 'R&A-S', 'Retire & Advance with Setting', 'RETADV;SET;', '');
INSERT INTO 'formation' VALUES (69, NULL, '2012-01-20 12:55:59.522103+00', 'R&L', 'Rights and Lefts', 'R&L', '');
INSERT INTO 'formation' VALUES (79, NULL, '2012-01-20 12:55:59.545756+00', 'R3PL1', 'Reel of three - dancing couple plus one', 'REEL;DC+;R3;', '');
INSERT INTO 'formation' VALUES (80, NULL, '2012-01-20 12:55:59.547816+00', 'R3DOU', 'Reel of three - double, (not GE)', 'REEL;DOUBLE;R3;', '');
INSERT INTO 'formation' VALUES (81, NULL, '2012-01-20 12:55:59.549838+00', 'R3PRO', 'Reel of three - promenade hold', 'REEL;PRMHLD;R3;', '');
INSERT INTO 'formation' VALUES (83, NULL, '2012-01-20 12:55:59.553938+00', 'R4ACR', 'Reel of four - across', 'REEL;ACROSS;R4;', '');
INSERT INTO 'formation' VALUES (84, NULL, '2012-01-20 12:55:59.555956+00', 'R4DIA', 'Reel of four - diagonal', 'REEL;DIAG;R4;', '');
INSERT INTO 'formation' VALUES (86, NULL, '2012-01-20 12:55:59.56008+00', 'REEL3', 'Reel of three', 'REEL;R3;', '');
INSERT INTO 'formation' VALUES (87, NULL, '2012-01-20 12:55:59.562085+00', 'REEL4', 'Reel of four', 'REEL;R4;', '');
INSERT INTO 'formation' VALUES (88, NULL, '2012-01-20 12:55:59.564086+00', 'REEL5', 'Reel of five', 'REEL;R5;', '');
INSERT INTO 'formation' VALUES (89, NULL, '2012-01-20 12:55:59.56609+00', 'REEL6', 'Reel of six', 'REEL;R6;', '');
INSERT INTO 'formation' VALUES (91, NULL, '2012-01-20 12:55:59.570093+00', 'RONDL', 'Rondel', 'RONDEL', '');
INSERT INTO 'formation' VALUES (92, NULL, '2012-01-20 12:55:59.572095+00', 'S&L-3', 'Set and Link for three', 'SETLNK;3P;', '');
INSERT INTO 'formation' VALUES (95, NULL, '2012-01-20 12:55:59.578286+00', 'S-2&2', 'Set in line in twos', 'SETLIN;2P;', '');
INSERT INTO 'formation' VALUES (96, NULL, '2012-01-20 12:55:59.58032+00', 'S-3&3', 'Set in line in threes', 'SETLIN;3P;', '');
INSERT INTO 'formation' VALUES (101, NULL, '2012-01-20 12:55:59.582338+00', 'SPURT', 'Spurtle', 'SPURT', '');
INSERT INTO 'formation' VALUES (227, NULL, '2012-01-20 12:55:59.820045+00', '', 'Rights and Lefts - chain', 'R&L;CHAIN;', '');
INSERT INTO 'formation' VALUES (125, NULL, '2012-01-20 12:55:59.623339+00', 'R3CNX', 'Reel of three - with corners & crossing', 'REEL;CRNRS;CROSS;R3;', '');
INSERT INTO 'formation' VALUES (102, NULL, '2012-01-20 12:55:59.584348+00', 'TOURB', 'Tourbillon', 'TOURB', '');
INSERT INTO 'formation' VALUES (54, NULL, '2014-09-02 07:33:17.517383+00', 'PET', 'Petronella (16 bars)', 'PET', '');
INSERT INTO 'formation' VALUES (55, NULL, '2014-09-02 07:33:52.690713+00', 'PET-H', 'Petronella - half (8 bars)', 'PET;HALF;', '');
INSERT INTO 'formation' VALUES (103, NULL, '2012-01-20 12:55:59.586494+00', 'TOURN', 'Tournee', 'TOURN', '');
INSERT INTO 'formation' VALUES (126, NULL, '2012-01-20 12:55:59.62536+00', 'DMU-4', 'Dance down and up - 4 people', 'DWNUP;4P;', '');
INSERT INTO 'formation' VALUES (2, NULL, '2017-10-10 15:14:18.693285+00', 'A&R-S', 'Advance and Retire, with Setting', 'ADVRET;2S;SET;', '');
INSERT INTO 'formation' VALUES (105, NULL, '2012-01-20 12:55:59.590573+00', 'C_CA', 'Corners'' Chain', 'CCHAIN', '');
INSERT INTO 'formation' VALUES (48, NULL, '2021-05-15 10:40:28.586826+00', 'KNOT2', 'Knot 2 couples', 'KNOT;2C;', 'The Knot was originally devised by <<ddp:Corson, Mina#86>> for <<ddd:Miss Milligan''s Strathspey#4555>> as mentioned in the extra info for <<ddd:Welcome Mina Corson#7017>>.');
INSERT INTO 'formation' VALUES (21, NULL, '2021-07-02 12:28:07.764396+00', 'CH-PR', 'Chain Progression', 'CH-PR', 'Introduced by Eric Forbes.');
INSERT INTO 'formation' VALUES (127, NULL, '2012-01-20 12:55:59.627374+00', 'CBL&B', 'Cast behind own lines and back', 'CBL&B', '');
INSERT INTO 'formation' VALUES (106, NULL, '2012-01-20 12:55:59.592588+00', 'ENRON', 'En Rond', 'ENROND', '');
INSERT INTO 'formation' VALUES (107, NULL, '2012-01-20 12:55:59.59463+00', 'SERP', 'Serpentine', 'SERP', '');
INSERT INTO 'formation' VALUES (109, NULL, '2012-01-20 12:55:59.596628+00', 'SPOKE', 'Spoke', 'SPOKE', '');
INSERT INTO 'formation' VALUES (110, NULL, '2012-01-20 12:55:59.598738+00', 'TARGE', 'Targe', 'TARGE', '');
INSERT INTO 'formation' VALUES (130, NULL, '2012-01-20 12:55:59.631388+00', 'STAR', 'Star Chain', 'GCHAIN;8P;STAR;', '');
INSERT INTO 'formation' VALUES (111, NULL, '2012-01-20 12:55:59.600818+00', 'DMU-L', 'Lead down and up', 'DWNUP;LEAD;', '');
INSERT INTO 'formation' VALUES (112, NULL, '2012-01-20 12:55:59.602843+00', 'R4-H', 'Reel of four - half', 'REEL;HALF;R4;', '');
INSERT INTO 'formation' VALUES (131, NULL, '2012-01-20 12:55:59.633391+00', 'DMU-3', 'Dance down and up - 3 people', 'DWNUP;3P;', '');
INSERT INTO 'formation' VALUES (132, NULL, '2012-01-20 12:55:59.635397+00', 'CLAP', 'Clap', 'CLAP', '');
INSERT INTO 'formation' VALUES (114, NULL, '2012-01-20 12:55:59.604848+00', 'R3-H', 'Reel of three - half', 'REEL;HALF;R3;', '');
INSERT INTO 'formation' VALUES (133, NULL, '2012-01-20 12:55:59.637402+00', 'S&T', 'Set to and turn Partners', 'S&T;PRTNRS;', '');
INSERT INTO 'formation' VALUES (117, NULL, '2012-01-20 12:55:59.606863+00', 'R4INT', 'Reel of four - interlocking', 'REEL;INTRLK;R4;', '');
INSERT INTO 'formation' VALUES (134, NULL, '2012-01-20 12:55:59.639417+00', 'A&R1', 'Advance and Retire - 1 step', 'ADVRET;1S;', '');
INSERT INTO 'formation' VALUES (135, NULL, '2012-01-20 12:55:59.641546+00', 'HR7', 'Hands round - 7', 'HR;7P;', '');
INSERT INTO 'formation' VALUES (118, NULL, '2012-01-20 12:55:59.608868+00', 'POU-1', 'Poussette 1 couple', 'POUSS;1C;', '');
INSERT INTO 'formation' VALUES (138, NULL, '2012-01-20 12:55:59.643713+00', 'HX4-X', 'Hands across - 4 - special', 'HX;4P;SPEC;', '');
INSERT INTO 'formation' VALUES (119, NULL, '2012-01-20 12:55:59.610872+00', 'R4DGH', 'Reel of four - diagonal - half', 'REEL;DIAG;HALF;R4;', '');
INSERT INTO 'formation' VALUES (139, NULL, '2012-01-20 12:55:59.645758+00', 'POUH-X', 'Poussette - half - special', 'POUSS;HALF;SPEC;', '');
INSERT INTO 'formation' VALUES (120, NULL, '2012-01-20 12:55:59.612873+00', 'LCHAH', 'Ladies'' Chain - half', 'LCHAIN;HALF;', '');
INSERT INTO 'formation' VALUES (142, NULL, '2012-01-20 12:55:59.649782+00', 'HR4-B', 'Hands round - 4 - and back', 'HR;4P;BACK;', '');
INSERT INTO 'formation' VALUES (121, NULL, '2012-01-20 12:55:59.615006+00', 'MCHAH', 'Men''s Chain - half', 'MCHAIN;HALF;', '');
INSERT INTO 'formation' VALUES (143, NULL, '2012-01-20 12:55:59.651797+00', 'HX4-RL', 'Hands across - 4 - and back', 'HX;4P;BACK;', '');
INSERT INTO 'formation' VALUES (144, NULL, '2012-01-20 12:55:59.653942+00', 'R&L-F-X', 'Rights and Lefts - four bars - special', 'R&L;FOURB;SPEC;', '');
INSERT INTO 'formation' VALUES (122, NULL, '2012-01-20 12:55:59.617028+00', 'MILLW', 'Millwheel', 'MILLWHEEL', '');
INSERT INTO 'formation' VALUES (124, NULL, '2012-01-20 12:55:59.621322+00', 'R3INT', 'Reel of three - interlocking', 'REEL;INTRLK;R3;', '');
INSERT INTO 'formation' VALUES (149, NULL, '2012-01-20 12:55:59.664077+00', 'CHAIN8', 'Grand Chain for 8', 'GCHAIN;8P;', '');
INSERT INTO 'formation' VALUES (150, NULL, '2012-01-20 12:55:59.666084+00', 'DKNOT', 'Divided Knot', 'KNOT;2C;DIVIDE;', '');
INSERT INTO 'formation' VALUES (151, NULL, '2012-01-20 12:55:59.668082+00', '', 'Roulette', 'ROULL', '');
INSERT INTO 'formation' VALUES (152, NULL, '2012-01-20 12:55:59.67009+00', '', 'Celtic Reel', 'REEL;CELTIC;', '');
INSERT INTO 'formation' VALUES (153, NULL, '2012-01-20 12:55:59.672093+00', '', 'Ecossais', 'ECOSSE', '');
INSERT INTO 'formation' VALUES (155, NULL, '2012-01-20 12:55:59.676114+00', '', 'Rosette', 'ROSETTE', '');
INSERT INTO 'formation' VALUES (156, NULL, '2012-01-20 12:55:59.678116+00', 'POUS2-X', 'Poussette - special', 'POUSS;SPEC;', '');
INSERT INTO 'formation' VALUES (177, NULL, '2012-01-20 12:55:59.719694+00', '', 'Corners'' Chain - rotating', 'CCHAIN;ROT;', '');
INSERT INTO 'formation' VALUES (178, NULL, '2012-01-20 12:55:59.721799+00', '', 'Surge', 'SURGE', '');
INSERT INTO 'formation' VALUES (157, NULL, '2012-01-20 12:55:59.680124+00', 'PROM1', 'Promenade single couple(s)', 'PROM;1C;', '');
INSERT INTO 'formation' VALUES (179, NULL, '2012-01-20 12:55:59.72383+00', '', 'Link & Change', 'LINKCH', '');
INSERT INTO 'formation' VALUES (158, NULL, '2012-01-20 12:55:59.682227+00', 'HR', 'Hands round', 'HR', '');
INSERT INTO 'formation' VALUES (180, NULL, '2012-01-20 12:55:59.725839+00', '', 'Hands across - 4 - back - cast', 'HX;4P;BACK;CAST;', '');
INSERT INTO 'formation' VALUES (181, NULL, '2012-01-20 12:55:59.727844+00', '', 'Rights and Lefts - four bars', 'R&L;FOURB;', '');
INSERT INTO 'formation' VALUES (159, NULL, '2012-01-20 12:55:59.684235+00', 'SWIRL', 'Swirl', 'SWIRL', '');
INSERT INTO 'formation' VALUES (183, NULL, '2012-01-20 12:55:59.731877+00', '', 'Hands across - 4 - half', 'HX;4P;HALF;', '');
INSERT INTO 'formation' VALUES (162, NULL, '2012-01-20 12:55:59.688254+00', 'CHAIN', 'Grand Chain', 'GCHAIN', '');
INSERT INTO 'formation' VALUES (163, NULL, '2012-01-20 12:55:59.690398+00', 'HX5-RL', 'Hands across - 5 - and back', 'HX;5P;BACK;', '');
INSERT INTO 'formation' VALUES (164, NULL, '2012-01-20 12:55:59.692425+00', 'R3DIA', 'Reel of three - diagonal', 'REEL;DIAG;R3;', '');
INSERT INTO 'formation' VALUES (188, NULL, '2012-01-20 12:55:59.742291+00', '', 'Reel of three - across - half', 'REEL;ACROSS;HALF;R3;', '');
INSERT INTO 'formation' VALUES (165, NULL, '2012-01-20 12:55:59.694952+00', '', 'Snowball Chain', 'SCHA', '');
INSERT INTO 'formation' VALUES (166, NULL, '2012-01-20 12:55:59.69699+00', '', 'Capstan', 'CPSTN', '');
INSERT INTO 'formation' VALUES (191, NULL, '2012-01-20 12:55:59.748375+00', '', 'Rondel - non progressive', 'RONDEL;NPROG;', '');
INSERT INTO 'formation' VALUES (167, NULL, '2012-01-20 12:55:59.699006+00', '', 'Double Capstan', 'CPSTN;DOUBLE;', '');
INSERT INTO 'formation' VALUES (192, NULL, '2012-01-20 12:55:59.750405+00', 'HR6-B', 'Hands round - 6 - and back', 'HR;6P;BACK;', '');
INSERT INTO 'formation' VALUES (193, NULL, '2012-01-20 12:55:59.752415+00', 'HR8-B', 'Hands round - 8 - and back', 'HR;8P;BACK;', '');
INSERT INTO 'formation' VALUES (168, NULL, '2012-01-20 12:55:59.70112+00', '', 'Rights and Lefts - diagonal - half', 'R&L;DIAG;HALF;', '');
INSERT INTO 'formation' VALUES (194, NULL, '2012-01-20 12:55:59.754434+00', '', 'Peerie', 'PEERIE', '');
INSERT INTO 'formation' VALUES (169, NULL, '2012-01-20 12:55:59.703163+00', '', 'Traversons', 'TRVS', '');
INSERT INTO 'formation' VALUES (195, NULL, '2012-01-20 12:55:59.756441+00', '', 'Revolve', 'RVOLV', '');
INSERT INTO 'formation' VALUES (170, NULL, '2012-01-20 12:55:59.705311+00', '', 'Targe - corners', 'TARGE;CRNRS;', '');
INSERT INTO 'formation' VALUES (171, NULL, '2012-01-20 12:55:59.707405+00', '', 'Rights and Lefts for 4 couples', 'R&L;4C;', '');
INSERT INTO 'formation' VALUES (172, NULL, '2012-01-20 12:55:59.709419+00', '', 'Rondel - half', 'RONDEL;HALF;', '');
INSERT INTO 'formation' VALUES (197, NULL, '2012-01-20 12:55:59.760465+00', '', 'Pass half round', 'PASSHR', '');
INSERT INTO 'formation' VALUES (175, NULL, '2012-01-20 12:55:59.715631+00', 'GCHAIN6H', 'Grand Chain for 6 - half', 'GCHAIN;6P;HALF;', '');
INSERT INTO 'formation' VALUES (198, NULL, '2012-01-20 12:55:59.762485+00', '', 'Engrenage', 'ENGRN', '');
INSERT INTO 'formation' VALUES (176, NULL, '2012-01-20 12:55:59.717679+00', 'GCHAIN8H', 'Grand Chain for 8 - half', 'GCHAIN;8P;HALF;', '');
INSERT INTO 'formation' VALUES (199, NULL, '2012-01-20 12:55:59.764586+00', '', 'Saltire', 'SALTIRE', '');
INSERT INTO 'formation' VALUES (201, NULL, '2012-01-20 12:55:59.768615+00', '', 'Chain and Turn', 'CHTURN', '');
INSERT INTO 'formation' VALUES (202, NULL, '2012-01-20 12:55:59.770644+00', '', 'Reel of four - across - half', 'REEL;ACROSS;HALF;R4;', '');
INSERT INTO 'formation' VALUES (203, NULL, '2012-01-20 12:55:59.772646+00', '', 'Reel of three - diagonal - half', 'REEL;DIAG;HALF;R3;', '');
INSERT INTO 'formation' VALUES (204, NULL, '2012-01-20 12:55:59.774893+00', '', 'Girandole, La', 'GIRAN', '');
INSERT INTO 'formation' VALUES (225, NULL, '2012-01-20 12:55:59.815597+00', '', 'Hands across - 4 - left', 'HX;4P;L;', '');
INSERT INTO 'formation' VALUES (206, NULL, '2012-01-20 12:55:59.77692+00', '', 'Reel of three - hand-in-hand', 'REEL;HANDIN;R3;', '');
INSERT INTO 'formation' VALUES (226, NULL, '2012-01-20 12:55:59.817973+00', '', 'Reel of six - half', 'REEL;HALF;R6;', '');
INSERT INTO 'formation' VALUES (207, NULL, '2012-01-20 12:55:59.779009+00', '', 'Reel of four - hand-in-hand', 'REEL;HANDIN;R4;', '');
INSERT INTO 'formation' VALUES (228, NULL, '2012-01-20 12:55:59.82206+00', 'ALL3C', 'Allemande for 3 couples  - circulating', 'ALLMND;3C;CIRC;', '');
INSERT INTO 'formation' VALUES (229, NULL, '2012-01-20 12:55:59.824152+00', '', 'Reel of four - crossing', 'REEL;CRSING;R4;', '');
INSERT INTO 'formation' VALUES (186, NULL, '2014-05-25 21:49:47.953087+00', 'SET&ROT3', 'Set and Rotate - 3 couples', 'SETROT;3C;', '');
INSERT INTO 'formation' VALUES (230, NULL, '2012-01-20 12:55:59.826226+00', '', 'Hands across - 5', 'HX;5P;', '');
INSERT INTO 'formation' VALUES (209, NULL, '2012-01-20 12:55:59.783032+00', '', 'Ladies'' Chain - double', 'LCHAIN;DOUBLE;', '');
INSERT INTO 'formation' VALUES (231, NULL, '2012-01-20 12:55:59.828234+00', '', 'Rights and Lefts for 3 persons', 'R&L;3P;', '');
INSERT INTO 'formation' VALUES (210, NULL, '2012-01-20 12:55:59.785277+00', '', 'Men''s Chain - double', 'MCHAIN;DOUBLE;', '');
INSERT INTO 'formation' VALUES (232, NULL, '2012-01-20 12:55:59.830254+00', '', 'Madoma Progression', 'MADOMA', '');
INSERT INTO 'formation' VALUES (200, NULL, '2015-02-14 03:08:52.495119+00', '  ', 'Grand Chain for 6 - fig8', 'GCHAIN;6P;FIG8', '');
INSERT INTO 'formation' VALUES (145, NULL, '2016-11-15 10:48:50.900517+00', 'FIG8HD', 'Figure of Eight - double - half', 'FIG8;2C;HALF;', '');
INSERT INTO 'formation' VALUES (182, NULL, '2018-04-26 16:24:36.060457+00', 'HR10', 'Hands round - 10 - (and back?)', 'HR;10P;&BACK?', '');
INSERT INTO 'formation' VALUES (160, NULL, '2017-12-17 02:11:12.33977+00', 'HR5', 'Hands round - 5 - (and back?)', 'HR;5P;', '');
INSERT INTO 'formation' VALUES (372, '2018-04-26 16:12:38.962924+00', '2018-04-26 16:26:18.239877+00', '  ', 'Hands Round - 12 - and back', 'HR; 12P;BACK;', '');
INSERT INTO 'formation' VALUES (212, NULL, '2012-01-20 12:55:59.789313+00', '', 'Neighbours Chain', 'NCHAIN', '');
INSERT INTO 'formation' VALUES (236, NULL, '2012-01-20 12:55:59.838291+00', '', 'Cogwheel', 'COG', '');
INSERT INTO 'formation' VALUES (213, NULL, '2012-01-20 12:55:59.791325+00', '', 'Rose Progression', 'ROSE', '');
INSERT INTO 'formation' VALUES (237, NULL, '2012-01-20 12:55:59.840297+00', '', 'Diddle', 'DIDL', '');
INSERT INTO 'formation' VALUES (129, NULL, '2021-06-12 09:46:19.013743+00', 'SKNOT', 'Slipknot 2C', 'KNOT;2C;NPROG;', 'Devised by Mel Briscoe.');
INSERT INTO 'formation' VALUES (214, NULL, '2012-01-20 12:55:59.793346+00', '', 'Hands round - 6, pivot & chase', 'HR;6P;PIVOT;', '');
INSERT INTO 'formation' VALUES (238, NULL, '2012-01-20 12:55:59.842307+00', '', 'Ladies'' Chain - 3 couples', 'LCHAIN;3C;', '');
INSERT INTO 'formation' VALUES (239, NULL, '2012-01-20 12:55:59.844307+00', '', 'Tournee - 3 couples', 'TOURN;3C;', '');
INSERT INTO 'formation' VALUES (173, NULL, '2022-01-01 00:37:04.319055+00', '  ', 'Reel of four - across from/to sidelines', 'REEL;ACROSS;R4;SIDE;', '');
INSERT INTO 'formation' VALUES (189, NULL, '2022-01-01 00:37:48.225371+00', '  ', 'Reel of three - on side - half', 'REEL;HALF;R3;SIDE;', '');
INSERT INTO 'formation' VALUES (185, NULL, '2022-01-01 00:39:04.910917+00', '  ', 'Reel of four - on side - half', 'REEL;HALF;R4;SIDE;', '');
INSERT INTO 'formation' VALUES (216, NULL, '2012-01-20 12:55:59.797384+00', '', 'Hands round - 8, pivot & chase', 'HR;8P;PIVOT;', '');
INSERT INTO 'formation' VALUES (217, NULL, '2012-01-20 12:55:59.799405+00', 'S&L-4', 'Set and Link for four', 'SETLNK;4P;', '');
INSERT INTO 'formation' VALUES (243, NULL, '2012-01-20 12:55:59.85062+00', '', 'Whirligig', 'WHIRL', '');
INSERT INTO 'formation' VALUES (218, NULL, '2012-01-20 12:55:59.801413+00', 'S&L-5', 'Set and Link for five', 'SETLNK;5P;', '');
INSERT INTO 'formation' VALUES (219, NULL, '2012-01-20 12:55:59.803428+00', 'KNOT1', 'Knot 1 couple', 'KNOT;1C;', '');
INSERT INTO 'formation' VALUES (244, NULL, '2012-01-20 12:55:59.852637+00', '', 'Japonaise', 'JAPAN', '');
INSERT INTO 'formation' VALUES (221, NULL, '2012-01-20 12:55:59.80755+00', '', 'Hands across - 3 - chng-ends', 'HX;3P;CHNG;', '');
INSERT INTO 'formation' VALUES (245, NULL, '2012-01-20 12:55:59.854658+00', '', 'Typhon', 'TYPH', '');
INSERT INTO 'formation' VALUES (222, NULL, '2012-01-20 12:55:59.809562+00', '', 'Hands across - 3 - half', 'HX;3P;HALF;', '');
INSERT INTO 'formation' VALUES (246, NULL, '2012-01-20 12:55:59.856659+00', 'HELIX2', 'Helix 2 couples', 'HELIX;2C;', '');
INSERT INTO 'formation' VALUES (224, NULL, '2012-01-20 12:55:59.813583+00', '', 'Hands across - 4 - right', 'HX;4P;R;', '');
INSERT INTO 'formation' VALUES (247, NULL, '2012-01-20 12:55:59.858676+00', ' ', 'Allepousse for 4 couples', 'ALLPOU;4C', '');
INSERT INTO 'formation' VALUES (248, NULL, '2012-01-20 12:55:59.860683+00', ' ', 'Reel of four - diagonal - double', 'REEL;DIAG;DOUBLE;R4;', '');
INSERT INTO 'formation' VALUES (249, NULL, '2012-01-20 12:55:59.862704+00', ' ', 'Set in line in fours', 'SETLIN;4P;', '');
INSERT INTO 'formation' VALUES (250, NULL, '2012-01-20 12:55:59.864733+00', 'KNOT3C', 'Knot 3 couples - circulating', 'KNOT;3C;CIRC;', '');
INSERT INTO 'formation' VALUES (252, NULL, '2012-01-20 12:55:59.868815+00', ' ', 'Allepousse for 2 couples', 'ALLPOU;2C', '');
INSERT INTO 'formation' VALUES (253, NULL, '2012-01-20 12:55:59.870845+00', ' ', 'Tornado', 'TRNDO', '');
INSERT INTO 'formation' VALUES (254, NULL, '2012-01-20 12:55:59.872852+00', 'RonaldCh', 'Celtic Cross Progression', '12SCDp27', '');
INSERT INTO 'formation' VALUES (255, NULL, '2012-01-20 12:55:59.874863+00', 'C-B&T', 'Balance and Turn Corners', 'B&T;CRNRS;', '');
INSERT INTO 'formation' VALUES (258, NULL, '2012-01-20 12:55:59.880879+00', ' ', 'Link for three', 'Link3', '');
INSERT INTO 'formation' VALUES (259, NULL, '2012-01-20 12:55:59.882894+00', ' ', 'Highland Schottische Balance in Line', 'HS-BiL', '');
INSERT INTO 'formation' VALUES (263, NULL, '2012-01-20 12:55:59.891043+00', ' ', 'Double Triangles - inverting', 'DBLTRI;INV', '');
INSERT INTO 'formation' VALUES (265, '2012-03-28 22:10:27.719307+00', '2012-03-28 22:10:27.719319+00', 'R3PROHLF', 'Reel of three - promenade hold - half', 'REEL;PRMHLD;R3;HALF;', 'Leading couple in promhold with two dancers.  ');
INSERT INTO 'formation' VALUES (278, '2012-10-02 22:32:03.430244+00', '2012-10-02 22:32:03.430254+00', '  ', 'Reel of three - tandem - half (no lead change)', 'REEL;HALF;R3;TANDEM;', '"No Lead Change" has been verified.');
INSERT INTO 'formation' VALUES (90, NULL, '2012-08-18 22:18:30.604119+00', 'REEL8', 'Reel of eight / Schiehallion', 'REEL;R8;', '');
INSERT INTO 'formation' VALUES (220, NULL, '2012-08-18 22:19:33.647324+00', '  ', 'Reel of eight / Schiehallion - half', 'REEL;HALF;R8;', '');
INSERT INTO 'formation' VALUES (269, '2012-09-07 14:16:24.210826+00', '2012-09-07 14:19:42.565192+00', '  ', 'Slip down and up', 'DWNUP;SLIP', 'CREATED120907 EricFerguson');
INSERT INTO 'formation' VALUES (276, '2012-10-02 22:14:45.671222+00', '2012-10-02 22:14:45.671233+00', '  ', 'Reel of four - tandem (no lead change)', 'REEL;R4;TANDEM;', '"No Lead Change" confirmed');
INSERT INTO 'formation' VALUES (373, '2018-04-26 16:13:30.780344+00', '2018-04-26 16:25:39.157047+00', '  ', 'Hands Round - 10 - and back', 'HR; 10P; BACK;', '');
INSERT INTO 'formation' VALUES (279, '2012-10-31 23:19:21.547369+00', '2012-10-31 23:21:57.544607+00', '  ', 'Crown Triangles - half', 'CROWN;HALF', '');
INSERT INTO 'formation' VALUES (74, NULL, '2012-10-26 20:55:01.719563+00', 'R3-GE', 'Reel of three - 16b mirror, crossing (Gates of E)', 'REEL;DOUBLE;GE;R3;', '');
INSERT INTO 'formation' VALUES (282, '2013-01-29 16:52:56.621535+00', '2013-01-29 16:53:51.916767+00', 'HR8-PB', 'Hands round - 8, pivot & back', 'HR;8P;PIVOT;BACK', '');
INSERT INTO 'formation' VALUES (281, '2013-01-13 00:31:37.54427+00', '2013-01-13 00:31:37.544281+00', 'Reel of ', 'Reel of four - diagonal - half - lead change', 'REEL;DIAG;HALF;R4;LEADCHNG;     ', '');
INSERT INTO 'formation' VALUES (283, '2013-03-14 17:55:35.483403+00', '2013-03-14 17:55:35.483407+00', 'CH-PR-CH', 'Chain Progression - Chaperoned', 'CH-PR-CH', '"Chaperoned Chain Progression" as in Linnea Strathspey');
INSERT INTO 'formation' VALUES (286, '2013-03-28 22:39:14.849666+00', '2013-03-28 22:39:14.84967+00', '  ', 'Double Triangles - half', 'DblTri;Half', 'created 2013-03-28 by Eric Ferguson, first use in the Salmonfield Poacher.');
INSERT INTO 'formation' VALUES (287, '2013-04-17 13:02:02.536381+00', '2013-04-17 13:03:09.996435+00', '  ', 'Hands across - 6 - half', 'HX;6P;HALF;', '');
INSERT INTO 'formation' VALUES (288, '2013-05-28 20:16:26.107313+00', '2013-05-28 20:16:26.107317+00', '  ', 'Rondel for Three', 'Rondel3', 'Nonprogressive figure for a 3-dancer set.  Devised by Jane Lataille');
INSERT INTO 'formation' VALUES (374, '2018-04-26 16:26:48.76713+00', '2018-04-26 16:27:40.790516+00', '  ', 'Hands Round - 12', 'HR; 12P;', '');
INSERT INTO 'formation' VALUES (290, '2013-05-28 20:26:47.337313+00', '2013-05-28 20:26:47.337317+00', '  ', 'Linear Rights and Lefts for three', 'Lin3R&L', 'A progressive figure for three dancers in a line; progression (231)');
INSERT INTO 'formation' VALUES (277, '2012-10-02 22:25:43.91064+00', '2014-05-25 21:27:54.733783+00', '  ', 'Reel of three - diagonal - half - tandem (no lead change)', 'REEL;DIAG;HALF;R3;TANDEM;', '"No lead change" has been verified');
INSERT INTO 'formation' VALUES (234, NULL, '2014-09-02 07:34:16.897316+00', 'PET-Q', 'Petronella - quarter (4 bars)', 'PET;QUART;', '');
INSERT INTO 'formation' VALUES (292, '2013-05-28 21:28:58.055683+00', '2013-05-28 21:28:58.055687+00', '   ', 'Single Triangles', 'SiTr3d', 'Progressive figure for three dancers in a triangular set (progression 231 or 312)');
INSERT INTO 'formation' VALUES (293, '2013-05-30 14:48:12.923788+00', '2013-05-30 14:48:12.923792+00', '  ', 'Teacups', 'Tcups', '5 dancers in X pattern.  Centre dancer RHA to the R while other two turn RH ; repeat L ');
INSERT INTO 'formation' VALUES (294, '2013-06-02 22:51:40.630472+00', '2013-06-02 23:02:31.604519+00', '  ', 'Double Triangles with Petronella', 'DTrPetr', 'Centre couple dances DTr while corners petronella one place counterclockwise on {3-4} and {7-8}');
INSERT INTO 'formation' VALUES (297, '2013-07-31 14:04:40.909053+00', '2013-07-31 14:29:13.13484+00', ' ', 'Allemande - Interlocking (all forms)', 'ALLMND;INTLOCK', 'This groups all Allemande formations where the paths of couples interlock. We can later split this collection into the many individual formations.');
INSERT INTO 'formation' VALUES (268, '2012-09-06 17:06:03.779635+00', '2015-02-14 01:24:09.803064+00', '  ', 'Lead/Dance down and up, cross and cast', 'DWNUP;cross;CAST', 'Added 120906');
INSERT INTO 'formation' VALUES (375, '2018-04-26 21:53:25.034616+00', '2018-04-26 21:53:25.034616+00', '  ', 'Hands round - 5 - and back', 'HR; 5P; BACK;', '');
INSERT INTO 'formation' VALUES (376, '2018-04-26 21:56:51.999511+00', '2018-04-26 21:56:51.999511+00', '  ', 'Hands Round - 5', 'HR; 5P;', '');
INSERT INTO 'formation' VALUES (378, '2018-04-29 05:56:33.207425+00', '2018-04-29 05:56:33.207425+00', '  ', 'Hands Round - 10 - half', 'HR; 10P; HALF;', '');
INSERT INTO 'formation' VALUES (215, NULL, '2018-04-29 06:09:34.387112+00', '  ', 'Hands round - 6, pivot & back', 'HR;6P;PIVOT; BACK;', '');
INSERT INTO 'formation' VALUES (379, '2018-04-29 06:11:35.725245+00', '2018-04-29 06:11:35.725245+00', '  ', 'Hands Round - 10 - pivot & chase', 'HR; 10P; PIVOT;', '');
INSERT INTO 'formation' VALUES (154, NULL, '2013-08-04 11:52:43.058592+00', '  ', 'Half-turn and cast away', 'HTCAST', 'Also called "half turn and twirl"');
INSERT INTO 'formation' VALUES (298, '2013-08-07 15:59:06.31014+00', '2013-08-07 15:59:06.31014+00', 'POUS2-N', 'Poussette - no hands', 'POUSS;NOHAND;', '');
INSERT INTO 'formation' VALUES (299, '2013-08-26 10:44:54.730914+00', '2013-08-26 10:44:54.730914+00', '  ', 'Pass, face and cast away', 'Pass;Face;Cast', 'A no-hands variant of "half turn and cast away"');
INSERT INTO 'formation' VALUES (301, '2013-09-10 08:20:08.376365+00', '2013-09-10 08:20:08.376365+00', ' ', 'Slip Back to Back ', 'SLIP;BtB', 'newly added 13-09-10. Formation for two couples.  ');
INSERT INTO 'formation' VALUES (147, NULL, '2013-09-22 12:32:04.620389+00', 'HX-8', 'Hands across - 8 ', 'HX;8;', 'This is HA for 8 dancers together, not the "big Star" of 4 couples in Hands Across');
INSERT INTO 'formation' VALUES (273, '2012-10-02 22:06:13.52538+00', '2022-01-01 00:33:10.652827+00', '  ', 'Reel of three - tandem (no lead change)', 'REEL;R3;TANDEM; ', '"No lead change" has been verified.');
INSERT INTO 'formation' VALUES (280, '2012-11-02 12:22:53.501609+00', '2022-01-01 00:16:04.588865+00', '  ', 'Reel of three - across - lead change', 'REEL;ACROSS;R3;LEADCHANGE;', '');
INSERT INTO 'formation' VALUES (260, NULL, '2022-01-01 00:20:06.31731+00', ' ', 'Reel of three - lead change', 'REEL;R3;LEADCHANGE;', '');
INSERT INTO 'formation' VALUES (285, '2013-03-27 22:01:10.778101+00', '2022-01-01 00:18:33.308336+00', '  ', 'Reel of three - diagonal - lead change', 'REEL;DIAG;R3;LEADCHANGE;', 'Added on 2013-03-27 for "Flight of the Falcon", as ths formation was missing.  Eric');
INSERT INTO 'formation' VALUES (141, NULL, '2022-01-01 00:24:05.714588+00', 'R3TNDM', 'Reel of three - tandem (no lead change? - needs check)', 'REEL;R3;TANDEM;?LEADCHANGE??;', '');
INSERT INTO 'formation' VALUES (296, '2013-07-27 15:36:20.181483+00', '2022-01-01 00:26:36.932839+00', '  ', 'Reel of four - intersecting', 'REEL;R4;INTSECT', 'In a square set, the reels of 4 intersect; either with no hands or 1/2 LHA in the middle');
INSERT INTO 'formation' VALUES (284, '2013-03-25 00:04:57.679009+00', '2022-01-01 00:30:59.384285+00', '  ', 'Reel of four - diagonal - lead change', 'REEL;R4;DIAG;LEADCHANGE;', '');
INSERT INTO 'formation' VALUES (261, NULL, '2022-01-01 00:33:59.444483+00', ' ', 'Reel of three - lead change - half', 'REEL;HALF;R3;LEADCHANGE;', '');
INSERT INTO 'formation' VALUES (241, NULL, '2022-08-18 08:58:16.12234+00', '  ', 'Bourrel - 3 couple', 'BIRL;3C;', 'For a discussion on the name see <<https://www.strathspey.org/lists/strathspey%40strathspey.org/t/3047/>>.');
INSERT INTO 'formation' VALUES (305, '2013-09-22 23:41:04.803028+00', '2013-09-22 23:44:22.908481+00', '  ', 'Reel of eight / Schiehallion - 3/4', 'REEL;3/4;R8', 'added 130923 Eric');
INSERT INTO 'formation' VALUES (306, '2013-10-05 22:39:50.74982+00', '2014-05-25 21:45:43.273611+00', '  ', 'Hands round (big circle RR)', 'HR;RR', 'Added 131005 by Eric');
INSERT INTO 'formation' VALUES (295, '2013-07-27 15:33:34.70166+00', '2014-05-25 21:47:14.543878+00', '  ', 'Double Targe', 'DBLTARGE', 'Targe for all couples in a 4C square set');
INSERT INTO 'formation' VALUES (310, '2013-10-23 10:44:56.353681+00', '2013-10-23 10:44:56.353681+00', '  ', 'Promenade - half', 'PROM;HALF', 'Added 131022. This is rare (Langholm Fair was the first); therefore no distinction yet into number of couples.');
INSERT INTO 'formation' VALUES (312, '2013-10-24 11:56:23.138978+00', '2013-10-24 11:56:23.138978+00', '  ', 'Hands round - 3 - half', 'HR;3C;HALF', 'Added 131025, for Kinmont Willie. Astonishingly this figure was not yet in our list.');
INSERT INTO 'formation' VALUES (314, '2013-10-26 15:14:40.385522+00', '2013-10-26 15:14:40.385522+00', '  ', 'Set as in Double.Triangles', 'SET_DT', 'Added 131026.  If "Balance in Line" deserves to be a figure, so does this, which in many dances occurs as a 2-bar figure separate from a full "Double Triangles".');
INSERT INTO 'formation' VALUES (315, '2013-10-29 01:11:19.769363+00', '2013-10-29 01:11:19.769363+00', 'R&LINT', 'Rights and Lefts - Interlocking', 'R&L;INTRLK', '');
INSERT INTO 'formation' VALUES (317, '2013-11-15 17:55:05.954884+00', '2013-11-15 20:55:50.749022+00', 'HR6', 'Hands round - 6 - L or R', 'HR;6P', 'This is "circle one way only" (normally 4 bars) ');
INSERT INTO 'formation' VALUES (322, '2014-04-03 00:29:53.734692+00', '2014-04-03 00:29:53.734692+00', 'Pinwheel', 'PinWheel', 'PIN', '');
INSERT INTO 'formation' VALUES (308, '2013-10-14 10:00:41.065517+00', '2013-11-26 18:31:42.173587+00', '  ', 'Cast behind own lines and lead up the middle', 'CBL&LeadUp', 'New formation added 131013, as idea for the new formation list. Not yet used in earlier formation listings');
INSERT INTO 'formation' VALUES (257, NULL, '2014-01-11 19:53:25.845443+00', 'HREELP', 'Half-Reel Progression', 'HREELP', '8 bars.  1c+2c turn 3/4 - half reel of 4 on midline - all turn RH 3/4.');
INSERT INTO 'formation' VALUES (321, '2014-03-16 15:53:08.648232+00', '2014-03-16 15:53:08.648232+00', 'xx', 'Set and Link (special)', 'S&Link', 'For all variants on S&Link, such as mirrored, or unusual starts or finishes. ');
INSERT INTO 'formation' VALUES (325, '2014-04-03 14:22:41.615771+00', '2014-04-03 14:22:41.615771+00', 'none ', 'Maurice Progression', 'MAU', '

1M 2W B-to-B _while_ 1W 2M cast CW & follow partner who is retiring.

1C+2C Half Poussette

');
INSERT INTO 'formation' VALUES (328, '2014-05-05 15:35:45.814829+00', '2014-05-05 15:35:45.814829+00', 'PROM1', 'Promenade single couple(s) in Allemande hold', 'PROM;1C;A', 'One or more couples promenade within or around the set, using allemande hold.');
INSERT INTO 'formation' VALUES (327, '2014-05-05 14:56:12.205943+00', '2014-05-05 14:56:45.735623+00', 'ALL1C', 'Allemande for 1 couple', 'ALLMND;1C', 'This is a normal 8-bar allemande, danced by just one couple only.');
INSERT INTO 'formation' VALUES (381, '2019-05-27 03:58:28.882757+00', '2019-05-27 03:58:47.806957+00', '--', 'Muirland Willie Formation', 'MuWi', 'The figure of bars 1-4 of "Muirland Willie", or closely related figures.');
INSERT INTO 'formation' VALUES (291, '2013-05-28 21:26:18.309449+00', '2014-05-25 21:39:05.993703+00', '  ', 'Poussette for three', 'Pouss3d', 'Progressive formation for three dances in a straight line  (312)');
INSERT INTO 'formation' VALUES (309, '2013-10-18 22:53:13.502164+00', '2014-05-25 21:40:32.176665+00', '  ', 'Hands across - other', 'HA;OTH', 'For all Hands Across not otherwise classified');
INSERT INTO 'formation' VALUES (307, '2013-10-06 20:17:56.773662+00', '2014-05-25 21:40:44.0169+00', '  ', 'Hands round - 3 - and back', 'HR;3P;BACK', 'Added 131006 Eric');
INSERT INTO 'formation' VALUES (330, '2014-06-09 15:32:20.945868+00', '2014-06-09 15:32:20.945868+00', '  ', 'Hands Round - 8 - quarter', 'HR8QTR', '');
INSERT INTO 'formation' VALUES (331, '2014-06-30 14:29:12.340309+00', '2014-07-01 19:33:12.40802+00', '  ', 'Rondel12', 'RONDEL12', 'This is a 12-bar version of the Rondel.  Start with 1c facing 2c nearer hands joined.  1-2 under arch | 3-4 cross and loop ; 5-6 W under M arch | 7-8 cross and loop ; 9-10 1c under 2c arch | 11-12 all cast with loop to new places] (2,1).  First used by Ray Dugan in the Longwood Collection (2014).');
INSERT INTO 'formation' VALUES (333, '2014-08-28 13:48:44.274121+00', '2014-08-28 13:54:12.63969+00', '  ', 'Slip (down or up)', 'ONEWAY;SLIP', '');
INSERT INTO 'formation' VALUES (190, NULL, '2014-09-02 11:46:03.888399+00', '  ', 'Petronella - triple ', 'PET;3C;', 'Triple petronella is like petronella in tandem, but for 3 dancers in a row moving to 3 in line at right angles on the right');
INSERT INTO 'formation' VALUES (332, '2014-08-20 12:59:08.661846+00', '2015-02-14 01:08:55.679728+00', '  ', 'Lead/Dance down, cross and cast up', 'DWN;CROSS;UP', '');
INSERT INTO 'formation' VALUES (318, '2013-11-26 18:33:18.08536+00', '2015-02-14 01:09:35.35688+00', '  ', 'Lead/Dance down and cast up', 'DWN;CBL', 'Added 131126. Eric');
INSERT INTO 'formation' VALUES (326, '2014-04-21 22:17:10.31523+00', '2016-11-15 10:46:40.044463+00', '  ', 'Reel of three - diagonal - half - promenade hold', 'REEL;DIAG;HALF;R3;Promhold;', 'Half Reel of three with one couple in promenade hold');
INSERT INTO 'formation' VALUES (303, '2013-09-20 22:50:56.77498+00', '2015-02-14 01:12:18.343477+00', '  ', 'Cast behind own lines and dance up the middle', 'CBL&DanceUp', 'New formation added 130920, as idea for the new formation list. Not yet used in earlier formation listings');
INSERT INTO 'formation' VALUES (302, '2013-09-15 20:27:09.805836+00', '2016-02-14 18:11:36.571608+00', '  ', 'Allemande Turn (to R or L)', 'ALL_RL', 'One-couple 4-bar figure: set advancing and join LH or RH, then W turns under own arm to face away from partner, M dances backwards and W forwards to place.  Known from 19th century dances.  Re-introduced into SCD by Derek Haynes.');
INSERT INTO 'formation' VALUES (35, NULL, '2016-11-15 10:56:21.408615+00', 'HR6old', 'Hands round - 6 - (&back?)', 'HR;6P;&BACK?', 'This name "Hands round - 6" has historically been used to mean both "Hands round - 6 (one way) and "Hands round - 6 and back".  I have started disambiguating these.  This is the temporary name given to the old entries.  Eric Ferguson');
INSERT INTO 'formation' VALUES (235, NULL, '2017-04-24 13:32:14.553584+00', ' ', 'Corners Pass, half-turn and cast away', 'CPassHTurn&Twirl', '{4 bars} Dancing couple and corners pass Rsh, the corners turn 1/2 RH or BH and face, and cast R to the opposite corner position, passing Rsh with the dancing couple who dance back in.');
INSERT INTO 'formation' VALUES (329, '2014-06-07 21:23:12.265873+00', '2017-10-09 19:59:06.957053+00', '  ', 'Spiral figures (various)', 'SPIR_VARIOUS', 'Various spiral movements; not the RSCDS formation "The Spiral".');
INSERT INTO 'formation' VALUES (240, NULL, '2021-02-21 20:03:55.839797+00', '  ', 'Weasel Reel', 'REEL;WEASL;', 'Name changed from"weasle". Three dances have these reels, two spell "weasel", the third does not give it name.   The word "Weasle" exists, does not refer to the animal, but has other connotations, see the Urban Dictionary.  Eric, 2014-01-21. 



According to the instructions for <<ddd:Isolated Weasel, The#20050>> the Weasel Reel was

*was created by Barry Skelton on July 1st, 1990.*');
INSERT INTO 'formation' VALUES (334, '2014-10-26 14:13:16.574259+00', '2014-10-26 14:13:16.574259+00', '  ', 'Interrupted Set to Corners and Partner', 'C-INTSCP', 'Two typical dances:

Hanna''s Pride        32J 3C        Dunsmuir Dances Book   (the Quarries) 

Chris Ronald''s Strathspey  32 Bar Strathspey for 3C/4L set  (Ron Wallace, San Andreas Collection, #9)



The original description in the Dunsmuir Book reads:



25-32  1st couple dance interrupted set to corners and partner (hello-goodbye): 1st couple set to 1st comers and partner then tum with right hands to face 2nd comers. 1st couple set to 2nd comers and partner then tum with right hands to finish in second place. 



In strathspey@strathspey.org:66273 we read the details:



1C move to the sideline on the left foot but instead of facing partner have

right shoulder facing partner, then the right hand turn is a three quarter

turn to face second corner; similarly, set to second corner on the right

foot, move on the left foot to between 2C or 3C but again don''t face

partner but have right shoulder facing ready for an easy three quarter

right hand turn to second place on own side.













');
INSERT INTO 'formation' VALUES (316, '2013-11-12 08:35:41.929048+00', '2022-01-01 00:29:51.462773+00', '  ', 'Reel of three - diagonal - tandem (no lead change)', 'REEL;R3;DIAG;TANDEM', '');
INSERT INTO 'formation' VALUES (324, '2014-04-03 14:08:34.695282+00', '2022-07-10 09:26:30.479151+00', '  ', 'Reel of four - special', 'REEL;R4;SPECIAL;', '');
INSERT INTO 'formation' VALUES (335, '2015-01-16 12:28:41.127+00', '2015-01-16 12:28:41.127+00', '    ', 'Kiwi Knot', 'KNOT;2C;KIWI;', '');
INSERT INTO 'formation' VALUES (337, '2015-01-26 11:57:03.582441+00', '2015-01-26 11:57:03.582441+00', '  ', 'Corners Pass and Back to Back', 'CP&BtB', 'Similar to "corners Pass and Turn", with Turn” replaced by “Dance BtB”');
INSERT INTO 'formation' VALUES (338, '2015-01-30 21:54:24.826366+00', '2015-01-30 21:54:24.826366+00', '  ', 'Stamp', 'STAMP', 'Stamp with one or more feet');
INSERT INTO 'formation' VALUES (340, '2015-02-13 16:32:27.927165+00', '2015-02-13 16:32:27.927165+00', '    ', 'Reel of eight / Schiehallion - 1/4', 'REEL;1/4;R8', '');
INSERT INTO 'formation' VALUES (251, NULL, '2015-02-14 01:11:02.912665+00', 'DMU', 'Dance down and up', 'DWNUP', '');
INSERT INTO 'formation' VALUES (148, NULL, '2015-02-14 01:24:51.156292+00', 'DMULC', 'Lead/Dance down and up, then cast', 'DWNUP;CAST', '');
INSERT INTO 'formation' VALUES (361, '2015-09-20 16:44:05.118458+00', '2015-09-20 16:44:05.118458+00', '   ', 'Reel of ten / Schiehallion', 'REEL;R10;', '');
INSERT INTO 'formation' VALUES (341, '2015-02-14 13:30:12.165378+00', '2015-02-14 13:31:03.726604+00', '   ', 'Set in line in fives', 'SETLIN;5P;', '');
INSERT INTO 'formation' VALUES (380, '2018-07-16 23:53:39.689594+00', '2018-07-16 23:53:39.689594+00', 'HG-POUSS', 'Hello-Goodbye Poussette', 'HG-POUSS;', 'Hello Goodbye Poussette (description by Rod Downey):



This begins in a diagonal line between first man''s place and second lady’s place with 1W and 2M back to back; 1C and 2C holding partners with both hands in order 1M 1W 2M 2W. The retain hands until the end of bar 6. All begin on the right foot.



1-2 All set R, and move left on the left jete'' to finish in a line across the set, with the 1M and 2W back to back. (This rotates the line 1/8 anticlockwise.)

3-4 Repeat a further 1/8, so that we are now on the second diagonal.



5-6 Repeat, so that now all are in a line up and down the set, (from the top), 2M, 2W, 1M, 1W. Drop hands.



7-8 All petronella to own sides in progressed places.



');
INSERT INTO 'formation' VALUES (362, '2015-09-21 11:00:54.752514+00', '2015-09-21 11:00:54.752514+00', ' ', 'Celtic Reel - half', 'REEL;CELTIC;HALF', '');
INSERT INTO 'formation' VALUES (289, '2013-05-28 20:18:59.098872+00', '2015-04-05 09:52:52.834088+00', '  ', 'Rights and Lefts - Triangular', 'TriR&L', 'A progressive figure for 3 dancers in a triangular set (progression 312)');
INSERT INTO 'formation' VALUES (344, '2015-05-01 09:15:49.681085+00', '2015-05-01 09:24:31.927084+00', 'ALL3C', 'Allemande Spray', 'ALLMND;3C;SPRAY', 'Formation devised by Tom Kerr');
INSERT INTO 'formation' VALUES (345, '2015-05-01 09:17:17.387338+00', '2015-05-01 09:25:21.906465+00', 'ALL2C', 'Crossing Allemandes', 'ALLMND;2C;CROSS', 'Formation devised by Tom Kerr');
INSERT INTO 'formation' VALUES (349, '2015-05-01 09:27:17.222802+00', '2015-05-01 09:27:17.222802+00', '   ', 'LaCross', 'LACROSS;', 'Formation devised by Tom Kerr');
INSERT INTO 'formation' VALUES (350, '2015-05-01 09:28:56.138651+00', '2015-05-01 09:28:56.138651+00', '   ', 'The Roundabout', 'RNDABOUT;', 'Formation devised by Tom Kerr');
INSERT INTO 'formation' VALUES (352, '2015-05-01 09:38:06.126338+00', '2015-05-01 09:38:06.126338+00', '   ', 'Untie the Knot 3 couples', 'KNOT;3C;UNTIE;', 'Formation devised by Tom Kerr');
INSERT INTO 'formation' VALUES (351, '2015-05-01 09:37:11.010534+00', '2015-05-01 09:38:55.470912+00', '   ', 'Untie the Knot 2 couples', 'KNOT;2C;UNTIE;', 'Formation devised by Tom Kerr');
INSERT INTO 'formation' VALUES (353, '2015-05-01 13:47:33.678462+00', '2015-05-01 13:48:17.127309+00', 'REEL6', 'Reel of six / Schiehallion', 'REEL;R6;', '');
INSERT INTO 'formation' VALUES (354, '2015-05-01 14:39:38.969196+00', '2015-05-01 14:40:25.493677+00', 'CHASE', 'Chase special', 'CHASE;SPECIAL;', '');
INSERT INTO 'formation' VALUES (355, '2015-05-06 11:51:36.231703+00', '2015-05-06 11:51:59.240004+00', '   ', 'Turn Partner and Corners', 'PCPC', '');
INSERT INTO 'formation' VALUES (256, NULL, '2015-05-06 21:18:28.199488+00', 'KNOT4C', 'Knot 4 couples - circular', 'KNOT;4C;CIRC;', 'The Circular Knot Formation is described as follows in the square set dance "The Blue Lights of Pizza Express":



1-2: Turn partner 1 1/4 with the right hand into promenade hold, facing anticlockwise around the set, men nearest the center;



2-4: Progress one place (1/4 way) round the set anticlockwise;



5-8: Turn 1 1/4 with the left hand, as in the knot, to finish man facing out, lady facing in.



Possibly the facing at the end might differ in other dances if the formation will be adopted by other devisors.');
INSERT INTO 'formation' VALUES (356, '2015-06-29 12:21:23.272806+00', '2015-06-29 12:21:23.272806+00', '  ', 'Grand Chain - special', 'GCHAIN-SP', 'A group name for all variants of Grand Chain that have no name of their own');
INSERT INTO 'formation' VALUES (358, '2015-08-26 15:42:11.033855+00', '2015-08-26 15:42:11.033855+00', 'KNOT2C', 'Knot 2 couples - circular', 'KNOT;2C;CIRC;', '');
INSERT INTO 'formation' VALUES (359, '2015-08-29 12:50:37.880135+00', '2015-08-29 12:50:37.880135+00', '   ', 'Double Triangles - 6bars', 'DBLTRI;6BARS', '');
INSERT INTO 'formation' VALUES (360, '2015-09-03 11:47:17.300823+00', '2015-09-03 11:47:51.151828+00', '   ', 'Rights and Lefts for 5 Persons', 'R&L;5P;', '');
INSERT INTO 'formation' VALUES (82, NULL, '2016-09-25 16:52:10.104681+00', 'R3SID', 'Reel of three - on side', 'REEL;R3;SIDES;', '');
INSERT INTO 'formation' VALUES (41, NULL, '2016-10-02 12:41:35.429209+00', 'HX-4C', 'Hands across - 4 couples in star (full or half)', 'HX;4C;', 'This needs to be split into "full" and "half", when time permits');
INSERT INTO 'formation' VALUES (364, '2017-01-22 00:24:39.971385+00', '2017-01-22 00:24:39.971385+00', '  ', 'Slipknot 3C', '(KNOT;3C;OthPROG;', 'Includes all variants of a 3C knot where the couples do not finish in inverted order.');
INSERT INTO 'formation' VALUES (365, '2017-02-13 13:57:11.9844+00', '2017-02-13 13:57:46.879075+00', '	HR;6P', 'Hands round - 6', 'HR;6P', 'Was missing; added 13 feb 2017.  Eric');
INSERT INTO 'formation' VALUES (366, '2017-08-23 11:15:44.092091+00', '2017-08-23 11:15:44.092091+00', 'CP&AR', 'Corners Pass and Advance and Retire', 'CP&AR', '');
INSERT INTO 'formation' VALUES (363, '2017-01-14 14:20:04.635658+00', '2017-10-09 19:56:40.778519+00', '--', 'Spiral (RSCDS), The ', 'SPIR_PGS', 'Manual 2013 section 6.31 (p. 163)



1c and 2c change places in 8 bars.  Formation as published in "Sailor Hector".



1 – 4   1st man and 2nd woman turn with the right hand three quarters and, giving left hand to other''s partner, all balance in line.  On the second setting step, 1st woman and 2nd man pull back left shoulder to face clockwise and join nearer hands with the same dancer as before.



5 – 8   1st and 2nd couples, in a diagonal line, dance round one place.  2nd man and 1st woman release hands while 1st man and 2nd woman continue turning with the right hand to finish on own sides, opposite partners, in progressed places.  ');
INSERT INTO 'formation' VALUES (368, '2017-10-10 15:12:30.430184+00', '2017-10-10 15:12:30.430184+00', '  ', 'Advance and Retire in Setting Step', 'ADVRET;SSTEP;', '');
INSERT INTO 'formation' VALUES (367, '2017-09-19 16:36:43.727113+00', '2017-09-19 16:38:12.552078+00', '    ', 'Allemande, 2C non-progressive', 'ALLMND, 2C NON-PROG', '');
INSERT INTO 'formation' VALUES (346, '2015-05-01 09:20:08.07668+00', '2020-01-11 22:59:54.70431+00', '   ', 'The Switch (Full, Left Hand, Right Hand)', 'SWITCH;FULL&LH&RH', 'Formations devised by Tom Kerr');
INSERT INTO 'formation' VALUES (370, '2017-11-02 02:26:25.835037+00', '2017-11-02 03:06:06.698667+00', ' ', 'Pushme-Pullyou Reel', 'REEL;PUSHPULL;', 'Description from the dance "Back to Back":



First couple dances a figure of eight on the side of the dance, around their own corner positions, starting with right shoulder to first corner  

while second and third men, and likewise second and third women, dance consecutive back to backs on the side of the dance. Second and third couples begin by passing right shoulders on bars 17-18 and left shoulders on bars 21-22. 



Note: besides the above way the Formation may be danced in a "mirrored" way (as in the dance "Still Together") with the dancing couple starting down and out and the corner couples dancing Back to Back accordingly.');
INSERT INTO 'formation' VALUES (336, '2015-01-22 12:14:02.752579+00', '2019-04-18 17:30:03.334652+00', '   ', 'Grand Chain - progressive (with turns)', 'CHAIN;HORSESHOE;', 'This formation was originally called Horseshoe Chain which occurs in the dance <ddd:Shin Kai Tei>>.



However in response to <<http://my.strathspey.org/dd/issue/1584/|issue 1584>> it was realised the same figure occurs in several other dances with a variety of names, the most common being progressive grand chain. So the name has now been changed to "Grand Chain - progressive (with turns)" and has been added as a formation used in those dances.');
INSERT INTO 'formation' VALUES (382, '2019-12-07 17:39:59.981755+00', '2019-12-07 17:39:59.981755+00', ' ', 'Reel of eight', 'REEL;R8;', '');
INSERT INTO 'formation' VALUES (211, NULL, '2019-12-14 15:17:58.44936+00', 'KEPP', 'Keppoch', 'KEPP', 'SCDDB previously had this formation spelled as Keppock, but Keppoch is used consistently in the videos of dances featuring this formation.');
INSERT INTO 'formation' VALUES (383, '2020-05-23 09:45:39.941273+00', '2020-05-23 09:45:39.941273+00', 'ALL2C', 'Allemande for 2 couples - circulating', 'ALLMND;2C;CIRC;', '');
INSERT INTO 'formation' VALUES (343, '2015-04-05 10:24:11.410834+00', '2022-01-01 00:14:07.320596+00', '  ', 'Reel of four - half - lead change', 'REEL;HALF;R4;LEADCHANGE; ', '');
INSERT INTO 'formation' VALUES (93, NULL, '2020-12-13 12:33:26.96285+00', 'S&LNK', 'Set and Link', 'SETLNK;2P;', 'According to notes at the end of <<ddpub:Bankhead Book Part 2#764>> <<ddp:Drewry, John#108>> writes that Set and Link was invented by <<ddp::Hay, Alec#173>> of Auckland, NZ.');
INSERT INTO 'formation' VALUES (56, NULL, '2020-12-13 12:33:55.271835+00', 'PET-T', 'Petronella - tandem', 'PET;TANDEM;', 'According to notes at the end of <<ddpub:Bankhead Book Part 2#764>> <<ddp:Drewry, John#108>> writes that Petronella in Tandem was first used by <<ddp::Boyd, Iain#173>> of Wellington, NZ and <<ddp:Boehmer, Marie#35>> of Ontario, Canada. However the name was assigned by Drewry.');
INSERT INTO 'formation' VALUES (28, NULL, '2021-02-17 23:25:05.052242+00', 'FIG8D', 'Figure of Eight - double', 'FIG8;2C;', 'According to <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-020-November-1964.pdf|issue 20 of The Thistle>> this formation was first devised by Hugh Foss.');
INSERT INTO 'formation' VALUES (15, NULL, '2021-02-24 10:01:01.186663+00', 'C-P&T', 'Corners Pass and Turn', 'C-P&T', 'According to a note in Copycat Suite - Prelude, Drewry says he first used Corners Pass and Turn in <<ddd:Tommy Ford''s Fancy#6644>> and then in <<ddd:Misses Farrell of Alloa#4602>>.');
INSERT INTO 'formation' VALUES (123, NULL, '2021-05-25 21:13:41.442134+00', 'SNAKE', 'Snake Pass', 'SNAKE', 'Normally a 3 couple figure. However the first versions may have been for 4 and 5 couples in dances <<ddd:Heights of Rechberg, The#13776>> and <<Sisters of Kintail, The#7948>> by <<ddp:Conrad, Adrian#1276>> under the name "Spiral Exchange".');
INSERT INTO 'formation' VALUES (59, NULL, '2021-06-07 10:23:17.455403+00', 'SPOUHS', 'Poussette Highland Schottische', 'POUSS;HS;', 'According to the instructions for <<ddd:Flodigarry Strathspey#2237>> this figure was devised by <<ddp:Johnstone, Jackie#200>> for the dance <<ddd:S. S. Johnstone#5786>>.');
INSERT INTO 'formation' VALUES (313, '2013-10-25 22:54:55.011171+00', '2021-07-04 08:22:57.726417+00', '  ', 'Set to corner and cast away', 'SET;CASTAWAY', 'Formation introduced by Alec Hay in "Peter White", and later used in "Aberdeen Hunt" (Ron Wallace), "John of Montrose" (Babs Hewinson), "Best Set in the Hall" (Helen Greenwood) and "The Jet Set Hornpipe" (Anselm Lingnau).



This figure may also occur elsewhere. Created in 2013 by Eric. This new formation now automatically comes onto the list of those to be named or not at the new revision of formations.



Another instance, there referred to as "Corners Pass and Rotate", is "Ruby Red" (Frances Wallace).');
INSERT INTO 'formation' VALUES (384, '2021-11-08 18:59:48.803064+00', '2021-11-08 18:59:48.803064+00', ' ', 'Figure of Love', 'FIGURE_LOVE', '');
INSERT INTO 'formation' VALUES (272, '2012-10-02 21:56:10.599757+00', '2022-01-01 00:07:21.200473+00', '  ', 'Reel of four - diagonal - half - tandem (no lead change)', 'REEL;DIAG;R4;HALF;TANDEM;', '"No lead change" has been verified.

The tag "HALF" was missing, and has been added by Eric Ferguson on 2022-01-01');
INSERT INTO 'formation' VALUES (267, '2012-08-09 14:14:59.665404+00', '2022-01-01 00:14:49.674653+00', '  ', 'Reel of four - with lead change', 'REEL;R4;LEADCHANGE;', 'One or more pairs of dancers "dance as one", and change the lead at the ends of the reel');
INSERT INTO 'formation' VALUES (262, NULL, '2022-01-01 00:16:30.076891+00', ' ', 'Reel of three - diagonal - half - lead change', 'REEL;DIAG;HALF;R3;LEADCHANGE;', '');
INSERT INTO 'formation' VALUES (300, '2013-08-26 13:55:47.686479+00', '2022-01-01 00:22:14.018926+00', '  ', 'Reel of three - on side - lead change', 'REEL;R3;SIDE;LEADCHANGE;', '');
INSERT INTO 'formation' VALUES (339, '2015-02-12 11:06:23.841626+00', '2022-01-01 00:25:56.673743+00', '  ', 'Axum Reel', 'REEL;AXUM;', 'Figure of 8 bars, in a 4C set.  End position 4x,3x,2x,1x.   Every 2 bars all dance to the next position along the path 1M, 2W, 1W, 3W, 4W, 3M, 4M, 2M, 1M, etc., passing other dancers Lsh each time.');
INSERT INTO 'formation' VALUES (311, '2013-10-23 23:43:47.591902+00', '2022-01-01 00:32:22.945156+00', '  ', 'Reel of three - crossing - R shoulder', 'REEL;R3;RSH;Cross', 'The special reels occuring in"Tulloch Gorm", "Cadgers" and "Willie wi'' his tartan trews".  Added 20131024 Eric Ferguson');
INSERT INTO 'formation' VALUES (85, NULL, '2022-01-01 00:35:50.957819+00', 'R4SID', 'Reel of four - on side', 'REEL;R4;SIDE;', '');
INSERT INTO 'formation' VALUES (184, NULL, '2022-01-01 00:36:24.273764+00', '  ', 'Figure of Eight - on side', 'FIG8;1C;SIDE;', '');
INSERT INTO 'formation' VALUES (385, '2022-03-20 12:07:06.227041+00', '2022-03-20 12:07:06.227041+00', 'ARNDL', 'Arandel', 'ARNDL;3C;', 'For details see <<http://www.rscds-swws.org/news/stories/arandel.htm>>.');
INSERT INTO 'formation' VALUES (386, '2022-04-25 16:52:34.852426+00', '2022-04-29 01:01:42.005743+00', 'BIRL', 'Bourrel - 2 couple', 'BIRL; 2C ', 'For a discussion on the name see <<https://www.strathspey.org/lists/strathspey%40strathspey.org/t/3047/>>.');
INSERT INTO 'formation' VALUES (319, '2013-12-07 21:16:31.077725+00', '2022-04-29 01:03:06.037085+00', ' ', 'Bourrel - 4 couple', 'BIRL;4C;', 'There are very few dances having a Bourrel that involves 4 couples, and their formations differ in details.  So for the time being we use this Formation as a collective name for all Bourrels involving 4 couples. If their number (ever) grows over a certain size, we can still split it.  Heiko has renamed the Formation to "Bourrel - 4 couple" to indicate that it includes not only one type.



For a discussion on the name see <<https://www.strathspey.org/lists/strathspey%40strathspey.org/t/3047/>>.');
INSERT INTO 'formation' VALUES (94, NULL, '2022-06-12 11:15:52.779283+00', 'S&ROT', 'Set and Rotate', 'SETROT;2C;', 'Devised by John Drewry in 1987 (according to <<ddd:The Gilly Flower>> in Book 36).



However the inscription for <<ddd:Brimmond#811>> says that is where Drewry intoduced the figure.');
INSERT INTO 'formation' VALUES (387, '2022-11-01 22:17:54.696661+00', '2022-11-01 22:17:54.696661+00', ' R4PRO', 'Reel of four - promenade hold', 'REEL;R4;PRMHLD', '');
INSERT INTO 'formation' VALUES (233, NULL, '2022-12-13 21:10:36.139902+00', 'ASQ', 'Asquith Turn', 'ASQ', 'For an explanation see https://www.strathspey.org/lists/strathspey%40strathspey.org/t/41863/');
INSERT INTO 'formation' VALUES (388, '2022-12-13 23:10:53.077037+00', '2022-12-13 23:10:53.077037+00', 'C-C&T', 'Corners Chase and Turn', 'C-C&T', 'Formation by <<ddp:Kowalczik , Judith #10759>>');


--
INSERT INTO 'formationmodifier' VALUES (37, '7P', 'seven');
INSERT INTO 'formationmodifier' VALUES (1, 'SET', 'with setting');
INSERT INTO 'formationmodifier' VALUES (2, '2C', 'for 2 couples');
INSERT INTO 'formationmodifier' VALUES (38, 'SPEC', 'special');
INSERT INTO 'formationmodifier' VALUES (3, '3C', 'for 3 couples');
INSERT INTO 'formationmodifier' VALUES (4, '4C', 'for 4 couples');
INSERT INTO 'formationmodifier' VALUES (39, 'CAST', 'cast');
INSERT INTO 'formationmodifier' VALUES (5, 'CRNRS', 'with corners');
INSERT INTO 'formationmodifier' VALUES (6, '1C', 'for 1 couple');
INSERT INTO 'formationmodifier' VALUES (40, '16P', 'sixteen');
INSERT INTO 'formationmodifier' VALUES (7, 'HALF', 'half');
INSERT INTO 'formationmodifier' VALUES (8, '3P', 'three');
INSERT INTO 'formationmodifier' VALUES (41, '8C', 'for eight couples');
INSERT INTO 'formationmodifier' VALUES (9, '4P', 'four');
INSERT INTO 'formationmodifier' VALUES (10, '6P', 'six');
INSERT INTO 'formationmodifier' VALUES (42, 'DIVIDE', 'divided');
INSERT INTO 'formationmodifier' VALUES (11, '8P', 'eight');
INSERT INTO 'formationmodifier' VALUES (12, 'TANDEM', 'in tandem');
INSERT INTO 'formationmodifier' VALUES (43, '5P', 'five');
INSERT INTO 'formationmodifier' VALUES (13, 'HS', 'Highland Schottische');
INSERT INTO 'formationmodifier' VALUES (14, 'RR', 'right round');
INSERT INTO 'formationmodifier' VALUES (44, 'SIDEL', 'from/to sidelines');
INSERT INTO 'formationmodifier' VALUES (15, 'DIAG', 'diagonal');
INSERT INTO 'formationmodifier' VALUES (16, 'DOUBLE', 'double');
INSERT INTO 'formationmodifier' VALUES (45, 'ROT', 'rotating');
INSERT INTO 'formationmodifier' VALUES (17, 'CRSING', 'crossing');
INSERT INTO 'formationmodifier' VALUES (46, '10P', 'ten');
INSERT INTO 'formationmodifier' VALUES (47, '12P', 'twelve');
INSERT INTO 'formationmodifier' VALUES (18, 'DC+', 'dancing couple plus one');
INSERT INTO 'formationmodifier' VALUES (48, 'PV', 'standard');
INSERT INTO 'formationmodifier' VALUES (19, 'PRMHLD', 'in promenade hold');
INSERT INTO 'formationmodifier' VALUES (49, 'FIG8', 'figure-8');
INSERT INTO 'formationmodifier' VALUES (50, 'HANDIN', 'hand-in-hand');
INSERT INTO 'formationmodifier' VALUES (20, 'OWNSID', 'on own sides');
INSERT INTO 'formationmodifier' VALUES (51, 'CHNG', 'change ends');
INSERT INTO 'formationmodifier' VALUES (21, 'ACROSS', 'across the dance');
INSERT INTO 'formationmodifier' VALUES (52, 'L', 'left');
INSERT INTO 'formationmodifier' VALUES (53, 'R', 'right');
INSERT INTO 'formationmodifier' VALUES (22, 'SIDES', 'on the sides');
INSERT INTO 'formationmodifier' VALUES (54, 'R&L', 'right and left');
INSERT INTO 'formationmodifier' VALUES (23, '2P', 'in twos');
INSERT INTO 'formationmodifier' VALUES (55, 'L&R', 'left and right');
INSERT INTO 'formationmodifier' VALUES (56, 'CHAIN', 'chain');
INSERT INTO 'formationmodifier' VALUES (24, '1S', 'one step');
INSERT INTO 'formationmodifier' VALUES (57, 'CIRC', 'circulating');
INSERT INTO 'formationmodifier' VALUES (25, 'FOURB', 'in 4 bars');
INSERT INTO 'formationmodifier' VALUES (58, 'QUART', 'quarter');
INSERT INTO 'formationmodifier' VALUES (59, 'PIVOT', 'pivot');
INSERT INTO 'formationmodifier' VALUES (26, 'COUNTR', 'counter');
INSERT INTO 'formationmodifier' VALUES (60, 'R4', '...of four');
INSERT INTO 'formationmodifier' VALUES (27, 'INTRLK', 'interlocking');
INSERT INTO 'formationmodifier' VALUES (61, 'R3', '...of three');
INSERT INTO 'formationmodifier' VALUES (62, 'R6', '...of six');
INSERT INTO 'formationmodifier' VALUES (28, 'GE', 'gates of Edin.');
INSERT INTO 'formationmodifier' VALUES (63, 'R8', '...of eight');
INSERT INTO 'formationmodifier' VALUES (29, 'CROSS', 'crossing sides');
INSERT INTO 'formationmodifier' VALUES (64, 'R5', '...of five');
INSERT INTO 'formationmodifier' VALUES (30, 'LEAD', 'leading hands');
INSERT INTO 'formationmodifier' VALUES (65, 'CELTIC', 'celtic...');
INSERT INTO 'formationmodifier' VALUES (31, 'NEAR', 'nearer hands');
INSERT INTO 'formationmodifier' VALUES (32, 'BACK', 'and back');
INSERT INTO 'formationmodifier' VALUES (66, 'WEASL', 'weasel...');
INSERT INTO 'formationmodifier' VALUES (33, 'NPROG', 'non-progressive');
INSERT INTO 'formationmodifier' VALUES (34, 'STAR', 'star');
INSERT INTO 'formationmodifier' VALUES (35, '2S', 'two steps');
INSERT INTO 'formationmodifier' VALUES (36, 'PRTNRS', 'with partners');


--
INSERT INTO 'formationroot' VALUES (28, 'KNOT', 'Knot');
INSERT INTO 'formationroot' VALUES (1, 'REEL', 'Reel');
INSERT INTO 'formationroot' VALUES (2, 'ADVRET', 'Advance and Retire');
INSERT INTO 'formationroot' VALUES (29, 'L&R', 'Lefts and rights');
INSERT INTO 'formationroot' VALUES (3, 'ADVTRN', 'Advance and Turn');
INSERT INTO 'formationroot' VALUES (4, 'ALLMND', 'Allemande');
INSERT INTO 'formationroot' VALUES (30, 'LCHAIN', 'Ladies Chain');
INSERT INTO 'formationroot' VALUES (5, 'ARCHES', 'Arches');
INSERT INTO 'formationroot' VALUES (6, 'BKTOBK', 'Back to Back');
INSERT INTO 'formationroot' VALUES (31, 'MCHAIN', 'Mens Chain');
INSERT INTO 'formationroot' VALUES (7, 'BALNCE', 'Balance in line');
INSERT INTO 'formationroot' VALUES (8, 'BARAT', 'Baratte');
INSERT INTO 'formationroot' VALUES (32, 'PET', 'Petronella');
INSERT INTO 'formationroot' VALUES (9, 'BIRL', 'Birl');
INSERT INTO 'formationroot' VALUES (10, 'C-D&S', 'Dance to corners and set');
INSERT INTO 'formationroot' VALUES (33, 'PHILA', 'Philabeg');
INSERT INTO 'formationroot' VALUES (11, 'C-DAN', 'Dance around or with Corners');
INSERT INTO 'formationroot' VALUES (12, 'C-P&T', 'Corners Pass and Turn');
INSERT INTO 'formationroot' VALUES (34, 'POUSS', 'Poussette');
INSERT INTO 'formationroot' VALUES (13, 'S&T', 'Set and Turn');
INSERT INTO 'formationroot' VALUES (14, 'C-SCP', 'Set to Corners and Partner');
INSERT INTO 'formationroot' VALUES (35, 'PROM', 'Promenade');
INSERT INTO 'formationroot' VALUES (15, 'C-SET', 'Set to Corners');
INSERT INTO 'formationroot' VALUES (16, 'CPCP', 'Turn Corner, Partner, Corner, Partner');
INSERT INTO 'formationroot' VALUES (36, 'RETADV', 'Retire and Advance');
INSERT INTO 'formationroot' VALUES (17, 'C-TRN', 'Turn Corners');
INSERT INTO 'formationroot' VALUES (18, 'CH-PR', 'Chain Progression');
INSERT INTO 'formationroot' VALUES (37, 'R&L', 'Rights and Lefts');
INSERT INTO 'formationroot' VALUES (19, 'GCHAIN', 'Grand Chain');
INSERT INTO 'formationroot' VALUES (20, 'CHASE', 'Chase');
INSERT INTO 'formationroot' VALUES (38, 'RONDEL', 'Rondel');
INSERT INTO 'formationroot' VALUES (21, 'CROWN', 'Crown Triangles');
INSERT INTO 'formationroot' VALUES (39, 'SETLNK', 'Set and Link');
INSERT INTO 'formationroot' VALUES (22, 'DBLTRI', 'Double Triangles');
INSERT INTO 'formationroot' VALUES (40, 'SETROT', 'Set and Rotate');
INSERT INTO 'formationroot' VALUES (41, 'SETLIN', 'Set in Line');
INSERT INTO 'formationroot' VALUES (23, 'ESPAN', 'Espagnole');
INSERT INTO 'formationroot' VALUES (42, 'SPURT', 'Spurtle');
INSERT INTO 'formationroot' VALUES (24, 'FIG8', 'Figure of eight');
INSERT INTO 'formationroot' VALUES (43, 'TOURB', 'Tourbillon');
INSERT INTO 'formationroot' VALUES (44, 'TOURN', 'Tournee');
INSERT INTO 'formationroot' VALUES (25, 'HR', 'Hands round');
INSERT INTO 'formationroot' VALUES (45, 'CCHAIN', 'Corners'' Chain');
INSERT INTO 'formationroot' VALUES (26, 'HFRPR', 'Half reel progression');
INSERT INTO 'formationroot' VALUES (46, 'ENROND', 'En Rond');
INSERT INTO 'formationroot' VALUES (47, 'SERP', 'Serpentine');
INSERT INTO 'formationroot' VALUES (27, 'HX', 'Hands across');
INSERT INTO 'formationroot' VALUES (48, 'SPOKE', 'The Spoke');
INSERT INTO 'formationroot' VALUES (49, 'TARGE', 'Targe');
INSERT INTO 'formationroot' VALUES (50, 'DWNUP', 'Lead Down and Up');
INSERT INTO 'formationroot' VALUES (51, 'MILLWH', 'Millwheel');
INSERT INTO 'formationroot' VALUES (52, 'SNAKE', 'Snake Pass');
INSERT INTO 'formationroot' VALUES (53, 'CBL&B', 'Cast behind own lines and back');
INSERT INTO 'formationroot' VALUES (54, 'CLAP', 'Clap');
INSERT INTO 'formationroot' VALUES (55, 'BOURR', 'Bourrel');
INSERT INTO 'formationroot' VALUES (56, 'ROULL', 'Roulette');
INSERT INTO 'formationroot' VALUES (57, 'ECOSSE', 'Ecossais');
INSERT INTO 'formationroot' VALUES (58, 'ROSETT', 'Rosette');
INSERT INTO 'formationroot' VALUES (59, 'SWIRL', 'Swirl');
INSERT INTO 'formationroot' VALUES (60, 'SCHA', 'Snowball Chain');
INSERT INTO 'formationroot' VALUES (61, 'CPSTN', 'Capstan');
INSERT INTO 'formationroot' VALUES (62, 'TRVS', 'Traversons');
INSERT INTO 'formationroot' VALUES (63, 'SURGE', 'Surge');
INSERT INTO 'formationroot' VALUES (64, 'LINKCH', 'Link & Change');
INSERT INTO 'formationroot' VALUES (65, 'PEERIE', 'Peerie');
INSERT INTO 'formationroot' VALUES (66, 'RVOLV', 'Revolve');
INSERT INTO 'formationroot' VALUES (67, 'PASSHR', 'Pass half round');
INSERT INTO 'formationroot' VALUES (68, 'ENGRN', 'Engrenage');
INSERT INTO 'formationroot' VALUES (69, 'SALTIR', 'Saltire');
INSERT INTO 'formationroot' VALUES (70, 'CHTURN', 'Chain and Turn');
INSERT INTO 'formationroot' VALUES (71, 'GIRAN', 'Girandole, La');
INSERT INTO 'formationroot' VALUES (72, 'KEPP', 'Keppock');
INSERT INTO 'formationroot' VALUES (73, 'NCHAIN', 'Neighbours Chain');
INSERT INTO 'formationroot' VALUES (74, 'MADOMA', 'Madoma Progression');
INSERT INTO 'formationroot' VALUES (75, 'ASQ', 'Asquith Turn');
INSERT INTO 'formationroot' VALUES (76, 'CTWIRL', 'Corners Pass and Twirl');
INSERT INTO 'formationroot' VALUES (77, 'COG', 'Cogwheel');
INSERT INTO 'formationroot' VALUES (78, 'DIDL', 'Diddle');
INSERT INTO 'formationroot' VALUES (79, 'HTCAST', 'Half-turn and cast away');
INSERT INTO 'formationroot' VALUES (80, 'WHIRL', 'Whirligig');
INSERT INTO 'formationroot' VALUES (81, 'JAPAN', 'Japonaise');
INSERT INTO 'formationroot' VALUES (82, 'TYPH', 'Typhon');


--
INSERT INTO 'formationstepmap' VALUES (1, 1, 1, 1);
INSERT INTO 'formationstepmap' VALUES (2, NULL, 1, 1);
INSERT INTO 'formationstepmap' VALUES (3, NULL, 1, 2);
INSERT INTO 'formationstepmap' VALUES (4, NULL, 1, 3);
INSERT INTO 'formationstepmap' VALUES (5, NULL, 1, 7);
INSERT INTO 'formationstepmap' VALUES (6, NULL, 1, 8);
INSERT INTO 'formationstepmap' VALUES (7, NULL, 1, 99);
INSERT INTO 'formationstepmap' VALUES (8, NULL, 2, 1);
INSERT INTO 'formationstepmap' VALUES (9, NULL, 2, 2);
INSERT INTO 'formationstepmap' VALUES (10, NULL, 2, 3);
INSERT INTO 'formationstepmap' VALUES (11, NULL, 2, 7);
INSERT INTO 'formationstepmap' VALUES (12, NULL, 2, 99);
INSERT INTO 'formationstepmap' VALUES (13, NULL, 3, 4);
INSERT INTO 'formationstepmap' VALUES (14, NULL, 3, 5);
INSERT INTO 'formationstepmap' VALUES (15, NULL, 3, 6);
INSERT INTO 'formationstepmap' VALUES (16, NULL, 3, 99);
INSERT INTO 'formationstepmap' VALUES (17, NULL, 10, 1);
INSERT INTO 'formationstepmap' VALUES (18, NULL, 10, 2);
INSERT INTO 'formationstepmap' VALUES (19, NULL, 10, 3);
INSERT INTO 'formationstepmap' VALUES (20, 1, 2, 1);
INSERT INTO 'formationstepmap' VALUES (21, 1, 3, 4);
INSERT INTO 'formationstepmap' VALUES (22, 1, 10, 1);
INSERT INTO 'formationstepmap' VALUES (23, 2, 1, 1);
INSERT INTO 'formationstepmap' VALUES (24, 2, 1, 2);
INSERT INTO 'formationstepmap' VALUES (25, 2, 2, 2);
INSERT INTO 'formationstepmap' VALUES (26, 2, 2, 1);
INSERT INTO 'formationstepmap' VALUES (27, 2, 3, 4);
INSERT INTO 'formationstepmap' VALUES (28, 2, 3, 5);
INSERT INTO 'formationstepmap' VALUES (29, 2, 10, 1);
INSERT INTO 'formationstepmap' VALUES (30, 2, 10, 2);
INSERT INTO 'formationstepmap' VALUES (31, 3, 10, 1);
INSERT INTO 'formationstepmap' VALUES (32, 3, 2, 1);
INSERT INTO 'formationstepmap' VALUES (33, 3, 1, 1);
INSERT INTO 'formationstepmap' VALUES (34, 4, 1, 1);
INSERT INTO 'formationstepmap' VALUES (35, 4, 2, 1);
INSERT INTO 'formationstepmap' VALUES (36, 4, 10, 1);
INSERT INTO 'formationstepmap' VALUES (37, 4, 3, 4);
INSERT INTO 'formationstepmap' VALUES (38, 5, 3, 4);
INSERT INTO 'formationstepmap' VALUES (39, 5, 1, 1);
INSERT INTO 'formationstepmap' VALUES (40, 5, 2, 1);
INSERT INTO 'formationstepmap' VALUES (41, 5, 10, 1);
INSERT INTO 'formationstepmap' VALUES (42, 6, 10, 1);
INSERT INTO 'formationstepmap' VALUES (43, 6, 2, 1);
INSERT INTO 'formationstepmap' VALUES (44, 6, 1, 1);
INSERT INTO 'formationstepmap' VALUES (45, 6, 3, 4);
INSERT INTO 'formationstepmap' VALUES (50, 7, 10, 1);
INSERT INTO 'formationstepmap' VALUES (51, 7, 2, 1);
INSERT INTO 'formationstepmap' VALUES (52, 7, 1, 1);
INSERT INTO 'formationstepmap' VALUES (53, 7, 3, 4);
INSERT INTO 'formationstepmap' VALUES (54, 8, 3, 4);
INSERT INTO 'formationstepmap' VALUES (55, 8, 1, 1);
INSERT INTO 'formationstepmap' VALUES (56, 8, 2, 1);
INSERT INTO 'formationstepmap' VALUES (57, 8, 10, 1);
INSERT INTO 'formationstepmap' VALUES (58, 21, 10, 1);
INSERT INTO 'formationstepmap' VALUES (59, 21, 1, 1);
INSERT INTO 'formationstepmap' VALUES (60, 21, 2, 1);
INSERT INTO 'formationstepmap' VALUES (61, 23, 2, 1);
INSERT INTO 'formationstepmap' VALUES (62, 23, 1, 1);
INSERT INTO 'formationstepmap' VALUES (63, 23, 10, 1);
INSERT INTO 'formationstepmap' VALUES (64, 23, 3, 4);
INSERT INTO 'formationstepmap' VALUES (65, 15, 3, 4);
INSERT INTO 'formationstepmap' VALUES (66, 15, 1, 1);
INSERT INTO 'formationstepmap' VALUES (67, 15, 2, 1);
INSERT INTO 'formationstepmap' VALUES (68, 15, 10, 1);
INSERT INTO 'formationstepmap' VALUES (69, 105, 10, 1);
INSERT INTO 'formationstepmap' VALUES (70, 105, 2, 1);
INSERT INTO 'formationstepmap' VALUES (71, 105, 1, 1);
INSERT INTO 'formationstepmap' VALUES (72, 105, 3, 4);
INSERT INTO 'formationstepmap' VALUES (73, 24, 1, 2);
INSERT INTO 'formationstepmap' VALUES (74, 24, 2, 2);
INSERT INTO 'formationstepmap' VALUES (75, NULL, 4, 1);
INSERT INTO 'formationstepmap' VALUES (76, NULL, 4, 2);
INSERT INTO 'formationstepmap' VALUES (77, NULL, 4, 3);
INSERT INTO 'formationstepmap' VALUES (78, NULL, 4, 4);
INSERT INTO 'formationstepmap' VALUES (79, NULL, 4, 5);
INSERT INTO 'formationstepmap' VALUES (80, NULL, 4, 6);
INSERT INTO 'formationstepmap' VALUES (81, NULL, 4, 8);
INSERT INTO 'formationstepmap' VALUES (82, NULL, 4, 99);
INSERT INTO 'formationstepmap' VALUES (83, NULL, 5, 99);
INSERT INTO 'formationstepmap' VALUES (84, NULL, 7, 8);
INSERT INTO 'formationstepmap' VALUES (85, NULL, 7, 99);
INSERT INTO 'formationstepmap' VALUES (86, NULL, 50, 99);
INSERT INTO 'formationstepmap' VALUES (87, NULL, 7, 99);
INSERT INTO 'formationstepmap' VALUES (88, 9, 2, 2);
INSERT INTO 'formationstepmap' VALUES (89, 9, 1, 2);
INSERT INTO 'formationstepmap' VALUES (90, 42, 1, 1);
INSERT INTO 'formationstepmap' VALUES (91, 43, 1, 1);
INSERT INTO 'formationstepmap' VALUES (92, 45, 1, 1);
INSERT INTO 'formationstepmap' VALUES (93, 45, 1, 2);
INSERT INTO 'formationstepmap' VALUES (94, 41, 1, 1);
INSERT INTO 'formationstepmap' VALUES (95, 46, 1, 1);
INSERT INTO 'formationstepmap' VALUES (96, 47, 1, 1);
INSERT INTO 'formationstepmap' VALUES (97, 47, 1, 2);
INSERT INTO 'formationstepmap' VALUES (98, 31, 1, 2);
INSERT INTO 'formationstepmap' VALUES (99, 30, 1, 3);
INSERT INTO 'formationstepmap' VALUES (100, 31, 1, 3);
INSERT INTO 'formationstepmap' VALUES (101, 32, 1, 3);
INSERT INTO 'formationstepmap' VALUES (102, 33, 1, 3);
INSERT INTO 'formationstepmap' VALUES (103, 34, 1, 3);
INSERT INTO 'formationstepmap' VALUES (104, 34, 1, 2);
INSERT INTO 'formationstepmap' VALUES (105, 35, 1, 3);
INSERT INTO 'formationstepmap' VALUES (106, 36, 1, 3);
INSERT INTO 'formationstepmap' VALUES (107, 37, 1, 3);
INSERT INTO 'formationstepmap' VALUES (108, 37, 1, 2);
INSERT INTO 'formationstepmap' VALUES (109, 38, 1, 3);
INSERT INTO 'formationstepmap' VALUES (110, 39, 1, 3);
INSERT INTO 'formationstepmap' VALUES (111, 114, 2, 1);
INSERT INTO 'formationstepmap' VALUES (112, 114, 1, 1);
INSERT INTO 'formationstepmap' VALUES (113, 114, 3, 4);
INSERT INTO 'formationstepmap' VALUES (114, 114, 10, 1);
INSERT INTO 'formationstepmap' VALUES (115, 86, 1, 1);
INSERT INTO 'formationstepmap' VALUES (116, 86, 2, 1);
INSERT INTO 'formationstepmap' VALUES (117, 86, 10, 1);
INSERT INTO 'formationstepmap' VALUES (118, 86, 3, 4);
INSERT INTO 'formationstepmap' VALUES (119, 35, 2, 3);
INSERT INTO 'formationstepmap' VALUES (120, 35, 3, 4);
INSERT INTO 'formationstepmap' VALUES (121, 27, 1, 1);
INSERT INTO 'formationstepmap' VALUES (122, 27, 2, 1);
INSERT INTO 'formationstepmap' VALUES (123, 27, 3, 4);
INSERT INTO 'formationstepmap' VALUES (124, 32, 3, 4);
INSERT INTO 'formationstepmap' VALUES (125, 32, 2, 3);
INSERT INTO 'formationstepmap' VALUES (126, 111, 1, 1);
INSERT INTO 'formationstepmap' VALUES (127, 111, 2, 1);
INSERT INTO 'formationstepmap' VALUES (128, 25, 1, 2);
INSERT INTO 'formationstepmap' VALUES (129, 25, 2, 2);
INSERT INTO 'formationstepmap' VALUES (130, 38, 3, 4);
INSERT INTO 'formationstepmap' VALUES (131, 38, 2, 3);
INSERT INTO 'formationstepmap' VALUES (132, 60, 3, 4);
INSERT INTO 'formationstepmap' VALUES (133, 60, 3, 5);
INSERT INTO 'formationstepmap' VALUES (134, 69, 1, 1);
INSERT INTO 'formationstepmap' VALUES (135, 69, 2, 1);
INSERT INTO 'formationstepmap' VALUES (136, 69, 3, 4);
INSERT INTO 'formationstepmap' VALUES (137, 52, 3, 4);
INSERT INTO 'formationstepmap' VALUES (138, 52, 1, 1);
INSERT INTO 'formationstepmap' VALUES (139, 52, 2, 1);
INSERT INTO 'formationstepmap' VALUES (140, 22, 3, 4);
INSERT INTO 'formationstepmap' VALUES (141, 22, 1, 1);
INSERT INTO 'formationstepmap' VALUES (142, 22, 2, 1);
INSERT INTO 'formationstepmap' VALUES (143, 1, 4, 1);
INSERT INTO 'formationstepmap' VALUES (144, 127, 1, 1);
INSERT INTO 'formationstepmap' VALUES (145, 127, 2, 1);
INSERT INTO 'formationstepmap' VALUES (146, 127, 3, 4);
INSERT INTO 'formationstepmap' VALUES (147, 26, 1, 1);
INSERT INTO 'formationstepmap' VALUES (148, 26, 2, 1);
INSERT INTO 'formationstepmap' VALUES (149, 26, 3, 4);
INSERT INTO 'formationstepmap' VALUES (150, 131, 1, 1);
INSERT INTO 'formationstepmap' VALUES (151, 131, 2, 1);
INSERT INTO 'formationstepmap' VALUES (152, 131, 3, 4);
INSERT INTO 'formationstepmap' VALUES (153, 42, 3, 4);
INSERT INTO 'formationstepmap' VALUES (154, 43, 3, 4);
INSERT INTO 'formationstepmap' VALUES (155, 143, 1, 1);
INSERT INTO 'formationstepmap' VALUES (156, 143, 2, 1);
INSERT INTO 'formationstepmap' VALUES (157, 143, 3, 4);
INSERT INTO 'formationstepmap' VALUES (159, 30, 2, 3);
INSERT INTO 'formationstepmap' VALUES (160, 30, 3, 4);
INSERT INTO 'formationstepmap' VALUES (161, 142, 1, 3);
INSERT INTO 'formationstepmap' VALUES (162, 142, 2, 3);
INSERT INTO 'formationstepmap' VALUES (163, 142, 3, 4);
INSERT INTO 'formationstepmap' VALUES (164, 48, 1, 1);
INSERT INTO 'formationstepmap' VALUES (165, 48, 2, 1);
INSERT INTO 'formationstepmap' VALUES (166, 48, 3, 4);
INSERT INTO 'formationstepmap' VALUES (167, 120, 1, 1);
INSERT INTO 'formationstepmap' VALUES (168, 120, 2, 1);
INSERT INTO 'formationstepmap' VALUES (169, 120, 3, 4);
INSERT INTO 'formationstepmap' VALUES (170, 61, 1, 2);
INSERT INTO 'formationstepmap' VALUES (171, 61, 2, 2);
INSERT INTO 'formationstepmap' VALUES (172, 134, 1, 1);
INSERT INTO 'formationstepmap' VALUES (173, 134, 2, 1);
INSERT INTO 'formationstepmap' VALUES (174, 134, 3, 4);
INSERT INTO 'formationstepmap' VALUES (175, 12, 1, 2);
INSERT INTO 'formationstepmap' VALUES (176, 12, 2, 2);
INSERT INTO 'formationstepmap' VALUES (177, 126, 1, 1);
INSERT INTO 'formationstepmap' VALUES (178, 126, 2, 1);
INSERT INTO 'formationstepmap' VALUES (179, 126, 3, 4);
INSERT INTO 'formationstepmap' VALUES (180, 28, 3, 4);
INSERT INTO 'formationstepmap' VALUES (181, 28, 1, 1);
INSERT INTO 'formationstepmap' VALUES (182, 28, 2, 1);
INSERT INTO 'formationstepmap' VALUES (183, 29, 1, 1);
INSERT INTO 'formationstepmap' VALUES (184, 29, 2, 1);
INSERT INTO 'formationstepmap' VALUES (185, 29, 3, 4);
INSERT INTO 'formationstepmap' VALUES (186, 145, 3, 4);
INSERT INTO 'formationstepmap' VALUES (187, 145, 1, 1);
INSERT INTO 'formationstepmap' VALUES (188, 145, 2, 1);
INSERT INTO 'formationstepmap' VALUES (189, 149, 1, 1);
INSERT INTO 'formationstepmap' VALUES (190, 149, 2, 1);
INSERT INTO 'formationstepmap' VALUES (191, 149, 3, 4);
INSERT INTO 'formationstepmap' VALUES (192, 138, 3, 4);
INSERT INTO 'formationstepmap' VALUES (193, 138, 1, 1);
INSERT INTO 'formationstepmap' VALUES (194, 138, 2, 1);
INSERT INTO 'formationstepmap' VALUES (195, 46, 3, 4);
INSERT INTO 'formationstepmap' VALUES (196, 147, 1, 1);
INSERT INTO 'formationstepmap' VALUES (197, 147, 2, 1);
INSERT INTO 'formationstepmap' VALUES (198, 33, 3, 4);
INSERT INTO 'formationstepmap' VALUES (199, 36, 3, 4);
INSERT INTO 'formationstepmap' VALUES (200, 135, 1, 3);
INSERT INTO 'formationstepmap' VALUES (201, 135, 2, 3);
INSERT INTO 'formationstepmap' VALUES (202, 39, 3, 4);
INSERT INTO 'formationstepmap' VALUES (203, 49, 1, 1);
INSERT INTO 'formationstepmap' VALUES (204, 49, 2, 1);
INSERT INTO 'formationstepmap' VALUES (205, 49, 3, 4);
INSERT INTO 'formationstepmap' VALUES (206, 50, 3, 4);
INSERT INTO 'formationstepmap' VALUES (207, 50, 1, 1);
INSERT INTO 'formationstepmap' VALUES (208, 50, 2, 1);
INSERT INTO 'formationstepmap' VALUES (209, 111, 3, 4);
INSERT INTO 'formationstepmap' VALUES (210, 148, 3, 4);
INSERT INTO 'formationstepmap' VALUES (211, 148, 1, 1);
INSERT INTO 'formationstepmap' VALUES (212, 148, 2, 1);
INSERT INTO 'formationstepmap' VALUES (213, 51, 1, 1);
INSERT INTO 'formationstepmap' VALUES (214, 51, 2, 1);
INSERT INTO 'formationstepmap' VALUES (215, 51, 3, 4);
INSERT INTO 'formationstepmap' VALUES (216, 53, 1, 1);
INSERT INTO 'formationstepmap' VALUES (217, 53, 2, 1);
INSERT INTO 'formationstepmap' VALUES (218, 53, 3, 4);
INSERT INTO 'formationstepmap' VALUES (219, 121, 3, 4);
INSERT INTO 'formationstepmap' VALUES (220, 121, 1, 1);
INSERT INTO 'formationstepmap' VALUES (221, 121, 2, 1);
INSERT INTO 'formationstepmap' VALUES (222, 54, 1, 2);
INSERT INTO 'formationstepmap' VALUES (223, 54, 2, 2);
INSERT INTO 'formationstepmap' VALUES (224, 54, 3, 5);
INSERT INTO 'formationstepmap' VALUES (225, 54, 3, 4);
INSERT INTO 'formationstepmap' VALUES (226, 55, 1, 2);
INSERT INTO 'formationstepmap' VALUES (227, 55, 2, 2);
INSERT INTO 'formationstepmap' VALUES (228, 55, 3, 5);
INSERT INTO 'formationstepmap' VALUES (229, 55, 3, 4);
INSERT INTO 'formationstepmap' VALUES (230, 56, 1, 2);
INSERT INTO 'formationstepmap' VALUES (231, 56, 2, 2);
INSERT INTO 'formationstepmap' VALUES (232, 56, 3, 5);
INSERT INTO 'formationstepmap' VALUES (233, 56, 3, 4);
INSERT INTO 'formationstepmap' VALUES (234, 93, 1, 2);
INSERT INTO 'formationstepmap' VALUES (235, 93, 1, 1);
INSERT INTO 'formationstepmap' VALUES (236, 93, 2, 1);
INSERT INTO 'formationstepmap' VALUES (237, 93, 2, 2);
INSERT INTO 'formationstepmap' VALUES (238, 93, 3, 5);
INSERT INTO 'formationstepmap' VALUES (239, 93, 3, 4);
INSERT INTO 'formationstepmap' VALUES (240, 92, 3, 4);
INSERT INTO 'formationstepmap' VALUES (241, 92, 3, 5);
INSERT INTO 'formationstepmap' VALUES (242, 92, 2, 2);
INSERT INTO 'formationstepmap' VALUES (243, 92, 2, 1);
INSERT INTO 'formationstepmap' VALUES (244, 92, 1, 1);
INSERT INTO 'formationstepmap' VALUES (245, 92, 1, 2);
INSERT INTO 'formationstepmap' VALUES (246, 16, 1, 2);
INSERT INTO 'formationstepmap' VALUES (247, 16, 2, 2);
INSERT INTO 'formationstepmap' VALUES (248, 16, 3, 5);
INSERT INTO 'formationstepmap' VALUES (249, 16, 3, 4);
INSERT INTO 'formationstepmap' VALUES (250, 129, 1, 1);
INSERT INTO 'formationstepmap' VALUES (251, 129, 2, 1);
INSERT INTO 'formationstepmap' VALUES (252, 129, 3, 4);
INSERT INTO 'formationstepmap' VALUES (253, 109, 1, 2);
INSERT INTO 'formationstepmap' VALUES (254, 109, 2, 2);
INSERT INTO 'formationstepmap' VALUES (255, 110, 1, 1);
INSERT INTO 'formationstepmap' VALUES (256, 110, 2, 1);
INSERT INTO 'formationstepmap' VALUES (257, 19, 1, 1);
INSERT INTO 'formationstepmap' VALUES (258, 19, 2, 1);
INSERT INTO 'formationstepmap' VALUES (259, 19, 3, 4);
INSERT INTO 'formationstepmap' VALUES (260, 101, 1, 1);
INSERT INTO 'formationstepmap' VALUES (261, 101, 2, 1);
INSERT INTO 'formationstepmap' VALUES (262, 101, 3, 4);
INSERT INTO 'formationstepmap' VALUES (263, 123, 1, 1);
INSERT INTO 'formationstepmap' VALUES (264, 123, 2, 1);
INSERT INTO 'formationstepmap' VALUES (265, 123, 3, 4);
INSERT INTO 'formationstepmap' VALUES (266, 150, 3, 5);
INSERT INTO 'formationstepmap' VALUES (267, 150, 3, 4);
INSERT INTO 'formationstepmap' VALUES (268, 10, 1, 2);
INSERT INTO 'formationstepmap' VALUES (269, 10, 1, 1);
INSERT INTO 'formationstepmap' VALUES (270, 10, 2, 1);
INSERT INTO 'formationstepmap' VALUES (271, 10, 2, 2);
INSERT INTO 'formationstepmap' VALUES (272, 10, 3, 5);
INSERT INTO 'formationstepmap' VALUES (273, 10, 3, 4);
INSERT INTO 'formationstepmap' VALUES (274, 13, 1, 1);
INSERT INTO 'formationstepmap' VALUES (275, 13, 1, 2);
INSERT INTO 'formationstepmap' VALUES (276, 13, 2, 2);
INSERT INTO 'formationstepmap' VALUES (277, 13, 2, 1);
INSERT INTO 'formationstepmap' VALUES (278, 13, 3, 4);
INSERT INTO 'formationstepmap' VALUES (279, 13, 3, 5);
INSERT INTO 'formationstepmap' VALUES (280, 153, 3, 9);
INSERT INTO 'formationstepmap' VALUES (281, NULL, 3, 9);
INSERT INTO 'formationstepmap' VALUES (282, 154, 1, 1);
INSERT INTO 'formationstepmap' VALUES (283, 154, 2, 1);
INSERT INTO 'formationstepmap' VALUES (284, 154, 3, 4);
INSERT INTO 'formationstepmap' VALUES (285, 141, 1, 1);
INSERT INTO 'formationstepmap' VALUES (286, 141, 2, 1);
INSERT INTO 'formationstepmap' VALUES (287, 141, 3, 4);
INSERT INTO 'formationstepmap' VALUES (288, 77, 3, 4);
INSERT INTO 'formationstepmap' VALUES (289, 77, 1, 1);
INSERT INTO 'formationstepmap' VALUES (290, 77, 2, 1);
INSERT INTO 'formationstepmap' VALUES (291, 155, 1, 1);
INSERT INTO 'formationstepmap' VALUES (292, 155, 1, 2);
INSERT INTO 'formationstepmap' VALUES (293, 155, 2, 2);
INSERT INTO 'formationstepmap' VALUES (294, 155, 2, 1);
INSERT INTO 'formationstepmap' VALUES (295, 155, 3, 5);
INSERT INTO 'formationstepmap' VALUES (296, 155, 3, 4);
INSERT INTO 'formationstepmap' VALUES (297, 82, 1, 1);
INSERT INTO 'formationstepmap' VALUES (298, 82, 2, 1);
INSERT INTO 'formationstepmap' VALUES (299, 82, 3, 4);
INSERT INTO 'formationstepmap' VALUES (300, 102, 1, 1);
INSERT INTO 'formationstepmap' VALUES (301, 102, 1, 2);
INSERT INTO 'formationstepmap' VALUES (302, 102, 2, 2);
INSERT INTO 'formationstepmap' VALUES (303, 102, 2, 1);
INSERT INTO 'formationstepmap' VALUES (304, 102, 3, 5);
INSERT INTO 'formationstepmap' VALUES (305, 102, 3, 4);
INSERT INTO 'formationstepmap' VALUES (306, 119, 1, 1);
INSERT INTO 'formationstepmap' VALUES (307, 119, 2, 1);
INSERT INTO 'formationstepmap' VALUES (308, 119, 3, 4);
INSERT INTO 'formationstepmap' VALUES (309, 36, 2, 3);
INSERT INTO 'formationstepmap' VALUES (310, 94, 1, 2);
INSERT INTO 'formationstepmap' VALUES (311, 94, 1, 1);
INSERT INTO 'formationstepmap' VALUES (312, 94, 2, 1);
INSERT INTO 'formationstepmap' VALUES (313, 94, 2, 2);
INSERT INTO 'formationstepmap' VALUES (314, 85, 3, 4);
INSERT INTO 'formationstepmap' VALUES (315, 71, 3, 4);
INSERT INTO 'formationstepmap' VALUES (316, 157, 1, 1);
INSERT INTO 'formationstepmap' VALUES (317, 157, 2, 1);
INSERT INTO 'formationstepmap' VALUES (318, 157, 3, 4);
INSERT INTO 'formationstepmap' VALUES (319, 163, 2, 1);
INSERT INTO 'formationstepmap' VALUES (320, 163, 1, 1);
INSERT INTO 'formationstepmap' VALUES (321, 163, 3, 4);
INSERT INTO 'formationstepmap' VALUES (322, 164, 1, 1);
INSERT INTO 'formationstepmap' VALUES (323, 164, 2, 1);
INSERT INTO 'formationstepmap' VALUES (324, 164, 3, 4);
INSERT INTO 'formationstepmap' VALUES (325, 165, 1, 1);
INSERT INTO 'formationstepmap' VALUES (326, 165, 2, 1);
INSERT INTO 'formationstepmap' VALUES (327, 165, 3, 4);
INSERT INTO 'formationstepmap' VALUES (328, 166, 1, 1);
INSERT INTO 'formationstepmap' VALUES (329, 166, 2, 1);
INSERT INTO 'formationstepmap' VALUES (330, 166, 3, 4);
INSERT INTO 'formationstepmap' VALUES (331, 167, 1, 1);
INSERT INTO 'formationstepmap' VALUES (332, 167, 2, 1);
INSERT INTO 'formationstepmap' VALUES (333, 167, 3, 4);
INSERT INTO 'formationstepmap' VALUES (334, 168, 1, 1);
INSERT INTO 'formationstepmap' VALUES (335, 168, 2, 1);
INSERT INTO 'formationstepmap' VALUES (336, 168, 3, 4);
INSERT INTO 'formationstepmap' VALUES (337, 169, 3, 4);
INSERT INTO 'formationstepmap' VALUES (338, 170, 3, 5);
INSERT INTO 'formationstepmap' VALUES (339, 170, 3, 4);
INSERT INTO 'formationstepmap' VALUES (340, 25, 3, 5);
INSERT INTO 'formationstepmap' VALUES (341, 25, 3, 4);
INSERT INTO 'formationstepmap' VALUES (342, 171, 1, 1);
INSERT INTO 'formationstepmap' VALUES (343, 171, 2, 1);
INSERT INTO 'formationstepmap' VALUES (344, 171, 3, 4);
INSERT INTO 'formationstepmap' VALUES (345, 172, 1, 1);
INSERT INTO 'formationstepmap' VALUES (348, 178, 3, 4);
INSERT INTO 'formationstepmap' VALUES (349, 179, 3, 5);
INSERT INTO 'formationstepmap' VALUES (350, 179, 3, 4);
INSERT INTO 'formationstepmap' VALUES (351, 180, 1, 1);
INSERT INTO 'formationstepmap' VALUES (352, 180, 2, 1);
INSERT INTO 'formationstepmap' VALUES (353, 180, 3, 4);
INSERT INTO 'formationstepmap' VALUES (354, 181, 1, 1);
INSERT INTO 'formationstepmap' VALUES (355, 181, 2, 1);
INSERT INTO 'formationstepmap' VALUES (356, 181, 3, 4);
INSERT INTO 'formationstepmap' VALUES (357, 125, 1, 1);
INSERT INTO 'formationstepmap' VALUES (358, 125, 2, 1);
INSERT INTO 'formationstepmap' VALUES (359, 125, 3, 4);
INSERT INTO 'formationstepmap' VALUES (360, 182, 1, 3);
INSERT INTO 'formationstepmap' VALUES (361, 182, 2, 3);
INSERT INTO 'formationstepmap' VALUES (362, 182, 3, 4);
INSERT INTO 'formationstepmap' VALUES (363, 112, 1, 1);
INSERT INTO 'formationstepmap' VALUES (364, 112, 2, 1);
INSERT INTO 'formationstepmap' VALUES (365, 112, 3, 4);
INSERT INTO 'formationstepmap' VALUES (366, 87, 1, 1);
INSERT INTO 'formationstepmap' VALUES (367, 87, 2, 1);
INSERT INTO 'formationstepmap' VALUES (368, 87, 3, 4);
INSERT INTO 'formationstepmap' VALUES (369, 85, 1, 1);
INSERT INTO 'formationstepmap' VALUES (370, 85, 2, 1);
INSERT INTO 'formationstepmap' VALUES (371, 185, 1, 1);
INSERT INTO 'formationstepmap' VALUES (372, 185, 2, 1);
INSERT INTO 'formationstepmap' VALUES (373, 185, 3, 4);
INSERT INTO 'formationstepmap' VALUES (377, 158, 2, 3);
INSERT INTO 'formationstepmap' VALUES (378, 46, 2, 1);
INSERT INTO 'formationstepmap' VALUES (379, 158, 1, 3);
INSERT INTO 'formationstepmap' VALUES (380, 158, 3, 4);
INSERT INTO 'formationstepmap' VALUES (381, 191, 3, 4);
INSERT INTO 'formationstepmap' VALUES (382, 103, 3, 4);
INSERT INTO 'formationstepmap' VALUES (383, 45, 3, 5);
INSERT INTO 'formationstepmap' VALUES (384, 45, 3, 4);
INSERT INTO 'formationstepmap' VALUES (385, 192, 1, 3);
INSERT INTO 'formationstepmap' VALUES (386, 192, 2, 3);
INSERT INTO 'formationstepmap' VALUES (387, 192, 3, 4);
INSERT INTO 'formationstepmap' VALUES (388, 81, 1, 1);
INSERT INTO 'formationstepmap' VALUES (389, 81, 2, 1);
INSERT INTO 'formationstepmap' VALUES (390, 81, 3, 4);
INSERT INTO 'formationstepmap' VALUES (391, 17, 3, 5);
INSERT INTO 'formationstepmap' VALUES (392, 17, 1, 2);
INSERT INTO 'formationstepmap' VALUES (393, 17, 2, 2);
INSERT INTO 'formationstepmap' VALUES (394, 193, 3, 4);
INSERT INTO 'formationstepmap' VALUES (395, 193, 1, 3);
INSERT INTO 'formationstepmap' VALUES (396, 193, 2, 3);
INSERT INTO 'formationstepmap' VALUES (397, 18, 3, 5);
INSERT INTO 'formationstepmap' VALUES (398, 18, 1, 2);
INSERT INTO 'formationstepmap' VALUES (399, 18, 2, 2);
INSERT INTO 'formationstepmap' VALUES (400, 194, 1, 2);
INSERT INTO 'formationstepmap' VALUES (401, 194, 2, 2);
INSERT INTO 'formationstepmap' VALUES (402, 195, 1, 1);
INSERT INTO 'formationstepmap' VALUES (403, 195, 2, 1);
INSERT INTO 'formationstepmap' VALUES (404, 195, 3, 4);
INSERT INTO 'formationstepmap' VALUES (408, 60, 1, 2);
INSERT INTO 'formationstepmap' VALUES (409, 60, 2, 2);
INSERT INTO 'formationstepmap' VALUES (410, 197, 3, 4);
INSERT INTO 'formationstepmap' VALUES (411, 197, 1, 1);
INSERT INTO 'formationstepmap' VALUES (412, 197, 2, 1);
INSERT INTO 'formationstepmap' VALUES (413, 198, 3, 5);
INSERT INTO 'formationstepmap' VALUES (414, 198, 3, 4);
INSERT INTO 'formationstepmap' VALUES (415, 199, 1, 1);
INSERT INTO 'formationstepmap' VALUES (416, 199, 2, 1);
INSERT INTO 'formationstepmap' VALUES (417, 199, 3, 4);
INSERT INTO 'formationstepmap' VALUES (418, 201, 3, 4);
INSERT INTO 'formationstepmap' VALUES (419, 90, 3, 4);
INSERT INTO 'formationstepmap' VALUES (420, 90, 1, 1);
INSERT INTO 'formationstepmap' VALUES (421, 90, 2, 1);
INSERT INTO 'formationstepmap' VALUES (422, 202, 1, 1);
INSERT INTO 'formationstepmap' VALUES (423, 202, 2, 1);
INSERT INTO 'formationstepmap' VALUES (424, 202, 3, 4);
INSERT INTO 'formationstepmap' VALUES (425, 213, 3, 4);
INSERT INTO 'formationstepmap' VALUES (426, 213, 3, 5);
INSERT INTO 'formationstepmap' VALUES (427, 214, 1, 3);
INSERT INTO 'formationstepmap' VALUES (428, 214, 1, 1);
INSERT INTO 'formationstepmap' VALUES (429, 214, 2, 1);
INSERT INTO 'formationstepmap' VALUES (430, 214, 2, 3);
INSERT INTO 'formationstepmap' VALUES (431, 215, 1, 3);
INSERT INTO 'formationstepmap' VALUES (432, 215, 2, 3);
INSERT INTO 'formationstepmap' VALUES (433, 215, 3, 4);
INSERT INTO 'formationstepmap' VALUES (434, 94, 3, 5);
INSERT INTO 'formationstepmap' VALUES (435, 94, 3, 4);
INSERT INTO 'formationstepmap' VALUES (436, 186, 3, 4);
INSERT INTO 'formationstepmap' VALUES (437, 186, 3, 5);
INSERT INTO 'formationstepmap' VALUES (438, 219, 3, 4);
INSERT INTO 'formationstepmap' VALUES (439, 160, 1, 3);
INSERT INTO 'formationstepmap' VALUES (440, 160, 2, 3);
INSERT INTO 'formationstepmap' VALUES (441, 160, 3, 4);
INSERT INTO 'formationstepmap' VALUES (442, 188, 3, 4);
INSERT INTO 'formationstepmap' VALUES (443, 189, 3, 4);
INSERT INTO 'formationstepmap' VALUES (444, 183, 3, 4);
INSERT INTO 'formationstepmap' VALUES (445, 225, 3, 4);
INSERT INTO 'formationstepmap' VALUES (446, 41, 3, 4);
INSERT INTO 'formationstepmap' VALUES (447, 221, 3, 4);
INSERT INTO 'formationstepmap' VALUES (448, 221, 1, 1);
INSERT INTO 'formationstepmap' VALUES (449, 221, 2, 1);
INSERT INTO 'formationstepmap' VALUES (450, 176, 3, 4);
INSERT INTO 'formationstepmap' VALUES (451, 230, 1, 1);
INSERT INTO 'formationstepmap' VALUES (452, 230, 2, 1);
INSERT INTO 'formationstepmap' VALUES (453, 230, 3, 4);
INSERT INTO 'formationstepmap' VALUES (454, 71, 1, 1);
INSERT INTO 'formationstepmap' VALUES (455, 203, 1, 1);
INSERT INTO 'formationstepmap' VALUES (456, 203, 2, 1);
INSERT INTO 'formationstepmap' VALUES (457, 203, 3, 4);
INSERT INTO 'formationstepmap' VALUES (458, 78, 1, 1);
INSERT INTO 'formationstepmap' VALUES (459, 78, 2, 1);
INSERT INTO 'formationstepmap' VALUES (460, 78, 3, 4);
INSERT INTO 'formationstepmap' VALUES (461, 61, 3, 5);
INSERT INTO 'formationstepmap' VALUES (462, 62, 1, 2);
INSERT INTO 'formationstepmap' VALUES (463, 62, 2, 2);


--
INSERT INTO 'group' VALUES (1, 532, 518);
INSERT INTO 'group' VALUES (2, 532, 517);
INSERT INTO 'group' VALUES (3, 22, 538);
INSERT INTO 'group' VALUES (4, 22, 21);
INSERT INTO 'group' VALUES (5, 1333, 653);
INSERT INTO 'group' VALUES (6, 1333, 43);
INSERT INTO 'group' VALUES (7, 1853, 49);
INSERT INTO 'group' VALUES (8, 1853, 550);
INSERT INTO 'group' VALUES (9, 496, 50);
INSERT INTO 'group' VALUES (10, 1856, 550);
INSERT INTO 'group' VALUES (11, 1856, 1848);
INSERT INTO 'group' VALUES (12, 808, 635);
INSERT INTO 'group' VALUES (13, 79, 926);
INSERT INTO 'group' VALUES (14, 58, 480);
INSERT INTO 'group' VALUES (15, 58, 1135);
INSERT INTO 'group' VALUES (18, 1326, 210);
INSERT INTO 'group' VALUES (19, 1369, 275);
INSERT INTO 'group' VALUES (20, 1369, 438);
INSERT INTO 'group' VALUES (21, 1369, 1313);
INSERT INTO 'group' VALUES (22, 627, 900);
INSERT INTO 'group' VALUES (23, 450, 1301);
INSERT INTO 'group' VALUES (24, 450, 70);
INSERT INTO 'group' VALUES (25, 720, 73);
INSERT INTO 'group' VALUES (28, 849, 1118);
INSERT INTO 'group' VALUES (29, 849, 210);
INSERT INTO 'group' VALUES (30, 561, 88);
INSERT INTO 'group' VALUES (31, 1682, 1658);
INSERT INTO 'group' VALUES (32, 1682, 1521);
INSERT INTO 'group' VALUES (33, 125, 1214);
INSERT INTO 'group' VALUES (34, 879, 1240);
INSERT INTO 'group' VALUES (35, 1348, 136);
INSERT INTO 'group' VALUES (36, 1348, 658);
INSERT INTO 'group' VALUES (37, 767, 658);
INSERT INTO 'group' VALUES (38, 139, 703);
INSERT INTO 'group' VALUES (39, 516, 517);
INSERT INTO 'group' VALUES (40, 148, 632);
INSERT INTO 'group' VALUES (41, 148, 351);
INSERT INTO 'group' VALUES (42, 148, 608);
INSERT INTO 'group' VALUES (43, 839, 152);
INSERT INTO 'group' VALUES (44, 170, 758);
INSERT INTO 'group' VALUES (45, 170, 954);
INSERT INTO 'group' VALUES (48, 1016, 618);
INSERT INTO 'group' VALUES (49, 749, 952);
INSERT INTO 'group' VALUES (50, 229, 433);
INSERT INTO 'group' VALUES (52, 273, 272);
INSERT INTO 'group' VALUES (53, 273, 965);
INSERT INTO 'group' VALUES (54, 1858, 1850);
INSERT INTO 'group' VALUES (58, 314, 613);
INSERT INTO 'group' VALUES (59, 314, 1840);
INSERT INTO 'group' VALUES (62, 332, 251);
INSERT INTO 'group' VALUES (63, 1828, 554);
INSERT INTO 'group' VALUES (64, 858, 759);
INSERT INTO 'group' VALUES (65, 585, 345);
INSERT INTO 'group' VALUES (66, 355, 356);
INSERT INTO 'group' VALUES (67, 355, 583);
INSERT INTO 'group' VALUES (68, 435, 1600);
INSERT INTO 'group' VALUES (71, 390, 389);
INSERT INTO 'group' VALUES (72, 390, 401);
INSERT INTO 'group' VALUES (73, 1368, 1012);
INSERT INTO 'group' VALUES (74, 1368, 1375);
INSERT INTO 'group' VALUES (76, 486, 1909);
INSERT INTO 'group' VALUES (77, 1919, 1551);
INSERT INTO 'group' VALUES (78, 1351, 1826);
INSERT INTO 'group' VALUES (79, 1371, 1987);
INSERT INTO 'group' VALUES (80, 2009, 1730);
INSERT INTO 'group' VALUES (81, 2009, 1733);
INSERT INTO 'group' VALUES (83, 2017, 1110);
INSERT INTO 'group' VALUES (84, 2017, 34);
INSERT INTO 'group' VALUES (87, 1007, 1359);
INSERT INTO 'group' VALUES (88, 3007, 3051);
INSERT INTO 'group' VALUES (89, 3007, 1668);
INSERT INTO 'group' VALUES (90, 3002, 1502);
INSERT INTO 'group' VALUES (91, 3037, 1525);
INSERT INTO 'group' VALUES (92, 3070, 1551);
INSERT INTO 'group' VALUES (406, 3403, 10634);
INSERT INTO 'group' VALUES (548, 11602, 11534);
INSERT INTO 'group' VALUES (409, 3137, 10649);
INSERT INTO 'group' VALUES (410, 10659, 10658);
INSERT INTO 'group' VALUES (411, 10076, 10658);
INSERT INTO 'group' VALUES (412, 10076, 1502);
INSERT INTO 'group' VALUES (93, 3070, 1585);
INSERT INTO 'group' VALUES (94, 3030, 1510);
INSERT INTO 'group' VALUES (95, 3030, 1511);
INSERT INTO 'group' VALUES (96, 3003, 1631);
INSERT INTO 'group' VALUES (97, 3032, 1578);
INSERT INTO 'group' VALUES (98, 3011, 1501);
INSERT INTO 'group' VALUES (99, 1007, 2027);
INSERT INTO 'group' VALUES (549, 11602, 11603);
INSERT INTO 'group' VALUES (550, 11602, 11605);
INSERT INTO 'group' VALUES (102, 2105, 2104);
INSERT INTO 'group' VALUES (103, 2105, 2100);
INSERT INTO 'group' VALUES (105, 2111, 2100);
INSERT INTO 'group' VALUES (106, 2112, 2002);
INSERT INTO 'group' VALUES (107, 2122, 17);
INSERT INTO 'group' VALUES (108, 2129, 5);
INSERT INTO 'group' VALUES (109, 2129, 116);
INSERT INTO 'group' VALUES (110, 332, 927);
INSERT INTO 'group' VALUES (111, 2178, 2206);
INSERT INTO 'group' VALUES (112, 2188, 2208);
INSERT INTO 'group' VALUES (113, 3015, 1502);
INSERT INTO 'group' VALUES (114, 2068, 1966);
INSERT INTO 'group' VALUES (115, 2068, 2221);
INSERT INTO 'group' VALUES (116, 2038, 1659);
INSERT INTO 'group' VALUES (117, 2029, 210);
INSERT INTO 'group' VALUES (118, 2231, 1615);
INSERT INTO 'group' VALUES (119, 3044, 1615);
INSERT INTO 'group' VALUES (121, 3006, 1793);
INSERT INTO 'group' VALUES (122, 2236, 1502);
INSERT INTO 'group' VALUES (123, 3038, 1572);
INSERT INTO 'group' VALUES (124, 3055, 1733);
INSERT INTO 'group' VALUES (125, 3023, 1591);
INSERT INTO 'group' VALUES (126, 3046, 1591);
INSERT INTO 'group' VALUES (127, 3013, 1591);
INSERT INTO 'group' VALUES (128, 3069, 1522);
INSERT INTO 'group' VALUES (130, 3012, 1576);
INSERT INTO 'group' VALUES (131, 2246, 1669);
INSERT INTO 'group' VALUES (132, 2184, 1643);
INSERT INTO 'group' VALUES (133, 2247, 1413);
INSERT INTO 'group' VALUES (134, 3028, 2266);
INSERT INTO 'group' VALUES (135, 2044, 1521);
INSERT INTO 'group' VALUES (136, 2044, 1615);
INSERT INTO 'group' VALUES (137, 2180, 3062);
INSERT INTO 'group' VALUES (138, 2180, 2286);
INSERT INTO 'group' VALUES (139, 2301, 1554);
INSERT INTO 'group' VALUES (140, 2303, 1872);
INSERT INTO 'group' VALUES (141, 2040, 2085);
INSERT INTO 'group' VALUES (142, 2040, 1796);
INSERT INTO 'group' VALUES (143, 2040, 1782);
INSERT INTO 'group' VALUES (144, 2328, 3058);
INSERT INTO 'group' VALUES (145, 3025, 2331);
INSERT INTO 'group' VALUES (146, 3017, 2335);
INSERT INTO 'group' VALUES (147, 3017, 1763);
INSERT INTO 'group' VALUES (148, 2065, 2340);
INSERT INTO 'group' VALUES (150, 2358, 2085);
INSERT INTO 'group' VALUES (151, 2358, 1511);
INSERT INTO 'group' VALUES (154, 2356, 1414);
INSERT INTO 'group' VALUES (155, 3065, 2366);
INSERT INTO 'group' VALUES (156, 2231, 2258);
INSERT INTO 'group' VALUES (157, 2037, 1634);
INSERT INTO 'group' VALUES (158, 3003, 2371);
INSERT INTO 'group' VALUES (159, 3003, 2372);
INSERT INTO 'group' VALUES (160, 3026, 1555);
INSERT INTO 'group' VALUES (161, 3014, 1590);
INSERT INTO 'group' VALUES (162, 2065, 2395);
INSERT INTO 'group' VALUES (165, 2398, 1615);
INSERT INTO 'group' VALUES (166, 2398, 2054);
INSERT INTO 'group' VALUES (167, 903, 1782);
INSERT INTO 'group' VALUES (168, 903, 1502);
INSERT INTO 'group' VALUES (169, 2414, 1557);
INSERT INTO 'group' VALUES (551, 11602, 11604);
INSERT INTO 'group' VALUES (552, 11611, 11610);
INSERT INTO 'group' VALUES (174, 3010, 1558);
INSERT INTO 'group' VALUES (175, 3061, 1611);
INSERT INTO 'group' VALUES (129, 3039, 1709);
INSERT INTO 'group' VALUES (51, 271, 270);
INSERT INTO 'group' VALUES (82, 2014, 2015);
INSERT INTO 'group' VALUES (170, 2121, 508);
INSERT INTO 'group' VALUES (404, 10000, 2395);
INSERT INTO 'group' VALUES (405, 10000, 10634);
INSERT INTO 'group' VALUES (407, 10000, 2763);
INSERT INTO 'group' VALUES (47, 2, 175);
INSERT INTO 'group' VALUES (403, 3342, 10607);
INSERT INTO 'group' VALUES (46, 533, 175);
INSERT INTO 'group' VALUES (163, 2396, 1780);
INSERT INTO 'group' VALUES (120, 147, 1615);
INSERT INTO 'group' VALUES (179, 1664, 1663);
INSERT INTO 'group' VALUES (180, 3020, 1608);
INSERT INTO 'group' VALUES (181, 2441, 2279);
INSERT INTO 'group' VALUES (70, 378, 377);
INSERT INTO 'group' VALUES (16, 1264, 480);
INSERT INTO 'group' VALUES (17, 1264, 371);
INSERT INTO 'group' VALUES (69, 921, 710);
INSERT INTO 'group' VALUES (104, 916, 2106);
INSERT INTO 'group' VALUES (60, 434, 1);
INSERT INTO 'group' VALUES (61, 434, 930);
INSERT INTO 'group' VALUES (182, 2441, 1525);
INSERT INTO 'group' VALUES (183, 2441, 3037);
INSERT INTO 'group' VALUES (57, 998, 1457);
INSERT INTO 'group' VALUES (152, 2360, 932);
INSERT INTO 'group' VALUES (55, 451, 452);
INSERT INTO 'group' VALUES (56, 451, 345);
INSERT INTO 'group' VALUES (26, 1343, 82);
INSERT INTO 'group' VALUES (27, 1343, 105);
INSERT INTO 'group' VALUES (184, 2451, 1640);
INSERT INTO 'group' VALUES (185, 3014, 168);
INSERT INTO 'group' VALUES (187, 1734, 1896);
INSERT INTO 'group' VALUES (553, 11613, 3731);
INSERT INTO 'group' VALUES (191, 2462, 1473);
INSERT INTO 'group' VALUES (192, 3059, 2499);
INSERT INTO 'group' VALUES (193, 2505, 1592);
INSERT INTO 'group' VALUES (194, 2507, 1612);
INSERT INTO 'group' VALUES (195, 2530, 2172);
INSERT INTO 'group' VALUES (196, 3050, 1808);
INSERT INTO 'group' VALUES (197, 2564, 377);
INSERT INTO 'group' VALUES (198, 3042, 1533);
INSERT INTO 'group' VALUES (199, 3018, 1585);
INSERT INTO 'group' VALUES (200, 2043, 1585);
INSERT INTO 'group' VALUES (201, 2043, 1502);
INSERT INTO 'group' VALUES (205, 2586, 1502);
INSERT INTO 'group' VALUES (206, 2596, 1572);
INSERT INTO 'group' VALUES (207, 808, 2623);
INSERT INTO 'group' VALUES (208, 634, 1341);
INSERT INTO 'group' VALUES (209, 634, 2623);
INSERT INTO 'group' VALUES (210, 2645, 2266);
INSERT INTO 'group' VALUES (211, 2245, 1113);
INSERT INTO 'group' VALUES (212, 2440, 1113);
INSERT INTO 'group' VALUES (213, 2440, 2245);
INSERT INTO 'group' VALUES (217, 2681, 1899);
INSERT INTO 'group' VALUES (218, 2681, 1966);
INSERT INTO 'group' VALUES (219, 2039, 1640);
INSERT INTO 'group' VALUES (220, 2583, 2693);
INSERT INTO 'group' VALUES (223, 2046, 1796);
INSERT INTO 'group' VALUES (224, 2047, 1796);
INSERT INTO 'group' VALUES (225, 2047, 2276);
INSERT INTO 'group' VALUES (226, 2276, 1796);
INSERT INTO 'group' VALUES (227, 2710, 1268);
INSERT INTO 'group' VALUES (228, 2721, 358);
INSERT INTO 'group' VALUES (229, 1924, 2221);
INSERT INTO 'group' VALUES (230, 1924, 2726);
INSERT INTO 'group' VALUES (231, 2728, 2717);
INSERT INTO 'group' VALUES (232, 2729, 2726);
INSERT INTO 'group' VALUES (233, 2729, 1966);
INSERT INTO 'group' VALUES (234, 3021, 2730);
INSERT INTO 'group' VALUES (235, 2732, 2581);
INSERT INTO 'group' VALUES (236, 2732, 2720);
INSERT INTO 'group' VALUES (239, 2734, 2724);
INSERT INTO 'group' VALUES (240, 2734, 1054);
INSERT INTO 'group' VALUES (241, 2736, 2717);
INSERT INTO 'group' VALUES (242, 2736, 2726);
INSERT INTO 'group' VALUES (243, 2737, 1054);
INSERT INTO 'group' VALUES (247, 973, 693);
INSERT INTO 'group' VALUES (248, 2081, 2802);
INSERT INTO 'group' VALUES (249, 2808, 1268);
INSERT INTO 'group' VALUES (250, 2808, 2488);
INSERT INTO 'group' VALUES (251, 2819, 2821);
INSERT INTO 'group' VALUES (252, 2834, 952);
INSERT INTO 'group' VALUES (255, 1396, 1534);
INSERT INTO 'group' VALUES (256, 2860, 2861);
INSERT INTO 'group' VALUES (258, 2920, 1659);
INSERT INTO 'group' VALUES (259, 2920, 1422);
INSERT INTO 'group' VALUES (260, 2944, 2856);
INSERT INTO 'group' VALUES (261, 2953, 2952);
INSERT INTO 'group' VALUES (262, 2970, 2969);
INSERT INTO 'group' VALUES (264, 2993, 1439);
INSERT INTO 'group' VALUES (266, 2774, 2998);
INSERT INTO 'group' VALUES (267, 2710, 3075);
INSERT INTO 'group' VALUES (268, 3081, 3075);
INSERT INTO 'group' VALUES (269, 3081, 1034);
INSERT INTO 'group' VALUES (270, 3081, 1268);
INSERT INTO 'group' VALUES (271, 3092, 2395);
INSERT INTO 'group' VALUES (272, 3092, 2221);
INSERT INTO 'group' VALUES (274, 3102, 870);
INSERT INTO 'group' VALUES (275, 3108, 308);
INSERT INTO 'group' VALUES (276, 3067, 2085);
INSERT INTO 'group' VALUES (277, 3136, 1849);
INSERT INTO 'group' VALUES (554, 11613, 11614);
INSERT INTO 'group' VALUES (281, 3008, 1527);
INSERT INTO 'group' VALUES (282, 3190, 1502);
INSERT INTO 'group' VALUES (283, 3190, 15);
INSERT INTO 'group' VALUES (284, 3190, 401);
INSERT INTO 'group' VALUES (285, 3190, 389);
INSERT INTO 'group' VALUES (286, 3190, 1760);
INSERT INTO 'group' VALUES (287, 858, 3191);
INSERT INTO 'group' VALUES (288, 3205, 635);
INSERT INTO 'group' VALUES (289, 3205, 2623);
INSERT INTO 'group' VALUES (290, 3205, 808);
INSERT INTO 'group' VALUES (291, 3205, 854);
INSERT INTO 'group' VALUES (292, 3205, 1415);
INSERT INTO 'group' VALUES (293, 3218, 1673);
INSERT INTO 'group' VALUES (295, 3217, 3220);
INSERT INTO 'group' VALUES (297, 3283, 3134);
INSERT INTO 'group' VALUES (298, 3283, 1130);
INSERT INTO 'group' VALUES (299, 947, 2626);
INSERT INTO 'group' VALUES (300, 947, 3117);
INSERT INTO 'group' VALUES (301, 3311, 1527);
INSERT INTO 'group' VALUES (302, 3311, 1533);
INSERT INTO 'group' VALUES (303, 3311, 1720);
INSERT INTO 'group' VALUES (304, 3330, 319);
INSERT INTO 'group' VALUES (307, 2892, 3312);
INSERT INTO 'group' VALUES (310, 3351, 1220);
INSERT INTO 'group' VALUES (313, 2245, 3371);
INSERT INTO 'group' VALUES (188, 2450, 508);
INSERT INTO 'group' VALUES (317, 2725, 3374);
INSERT INTO 'group' VALUES (318, 3394, 723);
INSERT INTO 'group' VALUES (319, 3403, 2395);
INSERT INTO 'group' VALUES (320, 3399, 2977);
INSERT INTO 'group' VALUES (323, 3435, 1042);
INSERT INTO 'group' VALUES (324, 2586, 3436);
INSERT INTO 'group' VALUES (325, 3447, 267);
INSERT INTO 'group' VALUES (326, 3022, 3452);
INSERT INTO 'group' VALUES (328, 3464, 2743);
INSERT INTO 'group' VALUES (329, 3464, 3465);
INSERT INTO 'group' VALUES (330, 3469, 401);
INSERT INTO 'group' VALUES (331, 3469, 1269);
INSERT INTO 'group' VALUES (332, 3476, 3475);
INSERT INTO 'group' VALUES (333, 3476, 3432);
INSERT INTO 'group' VALUES (335, 561, 3443);
INSERT INTO 'group' VALUES (336, 3092, 29);
INSERT INTO 'group' VALUES (337, 3483, 29);
INSERT INTO 'group' VALUES (338, 3483, 2099);
INSERT INTO 'group' VALUES (339, 3483, 3484);
INSERT INTO 'group' VALUES (340, 3494, 932);
INSERT INTO 'group' VALUES (341, 3494, 1283);
INSERT INTO 'group' VALUES (342, 3495, 3439);
INSERT INTO 'group' VALUES (343, 3496, 1966);
INSERT INTO 'group' VALUES (344, 3420, 1643);
INSERT INTO 'group' VALUES (345, 3034, 3438);
INSERT INTO 'group' VALUES (347, 3512, 3511);
INSERT INTO 'group' VALUES (348, 3512, 3514);
INSERT INTO 'group' VALUES (349, 3515, 2489);
INSERT INTO 'group' VALUES (350, 2603, 3278);
INSERT INTO 'group' VALUES (351, 3519, 618);
INSERT INTO 'group' VALUES (352, 3019, 1603);
INSERT INTO 'group' VALUES (353, 3530, 3436);
INSERT INTO 'group' VALUES (354, 3530, 2696);
INSERT INTO 'group' VALUES (355, 3539, 3328);
INSERT INTO 'group' VALUES (356, 229, 3545);
INSERT INTO 'group' VALUES (357, 2834, 3549);
INSERT INTO 'group' VALUES (358, 3591, 3586);
INSERT INTO 'group' VALUES (359, 3591, 3590);
INSERT INTO 'group' VALUES (360, 2053, 2054);
INSERT INTO 'group' VALUES (361, 3353, 3605);
INSERT INTO 'group' VALUES (263, 256, 583);
INSERT INTO 'group' VALUES (202, 2566, 1575);
INSERT INTO 'group' VALUES (278, 3139, 316);
INSERT INTO 'group' VALUES (279, 3139, 1846);
INSERT INTO 'group' VALUES (296, 3277, 782);
INSERT INTO 'group' VALUES (257, 2121, 2874);
INSERT INTO 'group' VALUES (265, 2992, 1439);
INSERT INTO 'group' VALUES (221, 2696, 2695);
INSERT INTO 'group' VALUES (222, 2696, 2698);
INSERT INTO 'group' VALUES (190, 2468, 3383);
INSERT INTO 'group' VALUES (334, 2992, 3482);
INSERT INTO 'group' VALUES (314, 3368, 3371);
INSERT INTO 'group' VALUES (315, 3368, 3369);
INSERT INTO 'group' VALUES (203, 2162, 1763);
INSERT INTO 'group' VALUES (204, 2162, 2581);
INSERT INTO 'group' VALUES (294, 3221, 3220);
INSERT INTO 'group' VALUES (321, 3418, 3419);
INSERT INTO 'group' VALUES (322, 3418, 1713);
INSERT INTO 'group' VALUES (327, 3459, 2197);
INSERT INTO 'group' VALUES (308, 3342, 2874);
INSERT INTO 'group' VALUES (189, 2450, 51);
INSERT INTO 'group' VALUES (176, 147, 3461);
INSERT INTO 'group' VALUES (362, 3619, 3620);
INSERT INTO 'group' VALUES (363, 3658, 1626);
INSERT INTO 'group' VALUES (364, 3679, 725);
INSERT INTO 'group' VALUES (365, 3686, 1113);
INSERT INTO 'group' VALUES (366, 3686, 2932);
INSERT INTO 'group' VALUES (367, 3064, 1606);
INSERT INTO 'group' VALUES (368, 3495, 3583);
INSERT INTO 'group' VALUES (273, 2947, 2863);
INSERT INTO 'group' VALUES (214, 2672, 1502);
INSERT INTO 'group' VALUES (215, 2672, 15);
INSERT INTO 'group' VALUES (253, 2851, 91);
INSERT INTO 'group' VALUES (186, 2042, 1135);
INSERT INTO 'group' VALUES (254, 2851, 108);
INSERT INTO 'group' VALUES (245, 2764, 558);
INSERT INTO 'group' VALUES (216, 2169, 2677);
INSERT INTO 'group' VALUES (244, 2760, 2759);
INSERT INTO 'group' VALUES (369, 3283, 3130);
INSERT INTO 'group' VALUES (370, 3160, 508);
INSERT INTO 'group' VALUES (371, 3726, 3536);
INSERT INTO 'group' VALUES (372, 3726, 2927);
INSERT INTO 'group' VALUES (246, 2767, 2766);
INSERT INTO 'group' VALUES (346, 2767, 3511);
INSERT INTO 'group' VALUES (373, 3726, 1381);
INSERT INTO 'group' VALUES (374, 3726, 3731);
INSERT INTO 'group' VALUES (375, 3726, 3728);
INSERT INTO 'group' VALUES (376, 3726, 3729);
INSERT INTO 'group' VALUES (380, 3765, 3762);
INSERT INTO 'group' VALUES (381, 3777, 3775);
INSERT INTO 'group' VALUES (382, 3782, 3606);
INSERT INTO 'group' VALUES (383, 3782, 118);
INSERT INTO 'group' VALUES (402, 10475, 319);
INSERT INTO 'group' VALUES (413, 10777, 10763);
INSERT INTO 'group' VALUES (414, 10777, 10776);
INSERT INTO 'group' VALUES (415, 10807, 10359);
INSERT INTO 'group' VALUES (419, 10272, 1640);
INSERT INTO 'group' VALUES (420, 10915, 10658);
INSERT INTO 'group' VALUES (421, 10915, 3436);
INSERT INTO 'group' VALUES (422, 10915, 1502);
INSERT INTO 'group' VALUES (423, 10380, 3369);
INSERT INTO 'group' VALUES (424, 10380, 3674);
INSERT INTO 'group' VALUES (425, 10380, 3371);
INSERT INTO 'group' VALUES (426, 10380, 1113);
INSERT INTO 'group' VALUES (311, 3370, 3369);
INSERT INTO 'group' VALUES (312, 3370, 3371);
INSERT INTO 'group' VALUES (427, 3370, 3674);
INSERT INTO 'group' VALUES (428, 340, 1502);
INSERT INTO 'group' VALUES (429, 3750, 1842);
INSERT INTO 'group' VALUES (386, 10020, 1054);
INSERT INTO 'group' VALUES (390, 10020, 3722);
INSERT INTO 'group' VALUES (391, 10020, 10011);
INSERT INTO 'group' VALUES (392, 10020, 10027);
INSERT INTO 'group' VALUES (393, 10020, 10028);
INSERT INTO 'group' VALUES (387, 10022, 1054);
INSERT INTO 'group' VALUES (394, 10022, 10025);
INSERT INTO 'group' VALUES (395, 10022, 10029);
INSERT INTO 'group' VALUES (396, 10022, 1846);
INSERT INTO 'group' VALUES (388, 10023, 1054);
INSERT INTO 'group' VALUES (397, 10023, 10008);
INSERT INTO 'group' VALUES (385, 10019, 1054);
INSERT INTO 'group' VALUES (280, 3139, 1657);
INSERT INTO 'group' VALUES (430, 11136, 848);
INSERT INTO 'group' VALUES (431, 11136, 11135);
INSERT INTO 'group' VALUES (432, 11142, 11049);
INSERT INTO 'group' VALUES (433, 11142, 11141);
INSERT INTO 'group' VALUES (436, 11167, 10307);
INSERT INTO 'group' VALUES (437, 11167, 11154);
INSERT INTO 'group' VALUES (438, 11170, 370);
INSERT INTO 'group' VALUES (439, 11170, 1144);
INSERT INTO 'group' VALUES (75, 846, 5);
INSERT INTO 'group' VALUES (495, 11441, 3462);
INSERT INTO 'group' VALUES (496, 11441, 57);
INSERT INTO 'group' VALUES (434, 11164, 10961);
INSERT INTO 'group' VALUES (435, 11164, 11163);
INSERT INTO 'group' VALUES (442, 10292, 11212);
INSERT INTO 'group' VALUES (443, 10292, 10288);
INSERT INTO 'group' VALUES (444, 10291, 11214);
INSERT INTO 'group' VALUES (445, 10291, 11213);
INSERT INTO 'group' VALUES (446, 10291, 10288);
INSERT INTO 'group' VALUES (440, 10309, 10293);
INSERT INTO 'group' VALUES (441, 10309, 10288);
INSERT INTO 'group' VALUES (447, 10289, 10288);
INSERT INTO 'group' VALUES (448, 10289, 11216);
INSERT INTO 'group' VALUES (316, 3368, 1113);
INSERT INTO 'group' VALUES (497, 11474, 11475);
INSERT INTO 'group' VALUES (379, 3756, 2692);
INSERT INTO 'group' VALUES (449, 3756, 11217);
INSERT INTO 'group' VALUES (450, 10899, 10451);
INSERT INTO 'group' VALUES (451, 10899, 11111);
INSERT INTO 'group' VALUES (452, 2252, 1615);
INSERT INTO 'group' VALUES (453, 2252, 1533);
INSERT INTO 'group' VALUES (454, 10932, 1558);
INSERT INTO 'group' VALUES (455, 10932, 1611);
INSERT INTO 'group' VALUES (456, 10070, 3731);
INSERT INTO 'group' VALUES (457, 10070, 2977);
INSERT INTO 'group' VALUES (461, 11220, 10582);
INSERT INTO 'group' VALUES (462, 11220, 11219);
INSERT INTO 'group' VALUES (463, 2696, 3282);
INSERT INTO 'group' VALUES (464, 271, 11229);
INSERT INTO 'group' VALUES (498, 11474, 11476);
INSERT INTO 'group' VALUES (466, 11248, 11246);
INSERT INTO 'group' VALUES (467, 11248, 11247);
INSERT INTO 'group' VALUES (468, 2014, 11253);
INSERT INTO 'group' VALUES (469, 11298, 3058);
INSERT INTO 'group' VALUES (470, 11311, 11310);
INSERT INTO 'group' VALUES (471, 11311, 11309);
INSERT INTO 'group' VALUES (473, 11351, 11314);
INSERT INTO 'group' VALUES (474, 11351, 11355);
INSERT INTO 'group' VALUES (475, 11367, 11370);
INSERT INTO 'group' VALUES (499, 2162, 11483);
INSERT INTO 'group' VALUES (500, 2162, 2977);
INSERT INTO 'group' VALUES (501, 2162, 1829);
INSERT INTO 'group' VALUES (502, 11484, 1829);
INSERT INTO 'group' VALUES (503, 11484, 11483);
INSERT INTO 'group' VALUES (504, 11484, 2977);
INSERT INTO 'group' VALUES (505, 11489, 2792);
INSERT INTO 'group' VALUES (476, 11376, 11321);
INSERT INTO 'group' VALUES (477, 11376, 11378);
INSERT INTO 'group' VALUES (478, 11376, 11379);
INSERT INTO 'group' VALUES (479, 11376, 11384);
INSERT INTO 'group' VALUES (480, 11385, 1331);
INSERT INTO 'group' VALUES (481, 11385, 11321);
INSERT INTO 'group' VALUES (377, 3736, 3134);
INSERT INTO 'group' VALUES (484, 11388, 1331);
INSERT INTO 'group' VALUES (485, 11388, 11387);
INSERT INTO 'group' VALUES (486, 11388, 1393);
INSERT INTO 'group' VALUES (487, 11394, 11395);
INSERT INTO 'group' VALUES (488, 11394, 11396);
INSERT INTO 'group' VALUES (171, 2121, 51);
INSERT INTO 'group' VALUES (172, 2121, 814);
INSERT INTO 'group' VALUES (173, 2121, 787);
INSERT INTO 'group' VALUES (309, 2121, 10607);
INSERT INTO 'group' VALUES (490, 2121, 11400);
INSERT INTO 'group' VALUES (491, 2121, 11401);
INSERT INTO 'group' VALUES (492, 2121, 1760);
INSERT INTO 'group' VALUES (493, 2121, 11402);
INSERT INTO 'group' VALUES (494, 10981, 1508);
INSERT INTO 'group' VALUES (408, 10000, 3484);
INSERT INTO 'group' VALUES (506, 11489, 11488);
INSERT INTO 'group' VALUES (507, 11495, 11493);
INSERT INTO 'group' VALUES (508, 11495, 11494);
INSERT INTO 'group' VALUES (512, 10209, 2390);
INSERT INTO 'group' VALUES (515, 10209, 11510);
INSERT INTO 'group' VALUES (389, 3372, 10028);
INSERT INTO 'group' VALUES (509, 3372, 2724);
INSERT INTO 'group' VALUES (398, 10008, 10012);
INSERT INTO 'group' VALUES (518, 3802, 11512);
INSERT INTO 'group' VALUES (513, 3045, 1621);
INSERT INTO 'group' VALUES (519, 3802, 11513);
INSERT INTO 'group' VALUES (516, 3806, 1691);
INSERT INTO 'group' VALUES (514, 3221, 11510);
INSERT INTO 'group' VALUES (511, 10209, 1621);
INSERT INTO 'group' VALUES (517, 3806, 11511);
INSERT INTO 'group' VALUES (522, 3749, 1713);
INSERT INTO 'group' VALUES (465, 3736, 1130);
INSERT INTO 'group' VALUES (520, 11515, 3419);
INSERT INTO 'group' VALUES (458, 11115, 10759);
INSERT INTO 'group' VALUES (523, 3339, 11525);
INSERT INTO 'group' VALUES (399, 10008, 10009);
INSERT INTO 'group' VALUES (530, 11544, 11540);
INSERT INTO 'group' VALUES (531, 11544, 11541);
INSERT INTO 'group' VALUES (532, 11544, 11542);
INSERT INTO 'group' VALUES (533, 11544, 11543);
INSERT INTO 'group' VALUES (534, 11544, 11539);
INSERT INTO 'group' VALUES (540, 11573, 3316);
INSERT INTO 'group' VALUES (541, 11573, 11572);
INSERT INTO 'group' VALUES (542, 2, 11592);
INSERT INTO 'group' VALUES (543, 2, 534);
INSERT INTO 'group' VALUES (544, 2, 535);
INSERT INTO 'group' VALUES (545, 533, 11592);
INSERT INTO 'group' VALUES (546, 11412, 11598);
INSERT INTO 'group' VALUES (547, 11412, 10625);
INSERT INTO 'group' VALUES (556, 11627, 700);
INSERT INTO 'group' VALUES (557, 11627, 11626);
INSERT INTO 'group' VALUES (177, 2418, 1846);
INSERT INTO 'group' VALUES (178, 2418, 1054);
INSERT INTO 'group' VALUES (558, 2418, 10012);
INSERT INTO 'group' VALUES (559, 11524, 11641);
INSERT INTO 'group' VALUES (164, 2396, 2340);
INSERT INTO 'group' VALUES (560, 11651, 11645);
INSERT INTO 'group' VALUES (561, 11651, 11646);
INSERT INTO 'group' VALUES (562, 11651, 11647);
INSERT INTO 'group' VALUES (563, 11651, 11648);
INSERT INTO 'group' VALUES (564, 11651, 11649);
INSERT INTO 'group' VALUES (565, 11651, 11650);
INSERT INTO 'group' VALUES (566, 11654, 11653);
INSERT INTO 'group' VALUES (567, 11654, 11011);
INSERT INTO 'group' VALUES (535, 10583, 10584);
INSERT INTO 'group' VALUES (418, 10204, 2965);
INSERT INTO 'group' VALUES (401, 10373, 2973);
INSERT INTO 'group' VALUES (570, 11662, 11487);
INSERT INTO 'group' VALUES (571, 11662, 11661);
INSERT INTO 'group' VALUES (572, 11673, 11671);
INSERT INTO 'group' VALUES (573, 11673, 11672);
INSERT INTO 'group' VALUES (576, 11713, 3617);
INSERT INTO 'group' VALUES (577, 11713, 11709);
INSERT INTO 'group' VALUES (578, 11719, 1862);
INSERT INTO 'group' VALUES (555, 2363, 50);
INSERT INTO 'group' VALUES (472, 11078, 11340);
INSERT INTO 'group' VALUES (384, 10018, 1575);
INSERT INTO 'group' VALUES (524, 3009, 1652);
INSERT INTO 'group' VALUES (510, 10503, 2724);
INSERT INTO 'group' VALUES (525, 3009, 1650);
INSERT INTO 'group' VALUES (579, 11728, 11577);
INSERT INTO 'group' VALUES (580, 11728, 11727);
INSERT INTO 'group' VALUES (583, 11736, 11739);
INSERT INTO 'group' VALUES (584, 10748, 1456);
INSERT INTO 'group' VALUES (585, 10580, 1456);
INSERT INTO 'group' VALUES (586, 10580, 1437);
INSERT INTO 'group' VALUES (459, 10321, 1381);
INSERT INTO 'group' VALUES (460, 10321, 1382);
INSERT INTO 'group' VALUES (587, 11748, 193);
INSERT INTO 'group' VALUES (588, 11748, 11747);
INSERT INTO 'group' VALUES (589, 2915, 10495);
INSERT INTO 'group' VALUES (590, 11772, 1378);
INSERT INTO 'group' VALUES (591, 11772, 11771);
INSERT INTO 'group' VALUES (592, 2031, 11777);
INSERT INTO 'group' VALUES (595, 11787, 11780);
INSERT INTO 'group' VALUES (596, 11787, 11781);
INSERT INTO 'group' VALUES (597, 11791, 11790);
INSERT INTO 'group' VALUES (598, 11791, 10908);
INSERT INTO 'group' VALUES (400, 10008, 10030);
INSERT INTO 'group' VALUES (600, 11804, 11803);
INSERT INTO 'group' VALUES (601, 11804, 11802);
INSERT INTO 'group' VALUES (602, 11812, 2863);
INSERT INTO 'group' VALUES (603, 11812, 11811);
INSERT INTO 'group' VALUES (604, 3459, 10968);
INSERT INTO 'group' VALUES (605, 11813, 11165);
INSERT INTO 'group' VALUES (606, 11813, 2197);
INSERT INTO 'group' VALUES (607, 2450, 1760);
INSERT INTO 'group' VALUES (574, 11702, 10288);
INSERT INTO 'group' VALUES (575, 11702, 2688);
INSERT INTO 'group' VALUES (610, 11836, 11152);
INSERT INTO 'group' VALUES (611, 11836, 11465);
INSERT INTO 'group' VALUES (614, 11860, 2986);
INSERT INTO 'group' VALUES (615, 11860, 11859);
INSERT INTO 'group' VALUES (616, 11862, 10432);
INSERT INTO 'group' VALUES (617, 11862, 11861);
INSERT INTO 'group' VALUES (619, 11885, 463);
INSERT INTO 'group' VALUES (620, 11885, 11884);
INSERT INTO 'group' VALUES (621, 11886, 308);
INSERT INTO 'group' VALUES (622, 11886, 370);
INSERT INTO 'group' VALUES (568, 11656, 11049);
INSERT INTO 'group' VALUES (569, 11656, 11657);
INSERT INTO 'group' VALUES (623, 11909, 11907);
INSERT INTO 'group' VALUES (624, 11909, 11908);
INSERT INTO 'group' VALUES (85, 2018, 210);
INSERT INTO 'group' VALUES (86, 2018, 1873);
INSERT INTO 'group' VALUES (237, 2733, 1461);
INSERT INTO 'group' VALUES (238, 2733, 2726);
INSERT INTO 'group' VALUES (625, 2061, 1461);
INSERT INTO 'group' VALUES (593, 11785, 11784);
INSERT INTO 'group' VALUES (594, 11785, 11783);
INSERT INTO 'group' VALUES (626, 10095, 1631);
INSERT INTO 'group' VALUES (627, 10095, 10097);
INSERT INTO 'group' VALUES (536, 11568, 1502);
INSERT INTO 'group' VALUES (537, 11568, 1631);
INSERT INTO 'group' VALUES (628, 11923, 608);
INSERT INTO 'group' VALUES (629, 11923, 2562);
INSERT INTO 'group' VALUES (630, 10310, 11925);
INSERT INTO 'group' VALUES (631, 10310, 10320);
INSERT INTO 'group' VALUES (632, 10890, 11244);
INSERT INTO 'group' VALUES (633, 10890, 10645);
INSERT INTO 'group' VALUES (634, 11928, 3416);
INSERT INTO 'group' VALUES (635, 11928, 3417);
INSERT INTO 'group' VALUES (608, 11817, 51);
INSERT INTO 'group' VALUES (609, 11817, 508);
INSERT INTO 'group' VALUES (636, 11944, 11942);
INSERT INTO 'group' VALUES (637, 11944, 11943);
INSERT INTO 'group' VALUES (638, 11949, 980);
INSERT INTO 'group' VALUES (639, 11952, 1722);
INSERT INTO 'group' VALUES (640, 11952, 1572);
INSERT INTO 'group' VALUES (641, 11953, 3685);
INSERT INTO 'group' VALUES (642, 11953, 11188);
INSERT INTO 'group' VALUES (643, 11953, 11954);
INSERT INTO 'group' VALUES (644, 11958, 2743);
INSERT INTO 'group' VALUES (645, 11958, 3465);
INSERT INTO 'group' VALUES (646, 11959, 1463);
INSERT INTO 'group' VALUES (647, 11960, 1556);
INSERT INTO 'group' VALUES (648, 10979, 11962);
INSERT INTO 'group' VALUES (649, 3709, 11066);
INSERT INTO 'group' VALUES (650, 11972, 10012);
INSERT INTO 'group' VALUES (651, 11972, 10009);
INSERT INTO 'group' VALUES (683, 12023, 12022);
INSERT INTO 'group' VALUES (653, 11979, 11155);
INSERT INTO 'group' VALUES (654, 11979, 11978);
INSERT INTO 'group' VALUES (655, 11983, 11967);
INSERT INTO 'group' VALUES (656, 11983, 11971);
INSERT INTO 'group' VALUES (657, 11984, 1415);
INSERT INTO 'group' VALUES (658, 11984, 854);
INSERT INTO 'group' VALUES (659, 11996, 3143);
INSERT INTO 'group' VALUES (660, 11996, 11995);
INSERT INTO 'group' VALUES (684, 2062, 1551);
INSERT INTO 'group' VALUES (661, 11999, 10973);
INSERT INTO 'group' VALUES (662, 11999, 11998);
INSERT INTO 'group' VALUES (663, 12003, 12001);
INSERT INTO 'group' VALUES (664, 12003, 12002);
INSERT INTO 'group' VALUES (665, 12004, 11233);
INSERT INTO 'group' VALUES (666, 12008, 11744);
INSERT INTO 'group' VALUES (667, 12008, 3390);
INSERT INTO 'group' VALUES (668, 12009, 3383);
INSERT INTO 'group' VALUES (669, 10114, 1526);
INSERT INTO 'group' VALUES (670, 10114, 10116);
INSERT INTO 'group' VALUES (685, 12042, 11786);
INSERT INTO 'group' VALUES (686, 916, 12049);
INSERT INTO 'group' VALUES (687, 10854, 154);
INSERT INTO 'group' VALUES (688, 10854, 1846);
INSERT INTO 'group' VALUES (689, 524, 12051);
INSERT INTO 'group' VALUES (690, 527, 12051);
INSERT INTO 'group' VALUES (671, 2042, 1932);
INSERT INTO 'group' VALUES (672, 2042, 12012);
INSERT INTO 'group' VALUES (673, 2042, 12013);
INSERT INTO 'group' VALUES (674, 2042, 1886);
INSERT INTO 'group' VALUES (675, 2042, 12014);
INSERT INTO 'group' VALUES (676, 2042, 12015);
INSERT INTO 'group' VALUES (679, 12019, 11529);
INSERT INTO 'group' VALUES (680, 12019, 11527);
INSERT INTO 'group' VALUES (681, 1213, 11747);
INSERT INTO 'group' VALUES (618, 10373, 11874);
INSERT INTO 'group' VALUES (692, 12066, 11356);
INSERT INTO 'group' VALUES (693, 12066, 12063);
INSERT INTO 'group' VALUES (691, 2764, 12065);
INSERT INTO 'group' VALUES (694, 12069, 11858);
INSERT INTO 'group' VALUES (695, 12069, 12058);
INSERT INTO 'group' VALUES (696, 10958, 12011);
INSERT INTO 'group' VALUES (697, 10958, 11558);
INSERT INTO 'group' VALUES (698, 2760, 12085);
INSERT INTO 'group' VALUES (699, 12090, 12089);
INSERT INTO 'group' VALUES (700, 12090, 12088);
INSERT INTO 'group' VALUES (701, 12108, 785);
INSERT INTO 'group' VALUES (702, 12108, 12107);
INSERT INTO 'group' VALUES (703, 12114, 11509);
INSERT INTO 'group' VALUES (704, 12114, 12113);
INSERT INTO 'group' VALUES (705, 11863, 12115);
INSERT INTO 'group' VALUES (706, 11863, 12116);
INSERT INTO 'group' VALUES (707, 12118, 312);
INSERT INTO 'group' VALUES (708, 12118, 208);
INSERT INTO 'group' VALUES (712, 12125, 12059);
INSERT INTO 'group' VALUES (713, 12125, 12124);
INSERT INTO 'group' VALUES (714, 12129, 12127);
INSERT INTO 'group' VALUES (715, 12129, 12128);
INSERT INTO 'group' VALUES (489, 11234, 11035);
INSERT INTO 'group' VALUES (716, 11234, 12131);
INSERT INTO 'group' VALUES (652, 11128, 2865);
INSERT INTO 'group' VALUES (717, 12140, 12138);
INSERT INTO 'group' VALUES (718, 12140, 12139);
INSERT INTO 'group' VALUES (719, 11612, 11140);
INSERT INTO 'group' VALUES (720, 11612, 12144);
INSERT INTO 'group' VALUES (709, 12122, 12058);
INSERT INTO 'group' VALUES (710, 12122, 11962);
INSERT INTO 'group' VALUES (711, 12122, 11858);
INSERT INTO 'group' VALUES (723, 12159, 2101);
INSERT INTO 'group' VALUES (724, 12159, 12158);
INSERT INTO 'group' VALUES (725, 12160, 316);
INSERT INTO 'group' VALUES (677, 12018, 12017);
INSERT INTO 'group' VALUES (678, 12018, 11528);
INSERT INTO 'group' VALUES (731, 998, 12176);
INSERT INTO 'group' VALUES (732, 2363, 12177);
INSERT INTO 'group' VALUES (733, 12180, 478);
INSERT INTO 'group' VALUES (734, 12180, 384);
INSERT INTO 'group' VALUES (735, 12185, 2677);
INSERT INTO 'group' VALUES (736, 12185, 12184);
INSERT INTO 'group' VALUES (737, 12189, 11347);
INSERT INTO 'group' VALUES (738, 12189, 12188);
INSERT INTO 'group' VALUES (305, 2885, 1829);
INSERT INTO 'group' VALUES (306, 2885, 1763);
INSERT INTO 'group' VALUES (599, 2885, 11799);
INSERT INTO 'group' VALUES (739, 3051, 1668);
INSERT INTO 'group' VALUES (740, 12215, 3580);
INSERT INTO 'group' VALUES (741, 12215, 12214);
INSERT INTO 'group' VALUES (529, 11078, 11533);
INSERT INTO 'group' VALUES (742, 3152, 12223);
INSERT INTO 'group' VALUES (743, 3152, 12224);
INSERT INTO 'group' VALUES (612, 11849, 11848);
INSERT INTO 'group' VALUES (613, 11849, 12243);
INSERT INTO 'group' VALUES (721, 12157, 3220);
INSERT INTO 'group' VALUES (722, 12157, 1527);
INSERT INTO 'group' VALUES (149, 883, 1457);
INSERT INTO 'group' VALUES (726, 883, 12172);
INSERT INTO 'group' VALUES (727, 883, 12174);
INSERT INTO 'group' VALUES (744, 10503, 3722);
INSERT INTO 'group' VALUES (745, 10503, 1829);
INSERT INTO 'group' VALUES (746, 10503, 1511);
INSERT INTO 'group' VALUES (747, 10503, 10025);
INSERT INTO 'group' VALUES (748, 10503, 1054);
INSERT INTO 'group' VALUES (749, 10503, 2221);
INSERT INTO 'group' VALUES (750, 10503, 12238);
INSERT INTO 'group' VALUES (751, 10503, 12239);
INSERT INTO 'group' VALUES (752, 10503, 12240);
INSERT INTO 'group' VALUES (753, 10503, 12241);
INSERT INTO 'group' VALUES (754, 587, 10788);
INSERT INTO 'group' VALUES (153, 2360, 1083);
INSERT INTO 'group' VALUES (755, 2584, 3766);
INSERT INTO 'group' VALUES (757, 2333, 12246);
INSERT INTO 'group' VALUES (758, 12247, 12246);
INSERT INTO 'group' VALUES (759, 12247, 2006);
INSERT INTO 'group' VALUES (526, 3009, 2219);
INSERT INTO 'group' VALUES (527, 3009, 2390);
INSERT INTO 'group' VALUES (528, 3009, 1531);
INSERT INTO 'group' VALUES (760, 12251, 105);
INSERT INTO 'group' VALUES (761, 12251, 12250);
INSERT INTO 'group' VALUES (728, 883, 12175);
INSERT INTO 'group' VALUES (729, 883, 1764);
INSERT INTO 'group' VALUES (730, 883, 12176);
INSERT INTO 'group' VALUES (762, 12262, 12168);
INSERT INTO 'group' VALUES (763, 12262, 11915);


--
INSERT INTO 'media' VALUES (3486, 1, 1, 'RSCDS CD-1', 1993, 1);
INSERT INTO 'media' VALUES (3487, 2, 3, 'CB6', 0, 1);
INSERT INTO 'media' VALUES (3488, 2, 1, 'CD6', 0, 1);
INSERT INTO 'media' VALUES (3489, 3, 1, 'SSCD 02', 1996, 1);
INSERT INTO 'media' VALUES (3490, 4, 1, 'SSCD03', 1996, 1);
INSERT INTO 'media' VALUES (3491, 5, 1, 'SSCD04', 1996, 1);
INSERT INTO 'media' VALUES (3492, 6, 1, 'SSCD05', 1996, 1);
INSERT INTO 'media' VALUES (3493, 7, 3, 'SC04', 1996, 1);
INSERT INTO 'media' VALUES (3494, 7, 1, 'SCO3', 1996, 1);
INSERT INTO 'media' VALUES (3495, 8, 1, 'HRMCD521', 1996, 1);
INSERT INTO 'media' VALUES (3496, 9, 1, 'HRMCD522', 1996, 1);
INSERT INTO 'media' VALUES (3497, 10, 1, 'HRMCD501', 1996, 1);
INSERT INTO 'media' VALUES (3498, 11, 1, 'HRMCD502', 1996, 1);
INSERT INTO 'media' VALUES (3499, 12, 1, 'HRMCD503', 1996, 1);
INSERT INTO 'media' VALUES (3500, 13, 1, 'HRMCD504', 1996, 1);
INSERT INTO 'media' VALUES (3501, 14, 1, 'HRMCD505', 1996, 1);
INSERT INTO 'media' VALUES (3502, 15, 3, '', 1987, 1);
INSERT INTO 'media' VALUES (3503, 15, 1, 'LCOM 9003', 1987, 1);
INSERT INTO 'media' VALUES (3504, 16, 1, 'RSCDS CD-3', 1995, 1);
INSERT INTO 'media' VALUES (3505, 17, 1, 'RSCDS CD-4', 1995, 1);
INSERT INTO 'media' VALUES (3506, 18, 1, 'RSCDS CD-5', 1995, 1);
INSERT INTO 'media' VALUES (3507, 19, 3, 'TRPS1', 1994, 1);
INSERT INTO 'media' VALUES (3508, 19, 1, 'TERPSCD', 1994, 1);
INSERT INTO 'media' VALUES (3509, 20, 3, '', 1996, 1);
INSERT INTO 'media' VALUES (3510, 20, 1, 'RSCDS CD-7', 1996, 1);
INSERT INTO 'media' VALUES (3511, 21, 2, 'ITV 491', 1989, 1);
INSERT INTO 'media' VALUES (3512, 21, 3, 'KITV 491', 1989, 1);
INSERT INTO 'media' VALUES (3513, 21, 1, 'CDITV 491', 1989, 1);
INSERT INTO 'media' VALUES (3514, 22, 3, 'SRC001', 1996, 1);
INSERT INTO 'media' VALUES (3515, 22, 1, 'SRCD001', 1996, 1);
INSERT INTO 'media' VALUES (3516, 23, 3, '', 1997, 1);
INSERT INTO 'media' VALUES (3517, 23, 1, 'CC264', 1997, 1);
INSERT INTO 'media' VALUES (3518, 24, 1, 'LC04664', 1997, 1);
INSERT INTO 'media' VALUES (3519, 25, 1, 'RSCDS CD-2', 1993, 1);
INSERT INTO 'media' VALUES (3521, 27, 3, 'LDDC8005', 1988, 1);
INSERT INTO 'media' VALUES (3522, 27, 1, 'LCOM9007', 1988, 1);
INSERT INTO 'media' VALUES (3523, 28, 3, 'EWO001C', 1995, 1);
INSERT INTO 'media' VALUES (3524, 28, 1, 'EWO001CD', 1995, 1);
INSERT INTO 'media' VALUES (3525, 29, 3, 'DACS9614', 1996, 1);
INSERT INTO 'media' VALUES (3526, 29, 1, 'DACD9614', 1996, 1);
INSERT INTO 'media' VALUES (3527, 30, 3, 'DIH001C', 1995, 1);
INSERT INTO 'media' VALUES (3528, 30, 1, 'DIH001CD', 1995, 1);
INSERT INTO 'media' VALUES (3529, 31, 3, 'GCDC942', 1994, 1);
INSERT INTO 'media' VALUES (3530, 31, 1, 'GCD 942', 1994, 1);
INSERT INTO 'media' VALUES (3531, 32, 3, 'AD010', 0, 0);
INSERT INTO 'media' VALUES (3532, 33, 2, 'SZLP 2125', 0, 1);
INSERT INTO 'media' VALUES (3533, 33, 3, 'GRTC37', 0, 1);
INSERT INTO 'media' VALUES (3534, 33, 1, 'GRCD37', 0, 1);
INSERT INTO 'media' VALUES (3535, 34, 2, 'RSCDS 5', 0, 1);
INSERT INTO 'media' VALUES (3536, 34, 3, 'RSCDS 5', 0, 1);
INSERT INTO 'media' VALUES (3537, 34, 1, 'RSCDS017', 0, 1);
INSERT INTO 'media' VALUES (3538, 35, 3, 'SS 5', 0, 1);
INSERT INTO 'media' VALUES (3539, 35, 1, 'SSCD 11', 0, 1);
INSERT INTO 'media' VALUES (3540, 36, 3, '', 1997, 0);
INSERT INTO 'media' VALUES (3541, 37, 3, 'HRMMC555', 1996, 1);
INSERT INTO 'media' VALUES (3542, 37, 1, 'HRMCD555', 1996, 1);
INSERT INTO 'media' VALUES (3543, 38, 1, 'CDLANG001', 0, 1);
INSERT INTO 'media' VALUES (3544, 39, 3, 'GRTC 48', 1991, 1);
INSERT INTO 'media' VALUES (3545, 39, 1, 'GRCD 48', 1991, 1);
INSERT INTO 'media' VALUES (3546, 40, 3, 'GCD 921', 1992, 1);
INSERT INTO 'media' VALUES (3547, 40, 1, 'HRMCD556', 1992, 1);
INSERT INTO 'media' VALUES (3548, 41, 3, 'SS 9', 1994, 0);
INSERT INTO 'media' VALUES (3549, 42, 3, 'TC RSCDS 51', 1995, 1);
INSERT INTO 'media' VALUES (3550, 42, 1, 'CD040', 1995, 1);
INSERT INTO 'media' VALUES (3551, 43, 2, 'RSCDS 49', 1994, 0);
INSERT INTO 'media' VALUES (3552, 43, 3, 'TC RSCDS 50', 1994, 0);
INSERT INTO 'media' VALUES (3553, 44, 2, 'RSCDS 34', 1990, 1);
INSERT INTO 'media' VALUES (4366, 326, 1, 'BRHCD59', 2011, 1);
INSERT INTO 'media' VALUES (4367, 1017, 1, 'SSCD sampler', 2011, 1);
INSERT INTO 'media' VALUES (4368, 197, 1, 'BRHCD58', 2012, 1);
INSERT INTO 'media' VALUES (4369, 249, 1, 'BRHCD61', 2012, 1);
INSERT INTO 'media' VALUES (4370, 1018, 1, 'BRHCD62', 2012, 1);
INSERT INTO 'media' VALUES (4371, 1019, 1, 'SSCD29', 2011, 1);
INSERT INTO 'media' VALUES (4372, 1020, 1, 'SSCD30', 2011, 1);
INSERT INTO 'media' VALUES (4373, 1021, 1, 'LBSDB03', 2012, 1);
INSERT INTO 'media' VALUES (4374, 1022, 1, 'BERK001', 2011, 1);
INSERT INTO 'media' VALUES (4375, 1023, 1, 'IMB008', 2012, 1);
INSERT INTO 'media' VALUES (4376, 1025, 1, 'CD071', 2012, 1);
INSERT INTO 'media' VALUES (3520, 26, 1, 'RSCDS CD-6', 1996, 0);
INSERT INTO 'media' VALUES (4377, 1026, 1, 'SSCD26', 2012, 1);
INSERT INTO 'media' VALUES (4378, 1027, 1, 'SSCD27', 2012, 1);
INSERT INTO 'media' VALUES (4379, 1028, 1, 'SSCD28', 2012, 1);
INSERT INTO 'media' VALUES (4380, 1029, 1, 'CB01', 2011, 1);
INSERT INTO 'media' VALUES (4381, 1030, 1, 'GLRCD03', 2006, 1);
INSERT INTO 'media' VALUES (4382, 1031, 1, 'BG-DW01-CDA', 2007, 1);
INSERT INTO 'media' VALUES (4383, 1032, 1, 'CD073', 2012, 1);
INSERT INTO 'media' VALUES (4384, 1033, 1, 'S22A017', 2012, 1);
INSERT INTO 'media' VALUES (4385, 1034, 1, 'CDTRAX371', 2012, 1);
INSERT INTO 'media' VALUES (4386, 827, 1, 'BRHCD71', 2012, 1);
INSERT INTO 'media' VALUES (4471, 1109, 1, 'MDM001', 2014, NULL);
INSERT INTO 'media' VALUES (4388, 1036, 1, 'WAX02', 2012, 1);
INSERT INTO 'media' VALUES (4389, 1037, 1, 'HRMCD012', 2005, 1);
INSERT INTO 'media' VALUES (4390, 1038, 1, 'BRHCD63', 2012, 1);
INSERT INTO 'media' VALUES (4391, 1039, 1, 'MAC2', 2011, 1);
INSERT INTO 'media' VALUES (4392, 1040, 1, 'HRMCD019', 2010, 1);
INSERT INTO 'media' VALUES (4395, 1043, 1, 'BRHCD80', 2012, 1);
INSERT INTO 'media' VALUES (4396, 1044, 1, 'BRHCD79', 2012, 1);
INSERT INTO 'media' VALUES (4397, 1045, 1, 'BRHCD77', 2012, 1);
INSERT INTO 'media' VALUES (4398, 1046, 1, 'BRHCD72', 2012, 1);
INSERT INTO 'media' VALUES (4399, 1047, 1, 'HIMDFCD001', 2012, 1);
INSERT INTO 'media' VALUES (4400, 1048, 1, 'BRHCD76', 2012, 1);
INSERT INTO 'media' VALUES (4402, 1049, 1, 'BRHCD75', 2012, 1);
INSERT INTO 'media' VALUES (4404, 1050, 1, 'CDTRAX369', 2012, 1);
INSERT INTO 'media' VALUES (3554, 44, 3, 'TC RSCDS 34', 1990, 1);
INSERT INTO 'media' VALUES (3555, 45, 3, 'JMLC 101', 1990, 0);
INSERT INTO 'media' VALUES (3556, 46, 3, 'SS 6', 1991, 0);
INSERT INTO 'media' VALUES (3557, 47, 3, 'SS 8', 1993, 0);
INSERT INTO 'media' VALUES (3558, 48, 3, 'SS 7', 1992, 1);
INSERT INTO 'media' VALUES (3559, 48, 1, 'SSCD 12', 1992, 1);
INSERT INTO 'media' VALUES (3560, 49, 2, 'RSCDS 46', 1993, 1);
INSERT INTO 'media' VALUES (3561, 49, 3, 'TC RSCDS 47', 1993, 1);
INSERT INTO 'media' VALUES (3562, 49, 1, 'CD049', 1993, 1);
INSERT INTO 'media' VALUES (3563, 50, 2, 'RSCDS 45', 1992, 1);
INSERT INTO 'media' VALUES (3564, 50, 3, 'TC RSCDS 45', 1992, 1);
INSERT INTO 'media' VALUES (3565, 51, 3, 'DACS 9208', 1992, 0);
INSERT INTO 'media' VALUES (3566, 52, 3, 'NRSCDS 106', 1991, 0);
INSERT INTO 'media' VALUES (3567, 53, 2, 'LILP 5112', 1981, 0);
INSERT INTO 'media' VALUES (3568, 53, 3, 'LICS 5112', 1981, 0);
INSERT INTO 'media' VALUES (3569, 54, 3, 'SS 4', 1990, 0);
INSERT INTO 'media' VALUES (3570, 55, 2, 'RSCDS 36', 1990, 0);
INSERT INTO 'media' VALUES (3571, 55, 3, 'TC-RSCDS 36', 1990, 0);
INSERT INTO 'media' VALUES (3572, 56, 2, 'RSCDS 28', 1988, 0);
INSERT INTO 'media' VALUES (3573, 56, 3, 'RSCDS 28', 1988, 0);
INSERT INTO 'media' VALUES (3574, 57, 2, 'RSCDS 18', 1985, 1);
INSERT INTO 'media' VALUES (3575, 57, 3, 'RSCDS 18', 1985, 1);
INSERT INTO 'media' VALUES (3576, 58, 3, 'TC RSCDS 43', 1991, 0);
INSERT INTO 'media' VALUES (3577, 59, 2, 'RSCDS 42', 1991, 0);
INSERT INTO 'media' VALUES (3578, 59, 3, 'TC RSCDS 42', 1991, 0);
INSERT INTO 'media' VALUES (3579, 60, 2, 'RSCDS 31', 1989, 0);
INSERT INTO 'media' VALUES (3580, 60, 3, 'RSCDS 31', 1989, 0);
INSERT INTO 'media' VALUES (3581, 61, 3, 'CRY 101', 1993, 0);
INSERT INTO 'media' VALUES (3582, 62, 3, 'SC02', 1992, 0);
INSERT INTO 'media' VALUES (3583, 63, 2, 'RSCDS 26', 1988, 0);
INSERT INTO 'media' VALUES (3584, 63, 3, 'RSCDS 26', 1988, 0);
INSERT INTO 'media' VALUES (4393, 1041, 1, 'THISTLE107', 2006, 1);
INSERT INTO 'media' VALUES (3585, 64, 2, 'NRCDS 107', 1993, 1);
INSERT INTO 'media' VALUES (4472, 1111, 1, '', 2018, NULL);
INSERT INTO 'media' VALUES (3586, 64, 3, 'NRSCDS 107', 1993, 1);
INSERT INTO 'media' VALUES (3587, 65, 3, 'TC RSCDS 52', 1996, 1);
INSERT INTO 'media' VALUES (3588, 65, 1, 'RSCDS019', 1996, 1);
INSERT INTO 'media' VALUES (3589, 66, 3, 'RSCDS 37', 1990, 1);
INSERT INTO 'media' VALUES (3592, 68, 2, 'RSCDS 23', 1986, 1);
INSERT INTO 'media' VALUES (3593, 68, 3, 'TC RSCDS 23', 1986, 1);
INSERT INTO 'media' VALUES (3594, 69, 2, 'RSCDS 21', 1986, 1);
INSERT INTO 'media' VALUES (3595, 69, 3, 'TC-RSCDS 21', 1986, 1);
INSERT INTO 'media' VALUES (3596, 69, 1, 'CD030', 1986, 1);
INSERT INTO 'media' VALUES (3597, 70, 3, 'SHIELMC001', 1997, 1);
INSERT INTO 'media' VALUES (3598, 70, 1, 'SHIELCD001', 1997, 1);
INSERT INTO 'media' VALUES (3599, 71, 3, 'SRMC002', 1997, 1);
INSERT INTO 'media' VALUES (3600, 71, 1, 'SRCD002', 1997, 1);
INSERT INTO 'media' VALUES (3601, 72, 3, 'FAC CS134', 1992, 1);
INSERT INTO 'media' VALUES (3602, 72, 1, 'FAC CD134', 1992, 1);
INSERT INTO 'media' VALUES (3603, 73, 3, 'DLR C2', 1997, 1);
INSERT INTO 'media' VALUES (3604, 73, 1, 'DLR D2', 1997, 1);
INSERT INTO 'media' VALUES (3605, 74, 3, 'F&I101', 1992, 1);
INSERT INTO 'media' VALUES (3606, 74, 1, 'F&I 101', 1992, 1);
INSERT INTO 'media' VALUES (3607, 75, 3, 'TC RSCDS 55', 2002, 1);
INSERT INTO 'media' VALUES (3608, 75, 1, 'RSCDS CD027', 2002, 1);
INSERT INTO 'media' VALUES (3609, 76, 3, 'TC RSCDS 56', 1997, 1);
INSERT INTO 'media' VALUES (3610, 76, 1, 'RSCDS022', 1997, 1);
INSERT INTO 'media' VALUES (3611, 77, 3, 'TC595', 1995, 1);
INSERT INTO 'media' VALUES (3612, 77, 1, 'TRCD9801', 1995, 1);
INSERT INTO 'media' VALUES (3613, 78, 2, 'RSCDS 11', 1982, 0);
INSERT INTO 'media' VALUES (3614, 78, 3, 'C-RSCDS 11', 1982, 0);
INSERT INTO 'media' VALUES (3615, 79, 2, 'RSCDS 16', 1986, 1);
INSERT INTO 'media' VALUES (3616, 79, 3, 'TC RSCDS 16', 1986, 1);
INSERT INTO 'media' VALUES (3617, 79, 1, 'RSCDSCD038', 1986, 1);
INSERT INTO 'media' VALUES (3618, 80, 2, 'RSCDS 19', 1985, 0);
INSERT INTO 'media' VALUES (3619, 80, 3, 'C-RSCDS 19', 1985, 0);
INSERT INTO 'media' VALUES (3620, 81, 1, 'EBCD001', 1997, 1);
INSERT INTO 'media' VALUES (3621, 82, 3, 'DACS9716', 1997, 1);
INSERT INTO 'media' VALUES (3590, 67, 2, 'RSCDS 48', 0, 0);
INSERT INTO 'media' VALUES (3591, 67, 3, 'TC RSCDS 48', 0, 0);
INSERT INTO 'media' VALUES (4403, 210, 1, 'BRHCD74', 2012, 1);
INSERT INTO 'media' VALUES (3622, 82, 1, 'DACD9716', 1997, 1);
INSERT INTO 'media' VALUES (3623, 83, 3, 'SKYE01', 0, 0);
INSERT INTO 'media' VALUES (3625, 84, 1, 'SSCD 01', 0, 1);
INSERT INTO 'media' VALUES (3628, 86, 2, 'JW 001', 1984, 1);
INSERT INTO 'media' VALUES (3629, 86, 3, 'CJW 001', 1984, 1);
INSERT INTO 'media' VALUES (3630, 87, 2, 'WGR066', 1961, 1);
INSERT INTO 'media' VALUES (3631, 87, 3, 'CWGR066', 1961, 1);
INSERT INTO 'media' VALUES (3632, 88, 3, 'CD1031CAS', 1993, 1);
INSERT INTO 'media' VALUES (3633, 88, 1, 'CD1031', 1993, 1);
INSERT INTO 'media' VALUES (3634, 89, 3, 'TC1026', 1992, 1);
INSERT INTO 'media' VALUES (3635, 90, 3, 'DACS9411', 1994, 0);
INSERT INTO 'media' VALUES (3636, 91, 2, '', 0, 0);
INSERT INTO 'media' VALUES (3637, 92, 3, 'CWGR131', 1989, 1);
INSERT INTO 'media' VALUES (3638, 93, 3, 'CWGR022', 0, 0);
INSERT INTO 'media' VALUES (3639, 94, 2, 'BRG 001', 1979, 1);
INSERT INTO 'media' VALUES (3640, 94, 3, 'CWGR033', 1979, 1);
INSERT INTO 'media' VALUES (3641, 95, 2, 'BRG 002', 1980, 1);
INSERT INTO 'media' VALUES (3642, 95, 3, 'CWGR034', 1980, 1);
INSERT INTO 'media' VALUES (3643, 96, 2, 'BRG-003', 1981, 1);
INSERT INTO 'media' VALUES (3644, 96, 3, 'CWGR035', 1981, 1);
INSERT INTO 'media' VALUES (3645, 97, 1, 'SAB 200', 0, 1);
INSERT INTO 'media' VALUES (3646, 98, 2, '583 018', 1967, 0);
INSERT INTO 'media' VALUES (3647, 99, 1, 'GRACC27', 1994, 1);
INSERT INTO 'media' VALUES (3648, 100, 3, 'TC1004', 1981, 1);
INSERT INTO 'media' VALUES (3649, 101, 3, 'TC1005', 1982, 1);
INSERT INTO 'media' VALUES (3650, 102, 3, 'TC1010', 1989, 1);
INSERT INTO 'media' VALUES (3651, 103, 2, 'JMLC 102', 1993, 1);
INSERT INTO 'media' VALUES (3652, 103, 3, 'JMLC 102', 1993, 1);
INSERT INTO 'media' VALUES (3653, 103, 1, 'TRCD 9701', 1993, 1);
INSERT INTO 'media' VALUES (3654, 104, 2, 'RSCDS 22', 1986, 1);
INSERT INTO 'media' VALUES (3655, 104, 3, '', 1986, 1);
INSERT INTO 'media' VALUES (3656, 105, 2, 'RSCDS 9', 1987, 1);
INSERT INTO 'media' VALUES (3657, 105, 3, '', 1987, 1);
INSERT INTO 'media' VALUES (3658, 106, 2, 'RSCDS 10', 1987, 1);
INSERT INTO 'media' VALUES (3659, 106, 3, '', 1987, 1);
INSERT INTO 'media' VALUES (3660, 107, 2, 'RSCDS 27', 1988, 1);
INSERT INTO 'media' VALUES (3661, 107, 3, 'RSCDS 27', 1988, 1);
INSERT INTO 'media' VALUES (3662, 108, 2, 'RSCDS 29', 1988, 0);
INSERT INTO 'media' VALUES (3663, 108, 3, 'RSCDS 29', 1988, 0);
INSERT INTO 'media' VALUES (3664, 109, 2, 'RSCDS 30', 1988, 1);
INSERT INTO 'media' VALUES (3665, 109, 3, '', 1988, 1);
INSERT INTO 'media' VALUES (3666, 110, 2, 'RSCDS 35', 1990, 1);
INSERT INTO 'media' VALUES (3667, 110, 3, '', 1990, 1);
INSERT INTO 'media' VALUES (3668, 111, 3, 'TC RSCDS 53', 1996, 1);
INSERT INTO 'media' VALUES (3669, 112, 3, 'RSCDS54', 1996, 1);
INSERT INTO 'media' VALUES (3670, 113, 2, 'ZRS 8009', 1975, 1);
INSERT INTO 'media' VALUES (3671, 113, 3, 'RSCDS 1', 1975, 1);
INSERT INTO 'media' VALUES (3672, 114, 2, 'RSCDS 2', 1977, 1);
INSERT INTO 'media' VALUES (3673, 114, 3, '', 1977, 1);
INSERT INTO 'media' VALUES (3674, 114, 1, 'CD052', 1977, 1);
INSERT INTO 'media' VALUES (3675, 115, 2, 'RSCDS 4', 2002, 1);
INSERT INTO 'media' VALUES (3676, 115, 3, '', 2002, 1);
INSERT INTO 'media' VALUES (3677, 115, 1, 'RSCDS CD031', 2002, 1);
INSERT INTO 'media' VALUES (3678, 116, 2, 'RSCDS 6', 0, 1);
INSERT INTO 'media' VALUES (3679, 116, 3, '', 0, 1);
INSERT INTO 'media' VALUES (3680, 117, 2, 'RSCDS 12', 1983, 1);
INSERT INTO 'media' VALUES (3681, 117, 3, '', 1983, 1);
INSERT INTO 'media' VALUES (3684, 118, 1, 'RSCDS023', 0, 1);
INSERT INTO 'media' VALUES (3685, 119, 2, 'RSCDS 17', 1984, 0);
INSERT INTO 'media' VALUES (3686, 119, 3, 'RSCDS 17', 1984, 0);
INSERT INTO 'media' VALUES (3687, 120, 2, 'RSCDS 13', 1983, 1);
INSERT INTO 'media' VALUES (3688, 120, 3, 'RSCDS 13', 1983, 1);
INSERT INTO 'media' VALUES (3689, 121, 2, 'RSCDS 25', 1987, 1);
INSERT INTO 'media' VALUES (3690, 121, 3, 'RSCDS 25', 1987, 1);
INSERT INTO 'media' VALUES (3624, 84, 3, 'SS10', 0, NULL);
INSERT INTO 'media' VALUES (3691, 122, 2, 'RSCDS 7', 1981, 0);
INSERT INTO 'media' VALUES (3692, 122, 3, 'RSCDS 7', 1981, 0);
INSERT INTO 'media' VALUES (3693, 123, 2, 'RSCDS 3', 1978, 0);
INSERT INTO 'media' VALUES (3694, 123, 3, 'C-RSCDS 3', 1978, 0);
INSERT INTO 'media' VALUES (3695, 124, 2, 'BBL 7376', 0, 0);
INSERT INTO 'media' VALUES (3696, 125, 3, 'WRC4-6641', 0, 1);
INSERT INTO 'media' VALUES (3697, 126, 2, 'Cabbage 101', 1976, 1);
INSERT INTO 'media' VALUES (3698, 126, 1, 'FAC CD 401', 1976, 1);
INSERT INTO 'media' VALUES (3699, 127, 3, 'SS2', 1989, 1);
INSERT INTO 'media' VALUES (3700, 128, 2, 'SC3', 1988, 0);
INSERT INTO 'media' VALUES (3701, 129, 2, 'LILP 5141', 1985, 1);
INSERT INTO 'media' VALUES (3702, 129, 3, 'LICS 5141', 1985, 1);
INSERT INTO 'media' VALUES (3703, 130, 2, '6174', 0, 0);
INSERT INTO 'media' VALUES (3704, 131, 3, 'LB.2', 0, 1);
INSERT INTO 'media' VALUES (3705, 132, 2, 'EO 838', 1988, 0);
INSERT INTO 'media' VALUES (3706, 133, 2, 'FR LP 42', 0, 0);
INSERT INTO 'media' VALUES (3707, 134, 2, 'BBR/LP 110', 1978, 0);
INSERT INTO 'media' VALUES (3708, 135, 2, 'PAD 101', 1987, 1);
INSERT INTO 'media' VALUES (3709, 135, 3, 'PAD 101', 1987, 1);
INSERT INTO 'media' VALUES (3710, 136, 2, 'LHR LP6', 1977, 0);
INSERT INTO 'media' VALUES (3711, 137, 2, 'BSLP 104 S', 0, 1);
INSERT INTO 'media' VALUES (3712, 138, 2, 'BSLP 122 S', 0, 1);
INSERT INTO 'media' VALUES (3713, 139, 2, 'BSLP 113 S', 0, 1);
INSERT INTO 'media' VALUES (3714, 140, 2, 'BSLP 66', 2011, 0);
INSERT INTO 'media' VALUES (3716, 141, 2, 'ITV 517', 1979, 0);
INSERT INTO 'media' VALUES (3717, 142, 2, 'ACL 7711', 0, 0);
INSERT INTO 'media' VALUES (3718, 143, 2, 'NRSCDS 102', 1976, 1);
INSERT INTO 'media' VALUES (3719, 143, 3, 'NRCDS102', 1976, 1);
INSERT INTO 'media' VALUES (3720, 144, 2, 'NRSCDS 103', 1979, 0);
INSERT INTO 'media' VALUES (3721, 145, 2, 'FR LP 43', 1990, 0);
INSERT INTO 'media' VALUES (3722, 145, 3, '', 1990, 0);
INSERT INTO 'media' VALUES (3723, 146, 3, 'TAC 006C', 0, 1);
INSERT INTO 'media' VALUES (3724, 146, 1, 'TAC 006CD', 0, 1);
INSERT INTO 'media' VALUES (3725, 147, 2, 'NRSCDS 105', 1983, 0);
INSERT INTO 'media' VALUES (3726, 148, 3, 'CB40X1', 1992, 1);
INSERT INTO 'media' VALUES (3727, 149, 2, 'LHR LP4', 1976, 0);
INSERT INTO 'media' VALUES (3728, 150, 2, 'BSLP 67', 0, 1);
INSERT INTO 'media' VALUES (3729, 150, 1, 'THISTLE106', 0, 1);
INSERT INTO 'media' VALUES (3730, 151, 2, 'WAV 25012', 0, 0);
INSERT INTO 'media' VALUES (3731, 153, 2, 'RGSCD 101', 1983, 0);
INSERT INTO 'media' VALUES (3732, 154, 2, 'SNC 7102', 0, 0);
INSERT INTO 'media' VALUES (3733, 155, 3, 'SRCM 148', 1986, 0);
INSERT INTO 'media' VALUES (3734, 156, 2, '33SR 152', 1975, 0);
INSERT INTO 'media' VALUES (3735, 157, 1, '', 1998, 1);
INSERT INTO 'media' VALUES (3736, 158, 3, 'SRCM 008', 1973, 0);
INSERT INTO 'media' VALUES (3737, 159, 3, 'WRA4-586', 1988, 0);
INSERT INTO 'media' VALUES (3739, 161, 2, 'LILP 5175', 1989, 0);
INSERT INTO 'media' VALUES (3740, 161, 3, 'LILP 5175', 1989, 0);
INSERT INTO 'media' VALUES (3741, 163, 2, 'FLPS 1824', 1972, 0);
INSERT INTO 'media' VALUES (3742, 164, 2, 'ZLP 2099', 1967, 0);
INSERT INTO 'media' VALUES (3743, 165, 2, 'TAC002', 1979, 1);
INSERT INTO 'media' VALUES (3745, 166, 2, 'TAC001', 1978, 1);
INSERT INTO 'media' VALUES (3747, 167, 2, 'TAC 004', 1986, 0);
INSERT INTO 'media' VALUES (3748, 168, 1, 'WHITECD1', 1997, 1);
INSERT INTO 'media' VALUES (3749, 169, 2, 'CB2', 1989, 0);
INSERT INTO 'media' VALUES (3750, 169, 3, 'CB2C', 1989, 0);
INSERT INTO 'media' VALUES (3753, 171, 2, 'INTS 1321', 1971, 0);
INSERT INTO 'media' VALUES (3754, 172, 2, 'BSLP 105S', 0, 0);
INSERT INTO 'media' VALUES (3755, 174, 2, 'WAV 25014', 1967, 0);
INSERT INTO 'media' VALUES (3756, 175, 3, 'Cabbage 417C', 1986, 0);
INSERT INTO 'media' VALUES (3757, 176, 2, 'GMHC86/1', 1986, 1);
INSERT INTO 'media' VALUES (3758, 176, 1, 'BRG022-CD', 1986, 1);
INSERT INTO 'media' VALUES (3715, 140, 1, 'BRHCD57 (Let''s Go Scottish Country Dancing)', 2011, 1);
INSERT INTO 'media' VALUES (3738, 160, 3, 'SS1', 0, 0);
INSERT INTO 'media' VALUES (3744, 165, 1, 'TAC002CD', 1979, 1);
INSERT INTO 'media' VALUES (3746, 166, 1, 'TAC001CD', 1978, 1);
INSERT INTO 'media' VALUES (3759, 177, 2, 'BRG017', 0, 1);
INSERT INTO 'media' VALUES (3760, 178, 2, 'YPRX 2158', 1983, 0);
INSERT INTO 'media' VALUES (3761, 179, 2, 'Cabbage 402', 1978, 0);
INSERT INTO 'media' VALUES (3762, 180, 2, 'BSLP 71', 0, 0);
INSERT INTO 'media' VALUES (3763, 181, 2, 'TL5279', 0, 0);
INSERT INTO 'media' VALUES (3764, 182, 2, 'SDL-004', 1967, 0);
INSERT INTO 'media' VALUES (3765, 182, 3, 'SRCM004', 1967, 0);
INSERT INTO 'media' VALUES (3766, 183, 2, 'ZLP 2087', 1967, 0);
INSERT INTO 'media' VALUES (3767, 184, 2, 'BSLP 107S', 0, 0);
INSERT INTO 'media' VALUES (3768, 185, 2, 'LDN 453', 0, 0);
INSERT INTO 'media' VALUES (3769, 186, 1, '', 0, 1);
INSERT INTO 'media' VALUES (3770, 187, 1, 'CC218', 0, 1);
INSERT INTO 'media' VALUES (3771, 188, 1, '72438298820', 1994, 1);
INSERT INTO 'media' VALUES (3772, 189, 2, 'LILP 5120', 1982, 1);
INSERT INTO 'media' VALUES (3773, 189, 3, 'LICS 5120', 1982, 1);
INSERT INTO 'media' VALUES (3774, 191, 2, 'AB 008', 1986, 0);
INSERT INTO 'media' VALUES (3775, 192, 3, 'Duns 01', 1995, 1);
INSERT INTO 'media' VALUES (3776, 193, 2, 'STAL 5001', 1967, 1);
INSERT INTO 'media' VALUES (3777, 193, 3, 'ZCLLS706', 1967, 1);
INSERT INTO 'media' VALUES (3778, 194, 2, 'LILP5097', 1979, 1);
INSERT INTO 'media' VALUES (3779, 194, 3, 'LICS5097', 1979, 1);
INSERT INTO 'media' VALUES (3780, 195, 2, 'LHCLP7', 1984, 1);
INSERT INTO 'media' VALUES (3781, 195, 3, 'LHCCT7', 1984, 1);
INSERT INTO 'media' VALUES (3782, 196, 2, 'LRD 1001', 1978, 0);
INSERT INTO 'media' VALUES (3783, 197, 2, 'BSLP 118S', 0, 0);
INSERT INTO 'media' VALUES (3784, 198, 2, 'TAC005R', 1991, 1);
INSERT INTO 'media' VALUES (3785, 198, 3, 'TAC005C', 1991, 1);
INSERT INTO 'media' VALUES (3786, 198, 1, 'TAC005CD', 1991, 1);
INSERT INTO 'media' VALUES (3787, 199, 1, 'BRG 020-CD', 1998, 1);
INSERT INTO 'media' VALUES (3788, 200, 1, 'EWO-002', 1998, 1);
INSERT INTO 'media' VALUES (3789, 201, 2, 'BBR/LP 119', 1979, 0);
INSERT INTO 'media' VALUES (3790, 202, 2, 'TRC1035', 1971, 0);
INSERT INTO 'media' VALUES (3791, 203, 2, 'Cabbage 405', 1979, 0);
INSERT INTO 'media' VALUES (3792, 204, 2, 'WRC1-2626', 1982, 0);
INSERT INTO 'media' VALUES (3793, 205, 2, 'REL 461', 1977, 0);
INSERT INTO 'media' VALUES (3794, 206, 2, 'TAC003', 0, 1);
INSERT INTO 'media' VALUES (3795, 206, 1, 'TAC003CD', 0, 1);
INSERT INTO 'media' VALUES (3796, 207, 2, 'FE 029', 0, 1);
INSERT INTO 'media' VALUES (3797, 208, 1, 'CRC101', 0, 1);
INSERT INTO 'media' VALUES (3798, 209, 1, 'SFCD1', 1997, 1);
INSERT INTO 'media' VALUES (3799, 210, 2, 'BSLP 76', 0, 0);
INSERT INTO 'media' VALUES (3800, 211, 1, 'IRCD021', 1992, 1);
INSERT INTO 'media' VALUES (3801, 212, 2, 'OU 2107', 1976, 0);
INSERT INTO 'media' VALUES (3802, 213, 3, 'LICS5190', 1995, 1);
INSERT INTO 'media' VALUES (3803, 213, 1, 'LCOM5190', 1995, 1);
INSERT INTO 'media' VALUES (3804, 214, 2, 'GES 1055', 1971, 0);
INSERT INTO 'media' VALUES (3805, 215, 3, 'RSCDS8', 1983, 1);
INSERT INTO 'media' VALUES (3806, 216, 2, 'AB001', 1982, 0);
INSERT INTO 'media' VALUES (3807, 217, 1, 'KICC 5145', 1987, 1);
INSERT INTO 'media' VALUES (3808, 218, 2, 'AB007', 0, 0);
INSERT INTO 'media' VALUES (3809, 219, 3, 'AB009C', 1988, 0);
INSERT INTO 'media' VALUES (3810, 220, 2, 'SP 214', 0, 0);
INSERT INTO 'media' VALUES (3811, 221, 2, 'SMT 70-29', 0, 0);
INSERT INTO 'media' VALUES (3812, 222, 2, 'SMT7030', 0, 0);
INSERT INTO 'media' VALUES (3813, 223, 2, 'SMT7031', 0, 0);
INSERT INTO 'media' VALUES (3814, 224, 2, 'SMT 70-2', 1970, 0);
INSERT INTO 'media' VALUES (3815, 225, 2, 'LBLP 2005', 0, 0);
INSERT INTO 'media' VALUES (3816, 225, 3, 'ZCLBP 2005', 0, 0);
INSERT INTO 'media' VALUES (3817, 226, 3, '', 0, 0);
INSERT INTO 'media' VALUES (3818, 227, 2, 'LILP 5029', 1975, 0);
INSERT INTO 'media' VALUES (3819, 227, 3, 'LICS5029', 1975, 0);
INSERT INTO 'media' VALUES (3820, 228, 2, 'SC2', 1986, 0);
INSERT INTO 'media' VALUES (3821, 229, 3, 'IM OX2', 1994, 1);
INSERT INTO 'media' VALUES (3822, 230, 2, 'SC1', 0, 0);
INSERT INTO 'media' VALUES (3823, 230, 3, 'SC1', 0, 0);
INSERT INTO 'media' VALUES (3824, 231, 2, 'BSLP 94', 0, 0);
INSERT INTO 'media' VALUES (3825, 232, 3, '', 1987, 1);
INSERT INTO 'media' VALUES (3828, 234, 3, 'TC RSCDS 15', 1983, 0);
INSERT INTO 'media' VALUES (3829, 235, 3, 'RSCDS 39', 1990, 1);
INSERT INTO 'media' VALUES (3830, 236, 3, 'LB1', 1987, 0);
INSERT INTO 'media' VALUES (3831, 237, 3, 'GRC02C', 1982, 1);
INSERT INTO 'media' VALUES (3832, 238, 2, 'GH-100', 0, 0);
INSERT INTO 'media' VALUES (3833, 239, 2, 'BSLP 112s', 0, 1);
INSERT INTO 'media' VALUES (3834, 240, 2, '1008', 0, 0);
INSERT INTO 'media' VALUES (3835, 241, 2, 'SRC01', 1978, 0);
INSERT INTO 'media' VALUES (3836, 241, 3, 'SRC01', 1978, 0);
INSERT INTO 'media' VALUES (3837, 242, 3, 'AB015C', 1991, 0);
INSERT INTO 'media' VALUES (3838, 243, 2, 'BSLP 123S', 0, 0);
INSERT INTO 'media' VALUES (3839, 244, 1, 'BBC CD 762', 1989, 1);
INSERT INTO 'media' VALUES (3840, 245, 2, 'LHC LP5', 1977, 0);
INSERT INTO 'media' VALUES (3841, 246, 2, 'GES 1141', 1976, 0);
INSERT INTO 'media' VALUES (3842, 247, 2, 'PMC 1144', 1961, 0);
INSERT INTO 'media' VALUES (3843, 248, 2, 'MFS 768', 1975, 0);
INSERT INTO 'media' VALUES (3845, 250, 2, 'IA3032', 0, 0);
INSERT INTO 'media' VALUES (3846, 251, 2, 'LSA3110', 1972, 0);
INSERT INTO 'media' VALUES (3847, 252, 1, 'KCN 001', 1997, 1);
INSERT INTO 'media' VALUES (3848, 253, 2, 'SLC-142', 1976, 0);
INSERT INTO 'media' VALUES (3849, 254, 1, 'SW01', 1999, 1);
INSERT INTO 'media' VALUES (3850, 255, 2, 'CSPS 1834', 0, 1);
INSERT INTO 'media' VALUES (3851, 255, 3, 'GMI 001C', 0, 1);
INSERT INTO 'media' VALUES (3852, 256, 2, 'RRLP 00831', 0, 0);
INSERT INTO 'media' VALUES (3853, 256, 3, 'RRCS 00831', 0, 0);
INSERT INTO 'media' VALUES (3854, 257, 2, 'HES 6018', 1968, 0);
INSERT INTO 'media' VALUES (3855, 258, 3, 'TS1', 1993, 0);
INSERT INTO 'media' VALUES (3856, 259, 2, 'LILP 5107', 1980, 1);
INSERT INTO 'media' VALUES (3857, 259, 3, 'LICS 5107', 1980, 1);
INSERT INTO 'media' VALUES (3858, 259, 1, 'JECB101', 1980, 1);
INSERT INTO 'media' VALUES (3859, 260, 1, 'CUL009D', 0, 1);
INSERT INTO 'media' VALUES (3860, 261, 2, 'LILP5046', 1976, 0);
INSERT INTO 'media' VALUES (3861, 262, 2, 'SW99569', 1976, 0);
INSERT INTO 'media' VALUES (3862, 263, 2, 'STAL 5018', 1971, 0);
INSERT INTO 'media' VALUES (3863, 264, 2, 'EROS 8090', 0, 0);
INSERT INTO 'media' VALUES (3864, 265, 2, 'AS 8208', 0, 0);
INSERT INTO 'media' VALUES (3826, 233, 2, 'CAB420', 1988, 1);
INSERT INTO 'media' VALUES (3865, 266, 2, 'AS 8209', 0, 0);
INSERT INTO 'media' VALUES (3866, 267, 2, 'CSPS 2141', 0, 0);
INSERT INTO 'media' VALUES (3868, 269, 2, 'STAL 5022', 1971, 0);
INSERT INTO 'media' VALUES (3869, 270, 2, 'LILP5059', 1977, 1);
INSERT INTO 'media' VALUES (3870, 270, 3, 'LICS5059', 1977, 1);
INSERT INTO 'media' VALUES (3871, 271, 2, 'WGR 068', 1983, 0);
INSERT INTO 'media' VALUES (3872, 272, 3, 'RSCDS 14', 1983, 0);
INSERT INTO 'media' VALUES (3873, 273, 2, 'SBE 123', 1963, 0);
INSERT INTO 'media' VALUES (3874, 274, 2, 'SBE1005', 1972, 0);
INSERT INTO 'media' VALUES (3875, 275, 2, 'SBE 149', 0, 0);
INSERT INTO 'media' VALUES (3876, 276, 2, 'GES1213', 1979, 0);
INSERT INTO 'media' VALUES (3877, 277, 2, 'SGW5014', 1976, 0);
INSERT INTO 'media' VALUES (3878, 278, 2, 'SLC-110', 0, 0);
INSERT INTO 'media' VALUES (3879, 279, 2, 'LDN 466', 0, 0);
INSERT INTO 'media' VALUES (3880, 280, 2, 'AKM-001', 0, 0);
INSERT INTO 'media' VALUES (3881, 281, 2, 'R.I.M. ZS86', 1971, 0);
INSERT INTO 'media' VALUES (3882, 282, 2, 'GRALP26', 1968, 1);
INSERT INTO 'media' VALUES (3883, 282, 3, 'GRA026', 1968, 1);
INSERT INTO 'media' VALUES (3884, 283, 2, 'GES 1025', 1969, 0);
INSERT INTO 'media' VALUES (3885, 284, 2, 'TFE 17048', 0, 0);
INSERT INTO 'media' VALUES (3886, 285, 2, 'PCS 3007', 1960, 1);
INSERT INTO 'media' VALUES (3887, 285, 1, 'BRH CD42', 1960, 1);
INSERT INTO 'media' VALUES (3888, 286, 3, 'TC CSP101', 0, 0);
INSERT INTO 'media' VALUES (3889, 287, 2, '', 1978, 0);
INSERT INTO 'media' VALUES (3890, 288, 2, 'SR 148', 1966, 0);
INSERT INTO 'media' VALUES (3891, 289, 2, 'PMC1263', 1965, 0);
INSERT INTO 'media' VALUES (3892, 290, 2, 'SZLP 122', 1970, 0);
INSERT INTO 'media' VALUES (3893, 291, 2, 'MFP 5613', 1983, 0);
INSERT INTO 'media' VALUES (3894, 292, 2, 'T10014', 0, 0);
INSERT INTO 'media' VALUES (3895, 293, 2, 'PMC 1069', 1958, 1);
INSERT INTO 'media' VALUES (3844, 249, 2, 'LF18003', 1958, 0);
INSERT INTO 'media' VALUES (3897, 294, 2, 'BSLP 98', 2011, 0);
INSERT INTO 'media' VALUES (3898, 294, 1, 'BRHCD57 (Let''s Go Scottish Country Dancing)', 2011, 0);
INSERT INTO 'media' VALUES (3899, 295, 2, 'BSLP 88', 0, 0);
INSERT INTO 'media' VALUES (3900, 296, 2, 'GES 1049', 1970, 0);
INSERT INTO 'media' VALUES (3901, 297, 2, 'GRALP 5', 1985, 1);
INSERT INTO 'media' VALUES (3902, 297, 3, 'GRTC 5', 1985, 1);
INSERT INTO 'media' VALUES (3903, 298, 2, '104099X', 1981, 0);
INSERT INTO 'media' VALUES (3904, 299, 3, 'CC004C', 1985, 1);
INSERT INTO 'media' VALUES (3905, 300, 2, 'BRG012', 0, 0);
INSERT INTO 'media' VALUES (3906, 301, 2, 'LILP 5158', 1987, 1);
INSERT INTO 'media' VALUES (3907, 301, 3, 'LICS 5158', 1987, 1);
INSERT INTO 'media' VALUES (3908, 302, 2, 'Calclan 006', 1987, 1);
INSERT INTO 'media' VALUES (3909, 302, 3, 'CC006C', 1987, 1);
INSERT INTO 'media' VALUES (3910, 303, 2, 'Calclan 005', 0, 1);
INSERT INTO 'media' VALUES (3911, 303, 3, 'CC005C', 0, 1);
INSERT INTO 'media' VALUES (3912, 304, 2, 'NPL-30080', 0, 0);
INSERT INTO 'media' VALUES (3913, 305, 3, 'SRCM 153', 0, 0);
INSERT INTO 'media' VALUES (3914, 306, 2, 'GMI 001', 0, 0);
INSERT INTO 'media' VALUES (3915, 306, 3, 'CBS 001C', 0, 0);
INSERT INTO 'media' VALUES (3916, 307, 2, 'BSLP 126s', 0, 0);
INSERT INTO 'media' VALUES (3917, 308, 2, 'STAL 5034', 1974, 0);
INSERT INTO 'media' VALUES (3918, 309, 2, 'STAL 5007', 1970, 0);
INSERT INTO 'media' VALUES (3919, 310, 2, 'VRC 1901', 1986, 0);
INSERT INTO 'media' VALUES (3920, 310, 3, 'VRC 1901', 1986, 0);
INSERT INTO 'media' VALUES (3921, 311, 3, 'GSCS 9201', 0, 0);
INSERT INTO 'media' VALUES (3922, 312, 3, '', 0, 0);
INSERT INTO 'media' VALUES (3923, 313, 3, 'BRC 010', 1998, 0);
INSERT INTO 'media' VALUES (3924, 313, 1, 'BRCD010', 1998, 0);
INSERT INTO 'media' VALUES (3925, 314, 3, '', 1989, 0);
INSERT INTO 'media' VALUES (4473, 1110, 1, '', 0, NULL);
INSERT INTO 'media' VALUES (3927, 316, 3, 'LHC CT8', 0, 0);
INSERT INTO 'media' VALUES (3928, 317, 1, 'HRMCD 506', 1999, 1);
INSERT INTO 'media' VALUES (3929, 318, 1, 'HRMCD 507', 1999, 1);
INSERT INTO 'media' VALUES (3930, 319, 3, '', 1998, 1);
INSERT INTO 'media' VALUES (3931, 319, 1, 'TRCD9804', 1998, 1);
INSERT INTO 'media' VALUES (3932, 320, 1, '', 0, 1);
INSERT INTO 'media' VALUES (3933, 321, 2, 'GGL 0348', 1965, 0);
INSERT INTO 'media' VALUES (3934, 322, 1, 'HRMCD508', 1999, 1);
INSERT INTO 'media' VALUES (3935, 323, 1, 'HRMCD509', 1999, 1);
INSERT INTO 'media' VALUES (3936, 324, 1, 'SC05', 1998, 1);
INSERT INTO 'media' VALUES (3937, 325, 1, 'HRMCD510', 1999, 1);
INSERT INTO 'media' VALUES (3938, 326, 2, 'SBE121', 1960, 0);
INSERT INTO 'media' VALUES (3939, 327, 3, 'BBR/C 162', 1987, 0);
INSERT INTO 'media' VALUES (3940, 328, 1, 'SSCD08', 1999, 1);
INSERT INTO 'media' VALUES (3941, 329, 2, 'LHR LP3', 1975, 0);
INSERT INTO 'media' VALUES (3942, 330, 3, '', 0, 1);
INSERT INTO 'media' VALUES (3944, 331, 3, 'MC 415', 1990, 1);
INSERT INTO 'media' VALUES (3945, 331, 1, 'CD 415', 1990, 1);
INSERT INTO 'media' VALUES (3946, 332, 2, 'LILP 5109', 1980, 0);
INSERT INTO 'media' VALUES (3947, 332, 3, '', 1980, 0);
INSERT INTO 'media' VALUES (3948, 333, 3, 'CAB 419C', 1986, 0);
INSERT INTO 'media' VALUES (3949, 334, 3, 'WAB1', 0, 0);
INSERT INTO 'media' VALUES (3950, 335, 2, 'RLP 71', 0, 0);
INSERT INTO 'media' VALUES (3951, 336, 3, 'MC 426', 0, 0);
INSERT INTO 'media' VALUES (3952, 337, 2, 'PMD1015', 0, 0);
INSERT INTO 'media' VALUES (3953, 338, 2, 'PMD1047', 0, 0);
INSERT INTO 'media' VALUES (3954, 339, 2, 'V1666', 0, 0);
INSERT INTO 'media' VALUES (3955, 340, 2, 'NRSCDS 101', 1974, 0);
INSERT INTO 'media' VALUES (3956, 341, 2, 'V1680', 0, 0);
INSERT INTO 'media' VALUES (3957, 342, 2, 'ELS 304', 0, 0);
INSERT INTO 'media' VALUES (3958, 343, 3, '', 1993, 1);
INSERT INTO 'media' VALUES (3959, 343, 1, 'LCOM 5225', 1993, 1);
INSERT INTO 'media' VALUES (3960, 344, 2, 'GES 1018', 0, 0);
INSERT INTO 'media' VALUES (3961, 345, 3, '', 0, 0);
INSERT INTO 'media' VALUES (3962, 346, 3, '', 1999, 1);
INSERT INTO 'media' VALUES (3963, 346, 1, 'CD013', 1999, 1);
INSERT INTO 'media' VALUES (3964, 347, 3, '', 1999, 1);
INSERT INTO 'media' VALUES (3965, 347, 1, 'CD014', 1999, 1);
INSERT INTO 'media' VALUES (3966, 349, 2, 'GSGL 10481', 1972, 0);
INSERT INTO 'media' VALUES (3967, 353, 1, 'SHIELCD007', 1999, 1);
INSERT INTO 'media' VALUES (3968, 354, 3, '', 1999, 1);
INSERT INTO 'media' VALUES (3969, 354, 1, 'CD015', 1999, 1);
INSERT INTO 'media' VALUES (3970, 355, 3, '', 1999, 1);
INSERT INTO 'media' VALUES (3971, 355, 1, 'DSMCD001', 1999, 1);
INSERT INTO 'media' VALUES (3972, 356, 1, 'BRCD 015', 1999, 1);
INSERT INTO 'media' VALUES (3973, 357, 1, 'KSCD004', 1999, 1);
INSERT INTO 'media' VALUES (3974, 358, 2, 'FJL504', 0, 0);
INSERT INTO 'media' VALUES (3975, 359, 3, 'TRMC9903', 1999, 1);
INSERT INTO 'media' VALUES (3976, 359, 1, 'TRCD9903', 1999, 1);
INSERT INTO 'media' VALUES (3977, 360, 1, 'CDN001CD', 2000, 1);
INSERT INTO 'media' VALUES (3978, 361, 1, 'HRMCD511', 2000, 1);
INSERT INTO 'media' VALUES (3979, 362, 1, 'BOS CD 001', 2000, 1);
INSERT INTO 'media' VALUES (3980, 363, 3, 'SRMC004', 1999, 1);
INSERT INTO 'media' VALUES (3981, 363, 1, 'SRCD004', 1999, 1);
INSERT INTO 'media' VALUES (3982, 364, 3, '', 0, 0);
INSERT INTO 'media' VALUES (3984, 366, 1, 'JA102', 1995, 1);
INSERT INTO 'media' VALUES (3985, 367, 1, 'BRG021-CD', 2000, 1);
INSERT INTO 'media' VALUES (3987, 369, 1, 'CD016', 2000, 1);
INSERT INTO 'media' VALUES (3988, 370, 2, 'GGL 0397', 1967, 0);
INSERT INTO 'media' VALUES (3989, 371, 2, 'TC-1A', 1965, 0);
INSERT INTO 'media' VALUES (3990, 372, 2, 'AJP 1007/8', 1977, 0);
INSERT INTO 'media' VALUES (3991, 373, 1, 'ABC102', 2000, 1);
INSERT INTO 'media' VALUES (3992, 374, 2, '2460 260', 1976, 0);
INSERT INTO 'media' VALUES (3993, 374, 3, '3170 260', 1976, 0);
INSERT INTO 'media' VALUES (3994, 375, 1, 'ABC101', 2000, 1);
INSERT INTO 'media' VALUES (3995, 376, 1, 'WAG 001', 1998, 1);
INSERT INTO 'media' VALUES (3996, 377, 1, 'SSCD09', 2000, 1);
INSERT INTO 'media' VALUES (3997, 378, 3, 'WA001', 1994, 0);
INSERT INTO 'media' VALUES (3998, 379, 2, 'MFP 50374', 0, 0);
INSERT INTO 'media' VALUES (3999, 380, 3, 'KGM01', 1998, 0);
INSERT INTO 'media' VALUES (3983, 365, 3, 'AYRC131', 1991, NULL);
INSERT INTO 'media' VALUES (4000, 381, 2, 'FLPS1746', 1968, 0);
INSERT INTO 'media' VALUES (4001, 381, 3, '', 1968, 0);
INSERT INTO 'media' VALUES (4003, 383, 3, 'TSW001', 1995, 1);
INSERT INTO 'media' VALUES (3943, 330, 1, 'DLRD3', 1998, 1);
INSERT INTO 'media' VALUES (4004, 383, 1, 'TSW001CD', 1995, 1);
INSERT INTO 'media' VALUES (4005, 384, 1, 'SICD01', 0, 1);
INSERT INTO 'media' VALUES (4006, 385, 3, 'ARC100', 1952, 1);
INSERT INTO 'media' VALUES (4007, 386, 1, 'BDA003', 0, 1);
INSERT INTO 'media' VALUES (4008, 387, 1, 'SSCD 10', 2001, 1);
INSERT INTO 'media' VALUES (4009, 388, 1, 'SAB 220', 0, 1);
INSERT INTO 'media' VALUES (4010, 389, 1, 'KSCD 005', 2000, 1);
INSERT INTO 'media' VALUES (4011, 390, 1, 'EWO-003', 2001, 1);
INSERT INTO 'media' VALUES (4013, 392, 1, 'HRM CD 557', 2001, 1);
INSERT INTO 'media' VALUES (4014, 393, 1, '', 2001, 1);
INSERT INTO 'media' VALUES (4474, 1112, 1, 'RSCDS CD081', 2015, 1);
INSERT INTO 'media' VALUES (4016, 395, 1, '', 1999, 1);
INSERT INTO 'media' VALUES (4017, 396, 1, 'CD024', 0, 1);
INSERT INTO 'media' VALUES (4019, 398, 2, 'SCL 2', 1973, 0);
INSERT INTO 'media' VALUES (4020, 399, 2, 'PMC 1210/PCS 3048', 1963, 0);
INSERT INTO 'media' VALUES (4021, 400, 1, 'SHIELCD011', 2001, 0);
INSERT INTO 'media' VALUES (4022, 401, 1, '', 2001, 1);
INSERT INTO 'media' VALUES (4023, 402, 1, 'PFRD 0009', 0, 1);
INSERT INTO 'media' VALUES (4024, 403, 1, 'RSCDS CD018', 1996, 1);
INSERT INTO 'media' VALUES (4025, 404, 1, 'SICD02', 2002, 1);
INSERT INTO 'media' VALUES (4026, 405, 1, '', 2001, 1);
INSERT INTO 'media' VALUES (4027, 406, 1, 'CDLBP 2024', 1996, 1);
INSERT INTO 'media' VALUES (4028, 407, 1, 'CD028', 2002, 1);
INSERT INTO 'media' VALUES (4029, 408, 1, 'CDLBP 2017', 1994, 1);
INSERT INTO 'media' VALUES (4030, 409, 1, 'CD026', 2002, 1);
INSERT INTO 'media' VALUES (4031, 410, 1, 'WAG002', 2002, 1);
INSERT INTO 'media' VALUES (4032, 411, 1, 'SKYECD001', 2001, 1);
INSERT INTO 'media' VALUES (4002, 382, 1, 'DACD0022', 2001, 1);
INSERT INTO 'media' VALUES (4018, 397, 1, 'DACD0023', 2000, 1);
INSERT INTO 'media' VALUES (3986, 368, 2, 'BSLP 59', 1960, 0);
INSERT INTO 'media' VALUES (4034, 413, 1, 'EMPRCD 784', 1991, 1);
INSERT INTO 'media' VALUES (4035, 414, 2, 'KITV 422', 0, 0);
INSERT INTO 'media' VALUES (4036, 415, 2, 'LP 1255', 1964, 0);
INSERT INTO 'media' VALUES (4037, 416, 1, 'SHIELCD010', 2000, 1);
INSERT INTO 'media' VALUES (4038, 417, 2, 'LILP 5098', 1979, 0);
INSERT INTO 'media' VALUES (4039, 418, 2, 'PMD 1029', 0, 0);
INSERT INTO 'media' VALUES (4040, 419, 2, 'GES 1140', 1975, 0);
INSERT INTO 'media' VALUES (4041, 420, 2, 'PA001', 1973, 0);
INSERT INTO 'media' VALUES (4042, 421, 2, 'GES 1119', 1974, 0);
INSERT INTO 'media' VALUES (4044, 423, 1, 'SCD13', 2002, 1);
INSERT INTO 'media' VALUES (4045, 424, 1, 'SSCD14', 2002, 1);
INSERT INTO 'media' VALUES (4046, 425, 1, '19416-2', 1997, 1);
INSERT INTO 'media' VALUES (4047, 426, 1, '', 2002, 1);
INSERT INTO 'media' VALUES (4048, 427, 1, 'RSCDS CD029', 2002, 1);
INSERT INTO 'media' VALUES (4049, 428, 1, 'HRMCD601', 2002, 1);
INSERT INTO 'media' VALUES (4050, 429, 1, '', 2002, 1);
INSERT INTO 'media' VALUES (4051, 430, 1, 'SRCD005', 2002, 1);
INSERT INTO 'media' VALUES (4052, 431, 1, 'CD033', 2002, 1);
INSERT INTO 'media' VALUES (4053, 432, 1, 'CD034', 2002, 1);
INSERT INTO 'media' VALUES (4054, 433, 1, 'CD032', 0, 1);
INSERT INTO 'media' VALUES (4055, 434, 1, 'DACD0225', 2002, 1);
INSERT INTO 'media' VALUES (4056, 435, 1, 'KRCD0101', 0, 1);
INSERT INTO 'media' VALUES (4057, 436, 1, 'Waverley CD001', 2003, 1);
INSERT INTO 'media' VALUES (4058, 437, 2, 'STAL 5002', 0, 0);
INSERT INTO 'media' VALUES (4060, 439, 1, 'TRCD0302', 2003, 1);
INSERT INTO 'media' VALUES (4061, 440, 1, 'NS116CD', 2003, 1);
INSERT INTO 'media' VALUES (4062, 441, 1, 'CD041', 2003, 1);
INSERT INTO 'media' VALUES (4063, 442, 1, 'BRCD 034', 2003, 1);
INSERT INTO 'media' VALUES (4064, 443, 1, 'HRMCD524', 2003, 1);
INSERT INTO 'media' VALUES (4066, 445, 1, 'HJC 2003', 2003, 1);
INSERT INTO 'media' VALUES (4067, 446, 1, 'CDTRAX 037', 1990, 1);
INSERT INTO 'media' VALUES (4069, 448, 1, 'CD044', 2004, 1);
INSERT INTO 'media' VALUES (4070, 449, 1, 'SSCD16', 2004, 1);
INSERT INTO 'media' VALUES (4071, 450, 1, 'SSSCD 15', 2003, 1);
INSERT INTO 'media' VALUES (4072, 451, 1, 'CD045', 2004, 1);
INSERT INTO 'media' VALUES (4073, 452, 1, 'CD046', 2004, 1);
INSERT INTO 'media' VALUES (4074, 453, 1, 'HRMCD558', 2004, 1);
INSERT INTO 'media' VALUES (4076, 456, 1, 'RSCDSCD035', 2003, 1);
INSERT INTO 'media' VALUES (4077, 457, 1, '', 2003, 1);
INSERT INTO 'media' VALUES (4078, 458, 1, 'HRMCD602', 2004, 1);
INSERT INTO 'media' VALUES (4079, 459, 1, 'KEN 005', 2003, 1);
INSERT INTO 'media' VALUES (4080, 460, 1, '', 2004, 1);
INSERT INTO 'media' VALUES (4081, 461, 1, 'RSCDSCD036', 2004, 1);
INSERT INTO 'media' VALUES (4082, 462, 1, 'DACD0427', 2004, 1);
INSERT INTO 'media' VALUES (4083, 463, 1, 'SRCD006', 2004, 1);
INSERT INTO 'media' VALUES (4086, 466, 1, 'RTM02', 2004, 1);
INSERT INTO 'media' VALUES (4087, 467, 1, '', 2003, 1);
INSERT INTO 'media' VALUES (4088, 468, 1, 'CFDS001', 2004, 1);
INSERT INTO 'media' VALUES (4090, 470, 1, '', 0, 1);
INSERT INTO 'media' VALUES (4091, 471, 1, '', 2004, 1);
INSERT INTO 'media' VALUES (4092, 472, 1, 'FM001', 2005, 1);
INSERT INTO 'media' VALUES (4093, 473, 1, 'BRCD035', 2004, 1);
INSERT INTO 'media' VALUES (4094, 474, 1, 'KSCD012', 2005, 1);
INSERT INTO 'media' VALUES (4095, 475, 2, 'AD001', 1979, 0);
INSERT INTO 'media' VALUES (4096, 476, 2, 'SZLP 2125', 1971, 0);
INSERT INTO 'media' VALUES (4097, 476, 3, 'GRTC37', 1971, 0);
INSERT INTO 'media' VALUES (4099, 478, 2, '', 0, 0);
INSERT INTO 'media' VALUES (4100, 479, 1, 'SHIELCD019', 0, 1);
INSERT INTO 'media' VALUES (4101, 480, 1, 'RSCD CD048', 2005, 1);
INSERT INTO 'media' VALUES (4102, 481, 1, 'RSCDSCD037', 2003, 1);
INSERT INTO 'media' VALUES (4103, 482, 1, 'RSCDSCD039', 2003, 1);
INSERT INTO 'media' VALUES (4043, 422, 1, 'FALCDS002', 2001, 1);
INSERT INTO 'media' VALUES (4065, 444, 1, 'FDM09', 2003, 1);
INSERT INTO 'media' VALUES (4068, 447, 1, 'Invercauld001', 2003, 1);
INSERT INTO 'media' VALUES (4104, 483, 1, '', 2005, 1);
INSERT INTO 'media' VALUES (4105, 484, 1, 'JDM010CD', 2005, 1);
INSERT INTO 'media' VALUES (4106, 485, 1, 'JWPCD01', 2005, 1);
INSERT INTO 'media' VALUES (4107, 486, 1, 'HRMCD512', 2005, 1);
INSERT INTO 'media' VALUES (4108, 487, 1, 'CFDS001', 2004, 1);
INSERT INTO 'media' VALUES (4109, 488, 1, 'HRMCD513', 2005, 1);
INSERT INTO 'media' VALUES (4110, 489, 1, 'CD053', 2005, 1);
INSERT INTO 'media' VALUES (4112, 491, 1, 'SPCD002', 2006, 1);
INSERT INTO 'media' VALUES (4113, 492, 1, '', 2003, 1);
INSERT INTO 'media' VALUES (4114, 493, 1, 'BRG 024-CD', 2006, 1);
INSERT INTO 'media' VALUES (4115, 494, 1, 'S22A011', 2006, 1);
INSERT INTO 'media' VALUES (4116, 495, 1, '', 2006, 1);
INSERT INTO 'media' VALUES (4117, 496, 1, 'CD11', 2003, 1);
INSERT INTO 'media' VALUES (4118, 497, 1, '', 2006, 1);
INSERT INTO 'media' VALUES (4119, 498, 3, '', 0, 0);
INSERT INTO 'media' VALUES (4120, 499, 1, 'EWO 004', 2006, 1);
INSERT INTO 'media' VALUES (4121, 500, 1, 'BCDS0601', 2006, 1);
INSERT INTO 'media' VALUES (4122, 501, 1, '', 0, 1);
INSERT INTO 'media' VALUES (4127, 506, 3, 'SMR020', 1995, 0);
INSERT INTO 'media' VALUES (4128, 507, 1, '', 2006, 1);
INSERT INTO 'media' VALUES (4129, 508, 1, 'BB D0601', 2006, 1);
INSERT INTO 'media' VALUES (4130, 509, 1, 'JVMCD0601', 2006, 1);
INSERT INTO 'media' VALUES (4131, 510, 1, 'ADPCD001', 2006, 1);
INSERT INTO 'media' VALUES (4132, 511, 1, 'LBCD0601', 2006, 1);
INSERT INTO 'media' VALUES (4133, 512, 1, 'SBJ0701', 2007, 1);
INSERT INTO 'media' VALUES (4134, 513, 1, '', 2006, 1);
INSERT INTO 'media' VALUES (4136, 516, 1, 'HRMCD015', 2007, 1);
INSERT INTO 'media' VALUES (4137, 702, 2, '2384-074', 1975, 0);
INSERT INTO 'media' VALUES (4138, 703, 2, 'ACL 7708', 0, 0);
INSERT INTO 'media' VALUES (4123, 502, 1, '', 2001, 1);
INSERT INTO 'media' VALUES (4089, 469, 1, 'S22A006', 2004, 1);
INSERT INTO 'media' VALUES (4085, 465, 1, 'SHIELCD022', 2004, 1);
INSERT INTO 'media' VALUES (4033, 412, 1, 'FALCDS001', 2001, 1);
INSERT INTO 'media' VALUES (4139, 705, 3, 'IM9305', 0, 1);
INSERT INTO 'media' VALUES (4140, 706, 2, '', 1974, 0);
INSERT INTO 'media' VALUES (4141, 709, 3, '', 1996, 0);
INSERT INTO 'media' VALUES (4142, 709, 1, '', 1996, 0);
INSERT INTO 'media' VALUES (4143, 711, 1, 'CDTRAX107', 1996, 1);
INSERT INTO 'media' VALUES (4144, 712, 2, 'GES1034', 0, 0);
INSERT INTO 'media' VALUES (4145, 714, 2, 'ACL 7715', 0, 0);
INSERT INTO 'media' VALUES (4146, 715, 2, 'INTS 1106', 1970, 0);
INSERT INTO 'media' VALUES (4147, 716, 2, '', 1974, 0);
INSERT INTO 'media' VALUES (4148, 717, 2, 'CSPS 2025', 0, 0);
INSERT INTO 'media' VALUES (4149, 718, 2, 'WRCS 4705', 0, 0);
INSERT INTO 'media' VALUES (4150, 719, 2, 'ZLP 2112', 1968, 0);
INSERT INTO 'media' VALUES (4151, 721, 2, 'NRSCDS 104', 1980, 0);
INSERT INTO 'media' VALUES (4152, 722, 2, 'MAL 899', 1969, 0);
INSERT INTO 'media' VALUES (4153, 723, 2, 'BSLP 125S', 0, 0);
INSERT INTO 'media' VALUES (4154, 724, 2, 'ACL 7706', 0, 0);
INSERT INTO 'media' VALUES (4155, 725, 2, 'ACL7707', 0, 0);
INSERT INTO 'media' VALUES (4156, 727, 2, 'LHC LP2', 1974, 0);
INSERT INTO 'media' VALUES (4157, 728, 1, 'FAC CD 137', 1997, 1);
INSERT INTO 'media' VALUES (4158, 729, 2, '33SR 150', 1973, 0);
INSERT INTO 'media' VALUES (4159, 730, 2, 'SR 33102', 0, 0);
INSERT INTO 'media' VALUES (4160, 732, 3, 'RECS497', 1994, 1);
INSERT INTO 'media' VALUES (4161, 732, 1, 'RECD497', 1994, 1);
INSERT INTO 'media' VALUES (4162, 734, 3, 'CDR005', 1987, 1);
INSERT INTO 'media' VALUES (4163, 735, 2, 'RLP 2001', 0, 0);
INSERT INTO 'media' VALUES (4164, 737, 2, 'OU 2015', 1973, 0);
INSERT INTO 'media' VALUES (4165, 740, 2, 'MFP 50373', 0, 0);
INSERT INTO 'media' VALUES (4166, 741, 2, 'GLN 1025', 1981, 0);
INSERT INTO 'media' VALUES (4167, 743, 2, 'BRG 019', 1996, 1);
INSERT INTO 'media' VALUES (4168, 743, 1, 'BRG019', 1996, 1);
INSERT INTO 'media' VALUES (4169, 745, 2, '1A-3027', 0, 1);
INSERT INTO 'media' VALUES (4170, 745, 1, 'CFIRST04 (1-10 other dance sequence)', 0, 1);
INSERT INTO 'media' VALUES (4171, 746, 2, 'IAS 3048', 0, 0);
INSERT INTO 'media' VALUES (4172, 746, 1, 'CFIRST04 (11-20 other dance sequence)', 0, 0);
INSERT INTO 'media' VALUES (4173, 747, 2, 'GH536', 0, 0);
INSERT INTO 'media' VALUES (4174, 748, 2, '2384 085', 1976, 0);
INSERT INTO 'media' VALUES (4175, 748, 3, '3192 361', 1976, 0);
INSERT INTO 'media' VALUES (4176, 749, 2, '2384 088', 1976, 0);
INSERT INTO 'media' VALUES (4177, 750, 3, 'DML C01', 1995, 0);
INSERT INTO 'media' VALUES (4178, 751, 2, 'SSM 029', 1988, 0);
INSERT INTO 'media' VALUES (4179, 751, 3, 'SSM 029C', 1988, 0);
INSERT INTO 'media' VALUES (4180, 752, 2, 'MFP A8104', 1969, 0);
INSERT INTO 'media' VALUES (4125, 504, 1, 'HBT005', 2005, 1);
INSERT INTO 'media' VALUES (4135, 514, 1, 'EWO 005', 2007, 1);
INSERT INTO 'media' VALUES (4126, 505, 1, 'WACD0001', 2006, 1);
INSERT INTO 'media' VALUES (4111, 490, 1, 'CD050', 2005, 1);
INSERT INTO 'media' VALUES (4181, 752, 1, 'RCD03', 1969, 0);
INSERT INTO 'media' VALUES (4182, 754, 2, 'Eros 8059', 1965, 0);
INSERT INTO 'media' VALUES (4183, 755, 2, 'ZLP 2058', 0, 0);
INSERT INTO 'media' VALUES (4184, 756, 3, 'PE1010', 1991, 1);
INSERT INTO 'media' VALUES (4185, 758, 2, 'ACL 7710', 0, 0);
INSERT INTO 'media' VALUES (4186, 760, 2, 'SGW 5008', 1975, 0);
INSERT INTO 'media' VALUES (4187, 771, 3, '', 1997, 1);
INSERT INTO 'media' VALUES (4188, 771, 1, 'LCOM 5260', 1997, 1);
INSERT INTO 'media' VALUES (4189, 774, 1, 'RSCDSCD008', 1998, 1);
INSERT INTO 'media' VALUES (4190, 775, 1, 'RSCDSCD009', 1998, 1);
INSERT INTO 'media' VALUES (4191, 777, 1, 'CDLBP 2025', 1996, 0);
INSERT INTO 'media' VALUES (4192, 780, 2, 'FL215 (TLP 8045)', 0, 0);
INSERT INTO 'media' VALUES (4193, 781, 2, 'FE007', 1977, 0);
INSERT INTO 'media' VALUES (4194, 785, 2, 'SCL 3', 1975, 0);
INSERT INTO 'media' VALUES (4195, 786, 2, 'CRL 57489', 0, 0);
INSERT INTO 'media' VALUES (4197, 790, 2, 'BSLP 128S', 0, 0);
INSERT INTO 'media' VALUES (4199, 803, 2, 'KXL1-0383', 1979, 0);
INSERT INTO 'media' VALUES (4200, 805, 2, 'LILP 5075', 1977, 0);
INSERT INTO 'media' VALUES (4201, 811, 2, 'ALL 810/WLP6051', 0, 0);
INSERT INTO 'media' VALUES (4202, 822, 2, 'T6032 (XEX 426)', 1957, 0);
INSERT INTO 'media' VALUES (4203, 824, 3, 'AB012', 1991, 0);
INSERT INTO 'media' VALUES (4204, 826, 2, 'TFL 5033', 1961, 0);
INSERT INTO 'media' VALUES (4205, 827, 2, 'SBE 109', 1962, 0);
INSERT INTO 'media' VALUES (4206, 829, 2, 'AB 002', 1984, 0);
INSERT INTO 'media' VALUES (4207, 832, 2, 'SBE 119', 1958, 0);
INSERT INTO 'media' VALUES (4208, 833, 2, 'ST 10373', 0, 0);
INSERT INTO 'media' VALUES (4209, 836, 2, 'AB003-D', 1984, 0);
INSERT INTO 'media' VALUES (4210, 838, 2, '6414 317', 1972, 0);
INSERT INTO 'media' VALUES (4211, 841, 1, 'PBM 048', 1997, 1);
INSERT INTO 'media' VALUES (4212, 847, 3, 'CDR009', 1988, 1);
INSERT INTO 'media' VALUES (4213, 849, 3, '', 1998, 1);
INSERT INTO 'media' VALUES (4214, 849, 1, 'SMR074CD', 1998, 1);
INSERT INTO 'media' VALUES (4215, 852, 2, '', 0, 0);
INSERT INTO 'media' VALUES (4216, 853, 3, 'LICS 5187', 1989, 0);
INSERT INTO 'media' VALUES (4217, 854, 1, 'CDLBP 2015', 1994, 0);
INSERT INTO 'media' VALUES (4218, 856, 2, 'SCL-4', 1976, 0);
INSERT INTO 'media' VALUES (4219, 864, 2, 'BSLP 117S', 0, 0);
INSERT INTO 'media' VALUES (4220, 868, 3, '', 1998, 1);
INSERT INTO 'media' VALUES (4221, 868, 1, 'RSCDS CD010', 1998, 1);
INSERT INTO 'media' VALUES (4222, 869, 3, 'TC RSCDS 57', 1998, 1);
INSERT INTO 'media' VALUES (4223, 869, 1, 'RSCDS CD011', 1998, 1);
INSERT INTO 'media' VALUES (4224, 870, 3, 'TC RSCDS 58', 1998, 1);
INSERT INTO 'media' VALUES (4225, 870, 1, 'RSCDS CD012', 1998, 1);
INSERT INTO 'media' VALUES (4226, 871, 1, 'SSCD 07', 1998, 1);
INSERT INTO 'media' VALUES (4227, 872, 3, 'DACS9818', 1998, 1);
INSERT INTO 'media' VALUES (4228, 872, 1, 'DACD9818', 1998, 1);
INSERT INTO 'media' VALUES (4229, 875, 3, 'SRMC003', 1998, 1);
INSERT INTO 'media' VALUES (4230, 875, 1, 'SRCD003', 1998, 1);
INSERT INTO 'media' VALUES (4231, 876, 1, 'SSCD 06', 1998, 1);
INSERT INTO 'media' VALUES (4232, 878, 3, 'RSCDS 41', 1991, 1);
INSERT INTO 'media' VALUES (4233, 879, 1, '-', 2009, 1);
INSERT INTO 'media' VALUES (4234, 880, 1, 'RISK0801', 2008, 1);
INSERT INTO 'media' VALUES (4235, 881, 1, 'SSCD20', 2008, 1);
INSERT INTO 'media' VALUES (4236, 882, 1, 'SSCD21', 2008, 1);
INSERT INTO 'media' VALUES (4237, 883, 1, 'RSCDS_CD064', 2008, 1);
INSERT INTO 'media' VALUES (4238, 884, 1, 'DACD0831', 2008, 1);
INSERT INTO 'media' VALUES (4239, 885, 1, 'RSCDS_CD060', 2007, 1);
INSERT INTO 'media' VALUES (4240, 886, 1, '?', 2008, 1);
INSERT INTO 'media' VALUES (4241, 887, 1, 'CD062', 2007, 1);
INSERT INTO 'media' VALUES (4242, 888, 1, 'SRCD007', 2007, 1);
INSERT INTO 'media' VALUES (4243, 889, 1, 'LBSDB02', 2009, 1);
INSERT INTO 'media' VALUES (4244, 890, 1, 'CD054', 2006, 1);
INSERT INTO 'media' VALUES (4245, 891, 1, 'CD055', 2006, 1);
INSERT INTO 'media' VALUES (4246, 892, 1, 'LBSDB01', 2008, 1);
INSERT INTO 'media' VALUES (4247, 893, 1, 'CD059', 2007, 1);
INSERT INTO 'media' VALUES (4248, 894, 1, 'EWO006', 2008, 0);
INSERT INTO 'media' VALUES (4249, 895, 1, 'FM003', 2009, 1);
INSERT INTO 'media' VALUES (4250, 896, 1, 'ELMES1', 2009, 1);
INSERT INTO 'media' VALUES (4251, 897, 1, 'CD061', 2007, 1);
INSERT INTO 'media' VALUES (4252, 898, 1, 'CD057', 2006, 1);
INSERT INTO 'media' VALUES (4253, 899, 1, 'CD065', 2008, 1);
INSERT INTO 'media' VALUES (4254, 900, 1, 'CD066', 2009, 1);
INSERT INTO 'media' VALUES (4255, 901, 1, 'CD063', 2008, 1);
INSERT INTO 'media' VALUES (4256, 902, 1, 'TAC-007', 2008, 1);
INSERT INTO 'media' VALUES (4257, 903, 1, 'DSMCD-004', 2009, 1);
INSERT INTO 'media' VALUES (4258, 904, 1, 'JVMCD0701', 2007, 1);
INSERT INTO 'media' VALUES (4259, 905, 1, 'JVMCD0801', 2008, 1);
INSERT INTO 'media' VALUES (4260, 906, 1, 'JVMCD0802', 2008, 1);
INSERT INTO 'media' VALUES (4261, 907, 1, 'RVC02', 2009, 1);
INSERT INTO 'media' VALUES (4262, 908, 1, 'BLANK', 2009, 1);
INSERT INTO 'media' VALUES (4263, 909, 1, 'HEATHER', 2009, 1);
INSERT INTO 'media' VALUES (4264, 910, 1, 'Perth_CD0801', 2008, 1);
INSERT INTO 'media' VALUES (4265, 911, 1, 'SSCD23', 2009, 1);
INSERT INTO 'media' VALUES (4266, 912, 1, 'ABC104', 2007, 1);
INSERT INTO 'media' VALUES (4267, 913, 1, 'BLANK', 2008, 1);
INSERT INTO 'media' VALUES (4268, 914, 1, 'SSCD019', 2007, 1);
INSERT INTO 'media' VALUES (4269, 915, 1, 'SDP10', 2009, 0);
INSERT INTO 'media' VALUES (4270, 916, 1, 'MAC99-CD', 2009, 1);
INSERT INTO 'media' VALUES (4271, 917, 1, 'DACD0629', 2006, 1);
INSERT INTO 'media' VALUES (4272, 918, 1, 'CRESCSCD0109', 2009, 1);
INSERT INTO 'media' VALUES (4273, 919, 1, 'BRCD052', 2009, 1);
INSERT INTO 'media' VALUES (4274, 922, 1, 'SPCD004', 2007, 1);
INSERT INTO 'media' VALUES (4275, 923, 1, 'LEGACY18CD', 2004, 1);
INSERT INTO 'media' VALUES (4276, 924, 1, 'HRMCD559', 2006, 1);
INSERT INTO 'media' VALUES (4277, 925, 1, 'FM002', 2007, 1);
INSERT INTO 'media' VALUES (4278, 926, 1, 'S22A004', 2004, 1);
INSERT INTO 'media' VALUES (4279, 927, 1, 'S22A007', 2005, 1);
INSERT INTO 'media' VALUES (4280, 928, 1, 'PFFM-CD01', 2003, 1);
INSERT INTO 'media' VALUES (4281, 929, 1, 'CM109', 2008, 1);
INSERT INTO 'media' VALUES (4282, 930, 1, 'RVC01', 2007, 1);
INSERT INTO 'media' VALUES (4283, 931, 1, 'CNACD001', 2005, 1);
INSERT INTO 'media' VALUES (4284, 932, 1, 'CCB_CD1', 1996, 1);
INSERT INTO 'media' VALUES (4285, 933, 1, 'CNACD002', 2006, 1);
INSERT INTO 'media' VALUES (4286, 934, 1, 'JHCD001', 2006, 1);
INSERT INTO 'media' VALUES (4287, 935, 1, 'BBB2004', 2004, 1);
INSERT INTO 'media' VALUES (4288, 936, 1, 'CBCD08', 2006, 1);
INSERT INTO 'media' VALUES (4289, 937, 1, 'CDGR174', 2001, 1);
INSERT INTO 'media' VALUES (4290, 938, 1, 'CDGR175', 2001, 1);
INSERT INTO 'media' VALUES (4291, 939, 1, 'CDGR185', 2002, 1);
INSERT INTO 'media' VALUES (4292, 940, 1, 'CDN005', 2009, 1);
INSERT INTO 'media' VALUES (4293, 941, 1, 'BELTONA209', 2007, 1);
INSERT INTO 'media' VALUES (4294, 942, 1, 'THISTLE105CD', 1967, 1);
INSERT INTO 'media' VALUES (4295, 943, 1, 'SDP05', 2009, 1);
INSERT INTO 'media' VALUES (4296, 944, 1, 'SDP06', 2009, 1);
INSERT INTO 'media' VALUES (4297, 945, 1, 'HRMCD017', 2009, 1);
INSERT INTO 'media' VALUES (4298, 946, 1, 'IMTCD001', 2009, 1);
INSERT INTO 'media' VALUES (4299, 947, 1, 'HRMCD016', 2009, 1);
INSERT INTO 'media' VALUES (4300, 948, 1, 'Fidula-CD 4472', 1999, 1);
INSERT INTO 'media' VALUES (4301, 949, 1, 'S22A018', 2008, 1);
INSERT INTO 'media' VALUES (4302, 950, 1, 'GLRCD01', 2005, 1);
INSERT INTO 'media' VALUES (4303, 951, 1, 'KRCD0302', 2003, 1);
INSERT INTO 'media' VALUES (4304, 952, 1, 'TOKYOCD001', 2009, 1);
INSERT INTO 'media' VALUES (4305, 953, 1, 'BRHCD40', 2009, 1);
INSERT INTO 'media' VALUES (4306, 954, 1, 'GWR0001CD', 2009, 0);
INSERT INTO 'media' VALUES (4307, 955, 1, 'BRHCD36', 2009, 1);
INSERT INTO 'media' VALUES (4308, 956, 1, 'RSCDSCD051', 2005, 1);
INSERT INTO 'media' VALUES (4309, 957, 1, 'RSCDSCD068', 2010, 1);
INSERT INTO 'media' VALUES (4310, 958, 1, 'RSCDSCD067', 2010, 1);
INSERT INTO 'media' VALUES (4311, 959, 1, 'RSCDSCD070', 2010, 1);
INSERT INTO 'media' VALUES (4312, 960, 1, 'SDP03', 2007, 1);
INSERT INTO 'media' VALUES (4313, 961, 1, 'THISTLE102', 2005, 1);
INSERT INTO 'media' VALUES (4314, 962, 1, 'SDP09', 2008, 1);
INSERT INTO 'media' VALUES (4315, 963, 1, 'CVCD01', 2007, 1);
INSERT INTO 'media' VALUES (4316, 964, 1, 'CVCD02', 2009, 1);
INSERT INTO 'media' VALUES (4317, 965, 1, 'PSRS008CD', 2009, 1);
INSERT INTO 'media' VALUES (4318, 966, 1, 'BRG-027CD', 2010, 1);
INSERT INTO 'media' VALUES (4319, 967, 1, 'CDTRAX315', 2007, 1);
INSERT INTO 'media' VALUES (4320, 968, 1, 'CDTRAX355', 2010, 1);
INSERT INTO 'media' VALUES (4321, 969, 1, 'CDTRAX303', 2006, 1);
INSERT INTO 'media' VALUES (4322, 970, 1, 'SMR150CD', 2007, 1);
INSERT INTO 'media' VALUES (4323, 971, 1, 'TRVCD001', 2010, 1);
INSERT INTO 'media' VALUES (4324, 972, 1, 'HRMCD514', 2010, 1);
INSERT INTO 'media' VALUES (4325, 973, 1, 'CD069', 2010, 1);
INSERT INTO 'media' VALUES (4326, 974, 1, 'SRCD008', 2010, 1);
INSERT INTO 'media' VALUES (4327, 975, 1, 'GWR0002CD', 2010, 1);
INSERT INTO 'media' VALUES (4328, 976, 1, 'LEGACY37CD', 2010, 1);
INSERT INTO 'media' VALUES (4329, 977, 1, 'YCD01', 2010, 1);
INSERT INTO 'media' VALUES (4330, 978, 1, 'EESH001', 2006, 1);
INSERT INTO 'media' VALUES (4331, 979, 1, '3TRDC01', 2010, 1);
INSERT INTO 'media' VALUES (4332, 980, 1, 'DMM6648', 2006, 1);
INSERT INTO 'media' VALUES (4333, 981, 1, 'CFIRST04', 2010, 1);
INSERT INTO 'media' VALUES (4334, 982, 1, 'THISTLE109', 2010, 1);
INSERT INTO 'media' VALUES (4335, 983, 1, 'HRMCD018', 2010, 1);
INSERT INTO 'media' VALUES (4336, 984, 1, 'HRMCD101', 2004, 1);
INSERT INTO 'media' VALUES (4337, 985, 1, 'BRHCD45', 2010, 1);
INSERT INTO 'media' VALUES (4338, 986, 1, 'BWB1', 2010, 1);
INSERT INTO 'media' VALUES (4339, 987, 1, 'RVC03', 2011, 1);
INSERT INTO 'media' VALUES (4340, 988, 1, 'CBCD09', 2011, 0);
INSERT INTO 'media' VALUES (4341, 989, 2, 'TFL 5166', 1962, 0);
INSERT INTO 'media' VALUES (4342, 990, 1, 'CD071', 2011, 1);
INSERT INTO 'media' VALUES (4343, 991, 1, 'HRMCD020', 2011, 1);
INSERT INTO 'media' VALUES (4344, 995, 1, 'FAC832CD', 2011, 1);
INSERT INTO 'media' VALUES (4345, 996, 1, '-', 2010, 1);
INSERT INTO 'media' VALUES (4346, 997, 1, 'NS120CD_(2CDs)', 2011, 1);
INSERT INTO 'media' VALUES (4347, 998, 1, 'HRMCD013', 2008, 1);
INSERT INTO 'media' VALUES (4348, 999, 1, 'HRMCD102', 2005, 1);
INSERT INTO 'media' VALUES (4349, 1000, 1, 'LOGAN001', 2010, 1);
INSERT INTO 'media' VALUES (4350, 1001, 1, 'HRMCD002', 1997, 1);
INSERT INTO 'media' VALUES (4351, 1002, 1, 'HRMCD008', 2001, 1);
INSERT INTO 'media' VALUES (4352, 1003, 1, 'HRMCD004', 1998, 1);
INSERT INTO 'media' VALUES (4353, 1004, 1, 'SCBCD01', 2005, 1);
INSERT INTO 'media' VALUES (4354, 1005, 1, 'LEGACY07CD', 2000, 1);
INSERT INTO 'media' VALUES (4355, 1006, 1, 'LEGACY08CD', 2000, 1);
INSERT INTO 'media' VALUES (4356, 1007, 1, 'VRCD001', 2010, 1);
INSERT INTO 'media' VALUES (4357, 1008, 1, 'BRCD058', 2010, 1);
INSERT INTO 'media' VALUES (4358, 1009, 1, 'STCD004', 2006, 1);
INSERT INTO 'media' VALUES (4359, 1010, 1, 'RCD01', 2009, 1);
INSERT INTO 'media' VALUES (4360, 1011, 1, 'SMR160CD', 2011, 1);
INSERT INTO 'media' VALUES (4361, 1012, 1, 'BRHCD49', 2011, 1);
INSERT INTO 'media' VALUES (4362, 1013, 1, 'BRHCD48', 2011, 1);
INSERT INTO 'media' VALUES (4363, 1014, 1, 'Six-Sixty', 2007, 1);
INSERT INTO 'media' VALUES (4364, 1015, 1, 'BRHCD57', 2011, 1);
INSERT INTO 'media' VALUES (4365, 1016, 1, 'NRSCDS110', 2011, 1);
INSERT INTO 'media' VALUES (4405, 231, 1, 'BRHCD82', 2013, 1);
INSERT INTO 'media' VALUES (4407, 1052, 1, '', 0, 1);
INSERT INTO 'media' VALUES (4408, 1053, 1, 'WAG004', 2013, 1);
INSERT INTO 'media' VALUES (4406, 1051, 1, 'CBCD10', 2012, 1);
INSERT INTO 'media' VALUES (4409, 1054, 1, 'RSCDS CD075', 2013, 1);
INSERT INTO 'media' VALUES (4410, 1055, 1, 'TSC01MA', 2013, 1);
INSERT INTO 'media' VALUES (4411, 1056, 1, 'WACD0002', 2013, 1);
INSERT INTO 'media' VALUES (4412, 1057, 1, 'TRCD9905', 1999, 1);
INSERT INTO 'media' VALUES (4413, 1058, 1, 'DSMCD005', 2013, 1);
INSERT INTO 'media' VALUES (4414, 1059, 1, 'SSCD31', 2013, 1);
INSERT INTO 'media' VALUES (4415, 1060, 1, 'RSCDSWPG1', 2013, 1);
INSERT INTO 'media' VALUES (4416, 1061, 1, 'BRCD074', 2013, 1);
INSERT INTO 'media' VALUES (4124, 503, 1, '', 2001, 1);
INSERT INTO 'media' VALUES (4417, 1062, 1, 'BRCD062 (2 disks)', 2011, NULL);
INSERT INTO 'media' VALUES (4418, 1063, 1, 'CM111', 2014, 1);
INSERT INTO 'media' VALUES (4419, 1064, 1, 'LBSDB04', 2014, 1);
INSERT INTO 'media' VALUES (4421, 1066, 1, 'HONKY2', 2012, 1);
INSERT INTO 'media' VALUES (4422, 1067, 1, 'IMCD2013', 2013, 1);
INSERT INTO 'media' VALUES (4423, 1068, 1, 'SKYC5030', 2010, 1);
INSERT INTO 'media' VALUES (4424, 1069, 1, 'JMM2013', 2013, 1);
INSERT INTO 'media' VALUES (4425, 1070, 1, 'BRHCD90', 2013, 1);
INSERT INTO 'media' VALUES (4426, 1071, 1, 'BRHCD85', 2013, 1);
INSERT INTO 'media' VALUES (4427, 1072, 1, 'BRHCD84', 2013, 1);
INSERT INTO 'media' VALUES (4428, 1073, 1, 'BRHCD88', 2013, 1);
INSERT INTO 'media' VALUES (4429, 1074, 1, 'SMP001', 2014, 1);
INSERT INTO 'media' VALUES (4196, 788, 2, 'RWEP 652', 1966, 0);
INSERT INTO 'media' VALUES (4012, 391, 1, 'TRCD9906', 1999, NULL);
INSERT INTO 'media' VALUES (4394, 1042, 1, 'THISTLE108', 2006, 1);
INSERT INTO 'media' VALUES (3752, 170, 1, 'THISTLE104', 2005, 1);
INSERT INTO 'media' VALUES (3751, 170, 2, 'BSLPO 116S', 0, NULL);
INSERT INTO 'media' VALUES (4430, 1075, 1, 'RSCDS CD077', 2014, 1);
INSERT INTO 'media' VALUES (4431, 1076, 1, 'RSCDS CD078', 2014, 1);
INSERT INTO 'media' VALUES (4432, 1077, 1, 'RSCDS CD076', 2014, 1);
INSERT INTO 'media' VALUES (4433, 1078, 1, 'SC No 016085', 2014, NULL);
INSERT INTO 'media' VALUES (4434, 1079, 1, 'EBCD003', 2014, 1);
INSERT INTO 'media' VALUES (4435, 288, 2, 'SDL-002', 1966, 0);
INSERT INTO 'media' VALUES (4436, 1080, 1, 'LEEDS50CD', 2014, 1);
INSERT INTO 'media' VALUES (4015, 394, 1, 'BRG023CD', 2008, 1);
INSERT INTO 'media' VALUES (4437, 1081, 1, 'CD 24553', 2014, 1);
INSERT INTO 'media' VALUES (4438, 1082, 1, '3TRCD02', 2015, NULL);
INSERT INTO 'media' VALUES (3926, 315, 3, 'CDR 017', 0, NULL);
INSERT INTO 'media' VALUES (4440, 1083, 1, 'IMB015', 2015, 1);
INSERT INTO 'media' VALUES (4441, 352, 2, 'LILP 5005', 1974, 0);
INSERT INTO 'media' VALUES (4442, 352, 6, 'iTune', 0, 1);
INSERT INTO 'media' VALUES (4443, 1084, 1, 'CD080', 2015, 1);
INSERT INTO 'media' VALUES (4444, 1085, 1, 'HAPPY TARTAN', 2014, 1);
INSERT INTO 'media' VALUES (4445, 1086, 1, 'SHEFFCD60', 2015, NULL);
INSERT INTO 'media' VALUES (4446, 1087, 1, '', 2015, 1);
INSERT INTO 'media' VALUES (4447, 1088, 2, 'BSLP 81', 0, 0);
INSERT INTO 'media' VALUES (4420, 1065, 1, 'HONKY1', 199, 1);
INSERT INTO 'media' VALUES (4448, 1089, 4, 'SEPM 21', 1954, 0);
INSERT INTO 'media' VALUES (4449, 1090, 1, 'RSCDS CD082', 2016, 1);
INSERT INTO 'media' VALUES (4450, 1091, 1, 'RSCDS CD083', 2016, 1);
INSERT INTO 'media' VALUES (4451, 1092, 1, 'SFCD 02', 2016, 1);
INSERT INTO 'media' VALUES (4452, 1093, 1, 'TSC02MA', 2016, 1);
INSERT INTO 'media' VALUES (4453, 1094, 1, 'TC001', 2015, 1);
INSERT INTO 'media' VALUES (4454, 1095, 1, 'TSC12NM', 2016, 1);
INSERT INTO 'media' VALUES (4455, 1096, 1, 'IMB016', 2016, NULL);
INSERT INTO 'media' VALUES (4456, 1088, 1, 'Thistle101', 2005, 0);
INSERT INTO 'media' VALUES (4457, 1088, 6, '', 0, 1);
INSERT INTO 'media' VALUES (4458, 1097, 1, 'LBSDB05', 2015, 1);
INSERT INTO 'media' VALUES (4459, 1098, 1, 'RSCDSBB2016', 2016, 1);
INSERT INTO 'media' VALUES (4460, 1099, 1, '', 2013, NULL);
INSERT INTO 'media' VALUES (4387, 1035, 1, 'BRG-Live', 2012, 1);
INSERT INTO 'media' VALUES (4461, 1100, 1, 'RSCDS-NS-01', 2017, 1);
INSERT INTO 'media' VALUES (4462, 1101, 1, 'RSCDS-CD084', 2017, 1);
INSERT INTO 'media' VALUES (4463, 1102, 1, 'SBCD001', 2017, 1);
INSERT INTO 'media' VALUES (4464, 175, 6, 'CD Baby SO05257234', 2017, 1);
INSERT INTO 'media' VALUES (4465, 1103, 1, 'SMP002-CD', 2017, 1);
INSERT INTO 'media' VALUES (4466, 1104, 1, '', 2017, 1);
INSERT INTO 'media' VALUES (4467, 1105, 1, 'SSCD32', 2017, 1);
INSERT INTO 'media' VALUES (4469, 1107, 1, 'BLCD002', 2017, 1);
INSERT INTO 'media' VALUES (4468, 1106, 1, 'BLCD001', 2017, 1);
INSERT INTO 'media' VALUES (4470, 1108, 1, 'BLCD003', 2017, 1);
INSERT INTO 'media' VALUES (4475, 1112, 6, 'RSCDS Homepage login / Media / Audio, Video / DuK MMM remastert', 0, NULL);
INSERT INTO 'media' VALUES (3867, 268, 2, 'DER 1042', 0, 0);
INSERT INTO 'media' VALUES (4476, 1113, 1, 'RSCDS-CD085', 2018, 1);
INSERT INTO 'media' VALUES (4477, 1114, 1, 'TSC41MA', 2018, 1);
INSERT INTO 'media' VALUES (4075, 455, 1, 'SSCD 17', 2004, 1);
INSERT INTO 'media' VALUES (4478, 1115, 1, 'BBDCD1', 0, 1);
INSERT INTO 'media' VALUES (4480, 1117, 1, 'CDBB002', 0, 1);
INSERT INTO 'media' VALUES (4479, 1116, 1, 'CDBB003', 0, 1);
INSERT INTO 'media' VALUES (4481, 1118, 1, 'HBT010', 2018, 1);
INSERT INTO 'media' VALUES (4482, 1119, 1, 'TSC21JL', 2019, 1);
INSERT INTO 'media' VALUES (4483, 1120, 1, 'WYR201901', 2019, 1);
INSERT INTO 'media' VALUES (4485, 1121, 2, 'RSCDS 20', 0, 1);
INSERT INTO 'media' VALUES (4486, 1121, 3, 'RSCDS 20', 0, 1);
INSERT INTO 'media' VALUES (4488, 203, 1, '', 2017, 1);
INSERT INTO 'media' VALUES (4059, 438, 1, 'SW02', 2003, 1);
INSERT INTO 'media' VALUES (4489, 1122, 1, 'RM1901', 2019, 1);
INSERT INTO 'media' VALUES (4490, 1123, 1, 'CM113', 0, NULL);
INSERT INTO 'media' VALUES (4491, 1124, 1, '', 2020, 1);
INSERT INTO 'media' VALUES (4492, 1125, 1, '', 2020, NULL);
INSERT INTO 'media' VALUES (4493, 1126, 1, '', 1997, NULL);
INSERT INTO 'media' VALUES (3827, 233, 1, 'HH021', 2002, 1);
INSERT INTO 'media' VALUES (4494, 1127, 1, '', 0, NULL);
INSERT INTO 'media' VALUES (4495, 1128, 1, '', 2018, NULL);
INSERT INTO 'media' VALUES (4496, 1130, 2, 'CBS 52697', 1969, NULL);
INSERT INTO 'media' VALUES (4497, 1131, 2, 'ZLP 2058', 1966, NULL);
INSERT INTO 'media' VALUES (4498, 1132, 2, 'STAL 5015', 1970, NULL);
INSERT INTO 'media' VALUES (4499, 1133, 2, 'STL5353', 1966, NULL);
INSERT INTO 'media' VALUES (4500, 1134, 1, '', 2019, 1);
INSERT INTO 'media' VALUES (4501, 1135, 1, '', 2021, NULL);
INSERT INTO 'media' VALUES (4502, 1136, 1, 'EGCD008', 2021, 1);
INSERT INTO 'media' VALUES (4503, 1137, 1, 'BCDS0602', 2021, 1);
INSERT INTO 'media' VALUES (4504, 1138, 1, 'CD074', 2014, 1);
INSERT INTO 'media' VALUES (4505, 1139, 1, 'DBCD01', 2019, 1);
INSERT INTO 'media' VALUES (4506, 1140, 1, 'JSCD0001', 2020, NULL);
INSERT INTO 'media' VALUES (4507, 1141, 1, '', 2020, 1);
INSERT INTO 'media' VALUES (4508, 1142, 1, '', 0, NULL);
INSERT INTO 'media' VALUES (4509, 1143, 1, 'GOSH081', 2008, 1);
INSERT INTO 'media' VALUES (3896, 293, 1, 'BRHCD39', 2000, 1);
INSERT INTO 'media' VALUES (4510, 1144, 1, 'DLR-D5', 2021, 1);
INSERT INTO 'media' VALUES (4511, 1145, 1, 'FMS 2088', 2000, NULL);
INSERT INTO 'media' VALUES (3627, 85, 1, 'CWSDCD001', 1997, 1);
INSERT INTO 'media' VALUES (3626, 85, 3, 'CWSDMC001', 1997, 1);
INSERT INTO 'media' VALUES (4512, 167, 1, 'TAC 004-CD', 0, 1);
INSERT INTO 'media' VALUES (4487, 177, 1, 'BRG 017-CD', 0, NULL);
INSERT INTO 'media' VALUES (4513, 1146, 1, '', 0, NULL);
INSERT INTO 'media' VALUES (4439, 1082, 6, '', 2015, 1);
INSERT INTO 'media' VALUES (4514, 1147, 6, '', 2013, 1);
INSERT INTO 'media' VALUES (4098, 477, 2, 'Rediffusion ZS 147 (UK) / Olympic Records OL-6174 (US)', 1973, 0);
INSERT INTO 'media' VALUES (4515, 1150, 1, '', 2017, 1);
INSERT INTO 'media' VALUES (4516, 348, 2, 'Crest International ‎CRINT 107', 0, NULL);
INSERT INTO 'media' VALUES (4517, 348, 6, '', 0, NULL);
INSERT INTO 'media' VALUES (4518, 348, 2, 'Crest International ‎CRINT 107', 1968, NULL);
INSERT INTO 'media' VALUES (4519, 348, 6, '', 1968, NULL);
INSERT INTO 'media' VALUES (4198, 800, 2, 'SCL-1264', 1969, 0);
INSERT INTO 'media' VALUES (4520, 1151, 2, 'SCL-1258', 1968, NULL);
INSERT INTO 'media' VALUES (4521, 1152, 2, 'Decca SPA 154', 1971, NULL);
INSERT INTO 'media' VALUES (4522, 1153, 1, 'Scotdisc 723', 2005, 1);
INSERT INTO 'media' VALUES (4523, 1154, 1, 'Ythan Music LEGACY20CD', 0, NULL);
INSERT INTO 'media' VALUES (4524, 1155, 1, 'Ythan Music LEGACY21CD', 0, NULL);
INSERT INTO 'media' VALUES (4525, 1156, 1, 'Ythan Music LEGACY34CD', 0, NULL);
INSERT INTO 'media' VALUES (4526, 1157, 1, 'Ythan Music LEGACY35CD', 0, NULL);
INSERT INTO 'media' VALUES (4527, 1158, 1, 'Ythan Music LEGACY31CD', 0, NULL);
INSERT INTO 'media' VALUES (4528, 1159, 1, 'Ythan Music LEGACY31CD', 0, NULL);
INSERT INTO 'media' VALUES (4530, 1161, 1, 'Ythan Music LEGACY39CD', 0, NULL);
INSERT INTO 'media' VALUES (4529, 1160, 1, 'Ythan Music LEGACY38CD', 0, NULL);
INSERT INTO 'media' VALUES (4531, 1162, 1, 'TOKAI001', 2023, 1);


--
INSERT INTO 'mediatype' VALUES (1, 'Compact Disc', 'CD', 10);
INSERT INTO 'mediatype' VALUES (6, 'MP3 File', 'MP3', 20);
INSERT INTO 'mediatype' VALUES (2, 'Long-Playing Record', 'LP', 30);
INSERT INTO 'mediatype' VALUES (4, 'EP Record', 'EP', 31);
INSERT INTO 'mediatype' VALUES (3, 'MusiCassette', 'MC', 40);
INSERT INTO 'mediatype' VALUES (5, '78-RPM Record', '78', 50);


--
INSERT INTO 'medleytype' VALUES (34, 'J48+S64+R48', 'J048S064R048');
INSERT INTO 'medleytype' VALUES (1, 'S16+R16', 'S016R016');
INSERT INTO 'medleytype' VALUES (2, 'S64+R64', 'S064R064');
INSERT INTO 'medleytype' VALUES (10026, 'R32+S32+J32', 'R032S032J032');
INSERT INTO 'medleytype' VALUES (35, 'S60+R60', 'S060R060');
INSERT INTO 'medleytype' VALUES (3, 'S96+R96', 'S096R096');
INSERT INTO 'medleytype' VALUES (10027, 'X32+S32+R32', 'X032S032R032');
INSERT INTO 'medleytype' VALUES (4, 'S40+R40', 'S040R040');
INSERT INTO 'medleytype' VALUES (36, 'S48+R56', 'S048R056');
INSERT INTO 'medleytype' VALUES (5, 'S32+R32', 'S032R032');
INSERT INTO 'medleytype' VALUES (6, 'S16+R16+J16', 'S016R016J016');
INSERT INTO 'medleytype' VALUES (39, 'S24+R48', 'S024R048');
INSERT INTO 'medleytype' VALUES (7, 'S40+J40', 'S040J040');
INSERT INTO 'medleytype' VALUES (8, 'S16+J16', 'S016J016');
INSERT INTO 'medleytype' VALUES (40, 'J16+S16', 'J016S016');
INSERT INTO 'medleytype' VALUES (9, 'R24+S24', 'R024S024');
INSERT INTO 'medleytype' VALUES (10, 'S80+R80', 'S080R080');
INSERT INTO 'medleytype' VALUES (41, 'R128+S96+J136', 'R128S096J136');
INSERT INTO 'medleytype' VALUES (11, 'S48+R48', 'S048R048');
INSERT INTO 'medleytype' VALUES (12, 'R16+S16', 'R016S016');
INSERT INTO 'medleytype' VALUES (42, 'S32+R64', 'S032R064');
INSERT INTO 'medleytype' VALUES (13, 'S64+J64', 'S064J064');
INSERT INTO 'medleytype' VALUES (14, 'S24+R24', 'S024R024');
INSERT INTO 'medleytype' VALUES (49, 'J96+S64+R120', 'J096S064R120');
INSERT INTO 'medleytype' VALUES (15, 'R40+S40+R40', 'R040S040R040');
INSERT INTO 'medleytype' VALUES (16, 'J24+S72+J24', 'J024S072J024');
INSERT INTO 'medleytype' VALUES (50, 'S64+R16', 'S064R016');
INSERT INTO 'medleytype' VALUES (17, 'S32+J32', 'S032J032');
INSERT INTO 'medleytype' VALUES (18, 'S48+R64', 'S048R064');
INSERT INTO 'medleytype' VALUES (51, 'R64+S64', 'R064S064');
INSERT INTO 'medleytype' VALUES (53, 'R72+S40+R84', 'R072S040R084');
INSERT INTO 'medleytype' VALUES (19, 'S64+R48', 'S064R048');
INSERT INTO 'medleytype' VALUES (54, 'S48+J48', 'S048J048');
INSERT INTO 'medleytype' VALUES (20, 'R32+S64+R32', 'R032S064R032');
INSERT INTO 'medleytype' VALUES (55, 'S128+R128', 'S128R128');
INSERT INTO 'medleytype' VALUES (56, 'R32+J32+R32', 'R032J032R032');
INSERT INTO 'medleytype' VALUES (21, 'J32+S32+R32', 'J032S032R032');
INSERT INTO 'medleytype' VALUES (57, 'J80+S64+R64', 'J080S064R064');
INSERT INTO 'medleytype' VALUES (22, 'R32+S32', 'R032S032');
INSERT INTO 'medleytype' VALUES (58, 'J24+J24', 'J024J024');
INSERT INTO 'medleytype' VALUES (59, 'S144+R144', 'S144R144');
INSERT INTO 'medleytype' VALUES (23, 'S32+R32+S64', 'S032R032S064');
INSERT INTO 'medleytype' VALUES (60, 'J32+S32', 'J032S032');
INSERT INTO 'medleytype' VALUES (24, 'J48+S48+J48', 'J048S048J048');
INSERT INTO 'medleytype' VALUES (61, 'S16+J16+R16', 'S016J016R016');
INSERT INTO 'medleytype' VALUES (62, 'S48+R80', 'S048R080');
INSERT INTO 'medleytype' VALUES (25, 'S16+R24', 'S016R024');
INSERT INTO 'medleytype' VALUES (63, 'J48+S48', 'J048S048');
INSERT INTO 'medleytype' VALUES (27, 'S32+R72', 'S032R072');
INSERT INTO 'medleytype' VALUES (9998, 'Display', 'Z');
INSERT INTO 'medleytype' VALUES (28, 'S32+R40', 'S032R040');
INSERT INTO 'medleytype' VALUES (10000, 'S128+J128', 'S128J128');
INSERT INTO 'medleytype' VALUES (29, 'S32+J80', 'S032J080');
INSERT INTO 'medleytype' VALUES (10001, 'R128+S88+R128', 'R128S088R128');
INSERT INTO 'medleytype' VALUES (10002, 'X128+S64+R96', 'X128S064R096');
INSERT INTO 'medleytype' VALUES (33, 'X16+W16+P16', 'X016W016P016');
INSERT INTO 'medleytype' VALUES (10003, 'J128+S64+R96', 'J128S064R096');
INSERT INTO 'medleytype' VALUES (10004, 'J192+R64', 'J192R064');
INSERT INTO 'medleytype' VALUES (10005, 'S64+R96', 'S064R096');
INSERT INTO 'medleytype' VALUES (10006, 'S16+R16+S16+R16', 'S016R016S016R016');
INSERT INTO 'medleytype' VALUES (10007, 'S32+R32+S32', 'S032R032S032');
INSERT INTO 'medleytype' VALUES (10008, 'S32+R32+R48', 'S032R032R048');
INSERT INTO 'medleytype' VALUES (10009, 'S96+J96', 'S096J096');
INSERT INTO 'medleytype' VALUES (10010, 'R48+S48+J48', 'R048S048J048');
INSERT INTO 'medleytype' VALUES (10011, 'S48+R88', 'S048R088');
INSERT INTO 'medleytype' VALUES (10012, 'J56+S32+R128', 'J056S032R128');
INSERT INTO 'medleytype' VALUES (10013, 'R16+R96+R16', 'R016R096R016');
INSERT INTO 'medleytype' VALUES (10014, 'X64+S48+R32', 'X064S048R032');
INSERT INTO 'medleytype' VALUES (10015, 'X64+S32+R48', 'X064S032R048');
INSERT INTO 'medleytype' VALUES (10016, 'X64+S32+R32', 'X064S032R032');
INSERT INTO 'medleytype' VALUES (10017, 'S32+R32+R64', 'S032R032R064');
INSERT INTO 'medleytype' VALUES (10018, 'S48+R96', 'S048R096');
INSERT INTO 'medleytype' VALUES (10019, 'R32+S64', 'R032S064');
INSERT INTO 'medleytype' VALUES (10020, 'S32+R32+S32+R32', 'S032R032S032R032');
INSERT INTO 'medleytype' VALUES (10021, 'S48+J48', 'S048J048');
INSERT INTO 'medleytype' VALUES (10023, 'S16+R32', 'S016R032');
INSERT INTO 'medleytype' VALUES (10028, 'R32+S32+R32', 'R032S032R032');
INSERT INTO 'medleytype' VALUES (10029, 'S32+S32+J32', 'S032S032J032');
INSERT INTO 'medleytype' VALUES (10030, 'S32+R48', 'S032R048');
INSERT INTO 'medleytype' VALUES (10031, 'X128+J192', 'X128J192');
INSERT INTO 'medleytype' VALUES (10033, 'J16+S16+R16', 'J016S016R016');
INSERT INTO 'medleytype' VALUES (10034, 'S32+S32+R32+R32', 'S032S032R032R032');
INSERT INTO 'medleytype' VALUES (10038, 'R32+S32+J32+S32', 'R032S032J032S032');
INSERT INTO 'medleytype' VALUES (10040, 'S32+S32+J32+J32', 'S032S032J032J032');
INSERT INTO 'medleytype' VALUES (10041, 'S24+J24', 'S024J024');
INSERT INTO 'medleytype' VALUES (10043, 'Min64+J64', 'M064J064');
INSERT INTO 'medleytype' VALUES (10044, 'R64+J64', 'R064J064');
INSERT INTO 'medleytype' VALUES (10046, 'S32+R128', 'S032R128');
INSERT INTO 'medleytype' VALUES (10047, 'S32+J32+S32+J32', 'S032J032S032J032');
INSERT INTO 'medleytype' VALUES (10049, 'S32+J48', 'S032J048');
INSERT INTO 'medleytype' VALUES (10050, 'W64+R64', 'W064R064');
INSERT INTO 'medleytype' VALUES (10051, 'S56+R24', 'S056R024');
INSERT INTO 'medleytype' VALUES (10052, 'R16+J16+S16', 'R016J016S016');
INSERT INTO 'medleytype' VALUES (10053, 'S32+J32+J32', 'S032J032J032');
INSERT INTO 'medleytype' VALUES (9999, '-', 'A');
INSERT INTO 'medleytype' VALUES (10022, 'J48+S48+R48', 'J048S048R048');
INSERT INTO 'medleytype' VALUES (10035, 'R32+W32+S32+R32', 'R032W032S032R032');
INSERT INTO 'medleytype' VALUES (10042, 'R72+S72', 'R072S072');
INSERT INTO 'medleytype' VALUES (10032, 'S120+J120', 'S120J120');
INSERT INTO 'medleytype' VALUES (10045, 'S160+R160', 'S160R160');
INSERT INTO 'medleytype' VALUES (10039, 'S32+R80', 'S032R080');
INSERT INTO 'medleytype' VALUES (10025, 'S64+R122', 'S064R122');
INSERT INTO 'medleytype' VALUES (10037, 'S64+R32', 'S064R032');
INSERT INTO 'medleytype' VALUES (10036, 'S64+R64+S64', 'S064R064S064');
INSERT INTO 'medleytype' VALUES (10024, 'S16+R32+S16', 'S016R032S016');
INSERT INTO 'medleytype' VALUES (10048, 'S48+J64+S48', 'S048J064S048');
INSERT INTO 'medleytype' VALUES (10054, 'S48+R48+S48+R48+S48', 'S048R048S048R048S048');


--
INSERT INTO 'person' VALUES (10603, '2012-02-07 10:15:06.55507+00', '2012-02-07 10:15:06.55508+00', 'Deeay Music', 'Deeay Music', 'Deeay Music', 'Forfar', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10604, '2012-02-09 00:47:07.384128+00', '2012-02-09 00:47:07.384138+00', 'Henderson, Elizabeth', '', 'Liz Henderson', 'Lothian Branch', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (18, NULL, '2012-01-20 12:54:06.936009+00', 'Bain, Captain James', '', 'Captain James Bain', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (19, NULL, '2012-01-20 12:54:06.938544+00', 'Banton SCD class', '', 'Banton SCD class', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3, NULL, '2012-01-20 12:54:06.897333+00', 'Adams, Florence H', '', 'Florence H Adams', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (20, NULL, '2012-01-20 12:54:06.941077+00', 'Baptie, Margot', '', 'Margot Baptie', 'Sydney Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (22, NULL, '2012-01-20 12:54:06.946142+00', 'Barbour, Ian & Hilary', '', 'Ian & Hilary Barbour', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (23, NULL, '2012-01-20 12:54:06.948688+00', 'Barnes, Elizabeth Lee', '', 'Elizabeth Lee Barnes', 'Washington DC, USA', 'thistledance@erols.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (6, NULL, '2012-01-20 12:54:06.905004+00', 'Anderson, Jean', '', 'Jean Anderson', 'Toronto', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (24, NULL, '2012-01-20 12:54:06.95123+00', 'Harvey, Carolynn', '', 'Carolynn Harvey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (7, NULL, '2012-01-20 12:54:06.907562+00', 'Ardbrae Dancers', '', 'Ardbrae Dancers', 'Ottawa', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (26, NULL, '2012-01-20 12:54:06.956466+00', 'Bayly, John', '', 'John Bayly', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (8, NULL, '2012-01-20 12:54:06.910123+00', 'Argyll Dancers', '', 'Argyll Dancers', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (9, NULL, '2012-01-20 12:54:06.91267+00', 'Arrowsmith, Ron', '', 'Ron Arrowsmith', 'Vancouver, B.C.', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (27, NULL, '2012-01-20 12:54:06.959001+00', 'Beattie, Bob', '', 'Bob Beattie', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10, NULL, '2012-01-20 12:54:06.915539+00', 'Yates, E M', '', 'E M Yates', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11, NULL, '2012-01-20 12:54:06.918127+00', 'Ashbourne Highland Gathering', '', 'Ashbourne Highland Gathering', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (28, NULL, '2012-01-20 12:54:06.961533+00', 'Bell, Dorothy', '', 'Dorothy Bell', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (14, NULL, '2012-01-20 12:54:06.925815+00', 'Auckland Region, New Zealand Branch', '', 'Auckland Region New Zealand Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11600, '2018-02-20 23:13:35.45809+00', '2018-02-21 00:56:04.790554+00', 'Brown, Douglas', '', 'Douglas Brown', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (31, NULL, '2012-01-20 12:54:06.969134+00', 'Bestwick, Roger', '', 'Roger Bestwick', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (33, NULL, '2012-01-20 12:54:06.974199+00', 'Blair, Christopher', '', 'Christopher Blair', 'Newcastle-Upon-Tyne', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10601, '2012-02-06 11:30:27.083144+00', '2012-02-06 11:30:27.083154+00', 'Esson, Chas. Jnr', '', 'Chas. Esson Jnr.', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (52, NULL, '2012-01-20 12:54:07.023144+00', 'Brown Twins', '', 'Brown Twins', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (53, NULL, '2012-01-20 12:54:07.025814+00', 'Brown, Mary McCulloch', '', 'Mary McCulloch Brown', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (55, NULL, '2012-01-20 12:54:07.030922+00', 'Brunett, G', '', 'G Brunett', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (56, NULL, '2012-01-20 12:54:07.033462+00', 'Bullivant, Fiona', '', 'Fiona Bullivant', 'Sydney, Aust', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (58, NULL, '2012-01-20 12:54:07.038548+00', 'Burrage, Priscilla / Miskoe, Sylvia', '', 'Burrage, Priscilla / Miskoe, Sylvia', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (59, NULL, '2012-01-20 12:54:07.041376+00', 'Butterfield, Romaine', '', 'Romaine Butterfield', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (60, NULL, '2012-01-20 12:54:07.043992+00', 'Mitchell, Gordon', '', 'Gordon Mitchell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (61, NULL, '2012-01-20 12:54:07.046544+00', 'Cambridge Scottish Society', '', 'Cambridge Scottish Society', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (62, NULL, '2012-01-20 12:54:07.04909+00', 'Campbell, Robert M', '', 'Robert M Campbell', 'Oakville, Ontario', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (64, NULL, '2012-01-20 12:54:07.054163+00', 'Maarseveen, Irene van', '', 'Irene van Maarseveen', '', 'scitech@lantic.net', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (65, NULL, '2012-01-20 12:54:07.056712+00', 'Candlich, Isobel W', '', 'Isobel W Candlich', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (66, NULL, '2012-01-20 12:54:07.059953+00', 'McFarland', '', 'McFarland', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (67, NULL, '2012-01-20 12:54:07.062636+00', 'Carson and others', '', 'Carson and others', 'Ontario', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (36, NULL, '2012-01-20 12:54:06.981805+00', 'Hyssett, Peter', '', 'Peter Hyssett', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (38, NULL, '2012-01-20 12:54:06.986905+00', 'Betsche, Rosi', '', 'Rosi Betsche', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (39, NULL, '2012-01-20 12:54:06.989587+00', 'Bourne, A A', '', 'A A Bourne', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (42, NULL, '2012-01-20 12:54:06.997385+00', 'Bowlen, Francine', '', 'Francine Bowlen', 'Melbourne, Aust', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (43, NULL, '2012-01-20 12:54:06.999926+00', 'Bowlen, Phil', '', 'Phil Bowlen', 'Melbourne, Aust', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (45, NULL, '2012-01-20 12:54:07.005012+00', 'Mathieson, N', '', 'N Mathieson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (46, NULL, '2012-01-20 12:54:07.007557+00', 'Bradford Reel Club', '', 'Bradford Reel Club', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10600, '2012-02-06 11:06:23.088037+00', '2013-01-06 22:02:30.804521+00', 'Sidlaw Music', 'Sidlaw Music', 'Sidlaw Music', 'Forfar', '', 0, 1, 0, 0, NULL, 0, 0, NULL, 'Iain Gent writes in jan 2013: I think this is Douglas Adamson who also publishes under Deeay Music.');
INSERT INTO 'person' VALUES (11601, '2018-03-06 00:13:58.551856+00', '2018-03-06 00:14:12.81411+00', 'McCourt, Lesley', '', 'Lesley McCourt', 'Oxford, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (48, NULL, '2012-01-20 12:54:07.012795+00', 'Bradley, Jenny', '', 'Jenny Bradley', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (362, NULL, '2012-01-20 12:54:07.837289+00', 'Smith, Lydia', '', 'Lydia Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (5, NULL, '2015-03-14 18:10:58.64847+00', 'Anderson, Allie', '', 'Allie Anderson', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (29, NULL, '2015-03-14 18:11:00.424254+00', 'Bentley, Michael Ross', '', 'Michael Ross Bentley', '', '', 1, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (34, NULL, '2015-03-14 18:11:00.922876+00', 'Blaschke, Ted', '', 'Ted Blaschke', 'Atlanta', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (68, NULL, '2015-03-14 18:11:03.239241+00', 'Cattell, Graham & Fay', '', 'Graham & Fay Cattell', 'London', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (21, NULL, '2017-05-11 08:25:50.649688+00', 'Barbour, Ian', '', 'Ian Barbour', 'Guisborough, Cleveland, UK', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (57, NULL, '2017-01-21 00:56:05.273349+00', 'Bulteel, Anthony', '', 'Anthony Bulteel', '', '', 1, 1, 0, 0, NULL, 1927, 2014, NULL, '');
INSERT INTO 'person' VALUES (63, NULL, '2017-06-03 09:30:12.819842+00', 'Wheadon, Joe', '', 'Joe Wheadon', 'Darmstadt, Germany', '', 1, 0, 0, 0, NULL, 1943, 0, NULL, '');
INSERT INTO 'person' VALUES (47, NULL, '2017-10-04 21:43:17.123574+00', 'Bradley, Barbara', '', 'Barbara Bradley', 'Cape Town', '', 1, 0, 0, 0, 447, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2, NULL, '2018-01-19 13:29:08.990126+00', 'Haynes, Derek and friends', '', 'Derek Haynes and friends', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (49, NULL, '2012-01-20 12:54:07.015415+00', 'Bradshaw, Caroline', '', 'Caroline Bradshaw', '', 'Caroline.Bradshaw@dial.pipex.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (69, NULL, '2012-01-20 12:54:07.067726+00', 'Catto, M A', '', 'M A Catto', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (15, NULL, '2021-02-25 13:29:14.761715+00', 'Zobel, Bill', '', 'Bill Zobel', '', 'billivan@cox.net', 1, 0, 0, 0, NULL, 0, 0, NULL, 'An article by Bill on his background and opinions about dancing appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/11/Reel-305-electronic.pdf#page=11|issue 305 of The Reel>>.');
INSERT INTO 'person' VALUES (1, NULL, '2021-07-30 18:57:58.907446+00', 'Rhodes, Harry', '', 'Harry Rhodes', ' Bethel, Gwynedd, Wales', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12, NULL, '2021-08-22 03:40:49.365411+00', 'Atlanta Branch RSCDS', '', 'Atlanta Branch RSCDS', 'Atlanta, USA', '', 0, 1, 0, 0, NULL, 1976, 0, NULL, '');
INSERT INTO 'person' VALUES (16, NULL, '2021-08-22 03:43:22.673994+00', 'Ayr Branch RSCDS', '', 'Ayr Branch RSCDS', 'Ayrshire, UK', '', 0, 1, 0, 0, NULL, 1933, 0, NULL, '');
INSERT INTO 'person' VALUES (25, NULL, '2021-08-22 03:48:06.163847+00', 'Bath Branch RSCDS', '', 'Bath Branch RSCDS', 'Bath, UK', '', 0, 1, 0, 0, NULL, 1948, 0, NULL, '');
INSERT INTO 'person' VALUES (32, NULL, '2021-08-22 03:55:15.228902+00', 'Birmingham Branch RSCDS', '', 'Birmingham Branch RSCDS', 'Birmingham, UK', '', 0, 1, 0, 0, NULL, 1946, 0, NULL, '');
INSERT INTO 'person' VALUES (37, NULL, '2021-08-22 03:57:18.431147+00', 'Boston Branch RSCDS', '', 'Boston Branch RSCDS', 'Boston, MA, USA', '', 0, 1, 0, 0, NULL, 1950, 0, NULL, '');
INSERT INTO 'person' VALUES (40, NULL, '2021-08-22 03:59:47.502059+00', 'Bournemouth Branch RSCDS', '', 'Bournemouth Branch RSCDS', 'Bournemouth, UK', '', 0, 1, 0, 0, NULL, 1965, 0, NULL, '');
INSERT INTO 'person' VALUES (70, NULL, '2012-01-20 12:54:07.07035+00', 'Chamoin, Liliane', '', 'Liliane Chamoin', '', '', 1, 0, 0, 0, NULL, 0, 1998, NULL, '');
INSERT INTO 'person' VALUES (71, NULL, '2012-01-20 12:54:07.072917+00', 'Champion, Greta', '', 'Greta Champion', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (87, NULL, '2012-01-20 12:54:07.115639+00', 'Cosh, James B', '', 'James B Cosh', 'Gifnock', '', 1, 1, 0, 0, NULL, 0, 1995, NULL, '');
INSERT INTO 'person' VALUES (72, NULL, '2012-01-20 12:54:07.07545+00', 'Chandler, Wendy', '', 'Wendy Chandler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (88, NULL, '2012-01-20 12:54:07.118212+00', 'Noden, Dick', '', 'Dick Noden', 'Leicester', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (89, NULL, '2012-01-20 12:54:07.120898+00', 'Coutts, Frank', '', 'Frank Coutts', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (73, NULL, '2012-01-20 12:54:07.077988+00', 'Chapple, Rosemary', '', 'Rosemary Chapple', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (90, NULL, '2012-01-20 12:54:07.123483+00', 'Cragg, Gale', '', 'Gale Cragg', 'Canada', '', 1, 0, 0, 0, NULL, 0, 2000, NULL, '');
INSERT INTO 'person' VALUES (74, NULL, '2012-01-20 12:54:07.080522+00', 'Charlton, Brian', '', 'Brian Charlton', 'Sydney, NSW Australia', 'briangcharlton@gmail.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (75, NULL, '2012-01-20 12:54:07.083846+00', 'Cheshire Branch RSCDS', '', 'Cheshire Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (76, NULL, '2012-01-20 12:54:07.08678+00', 'Chicago Branch RSCDS', '', 'Chicago Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (92, NULL, '2012-01-20 12:54:07.128567+00', 'Croydon & District Branch RSCDS', '', 'Croydon & District Branch RSCDS', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (77, NULL, '2012-01-20 12:54:07.089433+00', 'Clancey, W M', '', 'W M Clancey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (95, NULL, '2012-01-20 12:54:07.136203+00', 'Taylor, Alan', '', 'Alan Taylor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (79, NULL, '2012-01-20 12:54:07.094552+00', 'Bulmer, Hilda & Len', '', 'Hilda & Len Bulmer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (97, NULL, '2012-01-20 12:54:07.141284+00', 'Deep River Branch RSCDS', '', 'Deep River Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (81, NULL, '2012-01-20 12:54:07.099796+00', 'Clingan, Iris', '', 'Iris Clingan', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (100, NULL, '2012-01-20 12:54:07.148901+00', 'Murdoch, Archie', '', 'Archie Murdoch', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (83, NULL, '2012-01-20 12:54:07.105431+00', 'Caldwell, Wyn', '', 'Wyn Caldwell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (85, NULL, '2012-01-20 12:54:07.110518+00', 'Conway, Jean', '', 'Jean Conway', 'Canberra, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (103, NULL, '2012-01-20 12:54:07.156527+00', 'Dingley, Keith W', '', 'Keith W Dingley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (106, NULL, '2012-01-20 12:54:07.164202+00', 'Doncaster RSCDS', '', 'Doncaster RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (107, NULL, '2012-01-20 12:54:07.166743+00', 'Douglas, Jean', '', 'Jean Douglas', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (109, NULL, '2012-01-20 12:54:07.171821+00', 'Duewell, Heinz', '', 'Heinz Duewell', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (78, NULL, '2012-01-20 12:54:07.092005+00', 'Clark, Evelyn', '', 'Evelyn Clark', 'Toronto', '', 1, 0, 0, 0, 78, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (125, NULL, '2012-01-20 12:54:07.229516+00', 'Fleming, Betty / Henry, Angus & Puka', '', 'Fleming, Betty / Henry, Angus & Puka', 'NT Branch, Aust', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (126, NULL, '2012-01-20 12:54:07.23207+00', 'Fleming, Jim', '', 'Jim Fleming', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (131, NULL, '2012-01-20 12:54:07.244951+00', 'Russell, Peter', '', 'Peter Russell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (132, NULL, '2012-01-20 12:54:07.247491+00', 'Fraser', '', 'Fraser', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (133, NULL, '2012-01-20 12:54:07.250024+00', 'Fredericton SCD Group', '', 'Fredericton SCD Group', 'Canada', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (134, NULL, '2012-01-20 12:54:07.252562+00', 'French, Nancy', '', 'Nancy French', 'Newport, Fife', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11603, '2018-03-11 09:11:25.999913+00', '2018-03-12 00:56:23.792518+00', 'Stausberg, Joana', '', 'Joana Stausberg', 'Bonn, DE', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (136, NULL, '2012-01-20 12:54:07.257635+00', 'Fyfe, Jim', '', 'Jim Fyfe', 'Crewe', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (137, NULL, '2012-01-20 12:54:07.260717+00', 'Gair, Daphne', '', 'Daphne Gair', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (138, NULL, '2012-01-20 12:54:07.263312+00', 'Cairngorm Dancers', '', 'Cairngorm Dancers', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (139, NULL, '2012-01-20 12:54:07.26585+00', 'Gallamore, Sandy & Scotty', '', 'Sandy & Scotty Gallamore', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (141, NULL, '2012-01-20 12:54:07.270932+00', 'Gibbs, Margaret', '', 'Margaret Gibbs', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (142, NULL, '2012-01-20 12:54:07.273466+00', 'Gillies, Andrew', '', 'Andrew Gillies', '', '', 1, 0, 0, 0, NULL, 1920, 2002, NULL, '');
INSERT INTO 'person' VALUES (143, NULL, '2012-01-20 12:54:07.276019+00', 'Gilroy, Elizabeth D', '', 'Elizabeth D Gilroy', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (110, NULL, '2012-01-20 12:54:07.174357+00', 'Panting, Dave', '', 'Dave Panting', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (111, NULL, '2012-01-20 12:54:07.17691+00', 'Duigenan, John', '', 'John Duigenan', 'Ottawa', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (112, NULL, '2012-01-20 12:54:07.17945+00', 'Dundee Branch RSCDS', '', 'Dundee Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (113, NULL, '2012-01-20 12:54:07.181983+00', 'Dunedin Dancers', '', 'Dunedin Dancers', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (114, NULL, '2012-01-20 12:54:07.184517+00', 'Hitchens, Derek', '', 'Derek Hitchens', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (115, NULL, '2012-01-20 12:54:07.187051+00', 'Duns and District Branch', '', 'Duns and District Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (91, NULL, '2018-04-03 15:44:40.654948+00', 'Cramb, Isobel', '', 'Isobel Cramb', 'Aberdeen', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Also known as "Tibbie Cramb".');
INSERT INTO 'person' VALUES (498, NULL, '2012-01-20 12:54:08.192556+00', 'Ashton, Jimmy', '', 'Jimmy Ashton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (119, NULL, '2012-01-20 12:54:07.214166+00', 'Edinburgh Branch RSCDS', '', 'Edinburgh Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (120, NULL, '2012-01-20 12:54:07.216732+00', 'Edwards, Bob', '', 'Bob Edwards', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (102, NULL, '2014-07-12 18:51:51.728097+00', 'Dodwell, Joan', '', 'Joan Dodwell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (122, NULL, '2012-01-20 12:54:07.221864+00', 'Ferguson, Geraldine', '', 'Geraldine Ferguson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (123, NULL, '2012-01-20 12:54:07.224416+00', 'Fidler, Roy', '', 'Roy Fidler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (512, NULL, '2012-01-20 12:54:08.235735+00', 'Rigby, Nicola', '', 'Nicola Rigby', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (84, NULL, '2015-07-08 23:56:13.641959+00', 'Kerr, Tom', '', 'Tom Kerr', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (94, NULL, '2016-06-26 22:23:31.789838+00', 'Davison, Lily', '', 'Lily Davison', 'Elizabeth, South Australia', '', 1, 1, 0, 0, NULL, 0, 2013, NULL, '');
INSERT INTO 'person' VALUES (128, NULL, '2019-01-26 06:33:49.355072+00', 'Forbes, Eric', '', 'Eric Forbes', 'RSCDS Birmingham', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (130, NULL, '2019-10-26 15:37:03.254855+00', 'Jamieson, Gordon', '', 'Gordon Jamieson', 'Shetland', '', 0, 0, 1, 0, NULL, 1947, 2005, NULL, '');
INSERT INTO 'person' VALUES (124, NULL, '2012-01-20 12:54:07.226967+00', 'Fifty First Club Johannesburg', '', 'Fifty First Club Johannesburg', 'South Africa', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (145, NULL, '2012-01-20 12:54:07.281095+00', 'Glover, Robert E', '', 'Robert E Glover', '', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (163, NULL, '2012-01-20 12:54:07.327039+00', 'Hague District Branch RSCDS', '', 'Hague District Branch RSCDS', 'Netherlands', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (99, NULL, '2020-04-22 20:54:49.19911+00', 'Derrick, Lewis N', '', 'Lewis N Derrick', '', 'lewisderrick27@virginmedia.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (127, NULL, '2021-02-25 15:25:01.976684+00', 'Forbes, Bill', '', 'Bill Forbes', '', '', 1, 1, 0, 0, NULL, 1921, 2016, NULL, 'John Fletcher’s tribute to the late Bill Forbes appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2016/12/Reel-297.pdf#page=8|issue 297 of The Reel>>.');
INSERT INTO 'person' VALUES (121, NULL, '2021-04-16 22:49:34.117145+00', 'Emmerson, George S', '', 'George S Emmerson', 'London, Ontario, Canada', '', 1, 1, 0, 0, NULL, 0, 2001, NULL, '');
INSERT INTO 'person' VALUES (93, NULL, '2021-10-18 13:28:52.924303+00', 'Cumming, A Leslie', '', 'A Leslie Cumming', 'Canberra, Australia', '', 1, 0, 1, 0, NULL, 1926, 2021, NULL, '');
INSERT INTO 'person' VALUES (164, NULL, '2012-01-20 12:54:07.32959+00', 'Halifax-Dartmouth Branch', '', 'Halifax-Dartmouth Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (165, NULL, '2012-01-20 12:54:07.332127+00', 'Hall, Tom', '', 'Tom Hall', 'Banchory', 'hall20@supanet.com', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11635, '2018-05-22 17:34:38.773212+00', '2018-05-22 17:36:15.658757+00', 'Horne, Sylvie', '', 'Sylvie Horne', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (169, NULL, '2012-01-20 12:54:07.342272+00', 'Macintyre, Charles', '', 'Charles Macintyre', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (140, NULL, '2023-01-08 00:56:22.392295+00', 'Georgeson, Tom', '', 'Tom Georgeson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (170, NULL, '2012-01-20 12:54:07.344839+00', 'Hamilton, Jo & Kass, Susie Langdon', '', 'Hamilton, Jo & Kass, Susie Langdon', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (171, NULL, '2012-01-20 12:54:07.347382+00', 'Handy, E H Jr', '', 'E H Jr Handy', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (172, NULL, '2012-01-20 12:54:07.349975+00', 'Harrison, Anne', '', 'Anne Harrison', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (173, NULL, '2012-01-20 12:54:07.352557+00', 'Hay, Alec', '', 'Alec Hay', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (176, NULL, '2012-01-20 12:54:07.360336+00', 'Henderson, Douglas', '', 'Douglas Henderson', 'Dundee', '', 1, 1, 0, 0, NULL, 0, 1987, NULL, '');
INSERT INTO 'person' VALUES (177, NULL, '2012-01-20 12:54:07.362875+00', 'Henderson, Jean', '', 'Jean Henderson', 'East Lothian', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (178, NULL, '2012-01-20 12:54:07.365447+00', 'Henderson, Jocelyn', '', 'Jocelyn Henderson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (180, NULL, '2012-01-20 12:54:07.370514+00', 'Hill, Frederick (M/S 1840)', '', 'Frederick (M/S 1840) Hill', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (148, NULL, '2012-01-20 12:54:07.288779+00', 'Goddard, I / Sizer, R / Stoddard, R', '', 'Goddard, I / Sizer, R / Stoddard, R', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (150, NULL, '2012-01-20 12:54:07.293929+00', 'Gordon, Pat', '', 'Pat Gordon', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (154, NULL, '2012-01-20 12:54:07.304165+00', 'Gray, Alex', '', 'Alex Gray', 'Cardiff', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (155, NULL, '2012-01-20 12:54:07.306701+00', 'Gray, Frances', '', 'Frances Gray', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (156, NULL, '2012-01-20 12:54:07.30925+00', 'Green, Jeff', '', 'Jeff Green', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (157, NULL, '2012-01-20 12:54:07.311796+00', 'Green, Nell', '', 'Nell Green', 'Sydney Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (158, NULL, '2012-01-20 12:54:07.314332+00', 'Davidson', '', 'Davidson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (160, NULL, '2012-01-20 12:54:07.31944+00', 'Grubb, Dr', '', 'Dr Grubb', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (161, NULL, '2012-01-20 12:54:07.321974+00', 'MacLennan, Jean', '', 'Jean MacLennan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (162, NULL, '2012-01-20 12:54:07.324505+00', 'Guisborough SCD Club', '', 'Guisborough SCD Club', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (181, NULL, '2012-01-20 12:54:07.373057+00', 'Holden, Anna Campbell', '', 'Anna Campbell Holden', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (182, NULL, '2012-01-20 12:54:07.375594+00', 'Holland, Philippa', '', 'Philippa Holland', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (183, NULL, '2012-01-20 12:54:07.378121+00', 'Honolulu Branch RSCDS', '', 'Honolulu Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (199, NULL, '2012-01-20 12:54:07.419111+00', 'Johnston, Ian', '', 'Ian Johnston', 'Glasgow', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (184, NULL, '2012-01-20 12:54:07.380659+00', 'Houston, Jean', '', 'Jean Houston', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (201, NULL, '2012-01-20 12:54:07.424247+00', 'Smith, A / Levine, B', '', 'A Smith / B Levine', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (202, NULL, '2012-01-20 12:54:07.426788+00', 'Jordan, Andrew', '', 'Andrew Jordan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (203, NULL, '2012-01-20 12:54:07.429319+00', 'Joyce, Doreen', '', 'Doreen Joyce', 'NSW Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (186, NULL, '2012-01-20 12:54:07.385736+00', 'Howard, Mary', '', 'Mary Howard', 'Sheerness', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (204, NULL, '2012-01-20 12:54:07.431857+00', 'Katzberg, Ferne', '', 'Ferne Katzberg', 'Canada', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (187, NULL, '2012-01-20 12:54:07.388282+00', 'Hudson, Judith', '', 'Judith Hudson', 'Sydney, Aust', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (205, NULL, '2012-01-20 12:54:07.434397+00', 'Keir, Betty', '', 'Betty Keir', 'Perth', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (206, NULL, '2012-01-20 12:54:07.437062+00', 'Kendall, Ian', '', 'Ian Kendall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (189, NULL, '2012-01-20 12:54:07.393389+00', 'Hunter, L.M', '', 'L.M Hunter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (190, NULL, '2012-01-20 12:54:07.395923+00', 'Hutchings, Eddie', '', 'Eddie Hutchings', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (191, NULL, '2012-01-20 12:54:07.39846+00', 'Illawarra Scottish Country Dancers', '', 'Illawarra Scottish Country Dancers', 'NSW Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (211, NULL, '2012-01-20 12:54:07.449791+00', 'Ker, Bruce', '', 'Bruce Ker', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (192, NULL, '2012-01-20 12:54:07.401007+00', 'Imperial Society of Teachers of Dancing', '', 'Imperial Society of Teachers of Dancing', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (193, NULL, '2012-01-20 12:54:07.40355+00', 'Innes-Russell, W', '', 'W Innes-Russell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (194, NULL, '2012-01-20 12:54:07.406085+00', 'Island Bay SCD Club', '', 'Island Bay SCD Club', 'New Zealand', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (213, NULL, '2012-01-20 12:54:07.454878+00', 'Kincaid, Pat', '', 'Pat Kincaid', 'Toronto Ontario', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (195, NULL, '2012-01-20 12:54:07.408628+00', 'Iwasawa, Takashi', '', 'Takashi Iwasawa', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (196, NULL, '2012-01-20 12:54:07.41122+00', 'Jamieson, Marie', '', 'Marie Jamieson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (214, NULL, '2012-01-20 12:54:07.457417+00', 'King, Russell', '', 'Russell King', 'San Francisco', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (200, NULL, '2013-08-29 12:48:47.917802+00', 'Johnstone, Jackie', '', 'Jackie Johnstone', '', '', 1, 1, 0, 0, NULL, 1923, 2007, NULL, 'Born in Lochmaben, jan 1923');
INSERT INTO 'person' VALUES (215, NULL, '2012-01-20 12:54:07.460709+00', 'Kingston Ontario Branch', '', 'Kingston Ontario Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (216, NULL, '2012-01-20 12:54:07.463314+00', 'Brooks, Barbara', '', 'Barbara Brooks', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (144, NULL, '2015-03-14 18:11:08.546116+00', 'Glasgow Branch RSCDS', '', 'Glasgow Branch RSCDS', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (209, NULL, '2017-06-20 10:22:58.475686+00', 'Kent, Pat', '', 'Pat Kent', 'Nova Scotia', '', 1, 1, 0, 0, NULL, 1936, 2014, NULL, '');
INSERT INTO 'person' VALUES (179, NULL, '2015-03-14 18:11:10.651888+00', 'Henderson, Margaret', '', 'Margaret Henderson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (147, NULL, '2019-08-06 08:30:29.343984+00', 'Gonnella, R / Murray, E', '', 'Ron Gonnella and Evelyn Murray', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (149, NULL, '2017-12-28 10:04:15.317322+00', 'Gordon, Sara L', '', 'Sara L. Gordon', 'Newmains, Lanarkshire', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (152, NULL, '2017-08-19 12:50:45.60633+00', 'Grant, Betty', '', 'Betty Grant', 'Toronto, Canada', '', 1, 0, 0, 0, NULL, 1923, 2005, NULL, '');
INSERT INTO 'person' VALUES (159, NULL, '2017-10-13 23:36:27.483437+00', 'Grime, Arnold', '', 'Arnold Grime', 'Darwen SD Group (nr. Blackburn, UK)', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11866, '2019-08-30 18:50:34.166635+00', '2019-08-30 23:56:17.1049+00', 'Manson, R', '', 'R Manson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (219, NULL, '2012-01-20 12:54:07.470938+00', 'Lawrie, Mary Jane', '', 'Mary Jane Lawrie', 'Sydney, Aust', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (246, NULL, '2012-02-02 10:40:15.921228+00', 'Macpherson, Alan', '', 'Alan Macpherson', 'Larbert', 'amdmac@blueyonder.co.uk', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (235, NULL, '2012-01-20 12:54:07.512023+00', 'London Branch RSCDS', '', 'London Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (220, NULL, '2012-01-20 12:54:07.473473+00', 'Chardon d''Ecosse, Le', '', 'Le Chardon d''Ecosse', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (198, NULL, '2021-01-07 20:18:00.05434+00', 'Johnson (18C), Jno', '', 'Jno Johnson (18C)', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Jno is a diminutive for John.');
INSERT INTO 'person' VALUES (207, NULL, '2021-03-02 15:23:06.830246+00', 'Kellett, Wendy', '', 'Wendy Kellett', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (185, NULL, '2021-03-12 09:44:20.080818+00', 'Howarth, Nicola', '', 'Nicola Howarth', 'Cambridge, UK', 'nicola@gtl.com', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Nicola has climbed all 282 Munros.');
INSERT INTO 'person' VALUES (153, NULL, '2021-05-23 12:30:36.099638+00', 'Grant, Neil M', '', 'Neil M Grant', 'Forres, Scotland', '', 1, 0, 0, 0, NULL, 1942, 0, NULL, '');
INSERT INTO 'person' VALUES (167, NULL, '2021-10-18 13:51:20.471884+00', 'Hamilton, Bill', '', 'Bill Hamilton', 'Edinburgh', '', 1, 0, 0, 0, NULL, 0, 2021, NULL, '');
INSERT INTO 'person' VALUES (221, NULL, '2012-01-20 12:54:07.476012+00', 'Leamington Spa Branch', '', 'Leamington Spa Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (238, NULL, '2012-01-20 12:54:07.51971+00', 'MacCulloch, Phyllis', '', 'Phyllis MacCulloch', 'Montreal, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (222, NULL, '2012-01-20 12:54:07.478547+00', 'Leavett Brown, L R', '', 'L R Leavett Brown', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (239, NULL, '2012-01-20 12:54:07.522243+00', 'MacGregor, Helen', '', 'Helen MacGregor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (241, NULL, '2012-01-20 12:54:07.527334+00', 'Keiller, Douglas', '', 'Douglas Keiller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (212, NULL, '2022-05-23 14:33:52.076119+00', 'Killeen, Joseph', '', 'Joseph Killeen', '', '', 1, 1, 0, 0, NULL, 0, 2022, NULL, '');
INSERT INTO 'person' VALUES (224, NULL, '2012-01-20 12:54:07.483747+00', 'Leicester Branch RSCDS', '', 'Leicester Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (225, NULL, '2012-01-20 12:54:07.486292+00', 'Leslie, Malcolm W', '', 'Malcolm W Leslie', 'S.E.Qld, Aust', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (243, NULL, '2012-01-20 12:54:07.532425+00', 'Macfarlane, Iain', '', 'Iain Macfarlane', 'Hamilton,Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (226, NULL, '2012-01-20 12:54:07.488842+00', 'Lewis, Anne', '', 'Anne Lewis', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (245, NULL, '2012-01-20 12:54:07.537622+00', 'Maclachlan, Elizabeth', '', 'Elizabeth Maclachlan', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (247, NULL, '2012-01-20 12:54:07.542691+00', 'Marshall, Jess', '', 'Jess Marshall', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (230, NULL, '2012-01-20 12:54:07.499287+00', 'Liverpool Branch RSCDS', '', 'Liverpool Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (248, NULL, '2012-01-20 12:54:07.545229+00', 'McAdam, Jean', '', 'Jean McAdam', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (231, NULL, '2012-01-20 12:54:07.501831+00', 'Lockwood, Peter', '', 'Peter Lockwood', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (232, NULL, '2012-01-20 12:54:07.504361+00', 'Loeb, Arthur', '', 'Arthur Loeb', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (249, NULL, '2012-01-20 12:54:07.547763+00', 'McBryde, Peter', '', 'Peter McBryde', '', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (263, NULL, '2018-04-03 23:56:05.1735+00', 'Campbell, William (18C)', '', 'William (18C) Campbell', '', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (250, NULL, '2012-01-20 12:54:07.550295+00', 'McCarley, Jean B', '', 'Jean B McCarley', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (252, NULL, '2012-01-20 12:54:07.555417+00', 'McCormack, Avis', '', 'Avis McCormack', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (253, NULL, '2012-01-20 12:54:07.557946+00', 'McCulloch, Catherine', '', 'Catherine McCulloch', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (254, NULL, '2012-01-20 12:54:07.560576+00', 'McDonald, Janet', '', 'Janet McDonald', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (255, NULL, '2012-01-20 12:54:07.563129+00', 'MacKinnon, Helen', '', 'Helen MacKinnon', 'Melbourne, Aust', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (272, NULL, '2012-01-20 12:54:07.606344+00', 'Mitchell, Niall', '', 'Niall Mitchell', '', 'niall@rosniall.netscapeonline.co.uk', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (273, NULL, '2012-01-20 12:54:07.608886+00', 'Mitchell, Niall & Rosemary', '', 'Niall & Rosemary Mitchell', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (274, NULL, '2012-01-20 12:54:07.611613+00', 'Money, Margaret', '', 'Margaret Money', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (275, NULL, '2012-01-20 12:54:07.614209+00', 'Morris, Gary W', '', 'Gary W Morris', 'Wellington, New Zealand', 'bill.edginton@welcom.gen.nz', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (276, NULL, '2012-01-20 12:54:07.616754+00', 'Morrison, Rosalind', '', 'Rosalind Morrison', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (278, NULL, '2012-01-20 12:54:07.621884+00', 'Munro, Bobby', '', 'Bobby Munro', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (279, NULL, '2012-01-20 12:54:07.624491+00', 'Murison, Hamish S', '', 'Hamish S Murison', 'S.E.Qld Branch', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (281, NULL, '2012-01-20 12:54:07.629583+00', 'Neale, Keith & Anna', '', 'Keith & Anna Neale', 'Isle of Wight', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (283, NULL, '2012-01-20 12:54:07.634652+00', 'Nelson-Marlborough Region', '', 'Nelson-Marlborough Region', 'New Zealand', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (284, NULL, '2012-01-20 12:54:07.637198+00', 'New Forest Scottish Country Dancers', '', 'New Forest Scottish Country Dancers', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (285, NULL, '2012-01-20 12:54:07.639745+00', 'New Haven Branch, RSCDS', '', 'RSCDS New Haven Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (286, NULL, '2012-01-20 12:54:07.642286+00', 'New York RSCDS', '', 'New York RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (287, NULL, '2012-01-20 12:54:07.644826+00', 'New Zealand Branch RSCDS', '', 'New Zealand Branch RSCDS', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (257, NULL, '2012-01-20 12:54:07.56821+00', 'McCabe, Norma', '', 'Norma McCabe', 'Nowra, NSW, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (258, NULL, '2012-01-20 12:54:07.570752+00', 'Carston, Stan', '', 'Stan Carston', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (259, NULL, '2012-01-20 12:54:07.573286+00', 'McColl, Jeanetta', '', 'Jeanetta McColl', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (228, NULL, '2013-01-18 12:43:11.245889+00', 'Lingnau, Anselm', '', 'Anselm Lingnau', 'Mainz, Germany', 'anselm@strathspey.org', 1, 1, 1, 0, NULL, 1966, 0, NULL, '');
INSERT INTO 'person' VALUES (260, NULL, '2012-01-20 12:54:07.575844+00', 'McConnell, Gloria', '', 'Gloria McConnell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (261, NULL, '2012-01-20 12:54:07.578387+00', 'McDougall, Matthew', '', 'Matthew McDougall', 'Sydney, Aust', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (262, NULL, '2012-01-20 12:54:07.580932+00', 'Melbourne Branch RSCDS', '', 'Melbourne Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (265, NULL, '2012-01-20 12:54:07.588558+00', 'Mercer, George', '', 'George Mercer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (282, NULL, '2014-07-12 18:52:17.565001+00', 'Nelson, Elisabeth', '', 'Elisabeth Nelson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (266, NULL, '2012-01-20 12:54:07.591095+00', 'Merrimack SC Dancers', '', 'Merrimack SC Dancers', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (267, NULL, '2012-01-20 12:54:07.593634+00', 'Metcalf, Walter', '', 'Walter Metcalf', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (268, NULL, '2012-01-20 12:54:07.596183+00', 'Millar, Bob', '', 'Bob Millar', 'Toronto', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (217, NULL, '2015-03-14 18:11:13.277062+00', 'Knapman, Peter', '', 'Peter Knapman', 'Glasgow', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (218, NULL, '2015-03-14 18:11:13.3238+00', 'Knight, Peter', '', 'Peter Knight', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (237, NULL, '2015-03-14 18:11:14.554647+00', 'Low', '', 'Low', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (289, NULL, '2015-03-14 18:11:19.681039+00', 'Newcastle upon Tyne Branch', '', 'Newcastle upon Tyne Branch', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (288, NULL, '2015-03-14 18:11:19.768295+00', 'New Zealand Dancer', '', 'New Zealand Dancer', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (251, NULL, '2015-03-15 05:20:07.255981+00', 'McConachie, Jack', '', 'Jack McConachie', '', '', 1, 1, 0, 0, NULL, 0, 1967, NULL, '');
INSERT INTO 'person' VALUES (256, NULL, '2015-03-19 08:38:04.756898+00', 'McAdoo, L. & McLeod, N.S.', '', 'McAdoo, L. & McLeod, N.S.', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (234, NULL, '2015-06-28 23:56:12.827848+00', 'Hughes, Veronica', '', 'Veronica Hughes', 'Brighouse', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (271, NULL, '2015-12-18 11:34:29.57536+00', 'Mitchell, John & Woods, Sheila', '', 'John Mitchell & Sheila Woods', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (236, NULL, '2016-09-04 23:56:14.475036+00', 'Los Angeles Branch USA', '', 'Los Angeles Branch USA', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11636, '2018-05-22 20:44:06.516204+00', '2018-05-22 20:44:06.516204+00', 'Pressley, Jack', '', 'Jack Pressley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (280, NULL, '2019-08-06 23:56:21.487883+00', 'Murray-Lenthall, Evelyn', '', 'Evelyn Murray-Lenthall', 'Boston USA', '', 1, 0, 0, 0, 3461, 0, 0, NULL, 'Evelyn Murray-Lenthall is now again using her maiden name Evelyn Murray.');
INSERT INTO 'person' VALUES (264, NULL, '2019-07-25 11:15:45.62184+00', 'Melin, Mats', '', 'Mats Melin', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (290, NULL, '2012-01-20 12:54:07.652432+00', 'Newport SDC Club', '', 'Newport SDC Club', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (307, NULL, '2012-01-20 12:54:07.696468+00', 'Pettie, Dorothy M', '', 'Dorothy M Pettie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (309, NULL, '2012-01-20 12:54:07.701542+00', 'Philip, Bill', '', 'Bill Philip', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (310, NULL, '2012-01-20 12:54:07.704069+00', 'Pinder, O', '', 'O Pinder', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (311, NULL, '2012-01-20 12:54:07.706598+00', 'Pine, Robert', '', 'Robert Pine', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (314, NULL, '2012-01-20 12:54:07.714356+00', 'Purdon, Andrew / Over, George', '', 'Purdon, Andrew and Over, George', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (223, NULL, '2021-08-22 03:28:45.810589+00', 'Leeds Branch RSCDS', '', 'Leeds Branch RSCDS', 'Leeds, UK', '', 1, 1, 0, 0, NULL, 1962, 0, NULL, '');
INSERT INTO 'person' VALUES (317, NULL, '2012-01-20 12:54:07.722108+00', 'Quinn, Peter', '', 'Peter Quinn', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (320, NULL, '2012-01-20 12:54:07.729715+00', 'Tokyo Branch RSCDS', '', 'Tokyo Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (321, NULL, '2012-01-20 12:54:07.732256+00', 'Rae Macintosh', '', 'Rae Macintosh', 'Edinburgh', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (322, NULL, '2012-01-20 12:54:07.734799+00', 'Reeves, Joan', '', 'Joan Reeves', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (291, NULL, '2012-01-20 12:54:07.654968+00', 'Organ, Cecilie', '', 'Cecilie Organ', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (292, NULL, '2012-01-20 12:54:07.657508+00', 'Northallerton Caledonian Society', '', 'Northallerton Caledonian Society', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (293, NULL, '2012-01-20 12:54:07.660795+00', 'Northey, Tony', '', 'Tony Northey', 'Canberra, Aust', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (294, NULL, '2012-01-20 12:54:07.663435+00', 'Nottingham Branch RSCDS', '', 'Nottingham Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (295, NULL, '2012-01-20 12:54:07.665983+00', 'Ogg, C & Smart, A', '', 'Ogg, C & Smart, A', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (296, NULL, '2012-01-20 12:54:07.668523+00', 'Orange County Branch', '', 'Orange County Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (297, NULL, '2012-01-20 12:54:07.671061+00', 'Orlandi', '', 'Orlandi', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (299, NULL, '2012-01-20 12:54:07.676128+00', 'Ottawa Branch RSCDS', '', 'Ottawa Branch RSCDS', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (300, NULL, '2012-01-20 12:54:07.678664+00', 'Owen, Nancy', '', 'Nancy Owen', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (301, NULL, '2012-01-20 12:54:07.68122+00', 'Carr, George', '', 'George Carr', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (302, NULL, '2012-01-20 12:54:07.683759+00', 'Oxford Branch RSCDS', '', 'Oxford Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (303, NULL, '2012-01-20 12:54:07.686298+00', 'PEI Scottish Country Dancers', '', 'PEI Scottish Country Dancers', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (304, NULL, '2012-01-20 12:54:07.688835+00', 'Paterson, Andrew', '', 'Andrew Paterson', 'Bath', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (324, NULL, '2012-01-20 12:54:07.739869+00', 'Reynolds, Sam', '', 'Sam Reynolds', '', 'sam@SpinwardStars.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (325, NULL, '2012-01-20 12:54:07.742409+00', 'Roberts, Olivia', '', 'Olivia Roberts', 'Sydney, Aust', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (326, NULL, '2012-01-20 12:54:07.744956+00', 'Robertson, Iain Stuart', '', 'Iain Stuart Robertson', '', '', 1, 0, 1, 0, NULL, 1920, 1999, NULL, '');
INSERT INTO 'person' VALUES (327, NULL, '2012-01-20 12:54:07.747517+00', 'Robertson, Matthew', '', 'Matthew Robertson', 'Melbourne, Aust', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (342, NULL, '2012-01-20 12:54:07.786034+00', 'Scott, Margaret', '', 'Margaret Scott', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (343, NULL, '2012-01-20 12:54:07.788589+00', 'Scott, William C', '', 'William C Scott', 'Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (357, NULL, '2019-02-08 00:56:25.22528+00', 'Skye Branch RSCDS', '', 'Skye Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (345, NULL, '2012-01-20 12:54:07.793689+00', 'Shawyer, Bruce', '', 'Bruce Shawyer', 'Newfoundland', 'bshawyer@math.mun.ca', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (348, NULL, '2012-01-20 12:54:07.801316+00', 'Sigg, Claudette', '', 'Claudette Sigg', 'San Francisco', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (350, NULL, '2012-01-20 12:54:07.806382+00', 'Sinton, Margaret', '', 'Margaret Sinton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (351, NULL, '2012-01-20 12:54:07.808928+00', 'Sizer, Ralph', '', 'Ralph Sizer', 'Boston', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (354, NULL, '2012-01-20 12:54:07.816802+00', 'Skinner, Douglas G', '', 'Douglas G Skinner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (355, NULL, '2012-01-20 12:54:07.819394+00', 'Skipper, Ann / McLeod, Neil Stewart', '', 'Ann Skipper & Neil Stewart McLeod', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (358, NULL, '2012-01-20 12:54:07.827046+00', 'Smith, Alan', '', 'Alan Smith', 'Concord,Massachusetts', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (359, NULL, '2012-01-20 12:54:07.829615+00', 'Smith, Betty', '', 'Betty Smith', 'Belfast', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (328, NULL, '2012-01-20 12:54:07.750096+00', 'Rose', '', 'Rose', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (329, NULL, '2012-01-20 12:54:07.752726+00', 'Ross, Kathleen', '', 'Kathleen Ross', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (330, NULL, '2012-01-20 12:54:07.755286+00', 'Rothesay Branch', '', 'Rothesay Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (657, NULL, '2012-01-20 12:54:08.618722+00', 'Thompson, J C', '', 'J C Thompson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (323, NULL, '2012-09-11 13:15:26.376107+00', 'Reid, Frank Snr', '', 'Frank Reid Snr.', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (331, NULL, '2012-01-20 12:54:07.757825+00', 'Russell, Barbara', '', 'Barbara Russell', 'Boston USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (333, NULL, '2012-01-20 12:54:07.762915+00', 'South Dorset Caledonian Society', '', 'South Dorset Caledonian Society', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (334, NULL, '2012-01-20 12:54:07.765592+00', 'Sacramento Branch', '', 'Sacramento Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (335, NULL, '2012-01-20 12:54:07.768154+00', 'Buchanan, Doris', '', 'Doris Buchanan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (336, NULL, '2012-01-20 12:54:07.770698+00', 'Salt Lake Scottish Country Dancers', '', 'Salt Lake Scottish Country Dancers', 'Utah, USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (319, NULL, '2014-11-15 08:41:48.572756+00', 'RSCDS', '', 'RSCDS', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (339, NULL, '2012-01-20 12:54:07.778395+00', 'Castle Menzies (18C)', '', 'Castle Menzies (18C)', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (360, NULL, '2012-01-20 12:54:07.832189+00', 'Smith, Carol', '', 'Carol Smith', 'Wellington, NZ', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (361, NULL, '2012-01-20 12:54:07.834745+00', 'Smith, Kent W', '', 'Kent W Smith', 'Hartford, CT, US', 'kent.smith@trincoll.edu', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (305, NULL, '2015-03-14 18:11:20.733096+00', 'Peattie, Jack', '', 'Jack Peattie', 'Sydney, Aust', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (316, NULL, '2015-03-14 18:11:21.983567+00', 'Queen, David G', '', 'David G Queen', '', 'david.queen@btinternet.com', 1, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (337, NULL, '2015-03-14 18:11:24.078758+00', 'San Diego Branch', '', 'San Diego Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (340, NULL, '2015-03-14 18:13:01.718756+00', 'Scotscores', '', 'Scotscores', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (353, NULL, '2016-03-20 00:56:22.366615+00', 'Skiera, Nicholas', '', 'Nicholas Skiera', '', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (298, NULL, '2016-05-26 21:38:59.513793+00', 'Orlando Branch RSCDS', '', 'Orlando Branch RSCDS', 'FL, USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11884, '2019-09-26 14:23:49.218306+00', '2019-09-26 23:56:24.264535+00', 'Rooney, Di', '', 'Di Rooney', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (377, NULL, '2012-01-20 12:54:07.876019+00', 'Swirles, George', '', 'George Swirles', '', '', 1, 1, 0, 0, NULL, 1909, 2001, NULL, '');
INSERT INTO 'person' VALUES (379, NULL, '2012-01-20 12:54:07.881112+00', 'Sydney Branch RSCDS', '', 'Sydney Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (381, NULL, '2012-01-20 12:54:07.886191+00', 'Blake, Carol', '', 'Carol Blake', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (383, NULL, '2012-01-20 12:54:07.891282+00', 'Tartan Plaidie', '', 'Tartan Plaidie', 'Paris', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (384, NULL, '2012-01-20 12:54:07.893814+00', 'Taylor, Bob', '', 'Bob Taylor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (385, NULL, '2012-01-20 12:54:07.896353+00', 'Taylor, Colin', '', 'Colin Taylor', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (390, NULL, '2012-01-20 12:54:07.909082+00', 'Thomas, Gary & Wallace, Ron', '', 'Thomas, Gary & Wallace, Ron', 'Twin Cities Branch', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (391, NULL, '2012-01-20 12:54:07.911652+00', 'Wilson, Malcolm C', '', 'Malcolm C Wilson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (378, NULL, '2020-02-05 12:15:12.733772+00', 'Swirles and others, George', '', 'George Swirles and others', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (347, NULL, '2021-02-18 19:26:47.866581+00', 'Short, Mervyn C', '', 'Mervyn C Short', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, 'An article by Mervyn on his early days and dance devising can be found in <<https://www.rscdslondon.org.uk/wp-content/uploads/2019/11/Reel-309-electronic.pdf#page=9|The Reel 309>>.');
INSERT INTO 'person' VALUES (332, NULL, '2021-03-23 00:57:01.779183+00', 'Russell, Edna / McConachie, Jack', '', 'Edna Russell & Jack McConachie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (388, NULL, '2021-06-01 20:34:27.040228+00', 'Miller, Wilma', '', 'Wilma Miller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Duns and District Branch.');
INSERT INTO 'person' VALUES (341, NULL, '2021-10-18 14:08:51.313844+00', 'Scott, June', '', 'June Scott', 'Kingussie, Scotland', '', 1, 0, 0, 0, NULL, 0, 2021, NULL, '');
INSERT INTO 'person' VALUES (393, NULL, '2012-01-20 12:54:07.916816+00', 'Townley, Helen', '', 'Helen Townley', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (363, NULL, '2012-01-20 12:54:07.839824+00', 'South, James', '', 'James South', 'Brisbane, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (364, NULL, '2012-01-20 12:54:07.84236+00', 'Southport Branch RSCDS', '', 'Southport Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (365, NULL, '2012-01-20 12:54:07.844898+00', 'Sprague, Martin', '', 'Martin Sprague', 'South Dorset', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (366, NULL, '2012-01-20 12:54:07.847447+00', 'Springer, Alison', '', 'Alison Springer', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (367, NULL, '2012-01-20 12:54:07.849987+00', 'Saint Andrews Branch RSCDS', '', 'Saint Andrews Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (368, NULL, '2012-01-20 12:54:07.852536+00', 'St Mark''s Church, Aberdeen', '', 'Aberdeen St Mark''s Church', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (369, NULL, '2012-01-20 12:54:07.855092+00', 'Skeen, Ted', '', 'Ted Skeen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (371, NULL, '2012-01-20 12:54:07.860518+00', 'Stein, Ben', '', 'Ben Stein', '', 'dancers@compuserve.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (372, NULL, '2012-01-20 12:54:07.863108+00', 'Stephenson, J Trevor', '', 'J Trevor Stephenson', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11607, '2018-03-11 09:23:56.913012+00', '2018-03-12 00:56:18.759019+00', 'Naefe, Thomas', '', 'Thomas Naefe', 'München, DE', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (376, NULL, '2012-01-20 12:54:07.873439+00', 'Stone Scottish Country Dance Group', '', 'Stone Scottish Country Dance Group', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (395, NULL, '2012-01-20 12:54:07.921912+00', 'Twin Cities Branch RSCDS', '', 'Twin Cities Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (396, NULL, '2012-01-20 12:54:07.924448+00', 'Bide, Peter', '', 'Peter Bide', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (397, NULL, '2012-01-20 12:54:07.926985+00', 'Walsh (18C)', '', 'Walsh (18C)', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (432, NULL, '2018-04-03 23:56:27.82078+00', 'Wilson, Thomas (19C)', '', 'Thomas (19C) Wilson', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (412, NULL, '2012-01-20 12:54:07.965192+00', 'Western Australia Branch, RSCDS', '', 'Western Australia Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (413, NULL, '2012-01-20 12:54:07.967739+00', 'Wevers, John W', '', 'John W Wevers', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (414, NULL, '2012-01-20 12:54:07.970273+00', 'Whitworth, Ken', '', 'Ken Whitworth', 'Melbourne, Aust', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (415, NULL, '2012-01-20 12:54:07.97281+00', 'Wigan Thistle Society', '', 'Wigan Thistle Society', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (417, NULL, '2012-01-20 12:54:07.977885+00', 'Will, George', '', 'George Will', 'Vancouver', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (418, NULL, '2012-01-20 12:54:07.980424+00', 'Williamson, Arthur', '', 'Arthur Williamson', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (419, NULL, '2012-01-20 12:54:07.982962+00', 'Willson, K C & M', '', 'K C & M Willson', 'Papua, New Guinea', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (422, NULL, '2012-01-20 12:54:07.990598+00', 'Wolf, Anne', '', 'Anne Wolf', 'New Haven, USA', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (423, NULL, '2012-01-20 12:54:07.993128+00', 'Wood', '', 'Wood', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (424, NULL, '2012-01-20 12:54:07.995664+00', 'Wood, Erina', '', 'Erina Wood', 'Masterton New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (425, NULL, '2012-01-20 12:54:07.998194+00', 'Wood, John', '', 'John Wood', 'Nova Scotia', 'johnwood@accesscable.net', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (426, NULL, '2012-01-20 12:54:08.000737+00', 'York & North Humberside Branch', '', 'York & North Humberside Branch', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (427, NULL, '2012-01-20 12:54:08.003286+00', 'York SCD Club', '', 'York SCD Club', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (398, NULL, '2012-01-20 12:54:07.92952+00', 'Pilling, F L, & Successors', 'Pilling', 'F L Pilling & Successors', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (399, NULL, '2012-01-20 12:54:07.932071+00', 'Vancouver Branch, Canada', '', 'Canada Vancouver Branch', 'Canada', 'stewartc@bc.sympatico.ca', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (400, NULL, '2012-01-20 12:54:07.934609+00', 'Wallace, Jane', '', 'Jane Wallace', 'Ottawa, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (403, NULL, '2012-01-20 12:54:07.942254+00', 'Walton, John', '', 'John Walton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (404, NULL, '2012-01-20 12:54:07.944794+00', 'Wateraid - (Glasgow 1994)', '', 'Wateraid - (Glasgow 1994)', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (407, NULL, '2012-01-20 12:54:07.952428+00', 'Wellington Region, New Zealand Branch', '', 'New Zealand Branch Wellington Region', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (408, NULL, '2012-01-20 12:54:07.95502+00', 'West Lothian Branch RSCDS', '', 'West Lothian Branch RSCDS', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (409, NULL, '2012-01-20 12:54:07.957564+00', 'West Toronto Ball Committee', 'West Toronto Ball', 'West Toronto Ball Committee', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (386, NULL, '2014-06-17 01:02:37.271813+00', 'Taylor, Jim', '', 'Jim Taylor', '', '', 1, 0, 0, 0, NULL, 0, 1999, NULL, '');
INSERT INTO 'person' VALUES (410, NULL, '2012-01-20 12:54:07.960104+00', 'West Wittering Reel Club', '', 'West Wittering Reel Club', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (429, NULL, '2012-01-20 12:54:08.008374+00', 'Cameron, Jenny', '', 'Jenny Cameron', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (430, NULL, '2012-01-20 12:54:08.01219+00', 'Steele, Tom', '', 'Tom Steele', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (431, NULL, '2012-01-20 12:54:08.015123+00', 'Burnham, Maureen', '', 'Maureen Burnham', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (447, NULL, '2012-01-20 12:54:08.059164+00', 'Rendle-Braime, Barbara J.', '', 'Barbara J. Rendle-Braime', 'Somerset West, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (449, NULL, '2012-01-20 12:54:08.064396+00', 'Muir, Sheila', '', 'Sheila Muir', 'Croydon', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (513, NULL, '2012-01-20 12:54:08.238286+00', 'Wilson, Hilary', '', 'Hilary Wilson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (435, NULL, '2015-03-14 18:11:26.170123+00', 'Sproule, Vicky & Gillan, Sadie L.', '', 'Vicky Sproule & Sadie L. Gillan', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (389, NULL, '2015-03-14 18:11:27.243339+00', 'Thomas, Gary', '', 'Gary Thomas', '', 'GaryWThomas@cs.com', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (394, NULL, '2015-03-14 18:11:27.755596+00', 'Trew, John S', '', 'John S Trew', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (405, NULL, '2015-03-14 18:11:28.652663+00', 'Watson, G', '', 'G Watson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (370, NULL, '2015-08-18 16:00:24.508549+00', 'Stacey, Moira', '', 'Moira Stacey', 'Kirkcudbright, UK', 'moirastacey32@btinternet.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (428, NULL, '2015-09-04 16:46:40.483366+00', 'Chastelain, John de', '', 'John de Chastelain', 'Ottawa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (416, NULL, '2017-11-03 23:56:28.445414+00', 'Wilkie, Stanley', '', 'Stanley Wilkie', 'Edinburgh, Scotland', '', 1, 0, 0, 0, NULL, 1926, 2017, NULL, '');
INSERT INTO 'person' VALUES (11637, '2018-05-25 14:32:32.680105+00', '2018-05-25 23:56:05.158433+00', 'Brown, Malcolm & Volgina, Arina', '', 'Malcolm Brown & Arina Volgina', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (374, NULL, '2019-05-12 09:14:56.136562+00', 'Stuart, Jessie', '', 'Jessie Stuart', 'Dufftown', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (450, NULL, '2012-01-20 12:54:08.067076+00', 'Chamoin, Jacques & Liliane', '', 'Jacques & Liliane Chamoin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (452, NULL, '2012-01-20 12:54:08.072321+00', 'Mulligan, Martin', '', 'Martin Mulligan', '', 'mulligan@morgan.ucs.mun.ca', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (454, NULL, '2012-01-20 12:54:08.077875+00', 'Hamilton, Jessie', '', 'Jessie Hamilton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (456, NULL, '2012-01-20 12:54:08.083983+00', 'Gracie, Duncan', '', 'Duncan Gracie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (458, NULL, '2012-01-20 12:54:08.089338+00', 'Morris, Arthur', '', 'Arthur Morris', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (460, NULL, '2012-01-20 12:54:08.094422+00', 'Sutherland, John', '', 'John Sutherland', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (461, NULL, '2012-01-20 12:54:08.097213+00', 'Turnbull (19C)', '', 'Turnbull (19C)', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (462, NULL, '2012-01-20 12:54:08.100049+00', 'Huxley, Roz Scott', '', 'Roz Scott Huxley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (463, NULL, '2012-01-20 12:54:08.10284+00', 'Gaul, Linda C', '', 'Linda C Gaul', 'Pitlochry, Perthshire', 'the.gauls@btinternet.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11604, '2018-03-11 09:12:39.141504+00', '2018-03-12 00:56:09.359035+00', 'Fingerhuth, Judith', '', 'Judith Fingerhuth', 'Aalen, DE', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (437, NULL, '2012-01-20 12:54:08.03302+00', 'Central Kentucky Branch RSCDS', '', 'Central Kentucky Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (438, NULL, '2012-01-20 12:54:08.035706+00', 'Redfearn, Betty MacLellan', '', 'Betty MacLellan Redfearn', 'WInnipeg, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (441, NULL, '2012-01-20 12:54:08.043549+00', 'Motts, Judy', '', 'Judy Motts', 'Kingston-Waterloo, Ontario', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (444, NULL, '2012-01-20 12:54:08.051476+00', 'Drysdale, George', '', 'George Drysdale', 'Mombasa, Kenya', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (445, NULL, '2012-01-20 12:54:08.05402+00', 'Lowe, John', '', 'John Lowe', '', '', 1, 0, 1, 0, NULL, 1797, 1866, NULL, '');
INSERT INTO 'person' VALUES (446, NULL, '2012-01-20 12:54:08.05657+00', 'Playford', '', 'Playford', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (467, NULL, '2012-01-20 12:54:08.113424+00', 'Macdonald, Millicent', '', 'Millicent Macdonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (481, NULL, '2012-01-20 12:54:08.149233+00', 'Arton, Dorothy', '', 'Dorothy Arton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (483, NULL, '2012-01-20 12:54:08.154315+00', 'Monro', '', 'Monro', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (406, NULL, '2022-02-18 09:33:21.79621+00', 'Ways, Harry C', '', 'Harry C Ways', 'Potomac, MD, USA', '', 1, 1, 0, 0, NULL, 0, 2013, NULL, '');
INSERT INTO 'person' VALUES (448, NULL, '2022-06-01 12:32:19.709735+00', 'Timmins, Andrew', '', 'Andrew Timmins', 'Sindelfingen, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Formerly of Adelaide, Australia.');
INSERT INTO 'person' VALUES (451, NULL, '2022-12-26 10:48:06.691212+00', 'Mulligan, Martin / Shawyer, Bruce', '', 'Martin Mulligan & Bruce Shawyer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (484, NULL, '2012-01-20 12:54:08.156857+00', 'Mitchell, H P C', '', 'H P C Mitchell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (485, NULL, '2012-01-20 12:54:08.159399+00', 'Goulding (18C)', '', 'Goulding (18C)', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (486, NULL, '2012-01-20 12:54:08.161954+00', 'Cruickshank, Helen / Thomson, Heather', '', 'Cruickshank, Helen / Thomson, Heather', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (487, NULL, '2012-01-20 12:54:08.164508+00', 'Richards, Joan', '', 'Joan Richards', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (490, NULL, '2012-01-20 12:54:08.172179+00', 'Wilson, D J O', '', 'D J O Wilson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (491, NULL, '2012-01-20 12:54:08.174727+00', 'Watson, Michael', '', 'Michael Watson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (492, NULL, '2012-01-20 12:54:08.177265+00', 'Brown, Wilson', '', 'Wilson Brown', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (468, NULL, '2018-04-03 23:56:04.87902+00', 'Cahusac (18C)', '', 'Cahusac (18C)', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (494, NULL, '2012-01-20 12:54:08.182339+00', 'Currie, L, A & D', '', 'Currie, L, A & D', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (495, NULL, '2012-01-20 12:54:08.184883+00', 'Anderson, Margaret', '', 'Margaret Anderson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (496, NULL, '2012-01-20 12:54:08.187422+00', 'Brandon, Mary Shoolbraid / Smith, Stewart', '', 'Mary Shoolbraid Brandon / Stewart Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (497, NULL, '2012-01-20 12:54:08.189965+00', 'Mueller, Eberhard', '', 'Eberhard Mueller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (469, NULL, '2012-01-20 12:54:08.118517+00', 'Bishop', '', 'Bishop', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (470, NULL, '2012-01-20 12:54:08.121096+00', 'Smail, George', '', 'George Smail', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (472, NULL, '2012-01-20 12:54:08.126187+00', 'Gilroy, W H', '', 'W H Gilroy', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (473, NULL, '2012-01-20 12:54:08.128738+00', 'Craigmyle', '', 'Craigmyle', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (474, NULL, '2012-01-20 12:54:08.131375+00', 'Webster, W R', '', 'W R Webster', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (476, NULL, '2012-01-20 12:54:08.136503+00', 'Wood, Helen L', '', 'Helen L Wood', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (477, NULL, '2012-01-20 12:54:08.139053+00', 'Dewar, Catherine M', '', 'Catherine M Dewar', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (504, NULL, '2012-01-20 12:54:08.215218+00', 'Simcott', '', 'Simcott', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (506, NULL, '2012-01-20 12:54:08.220318+00', 'Everall, Roy', '', 'Roy Everall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (507, NULL, '2012-01-20 12:54:08.222871+00', 'Wright, Joan', '', 'Joan Wright', 'Burnley', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (508, NULL, '2012-01-20 12:54:08.225493+00', 'Briscoe, Ellie', '', 'Ellie Briscoe', 'Alexandria, Virginia', 'mail@briscoe.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (509, NULL, '2012-01-20 12:54:08.228044+00', 'Munz, Juergen', '', 'Juergen Munz', 'Edinburgh', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (510, NULL, '2012-01-20 12:54:08.230587+00', 'Taylor, Elma', '', 'Elma Taylor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (511, NULL, '2012-01-20 12:54:08.23318+00', 'Campbell, Shirley', '', 'Shirley Campbell', 'Leicester', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (503, NULL, '2015-03-14 18:11:23.253809+00', 'Roberts, P', '', 'P Roberts', 'Manchester', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (479, NULL, '2015-03-28 13:58:04.343583+00', 'Rae, Jim', '', 'Jim Rae', 'Lockerbie, Scotland', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (488, NULL, '2015-05-04 23:56:16.018871+00', 'MacKinnon, Gene A', '', 'Gene A MacKinnon', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (459, NULL, '2017-11-15 00:56:20.379797+00', 'Preston (18C)', '', 'Preston (18C)', '', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (500, NULL, '2017-09-03 13:20:46.37925+00', 'Frodsham, Jack', '', 'Jack Frodsham', 'Leamington Spa', '', 1, 0, 0, 0, NULL, 0, 2014, NULL, '');
INSERT INTO 'person' VALUES (505, NULL, '2017-02-07 20:05:06.114955+00', 'Brown, Stephen', '', 'Stephen Brown', 'Ribble Valley Branch, UK', 'stephenbrown07@btinternet.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (436, NULL, '2017-02-27 14:06:39.572837+00', 'Dryburgh, Frances', '', 'Frances Dryburgh', '', 'drywall@optusnet.com.au', 1, 0, 0, 0, 10433, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (502, NULL, '2017-10-13 09:16:22.909357+00', 'Goossen, Elizabeth', '', 'Elizabeth Goossen', 'Winnipeg', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'RSCDS Book 36 misspelt Elizabeth''s surname with only one S.');
INSERT INTO 'person' VALUES (482, NULL, '2017-11-15 00:56:19.308751+00', 'Owen, Robert', '', 'Robert Owen', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (466, NULL, '2017-11-15 00:56:24.664229+00', 'Thompson (18C)', '', 'Thompson (18C)', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (457, NULL, '2018-04-03 23:56:03.682272+00', 'Boag (18C), W', '', 'W Boag (18C)', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (514, NULL, '2012-01-20 12:54:08.24082+00', 'Elliott, Joyce', '', 'Joyce Elliott', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (515, NULL, '2012-01-20 12:54:08.243383+00', 'Wilkinson, John', '', 'John Wilkinson', '', 'JohnW@musselburgh21.freeserve.co.uk', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (516, NULL, '2012-01-20 12:54:08.245935+00', 'Gardner, Fiona & Jim', '', 'Fiona & Jim Gardner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (517, NULL, '2012-01-20 12:54:08.248474+00', 'Gardner, Jim', '', 'Jim Gardner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (518, NULL, '2012-01-20 12:54:08.251019+00', 'Adam, Stewart', '', 'Stewart Adam', '', 'sadam@tesco.net', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (519, NULL, '2012-01-20 12:54:08.253565+00', 'Ward, Catherine', '', 'Catherine Ward', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (520, NULL, '2012-01-20 12:54:08.256105+00', 'Hastings, Peter', '', 'Peter Hastings', '', 'P.Hastings@roe.ac.uk', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (521, NULL, '2012-01-20 12:54:08.258648+00', 'Archer, Pip', '', 'Pip Archer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (537, NULL, '2012-01-20 12:54:08.299611+00', 'Eddershaw, Basil', '', 'Basil Eddershaw', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11605, '2018-03-11 09:13:05.672318+00', '2018-03-12 00:56:12.696685+00', 'Hoffmann, Tim', '', 'Tim Hoffmann', 'Aalen, DE', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (539, NULL, '2012-01-20 12:54:08.304708+00', 'Thompson, Christine', '', 'Christine Thompson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (540, NULL, '2012-01-20 12:54:08.307254+00', 'Jameson, Janet', '', 'Janet Jameson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (541, NULL, '2012-01-20 12:54:08.309794+00', 'Robson, Norman & Helen', '', 'Norman & Helen Robson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (865, NULL, '2012-01-20 12:54:09.184498+00', 'Lockhart, G W', '', 'G W Lockhart', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (478, NULL, '2020-05-22 23:56:29.54883+00', 'Grant, Anne', '', 'Anne Grant', '', '', 1, 0, 1, 0, 3689, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (433, NULL, '2021-04-01 21:35:10.953004+00', 'Little, Bill', '', 'Bill Little', 'Castle Douglas, Scotland', '', 1, 0, 1, 0, NULL, 0, 2020, NULL, '');
INSERT INTO 'person' VALUES (489, NULL, '2021-04-11 23:19:08.257471+00', 'Seidelmann, Roswitha', '', 'Roswitha Seidelmann', 'Freiburg', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (542, NULL, '2012-01-20 12:54:08.312344+00', 'Bellerby, Sheila', '', 'Sheila Bellerby', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (543, NULL, '2012-01-20 12:54:08.314894+00', 'Scott, Doris', '', 'Doris Scott', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (544, NULL, '2012-01-20 12:54:08.317431+00', 'Armitage, Georgina', '', 'Georgina Armitage', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (545, NULL, '2012-01-20 12:54:08.319998+00', 'Peacocke, Hubert', '', 'Hubert Peacocke', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (546, NULL, '2012-01-20 12:54:08.322602+00', 'Tout, Cissie', '', 'Cissie Tout', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (547, NULL, '2012-01-20 12:54:08.325156+00', 'Archibald, Archie & Sheila', '', 'Archie & Sheila Archibald', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (548, NULL, '2012-01-20 12:54:08.327705+00', 'Brooke, Elizabeth', '', 'Elizabeth Brooke', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (551, NULL, '2012-01-20 12:54:08.335336+00', 'Watson, Martin', '', 'Martin Watson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (552, NULL, '2012-01-20 12:54:08.337879+00', 'Oswald, Diane', '', 'Diane Oswald', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (553, NULL, '2012-01-20 12:54:08.340413+00', 'Knox, Heather', '', 'Heather Knox', 'Linlithgow', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (522, NULL, '2012-01-20 12:54:08.261352+00', 'Douglas, John & Jan', '', 'John & Jan Douglas', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (523, NULL, '2012-01-20 12:54:08.263915+00', 'Bolton-Maggs, Tim', '', 'Tim Bolton-Maggs', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (526, NULL, '2012-01-20 12:54:08.271546+00', 'Lewis, Simon', '', 'Simon Lewis', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (528, NULL, '2012-01-20 12:54:08.276667+00', 'Barlow, Maureen', '', 'Maureen Barlow', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (529, NULL, '2012-01-20 12:54:08.279211+00', 'Ward, Philip', '', 'Philip Ward', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (530, NULL, '2012-01-20 12:54:08.28175+00', 'Marchand, Kevin', '', 'Kevin Marchand', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (475, NULL, '2022-11-12 18:39:00.634406+00', 'Smith, Ronald Morton', '', 'Ronald Morton Smith', 'Toronto, Ontario, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (501, NULL, '2022-12-20 00:56:36.331221+00', 'Levy, Milton', '', 'Milton Levy', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 1995, NULL, '');
INSERT INTO 'person' VALUES (534, NULL, '2012-01-20 12:54:08.291975+00', 'Boswell, Arthur C', '', 'Arthur C Boswell', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (536, NULL, '2012-01-20 12:54:08.297072+00', 'Tranter, Frank', '', 'Frank Tranter', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (556, NULL, '2012-01-20 12:54:08.348042+00', 'RSCDS Association of East Africa', '', 'RSCDS Association of East Africa', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (557, NULL, '2012-01-20 12:54:08.350671+00', 'Rogers, John', '', 'John Rogers', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (574, NULL, '2012-01-20 12:54:08.394453+00', 'Galway, Freda', '', 'Freda Galway', 'Belfast', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (575, NULL, '2012-01-20 12:54:08.397004+00', 'Burke, Kathrine', '', 'Kathrine Burke', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (576, NULL, '2012-01-20 12:54:08.399547+00', 'Beattie, Myra', '', 'Myra Beattie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (577, NULL, '2012-01-20 12:54:08.402094+00', 'Jordan, Margaret', '', 'Margaret Jordan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (578, NULL, '2012-01-20 12:54:08.404632+00', 'Ricketts, Doreen', '', 'Doreen Ricketts', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (579, NULL, '2012-01-20 12:54:08.407176+00', 'Annesley, Jean', '', 'Jean Annesley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (580, NULL, '2012-01-20 12:54:08.409715+00', 'Livingstone, Bob', '', 'Bob Livingstone', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (581, NULL, '2012-01-20 12:54:08.412329+00', 'Whyte, Murray', '', 'Murray Whyte', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (582, NULL, '2012-01-20 12:54:08.414882+00', 'Longstaff, Christopher', '', 'Christopher Longstaff', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (584, NULL, '2012-01-20 12:54:08.419974+00', 'MacLeod, Ewan M', '', 'Ewan M MacLeod', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (585, NULL, '2012-01-20 12:54:08.42251+00', 'Shawyer, Bruce & Jo', '', 'Bruce & Jo Shawyer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (586, NULL, '2012-01-20 12:54:08.425048+00', 'Hall, Robert A', '', 'Robert A Hall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (588, NULL, '2012-01-20 12:54:08.430136+00', 'Cuthbertson, Tom', '', 'Tom Cuthbertson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (590, NULL, '2012-01-20 12:54:08.435438+00', 'Heubner, Bobby', '', 'Bobby Heubner', 'Victoria, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (591, NULL, '2012-01-20 12:54:08.437981+00', 'Tague, David', '', 'David Tague', 'Westminster, CA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (592, NULL, '2012-01-20 12:54:08.440523+00', 'Draffin, David H', '', 'David H Draffin', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (593, NULL, '2012-01-20 12:54:08.443208+00', 'Burt, Don', '', 'Don Burt', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (559, NULL, '2012-01-20 12:54:08.355797+00', 'Donald, Sandy', '', 'Sandy Donald', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (560, NULL, '2012-01-20 12:54:08.358351+00', 'McCall, D M', '', 'D M McCall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (561, NULL, '2012-01-20 12:54:08.360898+00', 'Ferguson, Jean / Noden, Dick', '', 'Ferguson, Jean / Noden, Dick', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (562, NULL, '2012-01-20 12:54:08.363446+00', 'Chapman, Edith', '', 'Edith Chapman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (564, NULL, '2012-01-20 12:54:08.368545+00', 'Mather, D C', '', 'D C Mather', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (565, NULL, '2012-01-20 12:54:08.37109+00', 'Elliott, Tim', '', 'Tim Elliott', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (566, NULL, '2012-01-20 12:54:08.373628+00', 'Humphries, Norman', '', 'Norman Humphries', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (567, NULL, '2012-01-20 12:54:08.376206+00', 'Large, Anne', '', 'Anne Large', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (568, NULL, '2012-01-20 12:54:08.378748+00', 'Sharp, Ken', '', 'Ken Sharp', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (570, NULL, '2012-01-20 12:54:08.383832+00', 'Owen, Meg', '', 'Meg Owen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (571, NULL, '2012-01-20 12:54:08.386373+00', 'Seattle Branch RSCDS', '', 'Seattle Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (549, NULL, '2015-03-14 18:11:24.568486+00', 'Scott, John', '', 'John Scott', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (554, NULL, '2015-03-14 18:11:24.72355+00', 'Sennet, Vicky', '', 'Vicky Sennet', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (525, NULL, '2016-06-23 23:56:06.492993+00', 'Churnside, Norman', '', 'Norman Churnside', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (555, NULL, '2016-04-17 21:43:57.342457+00', 'Inglis, Charles', '', 'Charlie Inglis', 'Ottawa, Canada', 'charlie@saltire.ca', 1, 0, 0, 0, NULL, 1949, 0, NULL, 'Charlie wrote: Hi:  I prefer Charlie Inglis not Charles Inglis');
INSERT INTO 'person' VALUES (558, NULL, '2017-09-26 08:19:53.737103+00', 'Spägele, Rudi', '', 'Rudi Spägele', '', 'macrudi2004@yahoo.de', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (533, NULL, '2018-01-19 13:29:44.975478+00', 'Haynes, Derek & Gradon, John', '', 'Haynes, Derek & Gradon, John', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (535, NULL, '2018-01-20 00:56:12.850137+00', 'Harmsworth, Ian', '', 'Ian Harmsworth', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (572, NULL, '2012-01-20 12:54:08.388914+00', 'Barnes, Ruth', '', 'Ruth Barnes', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (573, NULL, '2012-01-20 12:54:08.391906+00', 'Jones, Daphne', '', 'Daphne Jones', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11606, '2018-03-11 09:21:01.688632+00', '2018-03-12 00:56:17.682604+00', 'Melsbach, Aileen / Melsbach, Manuel / Brick, Alex', 'Melsbach/Brick', 'Aileen & Manuel Melsbach / Alex Brick', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (596, NULL, '2012-01-20 12:54:08.451024+00', 'Crawford, Catherine B', '', 'Catherine B Crawford', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (597, NULL, '2012-01-20 12:54:08.453592+00', 'Chapman, Edith N', '', 'Edith N Chapman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (614, NULL, '2012-01-20 12:54:08.497028+00', 'Bothell, Joan', '', 'Joan Bothell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (615, NULL, '2012-01-20 12:54:08.502172+00', 'Baker, Joan', '', 'Joan Baker', 'Los Angeles', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (616, NULL, '2012-01-20 12:54:08.505498+00', 'Horwill, David', '', 'David Horwill', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (617, NULL, '2012-01-20 12:54:08.508788+00', 'Steventon, Howard', '', 'Howard Steventon', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (618, NULL, '2012-01-20 12:54:08.51214+00', 'Ivory, Derek', '', 'Derek Ivory', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (620, NULL, '2012-01-20 12:54:08.518727+00', 'Jones, David', '', 'David Jones', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (621, NULL, '2012-01-20 12:54:08.522005+00', 'Collins, Allison', '', 'Allison Collins', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (939, NULL, '2012-01-20 12:54:09.375891+00', 'Erskine, A M', '', 'A M Erskine', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (524, NULL, '2021-07-30 12:49:07.259786+00', 'Cass, Patricia', '', 'Patricia Cass', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (569, NULL, '2021-08-22 03:50:23.078902+00', 'Belfast Branch RSCDS', '', 'Belfast Branch RSCDS', 'Belfast', '', 0, 1, 0, 0, NULL, 1947, 0, NULL, '');
INSERT INTO 'person' VALUES (583, NULL, '2021-11-08 11:22:59.986719+00', 'McLeod, Neil Stewart', '', 'Neil Stewart McLeod', 'California, USA', '', 1, 1, 0, 0, NULL, 1947, 0, NULL, '');
INSERT INTO 'person' VALUES (622, NULL, '2012-01-20 12:54:08.525202+00', 'Ferguson, Elizabeth', '', 'Elizabeth Ferguson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (623, NULL, '2012-01-20 12:54:08.527803+00', 'Stratford, Raynor M', '', 'Raynor M Stratford', 'Upper Hutt, NZ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (624, NULL, '2012-01-20 12:54:08.530332+00', 'Vinnall, Lillian', '', 'Lillian Vinnall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (626, NULL, '2012-01-20 12:54:08.535413+00', 'Truswell, Barbara', '', 'Barbara Truswell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (627, NULL, '2012-01-20 12:54:08.537944+00', 'Cannonito, Jan & Frank', '', 'Jan & Frank Cannonito', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (629, NULL, '2012-01-20 12:54:08.545932+00', 'Rennie, Jack', '', 'Jack Rennie', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (630, NULL, '2012-01-20 12:54:08.54846+00', 'Smith, Bessie', '', 'Bessie Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (631, NULL, '2012-01-20 12:54:08.550995+00', 'Fleming, Maureen', '', 'Maureen Fleming', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (598, NULL, '2012-01-20 12:54:08.456145+00', 'Saint Amand, Deanna', '', 'Deanna Saint Amand', 'Los Angeles', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (599, NULL, '2012-01-20 12:54:08.458702+00', 'Dairiki, Ned', '', 'Ned Dairiki', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (600, NULL, '2012-01-20 12:54:08.461261+00', 'Baxter, Jack', '', 'Jack Baxter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (601, NULL, '2012-01-20 12:54:08.463799+00', 'Cowie, Isobel', '', 'Isobel Cowie', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (602, NULL, '2012-01-20 12:54:08.466345+00', 'Pugh, Mary', '', 'Mary Pugh', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (603, NULL, '2012-01-20 12:54:08.468885+00', 'Dickson, Rhona', '', 'Rhona Dickson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (604, NULL, '2012-01-20 12:54:08.471458+00', 'Sponseller, Cathy', '', 'Cathy Sponseller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (605, NULL, '2012-01-20 12:54:08.474001+00', 'Lumsden, Jean', '', 'Jean Lumsden', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (606, NULL, '2012-01-20 12:54:08.476622+00', 'Wilde, Ken', '', 'Ken Wilde', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (607, NULL, '2012-01-20 12:54:08.479189+00', 'Carmichael, Carmen', '', 'Carmen Carmichael', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (609, NULL, '2012-01-20 12:54:08.484297+00', 'Johnstone, Shirley', '', 'Shirley Johnstone', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (610, NULL, '2012-01-20 12:54:08.486848+00', 'Bradbury, Ron', '', 'Ron Bradbury', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (611, NULL, '2012-01-20 12:54:08.489392+00', 'Ayre, Betty', '', 'Betty Ayre', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (612, NULL, '2012-01-20 12:54:08.491932+00', 'Eder, Marjorie', '', 'Marjorie Eder', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (633, NULL, '2012-01-20 12:54:08.55606+00', 'MacNaughton, Angus', '', 'Angus MacNaughton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (634, NULL, '2012-01-20 12:54:08.558579+00', 'Baird, R & Brown, H', '', 'R Baird & H Brown', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (619, NULL, '2019-09-19 22:48:04.042461+00', 'Robertson, John', '', 'John Robertson', 'Perth  Scotland', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (652, NULL, '2012-01-20 12:54:08.60608+00', 'Loch Awe House SCD class', '', 'Loch Awe House SCD class', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (653, NULL, '2012-01-20 12:54:08.608622+00', 'Bowlen, Lawrie', '', 'Lawrie Bowlen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (654, NULL, '2012-01-20 12:54:08.611144+00', 'Lister, Jean', '', 'Jean Lister', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (656, NULL, '2012-01-20 12:54:08.616193+00', 'Bell, Carol', '', 'Carol Bell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (658, NULL, '2012-01-20 12:54:08.62126+00', 'Fyfe, John', '', 'John Fyfe', '', 'JohnFyfe@rscds.ednet.co.uk', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (659, NULL, '2012-01-20 12:54:08.623796+00', 'Feinstein, Lee', '', 'Lee Feinstein', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (660, NULL, '2012-01-20 12:54:08.626323+00', 'Brown, Edna', '', 'Edna Brown', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (661, NULL, '2012-01-20 12:54:08.628857+00', 'Cheltenham Girls High School', '', 'Cheltenham Girls High School', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (662, NULL, '2012-01-20 12:54:08.631387+00', 'Moss, John', '', 'John Moss', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (663, NULL, '2012-01-20 12:54:08.633911+00', 'McMillan, Stewart', '', 'Stewart McMillan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (664, NULL, '2012-01-20 12:54:08.636432+00', 'Murrells, Jonathan', '', 'Jonathan Murrells', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (665, NULL, '2012-01-20 12:54:08.638962+00', 'Buik, Allan / Morgan, Nicholas', '', 'Allan Buik / Nicholas Morgan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (666, NULL, '2012-01-20 12:54:08.641491+00', 'Malley, Ann', '', 'Ann Malley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (667, NULL, '2012-01-20 12:54:08.644027+00', 'Damey, Lindell A', '', 'Lindell A Damey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (668, NULL, '2012-01-20 12:54:08.646567+00', 'Smith, Maureen & Bill', '', 'Maureen & Bill Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (669, NULL, '2012-01-20 12:54:08.6491+00', 'Beatty, E A', '', 'E A Beatty', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (670, NULL, '2012-01-20 12:54:08.651627+00', 'Chitts, Don', '', 'Don Chitts', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (636, NULL, '2012-01-20 12:54:08.563639+00', 'Moretti, Tony', '', 'Tony Moretti', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (637, NULL, '2012-01-20 12:54:08.566179+00', 'Henderson, Monique', '', 'Monique Henderson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (638, NULL, '2012-01-20 12:54:08.568708+00', 'Troup, Ruth', '', 'Ruth Troup', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (639, NULL, '2012-01-20 12:54:08.571229+00', 'Keswick SCD class', '', 'Keswick SCD class', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (641, NULL, '2012-01-20 12:54:08.576287+00', 'Dempster, David', '', 'David Dempster', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (642, NULL, '2012-01-20 12:54:08.578811+00', 'Weiman, David', '', 'David Weiman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (643, NULL, '2012-01-20 12:54:08.583131+00', 'Duncan, Andrew', '', 'Andrew Duncan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (644, NULL, '2012-01-20 12:54:08.585734+00', 'Traynor, Anna', '', 'Anna Traynor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (646, NULL, '2012-01-20 12:54:08.590817+00', 'Smith, Edna', '', 'Edna Smith', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (647, NULL, '2012-01-20 12:54:08.593351+00', 'Dunn, Norah', '', 'Norah Dunn', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (649, NULL, '2012-01-20 12:54:08.598401+00', 'White, Stuart', '', 'Stuart White', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (650, NULL, '2012-01-20 12:54:08.600928+00', 'Johnson, Peter', '', 'Peter Johnson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (651, NULL, '2012-01-20 12:54:08.603548+00', 'Inagaki, Shun', '', 'Shun Inagaki', 'Tokyo', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (632, NULL, '2015-03-14 18:11:08.656022+00', 'Goddard, Iain', '', 'Iain Goddard', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (613, NULL, '2015-03-14 18:11:21.903815+00', 'Purdon, Andrew', '', 'Andrew Purdon', '', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (608, NULL, '2015-03-14 18:11:26.500737+00', 'Stoddard, Ralph', '', 'Ralph Stoddard', '', 'caberfei@aol.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (595, NULL, '2015-09-24 04:33:26.973257+00', 'Ryer, Charles W (Chuck)', '', 'Charles W (Chuck) Ryer', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Nickname: Chuck Ryer');
INSERT INTO 'person' VALUES (672, NULL, '2012-01-20 12:54:08.65668+00', 'Zuparko, Robert', '', 'Robert Zuparko', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (673, NULL, '2012-01-20 12:54:08.659633+00', 'Archer, Erica', '', 'Erica Archer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (674, NULL, '2012-01-20 12:54:08.662305+00', 'Hutcheson, Graeme', '', 'Graeme Hutcheson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (691, NULL, '2012-01-20 12:54:08.716366+00', 'Edmunds, Erik', '', 'Erik Edmunds', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (692, NULL, '2012-01-20 12:54:08.720025+00', 'Ramwell, Evelyn', '', 'Evelyn Ramwell', '', 'e.ramwell@btinternet.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (694, NULL, '2012-01-20 12:54:08.72702+00', 'Lindsey, Trafford', '', 'Trafford Lindsey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (695, NULL, '2012-01-20 12:54:08.730438+00', 'Cullison, David', '', 'David Cullison', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (696, NULL, '2012-01-20 12:54:08.733872+00', 'Firth, Sam', '', 'Sam Firth', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (697, NULL, '2012-01-20 12:54:08.737298+00', 'McGhee, Beryl', '', 'Beryl McGhee', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (698, NULL, '2012-01-20 12:54:08.740923+00', 'Brosse, Faith', '', 'Faith Brosse', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (699, NULL, '2012-01-20 12:54:08.744631+00', 'Burman, Peter', '', 'Peter Burman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (700, NULL, '2012-01-20 12:54:08.748252+00', 'Hitchins, Diana', '', 'Diana Hitchins', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (701, NULL, '2012-01-20 12:54:08.751692+00', 'Carroll, Geoffrey', '', 'Geoffrey Carroll', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (702, NULL, '2012-01-20 12:54:08.755153+00', 'Chapman, Cy', '', 'Cy Chapman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (625, NULL, '2021-08-16 22:41:49.505699+00', 'Hansen, Aase', '', 'Aase Hansen', 'Burbank, CA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11602, '2018-03-11 09:10:41.273584+00', '2018-03-12 00:56:23.724482+00', 'Stausberg/Fingerhuth/Stutz/Hoffmann', '', 'Stausberg/Fingerhuth/Stutz/Hoffmann', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (704, NULL, '2012-01-20 12:54:08.762282+00', 'Rusche, Steven', '', 'Steven Rusche', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (705, NULL, '2012-01-20 12:54:08.765906+00', 'Stern, Ed', '', 'Ed Stern', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (706, NULL, '2012-01-20 12:54:08.769303+00', 'Broome, Clare', '', 'Clare Broome', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (707, NULL, '2012-01-20 12:54:08.773241+00', 'Weller, Doris', '', 'Doris Weller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (708, NULL, '2012-01-20 12:54:08.776548+00', 'Owen, Charles', '', 'Charles Owen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (710, NULL, '2012-01-20 12:54:08.782528+00', 'Sverdlove, Freddy', '', 'Freddy Sverdlove', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (675, NULL, '2012-01-20 12:54:08.664847+00', 'Bartlett, Cathy', '', 'Cathy Bartlett', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (676, NULL, '2012-01-20 12:54:08.667393+00', 'Cox, Clare', '', 'Clare Cox', '', '', 1, 0, 0, 0, NULL, 1922, 2002, NULL, '');
INSERT INTO 'person' VALUES (677, NULL, '2012-01-20 12:54:08.669922+00', 'Trotter, Boronia', '', 'Boronia Trotter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (678, NULL, '2012-01-20 12:54:08.672454+00', 'Cook, Janet', '', 'Janet Cook', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (679, NULL, '2012-01-20 12:54:08.674988+00', 'Robinson, Hal', '', 'Hal Robinson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (680, NULL, '2012-01-20 12:54:08.677514+00', 'Beaton, Alec', '', 'Alec Beaton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (681, NULL, '2012-01-20 12:54:08.680085+00', 'Parker, June', '', 'June Parker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (682, NULL, '2012-01-20 12:54:08.682608+00', 'Briggs, Marty', '', 'Marty Briggs', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (683, NULL, '2012-01-20 12:54:08.685142+00', 'Ackerley, Jill', '', 'Jill Ackerley', 'Johannesburg, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (684, NULL, '2012-01-20 12:54:08.687672+00', 'Higgs, Nicola', '', 'Nicola Higgs', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (685, NULL, '2012-01-20 12:54:08.695183+00', 'Cotton, Lynne', '', 'Lynne Cotton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (687, NULL, '2012-01-20 12:54:08.702053+00', 'Olufson, Oluf', '', 'Oluf Olufson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (688, NULL, '2012-01-20 12:54:08.705684+00', 'Reading, Fiona', '', 'Fiona Reading', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (689, NULL, '2012-01-20 12:54:08.70948+00', 'Laidlaw, Michael', '', 'Michael Laidlaw', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (690, NULL, '2012-01-20 12:54:08.712843+00', 'Burns, Iain', '', 'Iain Burns', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (711, NULL, '2012-01-20 12:54:08.785086+00', 'Astley, Wilf', '', 'Wilf Astley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (712, NULL, '2012-01-20 12:54:08.787618+00', 'Oban Branch RSCDS', '', 'Oban Branch RSCDS', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (713, NULL, '2012-01-20 12:54:08.790336+00', 'Lees, Robert', '', 'Robert Lees', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (714, NULL, '2012-01-20 12:54:08.792927+00', 'Read, Tom', '', 'Tom Read', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (731, NULL, '2012-01-20 12:54:08.836726+00', 'Bell, Elizabeth', '', 'Elizabeth Bell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (732, NULL, '2012-01-20 12:54:08.839353+00', 'Douglas, Arthur', '', 'Arthur Douglas', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (733, NULL, '2012-01-20 12:54:08.841904+00', 'Russell, Bryan', '', 'Bryan Russell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (734, NULL, '2012-01-20 12:54:08.844458+00', 'Higgs, Lesley', '', 'Lesley Higgs', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (735, NULL, '2012-01-20 12:54:08.847036+00', 'Webster, Dawn', '', 'Dawn Webster', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (736, NULL, '2012-01-20 12:54:08.849581+00', 'Beveridge, Betty', '', 'Betty Beveridge', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (737, NULL, '2012-01-20 12:54:08.85225+00', 'Clarke, Douglas', '', 'Douglas Clarke', 'London, Ontario', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (738, NULL, '2012-01-20 12:54:08.854836+00', 'Shaw, Deborah', '', 'Deborah Shaw', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (739, NULL, '2012-01-20 12:54:08.857374+00', 'Wright, Margaret', '', 'Margaret Wright', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (740, NULL, '2012-01-20 12:54:08.860366+00', 'Anglin, Barbara', '', 'Barbara Anglin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (741, NULL, '2012-01-20 12:54:08.862962+00', 'Dungey / Prout / Miles / Hoare', '', 'Dungey / Prout / Miles / Hoare', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (742, NULL, '2012-01-20 12:54:08.865506+00', 'McKie, Ros', '', 'Ros McKie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (744, NULL, '2012-01-20 12:54:08.870595+00', 'Frazer, Margaret', '', 'Margaret Frazer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (745, NULL, '2012-01-20 12:54:08.873338+00', 'Hutcheon, Carolyn', '', 'Carolyn Hutcheon', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (746, NULL, '2012-01-20 12:54:08.875925+00', 'McLennan, John', '', 'John McLennan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (747, NULL, '2012-01-20 12:54:08.878468+00', 'MacKenzie, Mary', '', 'Mary MacKenzie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (715, NULL, '2012-01-20 12:54:08.795464+00', 'Crawford, Anna', '', 'Anna Crawford', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (716, NULL, '2012-01-20 12:54:08.797997+00', 'Bowater, Manly', '', 'Manly Bowater', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (717, NULL, '2012-01-20 12:54:08.800545+00', 'Taylor, Marianne', '', 'Marianne Taylor', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (718, NULL, '2012-01-20 12:54:08.803137+00', 'Sergeant, Emma', '', 'Emma Sergeant', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (719, NULL, '2012-01-20 12:54:08.805677+00', 'Edie, Sylvia', '', 'Sylvia Edie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (720, NULL, '2012-01-20 12:54:08.808212+00', 'Chapple, R / Fyfe, J', '', 'Chapple, R / Fyfe, J', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (721, NULL, '2012-01-20 12:54:08.810754+00', 'Rackley, Bernard', '', 'Bernard Rackley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (722, NULL, '2012-01-20 12:54:08.8133+00', 'Fraser, B O', '', 'B O Fraser', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (724, NULL, '2012-01-20 12:54:08.818363+00', 'Haines, Susan', '', 'Susan Haines', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (726, NULL, '2012-01-20 12:54:08.823606+00', 'MacKinnon, G & Miller, A', '', 'MacKinnon, G & Miller, A', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (727, NULL, '2012-01-20 12:54:08.82637+00', 'Burnell, Brenda', '', 'Brenda Burnell', 'Leeds', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (728, NULL, '2012-01-20 12:54:08.828917+00', 'Hewinson, Babs', '', 'Babs Hewinson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (729, NULL, '2012-01-20 12:54:08.831472+00', 'Varney, Julia', '', 'Julia Varney', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (750, NULL, '2012-01-20 12:54:08.886413+00', 'Hogg', '', 'Hogg', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (751, NULL, '2012-01-20 12:54:08.888975+00', 'Jackson, Peggy', '', 'Peggy Jackson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (752, NULL, '2012-01-20 12:54:08.891565+00', 'Bayliss, Bev', '', 'Bev Bayliss', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (753, NULL, '2012-01-20 12:54:08.894153+00', 'Gay, Penny', '', 'Penny Gay', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (769, NULL, '2012-01-20 12:54:08.935238+00', 'MacDougall, Matt', '', 'Matt MacDougall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (770, NULL, '2012-01-20 12:54:08.937787+00', 'Littlefair, Alan', '', 'Alan Littlefair', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (771, NULL, '2012-01-20 12:54:08.940319+00', 'Tucker, Dennis', '', 'Dennis Tucker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (772, NULL, '2012-01-20 12:54:08.942849+00', 'Taylor, Lisa', '', 'Lisa Taylor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (773, NULL, '2012-01-20 12:54:08.945376+00', 'Eastwood, Rita', '', 'Rita Eastwood', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (774, NULL, '2012-01-20 12:54:08.948217+00', 'Burden, John', '', 'John Burden', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (775, NULL, '2012-01-20 12:54:08.950848+00', 'Orme, Frank', '', 'Frank Orme', 'Berkley, CA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (776, NULL, '2012-01-20 12:54:08.953391+00', 'Kirkwhelpington class', '', 'Kirkwhelpington class', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (778, NULL, '2012-01-20 12:54:08.958462+00', 'Preissig, Lois von', '', 'Lois von Preissig', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (779, NULL, '2012-01-20 12:54:08.961+00', 'Whittaker, Glover', '', 'Glover Whittaker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (780, NULL, '2012-01-20 12:54:08.963528+00', 'Martyn, Nel', '', 'Nel Martyn', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (749, NULL, '2020-10-02 23:56:42.227084+00', 'Kelly, John & Jennifer', '', 'John & Jennifer Kelly', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (730, NULL, '2021-06-28 08:56:44.284388+00', 'Buchan, Lori', '', 'Lori Buchan', 'Lawrence, Massachusetts', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (709, NULL, '2020-12-07 22:46:45.64004+00', 'Bartlett, Donald J', '', 'Donald J Bartlett', 'Toronto, Canada', 'don.bartlett@veritrack.ca', 1, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (782, NULL, '2012-01-20 12:54:08.968731+00', 'Gertz, Don', '', 'Don Gertz', '', 'dlgertz@teleport.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (784, NULL, '2012-01-20 12:54:08.973844+00', 'Aitkenhead, G & P', '', 'G & P Aitkenhead', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (786, NULL, '2012-01-20 12:54:08.979112+00', 'Wood, Donald', '', 'Donald Wood', '', '', 1, 0, 0, 0, NULL, 1924, 2004, NULL, '');
INSERT INTO 'person' VALUES (787, NULL, '2012-01-20 12:54:08.981658+00', 'Kendall, Ingrid', '', 'Ingrid Kendall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (754, NULL, '2012-01-20 12:54:08.896694+00', 'MacDonald Airth, Sheila', '', 'Sheila MacDonald Airth', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (755, NULL, '2012-01-20 12:54:08.899236+00', 'Taylor, Pauline', '', 'Pauline Taylor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (756, NULL, '2012-01-20 12:54:08.901773+00', 'Griffiths, Joyce', '', 'Joyce Griffiths', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (757, NULL, '2012-01-20 12:54:08.904308+00', 'Wharton, Heather', '', 'Heather Wharton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11608, '2018-03-11 10:38:40.325492+00', '2018-03-12 00:56:23.917146+00', 'Stevenson, Bob', '', 'Bob Stevenson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (759, NULL, '2012-01-20 12:54:08.909567+00', 'Senyk, Onie', '', 'Onie Senyk', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (760, NULL, '2012-01-20 12:54:08.912111+00', 'Coleman, Catherine', '', 'Catherine Coleman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (761, NULL, '2012-01-20 12:54:08.914646+00', 'Vik, Pauline', '', 'Pauline Vik', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (762, NULL, '2012-01-20 12:54:08.917475+00', 'Cairn Country Dancers', '', 'Cairn Country Dancers', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (763, NULL, '2012-01-20 12:54:08.920021+00', 'Bourne, Betty', '', 'Betty Bourne', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (764, NULL, '2012-01-20 12:54:08.922551+00', 'Dunbar SCD class', '', 'Dunbar SCD class', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (765, NULL, '2012-01-20 12:54:08.925095+00', 'Graham, Eric', '', 'Eric Graham', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (766, NULL, '2012-01-20 12:54:08.927629+00', 'McCullough, Alison', '', 'Alison McCullough', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (767, NULL, '2012-01-20 12:54:08.930164+00', 'Fyfe, Lynn & John', '', 'Lynn & John Fyfe', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (783, NULL, '2022-05-23 14:20:23.047184+00', 'Cornet, Edward', '', 'Edward Cornet', 'Leamington Spa, UK', 'pipereddie@gmail.com', 1, 0, 1, 0, NULL, 0, 2021, NULL, '');
INSERT INTO 'person' VALUES (748, NULL, '2022-11-20 15:47:09.942983+00', 'Veale, Shirley', '', 'Shirley Veale', 'Ottawa, Ontario, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (768, NULL, '2012-01-20 12:54:08.932705+00', 'Hutcheon, Wendy', '', 'Wendy Hutcheon', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (788, NULL, '2012-01-20 12:54:08.984219+00', 'O''Connor, Noeline', '', 'Noeline O''Connor', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (789, NULL, '2012-01-20 12:54:08.98676+00', 'Breslauer, Russell', '', 'Russell Breslauer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (790, NULL, '2012-01-20 12:54:08.989291+00', 'Dubois-Pollard, Marie', '', 'Marie Dubois-Pollard', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (791, NULL, '2012-01-20 12:54:08.991826+00', 'Robertson, M M', '', 'M M Robertson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (807, NULL, '2012-01-20 12:54:09.032457+00', 'Shannon, Frank', '', 'Frank Shannon', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (808, NULL, '2012-01-20 12:54:09.034991+00', 'Brown, Helen & Malcolm', '', 'Helen & Malcolm Brown', 'York', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (809, NULL, '2012-01-20 12:54:09.037518+00', 'Miller, Andrew', '', 'Andrew Miller', '', 'Andrew_Miller@national.com.au', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (810, NULL, '2012-01-20 12:54:09.040077+00', 'Rimmer, Muriel', '', 'Muriel Rimmer', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (811, NULL, '2012-01-20 12:54:09.042618+00', 'McKinnon, Hector', '', 'Hector McKinnon', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (813, NULL, '2012-01-20 12:54:09.048034+00', 'Sell, Marjorie', '', 'Marjorie Sell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (814, NULL, '2012-01-20 12:54:09.050586+00', 'Collins, John', '', 'John Collins', '', 'collins@phys.psu.edu', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11534, '2017-10-19 21:51:49.623787+00', '2018-03-12 00:56:24.383668+00', 'Stutz, Kenton', '', 'Kenton Stutz', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (816, NULL, '2012-01-20 12:54:09.055726+00', 'Miller, Sybil', '', 'Sybil Miller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (817, NULL, '2012-01-20 12:54:09.058256+00', 'Rudd, Fiona', '', 'Fiona Rudd', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (818, NULL, '2012-01-20 12:54:09.061242+00', 'Moran, Capelthwaite', '', 'Capelthwaite Moran', '', '', 1, 0, 0, 0, NULL, 1954, 1993, NULL, '');
INSERT INTO 'person' VALUES (819, NULL, '2012-01-20 12:54:09.063846+00', 'MacDonald, J & Paton, L', '', 'MacDonald, J & Paton, L', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (820, NULL, '2012-01-20 12:54:09.066385+00', 'Gearey, Betty', '', 'Betty Gearey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (821, NULL, '2012-01-20 12:54:09.068926+00', 'Hay, Frances', '', 'Frances Hay', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (822, NULL, '2012-01-20 12:54:09.071456+00', 'Jalie, Krisham', '', 'Krisham Jalie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (823, NULL, '2012-01-20 12:54:09.073987+00', 'Deauville, Brian', '', 'Brian Deauville', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (825, NULL, '2012-01-20 12:54:09.079048+00', 'Paton, Lisbeth', '', 'Lisbeth Paton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (826, NULL, '2012-01-20 12:54:09.081581+00', 'Hammond, Sybil', '', 'Sybil Hammond', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (792, NULL, '2012-01-20 12:54:08.994357+00', 'Campbell, Phil', '', 'Phil Campbell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (793, NULL, '2012-01-20 12:54:08.996889+00', 'Goulden, Steve', '', 'Steve Goulden', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (794, NULL, '2012-01-20 12:54:08.999417+00', 'Farmer, Conor', '', 'Conor Farmer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (795, NULL, '2012-01-20 12:54:09.00195+00', 'Baker, Corinne', '', 'Corinne Baker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (797, NULL, '2012-01-20 12:54:09.007013+00', 'Barnes, Susan Lee', '', 'Susan Lee Barnes', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (798, NULL, '2012-01-20 12:54:09.00954+00', 'Mueller, Miriam', '', 'Miriam Mueller', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (799, NULL, '2012-01-20 12:54:09.012065+00', 'Sanderson, Ishbel', '', 'Ishbel Sanderson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (800, NULL, '2012-01-20 12:54:09.014599+00', 'Smith, William Andrew', '', 'William Andrew Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (801, NULL, '2012-01-20 12:54:09.017131+00', 'Cooke, Iain', '', 'Iain Cooke', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (802, NULL, '2012-01-20 12:54:09.01977+00', 'Wilson, Lyn', '', 'Lyn Wilson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (803, NULL, '2012-01-20 12:54:09.022328+00', 'James, June', '', 'June James', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (804, NULL, '2012-01-20 12:54:09.024858+00', 'McLean, Gwen', '', 'Gwen McLean', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (805, NULL, '2012-01-20 12:54:09.027393+00', 'Farr, Valerie', '', 'Valerie Farr', '', 'vfarr@yahoo.co.uk', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (806, NULL, '2012-01-20 12:54:09.029924+00', 'Crowley, John', '', 'John Crowley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (828, NULL, '2012-01-20 12:54:09.087652+00', 'Stahl, Ruth', '', 'Ruth Stahl', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (829, NULL, '2012-01-20 12:54:09.090275+00', 'Riker, Christine Tyrone', '', 'Christine Tyrone Riker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (847, NULL, '2012-01-20 12:54:09.137077+00', 'Reddick, Dale', '', 'Dale Reddick', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (849, NULL, '2012-01-20 12:54:09.142149+00', 'Easton, Kathleen / Keppie, J Duncan', '', 'Easton, Kathleen / Keppie, J Duncan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (850, NULL, '2012-01-20 12:54:09.144684+00', 'Henderson, Lisbeth & Douglas', '', 'Lisbeth & Douglas Henderson', 'Dundee', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (851, NULL, '2012-01-20 12:54:09.147226+00', 'Boal, Muriel', '', 'Muriel Boal', 'Dundee', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (852, NULL, '2012-01-20 12:54:09.149752+00', 'Smith, Robert', '', 'Robert Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (853, NULL, '2012-01-20 12:54:09.152284+00', 'Wilson, J K C', '', 'J K C Wilson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (855, NULL, '2012-01-20 12:54:09.157354+00', 'Ball, Marian', '', 'Marian Ball', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (856, NULL, '2012-01-20 12:54:09.15989+00', 'Galloway, J', '', 'J Galloway', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (857, NULL, '2012-01-20 12:54:09.162444+00', 'Swindle, Joe', '', 'Joe Swindle', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (858, NULL, '2012-01-20 12:54:09.164975+00', 'Senyk, George & Onie', '', 'George & Onie Senyk', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (859, NULL, '2012-01-20 12:54:09.167506+00', 'Ward, Stan', '', 'Stan Ward', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (861, NULL, '2012-01-20 12:54:09.172574+00', 'MacKenzie, Anne N', '', 'Anne N MacKenzie', 'Aberdeen', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (863, NULL, '2012-01-20 12:54:09.177638+00', 'MacQueen, Sheena', '', 'Sheena MacQueen', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (864, NULL, '2012-01-20 12:54:09.181889+00', 'Craig', '', 'Craig', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (830, NULL, '2012-01-20 12:54:09.092816+00', 'Ritchie, Doreen', '', 'Doreen Ritchie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (831, NULL, '2012-01-20 12:54:09.09536+00', 'Davis, Alan', '', 'Alan Davis', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (832, NULL, '2012-01-20 12:54:09.097897+00', 'MacKay, Joan', '', 'Joan MacKay', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (833, NULL, '2012-01-20 12:54:09.100608+00', 'Steele, Hugh', '', 'Hugh Steele', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (834, NULL, '2012-01-20 12:54:09.103454+00', 'Molyneux, Val', '', 'Val Molyneux', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (835, NULL, '2012-01-20 12:54:09.106214+00', 'Fuchs, Ruth von', '', 'Ruth von Fuchs', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (836, NULL, '2012-01-20 12:54:09.108787+00', 'Kirkwood, W', '', 'W Kirkwood', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (837, NULL, '2012-01-20 12:54:09.111329+00', 'Wright, Tony', '', 'Tony Wright', 'New Zealand', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (839, NULL, '2012-01-20 12:54:09.116519+00', 'Grant, Betty & David', '', 'Betty & David Grant', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (840, NULL, '2012-01-20 12:54:09.119051+00', 'Hilton, H Isis', '', 'H Isis Hilton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (841, NULL, '2012-01-20 12:54:09.121584+00', 'Sumby, Ken', '', 'Ken Sumby', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (842, NULL, '2012-01-20 12:54:09.124148+00', 'Lanyon, Roger', '', 'Roger Lanyon', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (844, NULL, '2012-01-20 12:54:09.129376+00', 'Walker, Roger', '', 'Roger Walker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (845, NULL, '2012-01-20 12:54:09.131986+00', 'Morgan, Nicholas', '', 'Nicholas Morgan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (866, NULL, '2012-01-20 12:54:09.187903+00', 'Sandbach & District ...', '', 'Sandbach & District ...', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (867, NULL, '2012-01-20 12:54:09.190495+00', 'Reed, Sylvia', '', 'Sylvia Reed', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (960, NULL, '2012-01-20 12:54:09.430222+00', 'Taylor, Frank', '', 'Frank Taylor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (843, NULL, '2018-03-20 16:22:40.679803+00', 'Obata, Masaaki', '', 'Masaaki Obata', 'Tokyo, Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (885, NULL, '2012-01-20 12:54:09.23838+00', 'Robertson, David', '', 'David Robertson', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (886, NULL, '2012-01-20 12:54:09.240907+00', 'Fraser, Elizabeth', '', 'Elizabeth Fraser', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (887, NULL, '2012-01-20 12:54:09.243435+00', 'Cuesta, Christian', '', 'Christian Cuesta', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (889, NULL, '2012-01-20 12:54:09.24858+00', 'Lanktree, John', '', 'John Lanktree', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (890, NULL, '2012-01-20 12:54:09.25112+00', 'Harris, David', '', 'David Harris', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (891, NULL, '2012-01-20 12:54:09.253651+00', 'Edminson, Emma', '', 'Emma Edminson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (892, NULL, '2012-01-20 12:54:09.256178+00', 'Ellis, Norm', '', 'Norm Ellis', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (893, NULL, '2012-01-20 12:54:09.258708+00', 'Low Fell SCD Club', '', 'Low Fell SCD Club', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (894, NULL, '2012-01-20 12:54:09.261485+00', 'Morrell, Elizabeth', '', 'Elizabeth Morrell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (895, NULL, '2012-01-20 12:54:09.264037+00', 'Hunt, Carolyn', '', 'Carolyn Hunt', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (896, NULL, '2012-01-20 12:54:09.26657+00', 'Carmichael, Charles', '', 'Charles Carmichael', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (897, NULL, '2012-01-20 12:54:09.269138+00', 'Abergavenny Children''s Class', '', 'Abergavenny Children''s Class', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (899, NULL, '2012-01-20 12:54:09.274226+00', 'Robson, Alan', '', 'Alan Robson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (901, NULL, '2012-01-20 12:54:09.279292+00', 'Gardner, Joyce', '', 'Joyce Gardner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (869, NULL, '2012-01-20 12:54:09.195567+00', 'Saint Andrews Demonstration Team', '', 'Saint Andrews Demonstration Team', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (870, NULL, '2012-01-20 12:54:09.198277+00', 'Haeckler, Brian', '', 'Brian Haeckler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (871, NULL, '2012-01-20 12:54:09.201134+00', 'Cooper, Jack', '', 'Jack Cooper', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (872, NULL, '2012-01-20 12:54:09.204586+00', 'Watson, Marilyn', '', 'Marilyn Watson', 'Bournemouth', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (873, NULL, '2012-01-20 12:54:09.207218+00', 'Flaherty, Patrick', '', 'Patrick Flaherty', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (874, NULL, '2012-01-20 12:54:09.210054+00', 'Noble, Dennis', '', 'Dennis Noble', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (875, NULL, '2012-01-20 12:54:09.212704+00', 'Duncan, Alistair', '', 'Alistair Duncan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (876, NULL, '2012-01-20 12:54:09.215242+00', 'Rogers, David', '', 'David Rogers', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (877, NULL, '2012-01-20 12:54:09.217866+00', 'Izbicki, Tom', '', 'Tom Izbicki', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (878, NULL, '2012-01-20 12:54:09.220416+00', 'Machin, Geoff', '', 'Geoff Machin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (879, NULL, '2012-01-20 12:54:09.222951+00', 'Frew, Robert & Day, Sue', '', 'Frew, Robert & Day, Sue', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (880, NULL, '2012-01-20 12:54:09.22548+00', 'Graham, Gayle', '', 'Gayle Graham', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (881, NULL, '2012-01-20 12:54:09.228002+00', 'Telford, Alison', '', 'Alison Telford', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (902, NULL, '2012-01-20 12:54:09.281822+00', 'Templeton and Chalmers', '', 'Templeton and Chalmers', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (903, NULL, '2012-01-20 12:54:09.284351+00', 'Fraser, Alasdair & Johnstone, Muriel', 'Fraser & Johnstone', 'Alasdair Fraser & Muriel Johnstone', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (868, NULL, '2015-04-22 10:41:48.195158+00', 'Miller, Lilian', '', 'Lilian Miller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (846, NULL, '2015-09-02 12:25:53.927048+00', 'Anderson, Allie / Lesslie, Florence', '', 'Allie Anderson & Florence D. Lesslie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (848, NULL, '2015-05-14 09:03:04.288136+00', 'Duncan, Chris', '', 'Chris Duncan', 'Australia', '', 1, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (888, NULL, '2016-09-09 08:55:04.587278+00', 'Dallere, Ginette', '', 'Ginette Dalleré', 'Paris', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11638, '2018-05-29 14:36:59.184515+00', '2018-05-30 23:56:22.647644+00', 'Osborne, Andrew', '', 'Andrew Osborne', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (862, NULL, '2017-11-14 00:56:05.929614+00', 'Cooke (18C), B', '', 'B Cooke (18C)', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11671, '2018-08-07 19:33:47.268157+00', '2018-08-07 23:56:09.987098+00', 'Gentles, Kate', '', 'Kate Gentles', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11711, '2018-09-18 17:44:33.706793+00', '2018-09-18 17:44:33.706793+00', 'Mills, Susan', '', 'Susan Mills', 'Rollo, MO, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (904, NULL, '2012-01-20 12:54:09.286879+00', 'Oetzel, George', '', 'George Oetzel', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (882, NULL, '2012-01-20 12:54:09.230527+00', 'Bouwsma, Barbara', '', 'Barbara Bouwsma', '', '', 1, 0, 0, 0, 1773, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (922, NULL, '2012-01-20 12:54:09.332487+00', 'Smith, Jean', '', 'Jean Smith', 'Bellevue, WA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (923, NULL, '2012-01-20 12:54:09.335017+00', 'Metz, Bruce', '', 'Bruce Metz', 'Renton, WA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (924, NULL, '2012-01-20 12:54:09.337544+00', 'Routledge, Alison', '', 'Alison Routledge', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (925, NULL, '2012-01-20 12:54:09.340061+00', 'Wright, Arthur', '', 'Arthur Wright', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (926, NULL, '2012-01-20 12:54:09.342587+00', 'Bulmer, Len', '', 'Len Bulmer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (928, NULL, '2012-01-20 12:54:09.34764+00', 'Slosek, Howard', '', 'Howard Slosek', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (929, NULL, '2012-01-20 12:54:09.350161+00', 'Barnes, Paulina', '', 'Paulina Barnes', 'Vancouver', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (931, NULL, '2012-01-20 12:54:09.355234+00', 'Rust, Susan', '', 'Susan Rust', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (932, NULL, '2012-01-20 12:54:09.357753+00', 'Jorgensen, Kim', '', 'Kim Jorgensen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (933, NULL, '2012-01-20 12:54:09.360301+00', 'Simpson, Emilie', '', 'Emilie Simpson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (935, NULL, '2012-01-20 12:54:09.365365+00', 'Bristol, Betty', '', 'Betty Bristol', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (936, NULL, '2012-01-20 12:54:09.367939+00', 'Carmichael, A R F', '', 'A R F Carmichael', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (937, NULL, '2012-01-20 12:54:09.370664+00', 'McQuilling, Carol', '', 'Carol McQuilling', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (938, NULL, '2012-01-20 12:54:09.373242+00', 'Willman, Marion', '', 'Marion Willman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (854, NULL, '2021-06-01 21:00:59.739218+00', 'Brown, Duncan', '', 'Duncan Brown', 'Bovey Tracey, Devon, UK', 'duncanqlnbrown@tiscali.co.uk', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (940, NULL, '2012-01-20 12:54:09.378445+00', 'Hesler, Gary', '', 'Gary Hesler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (905, NULL, '2012-01-20 12:54:09.289404+00', 'Tovey, Craig', '', 'Craig Tovey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (906, NULL, '2012-01-20 12:54:09.291968+00', 'Lambert, Bob', '', 'Bob Lambert', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (907, NULL, '2012-01-20 12:54:09.294498+00', 'Phillips, Rachel', '', 'Rachel Phillips', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11639, '2018-06-03 13:59:22.130137+00', '2018-06-03 13:59:22.130137+00', 'Carter, David', '', 'David Carter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (909, NULL, '2012-01-20 12:54:09.299574+00', 'Hamilton, May', '', 'May Hamilton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (910, NULL, '2012-01-20 12:54:09.302095+00', 'Orr, Jim', '', 'Jim Orr', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (911, NULL, '2012-01-20 12:54:09.304629+00', 'Mackintosh, Brenda', '', 'Brenda Mackintosh', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (912, NULL, '2012-01-20 12:54:09.307168+00', 'Astle, Eric', '', 'Eric Astle', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (913, NULL, '2012-01-20 12:54:09.309692+00', 'West, Charles', '', 'Charles West', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (914, NULL, '2012-01-20 12:54:09.312255+00', 'Rogers, Marci', '', 'Marci Rogers', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (915, NULL, '2012-01-20 12:54:09.314785+00', 'Baxter, Arlene', '', 'Arlene Baxter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (917, NULL, '2012-01-20 12:54:09.319846+00', 'Sattler, Freda', '', 'Freda Sattler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (918, NULL, '2012-01-20 12:54:09.322375+00', 'Hofmann, Doris', '', 'Doris Hofmann', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (920, NULL, '2012-01-20 12:54:09.327428+00', 'Stone, Joyce', '', 'Joyce Stone', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (941, NULL, '2012-01-20 12:54:09.380983+00', 'Thompson, Bill', '', 'Bill Thompson', 'Melbourne', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (942, NULL, '2012-01-20 12:54:09.383509+00', 'Whittaker, Frances', '', 'Frances Whittaker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (943, NULL, '2012-01-20 12:54:09.386036+00', 'Eyres, Tim', '', 'Tim Eyres', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (961, NULL, '2012-01-20 12:54:09.432753+00', 'Beckett, Norah', '', 'Norah Beckett', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (962, NULL, '2012-01-20 12:54:09.534793+00', 'Shaw, Rhoda', '', 'Rhoda Shaw', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (963, NULL, '2012-01-20 12:54:09.537349+00', 'Dow, Diane L', '', 'Diane L Dow', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (964, NULL, '2012-01-20 12:54:09.539892+00', 'Mackay, Bill', '', 'Bill Mackay', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (966, NULL, '2012-01-20 12:54:09.544969+00', 'Dufresne, Marie-Anne', '', 'Marie-Anne Dufresne', 'Paris', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (967, NULL, '2012-01-20 12:54:09.54751+00', 'Lean, Jim', '', 'Jim Lean', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (968, NULL, '2012-01-20 12:54:09.550036+00', 'Hinde, Myra', '', 'Myra Hinde', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (969, NULL, '2012-01-20 12:54:09.552603+00', 'Kearney, Leslie', '', 'Leslie Kearney', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (970, NULL, '2012-01-20 12:54:09.555161+00', 'Coleman, John', '', 'John Coleman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (971, NULL, '2012-01-20 12:54:09.5577+00', 'McKenzie, Dorothea', '', 'Dorothea McKenzie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (972, NULL, '2012-01-20 12:54:09.560233+00', 'Paterson, Dorothy', '', 'Dorothy Paterson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (944, NULL, '2012-01-20 12:54:09.388563+00', 'Anderson, Thane W', '', 'Thane W Anderson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (973, NULL, '2012-01-20 12:54:09.562764+00', 'Williams, R & Wallace, W', '', 'Williams, R & Wallace, W', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (974, NULL, '2012-01-20 12:54:09.565339+00', 'Gerrard, David', '', 'David Gerrard', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (975, NULL, '2012-01-20 12:54:09.567864+00', 'More, Muriel', '', 'Muriel More', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (976, NULL, '2012-01-20 12:54:09.57039+00', 'Young, J (18C)', '', 'J (18C) Young', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (977, NULL, '2012-01-20 12:54:09.573039+00', 'Dyall, Lorraine', '', 'Lorraine Dyall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (978, NULL, '2012-01-20 12:54:09.575659+00', 'Bracewell, H & D', '', 'H & D Bracewell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (979, NULL, '2012-01-20 12:54:09.578199+00', 'McLeod, Rona', '', 'Rona McLeod', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (945, NULL, '2012-01-20 12:54:09.391404+00', 'Mechan, George', '', 'George Mechan', 'Dundee', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (946, NULL, '2012-01-20 12:54:09.394003+00', 'Stokes, Bess', '', 'Bess Stokes', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (948, NULL, '2012-01-20 12:54:09.3996+00', 'Sullivan, Jim', '', 'Jim Sullivan', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (949, NULL, '2012-01-20 12:54:09.402141+00', 'Dickson, Phyllis', '', 'Phyllis Dickson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (950, NULL, '2012-01-20 12:54:09.404678+00', 'Whitson, Norman', '', 'Norman Whitson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (955, NULL, '2012-01-20 12:54:09.417321+00', 'Wagstaff, Ed', '', 'Ed Wagstaff', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (956, NULL, '2012-01-20 12:54:09.420061+00', 'Herbecq, John', '', 'John Herbecq', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (957, NULL, '2012-01-20 12:54:09.422627+00', 'Creighton, Allana', '', 'Allana Creighton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (959, NULL, '2012-01-20 12:54:09.427696+00', 'Essex, Harry', '', 'Harry Essex', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (981, NULL, '2012-01-20 12:54:09.583325+00', 'Kluger, Joe', '', 'Joe Kluger', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (982, NULL, '2012-01-20 12:54:09.585852+00', 'Riley, John', '', 'John Riley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (953, NULL, '2015-03-14 18:11:08.358621+00', 'Gibson', '', 'Gibson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (952, NULL, '2015-03-14 18:11:12.906665+00', 'Kelly, Jennifer', '', 'Jennifer Kelly', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (965, NULL, '2015-03-14 18:11:18.557161+00', 'Mitchell, Rosemary', '', 'Rosemary Mitchell', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (919, NULL, '2015-03-14 18:11:25.443882+00', 'Sinclair, Joe', '', 'Joe Sinclair', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (983, NULL, '2012-01-20 12:54:09.588385+00', 'MacLeod, Lyn', '', 'Lyn MacLeod', '', '', 1, 0, 0, 0, 983, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (999, NULL, '2012-01-20 12:54:09.628988+00', 'Readhead, Doris', '', 'Doris Readhead', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1000, NULL, '2012-01-20 12:54:09.631523+00', 'Wright (18C)', '', 'Wright (18C)', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1001, NULL, '2012-01-20 12:54:09.639316+00', 'Lamb', '', 'Lamb', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1002, NULL, '2012-01-20 12:54:09.642797+00', 'MacLeod, Sue', '', 'Sue MacLeod', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1003, NULL, '2012-01-20 12:54:09.646086+00', 'Adams, William', '', 'William Adams', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1004, NULL, '2012-01-20 12:54:09.649395+00', 'Houghton, Beverley', '', 'Beverley Houghton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1006, NULL, '2012-01-20 12:54:09.655126+00', 'Adams, Marjorie', '', 'Marjorie Adams', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1007, NULL, '2012-01-20 12:54:09.657672+00', 'Rae, Isabel / Duffield, Marjorie', '', 'Rae, Isabel & Duffield, Marjorie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1008, NULL, '2012-01-20 12:54:09.660525+00', 'Cunningham, Marion', '', 'Marion Cunningham', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1009, NULL, '2012-01-20 12:54:09.663088+00', 'Johnston, Kerr', '', 'Kerr Johnston', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1010, NULL, '2012-01-20 12:54:09.665626+00', 'Kitchener Waterloo', '', 'Kitchener Waterloo', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1011, NULL, '2012-01-20 12:54:09.668286+00', 'Nelson, Pearl', '', 'Pearl Nelson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1012, NULL, '2012-01-20 12:54:09.670847+00', 'Tyler, Susan', '', 'Susan Tyler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1014, NULL, '2012-01-20 12:54:09.675906+00', 'Norton, Doris', '', 'Doris Norton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1015, NULL, '2012-01-20 12:54:09.678431+00', 'Depres, Daniel', '', 'Daniel Depres', 'Paris', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1017, NULL, '2012-01-20 12:54:09.683503+00', 'Noakes, Eithne', '', 'Eithne Noakes', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1018, NULL, '2012-01-20 12:54:09.68603+00', 'Read', '', 'Read', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (984, NULL, '2012-01-20 12:54:09.591014+00', 'Cantelo (18C)', '', 'Cantelo (18C)', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (985, NULL, '2012-01-20 12:54:09.593577+00', 'Flett, Lorraine', '', 'Lorraine Flett', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (927, NULL, '2021-03-23 00:57:01.765838+00', 'Russell, Edna', '', 'Edna Russell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (921, NULL, '2021-05-08 23:09:08.659231+00', 'Sverdlove, F & Gruskin, R', 'Sverdlove & Gruskin', 'F Sverdlove & R Gruskin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Freddy Sverdlove and Robert Gruskin.');
INSERT INTO 'person' VALUES (916, NULL, '2021-06-02 16:06:13.57159+00', 'Hellinghuizer, Mr & Mrs', '', 'Mr & Mrs Hellinghuizer', 'de Bilt, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (930, NULL, '2021-07-30 18:58:11.518719+00', 'Rhodes, Jean', '', 'Jean Rhodes', ' Bethel, Gwynedd, Wales', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (986, NULL, '2012-01-20 12:54:09.596104+00', 'Green, Elizabeth', '', 'Elizabeth Green', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (987, NULL, '2012-01-20 12:54:09.598628+00', 'Stanaway, Pat', '', 'Pat Stanaway', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (988, NULL, '2012-01-20 12:54:09.601157+00', 'MacKay, M', '', 'M MacKay', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (989, NULL, '2012-01-20 12:54:09.603683+00', 'Smith, Arthur', '', 'Arthur Smith', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (990, NULL, '2012-01-20 12:54:09.606199+00', 'Graham, Lorraine', '', 'Lorraine Graham', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (991, NULL, '2012-01-20 12:54:09.608741+00', 'Thomson, Margaret P A', '', 'Margaret P A Thomson', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (992, NULL, '2012-01-20 12:54:09.611289+00', 'Kuipers, Benjamin', '', 'Benjamin Kuipers', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (994, NULL, '2012-01-20 12:54:09.616344+00', 'Gray, Mary & Mac', '', 'Mary & Mac Gray', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (995, NULL, '2012-01-20 12:54:09.618876+00', 'Martin, B & Wood, R', '', 'Martin, B & Wood, R', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (996, NULL, '2012-01-20 12:54:09.621401+00', 'MacLachlan, J & Harris, V', '', 'MacLachlan, J & Harris, V', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1019, NULL, '2012-01-20 12:54:09.688555+00', 'Smart, Betty', '', 'Betty Smart', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1020, NULL, '2012-01-20 12:54:09.691113+00', 'Blackhall, Colin', '', 'Colin Blackhall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1021, NULL, '2012-01-20 12:54:09.693649+00', 'Wurtzel, Chari', '', 'Chari Wurtzel', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1013, NULL, '2012-09-07 11:30:09.281682+00', 'Sager, Becky', '', 'Becky Sager', 'Marietta GA USA', 'bsager@bellsouth.net', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Full name: Rebecca Sager');
INSERT INTO 'person' VALUES (1022, NULL, '2012-01-20 12:54:09.696181+00', 'Gaiter', '', 'Gaiter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1023, NULL, '2012-01-20 12:54:09.698716+00', 'Helensburgh'' Children''s Class', '', 'Helensburgh'' Children''s Class', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1024, NULL, '2012-01-20 12:54:09.701245+00', 'Wing, Jill', '', 'Jill Wing', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1025, NULL, '2012-01-20 12:54:09.703892+00', 'Pilcher, Karen', '', 'Karen Pilcher', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1026, NULL, '2012-01-20 12:54:09.70643+00', 'Coupar Angus SCDC', '', 'Coupar Angus SCDC', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1027, NULL, '2012-01-20 12:54:09.708967+00', 'McKinnon, Donald', '', 'Donald McKinnon', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1028, NULL, '2012-01-20 12:54:09.711494+00', 'Bourne, Elliott & Varney', '', 'Elliott & Varney Bourne', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1029, NULL, '2012-01-20 12:54:09.714022+00', 'Trafford, Lindsey', '', 'Lindsey Trafford', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1046, NULL, '2012-01-20 12:54:09.757613+00', 'Zuppicich, Annette', '', 'Annette Zuppicich', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1048, NULL, '2012-01-20 12:54:09.76287+00', 'Murrells, Lindsay', '', 'Lindsay Murrells', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1050, NULL, '2012-01-20 12:54:09.768097+00', 'Abend, Rosemary', '', 'Rosemary Abend', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1052, NULL, '2012-01-20 12:54:09.773168+00', 'Sawyer, Will', '', 'Will Sawyer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1053, NULL, '2012-01-20 12:54:09.775697+00', 'Johnson, Mary', '', 'Mary Johnson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1055, NULL, '2012-01-20 12:54:09.780746+00', 'Reid, Gillian', '', 'Gillian Reid', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1016, NULL, '2014-07-11 16:53:41.733314+00', 'Ivory, Derek & Bacchus, Mick', '', 'Derek Ivory & Mick Bacchus', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1047, NULL, '2014-11-05 22:50:44.884519+00', 'Rigby, John F', '', 'John F Rigby', 'Cardiff, South Wales', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1056, NULL, '2012-01-20 12:54:09.783286+00', 'Donald, C / Cox, I', '', 'Donald, C / Cox, I', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1057, NULL, '2012-01-20 12:54:09.785809+00', 'Joyce, Shelley', '', 'Shelley Joyce', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1058, NULL, '2012-01-20 12:54:09.788338+00', 'Park, Charles', '', 'Charles Park', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1059, NULL, '2012-01-20 12:54:09.790878+00', 'Orr, Elspeth', '', 'Elspeth Orr', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1060, NULL, '2012-01-20 12:54:09.793403+00', 'McIntosh, Beryl', '', 'Beryl McIntosh', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1061, NULL, '2012-01-20 12:54:09.795934+00', 'McOwen, Robert', '', 'Robert McOwen', '', 'mcowen@neu.edu', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1062, NULL, '2012-01-20 12:54:09.79846+00', 'Moffat, David', '', 'David Moffat', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1063, NULL, '2012-01-20 12:54:09.801008+00', 'Duguid, David', '', 'David Duguid', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1064, NULL, '2012-01-20 12:54:09.803689+00', 'Willson, Ken', '', 'Ken Willson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1065, NULL, '2012-01-20 12:54:09.806261+00', 'Turnbull, Fiona', '', 'Fiona Turnbull', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1030, NULL, '2012-01-20 12:54:09.71655+00', 'Neilson, Arthur', '', 'Arthur Neilson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1031, NULL, '2012-01-20 12:54:09.719093+00', 'Peel, Tommy', '', 'Tommy Peel', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1032, NULL, '2012-01-20 12:54:09.721615+00', 'Davey, Roger', '', 'Roger Davey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1034, NULL, '2012-01-20 12:54:09.726856+00', 'Perry, John', '', 'John Perry', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1035, NULL, '2012-01-20 12:54:09.729391+00', 'Gillespie-Smith, Roy', '', 'Roy Gillespie-Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1036, NULL, '2012-01-20 12:54:09.732202+00', 'Gaze, George', '', 'George Gaze', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1037, NULL, '2012-01-20 12:54:09.734789+00', 'Winnipeg Childrens Class', '', 'Winnipeg Childrens Class', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1038, NULL, '2012-01-20 12:54:09.737341+00', 'Hollings, David', '', 'David Hollings', 'Dundee', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1005, NULL, '2016-05-16 00:39:12.839694+00', 'Wood, Ellen', '', 'Ellen Wood', '', '', 1, 0, 0, 0, 508, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1051, NULL, '2017-03-31 20:45:35.049207+00', 'Moorhead, William J', '', 'William J Moorhead', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1040, NULL, '2012-01-20 12:54:09.742396+00', 'Blundell, Doreen', '', 'Doreen Blundell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1041, NULL, '2012-01-20 12:54:09.744943+00', 'Austen, Barbara', '', 'Barbara Austen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1043, NULL, '2012-01-20 12:54:09.750034+00', 'Plummer, Paul', '', 'Paul Plummer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1044, NULL, '2012-01-20 12:54:09.752552+00', 'Smith, Hilda', '', 'Hilda Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1045, NULL, '2012-01-20 12:54:09.755078+00', 'Wainwright, Tracy', '', 'Tracy Wainwright', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1066, NULL, '2012-01-20 12:54:09.808807+00', 'Plant, Yvonne', '', 'Yvonne Plant', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1067, NULL, '2012-01-20 12:54:09.811356+00', 'Kemp, Suzanne', '', 'Suzanne Kemp', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1068, NULL, '2012-01-20 12:54:09.813887+00', 'Griffiths, Gordon', '', 'Gordon Griffiths', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1085, NULL, '2012-01-20 12:54:09.857447+00', 'Irias, Caedmon', '', 'Caedmon Irias', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1069, NULL, '2012-01-20 12:54:09.816415+00', 'Washer, Jeanne', '', 'Jeanne Washer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1086, NULL, '2012-01-20 12:54:09.860151+00', 'Cleaves, Helen', '', 'Helen Cleaves', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1087, NULL, '2012-01-20 12:54:09.862724+00', 'Dickson, Sheryl', '', 'Sheryl Dickson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1070, NULL, '2012-01-20 12:54:09.818961+00', 'Palmer, Geoffrey', '', 'Geoffrey Palmer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1071, NULL, '2012-01-20 12:54:09.821491+00', 'Donaldson, James', '', 'James Donaldson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1090, NULL, '2012-01-20 12:54:09.870328+00', 'Joyce, Jo-Anne', '', 'Jo-Anne Joyce', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1072, NULL, '2012-01-20 12:54:09.824114+00', 'Miller, Margaret', '', 'Margaret Miller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1091, NULL, '2012-01-20 12:54:09.873061+00', 'Butler, Helen', '', 'Helen Butler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1073, NULL, '2012-01-20 12:54:09.826664+00', 'Greer, Margaret', '', 'Margaret Greer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1092, NULL, '2012-01-20 12:54:09.875697+00', 'Bohlken, S / Johns, D', '', 'S Bohlken / D Johns', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1074, NULL, '2012-01-20 12:54:09.829187+00', 'Shaftesbury Branch', '', 'Shaftesbury Branch', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1075, NULL, '2012-01-20 12:54:09.831829+00', 'Williams, Melodie', '', 'Melodie Williams', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (997, NULL, '2021-05-27 22:00:49.581344+00', 'Westwood, Alex', '', 'Alex Westwood', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'A former president of RSCDS London Branch.');
INSERT INTO 'person' VALUES (1049, NULL, '2021-06-08 20:35:22.022142+00', 'Klokgieters, Anne-Miek', '', 'Anne-Miek Klokgieters', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1093, NULL, '2012-01-20 12:54:09.878248+00', 'Hamilton, Gordon', '', 'Gordon Hamilton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1094, NULL, '2012-01-20 12:54:09.880787+00', 'MacPherson Clan', '', 'MacPherson Clan', 'Edinburgh', '', 1, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1095, NULL, '2012-01-20 12:54:09.883326+00', 'Wendell, Keith', '', 'Keith Wendell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1077, NULL, '2012-01-20 12:54:09.836915+00', 'Gosforth School of Dancing', '', 'Gosforth School of Dancing', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1096, NULL, '2012-01-20 12:54:09.885942+00', 'Giessen, Irma van der', '', 'Irma van der Giessen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1078, NULL, '2012-01-20 12:54:09.839455+00', 'Stephen, Angus', '', 'Angus Stephen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1097, NULL, '2012-01-20 12:54:09.888499+00', 'Dezais (18C)', '', 'Dezais (18C)', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1079, NULL, '2012-01-20 12:54:09.841989+00', 'Crawforth, M & D', '', 'M & D Crawforth', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1080, NULL, '2012-01-20 12:54:09.844684+00', 'Jamieson, Sandy', '', 'Sandy Jamieson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1098, NULL, '2012-01-20 12:54:09.891021+00', 'Sheppard, Ann', '', 'Ann Sheppard', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1081, NULL, '2012-01-20 12:54:09.847259+00', 'Robertson, Doris', '', 'Doris Robertson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1082, NULL, '2012-01-20 12:54:09.849847+00', 'Prentice, Brian', '', 'Brian Prentice', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1099, NULL, '2012-01-20 12:54:09.893552+00', 'Hillman, Anne', '', 'Anne Hillman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1083, NULL, '2012-01-20 12:54:09.852379+00', 'Comings, Carolyn', '', 'Carolyn Comings', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1084, NULL, '2012-01-20 12:54:09.854916+00', 'Rintoul, Alan', '', 'Alan Rintoul', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1100, NULL, '2012-01-20 12:54:09.896088+00', 'Lees, Mairi', '', 'Mairi Lees', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1101, NULL, '2012-01-20 12:54:09.898646+00', 'Johnstone, Angela', '', 'Angela Johnstone', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1102, NULL, '2012-01-20 12:54:09.901186+00', 'Hanna, Beth', '', 'Beth Hanna', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1103, NULL, '2012-01-20 12:54:09.903851+00', 'Shields, Shirley M', '', 'Shirley M Shields', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1104, NULL, '2012-01-20 12:54:09.906421+00', 'Bailey, Sue', '', 'Sue Bailey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1105, NULL, '2012-01-20 12:54:09.908957+00', 'Urquart, Margaret', '', 'Margaret Urquart', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1106, NULL, '2012-01-20 12:54:09.911494+00', 'Gray, Betty', '', 'Betty Gray', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1107, NULL, '2012-01-20 12:54:09.914023+00', 'Pomeroy, Claire', '', 'Claire Pomeroy', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1088, NULL, '2012-01-20 12:54:09.865255+00', 'Doerr, Elizabeth', '', 'Elizabeth Doerr', '', 'liz@us.net', 1, 0, 0, 0, 1088, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1123, NULL, '2012-01-20 12:54:09.955113+00', 'Speed, Nina', '', 'Nina Speed', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1124, NULL, '2012-01-20 12:54:09.957653+00', 'Anapol, Vivian', '', 'Vivian Anapol', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1125, NULL, '2012-01-20 12:54:09.960301+00', 'Ellison, Barbara', '', 'Barbara Ellison', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1126, NULL, '2012-01-20 12:54:09.962853+00', 'Davidson, Elizabeth', '', 'Elizabeth Davidson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1127, NULL, '2012-01-20 12:54:09.965515+00', 'Pearson, Jessie', '', 'Jessie Pearson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1128, NULL, '2012-01-20 12:54:09.96805+00', 'Crosbie, G', '', 'G Crosbie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1129, NULL, '2012-01-20 12:54:09.970576+00', 'Fraser, J A', '', 'J A Fraser', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1130, NULL, '2012-01-20 12:54:09.973114+00', 'Cass, Peter', '', 'Peter Cass', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1131, NULL, '2012-01-20 12:54:09.97565+00', 'Middleton, Clarice', '', 'Clarice Middleton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1132, NULL, '2012-01-20 12:54:09.978178+00', 'Clark, William J', '', 'William J Clark', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1133, NULL, '2012-01-20 12:54:09.980709+00', 'Clyde, Eric', '', 'Eric Clyde', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1134, NULL, '2012-01-20 12:54:09.983652+00', 'Sheffield Branch RSCDS', '', 'Sheffield Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1136, NULL, '2012-01-20 12:54:09.989181+00', 'Morris', '', 'Morris', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1137, NULL, '2012-01-20 12:54:09.991979+00', 'Lund, Andrew', '', 'Andrew Lund', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1138, NULL, '2012-01-20 12:54:09.994586+00', 'Budd (18C)', '', 'Budd (18C)', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1139, NULL, '2012-01-20 12:54:09.99713+00', 'McIntosh', '', 'McIntosh', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1140, NULL, '2012-01-20 12:54:09.999703+00', 'Libby, Bill', '', 'Bill Libby', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1141, NULL, '2012-01-20 12:54:10.002225+00', 'Binns, Peter', '', 'Peter Binns', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1142, NULL, '2012-01-20 12:54:10.004757+00', 'Hopkins, Sharon', '', 'Sharon Hopkins', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1143, NULL, '2012-01-20 12:54:10.007301+00', 'Mitchell, Nan', '', 'Nan Mitchell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1108, NULL, '2012-01-20 12:54:09.916579+00', 'MacDougall, John', '', 'John MacDougall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1109, NULL, '2012-01-20 12:54:09.919151+00', 'Hutchison, Peg', '', 'Peg Hutchison', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1111, NULL, '2012-01-20 12:54:09.924235+00', 'Boblette / Patterson', '', 'Boblette / Patterson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1112, NULL, '2012-01-20 12:54:09.926777+00', 'McMurtry, Brian', '', 'Brian McMurtry', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11640, '2018-06-03 14:29:13.642789+00', '2018-06-03 14:29:13.642789+00', 'Carter, Patrick', '', 'Patrick Carter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1110, NULL, '2015-03-14 18:11:00.907821+00', 'Blaschke, Marilyn', '', 'Marilyn Blaschke', 'Atlanta', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1039, NULL, '2015-03-14 18:11:28.932772+00', 'West, Barry', '', 'Barry West', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1114, NULL, '2012-01-20 12:54:09.932258+00', 'Kinloch, Murray', '', 'Murray Kinloch', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1115, NULL, '2012-01-20 12:54:09.934851+00', 'Garvie, Mary', '', 'Mary Garvie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1116, NULL, '2012-01-20 12:54:09.937384+00', 'Crighton, Aileen', '', 'Aileen Crighton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1117, NULL, '2012-01-20 12:54:09.939925+00', 'Hutchinson, Nancy', '', 'Nancy Hutchinson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1118, NULL, '2012-01-20 12:54:09.94246+00', 'Easton, Kathleen', '', 'Kathleen Easton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1119, NULL, '2012-01-20 12:54:09.944994+00', 'Cheney, Allan', '', 'Allan Cheney', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1120, NULL, '2012-01-20 12:54:09.947518+00', 'James, Leslie', '', 'Leslie James', '', 'lljames@idirect.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1121, NULL, '2012-01-20 12:54:09.950047+00', 'Williams, Sue', '', 'Sue Williams', 'Paris', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1122, NULL, '2012-01-20 12:54:09.952581+00', 'Bunyan / Leeson', '', 'Bunyan / Leeson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1145, NULL, '2012-01-20 12:54:10.012363+00', 'Cornelius, Don', '', 'Don Cornelius', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1146, NULL, '2012-01-20 12:54:10.014898+00', 'Mackintosh, Brian', '', 'Brian Mackintosh', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1163, NULL, '2012-01-20 12:54:10.058939+00', 'Whitby, Maurice', '', 'Maurice Whitby', 'Montreal, Canada', '', 1, 0, 0, 0, NULL, 0, 2001, NULL, '');
INSERT INTO 'person' VALUES (1164, NULL, '2012-01-20 12:54:10.061659+00', 'Dix, Judy', '', 'Judy Dix', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1165, NULL, '2012-01-20 12:54:10.064212+00', 'Morris, Maureen', '', 'Maureen Morris', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1166, NULL, '2012-01-20 12:54:10.06677+00', 'Fraser, S & B', '', 'S & B Fraser', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1168, NULL, '2012-01-20 12:54:10.071835+00', 'Colville, John', '', 'John Colville', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1169, NULL, '2012-01-20 12:54:10.074362+00', 'Elder, E G', '', 'E G Elder', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1170, NULL, '2012-01-20 12:54:10.076895+00', 'Smith, Nina', '', 'Nina Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1171, NULL, '2012-01-20 12:54:10.079428+00', 'Upritchard, G S', '', 'G S Upritchard', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1172, NULL, '2012-01-20 12:54:10.081958+00', 'Voight (19C)', '', 'Voight (19C)', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1174, NULL, '2012-01-20 12:54:10.087774+00', 'Longton, Connie', '', 'Connie Longton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1175, NULL, '2012-01-20 12:54:10.090316+00', 'Webster, Bob', '', 'Bob Webster', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1176, NULL, '2012-01-20 12:54:10.09285+00', 'Janssen, Brenda', '', 'Brenda Janssen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1076, NULL, '2021-02-19 15:39:36.475665+00', 'MacDonald, Janet', '', 'Janet MacDonald', 'Christchurch, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1177, NULL, '2012-01-20 12:54:10.095412+00', 'Dobie, Charles', '', 'Charles Dobie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1178, NULL, '2012-01-20 12:54:10.097958+00', 'Kowalchuk, Sharon', '', 'Sharon Kowalchuk', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1179, NULL, '2012-01-20 12:54:10.100719+00', 'Roberts, Barbara', '', 'Barbara Roberts', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1180, NULL, '2012-01-20 12:54:10.103573+00', 'Crutcher / Hewinson', '', 'Crutcher / Hewinson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1181, NULL, '2012-01-20 12:54:10.106342+00', 'Taylor, Claire', '', 'Claire Taylor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1182, NULL, '2012-01-20 12:54:10.108898+00', 'Hartgill, Margaret', '', 'Margaret Hartgill', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1147, NULL, '2012-01-20 12:54:10.017431+00', 'McDowell, Andrea', '', 'Andrea McDowell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1148, NULL, '2012-01-20 12:54:10.020133+00', 'Charters, Gillian', '', 'Gillian Charters', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1149, NULL, '2012-01-20 12:54:10.022715+00', 'Fawdry, Biddy', '', 'Biddy Fawdry', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1151, NULL, '2012-01-20 12:54:10.027814+00', 'Shaw, Ken', '', 'Ken Shaw', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1152, NULL, '2012-01-20 12:54:10.030466+00', 'Gregor, Jack', '', 'Jack Gregor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1153, NULL, '2012-01-20 12:54:10.033021+00', 'Orr, Noyes', '', 'Noyes Orr', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1154, NULL, '2012-01-20 12:54:10.035549+00', 'Kinroy, Ian', '', 'Ian Kinroy', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1155, NULL, '2012-01-20 12:54:10.03807+00', 'Luscombe, Tim', '', 'Tim Luscombe', 'Newcastle', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1156, NULL, '2012-01-20 12:54:10.040645+00', 'Ogilvie, Margaret', '', 'Margaret Ogilvie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1157, NULL, '2012-01-20 12:54:10.043314+00', 'Faulding (18C)', '', 'Faulding (18C)', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1159, NULL, '2012-01-20 12:54:10.048675+00', 'McGregor, J & M', '', 'J & M McGregor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1160, NULL, '2012-01-20 12:54:10.05124+00', 'Blane / Weller', '', 'Blane / Weller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1161, NULL, '2012-01-20 12:54:10.053772+00', 'Astor (19C)', '', 'Astor (19C)', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1162, NULL, '2012-01-20 12:54:10.056379+00', 'McLellan, Gladys', '', 'Gladys McLellan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1183, NULL, '2012-01-20 12:54:10.111441+00', 'Saul, Susan', '', 'Susan Saul', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1184, NULL, '2012-01-20 12:54:10.113978+00', 'Block, Michael', '', 'Michael Block', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1185, NULL, '2012-01-20 12:54:10.116539+00', 'Tanner, Rhoda', '', 'Rhoda Tanner', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1186, NULL, '2012-01-20 12:54:10.11907+00', 'Cant, Barry', '', 'Barry Cant', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1202, NULL, '2012-01-20 12:54:10.161365+00', 'McWilliam, Jean', '', 'Jean McWilliam', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1203, NULL, '2012-01-20 12:54:10.163908+00', 'Williams, Mike', '', 'Mike Williams', 'Paris', 'Soundsscot@aol.com', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1204, NULL, '2012-01-20 12:54:10.166434+00', 'Ponteland Class', '', 'Ponteland Class', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1206, NULL, '2012-01-20 12:54:10.171499+00', 'Rowe, Sebastian', '', 'Sebastian Rowe', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1207, NULL, '2012-01-20 12:54:10.174027+00', 'Harvie, Evelyn', '', 'Evelyn Harvie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1208, NULL, '2012-01-20 12:54:10.176559+00', 'Morris, Jessie', '', 'Jessie Morris', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1209, NULL, '2012-01-20 12:54:10.179097+00', 'Pichel, Robin', '', 'Robin Pichel', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1210, NULL, '2012-01-20 12:54:10.181669+00', 'Estreicher, Helen', '', 'Helen Estreicher', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1211, NULL, '2012-01-20 12:54:10.184303+00', 'Maddison, Gay', '', 'Gay Maddison', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1212, NULL, '2012-01-20 12:54:10.186854+00', 'Paton, Walter', '', 'Walter Paton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1216, NULL, '2012-01-20 12:54:10.197026+00', 'Pierce, Todd', '', 'Todd Pierce', '', 'tpierce@terrabase.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1217, NULL, '2012-01-20 12:54:10.199557+00', 'Ewens, Margaret', '', 'Margaret Ewens', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1218, NULL, '2012-01-20 12:54:10.202126+00', 'Luke, Peter', '', 'Peter Luke', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1219, NULL, '2012-01-20 12:54:10.204718+00', 'Spooner, Denise', '', 'Denise Spooner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1220, NULL, '2012-01-20 12:54:10.207248+00', 'Miles, Dorothy', '', 'Dorothy Miles', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1221, NULL, '2012-01-20 12:54:10.209777+00', 'Fell, Margaret', '', 'Margaret Fell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1187, NULL, '2012-01-20 12:54:10.121693+00', 'Inglis, Norman', '', 'Norman Inglis', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1188, NULL, '2012-01-20 12:54:10.124258+00', 'Pugh, Elizabeth', '', 'Elizabeth Pugh', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1189, NULL, '2012-01-20 12:54:10.126803+00', 'Brown, Sheila', '', 'Sheila Brown', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1191, NULL, '2012-01-20 12:54:10.132818+00', 'Bourne, Sheila', '', 'Sheila Bourne', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1192, NULL, '2012-01-20 12:54:10.135535+00', 'Burnet, Jill', '', 'Jill Burnet', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1144, NULL, '2015-08-18 23:56:23.702248+00', 'Stacey, Keith', '', 'Keith Stacey', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1214, NULL, '2018-01-20 00:56:13.367616+00', 'Henry, Puka', '', 'Puka Henry', 'W. Australia', 'anguka@internode.on.net', 1, 1, 0, 0, NULL, 1950, 0, NULL, '');
INSERT INTO 'person' VALUES (1193, NULL, '2012-01-20 12:54:10.138088+00', 'Gamble, Maurice', '', 'Maurice Gamble', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1194, NULL, '2012-01-20 12:54:10.140622+00', 'Andrako, Michelle Chermely', '', 'Michelle Chermely Andrako', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1195, NULL, '2012-01-20 12:54:10.143377+00', 'Mollan, Nancy', '', 'Nancy Mollan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1196, NULL, '2012-01-20 12:54:10.146083+00', 'Colenbrander, Sijbout', '', 'Sijbout Colenbrander', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1197, NULL, '2012-01-20 12:54:10.148663+00', 'Parker, Linda', '', 'Linda Parker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1198, NULL, '2012-01-20 12:54:10.151203+00', 'Atkinson, Gwen', '', 'Gwen Atkinson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1200, NULL, '2012-01-20 12:54:10.15628+00', 'Lewandowski, Jan', '', 'Jan Lewandowski', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1201, NULL, '2012-01-20 12:54:10.158824+00', 'Allan, Pearl', '', 'Pearl Allan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1222, NULL, '2012-01-20 12:54:10.212308+00', 'Helm, Katherine', '', 'Katherine Helm', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1223, NULL, '2012-01-20 12:54:10.214838+00', 'Robertson, Elsie', '', 'Elsie Robertson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1224, NULL, '2012-01-20 12:54:10.217378+00', 'Boalch, Shirley', '', 'Shirley Boalch', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1225, NULL, '2012-01-20 12:54:10.21991+00', 'James, Bob', '', 'Bob James', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1241, NULL, '2012-01-20 12:54:10.260758+00', 'West, Sheena', '', 'Sheena West', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1242, NULL, '2012-01-20 12:54:10.263313+00', 'Stevens, Ian', '', 'Ian Stevens', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1243, NULL, '2012-01-20 12:54:10.265846+00', 'Horne, Neil', '', 'Neil Horne', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1244, NULL, '2012-01-20 12:54:10.268376+00', 'Gordon, C M', '', 'C M Gordon', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1245, NULL, '2012-01-20 12:54:10.270912+00', 'Bride (18C)', '', 'Bride (18C)', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1247, NULL, '2012-01-20 12:54:10.276166+00', 'Smart, John', '', 'John Smart', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1248, NULL, '2012-01-20 12:54:10.278702+00', 'Maxwell, Mairi', '', 'Mairi Maxwell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1249, NULL, '2012-01-20 12:54:10.281401+00', 'Edwards, Prudence', '', 'Prudence Edwards', 'Fredericton, NB, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1250, NULL, '2012-01-20 12:54:10.284102+00', 'MacDonald, A & N', '', 'A & N MacDonald', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1251, NULL, '2012-01-20 12:54:10.286655+00', 'Keir, E & Templeman, J', '', 'Keir, E & Templeman, J', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1252, NULL, '2012-01-20 12:54:10.289236+00', 'Darnell, Margaret', '', 'Margaret Darnell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1158, NULL, '2021-02-26 18:36:57.857489+00', 'MacMillan, Beryl', '', 'Beryl MacMillan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1246, NULL, '2021-04-20 19:36:09.744376+00', 'Elgie, Margaret / Crosbie, Jack', '', 'Margaret Elgie & Jack Crosbie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1253, NULL, '2012-01-20 12:54:10.292118+00', 'Rowe, Margaret', '', 'Margaret Rowe', 'Wigan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1254, NULL, '2012-01-20 12:54:10.294705+00', 'Caskie, Jock', '', 'Jock Caskie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1255, NULL, '2012-01-20 12:54:10.297402+00', 'Richmond Branch RSCDS', '', 'Richmond Branch RSCDS', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1257, NULL, '2012-01-20 12:54:10.302693+00', 'Rowland, Helen', '', 'Helen Rowland', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1259, NULL, '2012-01-20 12:54:10.307788+00', 'Saskatoon SCD Club', '', 'Saskatoon SCD Club', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1260, NULL, '2012-01-20 12:54:10.310321+00', 'Newton, Lilian', '', 'Lilian Newton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1226, NULL, '2012-01-20 12:54:10.222434+00', 'Brophy, Patrick', '', 'Patrick Brophy', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1227, NULL, '2012-01-20 12:54:10.224971+00', 'Deatherage, S / Koss, D', '', 'Deatherage, S / Koss, D', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1228, NULL, '2012-01-20 12:54:10.2275+00', 'Burrows, Rodney J', '', 'Rodney J Burrows', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1230, NULL, '2012-01-20 12:54:10.232568+00', 'Wellenberg, Peter', '', 'Peter Wellenberg', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1232, NULL, '2012-01-20 12:54:10.237635+00', 'Martin, Marjorie', '', 'Marjorie Martin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1233, NULL, '2012-01-20 12:54:10.240164+00', 'Matthews, Pat', '', 'Pat Matthews', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1234, NULL, '2012-01-20 12:54:10.242697+00', 'Lloyd, Gordon', '', 'Gordon Lloyd', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1235, NULL, '2012-01-20 12:54:10.245374+00', 'Waddell, Margaret', '', 'Margaret Waddell', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1236, NULL, '2012-01-20 12:54:10.247938+00', 'Barker, Rob', '', 'Rob Barker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1237, NULL, '2012-01-20 12:54:10.250475+00', 'Lord, David', '', 'David Lord', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1238, NULL, '2012-01-20 12:54:10.253009+00', 'Watkinson, Joan', '', 'Joan Watkinson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1239, NULL, '2012-01-20 12:54:10.255539+00', 'Poulton, E', '', 'E Poulton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1240, NULL, '2012-01-20 12:54:10.25817+00', 'Day, Sue', '', 'Sue Day', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1261, NULL, '2012-01-20 12:54:10.312868+00', 'Williams, Maisie', '', 'Maisie Williams', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1262, NULL, '2012-01-20 12:54:10.315408+00', 'McClintock, Sue', '', 'Sue McClintock', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1263, NULL, '2012-01-20 12:54:10.318084+00', 'Loch Michigan SC Dancers', '', 'Loch Michigan SC Dancers', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1279, NULL, '2012-01-20 12:54:10.359557+00', 'Vaughn, Genny', '', 'Genny Vaughn', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1280, NULL, '2012-01-20 12:54:10.362111+00', 'Adams, Neryl', '', 'Neryl Adams', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1281, NULL, '2012-01-20 12:54:10.364649+00', 'Kirk, Maggie & Randy', '', 'Maggie & Randy Kirk', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1282, NULL, '2012-01-20 12:54:10.367208+00', 'Winton, Jenny', '', 'Jenny Winton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1284, NULL, '2012-01-20 12:54:10.372274+00', 'Bolt, Tessa', '', 'Tessa Bolt', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1286, NULL, '2012-01-20 12:54:10.377335+00', 'Weaver, Jim', '', 'Jim Weaver', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1287, NULL, '2012-01-20 12:54:10.37986+00', 'Dunlop, Madge', '', 'Madge Dunlop', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1288, NULL, '2012-01-20 12:54:10.382384+00', 'Yates, Timothy', '', 'Timothy Yates', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1283, NULL, '2022-02-08 18:39:06.953126+00', 'Wendell, Kathy', '', 'Kathy Wendell', '', '', 1, 0, 0, 0, 11937, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1289, NULL, '2012-01-20 12:54:10.384946+00', 'Lewis, Robert', '', 'Robert Lewis', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1290, NULL, '2012-01-20 12:54:10.387492+00', 'Wilkinson, Alison', '', 'Alison Wilkinson', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1291, NULL, '2012-01-20 12:54:10.390033+00', 'Zon, Hans van', '', 'Hans van Zon', '', 'thehaguebranch@hetnet.nl', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1292, NULL, '2012-01-20 12:54:10.39259+00', 'Melville, M & D', '', 'M & D Melville', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1293, NULL, '2012-01-20 12:54:10.395126+00', 'Sarvis, Paul', '', 'Paul Sarvis', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1294, NULL, '2012-01-20 12:54:10.397654+00', 'Everett, Anne', '', 'Anne Everett', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1295, NULL, '2012-01-20 12:54:10.400312+00', 'Livesey, Lois', '', 'Lois Livesey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1296, NULL, '2012-01-20 12:54:10.402865+00', 'McMath, Robert', '', 'Robert McMath', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1297, NULL, '2012-01-20 12:54:10.405402+00', 'Thomson, Ishbel', '', 'Ishbel Thomson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1265, NULL, '2012-01-20 12:54:10.323516+00', 'Carr, Dottie', '', 'Dottie Carr', 'Sacramento', '', 1, 0, 0, 0, NULL, 0, 2006, NULL, '');
INSERT INTO 'person' VALUES (1266, NULL, '2012-01-20 12:54:10.326057+00', 'Sander, Denise', '', 'Denise Sander', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1267, NULL, '2012-01-20 12:54:10.328593+00', 'Galipeault, Deborah', '', 'Deborah Galipeault', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1270, NULL, '2012-01-20 12:54:10.336206+00', 'Drennan, Rena', '', 'Rena Drennan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1269, NULL, '2015-03-14 18:11:30.228545+00', 'Zadworny, Margaret', '', 'Margaret Zadworny', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1256, NULL, '2016-04-23 18:46:04.3168+00', 'McKenzie, Ian', '', 'Ian McKenzie', 'Stockton on Tees, UK', '', 1, 0, 0, 0, NULL, 0, 2016, NULL, '');
INSERT INTO 'person' VALUES (1285, NULL, '2017-09-09 23:56:12.642366+00', 'Kemp, L & E', '', 'L & E Kemp', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11641, '2018-06-10 11:13:30.641559+00', '2018-06-10 23:56:15.0248+00', 'Lang, Matthias', '', 'Matthias Lang', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11642, '2018-06-11 10:43:25.199438+00', '2018-06-11 10:43:25.199438+00', 'Hilpert, Corinne', '', 'Corinne Hilpert', 'Lyon, France', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1271, NULL, '2012-01-20 12:54:10.338745+00', 'Cunningham, P', '', 'P Cunningham', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1272, NULL, '2012-01-20 12:54:10.34128+00', 'Rintoul, Laura', '', 'Laura Rintoul', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1273, NULL, '2012-01-20 12:54:10.343838+00', 'Hutchinson, Jim', '', 'Jim Hutchinson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1274, NULL, '2012-01-20 12:54:10.346368+00', 'Potter, Hazel', '', 'Hazel Potter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1275, NULL, '2012-01-20 12:54:10.349275+00', 'Reid, Kenneth', '', 'Kenneth Reid', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1277, NULL, '2012-01-20 12:54:10.354383+00', 'Thompson, Henry', '', 'Henry Thompson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1278, NULL, '2012-01-20 12:54:10.356917+00', 'Mackenzie, Graham', '', 'Graham Mackenzie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1298, NULL, '2012-01-20 12:54:10.407926+00', 'Darney, Mike', '', 'Mike Darney', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1299, NULL, '2012-01-20 12:54:10.410455+00', 'Moodie, B & Murphy, T', '', 'Moodie, B & Murphy, T', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1300, NULL, '2012-01-20 12:54:10.412993+00', 'Dann, Barbara', '', 'Barbara Dann', 'Friday Harbor, WA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1301, NULL, '2012-01-20 12:54:10.415527+00', 'Chamoin, Jacques', '', 'Jacques Chamoin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1302, NULL, '2012-01-20 12:54:10.418056+00', 'Avery, Andrew', '', 'Andrew Avery', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1318, NULL, '2012-01-20 12:54:10.465261+00', 'Nicoll', '', 'Nicoll', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1303, NULL, '2012-01-20 12:54:10.420588+00', 'Seaton, B', '', 'B Seaton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1319, NULL, '2012-01-20 12:54:10.467807+00', 'Fergusson, Dave', '', 'Dave Fergusson', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1305, NULL, '2012-01-20 12:54:10.426259+00', 'Glenville/Miller', '', 'Glenville/Miller', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1320, NULL, '2012-01-20 12:54:10.470334+00', 'Doyle, George', '', 'George Doyle', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1306, NULL, '2012-01-20 12:54:10.429784+00', 'Gray, A Ogilvie', '', 'A Ogilvie Gray', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1307, NULL, '2012-01-20 12:54:10.433544+00', 'Harris, Austin & Gibson', '', 'Austin & Gibson Harris', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1321, NULL, '2012-01-20 12:54:10.472873+00', 'Anning, Jocelyn', '', 'Jocelyn Anning', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1308, NULL, '2012-01-20 12:54:10.437257+00', 'Padgham, Joan', '', 'Joan Padgham', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2396, NULL, '2018-06-11 11:09:38.530671+00', 'McGarrity, Kim & Taylor, John', '', 'Kim McGarrity & John Taylor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1322, NULL, '2012-01-20 12:54:10.475406+00', 'Small, Alex', '', 'Alex Small', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1310, NULL, '2012-01-20 12:54:10.443871+00', 'Clarke, Bronwyn', '', 'Bronwyn Clarke', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1311, NULL, '2012-01-20 12:54:10.447205+00', 'Hastings, Dorothy', '', 'Dorothy Hastings', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1323, NULL, '2012-01-20 12:54:10.477941+00', 'Herman, Myrtle Tudor', '', 'Myrtle Tudor Herman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1312, NULL, '2012-01-20 12:54:10.449982+00', 'Nichols, Bill', '', 'Bill Nichols', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1313, NULL, '2012-01-20 12:54:10.452533+00', 'Campbell, Edith Lauder', '', 'Edith Lauder Campbell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1324, NULL, '2012-01-20 12:54:10.480475+00', 'Pringle, Margaret', '', 'Margaret Pringle', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1314, NULL, '2012-01-20 12:54:10.45507+00', 'Parker, Pauline', '', 'Pauline Parker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1315, NULL, '2012-01-20 12:54:10.4576+00', 'Robertson, Harry', '', 'Harry Robertson', '', 'Club1941@blueyonder.co.uk', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1325, NULL, '2012-01-20 12:54:10.483004+00', 'Cruickshanks, Irene C', '', 'Irene C Cruickshanks', 'Dundee', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1316, NULL, '2012-01-20 12:54:10.460177+00', 'Boxall, Catherine', '', 'Catherine Boxall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1317, NULL, '2012-01-20 12:54:10.462726+00', 'Phythian, Margaret', '', 'Margaret Phythian', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1326, NULL, '2012-01-20 12:54:10.485534+00', 'Buie, M / Keppie, J D', '', 'M Buie / J D Keppie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1327, NULL, '2012-01-20 12:54:10.488065+00', 'Grant, Alan', '', 'Alan Grant', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1328, NULL, '2012-01-20 12:54:10.490598+00', 'Catto, Christian', '', 'Christian Catto', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1330, NULL, '2012-01-20 12:54:10.495663+00', 'Maxwell, John', '', 'John Maxwell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1332, NULL, '2012-01-20 12:54:10.500728+00', 'Shore, June', '', 'June Shore', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1333, NULL, '2012-01-20 12:54:10.503326+00', 'Bowlen, Phil & Lawrie', '', 'Phil & Lawrie Bowlen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1334, NULL, '2012-01-20 12:54:10.505859+00', 'Baker, Jean', '', 'Jean Baker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1335, NULL, '2012-01-20 12:54:10.508393+00', 'Burnham, Sydney', '', 'Sydney Burnham', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1336, NULL, '2012-01-20 12:54:10.510929+00', 'Kennedy, K', '', 'K Kennedy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1337, NULL, '2012-01-20 12:54:10.513464+00', 'Werner, Alan', '', 'Alan Werner', 'Renton, WA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1338, NULL, '2012-01-20 12:54:10.515998+00', 'Bower, Blair', '', 'Blair Bower', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1339, NULL, '2012-01-20 12:54:10.518532+00', 'Read, Rosemary', '', 'Rosemary Read', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1340, NULL, '2012-01-20 12:54:10.521073+00', 'Bone, Robert', '', 'Robert Bone', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1304, NULL, '2012-01-20 12:54:10.423186+00', 'MacKay, Hugh', '', 'Hugh MacKay', '', '', 0, 0, 1, 0, 1304, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1356, NULL, '2012-01-20 12:54:10.562236+00', 'Murdoch, Bruce', '', 'Bruce Murdoch', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1341, NULL, '2012-01-20 12:54:10.523619+00', 'Baird, Robert', '', 'Robert Baird', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1342, NULL, '2012-01-20 12:54:10.52622+00', 'Morrison, Tom', '', 'Tom Morrison', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1344, NULL, '2012-01-20 12:54:10.531284+00', 'Scott, Joyce', '', 'Joyce Scott', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1358, NULL, '2012-01-20 12:54:10.567335+00', 'Juarncich, Joan', '', 'Joan Juarncich', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1345, NULL, '2012-01-20 12:54:10.533811+00', 'Fleming, Priscilla', '', 'Priscilla Fleming', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1346, NULL, '2012-01-20 12:54:10.536348+00', 'Whitehorne, George', '', 'George Whitehorne', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1347, NULL, '2012-01-20 12:54:10.53889+00', 'Miller, Anne', '', 'Anne Miller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1348, NULL, '2012-01-20 12:54:10.541458+00', 'Fyfe, Jim, John & Lynn', '', 'Fyfe, Jim, John & Lynn', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1350, NULL, '2012-01-20 12:54:10.546581+00', 'Treble, Joan', '', 'Joan Treble', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1361, NULL, '2012-01-20 12:54:10.574943+00', 'Lawson, Mary', '', 'Mary Lawson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1351, NULL, '2012-01-20 12:54:10.549452+00', 'Fyfe, J & Hutton, Neil', '', 'Fyfe, J & Hutton, Neil', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1352, NULL, '2012-01-20 12:54:10.552066+00', 'Peerless, Elizabeth', '', 'Elizabeth Peerless', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1362, NULL, '2012-01-20 12:54:10.577474+00', 'Guilcher, Mylene', '', 'Mylene Guilcher', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1353, NULL, '2012-01-20 12:54:10.554614+00', 'Fraser, Nessie', '', 'Nessie Fraser', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1354, NULL, '2012-01-20 12:54:10.557168+00', 'Kyd, Fanny P', '', 'Fanny P Kyd', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1363, NULL, '2012-01-20 12:54:10.58+00', 'McBride, Irene', '', 'Irene McBride', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1355, NULL, '2012-01-20 12:54:10.559708+00', 'Steyn, Lorraine', '', 'Lorraine Steyn', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1364, NULL, '2012-01-20 12:54:10.582575+00', 'Savage, Margaret', '', 'Margaret Savage', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1365, NULL, '2012-01-20 12:54:10.585112+00', 'Mortier, Yvonne', '', 'Yvonne Mortier', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1366, NULL, '2012-01-20 12:54:10.587647+00', 'Miller, Mary', '', 'Mary Miller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1357, NULL, '2016-08-25 14:26:02.4768+00', 'Gray, Margaret', '', 'Margaret Gray', 'Australia?', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1331, NULL, '2016-10-04 23:56:18.907144+00', 'Herbold, Bruce', '', 'Bruce Herbold', 'San Francisco', 'bherbold@gmail.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1329, NULL, '2016-12-13 17:37:57.79244+00', 'Adams, Peter', '', 'Peter Adams', 'Hunter Valley Branch, Australia', '', 1, 0, 1, 0, NULL, 0, 2016, NULL, '');
INSERT INTO 'person' VALUES (1367, NULL, '2012-01-20 12:54:10.590176+00', 'Robertson, Monica', '', 'Monica Robertson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1368, NULL, '2012-01-20 12:54:10.592708+00', 'Tyler, Victor & Susan', '', 'Victor & Susan Tyler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1369, NULL, '2012-01-20 12:54:10.595247+00', 'Campbell / Redfearn / Morris', '', 'Campbell / Redfearn / Morris', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1370, NULL, '2012-01-20 12:54:10.597777+00', 'Anderson, Beth', '', 'Beth Anderson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1371, NULL, '2012-01-20 12:54:10.600368+00', 'Keech, Marjorie & Diana', '', 'Marjorie & Diana Keech', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1372, NULL, '2012-01-20 12:54:10.602905+00', 'Raynor, Mairi', '', 'Mairi Raynor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1373, NULL, '2012-01-20 12:54:10.605434+00', 'Homes, John', '', 'John Homes', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1374, NULL, '2012-01-20 12:54:10.607965+00', 'Schoeters, Veronica', '', 'Veronica Schoeters', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1375, NULL, '2012-01-20 12:54:10.6105+00', 'Tyler, Victor', '', 'Victor Tyler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1376, NULL, '2012-01-20 12:54:10.613044+00', 'Hogg, Elizabeth', '', 'Elizabeth Hogg', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1377, NULL, '2012-01-20 12:54:10.615576+00', 'Brookings, Pauline', '', 'Pauline Brookings', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1378, NULL, '2012-01-20 12:54:10.618107+00', 'Porter, Brenda', '', 'Brenda Porter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1359, NULL, '2012-01-20 12:54:10.56987+00', 'Macrae, Marjorie', '', 'Marjorie Macrae', 'West Lothian', '', 1, 1, 0, 0, 1359, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1379, NULL, '2012-01-20 12:54:10.620649+00', 'Cutts, Lesley', '', 'Lesley Cutts', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1380, NULL, '2012-01-20 12:54:10.623196+00', 'Simkins, Robert', '', 'Robert Simkins', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1395, NULL, '2012-01-20 12:54:10.66217+00', 'Harvey, Marianna', '', 'Marianna Harvey', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1383, NULL, '2012-01-20 12:54:10.630795+00', 'Hamilton, Bruce', '', 'Bruce Hamilton', 'San Francisco', 'brucehamilton@macconnect.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1396, NULL, '2012-01-20 12:54:10.664719+00', 'Hall, David and his Scottish Dance Band', 'David Hall', 'David Hall and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1384, NULL, '2012-01-20 12:54:10.63333+00', 'Antley-Olander, Tracy', '', 'Tracy Antley-Olander', 'Seattle', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1385, NULL, '2012-01-20 12:54:10.63586+00', 'Nus, Marge van', '', 'Marge van Nus', 'Seattle', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1397, NULL, '2012-01-20 12:54:10.667264+00', 'Rule, J', '', 'J Rule', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1386, NULL, '2012-01-20 12:54:10.63839+00', 'Hoffmann, Meredith', '', 'Meredith Hoffmann', 'Boston', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1387, NULL, '2012-01-20 12:54:10.64093+00', 'Bolton, Nel', '', 'Nel Bolton', 'Toronto', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1388, NULL, '2012-01-20 12:54:10.643464+00', 'McIntyre, Mrs', '', 'Mrs McIntyre', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1389, NULL, '2012-01-20 12:54:10.645986+00', 'Vanek, Mary Jane', '', 'Mary Jane Vanek', 'Lehigh Valley, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1399, NULL, '2012-01-20 12:54:10.672424+00', 'Wilson, John', '', 'John Wilson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1390, NULL, '2012-01-20 12:54:10.648967+00', 'Lewis, Uncle Barry', '', 'Uncle Barry Lewis', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1391, NULL, '2012-01-20 12:54:10.651668+00', 'Karwelis, Donald', '', 'Donald Karwelis', 'Orange County, USA', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1392, NULL, '2012-01-20 12:54:10.654209+00', 'Guilbert, Rose', '', 'Rose Guilbert', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1401, NULL, '2012-01-20 12:54:10.677659+00', 'Mackintosh, Abraham', '', 'Abraham Mackintosh', '', '', 0, 0, 1, 0, NULL, 1769, 1808, NULL, '');
INSERT INTO 'person' VALUES (1402, NULL, '2012-01-20 12:54:10.680194+00', 'Reekie, Moira', '', 'Moira Reekie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1403, NULL, '2012-01-20 12:54:10.682732+00', 'Millward, Jack', '', 'Jack Millward', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1404, NULL, '2012-01-20 12:54:10.685261+00', 'Esson, Charles W R', '', 'Charles W R Esson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1405, NULL, '2012-01-20 12:54:10.687793+00', 'Cowan, Marie', '', 'Marie Cowan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1406, NULL, '2012-01-20 12:54:10.690328+00', 'Mann, Alice B W', '', 'Alice B W Mann', 'Dundee', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1407, NULL, '2012-01-20 12:54:10.692861+00', 'Ellis, Robin', '', 'Robin Ellis', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1408, NULL, '2012-01-20 12:54:10.695435+00', 'Livingston, Beryl', '', 'Beryl Livingston', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1409, NULL, '2012-01-20 12:54:10.697961+00', 'MacLennan, Alice', '', 'Alice MacLennan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1410, NULL, '2012-01-20 12:54:10.700494+00', 'Wallace, Robert', '', 'Robert Wallace', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1411, NULL, '2012-01-20 12:54:10.703027+00', 'Bolton, Calum', '', 'Calum Bolton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1412, NULL, '2012-01-20 12:54:10.705559+00', 'MacLeod, Yvonne', '', 'Yvonne MacLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1414, NULL, '2012-01-20 12:54:10.710616+00', 'Mackinnon, Angus', 'Angus Mackinnon', 'Angus Mackinnon', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11643, '2018-06-12 23:24:24.175075+00', '2018-06-12 23:24:24.175075+00', 'Eysseric, Violaine', '', 'Violaine Eysseric', 'Paris, France', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1431, NULL, '2012-01-20 12:54:10.754267+00', 'Liddle, Samuel', '', 'Samuel Liddle', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1417, NULL, '2012-01-20 12:54:10.718199+00', 'Smith, John W', '', 'John W Smith', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1432, NULL, '2012-01-20 12:54:10.758924+00', 'Rorie, David', '', 'David Rorie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1419, NULL, '2012-01-20 12:54:10.72326+00', 'Bawcomb, Jack', '', 'Jack Bawcomb', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1420, NULL, '2012-01-20 12:54:10.725795+00', 'Stirling, Magdaline', '', 'Magdaline Stirling', '(18C)', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1433, NULL, '2012-01-20 12:54:10.761481+00', 'Leeves, Rev. W', '', 'Rev. W Leeves', '', '', 0, 0, 1, 0, NULL, 1748, 1828, NULL, '');
INSERT INTO 'person' VALUES (1421, NULL, '2012-01-20 12:54:10.728333+00', 'McLeod, Alexander', '', 'Alexander McLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1422, NULL, '2012-01-20 12:54:10.730887+00', 'Keenan, George', '', 'George Keenan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1423, NULL, '2012-01-20 12:54:10.733437+00', 'McLeod, Peter', '', 'Peter McLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1424, NULL, '2012-01-20 12:54:10.735964+00', 'Volti, Carl', '', 'Carl Volti', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1435, NULL, '2012-01-20 12:54:10.766544+00', 'Pollock, Willie', '', 'Willie Pollock', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1425, NULL, '2012-01-20 12:54:10.738493+00', 'Hall, John', '', 'John Hall', '', '', 0, 0, 1, 0, NULL, 1788, 1862, NULL, '');
INSERT INTO 'person' VALUES (1398, NULL, '2022-04-07 19:06:49.491181+00', 'Cameron, Alexander', '', 'Alexander Cameron', '', '', 0, 0, 1, 0, NULL, 1821, 1870, NULL, '');
INSERT INTO 'person' VALUES (1349, NULL, '2022-07-30 12:40:55.802732+00', 'Porter, Carol', '', 'Carol Porter', 'N. Virginia, USA', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1400, NULL, '2022-12-17 00:56:32.755217+00', 'Jamieson, J', '', 'J Jamieson', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1426, NULL, '2012-01-20 12:54:10.741037+00', 'Ramsay, P/M Donald Shaw', '', 'P/M Donald Shaw Ramsay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1436, NULL, '2012-01-20 12:54:10.76908+00', 'Gillan, J', '', 'J Gillan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1429, NULL, '2012-01-20 12:54:10.749073+00', 'Galloway, John P', '', 'John P Galloway', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1430, NULL, '2012-01-20 12:54:10.751725+00', 'Clapperton, Rena', '', 'Rena Clapperton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1440, NULL, '2012-01-20 12:54:10.779254+00', 'Mackellar, A', '', 'A Mackellar', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1441, NULL, '2012-01-20 12:54:10.781827+00', 'Volti, A M', '', 'A M Volti', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1442, NULL, '2012-01-20 12:54:10.78437+00', 'Watts, Stanley', '', 'Stanley Watts', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1439, NULL, '2015-03-14 18:11:06.732378+00', 'Ferguson, Hugh', '', 'Hugh Ferguson', '', '', 1, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1381, NULL, '2015-03-14 18:11:10.260349+00', 'Harriman, Sarah', '', 'Sarah Harriman', 'Austin, Texas', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1413, NULL, '2015-03-14 18:11:29.113965+00', 'White, David', '', 'David White', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1418, NULL, '2015-12-13 12:19:15.43729+00', 'Johnston, Margaret', '', 'Margaret Johnston', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, 'Margaret Johnston is the mother of dance author John A. Johnston.');
INSERT INTO 'person' VALUES (1393, NULL, '2016-10-25 12:30:39.384525+00', 'Newitt, David C', '', 'David C Newitt', 'San Francisco', 'dnewitt@sbcglobal.net', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1443, NULL, '2012-01-20 12:54:10.786906+00', 'Robertson, Anna', '', 'Anna Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1446, NULL, '2012-01-20 12:54:10.79456+00', 'MacLeish, Ian', '', 'Ian MacLeish', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1448, NULL, '2012-01-20 12:54:10.799645+00', 'Robertson, George', '', 'George Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1449, NULL, '2012-01-20 12:54:10.802179+00', 'MacNab, C', '', 'C MacNab', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1450, NULL, '2012-01-20 12:54:10.804859+00', 'Grey, William', '', 'William Grey', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1451, NULL, '2012-01-20 12:54:10.80743+00', 'Ramsay, Allan', '', 'Allan Ramsay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1452, NULL, '2012-01-20 12:54:10.809969+00', 'Magill, Jim', '', 'Jim Magill', 'Ontario, Canada', '', 0, 0, 1, 0, NULL, 1905, 1954, NULL, '');
INSERT INTO 'person' VALUES (1453, NULL, '2012-01-20 12:54:10.812513+00', 'Boyne, Charles', '', 'Charles Boyne', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1454, NULL, '2012-01-20 12:54:10.815044+00', 'Carnie, Winifred', '', 'Winifred Carnie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1427, NULL, '2012-01-20 12:54:10.743573+00', 'Blyth, Williamson', '', 'Williamson Blyth', '', '', 0, 0, 1, 0, 1427, 1821, 1897, NULL, '');
INSERT INTO 'person' VALUES (1455, NULL, '2012-01-20 12:54:10.817587+00', 'Bowman, D', '', 'D Bowman', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1456, NULL, '2012-01-20 12:54:10.820122+00', 'Stirrat, George B', 'George Stirrat', 'George B Stirrat', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1462, NULL, '2012-01-20 12:54:10.837851+00', 'MacFadyen, Joseph', '', 'Joseph MacFadyen', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1458, NULL, '2012-01-20 12:54:10.825188+00', 'Aird, James', '', 'James Aird', '', '', 0, 0, 1, 0, NULL, 0, 1795, NULL, '');
INSERT INTO 'person' VALUES (1459, NULL, '2012-01-20 12:54:10.827724+00', 'MacPherson, Colin', '', 'Colin MacPherson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1482, NULL, '2012-02-07 10:37:10.533721+00', 'Gent, Iain', '', 'Iain Gent', '?', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1460, NULL, '2012-01-20 12:54:10.830252+00', 'Hume, Alexander', '', 'Alexander Hume', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1464, NULL, '2012-01-20 12:54:10.844461+00', 'Robson, Brenda', '', 'Brenda Robson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1465, NULL, '2012-01-20 12:54:10.847748+00', 'Sturrock, Sheena', '', 'Sheena Sturrock', 'Cupar, Fife', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1466, NULL, '2012-01-20 12:54:10.85111+00', 'Young, James', '', 'James Young', 'Aberdeen', '', 0, 0, 1, 0, NULL, 1815, 1851, NULL, '');
INSERT INTO 'person' VALUES (1467, NULL, '2012-01-20 12:54:10.853922+00', 'Graetz, J M', '', 'J M Graetz', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1468, NULL, '2012-01-20 12:54:10.856471+00', 'Stewart, Gertrude', '', 'Gertrude Stewart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1469, NULL, '2012-01-20 12:54:10.859028+00', 'Blamire, Susanna', '', 'Susanna Blamire', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1470, NULL, '2012-01-20 12:54:10.861728+00', 'Grant, David', '', 'David Grant', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1472, NULL, '2012-01-20 12:54:10.866846+00', 'Taylor, Muriel', '', 'Muriel Taylor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1474, NULL, '2012-01-20 12:54:10.872031+00', 'Harvey, Bobby', 'Bobby Harvey', 'Bobby Harvey', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1475, NULL, '2012-01-20 12:54:10.875114+00', 'Billing, Margaret', '', 'Margaret Billing', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1477, NULL, '2012-01-20 12:54:10.881308+00', 'Sewell, John', '', 'John Sewell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1478, NULL, '2012-01-20 12:54:10.883914+00', 'Gibb, Janette', '', 'Janette Gibb', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1479, NULL, '2012-01-20 12:54:10.886502+00', 'Birkin, Kenneth', '', 'Kenneth Birkin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1480, NULL, '2012-01-20 12:54:10.889243+00', 'Lindsay, Jack', '', 'Jack Lindsay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1481, NULL, '2012-01-20 12:54:10.891989+00', 'HF Members Lodge Hill', '', 'HF Members Lodge Hill', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1483, NULL, '2012-01-20 12:54:10.897313+00', 'Watson, George', '', 'George Watson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1484, NULL, '2012-01-20 12:54:10.899849+00', 'Gillespie, Duncan', '', 'Duncan Gillespie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1485, NULL, '2012-01-20 12:54:10.902384+00', 'Eastwood, Karen', '', 'Karen Eastwood', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1487, NULL, '2012-01-20 12:54:10.907545+00', 'Troup, Alexander', '', 'Alexander Troup', '', '', 0, 0, 1, 0, NULL, 1835, 0, NULL, '');
INSERT INTO 'person' VALUES (1488, NULL, '2012-01-20 12:54:10.910077+00', 'Hunter, James M', '', 'James M Hunter', '', '', 0, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1489, NULL, '2012-01-20 12:54:10.912604+00', 'Gilbert, Joan', '', 'Joan Gilbert', '', '', 0, 0, 1, 0, NULL, 1915, 2002, NULL, '');
INSERT INTO 'person' VALUES (1491, NULL, '2012-01-20 12:54:10.918048+00', 'Macintosh, Jimmy Orchestra, The', 'Jimmy Macintosh', 'The Jimmy Macintosh Orchestra', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1493, NULL, '2012-01-20 12:54:10.923148+00', 'Campbell, Joshua', '', 'Joshua Campbell', '', '', 0, 0, 1, 0, NULL, 0, 1801, NULL, '');
INSERT INTO 'person' VALUES (1494, NULL, '2012-01-20 12:54:10.925701+00', 'Corelli, Archangelo', '', 'Archangelo Corelli', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1509, NULL, '2012-01-20 12:54:10.975292+00', 'Forbes, Francis', '', 'Francis Forbes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1495, NULL, '2012-01-20 12:54:10.928231+00', 'Jenkins, George', '', 'George Jenkins', '', '', 0, 0, 1, 0, NULL, 0, 1806, NULL, '');
INSERT INTO 'person' VALUES (1496, NULL, '2012-01-20 12:54:10.930804+00', 'MacAlpine, A', '', 'A MacAlpine', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1497, NULL, '2012-01-20 12:54:10.933341+00', 'Samson, P/M Stuart D', '', 'P/M Stuart D Samson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1498, NULL, '2012-01-20 12:54:10.93587+00', 'No Strings Attached', 'No Strings', 'No Strings Attached', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1499, NULL, '2012-01-20 12:54:10.938401+00', 'Center, James A', '', 'James A Center', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1512, NULL, '2012-01-20 12:54:10.983037+00', 'Skinner, James Scott', '', 'James Scott Skinner', '', '', 0, 1, 1, 0, NULL, 1842, 1927, NULL, '');
INSERT INTO 'person' VALUES (11740, '2018-10-20 21:46:28.209126+00', '2018-10-20 21:49:57.132929+00', 'Reeves, Jon', '', 'Jon Reeves', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1513, NULL, '2012-01-20 12:54:10.985574+00', 'McLeod, Rev. Wm.', '', 'Rev. Wm. McLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1503, NULL, '2012-01-20 12:54:10.959967+00', 'Miles', '', 'Miles', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1504, NULL, '2012-01-20 12:54:10.962502+00', 'O''Connor, Jean', '', 'Jean O''Connor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1514, NULL, '2012-01-20 12:54:10.988288+00', 'Robb, William', '', 'William Robb', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1506, NULL, '2012-01-20 12:54:10.967565+00', 'Findlay, Ian', '', 'Ian Findlay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1507, NULL, '2012-01-20 12:54:10.970155+00', 'Crichton, Ian', '', 'Ian Crichton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1517, NULL, '2012-01-20 12:54:10.995978+00', 'Gow, Nathaniel', '', 'Nathaniel Gow', '', '', 1, 0, 1, 0, NULL, 1766, 1831, NULL, '');
INSERT INTO 'person' VALUES (1518, NULL, '2012-01-20 12:54:10.998507+00', 'Gow, Niel', '', 'Niel Gow', '', '', 0, 0, 1, 0, NULL, 1727, 1807, NULL, '');
INSERT INTO 'person' VALUES (1490, NULL, '2015-03-14 18:11:03.769796+00', 'Clinkscale, Jimmy', '', 'Jimmy Clinkscale', '', '', 0, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1521, NULL, '2015-03-14 18:11:04.76902+00', 'Cunningham, David I (Snr)', '', 'David I (Snr) Cunningham', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1473, NULL, '2015-03-14 18:11:08.823893+00', 'Gordon, David', '', 'David Gordon', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1510, NULL, '2015-03-14 18:11:20.40954+00', 'Ozorak, Elizabeth Weiss', '', 'Elizabeth Weiss Ozorak', '', 'eozorak@allegheny.edu', 1, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1520, NULL, '2022-12-18 20:25:45.035272+00', 'Kindness, Allan', '', 'Allan Kindness', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1511, NULL, '2015-03-14 18:11:20.431064+00', 'Ozorak, Etienne W.', '', 'Etienne W. Ozorak', '', 'etozorak@toolcity.net', 0, 0, 1, 1, NULL, 1958, 0, NULL, '');
INSERT INTO 'person' VALUES (1461, NULL, '2015-03-14 18:11:20.686416+00', 'Pearlman, Ed', '', 'Ed Pearlman', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1457, NULL, '2015-03-14 18:11:21.722085+00', 'Price, Ian', '', 'Ian Price', 'Vancouver', 'ian@priceng.com', 1, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1508, NULL, '2016-12-02 00:56:18.052341+00', 'Meikle, George', '', 'George Meikle', '', 'George.Meikle@btinternet.com', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3334, NULL, '2018-10-29 11:07:10.96302+00', 'RSCDS Lyon Branch', '', 'RSCDS Lyon Branch', 'Lyon, France', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1524, NULL, '2012-01-20 12:54:11.013807+00', 'Magee, C', '', 'C Magee', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1528, NULL, '2012-01-20 12:54:11.02439+00', 'Shulman Shaw, P', '', 'P Shulman Shaw', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1530, NULL, '2012-01-20 12:54:11.030195+00', 'Cameron, Iain C', '', 'Iain C Cameron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1532, NULL, '2012-01-20 12:54:11.035726+00', 'Kemp, Willie', '', 'Willie Kemp', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1550, NULL, '2012-01-20 12:54:11.082087+00', 'Ritchie, Jimmy', '', 'Jimmy Ritchie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1535, NULL, '2012-01-20 12:54:11.043568+00', 'Jamieson, Frank Ronald', '', 'Frank Ronald Jamieson', 'Shetland', '', 0, 0, 1, 0, NULL, 1919, 1982, NULL, '');
INSERT INTO 'person' VALUES (1536, NULL, '2012-01-20 12:54:11.046306+00', 'Gray, Mabel', '', 'Mabel Gray', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1537, NULL, '2012-01-20 12:54:11.048859+00', 'Fleming, George', '', 'George Fleming', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1538, NULL, '2012-01-20 12:54:11.051397+00', 'Sherrit, Charles F', '', 'Charles F Sherrit', '', '', 0, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1539, NULL, '2012-01-20 12:54:11.053933+00', 'Hardie, Ian', '', 'Ian Hardie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1553, NULL, '2012-01-20 12:54:11.090463+00', 'MacDonald, Norman', '', 'Norman MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1541, NULL, '2012-01-20 12:54:11.059048+00', 'MacPherson, William', 'Wm MacPherson', 'William MacPherson', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1542, NULL, '2012-01-20 12:54:11.061689+00', 'Inglis, Susan', '', 'Susan Inglis', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1544, NULL, '2012-01-20 12:54:11.066768+00', 'Mullen, T C', '', 'T C Mullen', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1545, NULL, '2012-01-20 12:54:11.069319+00', 'Roever / Korb', '', 'Roever / Korb', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1546, NULL, '2012-01-20 12:54:11.071908+00', 'Macaulay, I', '', 'I Macaulay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1547, NULL, '2012-01-20 12:54:11.074485+00', 'MacGregor, John', '', 'John MacGregor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1557, NULL, '2012-01-20 12:54:11.100832+00', 'Reid, Frank', 'Frank Reid', 'Frank Reid', '', 'web@frankreid.com', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1549, NULL, '2012-01-20 12:54:11.07956+00', 'MacDonald, John', 'John MacDonald', 'John MacDonald', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11611, '2018-03-18 08:49:09.912495+00', '2018-03-31 23:56:16.081051+00', 'Matthew Maclennan Scottish Dance Band', 'Matthew Maclennan SDB', 'Matthew Maclennan Scottish Dance Band', 'Edinburgh', 'info@matthew-maclennan.co.ukBand', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1560, NULL, '2012-01-20 12:54:11.110499+00', 'Matthew, Winifred Bird', '', 'Winifred Bird Matthew', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1563, NULL, '2012-01-20 12:54:11.11926+00', 'Bland, A', '', 'A Bland', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1564, NULL, '2012-01-20 12:54:11.122745+00', 'MacLeod, Dugald C', '', 'Dugald C MacLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1552, NULL, '2020-04-02 22:51:01.371478+00', 'Bratton, John W', '', 'John W Bratton', '', '', 0, 0, 1, 0, NULL, 1867, 1947, NULL, 'https://en.wikipedia.org/wiki/John_W._Bratton');
INSERT INTO 'person' VALUES (1562, NULL, '2020-06-11 18:38:37.125148+00', 'Waugh, Robert', '', 'Robert Waugh', 'Canada', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Originally from Cockenzie, East Lothian.');
INSERT INTO 'person' VALUES (1505, NULL, '2020-07-04 10:01:31.824979+00', 'Murray, Bert', '', 'Bert Murray', '', '', 0, 1, 1, 0, NULL, 1913, 2003, NULL, '');
INSERT INTO 'person' VALUES (1526, NULL, '2021-01-05 16:03:15.711968+00', 'Dewhurst, Chris', '', 'Chris Dewhurst', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1500, NULL, '2021-06-08 20:37:57.618426+00', 'Boode, Aad L M', '', 'Aad L M Boode', '', 'aad@blueyonder.co.uk', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1565, NULL, '2012-01-20 12:54:11.128084+00', 'Thomson, Eileen', '', 'Eileen Thomson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1566, NULL, '2012-01-20 12:54:11.132288+00', 'Urquhart, James', '', 'James Urquhart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1568, NULL, '2012-01-20 12:54:11.138894+00', 'Braidwood, James', '', 'James Braidwood', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1569, NULL, '2012-01-20 12:54:11.142051+00', 'Loch, Rob', '', 'Rob Loch', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1570, NULL, '2012-01-20 12:54:11.144639+00', 'McDonald', '', 'McDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11524, '2017-09-12 23:46:59.779545+00', '2018-06-10 11:13:51.523758+00', 'Sievers, Anett, Staub, Susanne, and Lang, Matthias', 'Sievers / Staub / Lang', 'Anett Sievers, Susanne Staub and Matthias Lang', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1573, NULL, '2012-01-20 12:54:11.152609+00', 'MacInnes, Norrie', '', 'Norrie MacInnes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1588, NULL, '2012-01-20 12:54:11.190777+00', 'Robertson, John', '', 'John Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1574, NULL, '2012-01-20 12:54:11.155162+00', 'Douglas, John', '', 'John Douglas', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1519, NULL, '2013-12-30 01:22:01.544629+00', 'Mackintosh, Robert', '', 'Robert Mackintosh', '', '', 0, 0, 1, 0, NULL, 1745, 1807, NULL, '');
INSERT INTO 'person' VALUES (1589, NULL, '2012-01-20 12:54:11.193316+00', 'Lowe, James Fraser', '', 'James Fraser Lowe', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1577, NULL, '2012-01-20 12:54:11.162771+00', 'Telford, Roland', '', 'Roland Telford', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1590, NULL, '2012-01-20 12:54:11.195846+00', 'Muir, Ian R', 'Ian R Muir', 'Ian R Muir', 'Berkshire', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1581, NULL, '2012-01-20 12:54:11.173024+00', 'Wilson, J', '', 'J Wilson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1583, NULL, '2012-01-20 12:54:11.178075+00', 'Cook, Carol', '', 'Carol Cook', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1593, NULL, '2012-01-20 12:54:11.203441+00', 'Ridley, Donald', '', 'Donald Ridley', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1584, NULL, '2012-01-20 12:54:11.180607+00', 'Kier, Peter', '', 'Peter Kier', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1594, NULL, '2012-01-20 12:54:11.205961+00', 'Berry, Jim', '', 'Jim Berry', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1586, NULL, '2012-01-20 12:54:11.185701+00', 'Cook, Drummond', 'Drummond Cook', 'Drummond Cook', '', '', 0, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1587, NULL, '2012-01-20 12:54:11.188245+00', 'McGlashan, Alexander', '', 'Alexander McGlashan', '', '', 0, 0, 1, 0, NULL, 1740, 1797, NULL, '');
INSERT INTO 'person' VALUES (1596, NULL, '2012-01-20 12:54:11.211043+00', 'Renton, John', '', 'John Renton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1597, NULL, '2012-01-20 12:54:11.213567+00', 'MacLeod, Peter R', '', 'Peter R MacLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1599, NULL, '2012-01-20 12:54:11.218628+00', 'Halcrow, Jim', '', 'Jim Halcrow', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1601, NULL, '2012-01-20 12:54:11.223835+00', 'Edmond, Eddie', '', 'Eddie Edmond', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1602, NULL, '2012-01-20 12:54:11.226365+00', 'Townsend, Graham', '', 'Graham Townsend', '', '', 0, 0, 1, 0, NULL, 0, 1998, NULL, '');
INSERT INTO 'person' VALUES (1591, NULL, '2015-03-14 18:11:05.363699+00', 'Dewar, Colin', '', 'Colin Dewar', '', 'dewar369@btinternet.com', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1554, NULL, '2015-03-14 18:11:07.016762+00', 'Fitchet, Angus', 'Angus Fitchet', 'Angus Fitchet', '', '', 0, 1, 1, 1, NULL, 1910, 1998, NULL, '');
INSERT INTO 'person' VALUES (1600, NULL, '2015-03-14 18:11:08.447639+00', 'Gillan, Sadie L.', '', 'Sadie L. Gillan', '', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1555, NULL, '2015-03-14 18:11:08.872499+00', 'Gordon, Rob', '', 'Rob Gordon', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1523, NULL, '2015-03-14 18:11:09.151399+00', 'Grant, Neil', '', 'Neil Grant', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1534, NULL, '2015-03-14 18:11:09.821244+00', 'Hall, David I', '', 'David I Hall', '', 'HALLSCDB@aol.com', 1, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1525, NULL, '2015-03-14 18:11:12.354303+00', 'Johnstone, Jim', '', 'Jim Johnstone', '', '', 0, 1, 1, 1, NULL, 1937, 2008, NULL, '');
INSERT INTO 'person' VALUES (1576, NULL, '2015-03-14 18:11:19.892634+00', 'Nixon, Sandy', '', 'Sandy Nixon', '', 'sandy.nixon@tinyworld.co.uk', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1522, NULL, '2015-03-14 18:11:23.559436+00', 'Ross, Lindsay', '', 'Lindsay Ross', '', '', 0, 1, 1, 1, NULL, 0, 1980, NULL, '');
INSERT INTO 'person' VALUES (1592, NULL, '2022-12-19 16:48:00.218813+00', 'Mitchell, Graeme', 'Graeme Mitchell', 'Graeme Mitchell', '', 'mitch.box@btinternet.com', 0, 1, 1, 1, NULL, 1960, 0, NULL, '');
INSERT INTO 'person' VALUES (1580, NULL, '2022-12-11 20:49:27.887255+00', 'Barbour, Freeland', '', 'Freeland Barbour', '', '', 0, 0, 1, 1, NULL, 1951, 0, NULL, 'Biography: <<https://boxandfiddlearchive.weebly.com/freeland-barbour.html>>');
INSERT INTO 'person' VALUES (1527, NULL, '2022-12-31 17:45:47.273914+00', 'MacPhail, Iain Torquil', 'Iain MacPhail', 'Iain T MacPhail', '', '', 0, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1603, NULL, '2015-03-14 18:11:27.48871+00', 'Thomson, Kenny', '', 'Kenny Thomson', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1558, NULL, '2016-05-18 02:33:43.157614+00', 'Shand, Jimmy, Senior', '', 'Jimmy Shand, Senior', '', '', 0, 1, 1, 1, NULL, 1908, 2000, NULL, '');
INSERT INTO 'person' VALUES (1605, NULL, '2012-01-20 12:54:11.233947+00', 'MacLean, Calum', 'Calum MacLean', 'Calum MacLean', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1607, NULL, '2012-01-20 12:54:11.239281+00', 'Main, Nan', '', 'Nan Main', '', '', 0, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1609, NULL, '2012-01-20 12:54:11.244359+00', 'Bathgate, Andrew D', '', 'Andrew D Bathgate', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1610, NULL, '2012-01-20 12:54:11.246887+00', 'Moy, Frank', '', 'Frank Moy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1627, NULL, '2012-01-20 12:54:11.29796+00', 'McCroskie, John', '', 'John McCroskie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1614, NULL, '2012-01-20 12:54:11.261695+00', 'Allardyce, Adam', '', 'Adam Allardyce', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1629, NULL, '2012-01-20 12:54:11.303107+00', 'Griffin, Brian', '', 'Brian Griffin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1616, NULL, '2012-01-20 12:54:11.268283+00', 'Graham, Angus', '', 'Angus Graham', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1617, NULL, '2012-01-20 12:54:11.271578+00', 'Palmer, Violet', '', 'Violet Palmer', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1630, NULL, '2012-01-20 12:54:11.30563+00', 'Arthur, Davey', '', 'Davey Arthur', 'Donegal', '', 0, 0, 1, 0, NULL, 1954, 0, NULL, '');
INSERT INTO 'person' VALUES (1619, NULL, '2012-01-20 12:54:11.277633+00', 'Christian, W G M', '', 'W G M Christian', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1620, NULL, '2012-01-20 12:54:11.280179+00', 'MacKenzie, A', '', 'A MacKenzie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1632, NULL, '2012-01-20 12:54:11.310727+00', 'Lowe, Joseph', '', 'Joseph Lowe', '', '', 0, 0, 1, 0, NULL, 1796, 1866, NULL, '');
INSERT INTO 'person' VALUES (1561, NULL, '2012-11-29 07:57:13.776874+00', 'Gordon, George', '', 'George Gordon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1595, NULL, '2013-02-18 02:25:59.62514+00', 'Anderson, Billy', 'Billy Anderson', 'Billy Anderson', '', '', 0, 0, 1, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (1622, NULL, '2012-01-20 12:54:11.285243+00', 'Davidson, J', '', 'J Davidson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1624, NULL, '2012-01-20 12:54:11.290342+00', 'Low, Betty', '', 'Betty Low', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1625, NULL, '2012-01-20 12:54:11.292893+00', 'Hill, James', '', 'James Hill', 'Gateshead', '', 0, 0, 1, 0, NULL, 1815, 1858, NULL, '');
INSERT INTO 'person' VALUES (1636, NULL, '2012-01-20 12:54:11.322502+00', 'Graham, S', '', 'S Graham', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1637, NULL, '2012-01-20 12:54:11.325058+00', 'O''Connor, T', '', 'T O''Connor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1639, NULL, '2012-01-20 12:54:11.330439+00', 'Robinson', '', 'Robinson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1641, NULL, '2012-01-20 12:54:11.335645+00', 'Dodds, Jean', '', 'Jean Dodds', 'Adelaide, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1642, NULL, '2012-01-20 12:54:11.338426+00', 'Foote, S M', '', 'S M Foote', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1646, NULL, '2012-01-20 12:54:11.348843+00', 'Cameron, Angus', '', 'Angus Cameron', 'Kirriemuir', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1647, NULL, '2012-01-20 12:54:11.351381+00', 'Rae, Margaret T W', '', 'Margaret T W Rae', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1648, NULL, '2012-01-20 12:54:11.353913+00', 'Griffiths, David', '', 'David Griffiths', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1628, NULL, '2012-01-20 12:54:11.300562+00', 'Vancouver SC Dancers, USA', '', 'Vancouver SC Dancers, USA', 'Vancouver, WA, USA', '', 0, 1, 0, 0, 10586, 1985, 0, NULL, '');
INSERT INTO 'person' VALUES (1720, NULL, '2012-01-20 12:54:11.551536+00', 'Dixon, Bernard', '', 'Bernard Dixon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1572, NULL, '2020-05-26 23:56:33.743728+00', 'Hunter, Alastair C', '', 'Alastair C Hunter', 'Aberdeen', '', 0, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1635, NULL, '2020-10-31 10:55:07.982974+00', 'Ross, P/M William J', '', 'P/M William J Ross', 'Scotland', '', 0, 1, 1, 0, NULL, 1878, 1966, NULL, 'Known as Willie Ross.');
INSERT INTO 'person' VALUES (1604, NULL, '2021-10-16 23:03:31.335345+00', 'MacFarquhar, Peter', '', 'Peter MacFarquhar', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'There are also references on the web to his name as Peter Farquhar (without Mac).');
INSERT INTO 'person' VALUES (1634, NULL, '2019-10-01 20:53:33.996417+00', 'Black, Bill', '', 'Bill Black', 'UK', '', 0, 1, 1, 1, NULL, 1935, 2016, NULL, 'There is a brief note about Bill Black at <<https://thesession.org/tunes/18481>>');
INSERT INTO 'person' VALUES (1667, NULL, '2012-01-20 12:54:11.404233+00', 'Campbell, A', '', 'A Campbell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1651, NULL, '2012-01-20 12:54:11.361563+00', 'Lindsay, Edna', '', 'Edna Lindsay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1653, NULL, '2012-01-20 12:54:11.366612+00', 'Hamilton, Brian', '', 'Brian Hamilton', '', '', 0, 0, 1, 0, NULL, 1931, 2005, NULL, '');
INSERT INTO 'person' VALUES (1654, NULL, '2012-01-20 12:54:11.369232+00', 'Lowe, James', '', 'James Lowe', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1655, NULL, '2012-01-20 12:54:11.371762+00', 'Munro, Ian', '', 'Ian Munro', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1670, NULL, '2012-01-20 12:54:11.411809+00', 'Menzies, Hamish', '', 'Hamish Menzies', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1657, NULL, '2012-01-20 12:54:11.37685+00', 'Lyon, Andrew J', '', 'Andrew J Lyon', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1658, NULL, '2012-01-20 12:54:11.379382+00', 'Findlay, David', '', 'David Findlay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1671, NULL, '2012-01-20 12:54:11.414329+00', 'MacIntyre, D', '', 'D MacIntyre', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1660, NULL, '2012-01-20 12:54:11.384514+00', 'Black, Robert', '', 'Robert Black', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1672, NULL, '2012-01-20 12:54:11.41692+00', 'MacDonald, Angus', '', 'Angus MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1661, NULL, '2012-01-20 12:54:11.387055+00', 'Arthur, Jim', '', 'Jim Arthur', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1663, NULL, '2012-01-20 12:54:11.39404+00', 'Lauder, Harry', '', 'Harry Lauder', '', '', 0, 0, 1, 0, NULL, 0, 1950, NULL, '');
INSERT INTO 'person' VALUES (1664, NULL, '2012-01-20 12:54:11.396636+00', 'Lauder/Kendall', '', 'Lauder/Kendall', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1674, NULL, '2012-01-20 12:54:11.421996+00', 'Finlayson, Stuart', '', 'S Finlayson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1665, NULL, '2012-01-20 12:54:11.399172+00', 'Haydn, Joseph', '', 'Joseph Haydn', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1666, NULL, '2012-01-20 12:54:11.401704+00', 'Fettes, A', '', 'A Fettes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1675, NULL, '2012-01-20 12:54:11.424529+00', 'Ferguson, D', '', 'D Ferguson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1676, NULL, '2012-01-20 12:54:11.427101+00', 'Elliot, T J', '', 'T J Elliot', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1678, NULL, '2012-01-20 12:54:11.432368+00', 'Blake, Arthur', '', 'Arthur Blake', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1681, NULL, '2012-01-20 12:54:11.439956+00', 'Jones, Malcolm', '', 'Malcolm Jones', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1659, NULL, '2015-03-14 18:11:00.807345+00', 'Blair, Jimmy', '', 'Jimmy Blair', '', '', 0, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1640, NULL, '2015-03-14 18:11:00.968473+00', 'Blue, Jimmy', '', 'Jimmy Blue', '', '', 0, 0, 1, 1, NULL, 1929, 1999, NULL, '');
INSERT INTO 'person' VALUES (1612, NULL, '2015-03-14 18:11:03.02105+00', 'Carmichael, George', '', 'George Carmichael', 'Dundee', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1669, NULL, '2015-03-14 18:11:05.778516+00', 'Downie, Alastair', '', 'Alastair Downie', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1608, NULL, '2015-03-14 18:11:06.928546+00', 'Finlayson, Colin', '', 'Colin Finlayson', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1621, NULL, '2017-07-27 16:29:28.822681+00', 'McLaren, Nicol', '', 'Nicol McLaren', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1606, NULL, '2015-03-14 18:11:11.329225+00', 'Houliston, Max', '', 'Max Houliston', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1626, NULL, '2015-03-14 18:11:23.955067+00', 'Rutherford, Maureen', '', 'Maureen Rutherford', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1652, NULL, '2017-09-27 00:24:37.312235+00', 'MacLeod, Jim', '', 'Jim MacLeod', '', '', 0, 0, 1, 1, NULL, 1928, 2004, NULL, 'Jim MacLeod was a pianist, composer and band leader.



There is a long <<http://boxandfiddlearchive.weebly.com/jim-macleod.html|obituary on the box and fiddle archive>>.');
INSERT INTO 'person' VALUES (1638, NULL, '2015-08-31 21:24:05.34918+00', 'O''Brien, Billy and Wallace, Raymond', '', 'Billy O''Brien and Raymond Wallace', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'O''Brien, Billy and Wallace, Raymond ');
INSERT INTO 'person' VALUES (1611, NULL, '2016-05-18 02:34:25.075832+00', 'Shand, James, Junior', '', 'James Shand, Junior', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1682, NULL, '2012-01-20 12:54:11.44249+00', 'Findlay, David / Cunningham, David', '', 'Findlay, David / Cunningham, David', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1683, NULL, '2012-01-20 12:54:11.445034+00', 'Clark, P/M C T', '', 'P/M C T Clark', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1685, NULL, '2012-01-20 12:54:11.450107+00', 'Shaw, W', '', 'W Shaw', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1686, NULL, '2012-01-20 12:54:11.452835+00', 'Bannatyne, Dr Charles', '', 'Dr Charles Bannatyne', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1668, NULL, '2022-04-07 20:48:59.350698+00', 'Holmes, Ian', '', 'Ian Holmes', '', '', 0, 0, 1, 1, NULL, 1935, 0, NULL, '');
INSERT INTO 'person' VALUES (1687, NULL, '2012-01-20 12:54:11.45539+00', 'Rutherford, Walter', '', 'Walter Rutherford', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1688, NULL, '2012-01-20 12:54:11.457919+00', 'Dickie, Neil', '', 'Neil Dickie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1689, NULL, '2012-01-20 12:54:11.460458+00', 'Hughes, Richard', '', 'Richard Hughes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1690, NULL, '2012-01-20 12:54:11.463024+00', 'Johnstone, D', '', 'D Johnstone', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1692, NULL, '2012-01-20 12:54:11.469066+00', 'Boal, Jimmy', '', 'Jimmy Boal', 'Dundee', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1707, NULL, '2012-01-20 12:54:11.509688+00', 'Lawrence, Derek', '', 'Derek Lawrence', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1693, NULL, '2012-01-20 12:54:11.471596+00', 'MacGregor, Alistair', '', 'Alistair MacGregor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1708, NULL, '2012-01-20 12:54:11.5128+00', 'Dent, J', '', 'J Dent', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1695, NULL, '2012-01-20 12:54:11.476655+00', 'Petrie, Robert', '', 'Robert Petrie', '', '', 0, 0, 1, 0, NULL, 1767, 1830, NULL, '');
INSERT INTO 'person' VALUES (1696, NULL, '2012-01-20 12:54:11.479202+00', 'Barr', '', 'Barr', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1697, NULL, '2012-01-20 12:54:11.481741+00', 'Bates', '', 'Bates', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1710, NULL, '2012-01-20 12:54:11.518415+00', 'Anderson, Tom', '', 'Tom Anderson', '', '', 0, 1, 1, 0, NULL, 1910, 1991, NULL, '');
INSERT INTO 'person' VALUES (1699, NULL, '2012-01-20 12:54:11.486842+00', 'McLennan, P/M George S', '', 'P/M George S McLennan', '', '', 0, 0, 1, 0, NULL, 1884, 1929, NULL, '');
INSERT INTO 'person' VALUES (1711, NULL, '2012-01-20 12:54:11.521209+00', 'Scollay, Peter', '', 'Peter Scollay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1701, NULL, '2012-01-20 12:54:11.492066+00', 'Johnston, Beryl S', 'Beryl Johnston', 'Beryl S Johnston', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1702, NULL, '2012-01-20 12:54:11.494601+00', 'Barbour, Suzanne', '', 'Suzanne Barbour', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1712, NULL, '2012-01-20 12:54:11.524021+00', 'Quigley, A', '', 'A Quigley', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1703, NULL, '2012-01-20 12:54:11.497337+00', 'Scott, Lady Jane', '', 'Lady Jane Scott', '', '', 0, 0, 1, 0, NULL, 1810, 1890, NULL, '');
INSERT INTO 'person' VALUES (1704, NULL, '2012-01-20 12:54:11.500028+00', 'Stoddart, Gavin', '', 'Gavin Stoddart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1705, NULL, '2012-01-20 12:54:11.502735+00', 'MacKintosh, E G', '', 'E G MacKintosh', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1714, NULL, '2012-01-20 12:54:11.530148+00', 'Skeoch, Bill', '', 'Bill Skeoch', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1715, NULL, '2012-01-20 12:54:11.53348+00', 'Mortimer, Jimmy', '', 'Jimmy Mortimer', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1716, NULL, '2012-01-20 12:54:11.536756+00', 'Nisbet, William', '', 'William Nisbet', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1717, NULL, '2012-01-20 12:54:11.540058+00', 'Hall, Tom Rattray', '', 'Tom Rattray Hall', 'Surrey', 'tom.hall@hamiltonhall.co.uk', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1718, NULL, '2012-01-20 12:54:11.543384+00', 'Payne, Anthony C', '', 'Anthony C Payne', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1719, NULL, '2012-01-20 12:54:11.546733+00', 'Carmichael, Harry', '', 'Harry Carmichael', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1579, NULL, '2021-04-06 23:56:05.974272+00', 'Bell, George', '', 'George Bell', 'Blairgowrie, Scotland', '', 0, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1721, NULL, '2012-01-20 12:54:11.555029+00', 'Simon, Hans-Arno', '', 'Hans-Arno Simon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1725, NULL, '2012-01-20 12:54:11.568695+00', 'Thow, Ian', '', 'Ian Thow', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1726, NULL, '2012-01-20 12:54:11.571995+00', 'McGuire, Willie', '', 'Willie McGuire', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1728, NULL, '2012-01-20 12:54:11.578564+00', 'Wilkie, Alastair', '', 'Alastair Wilkie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1729, NULL, '2012-01-20 12:54:11.581846+00', 'Chalmers, Syd', '', 'Syd Chalmers', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1746, NULL, '2012-01-20 12:54:11.629079+00', 'Duncan, Samson', '', 'Samson Duncan', 'Kinclaven, Scotland', '', 0, 0, 1, 0, NULL, 1767, 1837, NULL, '');
INSERT INTO 'person' VALUES (1730, NULL, '2012-01-20 12:54:11.585177+00', 'Wilson, Ena', '', 'Ena Wilson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1680, NULL, '2014-11-08 21:53:00.707326+00', 'Maxwell, Douglas', '', 'Douglas Maxwell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Douglas Maxwell was member of the Olympians dance band.');
INSERT INTO 'person' VALUES (1706, NULL, '2014-11-09 00:12:37.549569+00', 'Anderson, George M', '', 'George M Anderson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1751, NULL, '2018-07-19 23:56:09.189872+00', 'Edinburgh University New Scotland Country Dance Society', '', 'Edinburgh University New Scotland Country Dance Society', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1732, NULL, '2012-01-20 12:54:11.593108+00', 'Stewart, Neil', '', 'Neil Stewart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1747, NULL, '2012-01-20 12:54:11.631635+00', 'Gow, William', '', 'William Gow', '', '', 0, 0, 1, 0, NULL, 1751, 1791, NULL, '');
INSERT INTO 'person' VALUES (1734, NULL, '2012-01-20 12:54:11.598239+00', 'Slaven, Ken and others', 'Ken Slaven', 'Ken Slaven and others', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1735, NULL, '2012-01-20 12:54:11.600878+00', 'Muir, Douglas', '', 'Douglas Muir', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1748, NULL, '2012-01-20 12:54:11.63416+00', 'Walker, Alexander', '', 'Alexander Walker', '', '', 0, 1, 1, 0, NULL, 1810, 0, NULL, '');
INSERT INTO 'person' VALUES (1736, NULL, '2012-01-20 12:54:11.603409+00', 'Rae, T Sinclair', '', 'T Sinclair Rae', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1737, NULL, '2012-01-20 12:54:11.605937+00', 'Windwick, Allie', '', 'Allie Windwick', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1738, NULL, '2012-01-20 12:54:11.608455+00', 'Cameron, Ian', '', 'Ian Cameron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1739, NULL, '2012-01-20 12:54:11.610983+00', 'Johnstone, G', '', 'G Johnstone', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1750, NULL, '2012-01-20 12:54:11.639217+00', 'Henderson, J Murdoch', '', 'J Murdoch Henderson', 'Aberdeen', '', 0, 0, 1, 0, NULL, 1902, 1972, NULL, '');
INSERT INTO 'person' VALUES (1740, NULL, '2012-01-20 12:54:11.613503+00', 'MacLeod, N', '', 'N MacLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1741, NULL, '2012-01-20 12:54:11.616143+00', 'McEwan, John', '', 'John McEwan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1743, NULL, '2012-01-20 12:54:11.621351+00', 'Thomson, Stuart', '', 'Stuart Thomson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1752, NULL, '2012-01-20 12:54:11.644274+00', 'McEachern, N', '', 'N McEachern', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1744, NULL, '2012-01-20 12:54:11.623908+00', 'Flynn, P', '', 'P Flynn', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1745, NULL, '2012-01-20 12:54:11.626529+00', 'Machlis, Paul', '', 'Paul Machlis', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1753, NULL, '2012-01-20 12:54:11.646804+00', 'Mowat, W', '', 'W Mowat', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1754, NULL, '2012-01-20 12:54:11.64932+00', 'Milbourne, Ray', '', 'Ray Milbourne', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1756, NULL, '2012-01-20 12:54:11.654373+00', 'Hunter, J', '', 'J Hunter', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1757, NULL, '2012-01-20 12:54:11.656951+00', 'Edwardson, G', '', 'G Edwardson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1733, NULL, '2015-03-14 18:11:29.520585+00', 'Wilson, Callum', '', 'Callum Wilson', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1749, NULL, '2017-11-15 00:56:04.437348+00', 'Bowie, John', '', 'John Bowie', '', '', 1, 1, 1, 0, NULL, 1759, 1815, NULL, '');
INSERT INTO 'person' VALUES (1691, NULL, '2017-07-28 03:58:04.359609+00', 'Nelson, Steve', '', 'Steve Nelson', 'New York, USA', '', 0, 0, 1, 0, NULL, 1907, 1981, NULL, '');
INSERT INTO 'person' VALUES (1758, NULL, '2012-01-20 12:54:11.65997+00', 'Vannini, Antonio', '', 'Antonio Vannini', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1759, NULL, '2012-01-20 12:54:11.662561+00', 'MacDonald, Forbes', '', 'Forbes MacDonald', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1761, NULL, '2012-01-20 12:54:11.667649+00', 'Cunningham, Phil', '', 'Phil Cunningham', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (827, NULL, '2018-03-26 13:30:05.87105+00', 'Toriyama, Tom', '', 'Tom Toriyama', 'Kawasaki, Japan', 't-toriyama660@jcom.home.ne.jp', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1765, NULL, '2012-01-20 12:54:11.677773+00', 'Unger, Larry', '', 'Larry Unger', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1766, NULL, '2012-01-20 12:54:11.680301+00', 'MacDonald, Dan R', '', 'Dan R MacDonald', '', '', 0, 0, 1, 0, NULL, 1911, 1976, NULL, '');
INSERT INTO 'person' VALUES (1767, NULL, '2012-01-20 12:54:11.682837+00', 'Parazotti', '', 'Parazotti', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1768, NULL, '2012-01-20 12:54:11.685367+00', 'Hazard, Jill', '', 'Jill Hazard', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1783, NULL, '2012-01-20 12:54:11.726727+00', 'Cassidy, Con', '', 'Con Cassidy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1769, NULL, '2012-01-20 12:54:11.687903+00', 'Shaw, Donald', '', 'Donald Shaw', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1770, NULL, '2012-01-20 12:54:11.690539+00', 'Crawford, Grant', '', 'Grant Crawford', '', 'grantcrawford22@aol.com', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1724, NULL, '2022-04-07 19:04:01.004343+00', 'Burns, Ian', '', 'Ian Burns', 'Shetland', '', 0, 1, 1, 0, NULL, 1932, 1995, NULL, '');
INSERT INTO 'person' VALUES (11612, '2018-03-23 22:10:09.040354+00', '2022-06-07 21:09:37.607854+00', 'Oyama, Yoshiki & Kaoru', '', 'Yoshiki & Kaoru Oyama', 'Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1700, NULL, '2023-01-20 17:44:21.318873+00', 'McLellan, P/M John', '', 'P/M John McLellan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1784, NULL, '2012-01-20 12:54:11.729536+00', 'Morrison, William', '', 'William Morrison', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1771, NULL, '2012-01-20 12:54:11.694793+00', 'Brock, Robin', '', 'Robin Brock', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1772, NULL, '2012-01-20 12:54:11.697527+00', 'Barbour, Carolyn M', '', 'Carolyn M Barbour', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1785, NULL, '2012-01-20 12:54:11.732126+00', 'McIntyre, Alastair C', '', 'Alastair C McIntyre', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1774, NULL, '2012-01-20 12:54:11.703272+00', 'Eglintoun, Earl of', '', 'Earl of Eglintoun', '', '', 0, 0, 1, 0, NULL, 1749, 1819, NULL, '');
INSERT INTO 'person' VALUES (1786, NULL, '2012-01-20 12:54:11.734667+00', 'Stove, Gideon', '', 'Gideon Stove', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1775, NULL, '2012-01-20 12:54:11.705837+00', 'MacLean, Norman', '', 'Norman MacLean', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1776, NULL, '2012-01-20 12:54:11.708378+00', 'Matthew, W Bird', '', 'W Bird Matthew', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1787, NULL, '2012-01-20 12:54:11.737346+00', 'Murray', '', 'Murray', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1788, NULL, '2012-01-20 12:54:11.739883+00', 'Henderson, W A', '', 'W A Henderson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1779, NULL, '2012-01-20 12:54:11.716565+00', 'Barnes, Peter', '', 'Peter Barnes', 'Boston, USA', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1780, NULL, '2012-01-20 12:54:11.719111+00', 'McGarrity, Kim', '', 'Kim McGarrity', '', '', 1, 0, 1, 0, NULL, 0, 1998, NULL, '');
INSERT INTO 'person' VALUES (1789, NULL, '2012-01-20 12:54:11.742417+00', 'Nicolson, Eann', '', 'Eann Nicolson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1782, NULL, '2012-01-20 12:54:11.724185+00', 'Fraser, Alasdair', 'Alasdair Fraser', 'Alasdair Fraser', 'California, US', 'AlasdairFraser@compuserve.com', 0, 0, 1, 1, NULL, 1955, 0, NULL, '');
INSERT INTO 'person' VALUES (1791, NULL, '2012-01-20 12:54:11.747539+00', 'Stubbert, Brenda', '', 'Brenda Stubbert', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1792, NULL, '2012-01-20 12:54:11.750078+00', 'Aitken, James', '', 'James Aitken', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1797, NULL, '2012-01-20 12:54:11.764033+00', 'Gourlay, Robert R', '', 'Robert R Gourlay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1799, NULL, '2012-01-20 12:54:11.769359+00', 'Connachan, J', '', 'J Connachan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1800, NULL, '2012-01-20 12:54:11.771969+00', 'Macaulay-Jones, Ken', '', 'Ken Macaulay-Jones', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1801, NULL, '2012-01-20 12:54:11.774525+00', 'McKercher, Duncan', '', 'Duncan McKercher', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1802, NULL, '2012-01-20 12:54:11.777233+00', 'Hand, J', '', 'J Hand', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1722, NULL, '2020-05-26 20:06:13.548707+00', 'Hunter, Charlie', '', 'Charlie Hunter', '', '', 0, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1790, NULL, '2021-02-16 19:32:48.565253+00', 'Robertson, James Stewart', '', 'James Stewart Robertson', 'Perthshire, Scotland', '', 0, 0, 1, 0, NULL, 1823, 1896, NULL, '');
INSERT INTO 'person' VALUES (1727, NULL, '2021-10-11 21:58:58.933545+00', 'Hargreaves, Dorothy', '', 'Dorothy Hargreaves', 'Deep Cove, BC, Canada', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1804, NULL, '2012-01-20 12:54:11.782362+00', 'Duncan, Ian', '', 'Ian Duncan', 'Keith', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1805, NULL, '2012-01-20 12:54:11.785024+00', 'Strachan, Jimmy', '', 'Jimmy Strachan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1806, NULL, '2012-01-20 12:54:11.787588+00', 'Starr, Will', '', 'Will Starr', '', '', 0, 0, 1, 0, NULL, 1922, 1976, NULL, '');
INSERT INTO 'person' VALUES (1803, NULL, '2012-01-20 12:54:11.779815+00', 'Frazer, A', '', 'A Frazer', '', '', 0, 0, 1, 0, 1803, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1807, NULL, '2012-01-20 12:54:11.790127+00', 'Grant, Charles', '', 'Charles Grant', '', '', 0, 0, 1, 0, NULL, 1806, 1892, NULL, '');
INSERT INTO 'person' VALUES (1823, NULL, '2012-01-20 12:54:11.83137+00', 'Logan, Mike', '', 'Mike Logan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1809, NULL, '2012-01-20 12:54:11.79532+00', 'Gordon, D A', '', 'D A Gordon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1824, NULL, '2012-01-20 12:54:11.833934+00', 'Cummins, Gillian M', '', 'Gillian M Cummins', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1810, NULL, '2012-01-20 12:54:11.79795+00', 'Crerar, John', '', 'John Crerar', '', '', 0, 0, 1, 0, NULL, 1750, 1840, NULL, '');
INSERT INTO 'person' VALUES (1812, NULL, '2012-01-20 12:54:11.803066+00', 'Clark, Kevin', '', 'Kevin Clark', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1813, NULL, '2012-01-20 12:54:11.805659+00', 'Mackay, Robert H', 'Robert Mackay', 'Robert H Mackay', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1825, NULL, '2012-01-20 12:54:11.837243+00', 'Bett, Norman', '', 'Norman Bett', '', '', 0, 0, 1, 0, NULL, 0, 2002, NULL, '');
INSERT INTO 'person' VALUES (1815, NULL, '2012-01-20 12:54:11.81076+00', 'Dickson, Nancy', 'Nancy Dickson', 'Nancy Dickson', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1816, NULL, '2012-01-20 12:54:11.813355+00', 'Chambers, Kim', '', 'Kim Chambers', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1817, NULL, '2012-01-20 12:54:11.815995+00', 'Mason, John', '', 'John Mason', 'Troon', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1827, NULL, '2012-01-20 12:54:11.842565+00', 'Houston, Craig', '', 'Craig Houston', 'Ayr Branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1818, NULL, '2012-01-20 12:54:11.818552+00', 'Milne, Peter', '', 'Peter Milne', '', '', 0, 0, 1, 0, NULL, 1824, 1908, NULL, '');
INSERT INTO 'person' VALUES (1819, NULL, '2012-01-20 12:54:11.821124+00', 'McAllister, J', '', 'J McAllister', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1828, NULL, '2012-01-20 12:54:11.845109+00', 'Sennett, Chris & Vicky', '', 'Chris & Vicky Sennett', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1820, NULL, '2012-01-20 12:54:11.823664+00', 'McLeish', '', 'McLeish', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1821, NULL, '2012-01-20 12:54:11.826195+00', 'Jack, Bobby', '', 'Bobby Jack', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1822, NULL, '2012-01-20 12:54:11.828761+00', 'Davidson, Freda', '', 'Freda Davidson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1830, NULL, '2012-01-20 12:54:11.85018+00', 'Queen, Mary', '', 'Mary Queen', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1831, NULL, '2012-01-20 12:54:11.852766+00', 'Barr, Janie', '', 'Janie Barr', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1832, NULL, '2012-01-20 12:54:11.855329+00', 'Brady, Gertrude', '', 'Gertrude Brady', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1833, NULL, '2012-01-20 12:54:11.857917+00', 'Brady, Marie', '', 'Marie Brady', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1834, NULL, '2012-01-20 12:54:11.860481+00', 'Feeney, Yvonne', '', 'Yvonne Feeney', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1794, NULL, '2017-11-15 00:56:10.230868+00', 'Gilruth, F', '', 'F Gilruth', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1796, NULL, '2015-03-14 18:11:07.554053+00', 'Frew, Robert', 'Bobby Frew', 'Robert Frew', '', '', 0, 0, 1, 1, NULL, 0, 2000, NULL, '');
INSERT INTO 'person' VALUES (1826, NULL, '2015-03-14 18:11:11.697007+00', 'Hutton, Neil', '', 'Neil Hutton', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1773, NULL, '2015-03-14 18:11:17.943605+00', 'McOwen, Barbara', '', 'Barbara McOwen', '', 'bmcowen@world.std.com', 1, 0, 1, 0, 1773, 1948, 0, NULL, '');
INSERT INTO 'person' VALUES (1808, NULL, '2015-03-14 18:11:24.823519+00', 'Shand, Gordon', '', 'Gordon Shand', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1798, NULL, '2015-12-16 00:56:17.215927+00', 'McDonald, D', '', 'D McDonald', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1793, NULL, '2016-03-17 00:56:07.551678+00', 'Cunningham, D R', '', 'D R Cunningham', '', '', 0, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1814, NULL, '2018-12-07 17:34:23.921171+00', 'Laird, Adam', '', 'Adam M. Laird', 'Winnipeg', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11614, '2018-03-29 18:34:00.042464+00', '2018-03-30 23:56:10.493789+00', 'Gorka, Julie', '', 'Julie Gorka', 'USA', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1835, NULL, '2012-01-20 12:54:11.863016+00', 'Malcolm, Keith', '', 'Keith Malcolm', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1837, NULL, '2012-01-20 12:54:11.868085+00', 'Shearer, L P', '', 'L P Shearer', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1838, NULL, '2012-01-20 12:54:11.870613+00', 'McGregor, D', '', 'D McGregor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1839, NULL, '2012-01-20 12:54:11.873367+00', 'Fraser, Julia M', '', 'Julia M Fraser', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1841, NULL, '2012-01-20 12:54:11.885445+00', 'Fyfe, D J', '', 'D J Fyfe', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1843, NULL, '2012-01-20 12:54:11.892039+00', 'Galley, Laurie', '', 'Laurie Galley', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1844, NULL, '2012-01-20 12:54:11.895378+00', 'Godfrey, Nugent', '', 'Nugent Godfrey', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1845, NULL, '2012-01-20 12:54:11.898054+00', 'Shepherd, William', '', 'William Shepherd', '', '', 0, 0, 1, 0, NULL, 0, 1812, NULL, '');
INSERT INTO 'person' VALUES (1847, NULL, '2012-01-20 12:54:11.903154+00', 'Dempster, Valerie', '', 'Valerie Dempster', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1860, NULL, '2012-01-20 12:54:11.936213+00', 'Innes, Hugh', '', 'Hugh Innes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1848, NULL, '2012-01-20 12:54:11.905681+00', 'Williams, James M', '', 'James M Williams', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1849, NULL, '2012-01-20 12:54:11.908208+00', 'Richardson, Iain E Garden', '', 'Iain E Garden Richardson', '', 'iaingr@bigfoot.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1861, NULL, '2012-01-20 12:54:11.938776+00', 'Atkinson, James Edward McCartney', '', 'James Edward McCartney Atkinson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1777, NULL, '2022-04-07 20:54:48.275012+00', 'Huband, John', 'John Huband', 'John Huband', '', '', 0, 0, 1, 0, NULL, 1942, 2000, NULL, '');
INSERT INTO 'person' VALUES (1850, NULL, '2012-01-20 12:54:11.910747+00', 'Wade, Elizabeth', '', 'Elizabeth Wade', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1851, NULL, '2012-01-20 12:54:11.913282+00', 'Marriage, Sophia / Sequeira, Dilip / Small, Sandy', '', 'Marriage, Sophia / Sequeira, Dilip / Small, Sandy', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1852, NULL, '2012-01-20 12:54:11.915878+00', 'Archibald, Christine', '', 'Christine Archibald', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1863, NULL, '2012-01-20 12:54:11.943915+00', 'Edwards, Alf', '', 'Alf Edwards', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1854, NULL, '2012-01-20 12:54:11.921031+00', 'Smith, R A', '', 'R A Smith', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1855, NULL, '2012-01-20 12:54:11.923562+00', 'Avery, Alison', '', 'Alison Avery', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1864, NULL, '2012-01-20 12:54:11.946449+00', 'Hastie, Stephen', '', 'Stephen Hastie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1856, NULL, '2012-01-20 12:54:11.926079+00', 'Brockbank, Ian / Williams, James M', '', 'Ian Brockbank / James M Williams', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1857, NULL, '2012-01-20 12:54:11.928628+00', 'McNeill, Brian', '', 'Brian McNeill', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1865, NULL, '2012-01-20 12:54:11.948974+00', 'Barnes, Tom', '', 'Tom Barnes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1858, NULL, '2012-01-20 12:54:11.931161+00', 'Moon, Charlotte / Wade, Elizabeth / Young, Alison', '', 'Moon, Charlotte / Wade, Elizabeth / Young, Alison', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1859, NULL, '2012-01-20 12:54:11.933685+00', 'Oswald, James', '', 'James Oswald', '', '', 0, 0, 1, 0, NULL, 1711, 1769, NULL, '');
INSERT INTO 'person' VALUES (1866, NULL, '2012-01-20 12:54:11.951516+00', 'Davidson, David', '', 'David Davidson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1867, NULL, '2012-01-20 12:54:11.954047+00', 'Middleton', '', 'Middleton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1868, NULL, '2012-01-20 12:54:11.956576+00', 'Fitzmaurice, Malcolm', '', 'Malcolm Fitzmaurice', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1869, NULL, '2012-01-20 12:54:11.959142+00', 'Hill, C M', '', 'C M Hill', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1870, NULL, '2012-01-20 12:54:11.961686+00', 'Briggs, Donald', '', 'Donald Briggs', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1871, NULL, '2012-01-20 12:54:11.964222+00', 'Ross, David', '', 'David Ross', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1874, NULL, '2012-01-20 12:54:11.971961+00', 'Hardy, J', '', 'J Hardy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1876, NULL, '2012-01-20 12:54:11.978426+00', 'Heron, Alasdair', '', 'Alasdair Heron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1877, NULL, '2012-01-20 12:54:11.981879+00', 'McEwan, Ian', '', 'Ian McEwan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1878, NULL, '2012-01-20 12:54:11.985307+00', 'Sutherland, Jim', '', 'J Sutherland', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1879, NULL, '2012-01-20 12:54:11.988604+00', 'Beaton, F', '', 'F Beaton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1880, NULL, '2012-01-20 12:54:11.991933+00', 'Lane-Smith, Derek', '', 'Derek Lane-Smith', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1881, NULL, '2012-01-20 12:54:11.995232+00', 'Purcell, Henry', '', 'Henry Purcell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1882, NULL, '2012-01-20 12:54:11.998515+00', 'O''Carolan, Turlough', '', 'Turlough O''Carolan', '', '', 0, 0, 1, 0, NULL, 1670, 1738, NULL, '');
INSERT INTO 'person' VALUES (1853, NULL, '2012-01-20 12:54:11.918491+00', 'Bradshaw, Caroline / Brockbank, Ian', '', 'Caroline Bradshaw / Ian Brockbank', 'Edinburgh', '', 1, 0, 0, 0, 3557, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1883, NULL, '2012-01-20 12:54:12.001819+00', 'Grant, Stewart', '', 'Stewart Grant', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1900, NULL, '2012-01-20 12:54:12.059407+00', 'Sullivan, Arthur', '', 'Arthur Sullivan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1884, NULL, '2012-01-20 12:54:12.005316+00', 'Cooper, James', '', 'James Cooper', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1885, NULL, '2012-01-20 12:54:12.008609+00', 'Mills, Kerry', '', 'Kerry Mills', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1901, NULL, '2012-01-20 12:54:12.063264+00', 'Campbell, L', '', 'L Campbell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1887, NULL, '2012-01-20 12:54:12.015395+00', 'Benson, Marian', '', 'Marian Benson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1888, NULL, '2012-01-20 12:54:12.018689+00', 'Kotzwara, F', '', 'F Kotzwara', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1889, NULL, '2012-01-20 12:54:12.022063+00', 'McColl, P/M John', '', 'P/M John McColl', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1890, NULL, '2012-01-20 12:54:12.025365+00', 'MacLeod, Iain', '', 'Iain MacLeod', 'Edinburgh', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1891, NULL, '2012-01-20 12:54:12.028748+00', 'MacGill, John', '', 'John MacGill', 'Girvan', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11613, '2018-03-29 18:32:49.722821+00', '2018-03-29 23:56:08.254688+00', 'Copious Notes', '', 'Copious Notes', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1893, NULL, '2012-01-20 12:54:12.035468+00', 'Auld, Derek W', '', 'Derek W Auld', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1905, NULL, '2012-01-20 12:54:12.07683+00', 'Hornsby, George F', '', 'George F Hornsby', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1894, NULL, '2012-01-20 12:54:12.038822+00', 'Brown, J S', '', 'J S Brown', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1906, NULL, '2012-01-20 12:54:12.080133+00', 'O''Scannell, Pat', '', 'Pat O''Scannell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1907, NULL, '2012-01-20 12:54:12.084023+00', 'McKone, Roger Dennis', '', 'Roger Dennis McKone', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1898, NULL, '2012-01-20 12:54:12.052556+00', 'Cook, Bill', '', 'Bill Cook', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1908, NULL, '2012-01-20 12:54:12.087518+00', 'Mackenzie, John C', '', 'John C Mackenzie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1909, NULL, '2015-03-14 18:11:04.629472+00', 'Cruickshank, Helen', '', 'Helen Cruickshank', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1875, NULL, '2015-03-14 18:11:07.256026+00', 'Ford, John', '', 'John Ford', '(19C)', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1872, NULL, '2015-03-14 18:11:12.096871+00', 'Jemmett, Charles', 'Charlie Jemmett', 'Charles Jemmett', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1892, NULL, '2015-03-14 18:11:15.655178+00', 'Mackintosh, James', '', 'James Mackintosh', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1840, NULL, '2015-03-14 18:11:20.348792+00', 'Over, George', '', 'George Over', '', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1896, NULL, '2015-03-14 18:11:25.615908+00', 'Slaven, Ken', '', 'Ken Slaven', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1903, NULL, '2016-05-18 02:34:49.668356+00', 'Gow, Neil, Junior', '', 'Neil Gow, Junior', '', '', 0, 0, 1, 0, NULL, 1795, 1823, NULL, '');
INSERT INTO 'person' VALUES (1911, NULL, '2012-01-20 12:54:12.097582+00', 'Henderson, Isla', '', 'Isla Henderson', 'Skye', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1912, NULL, '2012-01-20 12:54:12.101342+00', 'MacDonald, Iain', '', 'Iain MacDonald', 'Skye', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1913, NULL, '2012-01-20 12:54:12.1051+00', 'Mauchline, James', '', 'James Mauchline', '', '', 0, 0, 1, 0, NULL, 1817, 1896, NULL, '');
INSERT INTO 'person' VALUES (1914, NULL, '2012-01-20 12:54:12.108466+00', 'MacLeod, J M', '', 'J M MacLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1915, NULL, '2012-01-20 12:54:12.111771+00', 'Fischer, Johann A Christian', '', 'Johann A Christian Fischer', '', '', 0, 0, 1, 0, NULL, 1733, 1800, NULL, '');
INSERT INTO 'person' VALUES (1918, NULL, '2012-01-20 12:54:12.121718+00', 'Thomson, Bruce E', '', 'Bruce E Thomson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1919, NULL, '2012-01-20 12:54:12.125008+00', 'Powrie, Ian & Bill', '', 'Ian & Bill Powrie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1921, NULL, '2012-01-20 12:54:12.131696+00', 'Craig, Adam', '', 'Adam Craig', '', '', 0, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1922, NULL, '2012-01-20 12:54:12.135028+00', 'Ferrier, R', '', 'R Ferrier', '', '', 0, 0, 1, 0, NULL, 1939, 0, NULL, '');
INSERT INTO 'person' VALUES (1939, NULL, '2012-01-20 12:54:12.192415+00', 'Walker, James', '', 'James Walker', '', '', 0, 0, 1, 0, NULL, 0, 1840, NULL, '');
INSERT INTO 'person' VALUES (1923, NULL, '2012-01-20 12:54:12.138339+00', 'Munro, Dorothy', '', 'Dorothy Munro', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1924, NULL, '2012-01-20 12:54:12.141639+00', 'Worland, S & Murray, B', 'Worland/Murray', 'S Worland & B Murray', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1940, NULL, '2012-01-20 12:54:12.195758+00', 'Clough, Tom', '', 'Tom Clough', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1925, NULL, '2012-01-20 12:54:12.144945+00', 'Barnett, Tom', '', 'Tom Barnett', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1941, NULL, '2012-01-20 12:54:12.199053+00', 'Menzies, Archie', '', 'Archie Menzies', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1927, NULL, '2012-01-20 12:54:12.151653+00', 'Robertson', '', 'Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1942, NULL, '2012-01-20 12:54:12.202351+00', 'Logan, Major William', '', 'Major William Logan', '', '', 0, 0, 1, 0, NULL, 0, 1819, NULL, '');
INSERT INTO 'person' VALUES (1930, NULL, '2012-01-20 12:54:12.161621+00', 'Cameron, Scott', '', 'Scott Cameron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1943, NULL, '2012-01-20 12:54:12.205646+00', 'MacMillan, Bob', '', 'Bob MacMillan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1931, NULL, '2012-01-20 12:54:12.164917+00', 'Moncur, James', '', 'James Moncur', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1895, NULL, '2023-01-12 19:27:48.012629+00', 'Sinclair, John', '', 'John Sinclair', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'There is a John Sinclair (composer) that was called "Jackie Sinclair". Unclear if this is the same person.');
INSERT INTO 'person' VALUES (1944, NULL, '2012-01-20 12:54:12.20894+00', 'McFadyen, J', '', 'J McFadyen', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1933, NULL, '2012-01-20 12:54:12.172357+00', 'Young, W', '', 'W Young', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1945, NULL, '2012-01-20 12:54:12.212234+00', 'Shand Scott, Annie', '', 'Annie Shand Scott', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1935, NULL, '2012-01-20 12:54:12.17896+00', 'Cameron', '', 'Cameron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1946, NULL, '2012-01-20 12:54:12.215536+00', 'McIntyre, Duncan', '', 'Duncan McIntyre', '', '', 0, 0, 1, 0, NULL, 0, 1806, NULL, '');
INSERT INTO 'person' VALUES (1937, NULL, '2012-01-20 12:54:12.185824+00', 'Mcintosh, James', '', 'James Mcintosh', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1938, NULL, '2012-01-20 12:54:12.189124+00', 'Munro, Graeme', '', 'Graeme Munro', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1947, NULL, '2012-01-20 12:54:12.218837+00', 'Carruthers', '', 'Carruthers', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1948, NULL, '2012-01-20 12:54:12.222122+00', 'Rose, Aeneas', '', 'Aeneas Rose', 'Kingussie', '', 0, 0, 1, 0, NULL, 1832, 1905, NULL, '');
INSERT INTO 'person' VALUES (1949, NULL, '2012-01-20 12:54:12.225586+00', 'Campbell, Duncan', '', 'Duncan Campbell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1950, NULL, '2012-01-20 12:54:12.228895+00', 'MacDonald, James (18C)', '', 'James (18C) MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1951, NULL, '2012-01-20 12:54:12.232186+00', 'Watson, Alex', '', 'Alex Watson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1952, NULL, '2012-01-20 12:54:12.235484+00', 'Fishar, James A', '', 'James A Fishar', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1953, NULL, '2012-01-20 12:54:12.238786+00', 'Gowans, Helen', '', 'Helen Gowans', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1955, NULL, '2012-01-20 12:54:12.245371+00', 'Esplin, J B', '', 'J B Esplin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1956, NULL, '2012-01-20 12:54:12.248719+00', 'Hett, Rosalind', '', 'Rosalind Hett', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1957, NULL, '2012-01-20 12:54:12.252056+00', 'Bland, James A', '', 'James A Bland', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1958, NULL, '2012-01-20 12:54:12.255357+00', 'Hannah, William', '', 'William Hannah', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1928, NULL, '2020-12-03 21:31:35.101318+00', 'Duff, Charles', '', 'Charles Duff', '', '', 0, 1, 1, 0, NULL, 0, 1822, NULL, '');
INSERT INTO 'person' VALUES (1886, NULL, '2021-01-27 14:59:19.488222+00', 'Howard, Cal', '', 'Cal Howard', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, 'Cal Howard was also playing the bass in the White Cockade Scottish Country Dance Band.');
INSERT INTO 'person' VALUES (1899, NULL, '2021-10-04 16:03:04.735768+00', 'South, David', '', 'David South', 'Brisbane, Queensland, Australia', '', 0, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1960, NULL, '2012-01-20 12:54:12.262206+00', 'Sauer', '', 'Sauer', '', '', 0, 0, 1, 0, NULL, 1794, 1831, NULL, '');
INSERT INTO 'person' VALUES (1961, NULL, '2012-01-20 12:54:12.265758+00', 'French, Percy', '', 'Percy French', '', '', 0, 0, 1, 0, NULL, 1854, 1920, NULL, '');
INSERT INTO 'person' VALUES (2103, NULL, '2014-10-07 13:23:11.601132+00', 'Hegel, Susanne', '', 'Susanne Hegel', '', '', 1, 0, 0, 0, NULL, 1935, 2013, NULL, '');
INSERT INTO 'person' VALUES (1962, NULL, '2012-01-20 12:54:12.269065+00', 'Dumbreck, William', '', 'William Dumbreck', 'Linlithgow', '', 0, 0, 1, 0, NULL, 1866, 1935, NULL, '');
INSERT INTO 'person' VALUES (1963, NULL, '2012-01-20 12:54:12.272351+00', 'MacDonald, E', '', 'E MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1977, NULL, '2012-01-20 12:54:12.318727+00', 'Bowman, Alexander', '', 'Alexander Bowman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1964, NULL, '2012-01-20 12:54:12.275681+00', 'Carter, Thomas', '', 'Thomas Carter', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1965, NULL, '2012-01-20 12:54:12.278981+00', 'Will, Douglas', '', 'Douglas Will', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1978, NULL, '2012-01-20 12:54:12.32222+00', 'Mackie, David', '', 'David Mackie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1967, NULL, '2012-01-20 12:54:12.285564+00', 'Leburn, Alexander', '', 'Alexander Leburn', '', '', 0, 0, 1, 0, NULL, 1767, 1836, NULL, '');
INSERT INTO 'person' VALUES (1979, NULL, '2012-01-20 12:54:12.325532+00', 'McKellar, Kenneth', '', 'Kenneth McKellar', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1968, NULL, '2012-01-20 12:54:12.288871+00', 'Tongeman, Sheena', '', 'Sheena Tongeman', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1969, NULL, '2012-01-20 12:54:12.292157+00', 'Hardie, Alistair J', '', 'Alistair J Hardie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1980, NULL, '2012-01-20 12:54:12.328886+00', 'Morton, Bobby', '', 'Bobby Morton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1970, NULL, '2012-01-20 12:54:12.295589+00', 'Skinner, A', '', 'A Skinner', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1971, NULL, '2012-01-20 12:54:12.298939+00', 'Aulenbach, James C', '', 'James C Aulenbach', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1981, NULL, '2012-01-20 12:54:12.332184+00', 'McLeod, Dave', '', 'Dave McLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1972, NULL, '2012-01-20 12:54:12.30226+00', 'Gordon, M W', '', 'M W Gordon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1973, NULL, '2012-01-20 12:54:12.305565+00', 'McLaren, D', '', 'D McLaren', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1982, NULL, '2012-01-20 12:54:12.335484+00', 'Lawson, Alexis', '', 'Alexis Lawson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1974, NULL, '2012-01-20 12:54:12.30885+00', 'Gow, John', '', 'John Gow', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1975, NULL, '2012-01-20 12:54:12.312143+00', 'Finlay, D K', '', 'D K Finlay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1983, NULL, '2012-01-20 12:54:12.33883+00', 'Stacey, Patrick Keith', '', 'Patrick K Stacey', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1976, NULL, '2012-01-20 12:54:12.315434+00', 'Spence, A D', '', 'A D Spence', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1984, NULL, '2012-01-20 12:54:12.342156+00', 'Sullivan, Joseph', '', 'Joseph Sullivan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1985, NULL, '2012-01-20 12:54:12.345455+00', 'Bannerman, John M', '', 'John M Bannerman', '', '', 0, 0, 1, 0, NULL, 1901, 1969, NULL, '');
INSERT INTO 'person' VALUES (1986, NULL, '2012-01-20 12:54:12.348751+00', 'Walker, Bill', '', 'Bill Walker', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11615, '2018-03-30 09:36:43.876415+00', '2018-03-30 23:56:27.427787+00', 'Work, James C', '', 'James C. Work', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1988, NULL, '2012-01-20 12:54:12.355347+00', 'Schnabl, Karin', '', 'Karin Schnabl', 'D-Schwaebisch Gmuend', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1990, NULL, '2012-01-20 12:54:12.358631+00', 'Coombs, Johnny', '', 'Johnny Coombs', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1966, NULL, '2015-03-14 18:11:25.821742+00', 'Smith, Duncan', '', 'Duncan Smith', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1954, NULL, '2015-08-29 12:01:24.784392+00', 'McGowan, Ewan', '', 'Ewan McGowan', '', '', 0, 0, 1, 0, NULL, 1943, 2015, NULL, '');
INSERT INTO 'person' VALUES (1991, NULL, '2012-01-20 12:54:12.361922+00', 'Walton, Tom', '', 'Tom Walton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1992, NULL, '2012-01-20 12:54:12.365219+00', 'Durrands, B', '', 'B Durrands', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1993, NULL, '2012-01-20 12:54:12.368853+00', 'Moore, Alex', '', 'Alex Moore', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1994, NULL, '2012-01-20 12:54:12.372164+00', 'Painter, Sydney W', '', 'Sydney W Painter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1995, NULL, '2012-01-20 12:54:12.375473+00', 'Edney, B M & T', '', 'B M & T Edney', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1996, NULL, '2012-01-20 12:54:12.378763+00', 'Evans, John', '', 'John Evans', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1997, NULL, '2012-01-20 12:54:12.382041+00', 'Botham', '', 'Botham', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1998, NULL, '2012-01-20 12:54:12.385355+00', 'Finnigan, James', '', 'James Finnigan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1999, NULL, '2012-01-20 12:54:12.38864+00', 'Wood, Charles', '', 'Charles Wood', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2000, NULL, '2012-01-20 12:54:12.392511+00', 'Daniels, Charles J', '', 'Charles J Daniels', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2001, NULL, '2012-01-20 12:54:12.395866+00', 'Fuller, Ken', '', 'Ken Fuller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2002, NULL, '2012-01-20 12:54:12.404179+00', 'Taeger, Dirk', '', 'Dirk Taeger', 'D-Dortmund', 'taegerd@freenet.de', 1, 1, 0, 0, NULL, 1966, 0, NULL, '');
INSERT INTO 'person' VALUES (2003, NULL, '2012-01-20 12:54:12.407198+00', 'McRone, D', '', 'D McRone', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2004, NULL, '2012-01-20 12:54:12.40974+00', 'Stanley, F', '', 'F Stanley', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2005, NULL, '2012-01-20 12:54:12.412263+00', 'Webb, M & M', '', 'M & M Webb', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2006, NULL, '2012-01-20 12:54:12.414781+00', 'Gourlay, Ian', '', 'Ian Gourlay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2007, NULL, '2012-01-20 12:54:12.417299+00', 'Scott-Gatty, Alfred', '', 'Alfred Scott-Gatty', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2008, NULL, '2012-01-20 12:54:12.419825+00', 'Collin, Chris', '', 'Chris Collin', 'Ardbrae, Ottawa', 'collin@mondenet.com', 1, 0, 0, 0, NULL, 1959, 0, NULL, '');
INSERT INTO 'person' VALUES (2009, NULL, '2012-01-20 12:54:12.422347+00', 'Wilson, C & E', '', 'C & E Wilson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2010, NULL, '2012-01-20 12:54:12.424872+00', 'Collin, Irene', '', 'Irene Collin', 'Ardbrae, Ottawa', 'collin@mondenet.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2011, NULL, '2012-01-20 12:54:12.427396+00', 'Lyall, Donald', '', 'Donald Lyall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2012, NULL, '2012-01-20 12:54:12.429911+00', 'Mortimer, Brian', '', 'Brian Mortimer', 'Ardbrae, Ottawa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2013, NULL, '2012-01-20 12:54:12.432451+00', 'Celtic Society, University of Saint Andrews', '', 'University of Saint Andrews Celtic Society', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2015, NULL, '2012-01-20 12:54:12.437499+00', 'See, Elma', '', 'Elma See', 'Hunter Valley, Australia', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2016, NULL, '2012-01-20 12:54:12.440017+00', 'Lyndhurst SCD Group', '', 'Lyndhurst SCD Group', 'Ohio', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2017, NULL, '2012-01-20 12:54:12.442533+00', 'Blaschke, Marilyn & Ted', '', 'Marilyn & Ted Blaschke', 'Atlanta', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2019, NULL, '2012-01-20 12:54:12.447573+00', 'Delaware Valley Branch', '', 'Delaware Valley Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2020, NULL, '2012-01-20 12:54:12.450101+00', 'West Renfrewshire Assoc. RSCDS', '', 'West Renfrewshire Assoc. RSCDS', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2021, NULL, '2012-01-20 12:54:12.452622+00', 'Heston & District Scottish Association', '', 'Heston & District Scottish Association', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11616, '2018-03-30 09:38:17.480432+00', '2018-03-30 23:56:08.338101+00', 'Emmett, Danial', '', 'Daniel Emmett', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2023, NULL, '2012-01-20 12:54:12.457664+00', 'Urawa SCD group', '', 'Urawa SCD group', 'Tokyo', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2025, NULL, '2012-01-20 12:54:12.46274+00', 'Bond, Peter', '', 'Peter Bond', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2037, NULL, '2012-01-20 12:54:12.493076+00', 'Black, Bill and his Scottish Dance Band', 'Bill Black', 'Bill Black and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2026, NULL, '2012-01-20 12:54:12.465259+00', 'Bond, Simon', '', 'Simon Bond', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2038, NULL, '2012-01-20 12:54:12.49561+00', 'Blair, Jimmy and his Scottish Dance Band', 'Jimmy Blair', 'Jimmy Blair and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2039, NULL, '2012-01-20 12:54:12.498126+00', 'Blue, Jimmy and his Scottish Band', 'Jimmy Blue', 'Jimmy Blue and his Scottish Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2030, NULL, '2012-01-20 12:54:12.475359+00', 'Barthel, Stefan', '', 'Stefan Barthel', 'Erlangen, Germany', 'bast@net24.de', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11675, '2018-08-07 21:04:25.36193+00', '2020-03-12 00:56:52.11898+00', 'Nemiroff, Don', '', 'Don Nemiroff', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2024, NULL, '2021-04-01 21:28:51.093734+00', 'Bond, Dulcie', '', 'Dulcie Bond', 'Sheffield, UK', '', 1, 0, 0, 0, NULL, 1932, 2020, NULL, '');
INSERT INTO 'person' VALUES (2106, NULL, '2021-06-02 16:00:51.243213+00', 'Hellinghuizer, Jaap', '', 'Jaap Hellinghuizer', 'de Bilt, Netherlands', '', 1, 0, 0, 0, NULL, 1943, 2021, NULL, '');
INSERT INTO 'person' VALUES (2040, NULL, '2012-01-20 12:54:12.500654+00', 'Brown, Bobby / Fraser, Alasdair and others', 'Brown & Fraser', 'Bobby Brown, Alasdair Fraser and others', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2041, NULL, '2012-01-20 12:54:12.503239+00', 'Caber Feidh', 'Caber Feidh', 'Caber Feidh', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2043, NULL, '2012-01-20 12:54:12.508298+00', 'Crowe, Bobby & Johnstone, Muriel', 'Crowe & Johnstone', 'Bobby Crowe & Muriel Johnstone', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2044, NULL, '2012-01-20 12:54:12.510824+00', 'Cunningham, David Trio and Ron Gonnella', 'Cunningham / Gonnella', 'David Cunningham Trio and Ron Gonnella', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2045, NULL, '2012-01-20 12:54:12.513347+00', 'Ellis, Robin and his Band', 'Robin Ellis', 'Robin Ellis and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2046, NULL, '2012-01-20 12:54:12.515874+00', 'Frew, Bobby Trio', 'Bobby Frew', 'Bobby Frew Trio', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2047, NULL, '2012-01-20 12:54:12.518403+00', 'Frew, Bobby Four with Ian Powrie', 'Bobby Frew', 'Bobby Frew Four with Ian Powrie', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2048, NULL, '2012-01-20 12:54:12.520943+00', 'Glendale Scottish Dance Band, The', 'Glendale SD Band', 'The Glendale Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2027, NULL, '2012-01-20 12:54:12.467791+00', 'Duffield, Marjorie', '', 'Marjorie Duffield', 'West Lothian', '', 1, 1, 0, 0, 1359, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2049, NULL, '2012-01-20 12:54:12.523507+00', 'Monroe, Bill', '', 'Bill Monroe', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2050, NULL, '2012-01-20 12:54:12.526042+00', 'Mamula, Fred', '', 'Fred Mamula', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2051, NULL, '2012-01-20 12:54:12.528572+00', 'McDonnell, Julia', '', 'Julia McDonnell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2063, NULL, '2012-01-20 12:54:12.558905+00', 'Grant, Angus', '', 'Angus Grant', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2055, NULL, '2012-01-20 12:54:12.538676+00', 'Harp and Claymore', 'Harp and Claymore', 'Harp and Claymore', 'Hunter Valley', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2064, NULL, '2012-01-20 12:54:12.56142+00', 'Tillside Trio, The', 'Tillside Trio', 'The Tillside Trio', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2056, NULL, '2012-01-20 12:54:12.541201+00', 'Wright, Tim', 'Tim Wright', 'Tim Wright', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2057, NULL, '2012-01-20 12:54:12.543727+00', 'MacGregor, John Scottish Dance Band', 'John MacGregor', 'John MacGregor Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2065, NULL, '2012-01-20 12:54:12.56394+00', 'Taylor, John & Imbrie, Andrew', 'Taylor & Imbrie', 'John Taylor & Andrew Imbrie', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2014, NULL, '2016-05-13 14:57:53.737568+00', 'See, Elma and Eaton, Isobel', '', 'Elma See and Isobel Eaton', 'Hunter Valley, Australia', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2058, NULL, '2012-01-20 12:54:12.54625+00', 'McBain''s Scottish Country Dance Band', 'McBain''s Band', 'McBain''s Scottish Country Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2066, NULL, '2012-01-20 12:54:12.566462+00', 'Tullochgorum', 'Tullochgorum', 'Tullochgorum', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2060, NULL, '2012-01-20 12:54:12.551314+00', 'Reid, Ian and his Scottish Dance Band', 'Ian Reid', 'Ian Reid and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2067, NULL, '2012-01-20 12:54:12.56907+00', 'White, Peter and his Scottish Dance Band', 'Peter White', 'Peter White and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2068, NULL, '2012-01-20 12:54:12.571778+00', 'Smith, Duncan & Worland, Susan', 'Smith & Worland', 'Duncan Smith & Susan Worland', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2069, NULL, '2012-01-20 12:54:12.574348+00', 'Dancing Strings of Scotland', 'Dancing Strings', 'Dancing Strings of Scotland', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2070, NULL, '2012-01-20 12:54:12.576888+00', 'Cumming, John', '', 'John Cumming', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2072, NULL, '2012-01-20 12:54:12.581953+00', 'Coy, Alison', '', 'Alison Coy', 'Basel, Switzerland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2073, NULL, '2012-01-20 12:54:12.584488+00', 'Bare, Margaret', '', 'Margaret Bare', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2033, NULL, '2013-02-18 02:30:24.09898+00', 'Bartlett, Don and the Scotians', 'Don Bartlett', 'Don Bartlett and the Scotians', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (2059, NULL, '2013-02-18 02:30:50.842122+00', 'Bay Ladies Ceilidh Band', 'Bay Ladies', 'Bay Ladies Ceilidh Band', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (2034, NULL, '2013-02-18 02:31:42.59372+00', 'BBC Band (Archie Duncan et al)', 'BBC Band', 'BBC Band (Archie Duncan et al)', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (2036, NULL, '2013-02-18 02:34:29.293502+00', 'Berry, Jim and his Scottish Dance Band', 'Jim Berry', 'Jim Berry and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (2078, NULL, '2012-01-20 12:54:12.597157+00', 'Croot, David', '', 'David Croot', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2079, NULL, '2012-01-20 12:54:12.59968+00', 'Selling, Geoffrey', '', 'Geoffrey Selling', '', 'geoffreys@gfsnet.org', 1, 0, 0, 0, NULL, 1949, 0, NULL, '');
INSERT INTO 'person' VALUES (2080, NULL, '2012-01-20 12:54:12.602252+00', 'Ernst, Elizabeth', '', 'Elizabeth Ernst', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2081, NULL, '2012-01-20 12:54:12.604786+00', 'Keiller, George & Risa', '', 'George & Risa Keiller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2075, NULL, '2012-01-20 12:54:12.589552+00', 'Brown, Evelyn', '', 'Evelyn Brown', 'Llandudno', 'lyn.greatorme@btinernet.com', 1, 0, 0, 0, 983, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2096, NULL, '2012-01-20 12:54:12.646309+00', 'Coupe, Robert', '', 'Robert Coupe', 'Vancouver', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2083, NULL, '2012-01-20 12:54:12.609858+00', 'Phimister, Carol-Anne', '', 'Carol-Anne Phimister', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2084, NULL, '2012-01-20 12:54:12.61239+00', 'Rushton, Robert', '', 'Robert Rushton', 'Craven', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2097, NULL, '2012-01-20 12:54:12.648857+00', 'Acheson, Webb', '', 'Webb Acheson', 'Canada', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2086, NULL, '2012-01-20 12:54:12.617433+00', 'Ungar, Jay', '', 'Jay Ungar', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2098, NULL, '2012-01-20 12:54:12.651412+00', 'Golden Fiddles', 'Golden Fiddles', 'Golden Fiddles', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2087, NULL, '2012-01-20 12:54:12.619991+00', 'Don, A', '', 'A Don', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2088, NULL, '2012-01-20 12:54:12.622515+00', 'Occasionals, The', 'Occasionals', 'The Occasionals', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2089, NULL, '2012-01-20 12:54:12.625067+00', 'Craigenroan', 'Craigenroan', 'Craigenroan', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2091, NULL, '2012-01-20 12:54:12.630143+00', 'Wilcock, John D', '', 'John D Wilcock', '', 'j.d.wilcock@soc.staffs.ac.uk', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2100, NULL, '2012-01-20 12:54:12.656465+00', 'Zeuner, Hansmartin', '', 'Hansmartin Zeuner', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2094, NULL, '2012-01-20 12:54:12.64085+00', 'Cape Breton Symphony', 'Cape Breton', 'Cape Breton Symphony', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2095, NULL, '2012-01-20 12:54:12.643747+00', 'Dawson, Jim and his Scottish Country Dance Band', 'Jim Dawson', 'Jim Dawson and his Scottish Country Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2102, NULL, '2012-01-20 12:54:12.662033+00', 'Thinius, Oliver', '', 'Oliver Thinius', 'D-Essen', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2074, NULL, '2014-03-08 17:48:06.743122+00', 'Bond, E Paul', '', 'E Paul Bond', 'Wales', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2104, NULL, '2012-01-20 12:54:12.66712+00', 'Hartmann, Uwe', '', 'Uwe Hartmann', 'D-Dortmund', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2105, NULL, '2012-01-20 12:54:12.669647+00', 'Dreyer, E / Hartmann, U / Zeuner HM & C', '', 'Dreyer, E / Hartmann, U / Zeuner HM & C', 'D-Dortmund', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2239, NULL, '2012-01-20 12:54:13.008958+00', 'Kirkpatrick, C', '', 'C Kirkpatrick', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2052, NULL, '2021-03-17 19:55:06.680754+00', 'Adams, J E', 'Jim Adams', 'J E Adams', 'Camberley, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2062, NULL, '2021-04-05 12:00:56.737679+00', 'Powrie, Ian and his Band', 'Ian Powrie', 'Ian Powrie and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2071, NULL, '2021-08-19 22:05:46.915985+00', 'Otto, Oberdan', '', 'Oberdan Otto', 'Camarillo, CA, USA', 'ootto@tvt.com', 1, 1, 0, 0, NULL, 1947, 2021, NULL, '');
INSERT INTO 'person' VALUES (2107, NULL, '2012-01-20 12:54:12.674712+00', 'Barnes, Christopher', '', 'Christopher Barnes', 'Washington DC, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2108, NULL, '2012-01-20 12:54:12.677234+00', 'Lange, Dieter', '', 'Dieter Lange', 'D-Hamburg', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2109, NULL, '2012-01-20 12:54:12.67978+00', 'Bakalorz, Georg', '', 'Georg Bakalorz', 'D-Oberhausen', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2110, NULL, '2012-01-20 12:54:12.682308+00', 'Oppedijk, Anita', '', 'Anita Oppedijk', 'Zwolle, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2111, NULL, '2012-01-20 12:54:12.684838+00', 'Zeuner, Christine & Hansmartin', '', 'Christine & Hansmartin Zeuner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2112, NULL, '2012-01-20 12:54:12.687379+00', 'Kuhnt, Sonja / Taeger, Dirk', '', 'Kuhnt, Sonja / Taeger, Dirk', 'D-Dortmund', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2114, NULL, '2012-01-20 12:54:12.692445+00', 'Benson, Alan', '', 'Alan Benson', 'D-Berlin', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2115, NULL, '2012-01-20 12:54:12.694971+00', 'Fallas, Andrew', '', 'Andrew Fallas', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2132, NULL, '2012-01-20 12:54:12.735509+00', 'Scottish Country Dance Players', 'SCD Players', 'Scottish Country Dance Players', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2116, NULL, '2012-01-20 12:54:12.697505+00', 'Stein, Volker', '', 'Volker Stein', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2133, NULL, '2012-01-20 12:54:12.738047+00', 'Thistle Band, The', 'Thistle Band', 'The Thistle Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2134, NULL, '2012-01-20 12:54:12.740576+00', 'Bawden, Pat', '', 'Pat Bawden', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2135, NULL, '2012-01-20 12:54:12.743261+00', 'Cronin', '', 'Cronin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2119, NULL, '2012-01-20 12:54:12.702619+00', 'Bielefeld', '', 'Bielefeld', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2120, NULL, '2012-01-20 12:54:12.70515+00', 'Munich', '', 'Munich', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2137, NULL, '2012-01-20 12:54:12.748479+00', 'Craigowl Scottish Dance Band, The', 'Craigowl', 'The Craigowl Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2138, NULL, '2012-01-20 12:54:12.751028+00', 'MacLeod, Peter Jr.', '', 'Peter Jr. MacLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2139, NULL, '2012-01-20 12:54:12.753555+00', 'MacPherson, James', '', 'James MacPherson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2122, NULL, '2012-01-20 12:54:12.710219+00', 'Grisham, R / Messing, L / Shaw, D / Sheffield, M', '', 'Grisham, R / Messing, L / Shaw, D / Sheffield, M', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2289, NULL, '2012-01-20 12:54:13.137415+00', 'Thomson, D V', '', 'D V Thomson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2099, NULL, '2015-03-14 18:11:22.192877+00', 'Ramshaw, Lyle', '', 'Lyle Ramshaw', '', '', 1, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2035, NULL, '2015-03-25 09:53:49.834619+00', 'Berkeley Scottish Players', 'Berkeley Players', 'Berkeley Scottish Players', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (2121, NULL, '2016-10-25 02:51:11.730471+00', 'Quarries and Friends', '', 'Quarries and Friends', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2136, NULL, '2016-10-10 15:24:28.636661+00', 'Petrov, Susie et al.', 'Petrov et al.', 'Susie Petrov et al.', 'Cambridge, MA', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2076, NULL, '2017-05-04 20:39:07.684623+00', 'Burridge, Sue', '', 'Sue Burridge', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'London Branch');
INSERT INTO 'person' VALUES (11618, '2018-03-31 11:06:14.787182+00', '2018-03-31 23:56:27.022038+00', 'Walter, Andrew', '', 'Andrew Walter', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2140, NULL, '2012-01-20 12:54:12.756088+00', 'Downie, Campbell', '', 'Campbell Downie', 'South Africa', 'calm.down@pixie.co.za', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2141, NULL, '2012-01-20 12:54:12.758609+00', 'Ennis', '', 'Ennis', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2123, NULL, '2012-01-20 12:54:12.712759+00', 'Pipes Awa''', 'Pipes Awa''', 'Pipes Awa''', '', '', 0, 0, 0, 1, NULL, 1745, 1807, NULL, '');
INSERT INTO 'person' VALUES (2142, NULL, '2012-01-20 12:54:12.761301+00', 'Fraser, Captain Simon', '', 'Captain Simon Fraser', 'Ardachie', '', 0, 0, 1, 0, NULL, 1773, 1852, NULL, '');
INSERT INTO 'person' VALUES (2124, NULL, '2012-01-20 12:54:12.715283+00', 'Grech, Elma', 'Elma Grech', 'Elma Grech', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2143, NULL, '2012-01-20 12:54:12.763842+00', 'Laurie, Angus', '', 'Angus Laurie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2144, NULL, '2012-01-20 12:54:12.766371+00', 'Crockat, James', '', 'James Crockat', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2125, NULL, '2012-01-20 12:54:12.717807+00', 'Gore, Charlie', '', 'Charlie Gore', 'Argyll, Scotland', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2145, NULL, '2012-01-20 12:54:12.769066+00', 'O''Neill, J', '', 'J O''Neill', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2127, NULL, '2012-01-20 12:54:12.722867+00', 'Laufman, Dudley', '', 'Dudley Laufman', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2128, NULL, '2012-01-20 12:54:12.72539+00', 'McQuillen, Bob', '', 'Bob McQuillen', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2129, NULL, '2012-01-20 12:54:12.727918+00', 'Anderson, Allie / Duthie, John M', '', 'Allie Anderson & John M Duthie', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2090, NULL, '2013-02-18 02:29:45.14959+00', 'Auld Reekie', 'Auld Reekie', 'Auld Reekie', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (2092, NULL, '2013-02-18 02:36:27.310463+00', 'Blue Bonnets', 'Blue Bonnets', 'Blue Bonnets', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (2147, NULL, '2012-01-20 12:54:12.774135+00', 'Gillan', '', 'Gillan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2130, NULL, '2012-01-20 12:54:12.730448+00', 'Garvie, Ellen', '', 'Ellen Garvie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2131, NULL, '2012-01-20 12:54:12.73297+00', 'Hawthorn Scottish Dance Band', 'Hawthorn SD Band', 'Hawthorn Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2148, NULL, '2012-01-20 12:54:12.776671+00', 'MacMaster, Buddy', '', 'Buddy MacMaster', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2149, NULL, '2012-01-20 12:54:12.779292+00', 'McFadden', '', 'McFadden', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2150, NULL, '2012-01-20 12:54:12.781824+00', 'Beamish', '', 'Beamish', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2151, NULL, '2012-01-20 12:54:12.78435+00', 'Early', '', 'Early', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2153, NULL, '2012-01-20 12:54:12.789404+00', 'Carey', '', 'Carey', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2154, NULL, '2012-01-20 12:54:12.791928+00', 'Fraser, James', '', 'James Fraser', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2170, NULL, '2012-01-20 12:54:12.832623+00', 'Allan, Airchie', '', 'Airchie Allan', 'Forfar', '', 0, 0, 1, 0, NULL, 1794, 1831, NULL, '');
INSERT INTO 'person' VALUES (2155, NULL, '2012-01-20 12:54:12.794498+00', 'Campbell, Dan J / Gillis, Angus Allan', '', 'Campbell, Dan J / Gillis, Angus Allan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2156, NULL, '2012-01-20 12:54:12.797056+00', 'O''Reilly', '', 'O''Reilly', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2172, NULL, '2012-01-20 12:54:12.837716+00', 'Anderson, Ena', '', 'Ena Anderson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2173, NULL, '2012-01-20 12:54:12.840246+00', 'Douglas, Bill and his Scottish Dance Band', 'Bill Douglas', 'Bill Douglas and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2157, NULL, '2012-01-20 12:54:12.799592+00', 'Gray, Alf', '', 'Alf Gray', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2158, NULL, '2012-01-20 12:54:12.80211+00', 'Delaney, Jack', '', 'Jack Delaney', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2175, NULL, '2012-01-20 12:54:12.84532+00', 'Johnstone, James', '', 'James Johnstone', '(18C)', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2176, NULL, '2012-01-20 12:54:12.847851+00', 'Messer, Don', '', 'Don Messer', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2177, NULL, '2012-01-20 12:54:12.850378+00', 'Hamefarers, The', 'The Hamefarers', 'The Hamefarers', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2160, NULL, '2012-01-20 12:54:12.807172+00', 'Fielding, Marie', '', 'Marie Fielding', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2178, NULL, '2012-01-20 12:54:12.852914+00', 'McCallum, Ian and his Scottish Dance Band', 'Ian McCallum', 'Ian McCallum and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2179, NULL, '2012-01-20 12:54:12.855452+00', 'McDuff''s Ceilidh Band', 'McDuff', 'McDuff''s Ceilidh Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2180, NULL, '2012-01-20 12:54:12.857972+00', 'Shorthouse, Bert & the Glenlomond Band', 'Bert Shorthouse', 'Bert Shorthouse & the Glenlomond Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2181, NULL, '2012-01-20 12:54:12.860535+00', 'North Ayrshire Branch RSCDS', '', 'North Ayrshire Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2163, NULL, '2012-01-20 12:54:12.814787+00', 'Beaton, Donald Angus', '', 'Donald Angus Beaton', 'Cape Breton', '', 0, 0, 1, 0, NULL, 1912, 1982, NULL, '');
INSERT INTO 'person' VALUES (2183, NULL, '2012-01-20 12:54:12.865596+00', 'Morrison, Ian J', 'Ian Morrison', 'Ian J Morrison', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2164, NULL, '2012-01-20 12:54:12.817316+00', 'Bruce, John', '', 'John Bruce', 'Dumfries', '', 0, 0, 1, 0, NULL, 1720, 1785, NULL, '');
INSERT INTO 'person' VALUES (2255, NULL, '2012-01-20 12:54:13.049911+00', 'Stewart, Andy', '', 'Andy Stewart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2165, NULL, '2012-01-20 12:54:12.819844+00', 'Tullibardine, The Marchioness of', '', 'The Marchioness of Tullibardine', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2184, NULL, '2012-01-20 12:54:12.868119+00', 'Scotsmen, The', 'The Scotsmen', 'The Scotsmen', 'New Zealand', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2167, NULL, '2012-01-20 12:54:12.824945+00', 'Grogan, Lawrence', '', 'Lawrence Grogan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2185, NULL, '2012-01-20 12:54:12.870835+00', 'O''Brien, Dermot', 'Dermot O''Brien', 'Dermot O''Brien', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2186, NULL, '2012-01-20 12:54:12.873658+00', 'Cameron, Calum', 'Calum Cameron', 'Calum Cameron', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2202, NULL, '2012-01-20 12:54:12.914271+00', 'Galloway, Charlie', '', 'Charlie Galloway', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2188, NULL, '2012-01-20 12:54:12.878761+00', 'Cruickshanks, Ian and his Band', 'Ian Cruickshanks', 'Ian Cruickshanks and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2204, NULL, '2012-01-20 12:54:12.920077+00', 'Young, David (18C)', '', 'David (18C) Young', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2189, NULL, '2012-01-20 12:54:12.881313+00', 'Rennie, Adam and his SCD Quartet', 'Adam Rennie', 'Adam Rennie and his SCD Quartet', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2205, NULL, '2012-01-20 12:54:12.922607+00', 'Warrington', '', 'Warrington', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2190, NULL, '2012-01-20 12:54:12.883856+00', 'Evans, Dianne', '', 'Dianne Evans', '', 'devans@whidbey.net', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2207, NULL, '2012-01-20 12:54:12.927673+00', 'Atholl, Duchess of', '', 'Duchess of Atholl', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2191, NULL, '2012-01-20 12:54:12.886383+00', 'Dorkin, Ben', '', 'Ben Dorkin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2209, NULL, '2012-01-20 12:54:12.932744+00', 'McKay, A', '', 'A McKay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2210, NULL, '2012-01-20 12:54:12.935294+00', 'Redpath', '', 'Redpath', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2193, NULL, '2012-01-20 12:54:12.891478+00', 'Robertson, Marion', '', 'Marion Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2211, NULL, '2012-01-20 12:54:12.93782+00', 'Banks', '', 'Banks', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2126, NULL, '2017-01-06 00:56:05.007293+00', 'Campbell, John', '', 'John Campbell', '', '', 1, 0, 1, 0, NULL, 1929, 2010, NULL, '');
INSERT INTO 'person' VALUES (2206, NULL, '2015-03-14 18:11:16.904383+00', 'McCallum, Ian', '', 'Ian McCallum', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2152, NULL, '2015-03-14 18:11:17.883062+00', 'McNamara', '', 'McNamara', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2146, NULL, '2015-03-14 18:11:20.191063+00', 'O''Neill, Francis', '', 'Francis O''Neill', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2159, NULL, '2016-10-03 23:56:14.371583+00', 'Hardie, Bill', '', 'Bill Hardie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2162, NULL, '2017-05-19 08:48:30.372319+00', 'Scottish Weekend Ensemble', 'W''end Ensemble', 'Scottish Weekend Ensemble', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10321, NULL, '2018-10-29 16:39:52.05475+00', 'Harriman, Sarah & Torf', '', 'Sarah Harriman & Torf', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2194, NULL, '2012-01-20 12:54:12.894002+00', 'Thornton, David', '', 'David Thornton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2195, NULL, '2012-01-20 12:54:12.896532+00', 'Gillespie, Jonathan', '', 'Jonathan Gillespie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2212, NULL, '2012-01-20 12:54:12.940369+00', 'Taylor, P/M Willie', '', 'P/M Willie Taylor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2213, NULL, '2012-01-20 12:54:12.942922+00', 'Budzynski, Kerry', '', 'Kerry Budzynski', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2196, NULL, '2012-01-20 12:54:12.899061+00', 'Muir, Elizabeth', '', 'Elizabeth Muir', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2214, NULL, '2012-01-20 12:54:12.945468+00', 'Kenneth, A G', '', 'A G Kenneth', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2215, NULL, '2012-01-20 12:54:12.948043+00', 'Abbott, Bob', '', 'Bob Abbott', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2198, NULL, '2012-01-20 12:54:12.904118+00', 'Boyce, Peter', '', 'Peter Boyce', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2216, NULL, '2012-01-20 12:54:12.950565+00', 'Mulvihill, Brendan', '', 'Brendan Mulvihill', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2199, NULL, '2012-01-20 12:54:12.906694+00', 'Ward, Allan', '', 'Allan Ward', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2200, NULL, '2012-01-20 12:54:12.909219+00', 'Humberstone, Alan', '', 'Alan Humberstone', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2182, NULL, '2013-02-18 02:43:49.875752+00', 'Brydie, Ed and his Band', 'Ed Brydie', 'Ed Brydie and his Band', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (2217, NULL, '2012-01-20 12:54:12.953099+00', 'McAulay, P/M Angus', '', 'P/M Angus McAulay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2201, NULL, '2012-01-20 12:54:12.911752+00', 'Ferguson, David', '', 'David Ferguson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2218, NULL, '2012-01-20 12:54:12.955633+00', 'Williamson, C MacLeod', '', 'C MacLeod Williamson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2220, NULL, '2012-01-20 12:54:12.960685+00', 'Leslie, Bill', '', 'Bill Leslie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2222, NULL, '2012-01-20 12:54:12.965733+00', 'Anderson, Christine', '', 'Christine Anderson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2223, NULL, '2012-01-20 12:54:12.968428+00', 'Smith, J', '', 'J Smith', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2224, NULL, '2012-01-20 12:54:12.970977+00', 'Barrie, J', '', 'J Barrie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2225, NULL, '2012-01-20 12:54:12.973506+00', 'McLeod', '', 'McLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2240, NULL, '2012-01-20 12:54:13.011489+00', 'Flaum, Lisa', '', 'Lisa Flaum', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2226, NULL, '2012-01-20 12:54:12.976028+00', 'Mitchell, E Rosslyn', '', 'E Rosslyn Mitchell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2227, NULL, '2012-01-20 12:54:12.978548+00', 'Cockburn, George', '', 'G Cockburn', '', '', 0, 0, 1, 0, NULL, 1897, 1974, NULL, '');
INSERT INTO 'person' VALUES (2241, NULL, '2012-01-20 12:54:13.014023+00', 'Richardson, David', '', 'David Richardson', 'Northumberland', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2242, NULL, '2012-01-20 12:54:13.016555+00', 'Robertson, Alan B', '', 'Alan B Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2228, NULL, '2012-01-20 12:54:12.981077+00', 'Fyffe, Will', '', 'Will Fyffe', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2229, NULL, '2012-01-20 12:54:12.983602+00', 'Gordon, Joe', '', 'Joe Gordon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2244, NULL, '2012-01-20 12:54:13.021603+00', 'Backus, Zeke', '', 'Zeke Backus', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2246, NULL, '2012-01-20 12:54:13.026668+00', 'Downie, Alastair Band, The', 'Alastair Downie', 'The Alastair Downie Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2231, NULL, '2012-01-20 12:54:12.988654+00', 'Gonnella, Ron & MacIlwham, George', 'Gonnella/MacIlwham', 'Ron Gonnella & George MacIlwham', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2247, NULL, '2012-01-20 12:54:13.029203+00', 'White, David and his Band', 'David White', 'David White and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2174, NULL, '2022-04-07 20:10:01.099288+00', 'Fraser, William', '', 'William Fraser', '', '', 0, 0, 1, 0, NULL, 1760, 1825, NULL, '');
INSERT INTO 'person' VALUES (2233, NULL, '2012-01-20 12:54:12.993723+00', 'SCD Band of the Black Watch', 'Black Watch', 'SCD Band of the Black Watch', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2250, NULL, '2012-01-20 12:54:13.036947+00', 'McIver, P/M', '', 'P/M McIver', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2251, NULL, '2012-01-20 12:54:13.039501+00', 'Judson, Jack', '', 'Jack Judson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2234, NULL, '2012-01-20 12:54:12.996262+00', 'Gillies, Wilfred', '', 'Wilfred Gillies', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2235, NULL, '2012-01-20 12:54:12.99879+00', 'Waugh, Dorothy', '', 'Dorothy Waugh', 'Annapolis, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2236, NULL, '2012-01-20 12:54:13.001318+00', 'Johnstone, Muriel Trio, The', 'Muriel Johnstone', 'The Muriel Johnstone Trio', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2253, NULL, '2012-01-20 12:54:13.044793+00', 'Wood, Peter', '', 'Peter Wood', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2254, NULL, '2012-01-20 12:54:13.047383+00', 'Shaw, T B', '', 'T B Shaw', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2230, NULL, '2019-11-22 19:32:22.092272+00', 'Lee/Weston', '', 'Lee/Weston', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Full names are Bert Lee & Robert Patrick Weston.');
INSERT INTO 'person' VALUES (2192, NULL, '2021-02-18 18:01:04.55309+00', 'Nicol, Wilson', '', 'Wilson Nicol', 'London, UK', '', 0, 0, 1, 0, NULL, 1931, 2018, NULL, 'The Lives Remembered section of <<https://www.rscdslondon.org.uk/wp-content/uploads/2019/02/Reel-306-electronic.pdf#page=14|The Reel 306>> contains memories of Wilson Nicol.');
INSERT INTO 'person' VALUES (2168, NULL, '2021-08-16 15:40:50.169561+00', 'Forbes, Alistair', '', 'Alistair Forbes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Some scores of his tunes use the initials A B Forbes.');
INSERT INTO 'person' VALUES (2256, NULL, '2012-01-20 12:54:13.052434+00', 'Scott, Percy W', '', 'Percy W Scott', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2259, NULL, '2012-01-20 12:54:13.060041+00', 'Kennedy, J', '', 'J Kennedy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2260, NULL, '2012-01-20 12:54:13.062567+00', 'Jones, Mark', '', 'Mark Jones', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2261, NULL, '2012-01-20 12:54:13.0651+00', 'Mahony', '', 'Mahony', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2262, NULL, '2012-01-20 12:54:13.067635+00', 'Daniel, J', '', 'J Daniel', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2280, NULL, '2012-01-20 12:54:13.114486+00', 'Melly, Pat', '', 'Pat Melly', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2263, NULL, '2012-01-20 12:54:13.070151+00', 'Livingstone, F', '', 'F Livingstone', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2281, NULL, '2012-01-20 12:54:13.117177+00', 'Morris', '', 'Morris', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2264, NULL, '2012-01-20 12:54:13.072679+00', 'MacEachern, Dan Hughie', '', 'Dan Hughie MacEachern', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2282, NULL, '2012-01-20 12:54:13.119707+00', 'Kennedy, Stuart', '', 'Stuart Kennedy', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2283, NULL, '2012-01-20 12:54:13.122251+00', 'Maclean, Donald', '', 'Donald Maclean', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2265, NULL, '2012-01-20 12:54:13.075209+00', 'MacDonald, J R', '', 'J R MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2284, NULL, '2012-01-20 12:54:13.124782+00', 'McTaggart', '', 'McTaggart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2285, NULL, '2012-01-20 12:54:13.127315+00', 'Bell', '', 'Bell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2267, NULL, '2012-01-20 12:54:13.080251+00', 'Wilson, Gordon Stewart', '', 'Gordon Stewart Wilson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2287, NULL, '2012-01-20 12:54:13.132358+00', 'Jackson, Walter Piper', '', 'Walter Piper Jackson', 'Ireland, 18th C.', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2268, NULL, '2012-01-20 12:54:13.082796+00', 'Mearns', '', 'Mearns', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2288, NULL, '2012-01-20 12:54:13.134884+00', 'MacGregor, J G F', '', 'J G F MacGregor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2238, NULL, '2015-03-14 18:11:04.419426+00', 'Cranford, Paul', '', 'Paul Cranford', '', '', 0, 1, 1, 0, 2238, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2266, NULL, '2015-03-14 18:11:13.10943+00', 'Kerr, Ron', '', 'Ron Kerr', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2258, NULL, '2015-03-14 18:11:15.305693+00', 'MacIlwham, George', '', 'George MacIlwham', '', '', 0, 0, 1, 1, NULL, 1926, 0, NULL, '');
INSERT INTO 'person' VALUES (2279, NULL, '2015-03-14 18:11:19.598023+00', 'Neary, Paddy', '', 'Paddy Neary', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2286, NULL, '2015-03-14 18:11:25.295728+00', 'Shorthouse, Bert', '', 'Bert Shorthouse', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2221, NULL, '2015-03-14 18:11:29.959048+00', 'Worland, Susan', '', 'Susan Worland', '', '', 0, 0, 1, 1, 3484, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2252, NULL, '2015-09-24 04:24:38.949717+00', 'Gonnella, Ron & Rankine, Andrew', 'Gonnella/Rankine', 'Ron Gonnella & Andrew Rankine', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2219, NULL, '2017-09-27 23:56:11.037465+00', 'Gray, Hebbie', '', 'Hebbie Gray', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2269, NULL, '2012-01-20 12:54:13.085963+00', 'Munro', '', 'Munro', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2290, NULL, '2012-01-20 12:54:13.13996+00', 'McAlpin, A', '', 'A McAlpin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2270, NULL, '2012-01-20 12:54:13.088735+00', 'Meldrum, Ronald', '', 'R Meldrum', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2291, NULL, '2012-01-20 12:54:13.142489+00', 'MacGovern, Jimmy Country Dance Orchestra', 'Jimmy MacGovern', 'Jimmy MacGovern Country Dance Orchestra', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2292, NULL, '2012-01-20 12:54:13.145026+00', 'Lagganburn', '', 'Lagganburn', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2271, NULL, '2012-01-20 12:54:13.091288+00', 'McLean, Charles', '', 'Charles McLean', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2272, NULL, '2012-01-20 12:54:13.093817+00', 'Murdoch, B', '', 'B Murdoch', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2273, NULL, '2012-01-20 12:54:13.096359+00', 'Stewart', '', 'Stewart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2274, NULL, '2012-01-20 12:54:13.098892+00', 'Browne, Ronnie', '', 'Ronnie Browne', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2294, NULL, '2012-01-20 12:54:13.150078+00', 'Fraser, A', '', 'A Fraser', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2275, NULL, '2012-01-20 12:54:13.101607+00', 'Bell, Billy', '', 'Billy Bell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2276, NULL, '2012-01-20 12:54:13.104282+00', 'Frew, Bobby Four', 'Bobby Frew', 'Bobby Frew Four', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2295, NULL, '2012-01-20 12:54:13.152614+00', 'Ochil Players, The', 'Ochil Players', 'The Ochil Players', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2277, NULL, '2012-01-20 12:54:13.10684+00', 'Blair, Ian', '', 'Ian Blair', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2278, NULL, '2012-01-20 12:54:13.109377+00', 'Haynes, John', '', 'John Haynes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2296, NULL, '2012-01-20 12:54:13.155138+00', 'Orkney Strathspey and Reel Society, The', 'Orkney S&R Soc.', 'The Orkney Strathspey and Reel Society', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2297, NULL, '2012-01-20 12:54:13.157668+00', 'Lennie, W', '', 'W Lennie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2298, NULL, '2012-01-20 12:54:13.160201+00', 'Lucas, R / McCulloch, A', '', 'Lucas, R / McCulloch, A', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2299, NULL, '2012-01-20 12:54:13.16274+00', 'Coghill, B', '', 'B Coghill', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2300, NULL, '2012-01-20 12:54:13.165277+00', 'Montgomery, D', '', 'D Montgomery', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2317, NULL, '2012-01-20 12:54:13.208568+00', 'Duncan, Archie Quintet', 'Archie Duncan', 'Archie Duncan Quintet', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2318, NULL, '2012-01-20 12:54:13.211113+00', 'Dallas, J E', '', 'J E Dallas', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2301, NULL, '2012-01-20 12:54:13.16804+00', 'Fitchet, Angus and his All Star Scottish Band', 'Angus Fitchet', 'Angus Fitchet and his All Star Scottish Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2319, NULL, '2012-01-20 12:54:13.213643+00', 'MacLeod', '', 'MacLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2302, NULL, '2012-01-20 12:54:13.170644+00', 'Heller, M', '', 'M Heller', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2303, NULL, '2012-01-20 12:54:13.173183+00', 'Jemmett, Charlie and His Band', 'Charlie Jemmett', 'Charlie Jemmett and His Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2322, NULL, '2012-01-20 12:54:13.221254+00', 'Mitchell, Paul', '', 'Paul Mitchell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2304, NULL, '2012-01-20 12:54:13.175718+00', 'Park, M', '', 'M Park', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2323, NULL, '2012-01-20 12:54:13.223778+00', 'Halliday, P/M R', '', 'R Halliday', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2324, NULL, '2012-01-20 12:54:13.226767+00', 'MacLean, R I', '', 'R I MacLean', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2305, NULL, '2012-01-20 12:54:13.178246+00', 'Yorkston, James', '', 'James Yorkston', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2306, NULL, '2012-01-20 12:54:13.180774+00', 'Robinson, B', '', 'B Robinson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2293, NULL, '2022-04-07 20:07:43.866823+00', 'Foster, Stephen', '', 'Stephen Foster', '', '', 0, 0, 1, 0, NULL, 1826, 1864, NULL, '');
INSERT INTO 'person' VALUES (2257, NULL, '2022-12-19 19:38:19.092385+00', 'Hayes, John C.', 'Jack Hayes', 'John C. Hayes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Also known as J. C. Hayes and John C Hayes');
INSERT INTO 'person' VALUES (2326, NULL, '2012-01-20 12:54:13.231882+00', 'Dodds', '', 'Dodds', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2307, NULL, '2012-01-20 12:54:13.183304+00', 'Barrie, W M', '', 'W M Barrie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2308, NULL, '2012-01-20 12:54:13.18583+00', 'Kerr, John', '', 'John Kerr', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2330, NULL, '2012-01-20 12:54:13.241999+00', 'Park Film Studio Players', 'Park Film', 'Park Film Studio Players', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2309, NULL, '2012-01-20 12:54:13.188363+00', 'Macphedran, J', '', 'J Macphedran', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2310, NULL, '2012-01-20 12:54:13.190887+00', 'Morgan, Jock', '', 'Jock Morgan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2311, NULL, '2012-01-20 12:54:13.193411+00', 'Haugh, J', '', 'J Haugh', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2312, NULL, '2012-01-20 12:54:13.195937+00', 'Sousa', '', 'Sousa', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2332, NULL, '2012-01-20 12:54:13.247057+00', 'MacDonald', '', 'MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2313, NULL, '2012-01-20 12:54:13.198457+00', 'Barron, B', '', 'B Barron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2314, NULL, '2012-01-20 12:54:13.200994+00', 'Peyronnin, J', '', 'J Peyronnin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2315, NULL, '2012-01-20 12:54:13.203524+00', 'Smith, A', '', 'A Smith', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2316, NULL, '2012-01-20 12:54:13.206043+00', 'Cappelle, Frans van', '', 'Frans van Cappelle', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2336, NULL, '2012-01-20 12:54:13.257171+00', 'Smith, George and the Hebrideans', 'George Smith', 'George Smith and the Hebrideans', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2337, NULL, '2012-01-20 12:54:13.259958+00', 'Strathpeffer Band, The', 'Strathpeffer', 'The Strathpeffer Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2338, NULL, '2012-01-20 12:54:13.262526+00', 'MacDonald, W', '', 'W MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2355, NULL, '2012-01-20 12:54:13.305596+00', 'Nicholson, Norman S', '', 'Norman S Nicholson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2339, NULL, '2012-01-20 12:54:13.265071+00', 'Scotch Measure', 'Scotch Measure', 'Scotch Measure', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2356, NULL, '2012-01-20 12:54:13.30815+00', 'MacKinnon, Angus and the Scots Canadians', 'Angus MacKinnon', 'Angus MacKinnon and the Scots Canadians', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2357, NULL, '2012-01-20 12:54:13.310682+00', 'Howick SCD Club', '', 'Howick SCD Club', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11621, '2018-03-31 11:22:58.895656+00', '2018-03-31 23:56:17.070421+00', 'McNulty, P', '', 'P McNulty', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2358, NULL, '2012-01-20 12:54:13.313223+00', 'Brown, Bobby & Ozorak, Etienne', 'Brown & Ozorak', 'Bobby Brown & Etienne Ozorak', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2341, NULL, '2012-01-20 12:54:13.270143+00', 'Wilmot, John', '', 'John Wilmot', '', '', 0, 0, 1, 0, NULL, 1917, 1993, NULL, '');
INSERT INTO 'person' VALUES (2359, NULL, '2012-01-20 12:54:13.315762+00', 'Cincinnati Branch, RSCDS', '', 'RSCDS Cincinnati Branch', 'USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2342, NULL, '2012-01-20 12:54:13.272678+00', 'Drever, Ivan', '', 'Ivan Drever', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2361, NULL, '2012-01-20 12:54:13.320862+00', 'Carroll, Henry & Atteridge, Harold', '', 'Carroll, Henry & Atteridge, Harold', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2362, NULL, '2012-01-20 12:54:13.3234+00', 'Harper, Addie', '', 'Addie Harper', 'Wick/San Francisco', '', 0, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2364, NULL, '2012-01-20 12:54:13.328458+00', 'Chun, Ping Sun', '', 'Ping Sun Chun', 'Hawaii', 'ping.chun@att.net', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2345, NULL, '2012-01-20 12:54:13.280273+00', 'Wilson, Tom', '', 'Tom Wilson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2365, NULL, '2012-01-20 12:54:13.330986+00', 'Thomson', '', 'Thomson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2366, NULL, '2015-03-14 18:11:02.677821+00', 'Cameron, Jim', '', 'Jim Cameron', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2321, NULL, '2016-12-14 22:47:31.943598+00', 'Berlin, Irving', '', 'Irving Berlin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2343, NULL, '2018-09-15 11:54:10.919555+00', 'Lowthian, Ian', '', 'Ian Lowthian', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2945, NULL, '2019-02-01 00:56:27.359242+00', 'Mitchell, Vera', '', 'Vera Mitchell', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2367, NULL, '2012-01-20 12:54:13.336046+00', 'Leudders, Wil', '', 'Wil Leudders', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2347, NULL, '2012-01-20 12:54:13.285312+00', 'Burns', '', 'Burns', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2348, NULL, '2012-01-20 12:54:13.287838+00', 'Durocher, John', '', 'John Durocher', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2368, NULL, '2012-01-20 12:54:13.338568+00', 'Brannon, Cathy', '', 'Cathy Brannon', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2349, NULL, '2012-01-20 12:54:13.290354+00', 'Dacre, Harry', '', 'Harry Dacre', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2350, NULL, '2012-01-20 12:54:13.292935+00', 'Tilzer, Albert von', '', 'Albert von Tilzer', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2369, NULL, '2012-01-20 12:54:13.3411+00', 'Warren, Michael', '', 'Michael Warren', 'Victoria, BC', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2327, NULL, '2013-02-05 13:27:39.585553+00', 'Macrae, P/M Dan', '', 'P/M Dan Macrae', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2351, NULL, '2012-01-20 12:54:13.295481+00', 'Nugent, Maude', '', 'Maude Nugent', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2352, NULL, '2012-01-20 12:54:13.298007+00', 'Heatherton, Fred', '', 'Fred Heatherton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2353, NULL, '2012-01-20 12:54:13.300538+00', 'O''Connor, Shamus', '', 'Shamus O''Connor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2354, NULL, '2012-01-20 12:54:13.303068+00', 'Kind, John A Glover', '', 'John A Glover Kind', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2373, NULL, '2012-01-20 12:54:13.351223+00', 'McIntosh, P/M A', '', 'P/M A McIntosh', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2374, NULL, '2012-01-20 12:54:13.353757+00', 'Barratt, Bob', '', 'Bob Barratt', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2375, NULL, '2012-01-20 12:54:13.356296+00', 'Alexander, J M', '', 'J M Alexander', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2346, NULL, '2012-01-20 12:54:13.282794+00', 'Frosini, Pietro', '', 'Pietro Frosini', '', '', 0, 0, 1, 0, 2346, 1885, 1951, NULL, '');
INSERT INTO 'person' VALUES (2391, NULL, '2012-01-20 12:54:13.396784+00', 'Mostardi, David', '', 'David Mostardi', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2376, NULL, '2012-01-20 12:54:13.358823+00', 'Hamilton, E', '', 'E Hamilton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2392, NULL, '2012-01-20 12:54:13.399323+00', 'Ladig, Sherry Wohlers', '', 'Sherry Wohlers Ladig', '', 'ladig-dunquin@tcinternet.net', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2393, NULL, '2012-01-20 12:54:13.40185+00', 'Rasmusson, Teri', '', 'Teri Rasmusson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2377, NULL, '2012-01-20 12:54:13.361347+00', 'MacPherson, Donald', '', 'Donald MacPherson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2394, NULL, '2012-01-20 12:54:13.40438+00', 'Pincock, Dougie', '', 'Dougie Pincock', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2378, NULL, '2012-01-20 12:54:13.363879+00', 'Masson', '', 'Masson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11620, '2018-03-31 11:17:09.658431+00', '2018-03-31 23:56:04.758838+00', 'Campbell, Hugh', '', 'Hugh Campbell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2379, NULL, '2012-01-20 12:54:13.366405+00', 'Gonnella, Ron & MacPhail, Iain', 'MacPhail/Gonnella', 'Ron Gonnella & Iain MacPhail', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2397, NULL, '2012-01-20 12:54:13.411998+00', 'Maple Leaf Scottish Dance Band, The', 'Maple Leaf Band', 'The Maple Leaf Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2380, NULL, '2012-01-20 12:54:13.36894+00', 'Lowe, Robert', '', 'Robert Lowe', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2398, NULL, '2012-01-20 12:54:13.41453+00', 'Gonnella, Ron & Hamilton, Stan', 'Gonnella/Hamilton', 'Ron Gonnella & Stan Hamilton', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2399, NULL, '2012-01-20 12:54:13.417067+00', 'Mozart, W A', '', 'W A Mozart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2381, NULL, '2012-01-20 12:54:13.371485+00', 'McInnes, H', '', 'H McInnes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2400, NULL, '2012-01-20 12:54:13.419595+00', 'Page, Ralph', '', 'Ralph Page', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2382, NULL, '2012-01-20 12:54:13.374013+00', 'Reinagle, Joseph', '', 'Joseph Reinagle', '', '', 0, 0, 1, 0, NULL, 1762, 1836, NULL, '');
INSERT INTO 'person' VALUES (2402, NULL, '2012-01-20 12:54:13.42469+00', 'Gray', '', 'Gray', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2383, NULL, '2012-01-20 12:54:13.376543+00', 'Russell, P/M J', '', 'P/M J Russell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2403, NULL, '2012-01-20 12:54:13.427215+00', 'Miller, Brian', '', 'Brian Miller', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2363, NULL, '2022-07-13 15:14:14.210004+00', 'Brandon, Mary & David', '', 'Mary & David Brandon', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2360, NULL, '2022-12-22 20:28:13.608762+00', 'Comings, Carolyn & Jorgensen, Kim', '', 'Carolyn Comings & Kim Jorgensen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2344, NULL, '2023-01-11 00:56:51.746398+00', 'Reel Tradition', 'Reel Tradition', 'Reel Tradition', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2333, NULL, '2022-12-26 19:24:16.770173+00', 'Silver, David Band', 'David Silver Band', 'David Silver Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2384, NULL, '2012-01-20 12:54:13.379073+00', 'MacLauchlan, J', '', 'J MacLauchlan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2404, NULL, '2012-01-20 12:54:13.429732+00', 'Soane, Charlie', '', 'Charlie Soane', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2385, NULL, '2012-01-20 12:54:13.381599+00', 'McLennan, D R', '', 'D R McLennan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2405, NULL, '2012-01-20 12:54:13.432264+00', 'Lambert, Tony & Munier, Diane', '', 'Lambert, Tony & Munier, Diane', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2386, NULL, '2012-01-20 12:54:13.384127+00', 'MacNicol, D', '', 'D MacNicol', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2387, NULL, '2012-01-20 12:54:13.386654+00', 'MacGee, J', '', 'J MacGee', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2406, NULL, '2012-01-20 12:54:13.434792+00', 'MacKay, J', '', 'J MacKay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2388, NULL, '2012-01-20 12:54:13.389181+00', 'MacPhee', '', 'MacPhee', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2389, NULL, '2012-01-20 12:54:13.391726+00', 'MacFarlane, J', '', 'J MacFarlane', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2407, NULL, '2012-01-20 12:54:13.437323+00', 'Wilson', '', 'Wilson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11610, '2018-03-18 08:45:38.245828+00', '2018-03-31 23:56:15.239684+00', 'MacLennan, Matthew', '', 'Matthew MacLennan', 'Edinburgh', 'info@matthew-maclennan.co.uk', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2410, NULL, '2012-01-20 12:54:13.444926+00', 'Reynolds, Jodi', '', 'Jodi Reynolds', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2411, NULL, '2012-01-20 12:54:13.447456+00', 'Emmet, Dan', '', 'Dan Emmet', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2427, NULL, '2012-01-20 12:54:13.487917+00', 'Oswald, Mrs', '', 'Mrs Oswald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2412, NULL, '2012-01-20 12:54:13.44998+00', 'McCullough, Gordon and his Scottish Dance Band', 'Gordon McCulloch', 'Gordon McCullough and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2428, NULL, '2012-01-20 12:54:13.490447+00', 'McClellan, Audrey', '', 'Audrey McClellan', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2429, NULL, '2012-01-20 12:54:13.49298+00', 'Dunedin Scottish Dance Band', 'Dunedin', 'Dunedin Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 1950, 0, NULL, '');
INSERT INTO 'person' VALUES (2413, NULL, '2012-01-20 12:54:13.452532+00', 'Hayes, Martin', '', 'Martin Hayes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2430, NULL, '2012-01-20 12:54:13.495516+00', 'Johnstone''s Scottish Accordion Band', 'John Johnstone', 'Johnstone''s Scottish Accordion Band', '', '', 0, 0, 0, 1, NULL, 1950, 0, NULL, '');
INSERT INTO 'person' VALUES (2414, NULL, '2012-01-20 12:54:13.455069+00', 'Reid, Frank and his Band', 'Frank Reid', 'Frank Reid and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2431, NULL, '2012-01-20 12:54:13.498048+00', 'Northrop, Marlene', '', 'Marlene Northrop', 'Cambridge, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2432, NULL, '2012-01-20 12:54:13.500575+00', 'Buckle, Marie', '', 'Marie Buckle', 'Cambridge, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2415, NULL, '2012-01-20 12:54:13.457591+00', 'Rankin, Alec', '', 'Alec Rankin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2433, NULL, '2012-01-20 12:54:13.50311+00', 'Coles, Dorothy', '', 'Dorothy Coles', 'Cambridge, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2416, NULL, '2012-01-20 12:54:13.460123+00', 'Boes, Joan MacDonald', '', 'Joan MacDonald Boes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2434, NULL, '2012-01-20 12:54:13.505635+00', 'Coles, Kathryn', '', 'Kathryn Coles', 'Cambridge, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2435, NULL, '2012-01-20 12:54:13.508162+00', 'Wilson, Donald', '', 'Donald Wilson', 'Cambridge, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2417, NULL, '2012-01-20 12:54:13.462653+00', 'Kirkpatrick, J', '', 'J Kirkpatrick', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2438, NULL, '2012-01-20 12:54:13.51575+00', 'Booth, James', '', 'James Booth', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2419, NULL, '2012-01-20 12:54:13.467715+00', 'Sargent, Rob', '', 'Rob Sargent', 'Inverness', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2439, NULL, '2012-01-20 12:54:13.518278+00', 'Campbell, Alexander', '', 'Alexander Campbell', '', '', 0, 0, 1, 0, NULL, 1733, 1800, NULL, '');
INSERT INTO 'person' VALUES (2420, NULL, '2012-01-20 12:54:13.470239+00', 'Denholm, P/M William', '', 'P/M Denholm', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2440, NULL, '2012-01-20 12:54:13.520853+00', 'Cincinnati Branch Members', '', 'Cincinnati Branch Members', 'Cincinnati', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2421, NULL, '2012-01-20 12:54:13.472771+00', 'Dagg, John', '', 'John Dagg', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2372, NULL, '2015-03-14 18:11:20.390544+00', 'Oxtoby, Chris', '', 'Chris Oxtoby', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2401, NULL, '2016-10-04 23:56:27.902618+00', 'Redley', '', 'Redley', 'Carlisle', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2422, NULL, '2012-01-20 12:54:13.475296+00', 'Porteous Jr, W', '', 'W Porteous Jr', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2441, NULL, '2012-01-20 12:54:13.523416+00', 'Neary, Paddy with the Jim Johnstone Band', 'Neary/Johnstone', 'Paddy Neary with the Jim Johnstone Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2423, NULL, '2012-01-20 12:54:13.477819+00', 'White, Mrs.', '', 'Mrs. White', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2424, NULL, '2012-01-20 12:54:13.48035+00', 'Crofts, J', '', 'J Crofts', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2442, NULL, '2012-01-20 12:54:13.525953+00', 'Aim, Ronnie', '', 'Ronnie Aim', 'Orkney', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2425, NULL, '2012-01-20 12:54:13.48287+00', 'Done, J', '', 'J Done', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2426, NULL, '2012-01-20 12:54:13.485388+00', 'Herman, Fried de Metz', '', 'Fried de Metz Herman', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2443, NULL, '2012-01-20 12:54:13.528486+00', 'Cairns, P/M A M', '', 'P/M A M Cairns', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2444, NULL, '2012-01-20 12:54:13.531029+00', 'Henriksson, S', '', 'S Henriksson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2445, NULL, '2012-01-20 12:54:13.533569+00', 'Coleman, Cy', '', 'Cy Coleman', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2446, NULL, '2012-01-20 12:54:13.5361+00', 'Bart, Lionel', '', 'Lionel Bart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2447, NULL, '2012-01-20 12:54:13.538627+00', 'Serradell, N', '', 'N Serradell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2448, NULL, '2012-01-20 12:54:13.54115+00', 'Valek, K', '', 'K Valek', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2464, NULL, '2012-01-20 12:54:13.582242+00', 'Kokaly, Anton', '', 'Anton Kokaly', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2465, NULL, '2012-01-20 12:54:13.584882+00', 'Wattle and Thistle', 'Wattle & Thistle', 'Wattle and Thistle', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2449, NULL, '2012-01-20 12:54:13.543679+00', 'Peterburski, J', '', 'J Peterburski', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2467, NULL, '2012-01-20 12:54:13.589997+00', 'Hanley', '', 'Hanley', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11617, '2018-03-31 10:55:40.497642+00', '2018-03-31 23:56:15.58003+00', 'MacMillan, Fiona', '', 'Fiona MacMillan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2451, NULL, '2012-01-20 12:54:13.548746+00', 'Blue, Jimmy & Ainsworth, Mickie', 'Blue&Ainsworth', 'Jimmy Blue & Mickie Ainsworth', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2469, NULL, '2012-01-20 12:54:13.595105+00', 'MacLellan, Vincent', '', 'Vincent MacLellan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2452, NULL, '2012-01-20 12:54:13.551296+00', 'McCue, Bill', 'Bill McCue', 'Bill McCue', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2470, NULL, '2012-01-20 12:54:13.597634+00', 'MacDonald, Rory', '', 'Rory MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2471, NULL, '2012-01-20 12:54:13.600168+00', 'MacQuarrie, G', '', 'G MacQuarrie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2453, NULL, '2012-01-20 12:54:13.553822+00', 'Johnstone, Fergie', '', 'Fergie Johnstone', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2472, NULL, '2012-01-20 12:54:13.602692+00', 'Goering, Nancy', '', 'Nancy Goering', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2473, NULL, '2012-01-20 12:54:13.60523+00', 'McNamee, Laura', '', 'Laura McNamee', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2474, NULL, '2012-01-20 12:54:13.607757+00', 'Stuart, Robert', '', 'Robert Stuart', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2455, NULL, '2012-01-20 12:54:13.558909+00', 'Beethoven, Ludwig van', '', 'Ludwig van Beethoven', '', '', 0, 0, 1, 0, NULL, 1770, 1827, NULL, '');
INSERT INTO 'person' VALUES (2475, NULL, '2012-01-20 12:54:13.610277+00', 'O''Callaghan, Kevin', '', 'Kevin O''Callaghan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2456, NULL, '2012-01-20 12:54:13.561433+00', 'Chopin, Frederic', '', 'Frederic Chopin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2476, NULL, '2012-01-20 12:54:13.612808+00', 'Stuart, Geri', '', 'Geri Stuart', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2477, NULL, '2012-01-20 12:54:13.615331+00', 'Swingruber, Keith', '', 'Keith Swingruber', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2437, NULL, '2013-06-14 11:04:54.075367+00', 'Kennedy-Fraser, Marjory', 'M Kennedy-Fraser', 'Marjory Kennedy-Fraser', '', '', 0, 0, 1, 0, 2437, 1857, 1930, NULL, '');
INSERT INTO 'person' VALUES (2436, NULL, '2014-03-27 23:37:31.438432+00', 'Sutherland, Neil', '', 'Neil Sutherland', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2457, NULL, '2012-01-20 12:54:13.563958+00', 'Joplin, Scott', '', 'Scott Joplin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2458, NULL, '2012-01-20 12:54:13.566479+00', 'Debussy, Claude', '', 'Claude Debussy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2478, NULL, '2012-01-20 12:54:13.617853+00', 'Mackay, Angus', '', 'Angus Mackay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2459, NULL, '2012-01-20 12:54:13.569008+00', 'Kelly, Sgt A', '', 'Sgt A Kelly', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2460, NULL, '2012-01-20 12:54:13.571631+00', 'Knox, D', '', 'D Knox', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2479, NULL, '2012-01-20 12:54:13.620459+00', 'Turner, M', '', 'M Turner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2462, NULL, '2012-01-20 12:54:13.576685+00', 'Scottish Fare', 'Scottish Fare', 'Scottish Fare', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2480, NULL, '2012-01-20 12:54:13.623008+00', 'McLean, W', '', 'W McLean', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2463, NULL, '2012-01-20 12:54:13.579679+00', 'Poerschmann', '', 'Poerschmann', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2481, NULL, '2012-01-20 12:54:13.625536+00', 'Jonasson, E', '', 'E Jonasson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2482, NULL, '2012-01-20 12:54:13.628064+00', 'MacDonald, G D', '', 'G D MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2483, NULL, '2012-01-20 12:54:13.630586+00', 'Campbell, R', '', 'R Campbell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2484, NULL, '2012-01-20 12:54:13.633112+00', 'Davidson, William', '', 'William Davidson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2485, NULL, '2012-01-20 12:54:13.635653+00', 'Gates, Lance', '', 'Lance Gates', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2486, NULL, '2012-01-20 12:54:13.638165+00', 'Wild Rose', 'Wild Rose', 'Wild Rose', 'San Francisco', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2501, NULL, '2012-01-20 12:54:13.676751+00', 'Howie, Simon and his Scottish Dance Band', 'Simon Howie', 'Simon Howie and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2502, NULL, '2012-01-20 12:54:13.67931+00', 'Forrest, Jennifer and her Band', 'Jennifer Forest', 'Jennifer Forrest and her Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2503, NULL, '2012-01-20 12:54:13.686957+00', 'Kirkpatrick, Charlie and his Scottish Dance Band', 'Charlie Kirkpatrick', 'Charlie Kirkpatrick and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2504, NULL, '2012-01-20 12:54:13.689731+00', 'Gray, Suzanne and her Scottish Dance Band', 'Suzanne Gray', 'Suzanne Gray and her Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2505, NULL, '2012-01-20 12:54:13.692285+00', 'Mitchell, Graeme and his Scottish Dance Band', 'Graeme Mitchell', 'Graeme Mitchell and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2506, NULL, '2012-01-20 12:54:13.694831+00', 'Holder, J', '', 'J Holder', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2490, NULL, '2012-01-20 12:54:13.648274+00', 'Sieczynski, Rudolf', '', 'Rudolf Sieczynski', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2507, NULL, '2012-01-20 12:54:13.697419+00', 'Carmichael, George and his Scottish Dance Band', 'George Carmichael', 'George Carmichael and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2491, NULL, '2012-01-20 12:54:13.650799+00', 'Lehar, Franz', '', 'Franz Lehar', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2508, NULL, '2012-01-20 12:54:13.699953+00', 'Coull', '', 'Coull', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2510, NULL, '2012-01-20 12:54:13.705026+00', 'MacIntosh, Allan and his Scottish Dance Band', 'Allan MacIntosh', 'Allan MacIntosh and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2493, NULL, '2012-01-20 12:54:13.655857+00', 'Wood, Harry', '', 'Harry Wood', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2511, NULL, '2012-01-20 12:54:13.707556+00', 'Morris, G S', '', 'G S Morris', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2512, NULL, '2012-01-20 12:54:13.710081+00', 'Mullard / Jones', '', 'Mullard / Jones', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2494, NULL, '2012-01-20 12:54:13.65838+00', 'Harris, Charles K', '', 'Charles K Harris', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2466, NULL, '2015-03-14 18:11:15.947707+00', 'MacLeod, R R', '', 'R R MacLeod', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2450, NULL, '2019-06-02 23:30:17.993206+00', 'Briscoe, M & E / Brunken, E', '', 'M & E Briscoe and Elaine Brunken', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2513, NULL, '2012-01-20 12:54:13.712609+00', 'Andy, T', '', 'T Andy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2495, NULL, '2012-01-20 12:54:13.661516+00', 'Hughes, Jimmy / Lake, Frank', '', 'Hughes, Jimmy / Lake, Frank', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2496, NULL, '2012-01-20 12:54:13.664088+00', 'Sterling / Hunting / Krone / von Tilzer', '', 'Sterling / Hunting / Krone / von Tilzer', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2514, NULL, '2012-01-20 12:54:13.715135+00', 'Stuart, F', '', 'F Stuart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2498, NULL, '2012-01-20 12:54:13.669157+00', 'McGlynn, Fraser Trio', 'Fraser McGlynn', 'Fraser McGlynn Trio', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2515, NULL, '2012-01-20 12:54:13.717659+00', 'Robertson, Gordon', '', 'Gordon Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2500, NULL, '2012-01-20 12:54:13.674211+00', 'MacGill, Duncan', '', 'Duncan MacGill', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2516, NULL, '2012-01-20 12:54:13.720185+00', 'Stewart, Davie', '', 'Davie Stewart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2517, NULL, '2012-01-20 12:54:13.722756+00', 'Sturrock, Jim', '', 'Jim Sturrock', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2518, NULL, '2012-01-20 12:54:13.725298+00', 'Wilson / Sturdy', '', 'Wilson / Sturdy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2520, NULL, '2012-01-20 12:54:13.730367+00', 'Swallow', '', 'Swallow', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2522, NULL, '2012-01-20 12:54:13.735426+00', 'Beynon, I', '', 'I Beynon', '', '', 0, 0, 1, 0, NULL, 1901, 1969, NULL, '');
INSERT INTO 'person' VALUES (2523, NULL, '2012-01-20 12:54:13.737944+00', 'Smith, Judith M', '', 'Judith M Smith', '', '', 0, 0, 1, 0, NULL, 1962, 0, NULL, '');
INSERT INTO 'person' VALUES (2524, NULL, '2012-01-20 12:54:13.740468+00', 'Blair, Brian', '', 'Brian Blair', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2525, NULL, '2012-01-20 12:54:13.742989+00', 'Macfarlane, May', '', 'May Macfarlane', 'Toronto, Canada', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2526, NULL, '2012-01-20 12:54:13.745511+00', 'Pogson, David N', '', 'David N Pogson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2527, NULL, '2012-01-20 12:54:13.748224+00', 'Youngs, David', '', 'David Youngs', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2529, NULL, '2012-01-20 12:54:13.753319+00', 'Boyd, Ann / Robinson, Jane', '', 'Ann Boyd / Jane Robinson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2545, NULL, '2012-01-20 12:54:13.794412+00', 'Boland, E', '', 'E Boland', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2546, NULL, '2012-01-20 12:54:13.796943+00', 'MacKenzie, K', '', 'K MacKenzie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2530, NULL, '2012-01-20 12:54:13.755856+00', 'Anderson, Ian & Ena', '', 'Ian & Ena Anderson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2547, NULL, '2012-01-20 12:54:13.799467+00', 'North', '', 'North', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2531, NULL, '2012-01-20 12:54:13.75838+00', 'Brian, Bill', '', 'Bill Brian', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2548, NULL, '2012-01-20 12:54:13.801982+00', 'Reed / Riley', '', 'Reed / Riley', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2532, NULL, '2012-01-20 12:54:13.760916+00', 'Dick, J', '', 'J Dick', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2550, NULL, '2012-01-20 12:54:13.80708+00', 'Ainsworth, Mickie', '', 'Mickie Ainsworth', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2552, NULL, '2012-01-20 12:54:13.812173+00', 'MacFarlane, A', '', 'A MacFarlane', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2553, NULL, '2012-01-20 12:54:13.814703+00', 'Commonwealth Ceilidh Band, The', 'Commonwealth', 'The Commonwealth Ceilidh Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2535, NULL, '2012-01-20 12:54:13.768499+00', 'Horner, Yvette & Baselli, Joss', '', 'Horner, Yvette & Baselli, Joss', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2554, NULL, '2012-01-20 12:54:13.817239+00', 'McAskill, J', '', 'J McAskill', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2555, NULL, '2012-01-20 12:54:13.819841+00', 'Milner, Malcolm', '', 'Malcolm Milner', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2536, NULL, '2012-01-20 12:54:13.771083+00', 'McKenzie, Gordon', '', 'Gordon McKenzie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2556, NULL, '2012-01-20 12:54:13.822386+00', 'Ramsey, Jim', '', 'Jim Ramsey', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2537, NULL, '2012-01-20 12:54:13.773631+00', 'MacDonald, William M', '', 'William M MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2557, NULL, '2012-01-20 12:54:13.824924+00', 'Hunter', '', 'Hunter', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2539, NULL, '2012-01-20 12:54:13.779004+00', 'Venters, P/M A', '', 'P/M A Venters', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2558, NULL, '2012-01-20 12:54:13.827454+00', 'Binde, Melissa', '', 'Melissa Binde', '', 'binde@cs.swarthmore.edu', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2540, NULL, '2012-01-20 12:54:13.781708+00', 'Rizzo, V / Johnson, G', '', 'Rizzo, V / Johnson, G', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2559, NULL, '2012-01-20 12:54:13.829976+00', 'Babbs/Gain', '', 'Babbs/Gain', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2542, NULL, '2012-01-20 12:54:13.78685+00', 'Latann', '', 'Latann', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2492, NULL, '2022-04-07 20:11:50.233796+00', 'Gay, Noel', '', 'Noel Gay', '', '', 0, 0, 1, 0, NULL, 1898, 1954, NULL, '');
INSERT INTO 'person' VALUES (2543, NULL, '2012-01-20 12:54:13.789371+00', 'Collins, C / Leigh, F', '', 'Collins, C / Leigh, F', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2544, NULL, '2012-01-20 12:54:13.791893+00', 'Gross, W', '', 'W Gross', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2563, NULL, '2012-01-20 12:54:13.840102+00', 'Forbes, A', '', 'A Forbes', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2564, NULL, '2012-01-20 12:54:13.842651+00', 'Sheldon / Swirles', '', 'Sheldon/Swirles', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2565, NULL, '2012-01-20 12:54:13.845204+00', 'Forrest, Brian', '', 'Brian Forrest', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2567, NULL, '2012-01-20 12:54:13.850408+00', 'Currie, J', '', 'J Currie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2568, NULL, '2012-01-20 12:54:13.85295+00', 'Carrick, G', '', 'G Carrick', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2534, NULL, '2012-01-20 12:54:13.765973+00', 'Renwick, Willie', '', 'Willie Renwick', '', '', 0, 0, 1, 0, 2534, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2583, NULL, '2012-01-20 12:54:13.89142+00', 'Hendrie, Roy & his Scottish Dance Band', 'Roy Hendrie', 'Roy Hendrie & his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2569, NULL, '2012-01-20 12:54:13.855485+00', 'Meeks, Rudy', '', 'Rudy Meeks', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2488, NULL, '2020-07-23 15:49:05.684413+00', 'McCall, Todd', '', 'Todd McCall', '', 'jtmccall@bellaliant.net', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2562, NULL, '2020-03-02 15:31:08.50095+00', 'Garrett, Jill', '', 'Jill Garrett', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2585, NULL, '2012-01-20 12:54:13.896511+00', 'Legget, Sandy & the Carseloch Band', 'Sandy Legget', 'Sandy Legget & the Carseloch Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2570, NULL, '2012-01-20 12:54:13.858005+00', 'Cook, Drummond and his Scottish Dance Band', 'Drummond Cook', 'Drummond Cook and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2586, NULL, '2012-01-20 12:54:13.899053+00', 'Johnstone, Muriel & Smith, Keith', 'Johnstone/Smith', 'Muriel Johnstone & Keith Smith', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2587, NULL, '2012-01-20 12:54:13.90158+00', 'Gibbons, Tony', '', 'Tony Gibbons', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2571, NULL, '2012-01-20 12:54:13.860546+00', 'Cook, Edith', '', 'Edith Cook', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2588, NULL, '2012-01-20 12:54:13.904109+00', 'Butchart, Irene M', '', 'Irene M Butchart', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2572, NULL, '2012-01-20 12:54:13.863079+00', 'Muirison, Hamish', '', 'Hamish Muirison', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2589, NULL, '2012-01-20 12:54:13.906631+00', 'Morrison, Ian R', '', 'Ian R Morrison', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2590, NULL, '2012-01-20 12:54:13.909158+00', 'Stevenson, David', '', 'David Stevenson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2573, NULL, '2012-01-20 12:54:13.865606+00', 'Cook, Calum', '', 'Calum Cook', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2519, NULL, '2013-02-18 02:41:28.286243+00', 'Brock, Robin and his Band', 'Robin Brock', 'Robin Brock and his Band', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (2591, NULL, '2012-01-20 12:54:13.911687+00', 'de Souza, Brenda', '', 'Brenda De Souza', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2574, NULL, '2012-01-20 12:54:13.868134+00', 'Steyn, E L', '', 'E L Steyn', 'Johannesburg', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2538, NULL, '2015-03-14 18:11:03.377939+00', 'Chapman, Aubrey', '', 'Aubrey Chapman', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2551, NULL, '2015-03-14 18:11:15.867818+00', 'MacLeod, Francis', '', 'Francis MacLeod', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2497, NULL, '2015-03-14 18:11:17.064045+00', 'McCormick, John', '', 'John McCormick', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2566, NULL, '2015-03-25 10:00:06.628946+00', 'Muir, Ian Sound, The', 'Ian T Muir', 'The Ian Muir Sound', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2521, NULL, '2015-09-21 21:51:36.980063+00', 'Reid, A', '', 'A Reid', '', '', 0, 0, 1, 0, NULL, 1901, 1969, NULL, '');
INSERT INTO 'person' VALUES (2561, NULL, '2016-09-09 23:56:08.67102+00', 'Edmonton', '', 'Edmonton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2592, NULL, '2012-01-20 12:54:13.914218+00', 'O''Connor, Kathie and the Happy Highlanders', 'Kathie O''Connor', 'Kathie O''Connor and the Happy Highlanders', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2593, NULL, '2012-01-20 12:54:13.917033+00', 'MacCrimmon, I', '', 'I MacCrimmon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2575, NULL, '2012-01-20 12:54:13.870867+00', 'Gibson, Kay', '', 'Kay Gibson', 'RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2594, NULL, '2012-01-20 12:54:13.919577+00', 'McLachlan, N', '', 'N McLachlan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2576, NULL, '2012-01-20 12:54:13.873678+00', 'Reid, Martin', '', 'Martin Reid', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2596, NULL, '2012-01-20 12:54:13.924638+00', 'Hunter, Alastair & his Caledonian Ceilidh Band', 'Alastair Hunter', 'Alastair Hunter & his Caledonian Ceilidh Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2577, NULL, '2012-01-20 12:54:13.876233+00', 'Wallace, Mairi', '', 'Mairi Wallace', 'Pietermaritzburg, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2597, NULL, '2012-01-20 12:54:13.927175+00', 'Galbraith, D', '', 'D Galbraith', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2578, NULL, '2012-01-20 12:54:13.87877+00', 'Bolton, Moira', '', 'Moira Bolton', 'Pietermaritzburg,  RSA', 'bolton@exec.unp.ac.za', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2598, NULL, '2012-01-20 12:54:13.929698+00', 'MacAllister, Tom Jr.', '', 'Tom Jr. MacAllister', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2579, NULL, '2012-01-20 12:54:13.881303+00', 'Rondebosch Dancers', '', 'Rondebosch Dancers', 'Capetown, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2580, NULL, '2012-01-20 12:54:13.883832+00', 'Cruickshanks, Ian', '', 'Ian Cruickshanks', 'Durban, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2582, NULL, '2012-01-20 12:54:13.888891+00', 'Moore, Gene', '', 'Gene Moore', 'Asheville, NC, USA', 'dancing.trees.designs@worldnet.att.net', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2600, NULL, '2012-01-20 12:54:13.934764+00', 'Steed, Dennis', '', 'Dennis Steed', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2601, NULL, '2012-01-20 12:54:13.937306+00', 'Sanders, Teri', '', 'Teri Sanders', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2602, NULL, '2012-01-20 12:54:13.939836+00', 'Cordy, Gail', '', 'Gail Cordy', 'Utah, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2618, NULL, '2012-01-20 12:54:13.980382+00', 'Rennilson, Susan', '', 'Susan Rennilson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2603, NULL, '2012-01-20 12:54:13.942369+00', 'Abbott, Morag and Hocart, Charles', '', 'Morag Abbott and Charles Hocart', 'Utah, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2619, NULL, '2012-01-20 12:54:13.98292+00', 'Holdsworth, Linton', '', 'Linton Holdsworth', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2620, NULL, '2012-01-20 12:54:13.985447+00', 'O''Hara, Patrick', '', 'Patrick O''Hara', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2604, NULL, '2012-01-20 12:54:13.944909+00', 'Erdman, Zach', '', 'Zach Erdman', 'Utah, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2621, NULL, '2012-01-20 12:54:13.987967+00', 'McNaught, Malcolm', '', 'Malcolm McNaught', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2605, NULL, '2012-01-20 12:54:13.947506+00', 'Le Brocque, David', '', 'David Le Brocque', 'Brisbane, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2622, NULL, '2012-01-20 12:54:13.990487+00', 'Willingale, Tim', '', 'Tim Willingale', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2606, NULL, '2012-01-20 12:54:13.950047+00', 'Miller, W', '', 'W Miller', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2624, NULL, '2012-01-20 12:54:13.995547+00', 'Coutts, John', '', 'John Coutts', '', '', 0, 0, 1, 0, NULL, 1767, 1836, NULL, '');
INSERT INTO 'person' VALUES (2607, NULL, '2012-01-20 12:54:13.952576+00', 'Taylor', '', 'Taylor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11814, '2019-05-30 10:01:23.886143+00', '2019-05-30 10:01:23.886143+00', 'Wilson, Jo', '', 'Jo Wilson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2608, NULL, '2012-01-20 12:54:13.955103+00', 'Matthews, Roddy', '', 'Roddy Matthews', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2627, NULL, '2012-01-20 12:54:14.003124+00', 'Mumford, Wendy', '', 'Wendy Mumford', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2609, NULL, '2012-01-20 12:54:13.957626+00', 'Jones, M', '', 'M Jones', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2628, NULL, '2012-01-20 12:54:14.005648+00', 'Scarr, D M', '', 'D M Scarr', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2629, NULL, '2012-01-20 12:54:14.008178+00', 'Anderson, Richard', '', 'Richard Anderson', 'Elgin', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2610, NULL, '2012-01-20 12:54:13.960158+00', 'Knox, Harry', '', 'Harry Knox', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2630, NULL, '2012-01-20 12:54:14.010701+00', 'Gray, Archie', '', 'Archie Gray', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2611, NULL, '2012-01-20 12:54:13.962685+00', 'MacLeod, Johnny''s Scottish Country Dance Band', 'Johnny MacLeod', 'Johnny MacLeod''s Scottish Country Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2631, NULL, '2012-01-20 12:54:14.013228+00', 'Southern Cross Ceili Band, The', 'Southern Cross', 'The Southern Cross Ceili Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2632, NULL, '2012-01-20 12:54:14.01581+00', 'Niven, Peter', '', 'Peter Niven', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2612, NULL, '2022-04-07 20:16:16.14439+00', 'Gibb, Alexander', '', 'Alexander Gibb', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2613, NULL, '2012-01-20 12:54:13.967751+00', 'Clark, J', '', 'J Clark', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2614, NULL, '2012-01-20 12:54:13.970269+00', 'Parker, Averil', '', 'Averil Parker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2633, NULL, '2012-01-20 12:54:14.018333+00', 'Gilroy, W H', '', 'W H Gilroy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2615, NULL, '2012-01-20 12:54:13.972798+00', 'Wilson, Bett', '', 'Bett Wilson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2616, NULL, '2012-01-20 12:54:13.975323+00', 'Green, John', '', 'John Green', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2634, NULL, '2012-01-20 12:54:14.020859+00', 'Dempsey, Shelagh', '', 'Shelagh Dempsey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2617, NULL, '2012-01-20 12:54:13.977841+00', 'Burt, Mildred', '', 'Mildred Burt', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2636, NULL, '2012-01-20 12:54:14.025899+00', 'Nicolson', '', 'Nicolson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2637, NULL, '2012-01-20 12:54:14.028427+00', 'Henderson', '', 'Henderson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2638, NULL, '2012-01-20 12:54:14.030947+00', 'Lee, A M', '', 'A M Lee', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2635, NULL, '2021-03-13 19:10:21.134964+00', 'Pearson, Erica', '', 'Erica Pearson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2639, NULL, '2012-01-20 12:54:14.033471+00', 'Sims-Tredgett, Yvonne', '', 'Yvonne Sims-Tredgett', 'Doncaster', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2640, NULL, '2012-01-20 12:54:14.03599+00', 'Dyson, Reg', '', 'Reg Dyson', 'Otley', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2658, NULL, '2012-01-20 12:54:14.081931+00', 'Thompson', '', 'Thompson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2641, NULL, '2012-01-20 12:54:14.038512+00', 'Lindsay, Jennifer', '', 'Jennifer Lindsay', 'Wakefield', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2659, NULL, '2012-01-20 12:54:14.085004+00', 'Stoddart, J', '', 'J Stoddart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2660, NULL, '2012-01-20 12:54:14.087722+00', 'Hewie, J', '', 'J Hewie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2642, NULL, '2012-01-20 12:54:14.041058+00', 'Hook, James', '', 'James Hook', 'Norwich', '', 0, 0, 1, 0, NULL, 1746, 1827, NULL, '');
INSERT INTO 'person' VALUES (2661, NULL, '2012-01-20 12:54:14.090261+00', 'McKerron, Charlie', '', 'Charlie McKerron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2643, NULL, '2012-01-20 12:54:14.04376+00', 'Baldwin, Jean', '', 'Jean Baldwin', 'Otley', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2663, NULL, '2012-01-20 12:54:14.095687+00', 'Fife Council P.E.V.T.S.', '', 'Fife Council P.E.V.T.S.', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2644, NULL, '2012-01-20 12:54:14.04633+00', 'Hurst, Tony', '', 'Tony Hurst', '', '', 0, 0, 1, 0, NULL, 1746, 1827, NULL, '');
INSERT INTO 'person' VALUES (2645, NULL, '2012-01-20 12:54:14.04899+00', 'Kerr, Ron and his Scottish Dance Band', 'Ron Kerr', 'Ron Kerr and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2665, NULL, '2012-01-20 12:54:14.101103+00', 'Young, Doris S', '', 'Doris S Young', 'Aberdeen', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2647, NULL, '2012-01-20 12:54:14.054064+00', 'Pasowisty, V', '', 'V Pasowisty', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2666, NULL, '2012-01-20 12:54:14.103839+00', 'Keir, Douglas', '', 'Douglas Keir', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2667, NULL, '2012-01-20 12:54:14.106403+00', 'Craig, Webster', '', 'Webster Craig', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2581, NULL, '2015-03-14 18:11:07.823867+00', 'Gaddis, Earl', '', 'Earl Gaddis', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2662, NULL, '2017-08-27 00:34:16.990086+00', 'Gifford, Andrew', '', 'Andrew Gifford', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11820, '2019-06-14 20:03:21.024431+00', '2019-06-14 20:03:21.024431+00', 'Cann, Amy', '', 'Amy Cann', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2648, NULL, '2012-01-20 12:54:14.056618+00', 'Allen, W', '', 'W Allen', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2668, NULL, '2012-01-20 12:54:14.108939+00', 'Arbuckle, Fred', '', 'Fred Arbuckle', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2649, NULL, '2012-01-20 12:54:14.059162+00', 'Murdoch, Matilda', '', 'Matilda Murdoch', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2669, NULL, '2012-01-20 12:54:14.111472+00', 'Hornsby, Joseph', '', 'Joseph Hornsby', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2670, NULL, '2012-01-20 12:54:14.114001+00', 'Johnson, Rutherford B', '', 'Rutherford B Johnson', '', 'RuddBaron@aol.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2650, NULL, '2012-01-20 12:54:14.061694+00', 'Townsend, E', '', 'E Townsend', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2671, NULL, '2012-01-20 12:54:14.116624+00', 'O''Shea, Patrick M', '', 'Patrick M O''Shea', 'Tiraha', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2651, NULL, '2012-01-20 12:54:14.064229+00', 'MacCormack, D', '', 'D MacCormack', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2652, NULL, '2012-01-20 12:54:14.066758+00', 'Delorme, Bill', '', 'B Delhorme', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2653, NULL, '2012-01-20 12:54:14.069283+00', 'Landry, Ned', '', 'Ned Landry', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2673, NULL, '2012-01-20 12:54:14.121703+00', 'McLean, Alice', '', 'Alice McLean', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2654, NULL, '2012-01-20 12:54:14.071811+00', 'Wright, H', '', 'H Wright', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2657, NULL, '2012-01-20 12:54:14.079404+00', 'MacDonald, A', '', 'A MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2676, NULL, '2012-01-20 12:54:14.129313+00', 'Peacock, F', '', 'F Peacock', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2678, NULL, '2012-01-20 12:54:14.134382+00', 'Cole, M M Publishing Co.', '', 'M M Publishing Co. Cole', 'Chicago', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2656, NULL, '2012-01-20 12:54:14.076871+00', 'Saul, Mark', '', 'Mark Saul', '', '', 0, 0, 1, 0, 2656, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2679, NULL, '2012-01-20 12:54:14.136917+00', 'Peet, Denise', '', 'Denise Peet', 'Washington DC, USA', 'tempesst@juno.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2681, NULL, '2012-01-20 12:54:14.142029+00', 'South, David and his Scottish Dance Band', 'David South', 'David South and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2697, NULL, '2012-01-20 12:54:14.182718+00', 'Ryan, Buck & Walker, Arnold', '', 'Ryan, Buck & Walker, Arnold', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2699, NULL, '2012-01-20 12:54:14.187776+00', 'Grant, Angus R', '', 'Angus R Grant', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2700, NULL, '2012-01-20 12:54:14.190302+00', 'Edge Reels', 'Edge', 'Edge Reels', '', 'edgereels@care4free.net', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2684, NULL, '2012-01-20 12:54:14.149695+00', 'Hankins, Ann', '', 'Ann Hankins', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2701, NULL, '2012-01-20 12:54:14.19283+00', 'Wilson, Tim', '', 'Tim Wilson', 'San Francisco', 'TimToddW@hotmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2685, NULL, '2012-01-20 12:54:14.152233+00', 'Bennet, Ken', '', 'Ken Bennet', 'Vancouver', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2702, NULL, '2012-01-20 12:54:14.195398+00', 'Rippon, Hugh', '', 'Hugh Rippon', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2686, NULL, '2012-01-20 12:54:14.154771+00', 'Berne Scottish Country Dance Club', '', 'Berne Scottish Country Dance Club', 'CH-Berne', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2704, NULL, '2012-01-20 12:54:14.20046+00', 'Oliphant, Caroline (Lady Nairne)', '', 'Caroline (Lady Nairne) Oliphant', '', '', 0, 0, 1, 0, NULL, 1766, 1845, NULL, '');
INSERT INTO 'person' VALUES (2687, NULL, '2012-01-20 12:54:14.157308+00', 'Crawford, G Ian', '', 'G Ian Crawford', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2706, NULL, '2012-01-20 12:54:14.205568+00', 'Dam, Eric', '', 'Eric Dam', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2707, NULL, '2012-01-20 12:54:14.2081+00', 'McIntyre, Bonny', '', 'Bonny McIntyre', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2690, NULL, '2012-01-20 12:54:14.164909+00', 'Lunny, R', '', 'R Lunny', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2708, NULL, '2012-01-20 12:54:14.210622+00', 'Shirley, Hazel', '', 'Hazel Shirley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2691, NULL, '2012-01-20 12:54:14.167458+00', 'McMillan, Duncan', '', 'Duncan McMillan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2709, NULL, '2012-01-20 12:54:14.213152+00', 'Gwegorryn, Sherry', '', 'Sherry Gwegorryn', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11622, '2018-04-01 23:36:53.278959+00', '2018-04-01 23:56:22.432531+00', 'Skorobogatov, Alexander', '', 'Alexander Skorobogatov', 'Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2710, NULL, '2012-01-20 12:54:14.215685+00', 'Grundtner, D; Patzman, P; Schneider, D', '', 'Grundtner, D; Patzman, P; Schneider, D', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2711, NULL, '2012-01-20 12:54:14.218237+00', 'Kok, Kate', '', 'Kate Kok', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2712, NULL, '2012-01-20 12:54:14.220769+00', 'Begordis, Katrina', '', 'Katrina Begordis', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2713, NULL, '2012-01-20 12:54:14.223297+00', 'Woutat, Philip', '', 'Philip Woutat', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2714, NULL, '2012-01-20 12:54:14.225815+00', 'Graham, Anne', '', 'Anne Graham', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2689, NULL, '2012-01-20 12:54:14.162378+00', 'McCulloch, Alistair', '', 'Alistair McCulloch', '', '', 0, 0, 1, 0, 2689, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2729, NULL, '2012-01-20 12:54:14.263872+00', 'Murray & Smith', 'Murray/Smith', 'Murray & Smith', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2730, NULL, '2012-01-20 12:54:14.266406+00', 'Fiddlers Three', 'Fiddlers 3', 'Fiddlers Three', '', '', 0, 0, 0, 1, NULL, 1745, 1807, NULL, '');
INSERT INTO 'person' VALUES (2715, NULL, '2012-01-20 12:54:14.228347+00', 'McColl, Alexander C', '', 'Alexander C McColl', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2731, NULL, '2012-01-20 12:54:14.268934+00', 'Strathspey & Reel Society of New Hampshire', 'S&R of NH', 'Strathspey & Reel Society of New Hampshire', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2716, NULL, '2012-01-20 12:54:14.230875+00', 'Troost, Daan', '', 'Daan Troost', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2732, NULL, '2012-01-20 12:54:14.271472+00', 'Gaddis, Risk, Axelrod', 'Gaddis et. al.', 'Gaddis, Risk, Axelrod', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2672, NULL, '2020-04-21 23:23:20.892488+00', 'Zobel, Bill & Johnstone, Muriel', '', 'Bill Zobel / Muriel Johnstone', 'Pitlochry, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '"In 2011, Muriel and Bill returned from Canada to Scotland and now reside in Pitlochry, Perthshire."   ');
INSERT INTO 'person' VALUES (2625, NULL, '2020-11-15 20:33:54.075364+00', 'Frost, Malcolm', '', 'Malcolm Frost', 'Knareborough, Harrogate, UK', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2694, NULL, '2021-04-01 21:33:39.904785+00', 'Hunter, Campbell', '', 'Campbell Hunter', 'Falkirk, Scotland', '', 1, 0, 0, 0, NULL, 1966, 2020, NULL, '');
INSERT INTO 'person' VALUES (2734, NULL, '2012-01-20 12:54:14.27653+00', 'Pixton & Petrov', 'Pixton/Petrov', 'Pixton & Petrov', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2718, NULL, '2012-01-20 12:54:14.235932+00', 'Hemenway, Paul', '', 'Paul Hemenway', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2735, NULL, '2012-01-20 12:54:14.279085+00', 'Sprig of Ivy', 'Sprig of Ivy', 'Sprig of Ivy', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2736, NULL, '2012-01-20 12:54:14.281623+00', 'Cassel/Hooper/Murray', 'Cassel et. al.', 'Cassel/Hooper/Murray', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2719, NULL, '2012-01-20 12:54:14.238453+00', 'Scoy, Virginia van', '', 'Virginia van Scoy', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2737, NULL, '2012-01-20 12:54:14.284159+00', 'Local Hero', 'Local Hero', 'Local Hero', '', '', 0, 0, 0, 1, NULL, 1815, 1858, NULL, '');
INSERT INTO 'person' VALUES (2738, NULL, '2012-01-20 12:54:14.286691+00', 'MacDonald, Alex P/M', '', 'Alex P/M MacDonald', '', '', 0, 0, 1, 0, NULL, 1815, 1858, NULL, '');
INSERT INTO 'person' VALUES (2655, NULL, '2016-08-25 13:15:06.029553+00', 'Gray, M', '', 'M Gray', 'UK', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2717, NULL, '2015-03-14 18:11:11.200236+00', 'Hooper, Anne', '', 'Anne Hooper', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2680, NULL, '2015-03-14 18:11:18.286408+00', 'Miller, Fiona S', '', 'Fiona S Miller', '', 'fsmiller@telus.net', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2698, NULL, '2015-03-14 18:11:25.647945+00', 'Sloan, Cas', '', 'Cas Sloan', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2695, NULL, '2015-03-14 18:11:27.531173+00', 'Thomson, Meryl', '', 'Meryl Thomson', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2703, NULL, '2016-04-24 21:00:57.705107+00', 'Mair, Alan', '', 'Alan Mair', 'Cupar, Fife', 'alan58mair@btinternet.com', 1, 0, 0, 0, NULL, 0, 0, NULL, 'New e-address added 2016-04-24.');
INSERT INTO 'person' VALUES (2696, NULL, '2015-11-29 22:51:51.468062+00', 'Green Ginger', 'Green Ginger', 'Green Ginger', '', 'enquiries@greengingerband.co.uk', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2674, NULL, '2019-10-21 14:51:19.895107+00', 'Mair, Christine', '', 'Christine Mair', 'Cupar, Fife', '', 1, 0, 0, 0, NULL, 0, 2019, NULL, '');
INSERT INTO 'person' VALUES (2682, NULL, '2018-10-07 22:46:07.542154+00', 'Downey, Rod', '', 'Rod Downey', 'Wellington, NZ', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2739, NULL, '2012-01-20 12:54:14.289221+00', 'Gambold, Peter V', '', 'Peter V Gambold', '', '', 1, 1, 0, 0, NULL, 1866, 0, NULL, '');
INSERT INTO 'person' VALUES (2721, NULL, '2012-01-20 12:54:14.243517+00', 'Smith, Alan & Lydia', '', 'Alan & Lydia Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2740, NULL, '2012-01-20 12:54:14.291777+00', 'Kerr, Alan', '', 'Alan Kerr', '', '', 1, 0, 0, 0, NULL, 1866, 0, NULL, '');
INSERT INTO 'person' VALUES (2722, NULL, '2012-01-20 12:54:14.246041+00', 'Boston Branch Demonstration Team', '', 'Boston Branch Demonstration Team', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2741, NULL, '2012-01-20 12:54:14.294297+00', 'Cook, Isobel', '', 'Isobel Cook', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2742, NULL, '2012-01-20 12:54:14.296818+00', 'Leurs, Dorothy', '', 'Dorothy Leurs', 'Edinburgh', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2725, NULL, '2012-01-20 12:54:14.253725+00', 'Lasnik, Howard & Roberta', '', 'Howard & Roberta Lasnik', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2744, NULL, '2012-01-20 12:54:14.302071+00', 'Sturgeon, David', '', 'David Sturgeon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2727, NULL, '2012-01-20 12:54:14.258808+00', 'Highland Whisky', 'Highland Whisky', 'Highland Whisky', '', '', 0, 0, 0, 1, NULL, 1745, 1807, NULL, '');
INSERT INTO 'person' VALUES (2745, NULL, '2012-01-20 12:54:14.304625+00', 'Peterborough Branch RSCDS', 'Peterborough', 'Peterborough Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2728, NULL, '2012-01-20 12:54:14.261341+00', 'Hooper/Cassel/Schwab', 'Hooper et. al.', 'Hooper/Cassel/Schwab', '', '', 0, 0, 0, 1, NULL, 1745, 1807, NULL, '');
INSERT INTO 'person' VALUES (2746, NULL, '2012-01-20 12:54:14.307185+00', 'Kings Lynn SCD Group', 'Kings Lynn', 'Kings Lynn SCD Group', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2747, NULL, '2012-01-20 12:54:14.309726+00', 'Rabbett, Elizabeth', '', 'Elizabeth Rabbett', 'Peterborough', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2748, NULL, '2012-01-20 12:54:14.312277+00', 'Purcell, Rhoda', '', 'Rhoda Purcell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2749, NULL, '2012-01-20 12:54:14.314811+00', 'Wilson, Jonathan J', '', 'Jonathan J Wilson', '', 'Ryhall@HandyJon.fsnet.co.uk', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2750, NULL, '2012-01-20 12:54:14.317345+00', 'Purcell, R', '', 'R Purcell', 'Peterborough', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2751, NULL, '2012-01-20 12:54:14.319882+00', 'Hadman, R', '', 'R Hadman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2752, NULL, '2012-01-20 12:54:14.322423+00', 'Warner, Charles', '', 'Charles Warner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2768, NULL, '2012-01-20 12:54:14.363024+00', 'Allan, Eric', '', 'Eric Allan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2753, NULL, '2012-01-20 12:54:14.324957+00', 'Highlander Music', 'Highl. Music.', 'Highlander Music', 'Beauly (2011)', 'info@highlandermusic.com', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2769, NULL, '2012-01-20 12:54:14.365551+00', 'MacDougall, Mike', '', 'Mike MacDougall', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2754, NULL, '2012-01-20 12:54:14.327491+00', 'Bridgman, Jean', '', 'Jean Bridgman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11623, '2018-04-02 20:18:34.742623+00', '2018-04-02 23:56:04.995594+00', 'Buxton, Andrew', '', 'Andrew Buxton', 'Brighton, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2771, NULL, '2012-01-20 12:54:14.370608+00', 'Red Thistle Dancers, The', '', 'The Red Thistle Dancers', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2755, NULL, '2012-01-20 12:54:14.330012+00', 'Brown, Ann', '', 'Ann Brown', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2772, NULL, '2012-01-20 12:54:14.37314+00', 'Woodman, Elizabeth', '', 'Elizabeth Woodman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2756, NULL, '2012-01-20 12:54:14.332532+00', 'Goddard, Paul', '', 'Paul Goddard', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2773, NULL, '2012-01-20 12:54:14.375669+00', 'Falconer, Marjorie E', '', 'Marjorie E Falconer', 'Lausanne, Switzerland', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2757, NULL, '2012-01-20 12:54:14.33508+00', 'Mitchell, Jamie', '', 'Jamie Mitchell', '', '', 1, 0, 0, 0, NULL, 1962, 0, NULL, '');
INSERT INTO 'person' VALUES (2775, NULL, '2012-01-20 12:54:14.38073+00', 'Spink, A', '', 'A Spink', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2758, NULL, '2012-01-20 12:54:14.33761+00', 'McDonald, Don', '', 'Don McDonald', '', '', 1, 0, 0, 0, NULL, 1962, 0, NULL, '');
INSERT INTO 'person' VALUES (2776, NULL, '2012-01-20 12:54:14.383256+00', 'Stewart, R', '', 'R Stewart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2777, NULL, '2012-01-20 12:54:14.385779+00', 'Tulloch, Sandy', '', 'S Tulloch', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2778, NULL, '2012-01-20 12:54:14.388306+00', 'Matsuoka, Shigeki', '', 'Shigeki Matsuoka', 'Tokyo', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2761, NULL, '2012-01-20 12:54:14.345273+00', 'MacDonald, Lesley', '', 'Lesley MacDonald', '', '', 1, 0, 0, 0, NULL, 1962, 0, NULL, '');
INSERT INTO 'person' VALUES (2762, NULL, '2012-01-20 12:54:14.347815+00', 'Darnell, Derek', '', 'Derek Darnell', '', '', 1, 0, 0, 0, NULL, 1962, 0, NULL, '');
INSERT INTO 'person' VALUES (2780, NULL, '2012-01-20 12:54:14.393444+00', 'Hoshino, Kaoru', '', 'Kaoru Hoshino', 'Tokyo', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2781, NULL, '2012-01-20 12:54:14.395972+00', 'Watanabe, Seiichi', '', 'Seiichi Watanabe', 'Tokyo', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2782, NULL, '2012-01-20 12:54:14.398493+00', 'Gilliam, David', '', 'David Gilliam', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2783, NULL, '2012-01-20 12:54:14.401022+00', 'Winter, Tom', '', 'Tom Winter', 'San Francisco', 'foerster37-rscds@yahoo.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2784, NULL, '2012-01-20 12:54:14.403552+00', 'Nogales, Michelle', '', 'Michelle Nogales', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2785, NULL, '2012-01-20 12:54:14.406077+00', 'Strong, David & Palm, Olaf', '', 'Strong, David & Palm, Olaf', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2774, NULL, '2012-01-20 12:54:14.378198+00', 'Williams, Craig & Poapst, Jody', '', 'Craig Williams / Jody Poapst', '', '', 1, 0, 0, 0, 10597, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2802, NULL, '2012-01-20 12:54:14.449338+00', 'Keiller, Risa', '', 'Risa Keiller', 'USA-Houston, TX', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2812, NULL, '2021-07-25 21:58:59.529979+00', 'Miller, Eileen', '', 'Eileen Miller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2803, NULL, '2012-01-20 12:54:14.451885+00', 'Pollock Sisters, The', '', 'The Pollock Sisters', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2804, NULL, '2012-01-20 12:54:14.454407+00', 'Settrey, Ray', '', 'Ray Settrey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2787, NULL, '2012-01-20 12:54:14.41116+00', 'Hill, Jimmie', '', 'Jimmie Hill', 'Brighton', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2805, NULL, '2012-01-20 12:54:14.456952+00', 'Fidler, Irene', '', 'Irene Fidler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2675, NULL, '2021-03-02 17:58:11.010812+00', 'Bailey, Margaret', '', 'Margaret L Bailey', 'Invercargill, New Zealand', 'marglbailey@hotmail.com', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Now Margaret Allison.');
INSERT INTO 'person' VALUES (2759, NULL, '2021-11-18 12:18:23.041188+00', 'Davies, Elaine', '', 'Elaine Davies', '', '', 1, 0, 0, 0, NULL, 1983, 0, NULL, '');
INSERT INTO 'person' VALUES (2760, NULL, '2021-11-18 12:19:57.030778+00', 'Davies, Elaine & Napier, Clare', '', 'Davies, Elaine & Napier, Clare', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2788, NULL, '2012-01-20 12:54:14.413687+00', 'Avery, Peter', '', 'Peter Avery', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2807, NULL, '2012-01-20 12:54:14.462015+00', 'Phillipson, Freda M', '', 'Freda M Phillipson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2808, NULL, '2012-01-20 12:54:14.464541+00', 'Schneider, Doug & McCall, Todd', '', 'Schneider, Doug & McCall, Todd', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2790, NULL, '2012-01-20 12:54:14.41877+00', 'Garner, Kerrell', '', 'Kerrell Garner', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2809, NULL, '2012-01-20 12:54:14.467076+00', 'Blackburn, Terry', '', 'Terry Blackburn', 'Freiburg, Switzerland', 'blackburn@bluewin.ch', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2810, NULL, '2012-01-20 12:54:14.469612+00', 'Jackson, Olive / Sampson, Glen / Hamilton, Janice', '', 'Jackson, Olive / Sampson, Glen / Hamilton, Janice', '', 'gsampson@nsac.ns.ca', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2791, NULL, '2012-01-20 12:54:14.421295+00', 'Vosper, Henrietta', '', 'Henrietta Vosper', 'Cornwall', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2792, NULL, '2012-01-20 12:54:14.423824+00', 'Goodloe, Vicky', '', 'Vicky Goodloe', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3207, NULL, '2012-01-20 12:54:15.654649+00', 'Ferrel, Frank', '', 'Frank Ferrel', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2726, NULL, '2015-03-14 18:11:19.426568+00', 'Murray, Beth', '', 'Beth Murray', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2724, NULL, '2015-03-14 18:11:21.085679+00', 'Pixton, Tom', '', 'Tom Pixton', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2789, NULL, '2016-03-04 15:36:53.060088+00', 'Jones, Ken', '', 'Ken Jones', 'Sheffield', '', 1, 0, 0, 0, NULL, 0, 2011, NULL, '');
INSERT INTO 'person' VALUES (2814, NULL, '2012-01-20 12:54:14.479742+00', 'Corbett, Lois', '', 'Lois Corbett', 'Kingston, Ontario', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2794, NULL, '2012-01-20 12:54:14.428869+00', 'Sparks, Gordon', '', 'Gordon Sparks', 'Ontario', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2815, NULL, '2012-01-20 12:54:14.482265+00', 'Burrows, Ronella', '', 'Ronella Burrows', 'Durban, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2816, NULL, '2012-01-20 12:54:14.484789+00', 'McHaffie, Ian', '', 'Ian McHaffie', 'Toronto, Canada', 'ianmch@inforamp.net', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2796, NULL, '2012-01-20 12:54:14.433982+00', 'MacLeod, Stewart', '', 'Stewart MacLeod', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2817, NULL, '2012-01-20 12:54:14.487324+00', 'Sommerville, Ted', '', 'Ted Sommerville', 'Durban, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2797, NULL, '2012-01-20 12:54:14.436509+00', 'Skinner, June', '', 'June Skinner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2798, NULL, '2012-01-20 12:54:14.439082+00', 'Miyakawa, Kiyohiko', '', 'Kiyohiko Miyakawa', 'J-Tokyo', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2818, NULL, '2012-01-20 12:54:14.489858+00', 'Jardine, Lee', '', 'Lee Jardine', 'Somerset West, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2799, NULL, '2012-01-20 12:54:14.441622+00', 'Tait, J MacMillan', '', 'J MacMillan Tait', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2800, NULL, '2012-01-20 12:54:14.44415+00', 'Cambell, C.A.', '', 'C.A. Cambell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2801, NULL, '2012-01-20 12:54:14.44668+00', 'Schatz, Stefan', '', 'Stefan Schatz', '', 'stefan.piano.schatz@t-online.de', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2819, NULL, '2012-01-20 12:54:14.49239+00', 'Adams, The', '', 'The Adams', 'Cape Town, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2820, NULL, '2012-01-20 12:54:14.494916+00', 'Loveland, Rolf', '', 'Rolf Loveland', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2821, NULL, '2012-01-20 12:54:14.497439+00', 'Adams, Ron', '', 'Ron Adams', 'Cape Town, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2836, NULL, '2012-01-20 12:54:14.535498+00', 'Hennessy, Dave', '', 'Dave Hennessy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2837, NULL, '2012-01-20 12:54:14.538023+00', 'Stubbert, R', '', 'R Stubbert', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2822, NULL, '2012-01-20 12:54:14.499972+00', 'Powell, Sheila', '', 'Sheila Powell', 'Pretoria, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2838, NULL, '2012-01-20 12:54:14.540557+00', 'Stuart, J', '', 'J Stuart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2839, NULL, '2012-01-20 12:54:14.543085+00', 'MacDonald, M', '', 'M MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2840, NULL, '2012-01-20 12:54:14.545603+00', 'Cowans, H', '', 'H Cowans', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2824, NULL, '2012-01-20 12:54:14.505038+00', 'Hynes, Cynthia', '', 'Cynthia Hynes', 'Somerset West, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2825, NULL, '2012-01-20 12:54:14.507572+00', 'Murray, Saxon', '', 'Saxon Murray', 'Pinetown, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2823, NULL, '2014-09-04 14:10:04.41524+00', 'MacKay, Tine E', '', 'Tine E MacKay', 'Mountville, PA', 'tine.mackay@gmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2842, NULL, '2012-01-20 12:54:14.550649+00', 'Hunter, Dougie', '', 'Dougie Hunter', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2826, NULL, '2012-01-20 12:54:14.510091+00', 'Wilson, Vada', '', 'Vada Wilson', 'Pretoria, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2827, NULL, '2012-01-20 12:54:14.51262+00', 'Donaldson, Pat', '', 'Pat Donaldson', 'Bellville, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2845, NULL, '2012-01-20 12:54:14.558308+00', 'Cathcart, Pauline', '', 'Pauline Cathcart', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2828, NULL, '2012-01-20 12:54:14.515145+00', 'Monteith, Margo', '', 'Margo Monteith', 'Johannesburg, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2829, NULL, '2012-01-20 12:54:14.517675+00', 'Bell, William', '', 'William Bell', 'Castle Dougas, NI', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2830, NULL, '2012-01-20 12:54:14.520204+00', 'Robertson, Gail', '', 'Gail Robertson', 'Somerset West, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2849, NULL, '2012-01-20 12:54:14.590761+00', 'Green, T', '', 'T Green', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2831, NULL, '2012-01-20 12:54:14.522754+00', 'Frew, Alex', '', 'Alex Frew', 'Cape Town, RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2832, NULL, '2012-01-20 12:54:14.525294+00', 'Evans, Marlene Lloyd', '', 'Marlene Lloyd Evans', 'RSA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2833, NULL, '2012-01-20 12:54:14.527826+00', 'Graham, Grace', '', 'Grace Graham', 'Ontario, CAN', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2834, NULL, '2012-01-20 12:54:14.530398+00', 'Bissell, Eugene & Kelly, Jennifer', '', 'Eugene Bissell & Jennifer Kelly', 'San Francisco, USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2852, NULL, '2012-01-20 12:54:14.601468+00', 'McIntosh, Hamish', '', 'Hamish McIntosh', 'Aberdeen', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2853, NULL, '2012-01-20 12:54:14.604772+00', 'Hutchison, Anne', '', 'Anne Hutchison', 'Aberdeen', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2854, NULL, '2012-01-20 12:54:14.60819+00', 'Hardie, Elizabeth', '', 'Elizabeth Hardie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2855, NULL, '2012-01-20 12:54:14.611494+00', 'Main, Grace', '', 'Grace Main', 'Aberdeen', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2857, NULL, '2012-01-20 12:54:14.618068+00', 'Scott, Annie Shand', '', 'Annie Shand Scott', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2872, NULL, '2012-01-20 12:54:14.678213+00', 'Reiner, Joanna & Mellott, Emily', '', 'Reiner, Joanna & Mellott, Emily', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2858, NULL, '2012-01-20 12:54:14.621454+00', 'Bouvette, Reg', '', 'Reg Bouvette', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2859, NULL, '2012-01-20 12:54:14.626236+00', 'Banks, James', '', 'James Banks', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2875, NULL, '2012-01-20 12:54:14.688315+00', 'Wall, David', '', 'David Wall', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2860, NULL, '2012-01-20 12:54:14.629822+00', 'Mudrey, Michael / Steenport, Dyan', '', 'Mudrey, Michael & Steenport, Dyan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2876, NULL, '2012-01-20 12:54:14.691606+00', 'Bishop, Henry', '', 'Henry Bishop', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2851, NULL, '2021-02-19 14:57:17.943083+00', 'Cramb, Isobel / Cheyne, Bill / Drewry, John', 'Cramb, I / Cheyne, B / Drewry, J', 'Isobel Cramb / Bill Cheyne / John Drewry', 'Aberdeen', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2811, NULL, '2021-02-21 10:55:46.022632+00', 'Aldridge, David Kilgour', '', 'David Kilgour Aldridge', '', 'dancingduff@yahoo.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2795, NULL, '2021-06-08 20:43:25.125707+00', 'Feijtel, Joop', '', 'Joop Feijtel', 'NL-Gouda', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2764, NULL, '2021-09-19 11:48:22.453459+00', 'Spägele, Rudi & Rembold, Charly', '', 'Rudi Spägele & Charly Rembold', 'Schwaebisch Gmuend', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2850, NULL, '2021-08-22 03:34:40.640406+00', 'Aberdeen Branch RSCDS', '', 'Aberdeen Branch RSCDS', 'Aberdeen', '', 0, 1, 0, 0, NULL, 1925, 0, NULL, '');
INSERT INTO 'person' VALUES (2877, NULL, '2012-01-20 12:54:14.694891+00', 'MacAulay, Angus', '', 'Angus MacAulay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2861, NULL, '2012-01-20 12:54:14.640172+00', 'Mudrey, Michael', '', 'Michael Mudrey', 'Wisconsin, USA', 'mike@mudrey.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2878, NULL, '2012-01-20 12:54:14.698178+00', 'Nagle, Georg', '', 'Georg Nagle', 'Switzerland', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2846, NULL, '2013-02-18 02:24:15.793663+00', 'Acoustic Tuna', 'Acoustic Tuna', 'Acoustic Tuna', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (2862, NULL, '2012-01-20 12:54:14.643805+00', 'Knox, Gary', '', 'Gary Knox', '', 'gary@reeljig.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2879, NULL, '2012-01-20 12:54:14.701476+00', 'Crehan, Martin', '', 'Martin Crehan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2880, NULL, '2012-01-20 12:54:14.704761+00', 'Romberg, Sigmund', '', 'Sigmund Romberg', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2881, NULL, '2012-01-20 12:54:14.708052+00', 'Wagner, Josef Franz', '', 'Josef Franz Wagner', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2864, NULL, '2012-01-20 12:54:14.651323+00', 'Leyffer, Sven', '', 'Sven Leyffer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2882, NULL, '2012-01-20 12:54:14.711348+00', 'Walker, R', '', 'R Walker', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2883, NULL, '2012-01-20 12:54:14.714643+00', 'Joyce, A', '', 'A Joyce', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2835, NULL, '2017-06-24 19:00:37.523842+00', 'Blue, Jana', '', 'Jana Blue', 'Richmond, VA, USA', 'janablue@icloud.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2884, NULL, '2012-01-20 12:54:14.717933+00', 'Whinham, Robert', '', 'Robert Whinham', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2866, NULL, '2012-01-20 12:54:14.658087+00', 'Emery, Jill', '', 'Jill Emery', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2868, NULL, '2012-01-20 12:54:14.664818+00', 'Nealley, Katherine', '', 'Katherine Nealley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2869, NULL, '2012-01-20 12:54:14.668249+00', 'Nealley, Ed', '', 'Ed Nealley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2870, NULL, '2012-01-20 12:54:14.671631+00', 'De la Veaux, Paulette', '', 'Paulette De la Veaux', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2871, NULL, '2012-01-20 12:54:14.674926+00', 'Hurd, Eleanor', '', 'Eleanor Hurd', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2889, NULL, '2012-01-20 12:54:14.734598+00', 'Martin, Margaret', '', 'Margaret Martin', 'North Berwick', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2891, NULL, '2012-01-20 12:54:14.741322+00', 'Ellerton', '', 'Ellerton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2892, NULL, '2012-01-20 12:54:14.744617+00', 'Jamieson, Ann & Ian', '', 'Ann & Ian Jamieson', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2893, NULL, '2012-01-20 12:54:14.747914+00', 'Broughton, Leslie', '', 'Leslie Broughton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2895, NULL, '2012-01-20 12:54:14.754502+00', 'Ithaca', '', 'Ithaca', 'NY, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2896, NULL, '2012-01-20 12:54:14.758061+00', 'Watson, Nanette', '', 'Nanette Watson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2914, NULL, '2012-01-20 12:54:14.819165+00', 'Morrison, Alan', '', 'Alan Morrison', 'Forfar', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2897, NULL, '2012-01-20 12:54:14.761506+00', 'O''Hare, Ruby', '', 'Ruby O''Hare', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2898, NULL, '2012-01-20 12:54:14.765101+00', 'Gibbs, Stanley', '', 'Stanley Gibbs', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2899, NULL, '2012-01-20 12:54:14.768398+00', 'Harris, Bernard', '', 'Bernard Harris', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2919, NULL, '2012-01-20 12:54:14.835684+00', 'Farmer, Valerie', '', 'Valerie Farmer', 'Wirral', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2900, NULL, '2012-01-20 12:54:14.771688+00', 'Serjeant, Elizabeth', '', 'Elizabeth Serjeant', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2920, NULL, '2012-01-20 12:54:14.838977+00', 'Blair, Jimmy & Keenan, George', '', 'Blair, Jimmy & Keenan, George', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2886, NULL, '2018-07-25 23:01:14.286904+00', 'Shaw, Jean', '', 'Jean Shaw', 'North Wales', 'sscd-je4n@pobroadband.co.uk', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2921, NULL, '2012-01-20 12:54:14.842285+00', 'Gounod', '', 'Gounod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2922, NULL, '2012-01-20 12:54:14.845578+00', 'Morrison, May', '', 'May Morrison', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2902, NULL, '2012-01-20 12:54:14.778921+00', 'Napier, John', '', 'John Napier', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2923, NULL, '2012-01-20 12:54:14.849213+00', 'Blumentritt, Daniel', '', 'Daniel Blumentritt', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2903, NULL, '2012-01-20 12:54:14.78222+00', 'RSCDS in East Lothian', 'East Lothian', 'RSCDS in East Lothian', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2925, NULL, '2012-01-20 12:54:14.855801+00', 'Lewis, Ron', '', 'Ron Lewis', 'Accrington, England', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2904, NULL, '2012-01-20 12:54:14.785533+00', 'Grant, Jean', '', 'Jean Grant', 'Tranent', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2926, NULL, '2012-01-20 12:54:14.859228+00', 'Fordyce, Louise', '', 'Louise Fordyce', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2905, NULL, '2012-01-20 12:54:14.788834+00', 'Hewitt, Jan', '', 'Jan Hewitt', 'Prestonpans', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2907, NULL, '2012-01-20 12:54:14.795635+00', 'Kennedy, Margaret', '', 'Margaret Kennedy', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2908, NULL, '2012-01-20 12:54:14.799025+00', 'Greig, Andy', '', 'Andy Greig', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2928, NULL, '2012-01-20 12:54:14.865982+00', 'Silk & Thistle', '', 'Silk & Thistle', 'Chicago, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11673, '2018-08-07 19:35:18.895597+00', '2018-08-07 23:56:10.075551+00', 'Gentles, Kate and Suttie, Paul', '', 'Kate Gentles and Paul Suttie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2910, NULL, '2012-01-20 12:54:14.80579+00', 'Hall, Hazel', '', 'Hazel Hall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2929, NULL, '2012-01-20 12:54:14.869283+00', 'Houston, Texas', '', 'Texas Houston', 'Texas, USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2911, NULL, '2012-01-20 12:54:14.809183+00', 'Breckenridge, Margaret', '', 'Margaret Breckenridge', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2931, NULL, '2012-01-20 12:54:14.875984+00', 'Johnson, Susan', '', 'Susan Johnson', 'Frederick, MD, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2932, NULL, '2012-01-20 12:54:14.879295+00', 'Ternes, Ellen', '', 'Ellen Ternes', 'Frederick, MD, USA', 'eternes@umd.edu', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2933, NULL, '2012-01-20 12:54:14.88262+00', 'Wilson, Matthew', '', 'Matthew Wilson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2949, NULL, '2012-01-20 12:54:14.935853+00', 'McLeod, Cathy', '', 'Cathy McLeod', 'Brisbane, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2950, NULL, '2012-01-20 12:54:14.939385+00', 'Schofield, Viki', '', 'Viki Schofield', 'Brisbane, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2934, NULL, '2012-01-20 12:54:14.885913+00', 'Forbes, Jill', '', 'Jill Forbes', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2951, NULL, '2012-01-20 12:54:14.94278+00', 'Riddel, Jean', '', 'Jean Riddel', 'Brisbane, Australia', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2935, NULL, '2012-01-20 12:54:14.889214+00', 'Stevens, Graham', '', 'Graham Stevens', 'Kirkcaldy', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3714, NULL, '2012-01-20 12:54:17.175594+00', 'Chater, T', '', 'T Chater', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2888, NULL, '2013-01-24 10:05:38.079803+00', 'Earl, Kirsten', '', 'Kirsten Earl', 'Vancouver', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2952, NULL, '2012-01-20 12:54:14.946204+00', 'Archdeacon, Joanne', '', 'Joanne Archdeacon', 'Cairns, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2953, NULL, '2012-01-20 12:54:14.949709+00', 'Archdeacon, Anne & Joanne', '', 'Anne & Joanne Archdeacon', 'Cairns, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2841, NULL, '2020-11-22 18:30:16.845459+00', 'Cameron, Alan', '', 'Alan Cameron', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2890, NULL, '2020-03-01 16:43:16.356533+00', 'Bisset, Joy', '', 'Joy Bisset', 'Munlochy SCD Group, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2930, NULL, '2021-08-02 16:21:12.975167+00', 'Saskatchewan Branch RSCDS', '', 'Saskatchewan Branch RSCDS', 'Canada', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2917, NULL, '2021-06-08 20:38:59.044005+00', 'Heuvel, Francien van', '', 'Francien van Heuvel', 'Delft, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2918, NULL, '2021-06-08 20:42:30.011766+00', 'Zinnen, Petra van', '', 'Petra van Zinnen', 'Delft, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3077, NULL, '2012-01-20 12:54:15.322288+00', 'Roberts, Niles', '', 'Niles Roberts', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2844, NULL, '2022-12-16 08:38:17.156547+00', 'Hahm, Dietmar', '', 'Dietmar Hahm', '', 'tristan@dietmar-hahm.de', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2916, NULL, '2021-07-08 15:53:11.443679+00', 'Delft Branch RSCDS', '', 'Delft Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2867, NULL, '2021-11-22 12:14:49.440306+00', 'Davis, Katherine', '', 'Katherine Davis', '', '', 1, 0, 0, 0, 2976, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2936, NULL, '2012-01-20 12:54:14.89251+00', 'Queensland Branch RSCDS', '', 'Queensland Branch RSCDS', 'Australia', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2954, NULL, '2012-01-20 12:54:14.953157+00', 'Thomson, Sue', '', 'Sue Thomson', 'Brisbane, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2937, NULL, '2012-01-20 12:54:14.895814+00', 'Alba SC Dancers', '', 'Alba SC Dancers', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2955, NULL, '2012-01-20 12:54:14.956489+00', 'Buchanan, Leslye', '', 'Leslye Buchanan', 'Brisbane, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2956, NULL, '2012-01-20 12:54:14.959858+00', '26th Winter School Committee (Australia)', '', '26th Winter School Committee (Australia)', 'Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2887, NULL, '2016-06-23 23:25:01.749075+00', 'Marshall, Peter', '', 'Peter Marshall', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2913, NULL, '2016-09-04 23:56:02.795066+00', 'Auld, Charlie', '', 'Charlie Auld', 'Brechin', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11674, '2018-08-07 20:32:25.454777+00', '2018-08-07 23:56:14.10117+00', 'Kiskaddon, Katie', '', 'Katie Kiskaddon', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2906, NULL, '2019-04-15 17:20:32.955317+00', 'Maeso, Jerónimo', '', 'Jerónimo Maeso', 'Madrid, Spain', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Obituary published in Scottish Country Dancer Issue 28, April 2019');
INSERT INTO 'person' VALUES (2939, NULL, '2012-01-20 12:54:14.902403+00', 'McCrudden, Maureen', '', 'Maureen McCrudden', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2958, NULL, '2012-01-20 12:54:14.966571+00', 'Deane, Joanna', '', 'Joanna Deane', 'Toowoomba, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2940, NULL, '2012-01-20 12:54:14.90572+00', 'Byrne', '', 'Byrne', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2960, NULL, '2012-01-20 12:54:14.973612+00', 'Fraser, Helen', '', 'Helen Fraser', 'Brisbane, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2941, NULL, '2012-01-20 12:54:14.909014+00', 'Rintoul, Ruth', '', 'Ruth Rintoul', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2942, NULL, '2012-01-20 12:54:14.912377+00', 'Martin, Lindsay', '', 'Lindsay Martin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2961, NULL, '2012-01-20 12:54:14.976996+00', 'McMurtry, Bob', '', 'Bob McMurtry', 'Felton, CA, US', 'Fyreladdie@aol.com', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2943, NULL, '2012-01-20 12:54:14.91569+00', 'Wilkins, Sam', '', 'Sam Wilkins', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2962, NULL, '2012-01-20 12:54:14.980296+00', 'McCrum, Dorothy', '', 'Dorothy McCrum', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2946, NULL, '2012-01-20 12:54:14.925591+00', 'Ingram, Sandy', '', 'Sandy Ingram', 'Glamis', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2964, NULL, '2012-01-20 12:54:14.986883+00', 'Moloney, Paddy', '', 'Paddy Moloney', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2966, NULL, '2012-01-20 12:54:14.993599+00', 'Fraser-Collins, Kathleen', '', 'Kathleen Fraser-Collins', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2967, NULL, '2012-01-20 12:54:14.997015+00', 'Duncan, I A', '', 'I A Duncan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11672, '2018-08-07 19:34:13.252717+00', '2018-08-07 23:56:24.188245+00', 'Suttie, Paul', '', 'Paul Suttie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2974, NULL, '2012-01-20 12:54:15.02227+00', 'Schneeberger, Eva', '', 'Eva Schneeberger', 'Berne, Switzerland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2968, NULL, '2012-01-20 12:54:15.000389+00', 'Baker, Sister Dorcas', '', 'Sister Dorcas Baker', 'Milwaukee, USA', 'srstmary@execpc.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2976, NULL, '2012-01-20 12:54:15.029175+00', 'Giacoletti, Katherine', '', 'Katherine Giacoletti', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2969, NULL, '2012-01-20 12:54:15.003739+00', 'Hankes, Ron', '', 'Ron Hankes', 'Milwaukee, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2979, NULL, '2012-01-20 12:54:15.039236+00', 'Brown, R', '', 'R Brown', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2971, NULL, '2012-01-20 12:54:15.011493+00', 'Milwaukee SC Dancers', '', 'Milwaukee SC Dancers', 'Milwaukee, USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2959, NULL, '2018-10-23 15:24:16.225107+00', 'Heron, Sam', '', 'Sam Heron', 'Brisbane, Australia', '', 1, 0, 0, 0, NULL, 0, 2018, NULL, '');
INSERT INTO 'person' VALUES (2981, NULL, '2012-01-20 12:54:15.046223+00', 'Morrison', '', 'Morrison', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2972, NULL, '2012-01-20 12:54:15.015508+00', 'Fochs, Laura', '', 'Laura Fochs', 'Milwaukee, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2982, NULL, '2012-01-20 12:54:15.050376+00', 'McAlister, Bryan', '', 'Bryan McAlister', '', 'Bryan@bryanmac.demon.co.uk', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2984, NULL, '2012-01-20 12:54:15.057479+00', 'Young, J', '', 'J Young', 'Craven', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2985, NULL, '2012-01-20 12:54:15.060873+00', 'Burnett, Pat', '', 'Pat Burnett', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2986, NULL, '2012-01-20 12:54:15.065019+00', 'Young, Margaret', '', 'Margaret Young', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2987, NULL, '2012-01-20 12:54:15.069811+00', 'Berry, Barbara', '', 'Barbara Berry', 'Newburgh', '', 1, 0, 0, 0, NULL, 1670, 1738, NULL, '');
INSERT INTO 'person' VALUES (2988, NULL, '2012-01-20 12:54:15.073839+00', 'Elder, Jonathan D', '', 'Jonathan D Elder', 'Lubbock, USA', 'dr.rockets@juno.com', 1, 0, 0, 0, NULL, 0, 2002, NULL, '');
INSERT INTO 'person' VALUES (2989, NULL, '2012-01-20 12:54:15.077244+00', 'Wilson, George', '', 'George Wilson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2991, NULL, '2012-01-20 12:54:15.085572+00', 'MacLeod, Dave', '', 'Dave MacLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2993, NULL, '2012-01-20 12:54:15.092185+00', 'Ferguson, Hugh and the Dalriada Scottish Dance Band', 'Dalriada', 'Hugh Ferguson and the Dalriada Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2994, NULL, '2012-01-20 12:54:15.095503+00', 'MacDonald, Ross', '', 'Ross MacDonald', 'Ottawa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2995, NULL, '2012-01-20 12:54:15.099109+00', 'Elliot, Ross', '', 'Ross Elliot', 'Ottawa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2996, NULL, '2012-01-20 12:54:15.102591+00', 'Gillespie, Lloyd and Doreen', '', 'Lloyd and Doreen Gillespie', 'Ottawa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2997, NULL, '2012-01-20 12:54:15.106378+00', 'Scrimgeour, Jack', '', 'Jack Scrimgeour', 'Ottawa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11741, '2018-10-29 10:12:15.371643+00', '2018-10-29 10:12:26.418321+00', 'Eymin, Claire', '', 'Claire Eymin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2999, NULL, '2012-01-20 12:54:15.113161+00', 'Anglin, Bob', '', 'Bob Anglin', 'Ottawa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3000, NULL, '2012-01-20 12:54:15.116453+00', 'Scrimgeour, Pat', '', 'Pat Scrimgeour', 'Ottawa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3012, NULL, '2012-01-20 12:54:15.159466+00', 'Nixon, Sandy and his Scottish Dance Band', 'Sandy Nixon', 'Sandy Nixon and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3001, NULL, '2012-01-20 12:54:15.119763+00', 'Macarthur, Alex & His Scottish Dance Band', 'Alex Macarthur', 'Alex Macarthur & His Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3013, NULL, '2012-01-20 12:54:15.161999+00', 'Dewar, Colin Trio, The', 'Colin Dewar', 'The Colin Dewar Trio', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3014, NULL, '2012-01-20 12:54:15.164525+00', 'Craigellachie Band, The', 'Craigellachie Band', 'The Craigellachie Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3002, NULL, '2012-01-20 12:54:15.123103+00', 'Johnstone, Muriel''s Band', 'Muriel Johnstone', 'Muriel Johnstone''s Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3015, NULL, '2012-01-20 12:54:15.167061+00', 'Johnstone, Muriel Ensemble, The', 'Muriel Johnstone', 'The Muriel Johnstone Ensemble', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3003, NULL, '2012-01-20 12:54:15.135896+00', 'Sound Company', 'Sound Company', 'Sound Company', '', 'judith.robertson@telinco.co.uk', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3016, NULL, '2012-01-20 12:54:15.169585+00', 'Various Artists', '{various}', 'Various Artists', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3017, NULL, '2012-01-20 12:54:15.17212+00', 'Terpsichore', 'Terpsichore', 'Terpsichore', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3004, NULL, '2012-01-20 12:54:15.13898+00', 'Wick Fiddlers, The', 'Wick Fiddlers', 'The Wick Fiddlers', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3018, NULL, '2012-01-20 12:54:15.174657+00', 'Crowe, Bobby and his Scottish Dance Band', 'Bobby Crowe', 'Bobby Crowe and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3005, NULL, '2012-01-20 12:54:15.141643+00', 'Anderson, Betty', '', 'Betty Anderson', 'Ottawa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2924, NULL, '2020-09-30 09:50:07.757456+00', 'Harrison, Tim', '', 'Tim Harrison', 'La Grande, Oregon, USA', 'tim@timdoodle.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2975, NULL, '2021-08-06 20:51:32.399633+00', 'Harvey, Terry', '', 'Terry Harvey', 'Delaware Valley , USA', 'harvey@mail.eecis.udel.edu', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3019, NULL, '2012-01-20 12:54:15.177189+00', 'Thomson, Kenny and the Wardlaw Scottish Dance Band', 'Kenny Thomson', 'Kenny Thomson and the Wardlaw Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3020, NULL, '2012-01-20 12:54:15.17972+00', 'Finlayson, Colin and his Scottish Dance Band', 'Colin Finlayson', 'Colin Finlayson and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3021, NULL, '2012-01-20 12:54:15.18225+00', 'Fiddlers Three Plus Two', 'Fiddlers Three Plus Two', 'Fiddlers Three Plus Two', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3425, NULL, '2012-01-20 12:54:16.218633+00', 'Horrell, John', '', 'John Horrell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2927, NULL, '2015-03-14 18:11:25.000305+00', 'Shaw, Catherine', '', 'Catherine Shaw', 'Ontario', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2977, NULL, '2015-03-14 18:11:29.256478+00', 'Wiesler, Dave', '', 'Dave Wiesler', '', 'davewiesler@earthlink.net', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2978, NULL, '2015-04-23 09:39:05.262279+00', 'Cameron, James M', '', 'James M Cameron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3006, NULL, '2016-03-17 00:56:07.502419+00', 'Cunningham, David and his Scottish Dance Band', 'David Cunningham', 'David Cunningham and his Scottish Dance Band', '', '', 0, 1, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2983, NULL, '2017-01-13 01:05:58.102686+00', 'McClure, Peter', '', 'Peter McClure', 'Winnipeg, Canada', 'john.mcclure@umr.umanitoba.ca', 1, 0, 0, 0, NULL, 0, 0, NULL, 'New e-address 12 Jan 2017');
INSERT INTO 'person' VALUES (2992, NULL, '2017-02-23 00:15:52.360764+00', 'Ferguson, Joan & Hugh', '', 'Joan & Hugh Ferguson', 'Bristol UK', 'handjferguson@beeb.net', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3007, NULL, '2012-01-20 12:54:15.146719+00', 'Holmes, Ian and his Scottish Dance Band with Ian Powrie', 'Ian Holmes', 'Ian Holmes and his Scottish Dance Band with Ian Powrie', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3022, NULL, '2012-01-20 12:54:15.18478+00', 'Wood, Alastair and his Scottish Dance Band', 'Alastair Wood', 'Alastair Wood and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3008, NULL, '2012-01-20 12:54:15.149261+00', 'MacPhail, Iain and his Scottish Dance Band', 'Iain McPhail', 'Iain MacPhail and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3023, NULL, '2012-01-20 12:54:15.187315+00', 'Dewar, Colin and his Scottish Dance Band', 'Colin Dewar', 'Colin Dewar and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3024, NULL, '2012-01-20 12:54:15.18987+00', 'Olympians Scottish Dance Band', 'Olympians', 'Olympians Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (453, NULL, '2018-04-03 09:04:19.521007+00', 'Rutherford, David', 'Rutherford', 'David Rutherford', '', '', 1, 1, 1, 0, NULL, 0, 0, NULL, 'Though often denoted as just "Rutherford", the RSCDS publication "Scottish Country Dances Books 13 to 18" states Rutherford''s full given name as David.');
INSERT INTO 'person' VALUES (3010, NULL, '2012-01-20 12:54:15.154334+00', 'Shand, Jimmy and his Band', 'Jimmy Shand', 'Jimmy Shand and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3011, NULL, '2012-01-20 12:54:15.15691+00', 'Barron, Neil and his Scottish Dance Band', 'Neil Barron', 'Neil Barron and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3026, NULL, '2012-01-20 12:54:15.194935+00', 'Gordon, Rob and his Band', 'Rob Gordon', 'Rob Gordon and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3027, NULL, '2012-01-20 12:54:15.197454+00', 'Windermere SCD Club', '', 'Windermere SCD Club', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3028, NULL, '2012-01-20 12:54:15.199972+00', 'Kerr, Ron Quintet', 'Ron Kerr', 'Ron Kerr Quintet', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3041, NULL, '2012-01-20 12:54:15.232852+00', 'Danelaw Country Dance Band, The', 'Danelaw Band', 'The Danelaw Country Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3042, NULL, '2012-01-20 12:54:15.235391+00', 'Rankine, Andrew and his Band', 'Andrew Rankine', 'Andrew Rankine and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3029, NULL, '2012-01-20 12:54:15.20249+00', 'Tain Band, The', 'Tain Band', 'The Tain Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3030, NULL, '2012-01-20 12:54:15.205028+00', 'Music Makars, The', 'Music Makars', 'The Music Makars', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3044, NULL, '2012-01-20 12:54:15.24044+00', 'Gonnella, Ron Quartet, The', 'Ron Gonnella', 'The Ron Gonnella Quartet', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11676, '2018-08-09 22:27:54.197176+00', '2018-08-09 22:27:54.197176+00', 'Böttcher, Colin', '', 'Colin Böttcher', 'Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3031, NULL, '2012-01-20 12:54:15.20756+00', 'Wilson, T', '', 'T Wilson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3046, NULL, '2012-01-20 12:54:15.245512+00', 'Dewar, Colin Quartet, The', 'Colin Dewar', 'The Colin Dewar Quartet', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3032, NULL, '2012-01-20 12:54:15.210074+00', 'Adamson, The Deirdre A. Quartet', 'Deirdre Adamson', 'The Deirdre Adamson Quartet', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3047, NULL, '2012-01-20 12:54:15.248048+00', 'Carfuffle Ceilidh Band, The', 'Carfuffle Ceilidh Band', 'The Carfuffle Ceilidh Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3048, NULL, '2012-01-20 12:54:15.250571+00', 'Fiddlesticks & Ivory', 'Fiddlesticks & Ivory', 'Fiddlesticks & Ivory', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3033, NULL, '2012-01-20 12:54:15.212599+00', 'Low, Bill', '', 'Bill Low', 'Ottawa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3050, NULL, '2012-01-20 12:54:15.255755+00', 'Shand, Gordon and his Scottish Dance Band', 'Gordon Shand', 'Gordon Shand and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3052, NULL, '2012-01-20 12:54:15.260877+00', 'MacDonald, Fergie', 'Fergie MacDonald', 'Fergie MacDonald', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3035, NULL, '2012-01-20 12:54:15.21766+00', 'Robertson, David', '', 'David Robertson', 'Ottawa', 'dmr@magma.ca', 1, 0, 0, 0, NULL, 1939, 0, NULL, '');
INSERT INTO 'person' VALUES (3053, NULL, '2012-01-20 12:54:15.263445+00', 'Keith, Lex', 'Lex Keith', 'Lex Keith', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3036, NULL, '2012-01-20 12:54:15.220209+00', 'Gardiner, Alan and his Scottish Dance Band', 'Alan Gardiner', 'Alan Gardiner and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3037, NULL, '2012-01-20 12:54:15.222731+00', 'Johnstone, Jim and his Band', 'Jim Johnstone', 'Jim Johnstone and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3038, NULL, '2012-01-20 12:54:15.225262+00', 'Hunter, Alastair & the Lorne Scottish Dance Band', 'Alastair Hunter', 'Alastair Hunter & the Lorne Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11677, '2018-08-21 10:07:23.200408+00', '2018-08-21 23:56:06.086998+00', 'Chardon du Dauphine, Le', 'Chardon du Dauphine', 'Le Chardon du Dauphine', 'Grenoble, France', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3054, NULL, '2012-01-20 12:54:15.265973+00', 'Carmichael, John', 'John Carmichael', 'John Carmichael', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3055, NULL, '2012-01-20 12:54:15.268501+00', 'Wilson, Callum and his Scottish Dance Band', 'Callum Wilson', 'Callum Wilson and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3056, NULL, '2012-01-20 12:54:15.271033+00', 'Ellis, John and his Highland Country Band', 'John Ellis', 'John Ellis and his Highland Country Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3068, NULL, '2012-01-20 12:54:15.301944+00', 'Cavendish Dance Band, The', 'Cavendish', 'The Cavendish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3069, NULL, '2012-01-20 12:54:15.30449+00', 'Ross, Lindsay & his Scottish Dance Band', 'Lindsay Ross', 'Lindsay Ross & his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3057, NULL, '2012-01-20 12:54:15.273561+00', 'Glendaruel Scottish Dance Band, The', 'Glendaruel', 'The Glendaruel Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3071, NULL, '2012-01-20 12:54:15.309576+00', 'McCallum, Craig''s Scottish Dance Band', 'Craig McCallum', 'Craig McCallum''s Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3072, NULL, '2012-01-20 12:54:15.31213+00', 'Pipers and Drummers from The Royal Scots Regiment', 'Royal Scots', 'Pipers and Drummers from The Royal Scots Regiment', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3059, NULL, '2012-01-20 12:54:15.278905+00', 'Campbell, Colin and his Highland Band', 'Colin Campbell', 'Colin Campbell and his Highland Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3074, NULL, '2012-01-20 12:54:15.314691+00', 'Gullikson, Joy', '', 'Joy Gullikson', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3060, NULL, '2012-01-20 12:54:15.281618+00', 'Slater, Ian', 'Ian Slater', 'Ian Slater', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3043, NULL, '2019-11-22 19:38:14.634684+00', 'Finnegan, Brian', '', 'Brian Finnegan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3075, NULL, '2012-01-20 12:54:15.317238+00', 'Grundtner, Daniel', '', 'Daniel Grundtner', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3076, NULL, '2012-01-20 12:54:15.319772+00', 'Rehm, Kelly', '', 'Kelly Rehm', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3061, NULL, '2012-01-20 12:54:15.28417+00', 'Shand, Jimmy Jnr. and his Band', 'Jimmy Shand Jnr.', 'Jimmy Shand Jnr. and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3062, NULL, '2012-01-20 12:54:15.286709+00', 'Glenlomond Scottish Band', 'Glenlomond', 'Glenlomond Scottish Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3078, NULL, '2012-01-20 12:54:15.324815+00', 'Schladweiler, Mary Kay', '', 'Mary Kay Schladweiler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3079, NULL, '2012-01-20 12:54:15.32734+00', 'Husting, Mike', '', 'Mike Husting', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3063, NULL, '2012-01-20 12:54:15.289245+00', 'Wick Scottish Dance Band, The', 'Wick', 'The Wick Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3080, NULL, '2012-01-20 12:54:15.329863+00', 'DeLuka, Heather', '', 'Heather DeLuka', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3064, NULL, '2012-01-20 12:54:15.291808+00', 'Houliston, Max and his Scottish Band', 'Max Houliston', 'Max Houliston and his Scottish Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3070, NULL, '2015-03-14 18:11:21.623954+00', 'Powrie, Ian / Crowe, Bobby', 'Ian Powrie / Bobby Crowe', 'Ian Powrie & Bobby Crowe', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3081, NULL, '2012-01-20 12:54:15.332941+00', 'Grundtner, D; Kurze, D; Perry, J; Schneider, D', '', 'Grundtner, D; Kurze, D; Perry, J; Schneider, D', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3082, NULL, '2012-01-20 12:54:15.3355+00', 'Royal Tunbridge Wells Branch RSCDS', '', 'Royal Tunbridge Wells Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3065, NULL, '2012-01-20 12:54:15.294348+00', 'Cameron, Jim and his Scottish Dance Band', 'Jim Cameron', 'Jim Cameron and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3066, NULL, '2012-01-20 12:54:15.296881+00', 'Rennie, Ewen', '', 'Ewen Rennie', 'Aberdeen', 'mail@renniee.freeserve.co.uk', 1, 0, 0, 0, NULL, 1950, 0, NULL, '');
INSERT INTO 'person' VALUES (3084, NULL, '2012-01-20 12:54:15.340612+00', 'Bishop, Pauline', '', 'Pauline Bishop', 'Tunbridge Wells', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3085, NULL, '2012-01-20 12:54:15.343141+00', 'Simpson, Colin', '', 'Colin Simpson', 'Tunbridge Wells', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3087, NULL, '2012-01-20 12:54:15.348189+00', 'Davoll, Pat', '', 'Pat Davoll', 'Tunbridge Wells', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3102, NULL, '2012-01-20 12:54:15.386469+00', 'New Haven Committee', '', 'New Haven Committee', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3088, NULL, '2012-01-20 12:54:15.350715+00', 'Leech, Patricia', '', 'Patricia Leech', 'Tunbridge Wells', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3103, NULL, '2012-01-20 12:54:15.389007+00', 'Hof, Mardene', '', 'Mardene Hof', 'New Haven, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3089, NULL, '2012-01-20 12:54:15.353246+00', 'Campbell, Angela', '', 'Angela Campbell', 'Tunbridge Wells', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3104, NULL, '2012-01-20 12:54:15.391621+00', 'Blin, Vincent', '', 'Vincent Blin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3105, NULL, '2012-01-20 12:54:15.394147+00', 'Blackie, Bob', '', 'Bob Blackie', '', '', 1, 0, 0, 0, NULL, 1936, 1998, NULL, '');
INSERT INTO 'person' VALUES (3090, NULL, '2012-01-20 12:54:15.355774+00', 'Wood, Hazel', '', 'Hazel Wood', 'Tunbridge Wells', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3106, NULL, '2012-01-20 12:54:15.396671+00', 'Nimmo', '', 'Nimmo', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3091, NULL, '2012-01-20 12:54:15.358297+00', 'Finlay, Georgina', '', 'Georgina Finlay', 'Toronto, Canada', 'georginafinlay@sympatico.ca', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3107, NULL, '2012-01-20 12:54:15.399195+00', 'Conrow, Tim', '', 'Tim Conrow', 'CA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3108, NULL, '2012-01-20 12:54:15.401724+00', 'Petyt, Sue / Gamon, Jane', '', 'Petyt, Sue / Gamon, Jane', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3092, NULL, '2014-03-29 06:00:40.657987+00', 'Imbrie, A/Worland, S/Bentley, M R', 'Imbrie et al', 'Andrew Imbrie/Susan Worland/Michael R Bentley', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3034, NULL, '2014-09-30 00:45:53.626103+00', 'Geddes, Graham and his Scottish Dance Band', 'Graham Geddes', 'Graham Geddes and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3093, NULL, '2012-01-20 12:54:15.363446+00', 'McLean, Sandy', '', 'Sandy McLean', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3094, NULL, '2012-01-20 12:54:15.365978+00', 'Tully, Terry', '', 'Terry Tully', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3135, NULL, '2018-12-07 17:35:26.664472+00', 'van der Kamp, Els', '', 'Els van der Kamp', 'Geldermalsen, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3112, NULL, '2012-01-20 12:54:15.411829+00', 'Marr, Archie', '', 'Archie Marr', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3096, NULL, '2012-01-20 12:54:15.371061+00', 'Jelinek, Andy', '', 'Andy Jelinek', 'Munich, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3113, NULL, '2012-01-20 12:54:15.414345+00', 'Schmid, Cathrine', '', 'Cathrine Schmid', 'Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3097, NULL, '2012-01-20 12:54:15.373591+00', 'Way, Kenneth', '', 'Kenneth Way', 'New Haven, USA', 'k.way@worldnet.att.net', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3098, NULL, '2012-01-20 12:54:15.376128+00', 'Thomson, George', '', 'George Thomson', 'New Haven, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3114, NULL, '2012-01-20 12:54:15.416889+00', 'Columcille', '', 'Columcille', 'London', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3099, NULL, '2012-01-20 12:54:15.378663+00', 'Lavallee-Tente, Karen', '', 'Karen Lavallee-Tente', 'New Haven, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3100, NULL, '2012-01-20 12:54:15.381201+00', 'Anagnostakis, Christopher', '', 'Christopher Anagnostakis', 'New Haven, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3115, NULL, '2012-01-20 12:54:15.419439+00', 'Mitton, Earl', '', 'Earl Mitton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3116, NULL, '2012-01-20 12:54:15.421962+00', 'Morris, Isobel / Lines, Marion', '', 'Morris, Isobel & Lines, Marion', 'Crieff', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3117, NULL, '2012-01-20 12:54:15.42449+00', 'Moore, John', '', 'John Moore', 'Girvan, Ayrshire', 'john@jmoore200.freeserve.co.uk', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3118, NULL, '2012-01-20 12:54:15.427022+00', 'Sims, Maureen', '', 'Maureen Sims', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3119, NULL, '2012-01-20 12:54:15.429548+00', 'Watson, John', '', 'John Watson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3120, NULL, '2012-01-20 12:54:15.432074+00', 'Broekhuizen, Bas', '', 'Bas Broekhuizen', 'Epe, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3122, NULL, '2012-01-20 12:54:15.437318+00', 'Gall, Edith', '', 'Edith Gall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3138, NULL, '2012-01-20 12:54:15.478158+00', 'MacLeod, Peter', '', 'Peter MacLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3123, NULL, '2012-01-20 12:54:15.43985+00', 'Dunbar, Kathleen', '', 'Kathleen Dunbar', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3140, NULL, '2012-01-20 12:54:15.483231+00', 'Brock, Linda', '', 'Linda Brock', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3124, NULL, '2012-01-20 12:54:15.44241+00', 'Jennison, Helen M', '', 'Helen M Jennison', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3125, NULL, '2012-01-20 12:54:15.444943+00', 'Thompson, Joan', '', 'Joan Thompson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3141, NULL, '2012-01-20 12:54:15.485753+00', 'Pottinger, John', '', 'John Pottinger', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3126, NULL, '2012-01-20 12:54:15.447477+00', 'Gooch, Jill', '', 'Jill Gooch', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3127, NULL, '2012-01-20 12:54:15.45001+00', 'Barfoot, Andrea', '', 'Andrea Barfoot', 'Skye', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3144, NULL, '2012-01-20 12:54:15.493535+00', 'Ross, A', '', 'A Ross', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3128, NULL, '2012-01-20 12:54:15.452538+00', 'Baillie, Bill', '', 'Bill Baillie', 'Skye', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3145, NULL, '2012-01-20 12:54:15.496062+00', 'McNeil, B', '', 'B McNeil', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3129, NULL, '2012-01-20 12:54:15.455253+00', 'Duncan, Gordon', '', 'Gordon Duncan', '', '', 0, 0, 1, 0, NULL, 1964, 2005, NULL, '');
INSERT INTO 'person' VALUES (3146, NULL, '2012-01-20 12:54:15.498592+00', 'McCusker, John', '', 'John McCusker', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3147, NULL, '2012-01-20 12:54:15.501115+00', 'Lovell, H G', '', 'H G Lovell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3148, NULL, '2012-01-20 12:54:15.503642+00', 'Dempster, Colin', '', 'Colin Dempster', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3131, NULL, '2012-01-20 12:54:15.460394+00', 'Bromley, Peter', '', 'Peter Bromley', 'Gravesend', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3149, NULL, '2012-01-20 12:54:15.506161+00', 'MacLellan, Colin R', '', 'Colin R MacLellan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3083, NULL, '2021-04-01 21:39:19.743148+00', 'Orr, Eileen', '', 'Eileen Orr', 'Tunbridge Wells', '', 1, 0, 0, 0, NULL, 0, 2020, NULL, '');
INSERT INTO 'person' VALUES (3132, NULL, '2012-01-20 12:54:15.462919+00', 'Young, Jean', '', 'Jean Young', '', 'jean.young@cityu.edu.hk', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3151, NULL, '2012-01-20 12:54:15.511235+00', 'Barron, Myllie', '', 'Myllie Barron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3133, NULL, '2012-01-20 12:54:15.465447+00', 'Hallenbeck', '', 'Hallenbeck', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3153, NULL, '2012-01-20 12:54:15.51629+00', 'Cunnington, Margaret', '', 'Margaret Cunnington', 'Northallerton, England', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3121, NULL, '2017-07-09 10:39:55.263205+00', 'Gillespie, Jonathan W J', '', 'Jonathan W J Gillespie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3143, NULL, '2019-08-31 17:06:23.387985+00', 'Ross, Stuart', '', 'Stuart Ross', 'Sandbach, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Sandbach (Cheshire) Caledonian Society');
INSERT INTO 'person' VALUES (3136, NULL, '2012-01-20 12:54:15.473089+00', 'Richardson, Iain & Phyliss', '', 'Iain and Phyliss Richardson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3154, NULL, '2012-01-20 12:54:15.518815+00', 'Wood, Arthur', '', 'Arthur Wood', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3137, NULL, '2012-01-20 12:54:15.475621+00', 'Copland, Neil and his Scottish Dance Band', 'Neil Copland', 'Neil Copland and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3155, NULL, '2012-01-20 12:54:15.521347+00', 'Nicolson, A', '', 'A Nicolson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3156, NULL, '2012-01-20 12:54:15.523905+00', 'Lennow, C', '', 'C Lennow', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3157, NULL, '2012-01-20 12:54:15.526457+00', 'Ogilvie, D', '', 'D Ogilvie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3158, NULL, '2012-01-20 12:54:15.529006+00', 'Grant, D', '', 'D Grant', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3160, NULL, '2012-01-20 12:54:15.534056+00', 'Kingsley, Beth & Briscoe, Ellie', '', 'Kingsley, Beth & Briscoe, Ellie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3161, NULL, '2012-01-20 12:54:15.536596+00', 'Soul, M', '', 'M Soul', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3134, NULL, '2012-01-20 12:54:15.468002+00', 'Peutherer, Marion', '', 'Marion Peutherer', 'Newcastle', '', 1, 0, 0, 0, 3134, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3188, NULL, '2012-02-10 23:35:58.823638+00', 'Whittle, Ken', '', 'Ken Whittle', 'Boston (Lincolnshire), England', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3177, NULL, '2012-01-20 12:54:15.57736+00', 'Livsey, Catherine', '', 'Catherine Livsey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3162, NULL, '2012-01-20 12:54:15.53927+00', 'Grey, M & Gandy, B', '', 'Grey, M & Gandy, B', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3178, NULL, '2012-01-20 12:54:15.579908+00', 'Rae, Isabel Bert & Kirsty', '', 'Isabel Bert & Kirsty Rae', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3181, NULL, '2012-01-20 12:54:15.587558+00', 'Fletcher, Anne', '', 'Anne Fletcher', 'Adelaide, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3182, NULL, '2012-01-20 12:54:15.590089+00', 'Jones, H', '', 'H Jones', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3166, NULL, '2012-01-20 12:54:15.549455+00', 'Terry, Lesley', '', 'Lesley Terry', 'Bristol', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3184, NULL, '2012-01-20 12:54:15.595351+00', 'Mill, Jeanette', '', 'Jeanette Mill', 'Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3167, NULL, '2012-01-20 12:54:15.552004+00', 'Collins, Peter', '', 'Peter Collins', 'Bristol', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3186, NULL, '2012-01-20 12:54:15.600426+00', 'Philip, Michael', '', 'Michael Philip', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3168, NULL, '2012-01-20 12:54:15.554528+00', 'de Winton, Barbara', '', 'Barbara de Winton', 'Bristol', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3187, NULL, '2012-01-20 12:54:15.602946+00', 'Adams, Richard', '', 'Richard Adams', '', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3169, NULL, '2012-01-20 12:54:15.557077+00', 'Grant, Stuart', '', 'Stuart Grant', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3189, NULL, '2012-01-20 12:54:15.608558+00', 'Davidson, John', '', 'John Davidson', 'Perth', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3170, NULL, '2012-01-20 12:54:15.559645+00', 'Smith, Andrew', '', 'Andrew Smith', 'Bristol', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3190, NULL, '2012-01-20 12:54:15.611181+00', 'Johnstone/Zobel/Wallace/Thomas/Brunken', '', 'Johnstone/Zobel/Wallace/Thomas/Brunken', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3191, NULL, '2012-01-20 12:54:15.613736+00', 'Senyk, George', '', 'George Senyk', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3171, NULL, '2012-01-20 12:54:15.56217+00', 'Drew, Susan', '', 'Susan Drew', 'Bristol', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3173, NULL, '2012-01-20 12:54:15.56724+00', 'Graham, Jan', '', 'Jan Graham', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3174, NULL, '2012-01-20 12:54:15.569764+00', 'Young, M M', '', 'M M Young', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3175, NULL, '2012-01-20 12:54:15.572298+00', 'Brighouse Scottish Country Dancing Club', '', 'Brighouse Scottish Country Dancing Club', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3193, NULL, '2012-01-20 12:54:15.618816+00', 'Findlay, Lorraine', '', 'Lorraine Findlay', 'Adelaide, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3176, NULL, '2012-01-20 12:54:15.574834+00', 'Caldicot, Barbara', '', 'Barbara Caldicot', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3194, NULL, '2012-01-20 12:54:15.621362+00', 'Pastok, Julie', '', 'Julie Pastok', 'Adelaide, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3195, NULL, '2012-01-20 12:54:15.623895+00', 'Read, Graham', '', 'Graham Read', 'Adelaide, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3196, NULL, '2012-01-20 12:54:15.626427+00', 'Buchanan, Andrew', '', 'Andrew Buchanan', 'Adelaide, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3163, NULL, '2012-01-20 12:54:15.541851+00', 'Smith, Donny', '', 'Donny Smith', '', '', 0, 0, 1, 0, 3163, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3212, NULL, '2012-01-20 12:54:15.668405+00', 'Watson, Rosemary', '', 'Rosemary Watson', 'Helensburgh', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3197, NULL, '2012-01-20 12:54:15.628961+00', 'Buchanan, Anne', '', 'Anne Buchanan', 'Adelaide, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3213, NULL, '2012-01-20 12:54:15.670945+00', 'Murray, Helen M', '', 'Helen M Murray', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3214, NULL, '2012-01-20 12:54:15.673477+00', 'King, Lindsay & Caulfield, Emma', '', 'King, Lindsay & Caulfield, Emma', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3215, NULL, '2012-01-20 12:54:15.676023+00', 'Duncan, James', '', 'James Duncan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3341, NULL, '2012-01-20 12:54:15.999658+00', 'Salis, Shari', '', 'Shari Salis', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3216, NULL, '2012-01-20 12:54:15.678564+00', 'Forrest, M', '', 'M Forrest', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3218, NULL, '2012-01-20 12:54:15.683637+00', 'Taylor, R S & Mathieson R', '', 'R S & Mathieson R Taylor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3219, NULL, '2012-01-20 12:54:15.686163+00', 'Bain, Aly', '', 'Aly Bain', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3202, NULL, '2012-01-20 12:54:15.641774+00', 'McLennan, George A', '', 'George A McLennan', 'Edinburgh', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11625, '2018-04-03 10:17:28.802928+00', '2018-04-03 10:17:28.802928+00', 'Button/Whitaker/Beadnell', '', 'Button/Whitaker/Beadnell', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3203, NULL, '2012-01-20 12:54:15.6445+00', 'McMichan, Nicky', '', 'Nicky McMichan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3222, NULL, '2012-01-20 12:54:15.69375+00', 'Sandison, J', '', 'J Sandison', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3223, NULL, '2012-01-20 12:54:15.69647+00', 'McSkimming, Muriel', '', 'Muriel McSkimming', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3205, NULL, '2012-01-20 12:54:15.649585+00', 'Dunnington Browns, The', '', 'The Dunnington Browns', 'York', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3226, NULL, '2012-01-20 12:54:15.704087+00', 'Bain, Sandy', '', 'Sandy Bain', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3206, NULL, '2012-01-20 12:54:15.65212+00', 'Hanson, Michael', '', 'Michael Hanson', 'Seattle, WA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3110, NULL, '2020-01-15 18:27:46.312616+00', 'Friendly, Brooke & Sackett, Chris', '', 'Brooke Friendly & Chris Sackett', 'Oregon, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3201, NULL, '2020-03-10 11:09:45.665898+00', 'Visscher, Marycke', '', 'Marycke Visscher', '', '', 0, 0, 1, 0, NULL, 1934, 2020, NULL, '');
INSERT INTO 'person' VALUES (3139, NULL, '2021-03-23 00:57:03.214288+00', 'Scottish Measure', 'Scottish Measure', 'Scottish Measure', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3185, NULL, '2020-05-08 23:56:54.465768+00', 'Murray, Bobby', 'Bobby Murray', 'Bobby Murray', 'Florida', '', 1, 1, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3164, NULL, '2021-08-22 04:02:21.294222+00', 'Bristol Branch RSCDS', '', 'Bristol Branch RSCDS', 'Bristol, UK', '', 0, 1, 0, 0, NULL, 1962, 0, NULL, '');
INSERT INTO 'person' VALUES (3224, NULL, '2021-09-10 08:19:14.889754+00', 'Christie, Lyn', '', 'Lyn Christie', 'New Zealand but formerly Pretoria, South Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3172, NULL, '2015-03-14 18:10:59.013115+00', 'Andrews, John', '', 'John Andrews', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3183, NULL, '2015-03-14 18:11:27.572512+00', 'Thorn, Anne', '', 'Anne Thorn', 'Helensburgh', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3220, NULL, '2015-03-25 00:56:02.787421+00', 'Anderson, Marian', '', 'Marian Anderson', '', '', 0, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3217, NULL, '2015-03-25 00:56:02.852805+00', 'Anderson, Marian and her Band', 'Marian Anderson', 'Marian Anderson and her Band', '', '', 0, 1, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3130, NULL, '2016-03-19 12:23:42.691705+00', 'Garrett, Marion', '', 'Marion Garrett', 'Newcastle', '', 1, 0, 0, 0, 3134, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3204, NULL, '2016-09-16 19:15:04.349593+00', 'Wood, Richard', '', 'Richard Wood', 'Colorado, USA', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3199, NULL, '2017-01-03 23:24:31.825135+00', 'Ferguson, Monica', '', 'Monica Ferguson', 'Zeist, Netherlands', 'm.ferguson@antenna.nl', 1, 0, 0, 0, NULL, 1933, 0, NULL, '');
INSERT INTO 'person' VALUES (3198, NULL, '2018-01-17 11:28:45.735026+00', 'Thistle Club, The', '', 'The Thistle Club', 'Eindhoven, Netherlands', '', 0, 1, 0, 0, NULL, 1977, 0, NULL, '');
INSERT INTO 'person' VALUES (3227, NULL, '2012-01-20 12:54:15.706614+00', 'DeMille, George', '', 'George DeMille', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3208, NULL, '2012-01-20 12:54:15.65763+00', 'Pretoria Branch RSCDS', '', 'Pretoria Branch RSCDS', 'Pretoria, South Africa', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3209, NULL, '2012-01-20 12:54:15.660718+00', 'Helensburgh Branch RSCDS', '', 'Helensburgh Branch RSCDS', 'Helensburgh', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3228, NULL, '2012-01-20 12:54:15.709141+00', 'Parsons, Morag', '', 'Morag Parsons', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3210, NULL, '2012-01-20 12:54:15.663321+00', 'Rose, Peggy', '', 'Peggy Rose', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3229, NULL, '2012-01-20 12:54:15.71167+00', 'MacLennan, Noreen', '', 'Noreen MacLennan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3230, NULL, '2012-01-20 12:54:15.714199+00', 'Oakley, Karen', '', 'Karen Oakley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3231, NULL, '2012-01-20 12:54:15.71672+00', 'McKay, Donald', '', 'Donald McKay', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3232, NULL, '2012-01-20 12:54:15.719247+00', 'Bryan, Tara', '', 'Tara Bryan', 'Newfoundland', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3246, NULL, '2012-01-20 12:54:15.75507+00', 'Darlington Children''s Class', '', 'Darlington Children''s Class', '', '', 1, 0, 0, 0, NULL, 1991, 0, NULL, '');
INSERT INTO 'person' VALUES (3233, NULL, '2012-01-20 12:54:15.721767+00', 'Major, Seth & McCullough, Sarah', '', 'Major, Seth & McCullough, Sarah', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3247, NULL, '2012-01-20 12:54:15.757608+00', 'Thompson, Samantha', '', 'Samantha Thompson', 'Leeds', '', 1, 0, 0, 0, NULL, 1991, 0, NULL, '');
INSERT INTO 'person' VALUES (3248, NULL, '2012-01-20 12:54:15.760139+00', 'Gray, Don', '', 'Don Gray', '', '', 0, 0, 1, 0, NULL, 1991, 0, NULL, '');
INSERT INTO 'person' VALUES (3234, NULL, '2012-01-20 12:54:15.72431+00', 'Norwood, M', '', 'M Norwood', 'Leeds', '', 1, 0, 0, 0, NULL, 1991, 0, NULL, '');
INSERT INTO 'person' VALUES (3249, NULL, '2012-01-20 12:54:15.762688+00', 'Tripp, Jan', '', 'Jan Tripp', '', '', 1, 0, 0, 0, NULL, 1991, 0, NULL, '');
INSERT INTO 'person' VALUES (3235, NULL, '2012-01-20 12:54:15.726839+00', 'Holmes, Greta & Anna', '', 'Greta & Anna Holmes', 'Leeds', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3250, NULL, '2012-01-20 12:54:15.765221+00', 'Fryer, Jean', '', 'Jean Fryer', 'Pretoria, South Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3251, NULL, '2012-01-20 12:54:15.767749+00', 'Bergh, Ina', '', 'Ina Bergh', 'Pretoria, South Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3236, NULL, '2012-01-20 12:54:15.729365+00', 'Bailey, Rachel', '', 'Rachel Bailey', 'Leeds', '', 1, 0, 0, 0, NULL, 1989, 0, NULL, '');
INSERT INTO 'person' VALUES (3252, NULL, '2012-01-20 12:54:15.770279+00', 'Harris, Neill', '', 'Neill Harris', 'Pretoria, South Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3192, NULL, '2014-05-25 08:39:46.247702+00', 'Dawson, Peter', '', 'Peter Dawson', 'Peterborough, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3237, NULL, '2012-01-20 12:54:15.731891+00', 'Doubleday, Rachel', '', 'Rachel Doubleday', 'Leeds', '', 1, 0, 0, 0, NULL, 1989, 0, NULL, '');
INSERT INTO 'person' VALUES (3253, NULL, '2012-01-20 12:54:15.77281+00', 'Dinsdale, Dick', '', 'Dick Dinsdale', 'Pretoria, South Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3254, NULL, '2012-01-20 12:54:15.775345+00', 'Harris, Terry Lynne', '', 'Terry Lynne Harris', 'Pretoria, South Africa', 'HARRITL@unisa.ac.za', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3238, NULL, '2012-01-20 12:54:15.734411+00', 'Wilson, Helen', '', 'Helen Wilson', 'Leeds', '', 1, 0, 0, 0, NULL, 1991, 0, NULL, '');
INSERT INTO 'person' VALUES (3255, NULL, '2012-01-20 12:54:15.777871+00', 'Fourie, Elsie', '', 'Elsie Fourie', 'Pretoria, South Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3239, NULL, '2012-01-20 12:54:15.736975+00', 'Boughen, Jenny', '', 'Jenny Boughen', 'Leeds', '', 1, 0, 0, 0, NULL, 1991, 0, NULL, '');
INSERT INTO 'person' VALUES (3256, NULL, '2012-01-20 12:54:15.780407+00', 'Naylor, Anne', '', 'Anne Naylor', 'Pretoria, South Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3257, NULL, '2012-01-20 12:54:15.782934+00', 'Saint Andrews (Mordialloc) SCD Group', '', 'Saint Andrews (Mordialloc) SCD Group', 'Melbourne, Australia', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3240, NULL, '2012-01-20 12:54:15.739521+00', 'Lamb, James', '', 'James Lamb', 'Leeds', '', 1, 0, 0, 0, NULL, 1991, 0, NULL, '');
INSERT INTO 'person' VALUES (3258, NULL, '2012-01-20 12:54:15.785464+00', 'Canterbury Region NZ Branch RSCDS', '', 'Canterbury Region NZ Branch RSCDS', 'New Zealand', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3241, NULL, '2012-01-20 12:54:15.742048+00', 'Binks, Rachel & Sams, Filly May', '', 'Rachel Binks & Filly May Sams', 'Leeds', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3259, NULL, '2012-01-20 12:54:15.788004+00', 'Clyne, Pam', '', 'Pam Clyne', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3242, NULL, '2012-01-20 12:54:15.744589+00', 'Norwood, Rachel', '', 'Rachel Norwood', 'Leeds', '', 1, 0, 0, 0, NULL, 1991, 0, NULL, '');
INSERT INTO 'person' VALUES (3243, NULL, '2012-01-20 12:54:15.747353+00', 'Edlington School, Senior Group', '', 'Senior Group Ellington School', '', '', 1, 0, 0, 0, NULL, 1991, 0, NULL, '');
INSERT INTO 'person' VALUES (3244, NULL, '2012-01-20 12:54:15.749954+00', 'Ross, Stephanie', '', 'Stephanie Ross', 'Leeds', '', 1, 0, 0, 0, NULL, 1991, 0, NULL, '');
INSERT INTO 'person' VALUES (686, NULL, '2018-04-04 16:13:10.041318+00', 'Boyd, Angus', '', 'Angus Boyd', '', '', 1, 0, 0, 0, NULL, 0, 2018, NULL, '');
INSERT INTO 'person' VALUES (3245, NULL, '2012-01-20 12:54:15.752495+00', 'Edlington School, Class 8', '', 'Class 8 Edlington School', '', '', 1, 0, 0, 0, NULL, 1991, 0, NULL, '');
INSERT INTO 'person' VALUES (3262, NULL, '2012-01-20 12:54:15.795593+00', 'Wallis, Coreen', '', 'Coreen Wallis', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3263, NULL, '2012-01-20 12:54:15.798134+00', 'Makinson, Maurice', '', 'Maurice Makinson', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3264, NULL, '2012-01-20 12:54:15.800874+00', 'Ward, Irene', '', 'Irene Ward', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3265, NULL, '2012-01-20 12:54:15.803423+00', 'Walker, Helen', '', 'Helen Walker', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3281, NULL, '2012-01-20 12:54:15.844063+00', 'Scott, Lisa', '', 'Lisa Scott', 'USA', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3266, NULL, '2012-01-20 12:54:15.805949+00', 'Collingwood, Alison', '', 'Alison Collingwood', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3267, NULL, '2012-01-20 12:54:15.808514+00', 'Ramsay, Doreen', '', 'Doreen Ramsay', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3283, NULL, '2012-01-20 12:54:15.849178+00', 'Cass, Peter & Peutherer, Marion', '', 'Peter Cass / Marion Peutherer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3284, NULL, '2012-01-20 12:54:15.851877+00', 'Pringle, Rebecca', '', 'Rebecca Pringle', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3268, NULL, '2012-01-20 12:54:15.811068+00', 'Jenkinson, Douglas', '', 'Douglas Jenkinson', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3285, NULL, '2012-01-20 12:54:15.856467+00', 'Builth Wells', '', 'Builth Wells', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3269, NULL, '2012-01-20 12:54:15.813608+00', 'Leith, Julie', '', 'Julie Leith', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3286, NULL, '2012-01-20 12:54:15.859083+00', 'Smith, Alison', '', 'Alison Smith', '', 'inchgower@talk21.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3287, NULL, '2012-01-20 12:54:15.861614+00', 'Herbert, Dorothy', '', 'Dorothy Herbert', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3270, NULL, '2012-01-20 12:54:15.816143+00', 'Macleod, Laura', '', 'Laura Macleod', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3288, NULL, '2012-01-20 12:54:15.864207+00', 'Gaudie, John', '', 'John Gaudie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3271, NULL, '2012-01-20 12:54:15.818727+00', 'Flanagan, Maisie', '', 'Maisie Flanagan', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3289, NULL, '2012-01-20 12:54:15.866749+00', 'Johnston, Emma', '', 'Emma Johnston', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3290, NULL, '2012-01-20 12:54:15.869292+00', 'Johnston, Jeanna', '', 'Jeanna Johnston', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3272, NULL, '2012-01-20 12:54:15.82126+00', 'Idour, Jan', '', 'Jan Idour', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3291, NULL, '2012-01-20 12:54:15.872524+00', 'Crook, Roger', '', 'Roger Crook', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3422, NULL, '2012-01-20 12:54:16.21091+00', 'Idzik, Helen', '', 'Helen Idzik', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3273, NULL, '2012-01-20 12:54:15.823808+00', 'Mackle, Les', '', 'Les Mackle', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3292, NULL, '2012-01-20 12:54:15.875177+00', 'Campbell, Neil', '', 'Neil Campbell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3293, NULL, '2012-01-20 12:54:15.877714+00', 'Mackenzie, Louise', '', 'Louise Mackenzie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3294, NULL, '2012-01-20 12:54:15.88025+00', 'Mathers, Sandy', '', 'Sandy Mathers', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3295, NULL, '2012-01-20 12:54:15.882779+00', 'Stewart, Jack', '', 'Jack Stewart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3275, NULL, '2012-01-20 12:54:15.828856+00', 'Otago Region, NZ Branch RSCDS', '', 'NZ Branch RSCDS Otago Region', 'New Zealand', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3296, NULL, '2012-01-20 12:54:15.885312+00', 'MacLeod, Donald', '', 'Donald MacLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3276, NULL, '2012-01-20 12:54:15.83141+00', 'Allely, Susan', '', 'Susan Allely', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10156, NULL, '2012-01-20 12:54:18.00228+00', 'Monroe', '', 'Monroe', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3260, NULL, '2016-05-15 20:09:00.287377+00', 'Carruthers, Anne', '', 'Anne Carruthers', 'Christchurch, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Member of Hoon Hay SCDC');
INSERT INTO 'person' VALUES (3274, NULL, '2016-09-14 22:59:12.289433+00', 'Taylor, Ruth (N.Z.)', '', 'Ruth Taylor (N.Z.)', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3297, NULL, '2012-01-20 12:54:15.887864+00', 'Stickle, Fredamann', '', 'Fredamann Stickle', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3298, NULL, '2012-01-20 12:54:15.890392+00', 'Lawson, Gordon', '', 'Gordon Lawson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3278, NULL, '2012-01-20 12:54:15.836457+00', 'Abbott, Morag', '', 'Morag Abbott', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3279, NULL, '2012-01-20 12:54:15.838987+00', 'Walker, Kirstyn', '', 'Kirstyn Walker', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3299, NULL, '2012-01-20 12:54:15.89292+00', 'Driver, Fiona', '', 'Fiona Driver', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3280, NULL, '2012-01-20 12:54:15.841527+00', 'Black, John S', '', 'John S Black', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3300, NULL, '2012-01-20 12:54:15.895466+00', 'Martin, John', '', 'John Martin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3301, NULL, '2012-01-20 12:54:15.897992+00', 'Mathieson, A', '', 'A Mathieson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3302, NULL, '2012-01-20 12:54:15.900521+00', 'MacRae, Farquhar', '', 'Farquhar MacRae', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3303, NULL, '2012-01-20 12:54:15.903212+00', 'Stout, Chris', '', 'Chris Stout', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3319, NULL, '2012-01-20 12:54:15.943847+00', 'Morgan-Smith, Caroline', '', 'Caroline Morgan-Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3304, NULL, '2012-01-20 12:54:15.90584+00', 'Miller', '', 'Miller', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3320, NULL, '2012-01-20 12:54:15.946413+00', 'MacInnes, Ian', 'Ian MacInnes', 'Ian MacInnes', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3305, NULL, '2012-01-20 12:54:15.908392+00', 'MacGregor, Bruce', '', 'Bruce MacGregor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3321, NULL, '2012-01-20 12:54:15.948949+00', 'National Youth Orchestra of Scotland', 'NYOS', 'National Youth Orchestra of Scotland', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3322, NULL, '2012-01-20 12:54:15.951489+00', 'McPherson, Gordon', '', 'Gordon McPherson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3306, NULL, '2012-01-20 12:54:15.910933+00', 'Marwick, Gavin', '', 'Gavin Marwick', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3307, NULL, '2012-01-20 12:54:15.913467+00', 'Gorrie, John', '', 'John Gorrie', '', 'john@johnandrita.icom43.net', 1, 1, 0, 0, NULL, 1932, 0, NULL, '');
INSERT INTO 'person' VALUES (3324, NULL, '2012-01-20 12:54:15.956561+00', 'Campbell, Jack R', '', 'Jack R Campbell', 'Germany', '', 1, 0, 0, 0, NULL, 1945, 2002, NULL, '');
INSERT INTO 'person' VALUES (3309, NULL, '2012-01-20 12:54:15.91854+00', 'Davidson, Bob', '', 'Bob Davidson', '', 'Piobbeag@aol.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3326, NULL, '2012-01-20 12:54:15.961612+00', 'MacGregor, Flora', '', 'Flora MacGregor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3310, NULL, '2012-01-20 12:54:15.921077+00', 'Murray / McKenna / Mwenifumbo', '', 'Murray, McKenna, Mwenifumbo', 'Ottawa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3311, NULL, '2012-01-20 12:54:15.92362+00', 'Rankine / MacPhail / Dixon', '', 'Rankine / MacPhail / Dixon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3329, NULL, '2012-01-20 12:54:15.96919+00', 'Johnston, Robert', '', 'Robert Johnston', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3330, NULL, '2012-01-20 12:54:15.971723+00', 'RSCDS and RSGS', '', 'RSCDS and RSGS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3312, NULL, '2012-01-20 12:54:15.926149+00', 'Jamieson, Ian', '', 'Ian Jamieson', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3331, NULL, '2012-01-20 12:54:15.974243+00', 'Berkhamsted Strathspey and Reel Club', '', 'Berkhamsted Strathspey and Reel Club', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3313, NULL, '2012-01-20 12:54:15.928677+00', 'ISCA dancers', '', 'ISCA dancers', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3332, NULL, '2012-01-20 12:54:15.976772+00', 'Shand, Peter', '', 'Peter Shand', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3314, NULL, '2012-01-20 12:54:15.931202+00', 'Pickering, Graham & Josephine', '', 'Graham & Josephine Pickering', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3333, NULL, '2012-01-20 12:54:15.979297+00', 'Powell, Helen', '', 'Helen Powell', 'USA', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3315, NULL, '2012-01-20 12:54:15.933725+00', 'Summerwell, Ursula', '', 'Ursula Summerwell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3317, NULL, '2012-01-20 12:54:15.938785+00', 'Martin, Brian', '', 'Brian Martin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3336, NULL, '2012-01-20 12:54:15.986923+00', 'Prost, Céline', '', 'Céline Prost', 'Lyons, France', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3338, NULL, '2012-01-20 12:54:15.991992+00', 'Gélinier, Dinah', '', 'Dinah Gélinier', 'Lyons, France', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3354, NULL, '2012-01-20 12:54:16.032628+00', 'Gee, Aline', '', 'Aline Gee', 'Auckland, NZ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3356, NULL, '2012-01-20 12:54:16.0377+00', 'Mackay, Rob Donn', '', 'Rob Donn Mackay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3357, NULL, '2012-01-20 12:54:16.040239+00', 'Tuffery, Joan', '', 'Joan Tuffery', 'Invercargill, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3358, NULL, '2012-01-20 12:54:16.042775+00', 'Foster, John', '', 'John Foster', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3360, NULL, '2012-01-20 12:54:16.047986+00', 'McQuire, W', '', 'W McQuire', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3361, NULL, '2012-01-20 12:54:16.050521+00', 'MacAndrew, H', '', 'H MacAndrew', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3344, NULL, '2012-01-20 12:54:16.007247+00', 'Merriman, Trina', '', 'Trina Merriman', 'CA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3362, NULL, '2012-01-20 12:54:16.05305+00', 'Lees, I', '', 'I Lees', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11624, '2018-04-03 09:17:45.648923+00', '2018-04-03 23:56:06.954158+00', 'Dale (18C)', '', 'Dale (18C)', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, 'The RSCDS publication states "Dale''s Collection of Reels and Dances c. 1799" as a source of dances.');
INSERT INTO 'person' VALUES (3363, NULL, '2012-01-20 12:54:16.055738+00', 'Moore, Thomas', '', 'Thomas Moore', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3364, NULL, '2012-01-20 12:54:16.058298+00', 'Offenbach, Jacques', '', 'Jacques Offenbach', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3346, NULL, '2012-01-20 12:54:16.012312+00', 'McNab, J', '', 'J McNab', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3365, NULL, '2012-01-20 12:54:16.06084+00', 'Gruber, Edmund', '', 'Edmund Gruber', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3366, NULL, '2012-01-20 12:54:16.06337+00', 'Cohan, George M', '', 'George M Cohan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3347, NULL, '2012-01-20 12:54:16.014837+00', 'Robertson, Anne M', '', 'Anne M Robertson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3367, NULL, '2012-01-20 12:54:16.065896+00', 'Miller, Ian', '', 'Ian Miller', '', 'imiller@leight-heigel.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3348, NULL, '2012-01-20 12:54:16.01736+00', 'Adams, Alan', '', 'Alan Adams', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (465, NULL, '2018-04-03 23:56:11.033401+00', 'Harbour, Jacob', '', 'Jacob Harbour', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Though often denoted as just "J Harbour", the RSCDS publication "Scottish Country Dances Books 13 to 18" states Harbour''s full given name as Jacob.');
INSERT INTO 'person' VALUES (3335, NULL, '2018-10-29 23:51:13.1727+00', 'Vernay, Pierre', '', 'Pierre Vernay', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3350, NULL, '2012-01-20 12:54:16.022415+00', 'Miller, Jennie', '', 'Jennie Miller', 'Auckland, NZ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3351, NULL, '2012-01-20 12:54:16.024954+00', 'Miles, Dorothy & Connell, Janet', '', 'Miles, Dorothy & Connell, Janet', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3318, NULL, '2021-01-11 12:43:55.05078+00', 'Prone, Sarah', '', 'Sarah Prone', 'Bridport, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Now Sarah Prone Ashby.');
INSERT INTO 'person' VALUES (3337, NULL, '2021-02-01 16:50:45.639163+00', 'Sarran, Diana', '', 'Diana Sarran', 'Lyon, France', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3352, NULL, '2012-01-20 12:54:16.027487+00', 'Hornby, Gloria', '', 'Gloria Hornby', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3339, NULL, '2017-09-24 15:01:14.819481+00', 'Fairbairn, James & Scott, Stewart', '', 'Fairbairn, James & Scott, Stewart', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3369, NULL, '2015-03-14 18:11:14.311812+00', 'Lindsey, Gary', '', 'Gary Lindsey', 'OH, USA', 'Gary.lindsey@sbcglobal.net', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3277, NULL, '2015-09-22 13:35:11.169012+00', 'Stewart, Melissa / Gertz, Linda and Don', '', 'Melissa Stewart & Linda and Don Gertz ', 'Oregon, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3316, NULL, '2017-12-01 16:21:56.042412+00', 'Beeson, Pauline', '', 'Pauline Beeson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3340, NULL, '2019-05-13 23:56:08.352446+00', 'Dunsmuir Scottish Dancers', '', 'Dunsmuir Scottish Dancers', 'CA, USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3353, NULL, '2012-01-20 12:54:16.030047+00', 'Greenwood, Helen & Pollard, Chris', '', 'Greenwood, Helen & Pollard, Chris', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3373, NULL, '2012-01-20 12:54:16.081133+00', 'Dornbusch, Tina', '', 'Tina Dornbusch', 'Boston, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3308, NULL, '2022-05-01 19:18:53.247155+00', 'Macdonald, Anthea', '', 'Anthea Macdonald', 'Claremont, California, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3343, NULL, '2012-01-20 12:54:16.004714+00', 'Palmer, Melinda R', '', 'Melinda R Palmer', 'CA, USA', '', 1, 0, 0, 0, 10421, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3391, NULL, '2012-01-20 12:54:16.129586+00', 'Taylor-Memmory, Nan', '', 'Nan Taylor-Memmory', 'South Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3392, NULL, '2012-01-20 12:54:16.132418+00', 'Ramsay, Jenny', '', 'Jenny Ramsay', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3393, NULL, '2012-01-20 12:54:16.13545+00', 'Strath Hunter Youth Dancers', '', 'Strath Hunter Youth Dancers', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3394, NULL, '2012-01-20 12:54:16.138445+00', 'Vandegrift, Elinor & David', '', 'Elinor & David Vandegrift', 'Seattle WA  USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3395, NULL, '2012-01-20 12:54:16.141679+00', 'Rueesch, Morven', '', 'Morven Rueesch', 'Basle, Switzerland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3396, NULL, '2012-01-20 12:54:16.144277+00', 'Malton, Roger', '', 'Roger Malton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3397, NULL, '2012-01-20 12:54:16.146817+00', 'Lockhart, Helen', '', 'Helen Lockhart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3398, NULL, '2012-01-20 12:54:16.149339+00', 'Sinclair, Molly', '', 'Molly Sinclair', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3399, NULL, '2012-01-20 12:54:16.151874+00', 'Cassel, Hanneke & Wiesler, Dave', 'Hanneke/Wiesler', 'Hanneke Cassel & Dave Wiesler', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3400, NULL, '2012-01-20 12:54:16.154408+00', 'Vlug, Jack', '', 'Jack Vlug', 'Vancouver', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3401, NULL, '2012-01-20 12:54:16.156949+00', 'Petrie, Dr John', '', 'Dr John Petrie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3402, NULL, '2012-01-20 12:54:16.159496+00', 'Farrelly, Richard', '', 'Richard Farrelly', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3403, NULL, '2012-01-20 12:54:16.162029+00', 'Grosjean, D.B. & Imbrie, A', 'Grosjean/Imbrie', 'D B Grosjean & A Imbrie', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3404, NULL, '2012-01-20 12:54:16.164567+00', 'Gilbert, F', '', 'F Gilbert', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3405, NULL, '2012-01-20 12:54:16.167104+00', 'Leash, Jim', '', 'Jim Leash', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3406, NULL, '2012-01-20 12:54:16.169632+00', 'Forfar Branch Committee', '', 'Forfar Branch Committee', 'Forfar', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3407, NULL, '2012-01-20 12:54:16.172162+00', 'Carlton/Tunbridge', '', 'Carlton/Tunbridge', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3408, NULL, '2012-01-20 12:54:16.174688+00', 'Fragson/Lee/Worton', '', 'Fragson/Lee/Worton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3375, NULL, '2012-01-20 12:54:16.087235+00', 'Oughton, Mary', '', 'Mary Oughton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3376, NULL, '2012-01-20 12:54:16.089773+00', 'Oughton, Keith', '', 'Keith Oughton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3377, NULL, '2012-01-20 12:54:16.092308+00', 'Stevens, Rona', '', 'Rona Stevens', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3378, NULL, '2012-01-20 12:54:16.095126+00', 'Weynberg, Valerie', '', 'Valerie Weynberg', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3379, NULL, '2012-01-20 12:54:16.097792+00', 'Coull, Gary', '', 'Gary Coull', 'Dufftown', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3380, NULL, '2012-01-20 12:54:16.100506+00', 'Smart, E', '', 'E Smart', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3381, NULL, '2012-01-20 12:54:16.103101+00', 'MacLellan, M', '', 'M MacLellan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3385, NULL, '2012-01-20 12:54:16.113375+00', 'MacLellan, N', '', 'N MacLellan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3386, NULL, '2012-01-20 12:54:16.115978+00', 'Wood, Kathleen', '', 'Kathleen Wood', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3387, NULL, '2012-01-20 12:54:16.118724+00', 'Craven, Emily', '', 'Emily Craven', 'South Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3388, NULL, '2012-01-20 12:54:16.121482+00', 'Hewitt, Jane', '', 'Jane Hewitt', 'South Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3389, NULL, '2012-01-20 12:54:16.124251+00', 'Turton, Sandra', '', 'Sandra Turton', 'South Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3390, NULL, '2012-01-20 12:54:16.126914+00', 'Williams, Jennifer', '', 'Jennifer Williams', 'South Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3409, NULL, '2012-01-20 12:54:16.177216+00', 'Belton, Celia & Bob', '', 'Celia & Bob Belton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3410, NULL, '2012-01-20 12:54:16.17975+00', 'Oates, Annabel', '', 'Annabel Oates', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3411, NULL, '2012-01-20 12:54:16.182292+00', 'Raisin, Alison', '', 'Alison Raisin', '', 'AlisonRaisin@aol.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3427, NULL, '2012-01-20 12:54:16.223958+00', 'Pryce, Nancy Scott', '', 'Nancy Scott Pryce', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3428, NULL, '2012-01-20 12:54:16.228591+00', 'Horrell, Brenda', '', 'Brenda Horrell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3412, NULL, '2012-01-20 12:54:16.184894+00', 'Robertson, Pam', '', 'Pam Robertson', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3429, NULL, '2012-01-20 12:54:16.231896+00', 'Abdill, Ed', '', 'Ed Abdill', 'New York', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3413, NULL, '2012-01-20 12:54:16.187462+00', 'Borsberry, Nigel', '', 'Nigel Borsberry', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3430, NULL, '2012-01-20 12:54:16.235191+00', 'Horrell, Drew', '', 'Drew Horrell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3414, NULL, '2012-01-20 12:54:16.189987+00', 'Bennett, Catriona', '', 'Catriona Bennett', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3432, NULL, '2012-01-20 12:54:16.241777+00', 'Gray, Bill', '', 'Bill Gray', 'PA, USA', 'whgr@epix.net', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3415, NULL, '2012-01-20 12:54:16.192522+00', 'Wilde, Elaine', '', 'Elaine Wilde', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3433, NULL, '2012-01-20 12:54:16.245092+00', 'Macintyre, Mary', '', 'Mary Macintyre', 'Saint Andrews', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3434, NULL, '2012-01-20 12:54:16.248388+00', 'Bain, Helen & Roy', '', 'Helen & Roy Bain', 'Kilcreggan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3416, NULL, '2012-01-20 12:54:16.195058+00', 'Cashmore, Pauline', '', 'Pauline Cashmore', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3435, NULL, '2012-01-20 12:54:16.251682+00', 'Fordyce, McIlroy, Mitchell', '', 'Fordyce, McIlroy, Mitchell', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3417, NULL, '2012-01-20 12:54:16.197581+00', 'Ferrier, George', '', 'George Ferrier', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3437, NULL, '2012-01-20 12:54:16.258249+00', 'Clark, John', '', 'John Clark', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11678, '2018-08-23 10:07:47.040971+00', '2018-08-23 10:13:54.786756+00', 'Oliver, Brian', '', 'Brian Oliver', 'Cumbria, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2325, NULL, '2018-09-09 09:35:34.504989+00', 'Muirhead, Tom', '', 'Tom Muirhead', '', '', 0, 0, 1, 0, NULL, 1900, 1979, NULL, 'See http://pipetunes.ca/composer/t-muirhead/ for a biography.');
INSERT INTO 'person' VALUES (3440, NULL, '2012-01-20 12:54:16.268126+00', 'Nunley, Trish & Hayward, Laurel', '', 'Nunley/Hayward', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3441, NULL, '2012-01-20 12:54:16.271403+00', 'Stocker, Marilyn', '', 'Marilyn Stocker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3421, NULL, '2012-01-20 12:54:16.208233+00', 'Rankin, John Morris', '', 'John Morris Rankin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3442, NULL, '2012-01-20 12:54:16.27468+00', 'MacLeod, Derek', '', 'Derek MacLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3439, NULL, '2021-01-02 15:46:18.407139+00', 'Fogg, Stella', '', 'Stella Fogg', 'Little Rock, Arkansas, USA', 'stellafogg@outlook.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3328, NULL, '2021-02-18 17:55:02.291283+00', 'Reeve, John', '', 'John Reeve', '', '', 1, 0, 1, 0, NULL, 1931, 2018, NULL, 'A brief outline of John Reeve’s life can be found under Lives Remembered in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/05/Reel-303-electronic.pdf#page=15|The Reel 303>>.');
INSERT INTO 'person' VALUES (3423, NULL, '2012-01-20 12:54:16.213523+00', 'Bindoni, Giorgio', '', 'Giorgio Bindoni', 'New York, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3443, NULL, '2012-01-20 12:54:16.27796+00', 'Ferguson, Jean', '', 'Jean Ferguson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3424, NULL, '2012-01-20 12:54:16.216063+00', 'Pasqua, Mary', '', 'Mary Pasqua', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3438, NULL, '2015-03-14 18:11:08.193051+00', 'Geddes, Graham', '', 'Graham Geddes', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3371, NULL, '2015-03-14 18:11:14.264748+00', 'Lindsay, Patricia', '', 'Patricia Lindsay (Patty)', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3418, NULL, '2017-08-23 21:16:35.197315+00', 'Macfarlane, Peter / Linden, Lilian', 'Macfarlane/Linden', 'Peter Macfarlane / Lilian Linden', '', '', 0, 0, 0, 1, 3749, 0, 0, NULL, 'The collaboration between Peter Macfarlane and Lilian Linden ended when Peter emigrated to Vermont, USA in 2003.');
INSERT INTO 'person' VALUES (3426, NULL, '2012-01-20 12:54:16.221411+00', 'McCullogh, Sara', '', 'Sara McCullogh', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3445, NULL, '2012-01-20 12:54:16.284539+00', 'Frie, Birgit', '', 'Birgit Frie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (411, NULL, '2018-04-14 22:55:18.078549+00', 'West, Eddy', '', 'Eddy West', 'New Zealand', 'edg81169@gmail.com', 1, 1, 0, 0, NULL, 0, 2018, NULL, '37 of Eddy''s dances can be found on his website http://eddywest.nz/



Eddy''s death was announced on Strathspey on 14 April 2018');
INSERT INTO 'person' VALUES (3447, NULL, '2012-01-20 12:54:16.291112+00', 'Metcalf, Walter et al', '', 'Walter et al Metcalf', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3448, NULL, '2012-01-20 12:54:16.294387+00', 'Brown, C', '', 'C Brown', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3457, NULL, '2012-01-20 12:54:16.324167+00', 'Couper, A', '', 'A Couper', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3458, NULL, '2012-01-20 12:54:16.3275+00', 'Schaffer, Greg', '', 'Greg Schaffer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3450, NULL, '2012-01-20 12:54:16.301006+00', 'O''Brien, P', '', 'P O''Brien', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3451, NULL, '2012-01-20 12:54:16.304287+00', 'Reader, R', '', 'R Reader', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3462, NULL, '2012-01-20 12:54:16.34065+00', 'Bulteel, Angela', '', 'Angela Bulteel', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3463, NULL, '2012-01-20 12:54:16.343955+00', 'MacRae, P/M Evan', '', 'PM E MacRae', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3420, NULL, '2013-05-11 16:02:31.516454+00', 'Elmes, Peter and his Band', 'Peter Elmes'' Band', 'Peter Elmes'' Scottish Country Dance Band ', 'New Zealand', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3453, NULL, '2013-09-20 18:17:04.7783+00', 'Roby, John', '', 'John Roby', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3431, NULL, '2014-03-24 09:36:25.106606+00', 'Ferguson, James', 'Fergie', 'James Ferguson', 'New York, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3436, NULL, '2014-11-09 00:09:18.914081+00', 'Smith, Keith B', '', 'Keith B Smith', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3507, NULL, '2019-06-10 23:51:45.074662+00', 'Dreyer, Eva', '', 'Eva Dreyer', 'Essen, Germany', 'EvaDreyer@aol.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3455, NULL, '2012-01-20 12:54:16.317586+00', 'Smith, I', '', 'I Smith', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3466, NULL, '2012-01-20 12:54:16.353851+00', 'Napier, Marie Louise', '', 'Marie Louise Napier', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3456, NULL, '2012-01-20 12:54:16.320877+00', 'Robertson, Lell', '', 'Lell Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3467, NULL, '2012-01-20 12:54:16.357196+00', 'Muir, David', '', 'David Muir', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3468, NULL, '2012-01-20 12:54:16.360488+00', 'Coviello, Natalie', '', 'Natalie Coviello', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3469, NULL, '2012-01-20 12:54:16.363867+00', 'Wallace, Ron & Zadworny, Margaret', '', 'Wallace, Ron & Zadworny, Margaret', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3470, NULL, '2012-01-20 12:54:16.367156+00', 'Morrison, Rory Dall', '', 'Rory Dall Morrison', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3472, NULL, '2012-01-20 12:54:16.373913+00', 'Dickson, Campbell', '', 'Campbell Dickson', 'Forres', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3473, NULL, '2012-01-20 12:54:16.377203+00', 'Stein, Torsten', '', 'Torsten Stein', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3474, NULL, '2012-01-20 12:54:16.380498+00', 'Cummins, Fiona', '', 'Fiona Cummins', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3478, NULL, '2012-01-20 12:54:16.393665+00', 'White, Alan W', '', 'Alan W White', 'St Andrew''s Society, London', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3480, NULL, '2012-01-20 12:54:16.400248+00', 'Bell, Alan', '', 'Alan Bell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3481, NULL, '2012-01-20 12:54:16.403549+00', 'Wilkie, Irene', '', 'Irene Wilkie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3482, NULL, '2012-01-20 12:54:16.406841+00', 'Ferguson, Joan', '', 'Joan Ferguson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3483, NULL, '2012-01-20 12:54:16.410126+00', 'Ramshaw, L / Bentley, S W / Bentley, M', 'Ramshaw/Bentley', 'L Ramshaw / S W Bentley / M Bentley', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3485, NULL, '2012-01-20 12:54:16.416721+00', 'Campbell, Rod', '', 'Rod Campbell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3484, NULL, '2012-01-20 12:54:16.413433+00', 'Bentley, Susan Worland', '', 'Susan Worland Bentley', '', '', 0, 0, 1, 1, 3484, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3501, NULL, '2012-01-20 12:54:16.469417+00', 'Lieber, Dotty', '', 'Dotty Lieber', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3486, NULL, '2012-01-20 12:54:16.420008+00', 'Nasson, William', '', 'William Nasson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3502, NULL, '2012-01-20 12:54:16.472726+00', 'Montes, Julee', '', 'Julee Montes', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3487, NULL, '2012-01-20 12:54:16.423318+00', 'Auckland Dancers', '', 'Auckland Dancers', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3503, NULL, '2012-01-20 12:54:16.476071+00', 'Bourgeois, Patrice', '', 'Patrice Bourgeois', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3504, NULL, '2012-01-20 12:54:16.484252+00', 'Jacobson, Paula', '', 'Paula Jacobson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3488, NULL, '2012-01-20 12:54:16.426612+00', 'Dickson, Richard', '', 'Richard Dickson', 'Auckland, NZ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3505, NULL, '2012-01-20 12:54:16.487764+00', 'Howat, Joseph', '', 'Joseph Howat', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3489, NULL, '2012-01-20 12:54:16.429893+00', 'Sharman, Kerry', '', 'Kerry Sharman', 'Auckland, NZ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3506, NULL, '2012-01-20 12:54:16.491053+00', 'Lubin, Eve', '', 'Eve Lubin', 'CA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3490, NULL, '2012-01-20 12:54:16.433175+00', 'Hudson, Lynne', '', 'Lynne Hudson', 'Auckland, NZ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3508, NULL, '2012-01-20 12:54:16.49768+00', 'McGuire, Gerry', '', 'Gerry McGuire', 'CA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3509, NULL, '2012-01-20 12:54:16.500981+00', 'Williams / Van Alstyne', '', 'Williams / Van Alstyne', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3510, NULL, '2012-01-20 12:54:16.504274+00', 'Chicago Weekend Workshop', '', 'Chicago Weekend Workshop', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3492, NULL, '2012-01-20 12:54:16.439756+00', 'Ross, Charlie', '', 'Charlie Ross', 'Auckland, NZ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3511, NULL, '2012-01-20 12:54:16.507568+00', 'Newfield, Mady', '', 'Mady Newfield', 'Chicago, USA', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3493, NULL, '2012-01-20 12:54:16.443049+00', 'Pigg, B', '', 'B Pigg', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3512, NULL, '2012-01-20 12:54:16.510878+00', 'Newfield, Mady / Jensen, Doug', '', 'Newfield, Mady & Jensen, Doug', 'Chicago, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3513, NULL, '2012-01-20 12:54:16.514172+00', 'Hanson, Marsha', '', 'Marsha Hanson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3494, NULL, '2012-01-20 12:54:16.446334+00', 'Jorgensen, K & Wendell, K', '', 'Jorgensen, K & Wendell, K', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3514, NULL, '2012-01-20 12:54:16.517459+00', 'Jensen, Doug', '', 'Doug Jensen', 'Chicago, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3515, NULL, '2012-01-20 12:54:16.520751+00', 'Lindsey, Ann & Snowdon, Chuck', '', 'Lindsey, Ann & Snowdon, Chuck', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3495, NULL, '2012-01-20 12:54:16.449633+00', 'Fogg, Stella & Turner, Moira', '', 'Fogg, Stella & Turner, Moira', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3496, NULL, '2012-01-20 12:54:16.452943+00', 'Fraser Catherine & Smith Duncan', 'Fraser & Smith', 'Catherine Fraser & Duncan Smith', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3516, NULL, '2012-01-20 12:54:16.524077+00', 'Chau, Ken', '', 'Ken Chau', 'Chicago, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3497, NULL, '2012-01-20 12:54:16.456245+00', 'Briand, Elmer', '', 'Elmer Briand', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3498, NULL, '2012-01-20 12:54:16.459546+00', 'Bourgeois, Dana', '', 'Dana Bourgeois', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3499, NULL, '2012-01-20 12:54:16.462831+00', 'Lowers, Pat & Gregary, Sparky', '', 'Lowers, Pat & Gregary, Sparky', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3500, NULL, '2012-01-20 12:54:16.466118+00', 'Anderson, Sue', '', 'Sue Anderson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3465, NULL, '2015-03-14 18:11:03.669458+00', 'Clark, Pete', '', 'Pete Clark', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3479, NULL, '2015-03-14 18:11:04.169467+00', 'Corryvrechan', '', 'Corryvrechan', '', '', 0, 1, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3476, NULL, '2015-03-14 18:11:09.267354+00', 'Gray, Bill & Susan', '', 'Bill & Susan Gray', 'PA., USA', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3475, NULL, '2015-03-14 18:11:09.362752+00', 'Gray, Susan', '', 'Susan Gray', 'PA, USA', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3452, NULL, '2015-03-14 18:11:29.765609+00', 'Wood, Alastair', '', 'Alastair Wood', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3491, NULL, '2015-06-04 09:45:53.690697+00', 'Memory, Jill', '', 'Jill Memory', '	Auckland, NZ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3460, NULL, '2016-12-14 22:59:43.42427+00', 'Mendelssohn Bartholdy, Felix', '', 'Felix Mendelssohn Bartholdy', '', '', 0, 0, 1, 0, NULL, 1809, 1847, NULL, '');
INSERT INTO 'person' VALUES (3454, NULL, '2019-10-24 16:43:17.148229+00', 'Schad, Samantha', '', 'Samantha Schad', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3518, NULL, '2012-01-20 12:54:16.530662+00', 'Thistle SCD Club, Demonstration Team', '', 'Demonstration Team Thistle SCD Club', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3519, NULL, '2012-01-20 12:54:16.53395+00', 'Ivory, Derek & Rowatt, Elizabeth', '', 'Ivory, Derek & Rowatt, Elizabeth', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3520, NULL, '2012-01-20 12:54:16.537294+00', 'Zakharov, Beryl', '', 'Beryl Zakharov', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3522, NULL, '2012-01-20 12:54:16.543886+00', 'Porter, Sue', '', 'Sue Porter', 'Oban', 'sue.porter3@btopenworld.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3523, NULL, '2012-01-20 12:54:16.547171+00', 'Brown, Wilma', '', 'Wilma Brown', 'Ayr', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3524, NULL, '2012-01-20 12:54:16.55045+00', 'Bolton, Elizabeth', '', 'Elizabeth Bolton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3525, NULL, '2012-01-20 12:54:16.553752+00', 'Harrower, Pat', '', 'Pat Harrower', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3526, NULL, '2012-01-20 12:54:16.557042+00', 'Scott, Sue', '', 'Sue Scott', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3527, NULL, '2012-01-20 12:54:16.560342+00', 'Sergeant, Sheila', '', 'Sheila Sergeant', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3528, NULL, '2012-01-20 12:54:16.563639+00', 'Smith, Carol', '', 'Carol Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3529, NULL, '2012-01-20 12:54:16.566925+00', 'Kellie, Sheila', '', 'Sheila Kellie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3530, NULL, '2012-01-20 12:54:16.570213+00', 'Green Ginger & Keith Smith', 'Green Ginger +', 'Green Ginger & Keith Smith', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3546, NULL, '2012-01-20 12:54:16.623067+00', 'McNaughton, John', '', 'John McNaughton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11626, '2018-04-15 15:00:13.706439+00', '2018-04-15 23:56:24.549056+00', 'Strutt, Moira', '', 'Moira Strutt', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3548, NULL, '2012-01-20 12:54:16.62969+00', 'Yarden, Sheila', '', 'Sheila Yarden', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3532, NULL, '2012-01-20 12:54:16.576822+00', 'Harpenden SCD Club', '', 'Harpenden SCD Club', '', 'secretary@hscdc.org.uk', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3533, NULL, '2012-01-20 12:54:16.580123+00', 'Wood, Robin', '', 'Robin Wood', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3550, NULL, '2012-01-20 12:54:16.636308+00', 'Barnes, Barbara', '', 'Barbara Barnes', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3551, NULL, '2012-01-20 12:54:16.639595+00', 'Dewar', '', 'Dewar', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3534, NULL, '2012-01-20 12:54:16.583423+00', 'Kaye, Rosalind', '', 'Rosalind Kaye', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3552, NULL, '2012-01-20 12:54:16.642874+00', 'Fell, Andrea & Gray, Alison', '', 'Fell, Andrea & Gray, Alison', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3535, NULL, '2012-01-20 12:54:16.586736+00', 'Haslem, Barbara', '', 'Barbara Haslem', '', '', 0, 0, 1, 0, NULL, 1909, 2001, NULL, '');
INSERT INTO 'person' VALUES (3553, NULL, '2012-01-20 12:54:16.646146+00', 'Martin, Zena', '', 'Zena Martin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3554, NULL, '2012-01-20 12:54:16.649445+00', 'Kean, Doug', '', 'Doug Kean', 'Ontario, Canada', 'dm.kean@sympatico.ca', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3555, NULL, '2012-01-20 12:54:16.652747+00', 'Mortimer', '', 'Mortimer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3537, NULL, '2012-01-20 12:54:16.593418+00', 'Birkett, Mary', '', 'Mary Birkett', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3556, NULL, '2012-01-20 12:54:16.656035+00', 'Rixon/Hami', '', 'Rixon/Hami', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3558, NULL, '2012-01-20 12:54:16.663055+00', 'Bridges, Clive', '', 'Clive Bridges', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3539, NULL, '2012-01-20 12:54:16.599992+00', 'Reeve, John & Patricia', '', 'John & Patricia Reeve', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3559, NULL, '2012-01-20 12:54:16.666342+00', 'McMahon, Elizabeth', '', 'Elizabeth McMahon', '', 'bvon@sympatico.ca', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3540, NULL, '2012-01-20 12:54:16.603281+00', 'Walker, Terry', '', 'Terry Walker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3541, NULL, '2012-01-20 12:54:16.60656+00', 'Daly, Maureen / Caldwell, Jim', '', 'Daly, Maureen / Caldwell, Jim', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3560, NULL, '2012-01-20 12:54:16.66964+00', 'Mortimer, Stuart A', '', 'Stuart A Mortimer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3542, NULL, '2012-01-20 12:54:16.609861+00', 'Watanabe, Masaaki', '', 'Masaaki Watanabe', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3543, NULL, '2012-01-20 12:54:16.613162+00', 'Claire, Leigh', '', 'Leigh Clare', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3544, NULL, '2012-01-20 12:54:16.616464+00', 'Hayashi, Hiroko', '', 'Hiroko Hayashi', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3562, NULL, '2012-01-20 12:54:16.67621+00', 'Watanabe, Etsuko', '', 'Etsuko Watanabe', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3564, NULL, '2012-01-20 12:54:16.682785+00', 'Falmouth White Heather', '', 'Falmouth White Heather', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3565, NULL, '2012-01-20 12:54:16.686068+00', 'Corson, Don', '', 'Don Corson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3566, NULL, '2012-01-20 12:54:16.689351+00', 'Corson, Joyce', '', 'Joyce Corson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3567, NULL, '2012-01-20 12:54:16.692637+00', 'Bissell, Bill', '', 'Bill Bissell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3585, NULL, '2012-01-20 12:54:16.751953+00', 'Wickens, Claire', '', 'Claire Wickens', '', 'clairewickens@waitrose.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3568, NULL, '2012-01-20 12:54:16.69592+00', 'Hinson, Susan', '', 'Susan Hinson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3586, NULL, '2012-01-20 12:54:16.755248+00', 'Perkins, Pam', '', 'Pam Perkins', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3569, NULL, '2012-01-20 12:54:16.699212+00', 'Zumbro, John', '', 'John Zumbro', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3587, NULL, '2012-01-20 12:54:16.758527+00', 'Lysons, Angela', '', 'Angela Lysons', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3588, NULL, '2012-01-20 12:54:16.761871+00', 'McNaughton', '', 'McNaughton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3570, NULL, '2012-01-20 12:54:16.70249+00', 'Crist, Larry', '', 'Larry Crist', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3571, NULL, '2012-01-20 12:54:16.705778+00', 'MacMorran, Sheila', '', 'Sheila MacMorran', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3590, NULL, '2012-01-20 12:54:16.768443+00', 'Gorman, Ann', '', 'Ann Gorman', '', 'agorman2003@yahoo.co.uk', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3591, NULL, '2012-01-20 12:54:16.771733+00', 'Perkins, Pam / Gorman, Ann', '', 'Pam Perkins / Ann Gorman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3572, NULL, '2012-01-20 12:54:16.709068+00', 'MacKenzie, Duncan', '', 'Duncan MacKenzie', 'Vancouver', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3592, NULL, '2012-01-20 12:54:16.77502+00', 'Watson, Ron', '', 'Ron Watson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3573, NULL, '2012-01-20 12:54:16.712363+00', 'Turner, Mike', '', 'Mike Turner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3594, NULL, '2012-01-20 12:54:16.781614+00', 'McHardy, Elizabeth', '', 'Elizabeth McHardy', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3574, NULL, '2012-01-20 12:54:16.71565+00', 'Walker, Jan', '', 'Jan Walker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3595, NULL, '2012-01-20 12:54:16.78492+00', 'Evans, Les', '', 'Les Evans', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3575, NULL, '2012-01-20 12:54:16.718931+00', 'Corfield, Jean', '', 'Jean Corfield', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3596, NULL, '2012-01-20 12:54:16.788197+00', 'Chartrand, Karen', '', 'Karen Chartrand', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3576, NULL, '2012-01-20 12:54:16.72222+00', 'Frith, John', '', 'John Frith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3598, NULL, '2012-01-20 12:54:16.794754+00', 'Thomas, Glenday', '', 'Glenday Thomas', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3578, NULL, '2012-01-20 12:54:16.728769+00', 'Murray', '', 'Murray', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3599, NULL, '2012-01-20 12:54:16.798042+00', 'Reeves, John', '', 'John Reeves', 'Peterborough, ON, CA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3579, NULL, '2012-01-20 12:54:16.732051+00', 'Johnston/Stonehouse', '', 'Johnston/Stonehouse', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3538, NULL, '2021-03-07 23:05:04.684446+00', 'Sandeman, Ian', '', 'Ian Sandeman', 'Lakefield (Ontario), Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3549, NULL, '2015-03-14 18:11:00.655305+00', 'Bissell, Eugene', '', 'Eugene Bissell', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3563, NULL, '2016-05-26 21:57:48.561674+00', 'Exeter Branch RSCDS', '', 'Exeter Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3584, NULL, '2015-09-22 20:52:21.433247+00', 'Cackett, Ken', '', 'Ken Cackett', 'RSCDS Wirral', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3577, NULL, '2019-07-12 19:41:23.184074+00', 'Skene, Bill', '', 'Bill Skene', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3536, NULL, '2019-09-03 23:56:13.634922+00', 'Jappy, Ruth', '', 'Ruth Jappy', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3600, NULL, '2012-01-20 12:54:16.801327+00', 'Peterborough Scottish', '', 'Peterborough Scottish', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3581, NULL, '2012-01-20 12:54:16.73862+00', 'Sato, Hitomi', '', 'Hitomi Sato', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3582, NULL, '2012-01-20 12:54:16.741913+00', 'Idour, John', '', 'John Idour', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3601, NULL, '2012-01-20 12:54:16.804617+00', 'Kean, Margaret', '', 'Margaret Kean', 'Ontario, Canada', 'dm.kean@sympatico.ca', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3602, NULL, '2012-01-20 12:54:16.807909+00', 'Larsen', '', 'Larsen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3604, NULL, '2012-01-20 12:54:16.811192+00', 'West Telferton Caledonian Dance Band', 'West Telferton', 'West Telferton Caledonian Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3606, NULL, '2012-01-20 12:54:16.817793+00', 'Eder, Evalyn', '', 'Evalyn Eder', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3623, NULL, '2012-01-20 12:54:16.874461+00', 'Easton, R', '', 'R Easton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3607, NULL, '2012-01-20 12:54:16.821185+00', 'Abrajian, Janet', '', 'Janet Abrajian', 'Ontario', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3624, NULL, '2012-01-20 12:54:16.877793+00', 'Goodwin, D', '', 'D Goodwin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3625, NULL, '2012-01-20 12:54:16.881081+00', 'Currie, D', '', 'D Currie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3608, NULL, '2012-01-20 12:54:16.824506+00', 'Thompson, Philip', '', 'Philip Thompson', 'Ontario', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3626, NULL, '2014-03-29 21:04:13.879323+00', 'Crowe, James', '', 'James Crowe', '', '', 1, 0, 0, 0, NULL, 1930, 2011, NULL, '');
INSERT INTO 'person' VALUES (3561, NULL, '2014-02-08 14:34:27.263939+00', 'Matuhashi, Junko', '', 'Junko Matsuhashi', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3609, NULL, '2012-01-20 12:54:16.8278+00', 'Pearson, Dorothy', '', 'Dorothy Pearson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3627, NULL, '2012-01-20 12:54:16.887653+00', 'Souter, Ian', '', 'Ian Souter', 'Hamilton, ON, CA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3628, NULL, '2012-01-20 12:54:16.891117+00', 'Richardson, P', '', 'P Richardson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3610, NULL, '2012-01-20 12:54:16.831084+00', 'Sibley, Gail', '', 'Gail Sibley', 'Vancouver', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3629, NULL, '2012-01-20 12:54:16.894403+00', 'Anderson, T', '', 'T Anderson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3611, NULL, '2012-01-20 12:54:16.834363+00', 'Clark, Ewan', '', 'Ewan Clark', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3630, NULL, '2012-01-20 12:54:16.897694+00', 'Fyfe, W', '', 'W Fyfe', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3631, NULL, '2012-01-20 12:54:16.900991+00', 'Wignall, Rachel', '', 'Rachel Wignall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3612, NULL, '2012-01-20 12:54:16.837671+00', 'Wright, Janet', '', 'Janet Wright', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3632, NULL, '2012-01-20 12:54:16.904287+00', 'Gibson, J Stephen', '', 'J Stephen Gibson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3613, NULL, '2012-01-20 12:54:16.841148+00', 'Paul, Mike', '', 'Mike Paul', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3633, NULL, '2012-01-20 12:54:16.907579+00', 'Haddow, John C', '', 'J C Haddow', '', 'morris', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3614, NULL, '2012-01-20 12:54:16.844448+00', 'MacKinnon, Calum', '', 'Calum MacKinnon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3634, NULL, '2012-01-20 12:54:16.910883+00', 'McNeil, Mary', '', 'Mary McNeil', 'Glasgow', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3635, NULL, '2012-01-20 12:54:16.914167+00', 'Palmer, Carol', '', 'Carol Palmer', '', 'carolhpalmer@hotmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3615, NULL, '2012-01-20 12:54:16.847739+00', 'Muir, D', '', 'D Muir', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3636, NULL, '2012-01-20 12:54:16.917982+00', 'Wyant, Reece', '', 'Reece Wyant', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3616, NULL, '2012-01-20 12:54:16.851027+00', 'McKechnie, Vera', '', 'Vera McKechnie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3637, NULL, '2012-01-20 12:54:16.92129+00', 'Simmons, John M', '', 'John M Simmons', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3638, NULL, '2012-01-20 12:54:16.924574+00', 'McAndrew, Anne', '', 'Anne McAndrew', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3639, NULL, '2012-01-20 12:54:16.927864+00', 'Down, Arthur', '', 'Arthur Down', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3640, NULL, '2012-01-20 12:54:16.931147+00', 'Smith, Bill', '', 'Bill Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3622, NULL, '2012-01-20 12:54:16.871011+00', 'Taylor, Alastair', '', 'Alastair Taylor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3641, NULL, '2012-01-20 12:54:16.93442+00', 'McClure, Cheryl', '', 'Cheryl McClure', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11627, '2018-04-15 15:01:50.585754+00', '2018-04-15 23:56:11.89273+00', 'Hitchins, Diana & Strutt, Moira', '', 'Diana Hitchins & Moira Strutt', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3644, NULL, '2012-01-20 12:54:16.944276+00', 'Bell, W', '', 'W Bell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3646, NULL, '2012-01-20 12:54:16.95085+00', 'Roughgarden, Trudy', '', 'Trudy Roughgarden', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3662, NULL, '2012-01-20 12:54:17.003634+00', 'Teke, Ilona', '', 'Ilona Teke', 'Budapest, Hungary', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3663, NULL, '2012-01-20 12:54:17.007052+00', 'Szemeredi, Ferenc', '', 'Ferenc Szemeredi', 'Budapest, Hungary', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3649, NULL, '2012-01-20 12:54:16.960708+00', 'Shackleton', '', 'Shackleton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3665, NULL, '2012-01-20 12:54:17.013632+00', 'Miller, Anne Macauley', '', 'Anne Macauley Miller', 'Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3651, NULL, '2012-01-20 12:54:16.967317+00', 'Milne, Richard', '', 'Richard Milne', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3667, NULL, '2012-01-20 12:54:17.020275+00', 'Collier, Claire', '', 'Claire Collier', 'Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3652, NULL, '2012-01-20 12:54:16.9706+00', 'Unit 2&3 Summer School class 2005', '', 'Unit 2&3 Summer School class 2005', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3668, NULL, '2012-01-20 12:54:17.023558+00', 'Atkinson, Charlie', '', 'Charlie Atkinson', 'Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3653, NULL, '2012-01-20 12:54:16.973902+00', 'Wilson, Jennifer', 'Jennifer Wilson', 'Jennifer Wilson', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3670, NULL, '2012-01-20 12:54:17.030116+00', 'Miller, Paul', '', 'Paul Miller', 'Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3671, NULL, '2012-01-20 12:54:17.033393+00', 'McVittie, Robert', '', 'Robert McVittie', 'Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3672, NULL, '2012-01-20 12:54:17.036676+00', 'McKenna, Hugh', '', 'Hugh McKenna', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3655, NULL, '2012-01-20 12:54:16.980499+00', 'Nicholson, Judi', '', 'Judi Nicholson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3673, NULL, '2012-01-20 12:54:17.039965+00', 'Lacey, Elspeth', '', 'Elspeth Lacey', 'Canberra, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3656, NULL, '2012-01-20 12:54:16.983787+00', 'Nicholson, E', '', 'E Nicholson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3674, NULL, '2012-01-20 12:54:17.043299+00', 'Lindsey, Joyce', '', 'Joyce Lindsey', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3675, NULL, '2012-01-20 12:54:17.046622+00', 'Batt, P.M. R.', '', 'P.M. R. Batt', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3657, NULL, '2012-01-20 12:54:16.987077+00', 'Kelly, P J', '', 'P J Kelly', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3734, NULL, '2012-01-20 12:54:17.241364+00', 'Dennison, Deborah', '', 'Deborah Dennison', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3605, NULL, '2019-04-04 21:50:03.256876+00', 'Greenwood, Helen', '', 'Helen Greenwood', 'New Zealand', 'hgreenwood@orcon.net.nz', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3654, NULL, '2015-11-17 00:56:11.950257+00', 'Hunter, R', '', 'R Hunter', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3669, NULL, '2016-09-12 22:05:19.322714+00', 'Middleton, J''ina', '', 'J''ina Middleton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'It is possible the name should be Jina; the handwriting was unclear');
INSERT INTO 'person' VALUES (3645, NULL, '2016-09-27 08:07:38.491528+00', 'Werner, Edwin', '', 'Edwin Werner', 'NL', 'e.werner@ziggo.nl', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3648, NULL, '2021-08-22 03:45:07.499312+00', 'Banffshire Branch RSCDS', '', 'Banffshire Branch RSCDS', 'Banffshire', '', 0, 1, 0, 0, NULL, 1929, 0, NULL, '');
INSERT INTO 'person' VALUES (3618, NULL, '2021-09-06 21:02:01.761949+00', 'Anderson, Bob', '', 'Bob Anderson', 'Victoria, BC, Canada', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3666, NULL, '2018-08-03 20:03:13.158334+00', 'Morrison, Hugh', '', 'Hugh Morrison', 'Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3658, NULL, '2012-01-20 12:54:16.990353+00', 'Rutherford, Maureen & Copland, Neil', 'Rutherford/Copland', 'Rutherford, Maureen & Copland, Neil', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3676, NULL, '2012-01-20 12:54:17.049974+00', 'Stewart/Grant', '', 'Stewart/Grant', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3659, NULL, '2012-01-20 12:54:16.993656+00', 'Budapest Scottish Dance Club', '', 'Budapest Scottish Dance Club', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3677, NULL, '2012-01-20 12:54:17.053266+00', 'Meek, Billy', '', 'Billy Meek', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3660, NULL, '2012-01-20 12:54:16.996958+00', 'Horne, Kim', '', 'Kim Horne', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3680, NULL, '2012-01-20 12:54:17.06318+00', 'Bach, Johann Sebastian', '', 'Johann Sebastian Bach', '', '', 0, 0, 1, 0, NULL, 1685, 1750, NULL, '');
INSERT INTO 'person' VALUES (3681, NULL, '2012-01-20 12:54:17.066469+00', 'Swann, Cassie', '', 'Cassie Swann', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3697, NULL, '2012-01-20 12:54:17.119646+00', 'Hohenkerk, Keith', '', 'Keith Hohenkerk', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3682, NULL, '2012-01-20 12:54:17.069778+00', 'Mackie, Fiona', '', 'Fiona Mackie', 'Dundee', 'fionamackie683@hotmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3698, NULL, '2012-01-20 12:54:17.122965+00', 'Russell, Helen', '', 'Helen Russell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3679, NULL, '2013-04-10 10:02:16.006852+00', 'Laidlaw, Ruary et al', '', 'Ruary Laidlaw et al ', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3619, NULL, '2014-09-16 09:58:20.687149+00', 'McRobert, Willie''s SCDB', 'Willie McRobert', 'Willie McRobert''s SCDB', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3700, NULL, '2012-01-20 12:54:17.129539+00', 'Munro, David', '', 'David Munro', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3684, NULL, '2012-01-20 12:54:17.076378+00', 'Wallace, Bruce', '', 'Bruce Wallace', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3701, NULL, '2012-01-20 12:54:17.13282+00', 'Nicholson, Alan', '', 'A Nicholson', 'Shetland', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3686, NULL, '2012-01-20 12:54:17.083305+00', 'Ternes, E & Fuell, Lee', '', 'Ellen Ternes & Lee Fuell ', 'RSCDS Cincinnati, OH, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3704, NULL, '2012-01-20 12:54:17.142677+00', 'Eustis, Fred', '', 'Fred Eustis', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3705, NULL, '2012-01-20 12:54:17.145955+00', 'Rideout, Bonnie', '', 'Bonnie Rideout', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3687, NULL, '2012-01-20 12:54:17.086696+00', 'Mair, Jean', '', 'Jean Mair', 'Banff', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3706, NULL, '2012-01-20 12:54:17.149293+00', 'Sawin, Jenn', '', 'Jenn Sawin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3688, NULL, '2012-01-20 12:54:17.089981+00', 'Cowie, Margaret', '', 'Margaret Cowie', 'Buckie', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3708, NULL, '2012-01-20 12:54:17.155883+00', 'Mortimer, J', '', 'J Mortimer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3689, NULL, '2012-01-20 12:54:17.093271+00', 'Taylor, Anne', '', 'Anne Taylor', 'Fochabers', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3710, NULL, '2012-01-20 12:54:17.162461+00', 'Patrick, David', '', 'David Patrick', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3691, NULL, '2012-01-20 12:54:17.099871+00', 'Washington DC Dancers', '', 'Washington DC Dancers', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3711, NULL, '2012-01-20 12:54:17.165755+00', 'Kellett, A', '', 'A Kellett', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3692, NULL, '2012-01-20 12:54:17.1032+00', 'MacMaster, Natalie', '', 'N MacMaster', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3712, NULL, '2012-01-20 12:54:17.169043+00', 'Royle, J', '', 'J Royle', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3713, NULL, '2012-01-20 12:54:17.172318+00', 'Gibson, J', '', 'J Gibson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3695, NULL, '2012-01-20 12:54:17.113051+00', 'Knight, John', '', 'John Knight', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (900, NULL, '2018-04-16 21:01:42.60964+00', 'Cannonito, Frank', '', 'Frank Cannonito', 'RSCDS Orange County Branch', '', 1, 0, 0, 0, NULL, 0, 2018, NULL, 'Frank Cannonito passed away on April 7th, 2018.



Frank Cannonito was professor emeritus of mathematics at the University of California at Irvine.  He had been chair of the RSCDS Orange County Branch and an active volunteer with the Orange County Games Committee.

');
INSERT INTO 'person' VALUES (3716, NULL, '2012-01-20 12:54:17.18216+00', 'Reid, Stewart', '', 'Stewart Reid', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3719, NULL, '2012-01-20 12:54:17.192011+00', 'Bradbury, Joan F', '', 'Joan Bradbury', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3720, NULL, '2012-01-20 12:54:17.195301+00', 'Cormier, Paul', '', 'Paul Cormier', '', '', 0, 0, 1, 0, NULL, 1922, 2006, NULL, '');
INSERT INTO 'person' VALUES (3693, NULL, '2012-01-20 12:54:17.106478+00', 'Nicolson, Judi', '', 'Judi Nicolson', '', '', 0, 0, 1, 0, 10016, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11629, '2018-04-25 20:55:32.356628+00', '2018-04-25 20:55:32.356628+00', 'Buckingham, Jenny', '', 'Jenny Buckingham', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3721, NULL, '2012-01-20 12:54:17.198584+00', 'Cook, Pamela', '', 'Pamela Cook', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3737, NULL, '2012-01-20 12:54:17.251267+00', 'Garrett, Sarah', '', 'Sarah Garrett', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3738, NULL, '2012-01-20 12:54:17.25454+00', 'Haley, Ed', '', 'Ed Haley', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3739, NULL, '2012-01-20 12:54:17.257829+00', 'Rennebohm, Cory', '', 'Cory Rennebohm', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3740, NULL, '2012-01-20 12:54:17.261116+00', 'Ashman, Karl', '', 'Karl Ashman', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3741, NULL, '2012-01-20 12:54:17.264409+00', 'Siegel, D N', '', 'D N Siegel', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3724, NULL, '2012-01-20 12:54:17.208462+00', 'Ternes, Ellen & Anderson, Martha', '', 'Ternes, Ellen & Anderson, Martha', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3742, NULL, '2012-01-20 12:54:17.267702+00', 'Bratman, Breuer, Leroy', '', 'Bratman, Breuer, Leroy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3725, NULL, '2012-01-20 12:54:17.21176+00', 'Griffen', '', 'Griffen', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3743, NULL, '2012-01-20 12:54:17.27098+00', 'Aurora', '', 'Aurora', 'Aberdeen', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3744, NULL, '2012-01-20 12:54:17.27425+00', 'Vivaldi', '', 'Vivaldi', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3726, NULL, '2012-01-20 12:54:17.215045+00', 'Sisters of the Heart', '', 'Sisters of the Heart', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3727, NULL, '2012-01-20 12:54:17.218319+00', 'McCallum, Rebecca', '', 'Rebecca McCallum', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3747, NULL, '2012-01-20 12:54:17.284198+00', 'Esslemont, Neil', 'Neil Esslemont', 'Neil Esslemont', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3748, NULL, '2012-01-20 12:54:17.287472+00', 'Macrae, P/M K', '', 'P/M K Macrae', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11000, '2014-09-07 21:31:52.346199+00', '2018-09-09 17:12:16.728607+00', 'Haynes, David A', '', 'David A. Haynes', 'Wirral, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'One of the Minicrib team');
INSERT INTO 'person' VALUES (3730, NULL, '2012-01-20 12:54:17.22822+00', 'Michener, Gail', '', 'Gail Michener', 'Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3751, NULL, '2012-01-20 12:54:17.297413+00', 'Smith, Judith & Young, Angela', 'Smith/Young', 'Smith, Judith & Young, Angela', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3733, NULL, '2012-01-20 12:54:17.238082+00', 'Moore, Deborah', '', 'Deborah Moore', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3752, NULL, '2012-01-20 12:54:17.300714+00', 'Cutting, Andy', '', 'Andy Cutting', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3722, NULL, '2015-03-14 18:11:03.171916+00', 'Cassel, Hanneke', '', 'Hanneke Cassel', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3620, NULL, '2015-03-14 18:11:18.011458+00', 'McRobert, Willie', '', 'Willie McRobert', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3729, NULL, '2015-03-14 18:11:18.59095+00', 'Mitchell, Val', '', 'Val Mitchell', 'New Zealand', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3728, NULL, '2015-03-14 18:11:23.348919+00', 'Roman, Rebecca', '', 'Rebecca Roman', 'USA', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3732, NULL, '2015-03-14 18:11:24.105662+00', 'Santa Fe Country Dancers, The', '', 'The Santa Fe Country Dancers', 'USA', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3703, NULL, '2015-08-27 23:56:25.890116+00', 'Stephens, Pam', '', 'Pam Stephens', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3685, NULL, '2015-08-31 23:56:13.556424+00', 'Kasama, Akiko', 'Akiko Kasama', 'Akiko Kasama', 'Japan', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3731, NULL, '2015-09-24 23:56:24.685859+00', 'Shea, Mara', '', 'Mara Shea', 'USA', '', 0, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3735, NULL, '2012-01-20 12:54:17.244656+00', 'Morris, Joan & Len', '', 'Joan & Len Morris', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3723, NULL, '2020-06-04 23:57:04.845318+00', 'Sherman, Holly', '', 'Holly Sherman', '', 'hollyvalentine540@yahoo.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3709, NULL, '2020-06-27 21:18:28.219067+00', 'Faurere, J & Halak, S', '', 'Faurer, F & Halak, S', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3753, NULL, '2012-01-20 12:54:17.304155+00', 'Gray, Alasdair', '', 'Alasdair Gray', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3754, NULL, '2012-01-20 12:54:17.307626+00', 'Stone, Andy', '', 'Andy Stone', 'Wothing, England', 'petros103@tesco.net', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3755, NULL, '2012-01-20 12:54:17.310937+00', 'Brown, James B C', '', 'James B C Brown', 'Edinburgh', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3757, NULL, '2012-01-20 12:54:17.317532+00', 'Touw, John van der', '', 'John van der Touw', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3772, NULL, '2012-01-20 12:54:17.366868+00', 'Tyler, Campbell', '', 'Campbell Tyler', 'South Africa', '', 1, 0, 0, 0, NULL, 1946, 0, NULL, '');
INSERT INTO 'person' VALUES (3773, NULL, '2012-01-20 12:54:17.370179+00', 'Kashanski, Sue', '', 'Sue Kashanski', 'Nova Scotia', 'skashanski@ns.sympatico.ca', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3758, NULL, '2012-01-20 12:54:17.320825+00', 'Deacon, Jean & Gawler, Ross', '', 'Deacon, Jean & Gawler, Ross', 'Melbourne, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3774, NULL, '2012-01-20 12:54:17.37348+00', 'Corps, Deanne & Roxburgh, Debbie', '', 'Corps, Deanne & Roxburgh, Debbie', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3759, NULL, '2012-01-20 12:54:17.324135+00', 'Ross, Heather & Cole, Louise', '', 'Ross, Heather & Cole, Louise', 'Melbourne, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11630, '2018-04-25 20:56:47.784989+00', '2018-04-25 20:56:47.784989+00', 'Hedley, Douglas', '', 'Douglas Hedley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3702, NULL, '2014-08-29 17:10:31.88341+00', 'Burt, John', '', 'John Burt', '', '', 0, 0, 1, 0, 3702, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3775, NULL, '2012-01-20 12:54:17.37678+00', 'Hoppmann-Lacour, Ute', '', 'Ute Hoppmann-Lacour', 'Wuppertal, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3760, NULL, '2012-01-20 12:54:17.327437+00', 'Davies, Tina', '', 'T Davies', '', 'daveandtina@consolidated.net', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3777, NULL, '2012-01-20 12:54:17.383371+00', 'Mentrup, Beate & Hoppmann-Lacour, Ute', '', 'Mentrup, Beate & Hoppmann-Lacour, Ute', 'Wuppertal, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3761, NULL, '2012-01-20 12:54:17.330735+00', 'Milford SCD Club', '', 'Milford SCD Club', 'Auckland, New Zealand', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3778, NULL, '2012-01-20 12:54:17.386667+00', 'Carr, Francis', '', 'Francis Carr', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3762, NULL, '2012-01-20 12:54:17.334009+00', 'Hawkins, Nicola', '', 'Nicola Hawkins', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3763, NULL, '2012-01-20 12:54:17.337299+00', 'Schofield, Gail', '', 'Gail Schofield', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3782, NULL, '2012-01-20 12:54:17.396544+00', 'Eder, Evalyn & Ernst', '', 'Evalyn & Ernst Eder', 'Ontario, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3764, NULL, '2012-01-20 12:54:17.340586+00', 'Whatley, Roddy', '', 'Roddy Whatley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3784, NULL, '2012-01-20 12:54:17.403116+00', 'Mungall, James', '', 'James Mungall', 'Louisiana, USA', 'jeb_mungall@yahoo.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3765, NULL, '2012-01-20 12:54:17.343877+00', 'Jeffrey, M / Burr, M / Hawkins, N', '', 'Jeffrey, M / Burr, M / Hawkins, N', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3785, NULL, '2012-01-20 12:54:17.406395+00', 'Strachan, Keith', '', 'Keith Strachan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3786, NULL, '2012-01-20 12:54:17.409679+00', 'Lennon, John', '', 'John Lennon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3787, NULL, '2012-01-20 12:54:17.412964+00', 'Burt, Alfred', '', 'Alfred Burt', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3767, NULL, '2012-01-20 12:54:17.350438+00', 'Derrick, Luke', '', 'Luke Derrick', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3788, NULL, '2012-01-20 12:54:17.416251+00', 'Goss, John', '', 'John Goss', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3781, NULL, '2012-07-06 10:31:40.410294+00', 'Pittsburgh Scottish Country Dancers', '', 'Pittsburgh Scottish Country Dancers', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3718, NULL, '2013-02-15 23:33:55.886406+00', 'Morris, John', '', 'John Morris', 'Cheshire', 'vallinjmorris@aol.com', 1, 1, 0, 0, NULL, 0, 2012, NULL, '');
INSERT INTO 'person' VALUES (3768, NULL, '2012-01-20 12:54:17.353731+00', 'Milford Juniors', '', 'Milford Juniors', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3769, NULL, '2012-01-20 12:54:17.357012+00', 'Tonks, Peg', '', 'Peg Tonks', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3789, NULL, '2012-01-20 12:54:17.419535+00', 'Holst, Gustav', '', 'Gustav Holst', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3770, NULL, '2012-01-20 12:54:17.360293+00', 'Boyd, Veronica', '', 'Veronica Boyd', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3771, NULL, '2012-01-20 12:54:17.363576+00', 'Sturrock, John S', '', 'John S Sturrock', '', '', 1, 0, 0, 0, NULL, 1920, 0, NULL, '');
INSERT INTO 'person' VALUES (3790, NULL, '2012-01-20 12:54:17.422822+00', 'Anderson, Leroy', '', 'Leroy Anderson', '', '', 0, 0, 1, 0, NULL, 1908, 1975, NULL, '');
INSERT INTO 'person' VALUES (3791, NULL, '2012-01-20 12:54:17.426101+00', 'Grafton, Jimmy', '', 'Jimmy Grafton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3792, NULL, '2012-01-20 12:54:17.429385+00', 'Blake, Howard', '', 'Howard Blake', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (9998, NULL, '2012-01-20 12:54:17.482045+00', '(unknown)', '(unknown)', '(unknown)', '', '', 1, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3793, NULL, '2012-01-20 12:54:17.432679+00', 'Gardner, Donald', '', 'Donald Gardner', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10001, NULL, '2012-01-20 12:54:17.491936+00', 'Hamilton, Hammy', 'Hammy Hamilton', 'Hammy Hamilton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10002, NULL, '2012-01-20 12:54:17.495231+00', 'Sullivan, Tony', 'Tony Sullivan', 'Tony Sullivan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10003, NULL, '2012-01-20 12:54:17.498513+00', 'Byard, Lydia', 'Lydia Byard', 'Lydia Byard', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3796, NULL, '2012-01-20 12:54:17.442532+00', 'Weber, Andrew Lloyd', '', 'Andrew Lloyd Weber', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10005, NULL, '2012-01-20 12:54:17.505199+00', 'Carreño, Teresa', 'Teresa Carreño', 'Teresa Carreño', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3797, NULL, '2012-01-20 12:54:17.445875+00', 'Lewie, Jona', '', 'Jona Lewie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10006, NULL, '2012-01-20 12:54:17.508499+00', 'Forest, Richard', 'Richard Forest', 'Richard Forest', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10007, NULL, '2012-01-20 12:54:17.511884+00', 'Grant, Angus Jr.', 'Angus Jr. Grant', 'Angus Jr. Grant', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3799, NULL, '2012-01-20 12:54:17.452459+00', 'O''Connell, Tony', '', 'Tony O''Connell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11631, '2018-04-25 20:57:56.559401+00', '2018-04-25 20:57:56.559401+00', 'Stewart, Ian', '', 'Ian Stewart', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3800, NULL, '2012-01-20 12:54:17.455747+00', 'De Rose, Peter', '', 'Peter De Rose', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10010, NULL, '2012-01-20 12:54:17.522551+00', 'Thorburn, Andy', 'Andy Thorburn', 'Andy Thorburn', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3804, NULL, '2012-01-20 12:54:17.468895+00', 'Poser, Freddy', '', 'Freddy Poser', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3805, NULL, '2012-01-20 12:54:17.472187+00', 'Coot, Fred', '', 'Fred Coot', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3807, NULL, '2012-01-20 12:54:17.478762+00', 'Marks, Johnny', '', 'Johnny Marks', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10013, NULL, '2012-01-20 12:54:17.532482+00', 'Sutherland, Adam', 'Adam Sutherland', 'Adam Sutherland', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10011, NULL, '2015-03-14 18:11:04.204058+00', 'Cortese, Laura', 'Laura Cortese', 'Laura Cortese', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10012, NULL, '2015-03-14 18:11:22.874442+00', 'Risk, Laura', 'Laura Risk', 'Laura Risk', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (9999, NULL, '2015-03-14 18:11:27.704236+00', '(traditional)', '', '(traditional)', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3756, NULL, '2015-09-24 04:14:01.190199+00', 'Adam, Martin & Stevenson, Jim', '', 'Martin Adam & Jim Stevenson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3801, NULL, '2016-12-14 23:21:12.093128+00', 'Beal, Joe & Boothe, Jim', '', 'Joe Beal & Jim Boothe', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10000, NULL, '2016-12-18 00:56:37.597877+00', 'Reel of Seven', 'Reel of Seven', 'Reel of Seven', 'San Francisco, CA, US', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3803, NULL, '2017-03-02 00:23:56.809831+00', 'Styne, Jule', '', 'Jule Styne', '', '', 0, 0, 1, 0, NULL, 1905, 1994, NULL, '');
INSERT INTO 'person' VALUES (3783, NULL, '2017-11-10 20:24:45.524607+00', 'Kobayashi, Shigeyoshi', 'Kobby', 'Shigeyoshi Kobayashi', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3802, NULL, '2017-07-28 03:45:07.350488+00', 'Autry, Gene & Haldeman, Oakley', '', 'Gene Autry & Oakley Haldeman', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10014, NULL, '2012-01-20 12:54:17.535776+00', 'Garton, Joanne', 'Joanne Garton', 'Joanne Garton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10015, NULL, '2012-01-20 12:54:17.539073+00', 'Duval, Jean', 'Jean Duval', 'Jean Duval', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10016, NULL, '2012-01-20 12:54:17.542358+00', 'Nicolson, J', '', 'J Nicolson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10017, NULL, '2012-01-20 12:54:17.545632+00', 'Bell, G', 'G Bell', 'G Bell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10030, NULL, '2012-01-20 12:54:17.588511+00', 'Breton, Eric', '', 'Eric Breton', 'Montreal?, Canada', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10033, NULL, '2012-01-20 12:54:17.598491+00', 'Fraser, P', 'P Fraser', 'P Fraser', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10021, NULL, '2012-01-20 12:54:17.55883+00', 'MacDonald, Iain / Cunningham, Phil', 'Iain / Cunningham, Phil MacDonald', 'Iain / Cunningham, Phil MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10036, NULL, '2012-01-20 12:54:17.608379+00', 'Ingram, Alexander', 'Alexander Ingram', 'Alexander Ingram', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10038, NULL, '2012-01-20 12:54:17.61498+00', 'Coutts, James', 'James Coutts', 'James Coutts', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10024, NULL, '2012-01-20 12:54:17.568723+00', 'Kittel, J', 'J Kittel', 'J Kittel', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10040, NULL, '2012-01-20 12:54:17.621608+00', 'Ichikawa, Hirokazu', 'Hirokazu Ichikawa', 'Hirokazu Ichikawa', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10025, NULL, '2012-01-20 12:54:17.572028+00', 'Pasqua, Calum', 'Calum Pasqua', 'Calum Pasqua', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10041, NULL, '2012-01-20 12:54:17.625087+00', 'David, W', 'W David', 'W David', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10042, NULL, '2012-01-20 12:54:17.631397+00', 'Lyon, E', 'E Lyon', 'E Lyon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10026, NULL, '2012-01-20 12:54:17.575325+00', 'Ross, J', 'J Ross', 'J Ross', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10044, NULL, '2012-01-20 12:54:17.634816+00', 'Little, David', 'David Little', 'David Little', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10027, NULL, '2012-01-20 12:54:17.578614+00', 'Haas, Natalie', '', 'Natalie Haas', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10028, NULL, '2012-01-20 12:54:17.581903+00', 'Schneckenburger, Lissa', '', 'Lissa Schneckenburger', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10045, NULL, '2012-01-20 12:54:17.638111+00', 'West, John', 'John West', 'John West', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10029, NULL, '2012-01-20 12:54:17.585189+00', 'Houghton, Dan', '', 'Dan Houghton', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3794, NULL, '2012-12-07 17:25:52.523382+00', 'Bernard, Felix', '', 'Felix Bernard', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3798, NULL, '2013-01-03 07:41:01.65997+00', 'Osborne, Bruce', '', 'Bruce Osborne', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3766, NULL, '2022-12-23 23:18:56.451118+00', 'Anderson, David', '', 'David Anderson', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10046, NULL, '2012-01-20 12:54:17.641439+00', 'Weir, Lindsay and her Scottish Dance Band', 'Lindsay Weir', 'Lindsay Weir and her Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10047, NULL, '2012-01-20 12:54:17.645653+00', 'Stewart, Liam and his Scottish Dance Band', 'Liam Stewart', 'Liam Stewart and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10048, NULL, '2012-01-20 12:54:17.648961+00', 'Stewart, Liam', 'Liam Stewart', 'Liam Stewart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10049, NULL, '2012-01-20 12:54:17.652256+00', 'Guinchard, Rufus', 'Rufus Guinchard', 'Rufus Guinchard', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10050, NULL, '2012-01-20 12:54:17.655547+00', 'Wark, Jim', 'Jim Wark', 'Jim Wark', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10039, NULL, '2012-01-20 12:54:17.618285+00', 'Gifford, Alan', 'Alan Gifford', 'Alan Gifford', '', '', 0, 0, 1, 0, 10039, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10066, NULL, '2012-01-20 12:54:17.709119+00', 'Langille, Harold E', 'Harold E Langille', 'Harold E Langille', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10051, NULL, '2012-01-20 12:54:17.659641+00', 'Garvin, Colin', 'Colin Garvin', 'Colin Garvin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10068, NULL, '2012-01-20 12:54:17.715732+00', 'Paris, Philip', 'Philip Paris', 'Philip Paris', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10052, NULL, '2012-01-20 12:54:17.663019+00', 'Russell, Willie', 'Willie Russell', 'Willie Russell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10069, NULL, '2012-01-20 12:54:17.719009+00', 'Fraser, S', 'S Fraser', 'S Fraser', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10053, NULL, '2012-01-20 12:54:17.666304+00', 'Paton, P/M J Paton', 'P/M J Paton Paton', 'P/M J Paton Paton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10054, NULL, '2012-01-20 12:54:17.669593+00', 'McLeish, William', 'William McLeish', 'William McLeish', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10055, NULL, '2012-01-20 12:54:17.672886+00', 'Barnet, Tom J', 'Tom J Barnet', 'Tom J Barnet', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10072, NULL, '2012-01-20 12:54:17.728883+00', 'Cassidy, J', 'J Cassidy', 'J Cassidy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10057, NULL, '2012-01-20 12:54:17.679504+00', 'Gillis, W S', 'W S Gillis', 'W S Gillis', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10059, NULL, '2012-01-20 12:54:17.686081+00', 'Winnock, A', 'A Winnock', 'A Winnock', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10078, NULL, '2012-01-20 12:54:17.745496+00', 'McLean, C', 'C McLean', 'C McLean', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10079, NULL, '2012-01-20 12:54:17.748907+00', 'Hamilton, Stan and the Clansmen', 'Stan Hamilton', 'Stan Hamilton and the Clansmen', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10061, NULL, '2012-01-20 12:54:17.692666+00', 'Little, B', 'B Little', 'B Little', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10081, NULL, '2012-01-20 12:54:17.755522+00', 'Cowan, J R', 'J R Cowan', 'J R Cowan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10082, NULL, '2012-01-20 12:54:17.75882+00', 'Burns, J', 'J Burns', 'J Burns', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10062, NULL, '2012-01-20 12:54:17.695963+00', 'Morrison, F', 'F Morrison', 'F Morrison', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10083, NULL, '2012-01-20 12:54:17.762104+00', 'Rice, E', 'E Rice', 'E Rice', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10064, NULL, '2012-01-20 12:54:17.702535+00', 'McCusker, J', 'J McCusker', 'J McCusker', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11633, '2018-04-25 22:48:54.622742+00', '2018-04-25 23:56:23.289842+00', 'South East Herts Scottish Country Dance Society', 'SEHSCDS', 'S E Herts SCDS', 'Hertford, UK', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10084, NULL, '2012-01-20 12:54:17.765397+00', 'Marocco, J', 'J Marocco', 'J Marocco', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10085, NULL, '2012-01-20 12:54:17.768681+00', 'Nicholson, A', 'A Nicholson', 'A Nicholson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10087, NULL, '2012-01-20 12:54:17.775452+00', 'Macdonald, R S', 'R S Macdonald', 'R S Macdonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10020, NULL, '2015-03-25 10:05:27.33848+00', 'Petrov, Susie with The Ladies', 'Susie Petrov', 'Petrov, Susie with The Ladies', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10022, NULL, '2015-03-25 10:05:38.704147+00', 'Petrov, Susie with The Gentlemen', 'Susie Petrov', 'Petrov, Susie with The Gentlemen', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10023, NULL, '2015-03-25 10:06:01.328898+00', 'Petrov, Susie with Les Joueurs de Bon Accord', 'Susie Petrov & Les Joueurs', 'Petrov, Susie with Les Joueurs de Bon Accord', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10037, NULL, '2015-03-25 10:06:51.515874+00', 'Coutts, James and his Scottish Dance Band', 'James Coutts', 'James Coutts and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10070, NULL, '2015-09-24 04:26:50.823029+00', 'Shea, Mara & Wiesler, Dave', 'Shea/Wiesler', 'Mara Shea & Dave Wiesler', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10034, NULL, '2015-10-17 21:42:33.463665+00', 'Brady, Luke Scottish Dance Band', 'Luke Brady', 'Luke Brady''s Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10074, NULL, '2012-01-20 12:54:17.735559+00', 'Huband, J', 'J Huband', 'J Huband', '', '', 0, 0, 1, 0, 1777, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10080, NULL, '2012-01-20 12:54:17.752214+00', 'Blair, Murray', 'Murray Blair', 'Murray Blair', '', '', 0, 0, 1, 0, 10080, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10088, NULL, '2012-01-20 12:54:17.778767+00', 'Symington, Iain', 'I Symington', 'Iain Symington', '', '', 0, 0, 1, 0, 10088, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10104, NULL, '2012-01-20 12:54:17.832653+00', 'Hutson, Ian & his Scottish Dance Band', 'Ian Hutson', 'Ian Hutson & his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10058, NULL, '2019-11-04 18:32:36.801817+00', 'Guest, Bill', 'B Guest', 'Bill Guest', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10031, NULL, '2020-01-21 15:24:06.168717+00', 'Scollay, Margaret', 'Margaret Scollay', 'Margaret Scollay', '', '', 0, 0, 1, 0, 11918, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10089, NULL, '2012-01-20 12:54:17.782057+00', 'Jullien, Louis-Antoine', '', 'Louis Antoine Jullien', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10105, NULL, '2012-01-20 12:54:17.835969+00', 'Hutson, Ian', 'Ian Hutson', 'Ian Hutson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10090, NULL, '2012-01-20 12:54:17.785346+00', 'Bowes, Captain R', '', 'Captain R Bowes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10106, NULL, '2012-01-20 12:54:17.839299+00', 'Halcrow, David', '', 'David Halcrow', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10107, NULL, '2012-01-20 12:54:17.842586+00', 'Vollrath, C', '', 'C Vollrath', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10091, NULL, '2012-01-20 12:54:17.788633+00', 'MacFadyen, Walter', '', 'Walter MacFadyen', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10108, NULL, '2012-01-20 12:54:17.845875+00', 'Fustra, Da', 'Da Fustra', 'Da Fustra', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10092, NULL, '2012-01-20 12:54:17.791915+00', 'Allan, J', '', 'J Allan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10056, NULL, '2014-05-21 06:33:17.647231+00', 'Wood, Donald G', 'Donald G Wood', 'Donald G Wood', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Known familiarly as "Donny Wood"');
INSERT INTO 'person' VALUES (10109, NULL, '2012-01-20 12:54:17.849165+00', 'Barclay, John', 'John Barclay', 'John Barclay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10110, NULL, '2012-01-20 12:54:17.852458+00', 'Hughson, Andrew', 'Andrew Hughson', 'Andrew Hughson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10093, NULL, '2012-01-20 12:54:17.795228+00', 'Allan, T R', '', 'T R Allan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10111, NULL, '2012-01-20 12:54:17.855783+00', 'Sinclair, Peter', 'Peter Sinclair', 'Peter Sinclair', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10094, NULL, '2012-01-20 12:54:17.798508+00', 'Sinclaire, Pipe Corporal C', '', 'Pipe Corporal C Sinclaire', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10113, NULL, '2012-01-20 12:54:17.862407+00', 'Hallet, Nigel', 'Nigel Hallet', 'Nigel Hallet', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11628, '2018-04-25 20:53:54.488302+00', '2018-04-25 23:19:17.512959+00', 'Liggatt, Donald', '', 'Donald Liggatt', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10096, NULL, '2012-01-20 12:54:17.805101+00', 'Arcus, Alex', '', 'Alex Arcus', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10115, NULL, '2012-01-20 12:54:17.869016+00', 'Dewhurst, Chris & Nick', 'Chris & Nick Dewhurst', 'Chris & Nick Dewhurst', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10117, NULL, '2012-01-20 12:54:17.87611+00', 'Ceol na h-Alba', 'Ceol na h-Alba', 'Ceol na h-Alba', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10098, NULL, '2012-01-20 12:54:17.812538+00', 'Malouin, Fortina', '', 'Fortina Malouin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10099, NULL, '2012-01-20 12:54:17.816039+00', 'Soucy, Isidore', '', 'Isidore Soucy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10018, NULL, '2022-12-18 11:01:27.683375+00', 'Muir, Ian and his Scottish Dance Band', 'Ian T Muir', 'Ian Muir and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10086, NULL, '2022-12-23 13:40:09.570986+00', 'Spence, Steven', 'Steven Spence', 'Steven Spence', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'The database had misspelled/alternative entries for "Stephen Spence" and "S Spence" which have been deleted and all merged to this person.');
INSERT INTO 'person' VALUES (10100, NULL, '2012-01-20 12:54:17.819367+00', 'Ouellet, Raynald', '', 'Raynald Ouellet', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10101, NULL, '2012-01-20 12:54:17.822665+00', 'Loch, John', 'John Loch', 'John Loch', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10121, NULL, '2012-01-20 12:54:17.889475+00', 'Stokes, Peter', 'Peter Stokes', 'Peter Stokes', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10122, NULL, '2012-01-20 12:54:17.892824+00', 'Bensa, Enid', 'Enid Bensa', 'Enid Bensa', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10138, NULL, '2012-01-20 12:54:17.946175+00', 'Marchall, William', 'William Marchall', 'William Marchall', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10123, NULL, '2012-01-20 12:54:17.896121+00', 'Pearson, Marion', 'Marion Pearson', 'Marion Pearson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10139, NULL, '2012-01-20 12:54:17.9495+00', 'Anderson', 'Anderson', 'Anderson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10124, NULL, '2012-01-20 12:54:17.900022+00', 'Flockhart, Shauna', 'Shauna Flockhart', 'Shauna Flockhart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10140, NULL, '2012-01-20 12:54:17.952788+00', 'Milne, Doug', 'Doug Milne', 'Doug Milne', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10141, NULL, '2012-01-20 12:54:17.956078+00', 'Wright, Tim and his Scottish Dance Band', 'Tim Wright & Band', 'Tim Wright and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10125, NULL, '2012-01-20 12:54:17.903364+00', 'Sinclair Snr, P/M William', 'P/M William Sinclair Snr', 'P/M William Sinclair Snr', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10142, NULL, '2012-01-20 12:54:17.95939+00', 'Strathearn Scottish Dance Band', 'Strathearn', 'Strathearn Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10126, NULL, '2012-01-20 12:54:17.906654+00', 'Fleming, P/M Ron', 'P/M Ron Fleming', 'P/M Ron Fleming', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10143, NULL, '2012-01-20 12:54:17.962759+00', 'Wood, Chalmers', 'Chalmers Wood', 'Chalmers Wood', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10144, NULL, '2012-01-20 12:54:17.966056+00', 'Nicholson, Jim and his Band', 'Jim Nicholson', 'Jim Nicholson and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10127, NULL, '2012-01-20 12:54:17.90994+00', 'MacIntyre, Patrick', 'Patrick MacIntyre', 'Patrick MacIntyre', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11634, '2018-05-12 20:35:46.793408+00', '2018-05-12 20:49:16.841711+00', 'Ip, Alan', '', 'Alan Ip', 'London, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10145, NULL, '2012-01-20 12:54:17.969354+00', 'MacKay, Gregor and his Band', 'Gregor MacKay', 'Gregor MacKay and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10129, NULL, '2012-01-20 12:54:17.916536+00', 'Peterson, Chris & Hudson, Michael', 'Peterson/Hudson', 'Chris Peterson & Michael Hudson', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10130, NULL, '2012-01-20 12:54:17.919852+00', 'McGarr', 'McGarr', 'McGarr', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10147, NULL, '2012-01-20 12:54:17.975938+00', 'MacPherson, Hamish and his Band', 'Hamish MacPherson', 'Hamish MacPherson and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10148, NULL, '2012-01-20 12:54:17.979238+00', 'Davidson, Peter and his Band', 'Peter Davidson', 'Peter Davidson and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10131, NULL, '2012-01-20 12:54:17.923152+00', 'Weston', 'Weston', 'Weston', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10149, NULL, '2012-01-20 12:54:17.982528+00', 'Vickers, William', 'William Vickers', 'William Vickers', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10132, NULL, '2012-01-20 12:54:17.926437+00', 'Wimperis, A', 'A Wimperis', 'A Wimperis', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10133, NULL, '2012-01-20 12:54:17.929732+00', 'Judge, J', 'J Judge', 'J Judge', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10150, NULL, '2012-01-20 12:54:17.985818+00', 'Gibbons, Joshua', 'Joshua Gibbons', 'Joshua Gibbons', '', '', 0, 0, 1, 0, NULL, 1778, 1871, NULL, '');
INSERT INTO 'person' VALUES (10134, NULL, '2012-01-20 12:54:17.933018+00', 'Hill, R', 'R Hill', 'R Hill', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10135, NULL, '2012-01-20 12:54:17.936311+00', 'Andersson, B', 'B Andersson', 'B Andersson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10136, NULL, '2012-01-20 12:54:17.939601+00', 'Anderson, Keith', 'Keith Anderson', 'Keith Anderson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10137, NULL, '2012-01-20 12:54:17.942895+00', 'Lowthiam', 'Lowthiam', 'Lowthiam', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10152, NULL, '2012-01-20 12:54:17.992416+00', 'Cowan, Jack', 'Jack Cowan', 'Jack Cowan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10153, NULL, '2012-01-20 12:54:17.995703+00', 'Cameron, Lewis', 'Lewis Cameron', 'Lewis Cameron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10154, NULL, '2012-01-20 12:54:17.998995+00', 'Haugen, Arnt', 'Arnt Haugen', 'Arnt Haugen', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10120, NULL, '2015-03-14 18:11:12.176121+00', 'Jennings, Sue', 'Sue Jennings', 'Sue Jennings', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10118, NULL, '2015-03-14 18:11:12.569765+00', 'Jones, Phill', 'Phill Jones', 'Phill Jones', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10112, NULL, '2015-03-14 18:11:19.842809+00', 'Nicolson, Judy', 'Judy Nicolson', 'Judy Nicolson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10151, NULL, '2015-03-14 18:11:22.507051+00', 'Reid, Jenna', 'Jenna Reid', 'Jenna Reid', '', '', 0, 0, 1, 0, NULL, 1995, 0, NULL, '');
INSERT INTO 'person' VALUES (11682, '2018-08-25 08:26:38.99103+00', '2018-08-25 23:56:28.54342+00', 'Swan, Katie', '', 'Katie Swan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10157, NULL, '2012-01-20 12:54:18.005573+00', 'Ceilidh Folk Edinburgh', 'Ceilidh Folk Edinburgh', 'Ceilidh Folk Edinburgh', 'Edinburgh, Scotland', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10170, NULL, '2012-01-20 12:54:18.050182+00', 'Ivanovici, Iosif', 'Iosif Ivanovici', 'Iosif Ivanovici', '', '', 0, 0, 1, 0, NULL, 1845, 1902, NULL, '');
INSERT INTO 'person' VALUES (10171, NULL, '2012-01-20 12:54:18.053594+00', 'Waldteufel, Emile', 'Emile Waldteufel', 'Emile Waldteufel', '', '', 0, 0, 1, 0, NULL, 1837, 1915, NULL, '');
INSERT INTO 'person' VALUES (10172, NULL, '2012-01-20 12:54:18.056956+00', 'Robertson, Stuart', 'Stuart Robertson', 'Stuart Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10159, NULL, '2012-01-20 12:54:18.012163+00', 'McCulloch, K', '', 'K McCulloch', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10116, NULL, '2021-01-06 00:56:21.647335+00', 'Dewhurst, Nick', 'Nick Dewhurst', 'Nick Dewhurst', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10097, NULL, '2020-01-16 00:56:03.041933+00', 'Alderton, Rob', '', 'Rob Alderton', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10095, NULL, '2020-01-19 21:57:08.91572+00', 'Robertson, Ian & Alderton, Rob', 'Robertson&Alderton', 'Ian Robertson & Rob Alderton', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10160, NULL, '2012-01-20 12:54:18.015447+00', 'Wendel, J', 'J Wendel', 'J Wendel', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10175, NULL, '2012-01-20 12:54:18.063564+00', 'Endo', 'Endo', 'Endo', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10161, NULL, '2012-01-20 12:54:18.018754+00', 'McKelvie, Calum', 'C McKelvie', 'Calum McKelvie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10177, NULL, '2012-01-20 12:54:18.070182+00', 'Rennie, George Scottish Dance Band', 'George Rennie', 'George Rennie Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10162, NULL, '2012-01-20 12:54:18.02209+00', 'Fulton, Ricky', 'Ricky Fulton', 'Ricky Fulton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10178, NULL, '2012-01-20 12:54:18.073484+00', 'Martin, Dean', 'Dean Martin', 'Dean Martin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10179, NULL, '2012-01-20 12:54:18.076788+00', 'Karlin, Fred', 'Fred Karlin', 'Fred Karlin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10163, NULL, '2012-01-20 12:54:18.025396+00', 'Muir, Alex', 'Alex Muir', 'Alex Muir', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10180, NULL, '2012-01-20 12:54:18.080086+00', 'Hall, David A', 'David A Hall', 'David A Hall', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10164, NULL, '2012-01-20 12:54:18.028694+00', 'MacKay, KC & AC', 'KC & AC MacKay', 'KC & AC MacKay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10181, NULL, '2012-01-20 12:54:18.083458+00', 'Ruby, H', 'H Ruby', 'H Ruby', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10182, NULL, '2012-01-20 12:54:18.086749+00', 'Scherzinger, Victor', 'Victor Scherzinger', 'Victor Scherzinger', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10165, NULL, '2012-01-20 12:54:18.031979+00', 'Cameron, James', 'James Cameron', 'James Cameron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10183, NULL, '2012-01-20 12:54:18.09003+00', 'McGlynn, Fraser and his Scottish Dance Band', 'Fraser McGlynn & Band', 'Fraser McGlynn and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10166, NULL, '2012-01-20 12:54:18.035343+00', 'Greer, Philip', 'Philip Greer', 'Philip Greer', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10184, NULL, '2012-01-20 12:54:18.093342+00', 'Scollay, Allan', 'Allan Scollay', 'Allan Scollay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10168, NULL, '2012-01-20 12:54:18.042817+00', 'MacMillan, A', 'A MacMillan', 'A MacMillan', 'Colonsay', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10169, NULL, '2012-01-20 12:54:18.046166+00', 'Strauss, Johann Jnr', '', 'Johann Strauss Jnr', '', '', 0, 0, 1, 0, NULL, 1825, 1899, NULL, '');
INSERT INTO 'person' VALUES (10185, NULL, '2012-01-20 12:54:18.09702+00', 'Smith, Keith and James Gray', 'K Smith & J Gray', 'Keith Smith and James Gray', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10186, NULL, '2012-01-20 12:54:18.100355+00', 'Crawford, John with the Gleneden Scottish Band', 'John Crawford', 'John Crawford with the Gleneden Scottish Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10187, NULL, '2012-01-20 12:54:18.103659+00', 'Ringsted', 'Ringsted', 'Ringsted', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10189, NULL, '2012-01-20 12:54:18.110228+00', 'Grimshaw', '', 'Grimshaw', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10190, NULL, '2012-01-20 12:54:18.113507+00', 'Sutton, James', 'J Sutton', 'James Sutton', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10191, NULL, '2012-01-20 12:54:18.116823+00', 'Innes, Mike', 'M Innes', 'Mike Innes', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10192, NULL, '2012-01-20 12:54:18.120108+00', 'MacDonell, A', '', 'A MacDonell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10193, NULL, '2012-01-20 12:54:18.123398+00', 'Morton, Bob', '', 'Bob Morton', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10174, NULL, '2012-01-20 12:54:18.060266+00', 'Taki, Rentaro', 'Rentaro Taki', 'Rentaro Taki', '', '', 0, 0, 1, 0, 10174, 1879, 1903, NULL, '');
INSERT INTO 'person' VALUES (10211, NULL, '2012-01-20 12:54:18.19915+00', 'MacMillan, Neil', '', 'Neil MacMillan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10194, NULL, '2012-01-20 12:54:18.126688+00', 'Telford, Andrew', '', 'Andrew Telford', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10213, NULL, '2012-01-20 12:54:18.205849+00', 'McDiarmid, Duncan', '', 'Duncan McDiarmid', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10195, NULL, '2012-01-20 12:54:18.129974+00', 'Trougatt, W', '', 'W Trougatt', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10215, NULL, '2012-01-20 12:54:18.213501+00', 'Butterfield, James', '', 'James Butterfield', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10196, NULL, '2012-01-20 12:54:18.133251+00', 'Ganam, K', '', 'K Ganam', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10197, NULL, '2012-01-20 12:54:18.136553+00', 'Spencer, L', '', 'L Spencer', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10217, NULL, '2012-01-20 12:54:18.218687+00', 'Immel, J E', '', 'J E Immel', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10218, NULL, '2012-01-20 12:54:18.221246+00', 'Jolson, Al/Bud DeSylva/Joseph Myers', '', 'Al Jolson/Bud DeSylva/Joseph Myers', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10198, NULL, '2012-01-20 12:54:18.139847+00', 'McCallum, Duncan', '', 'Duncan McCallum', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10219, NULL, '2012-01-20 12:54:18.223933+00', 'Gershwin, George', '', 'George Gershwin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10199, NULL, '2012-01-20 12:54:18.143136+00', 'Sinclair, A', '', 'A Sinclair', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10220, NULL, '2012-01-20 12:54:18.226503+00', 'Wrubel, Allie', '', 'Allie Wrubel', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10221, NULL, '2012-01-20 12:54:18.229044+00', 'Darnell, Jeff', '', 'Jeff Darnell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10200, NULL, '2012-01-20 12:54:18.151575+00', 'Perth Strathspey & Reel Society', '', 'Perth Strathspey & Reel Society', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10222, NULL, '2012-01-20 12:54:18.231589+00', 'Dvorak, A/C Hand', '', 'A Dvorak/C Hand', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10224, NULL, '2012-01-20 12:54:18.236814+00', 'Alexander, T', '', 'T Alexander', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10202, NULL, '2012-01-20 12:54:18.160368+00', 'Sinclair, Norrie', '', 'Norrie Sinclair', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10225, NULL, '2012-01-20 12:54:18.239349+00', 'Morrison, Brian', '', 'Brian Morrison', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10205, NULL, '2012-01-20 12:54:18.18068+00', 'Cooper, Jim', 'Jim Cooper', 'Jim Cooper', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10206, NULL, '2012-01-20 12:54:18.184253+00', 'McGillivray, J', 'J McGillivray', 'J McGillivray', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10226, NULL, '2012-01-20 12:54:18.241878+00', 'Cass, R/Climies, R', '', 'R Cass / R Climies', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10207, NULL, '2012-01-20 12:54:18.188446+00', 'Wolanski, Rob', 'Rob Wolanski', 'Rob Wolanski', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10208, NULL, '2012-01-20 12:54:18.191872+00', 'Taylor, Barbara', '', 'Barbara Taylor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10227, NULL, '2012-01-20 12:54:18.244425+00', 'Brown, Colin', '', 'Colin Brown', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10228, NULL, '2012-01-20 12:54:18.24696+00', 'Vejvoda, Jaromir', '', 'Jaromir Vejvoda', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10229, NULL, '2012-01-20 12:54:18.249495+00', 'Rodgers, Richard / Hammerstein, Oscar', '', 'Richard Rodgers / Oscar Hammerstein', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10230, NULL, '2012-01-20 12:54:18.25203+00', 'Alford, Kenneth', '', 'Kenneth Alford', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10216, NULL, '2015-03-14 18:11:15.064934+00', 'MacFarlane, Jim', '', 'Jim MacFarlane', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10214, NULL, '2015-03-14 18:11:22.824698+00', 'Rimbault, Dr E. F.', '', 'Dr E. F. Rimbault', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10188, NULL, '2015-03-14 18:11:27.289331+00', 'Thomas/Marbel', '', 'Thomas/Marbel', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10158, NULL, '2015-03-14 18:11:28.854476+00', 'Wendell, J', '', 'J Wendell', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10212, NULL, '2015-03-14 18:11:29.63593+00', 'Wilson, Robert', '', 'Robert Wilson', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10167, NULL, '2017-08-27 00:34:36.446131+00', 'Adams, Neil', '', 'Neil Adams', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10201, NULL, '2017-08-27 00:37:03.015645+00', 'MacIntyre, George', '', 'George MacIntyre', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11685, '2018-08-25 08:31:41.843023+00', '2018-08-25 23:56:11.343571+00', 'Eddie, Carol', '', 'Carol Eddie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11684, '2018-08-25 08:29:36.922083+00', '2019-04-17 14:55:30.350661+00', 'French, Sandra', '', 'Sandra French', 'RSCDS Kirkcaldy and Dunfermline Branches', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10231, NULL, '2012-01-20 12:54:18.254571+00', 'MacArthur, W', '', 'W MacArthur', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10232, NULL, '2012-01-20 12:54:18.257104+00', 'Chabrier, Emmanuel', '', 'Emmanuel Chabrier', '', '', 0, 0, 1, 0, NULL, 1841, 1894, NULL, '');
INSERT INTO 'person' VALUES (10234, NULL, '2012-01-20 12:54:18.262204+00', 'MacLeod, D', '', 'D MacLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10235, NULL, '2012-01-20 12:54:18.26473+00', 'McGurr', '', 'McGurr', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10250, NULL, '2012-01-20 12:54:18.301761+00', 'Forbes, Gordon', 'Gordon Forbes', 'Gordon Forbes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10251, NULL, '2012-01-20 12:54:18.304359+00', 'Douglas, Bill', 'Bill Douglas', 'Bill Douglas', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10252, NULL, '2012-01-20 12:54:18.306905+00', 'Young, Angela', 'Angela Young', 'Angela Young', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10483, NULL, '2012-01-20 12:54:18.978292+00', 'Miss Sharpe', '', 'Miss Sharpe', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10237, NULL, '2012-01-20 12:54:18.270306+00', 'McLaren, Nicol and his Scottish Dance Band', 'Nicol McLaren', 'Nicol McLaren and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10253, NULL, '2012-01-20 12:54:18.309437+00', 'Reavell, M', '', 'M Reavell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10238, NULL, '2012-01-20 12:54:18.272907+00', 'RSCDS Ribble Valley Branch', 'RSCDS Ribble Valley', 'RSCDS Ribble Valley Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10254, NULL, '2012-01-20 12:54:18.311974+00', 'Phillips, Stella', '', 'Stella Phillips', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10255, NULL, '2012-01-20 12:54:18.314697+00', 'Young, Doris, and dancers of Airyhall class of RSCDS Aberdeen Branch', 'Doris Young & dancers of class', 'Doris Young and dancers of Airyhall class of RSCDS Aberdeen Branch', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10240, NULL, '2012-01-20 12:54:18.275462+00', 'Burrows, Jill', '', 'Jill Burrows', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10256, NULL, '2012-01-20 12:54:18.317382+00', 'New Zealand children''s class Margaret McMurtry', '', 'Children of Margaret McMurtry''s class in New Zealand', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10241, NULL, '2012-01-20 12:54:18.277994+00', 'Morris, Lavinia', '', 'Lavinia Morris', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10257, NULL, '2012-01-20 12:54:18.319986+00', 'Daughrty, J', 'J Daughrty', 'J Daughrty', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10258, NULL, '2012-01-20 12:54:18.322672+00', 'Hebert, B', '', 'B Hebert', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10242, NULL, '2012-01-20 12:54:18.280522+00', 'Grant, Linda', '', 'Linda Grant', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10259, NULL, '2012-01-20 12:54:18.325339+00', 'Hepworth, D', '', 'D Hepworth', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (17, NULL, '2018-06-18 14:21:30.888067+00', 'Sheffield, Martin', '', 'Martin Sheffield', 'Torremolinos, Spain', 'mj.sheffield@wanadoo.fr', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Martin Sheffield has taught SCD for many years in Great Britain and France.



Now retired he is living in Andalusia, Spain, and continues teaching SCD in Torremolinos on the Costa del Sol of the Mediterranean.



He also has devised a large number of scottish country dances. Among those for example Genevieve''s Jig that was published in RSCDS Book 32.');
INSERT INTO 'person' VALUES (10260, NULL, '2012-01-20 12:54:18.327881+00', 'Wilkie, P', '', 'P Wilkie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10261, NULL, '2012-01-20 12:54:18.330416+00', 'Arsenault, Eddy', '', 'Eddy Arsenault', '', '', 0, 0, 1, 0, NULL, 1921, 0, NULL, '');
INSERT INTO 'person' VALUES (10244, NULL, '2012-01-20 12:54:18.286252+00', 'Waddington, Chris', '', 'Chris Waddington', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10262, NULL, '2012-01-20 12:54:18.33295+00', 'Reavy, Ed', '', 'Ed Reavy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10245, NULL, '2012-01-20 12:54:18.288873+00', 'Middleton, Jeff', '', 'Jeff Middleton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10233, NULL, '2013-02-18 02:43:27.637339+00', 'Bruce, Peter', '', 'Peter Bruce', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (10246, NULL, '2012-01-20 12:54:18.291428+00', 'Weatherstone, J.C.', '', 'J.C. Weatherstone', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10247, NULL, '2012-01-20 12:54:18.293956+00', 'Craigievar Scottish Dance Band', 'Craigievar', 'Craigievar Scottish Dance Band', '', 'craigievarband@aol.com', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10264, NULL, '2012-01-20 12:54:18.338003+00', 'Murray, A', '', 'A Murray', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10248, NULL, '2012-01-20 12:54:18.296502+00', 'Lyon, Andrew Scottish Dance Band', 'Andrew Lyon', 'Andrew Lyon''s Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10265, NULL, '2012-01-20 12:54:18.340534+00', 'Marks/Simons', '', 'Marks/Simons', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10266, NULL, '2012-01-20 12:54:18.343203+00', 'Gershwin,George', 'Gershwin,George', 'Gershwin,George', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10267, NULL, '2012-01-20 12:54:18.345813+00', 'Hannah, William and his Band', 'William Hannah', 'William Hannah and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10268, NULL, '2012-01-20 12:54:18.348497+00', 'Lochside Ceilidh Band, The', 'Lochside', 'The Lochside Ceilidh Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10269, NULL, '2012-01-20 12:54:18.351262+00', 'Emblow, Jack', '', 'Jack Emblow', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10270, NULL, '2012-01-20 12:54:18.353885+00', 'Farnan, Peter', '', 'Peter Farnan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10271, NULL, '2012-01-20 12:54:18.356435+00', 'Bassmann, George', '', 'George Bassmann', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10273, NULL, '2012-01-20 12:54:18.361516+00', 'Starr, Will and his Band', '', 'Will Starr and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10274, NULL, '2012-01-20 12:54:18.364159+00', 'Hawthorne Accordion Band, The', 'Hawthorne', 'The Hawthorne Accordion Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10275, NULL, '2012-01-20 12:54:18.366757+00', 'Whitson, Freidman', '', 'Freidman Whitson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10276, NULL, '2012-01-20 12:54:18.369466+00', 'Smith, Laura R / J S Fearis', '', 'Laura R Smith / J S Fearis', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10277, NULL, '2012-01-20 12:54:18.372167+00', 'Hendry, Bill Dance Band', 'Bill Hendry', 'Bill Hendry Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10295, NULL, '2012-01-20 12:54:18.420553+00', 'Youngman, Brian', '', 'Brian Youngman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10278, NULL, '2012-01-20 12:54:18.374841+00', 'Hutchison, Kenny', '', 'Kenny Hutchison', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10279, NULL, '2012-01-20 12:54:18.377501+00', 'Dickson, Keith', '', 'Keith Dickson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10297, NULL, '2012-01-20 12:54:18.425634+00', 'Glenn-Lewis, Margo', '', 'Margo Glenn-Lewis', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10280, NULL, '2012-01-20 12:54:18.380174+00', 'Hadjidakis, Manos', '', 'Manos Hadjidakis', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10281, NULL, '2012-01-20 12:54:18.38274+00', 'Timothy, Al / Michael Julien', '', 'Al Timothy / Michael Julien', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10298, NULL, '2012-01-20 12:54:18.428173+00', 'Van Otterloo, E B', '', 'E B Van Otterloo', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10282, NULL, '2012-01-20 12:54:18.385274+00', 'Irvine, Linda', '', 'Linda Irvine', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10283, NULL, '2012-01-20 12:54:18.387852+00', 'Shannon, J', 'J Shannon', 'J Shannon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10299, NULL, '2012-01-20 12:54:18.434966+00', 'Lockwood, Lynne', '', 'Lynne Lockwood', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10284, NULL, '2012-01-20 12:54:18.390389+00', 'Williams, Roger', 'R Williams', 'Roger Williams', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10300, NULL, '2012-01-20 12:54:18.438432+00', 'Kesler, Sandra', '', 'Sandra Kesler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10302, NULL, '2012-01-20 12:54:18.441814+00', 'Dunlay, Kate', 'Kate Dunlay', 'Kate Dunlay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10303, NULL, '2012-01-20 12:54:18.445323+00', 'Randle, Bob', 'B Randle', 'Bob Randle', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10304, NULL, '2012-01-20 12:54:18.44877+00', 'Tully, Norman', 'N Tully', 'Norman Tully', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10305, NULL, '2012-01-20 12:54:18.452217+00', 'Forrester, Jamie', 'J Forrester', 'Jamie Forrester', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10286, NULL, '2015-03-14 18:11:26.288671+00', 'Steiner, Stefan ''Stoney''', '', 'Stefan ''Stoney'' Steiner', 'Vienna, Austria', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10292, NULL, '2015-09-24 03:57:09.019084+00', 'Hamelbeck, Felix & Wepner, Beatrix', '', 'Felix Hamelbeck and Beatrix Wepner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10294, NULL, '2015-09-24 04:18:35.087486+00', 'Murray, Ann', '', 'Ann Murray', 'Vienna, Austria', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10288, NULL, '2015-09-24 04:03:45.690582+00', 'Wepner, Beatrix (Bexi)', '', 'Beatrix (Bexi) Wepner', 'Vienna, Austria', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10289, NULL, '2015-09-24 04:05:41.051298+00', 'Wepner, Beatrix & Fergusson, Veronica', '', 'Beatrix Wepner and Veronica Fergusson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10306, NULL, '2012-01-31 11:43:13.618379+00', 'Colquhoun, Cpt. Andy / Colquhoun, Lt. Rob', 'A Colquhoun / R Colquhoun', 'Cpt. Andy Colquhoun / Lt. Rob Colquhoun', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10318, NULL, '2012-01-20 12:54:18.495263+00', 'Yates, Eilean', '', 'Eilean Yates', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10319, NULL, '2012-01-20 12:54:18.498615+00', 'Clarke, Joseph', '', 'Joseph Clarke', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10320, NULL, '2012-01-20 12:54:18.501918+00', 'Dorsey, Dawn W', '', 'Dawn W Dorsey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10307, NULL, '2012-01-20 12:54:18.458858+00', 'Ibbotson, Tom', '', 'Tom Ibbotson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10322, NULL, '2012-01-20 12:54:18.508553+00', 'Celtic Cross Dancers', '', 'Celtic Cross Dancers', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10308, NULL, '2012-01-20 12:54:18.462166+00', 'Walsham, Lindsey', '', 'Lindsey Walsham', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10324, NULL, '2012-01-20 12:54:18.515175+00', 'Inverness and District Branch RSCDS', '', 'Inverness and District Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10326, NULL, '2012-01-20 12:54:18.524413+00', 'Paris, C', '', 'C Paris', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10311, NULL, '2012-01-20 12:54:18.472089+00', 'Clarke, Larry', '', 'Larry Clarke', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10370, NULL, '2018-04-17 23:56:12.227292+00', 'Gunnarsson, M', '', 'M Gunnarsson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10328, NULL, '2012-01-20 12:54:18.531723+00', 'Ross, M', '', 'M Ross', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10312, NULL, '2012-01-20 12:54:18.475392+00', 'Peterkin, Andrew Blance', '', 'Andrew Blance Peterkin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10313, NULL, '2012-01-20 12:54:18.478675+00', 'Sleight, Brenda', '', 'Brenda Sleight', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11644, '2018-06-19 16:10:23.64815+00', '2018-06-19 16:19:33.631544+00', 'Arnoux, Jacques', '', 'Jacques Arnoux', 'La Mure, France', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10314, NULL, '2012-01-20 12:54:18.481971+00', 'McConnell Campbell, Mary & Gallamore, Sandy', '', 'Mary McConnell Campbell & Sandy Gallamore', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10332, NULL, '2012-01-20 12:54:18.544875+00', 'Ferguson, Shirley', '', 'Shirley Ferguson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10315, NULL, '2012-01-20 12:54:18.485287+00', 'Anderson, Paul', '', 'Paul Anderson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10316, NULL, '2012-01-20 12:54:18.488606+00', 'Thistle School of Scottish Country Dance', 'Thistle School', 'Thistle School of Scottish Country Dance', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10333, NULL, '2012-01-20 12:54:18.548192+00', 'Fletcher, John', '', 'John Fletcher', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10317, NULL, '2012-01-20 12:54:18.491969+00', 'Robertson, Judy', '', 'Judy Robertson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10334, NULL, '2012-01-20 12:54:18.551514+00', 'Houliston', '', 'Houliston', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10335, NULL, '2012-01-20 12:54:18.554138+00', 'Thompson, Micah', '', 'Micah Thompson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10336, NULL, '2012-01-20 12:54:18.556675+00', 'Scott, Gordon', '', 'Gordon Scott', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10338, NULL, '2012-01-20 12:54:18.564508+00', 'Loveland, Peter', '', 'Peter Loveland', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10340, NULL, '2012-01-20 12:54:18.57128+00', 'Tulloch, Bobby', '', 'Bobby Tulloch', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10356, NULL, '2012-01-20 12:54:18.608993+00', 'Okada Naitoh, Masako (Marchan)', 'Marchan', 'Masako (Marchan) Okada Naitoh', 'Tokyo', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10357, NULL, '2012-01-20 12:54:18.611538+00', 'Bluebell Dancers', '', 'Bluebell Dancers', 'Tokyo', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10358, NULL, '2012-01-20 12:54:18.614063+00', 'Hirota, Ryutaro', '', 'Ryutaro Hirota', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10342, NULL, '2012-01-20 12:54:18.577849+00', 'Bruce, Allan', '', 'Allan Bruce', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10343, NULL, '2012-01-20 12:54:18.580998+00', 'Boegborn, Ali', '', 'Ali Boegborn', 'Geldermalsen, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10360, NULL, '2012-01-20 12:54:18.61912+00', 'Brogan, Teresa', '', 'Brogan, T', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10361, NULL, '2012-01-20 12:54:18.621788+00', 'Norwich Branch RSCDS', '', 'Norwich Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10344, NULL, '2012-01-20 12:54:18.583592+00', 'Geldermalsen Scottish Country Dance Group', 'Geldermalsen SCDG', 'Geldermalsen SCDG', 'Geldermalsen, Netherlands', '', 0, 1, 0, 0, NULL, 1986, 0, NULL, '');
INSERT INTO 'person' VALUES (10362, NULL, '2012-01-20 12:54:18.62436+00', 'Belshaw, Roger', '', 'Roger Belshaw', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10363, NULL, '2012-01-20 12:54:18.627269+00', 'Daniels, Marean', '', 'Marean Daniels', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10364, NULL, '2012-01-20 12:54:18.629873+00', 'Carpenter, Sheila', '', 'Sheila Carpenter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10348, NULL, '2012-01-20 12:54:18.588701+00', 'Roos, Inge', '', 'Inge Roos', 'Geldermalsen, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10365, NULL, '2012-01-20 12:54:18.632992+00', 'Bride, Pat and Daniels, Marean', '', 'Pat Bride and Marean Daniels', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10349, NULL, '2012-01-20 12:54:18.591234+00', 'Stroet, Piet', '', 'Piet Stroet', 'Soest, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10366, NULL, '2012-01-20 12:54:18.635591+00', 'Saunderson, Anne', '', 'Anne Saunderson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10367, NULL, '2012-01-20 12:54:18.638124+00', 'Sheehan, Duncan', '', 'Duncan Sheehan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10350, NULL, '2012-01-20 12:54:18.593765+00', 'van der Kamp, Wim', '', 'Wim van der Kamp', 'Geldermalsen, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10368, NULL, '2012-01-20 12:54:18.640674+00', 'McManus, Susan and Ian', '', 'Susan and Ian McManus', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10351, NULL, '2012-01-20 12:54:18.596337+00', 'Reitsma, Rinie', '', 'Rinie Reitsma', 'Geldermalsen, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10369, NULL, '2012-01-20 12:54:18.64385+00', 'Sibilia, Gwynneth and Judson, Jack', '', 'Gwynneth Sibilia and Jack Judson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10352, NULL, '2012-01-20 12:54:18.59887+00', 'Kramer, Jannie', '', 'Jannie Kramer', 'Geldermalsen, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10354, NULL, '2012-01-20 12:54:18.603932+00', 'Delsink, Kitty', '', 'Kitty Delsink', 'Geldermalsen, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10355, NULL, '2012-01-20 12:54:18.606459+00', 'van Nimwegen, Tilly', '', 'Tilly van Nimwegen', 'Geldermalsen, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10372, NULL, '2012-01-20 12:54:18.652054+00', 'Blair, Patricia', '', 'Patricia Blair', 'Chemainus, British Columbia, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10374, NULL, '2012-01-20 12:54:18.657111+00', 'Emslie, Louis', '', 'Louis Emslie', 'Kitchener-Waterloo, ON, CA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10394, NULL, '2012-01-20 12:54:18.704307+00', 'Mackenzie, Liz', '', 'Liz Mackenzie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10395, NULL, '2012-01-20 12:54:18.706853+00', 'Hill, Margaret', '', 'Margaret Hill', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10396, NULL, '2012-01-20 12:54:18.709381+00', 'Branch, Manchester', '', 'Manchester Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10378, NULL, '2012-01-20 12:54:18.668242+00', 'Wentworth, Janet', '', 'Janet Wentworth', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10353, NULL, '2015-03-14 18:11:11.217194+00', 'Hootzen, Arie', '', 'Arie Hootzen', 'Geldermalsen, Netherlands', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10323, NULL, '2018-11-15 00:56:27.109109+00', 'Renton, Janet', '', 'Janet Renton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10330, NULL, '2015-03-25 09:59:33.689787+00', 'Muir, Ian and the Craigellachie Band', 'Craigellachie Band', 'Ian Muir and the Craigellachie Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10337, NULL, '2015-07-20 14:22:54.801113+00', 'Browne, John', '', 'John Browne', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10375, NULL, '2018-10-29 16:40:20.208179+00', 'Hamilton, Patricia', '', 'Patricia Hamilton', 'Wembley, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10309, NULL, '2015-09-24 04:02:31.887438+00', 'Schmidt, Heiko A & Wepner, Beatrix', '', 'Heiko A Schmidt / Beatrix Wepner', 'Vienna, Austria', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10398, NULL, '2012-01-20 12:54:18.714603+00', 'Saxton, Ishbel', '', 'Ishbel Saxton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11646, '2018-06-23 13:11:43.207106+00', '2018-06-23 13:11:43.207106+00', 'Kongsted, Jonas', '', 'Jonas Kongsted', 'Denmark', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10399, NULL, '2012-01-20 12:54:18.71714+00', 'Freer, Helen', '', 'Helen Freer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10382, NULL, '2012-01-20 12:54:18.675879+00', 'Frame, Helen', '', 'Helen Frame', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10400, NULL, '2012-01-20 12:54:18.719672+00', 'Handley, Barbara', '', 'Barbara Handley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10383, NULL, '2012-01-20 12:54:18.678406+00', 'West, Sheila', '', 'Sheila West', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10401, NULL, '2012-01-20 12:54:18.722202+00', 'Trigg, John', '', 'John Trigg', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10402, NULL, '2012-01-20 12:54:18.724731+00', 'Branch, New Zealand', '', 'New Zealand Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10403, NULL, '2012-01-20 12:54:18.727337+00', 'Craven and Turton, Norma and Sandra', '', 'Norma Craven and Sandra Turton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11645, '2018-06-23 13:09:55.040228+00', '2020-01-04 00:56:37.568463+00', 'Lees, Kevin', '', 'Kevin Lees', 'Denmark', '', 1, 0, 1, 1, NULL, 0, 0, NULL, 'Also known as Kev Lees');
INSERT INTO 'person' VALUES (10310, NULL, '2020-03-23 17:38:32.620006+00', 'Dorsey, Dawn W & Messner, Bob', '', 'Dawn W Dorsey & Bob Messner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10386, NULL, '2012-01-20 12:54:18.683496+00', 'Walsham, Lyndsey', '', 'Lyndsey Walsham', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10405, NULL, '2012-01-20 12:54:18.732404+00', 'Brackett, Joseph', '', 'Joseph Brackett', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10406, NULL, '2012-01-20 12:54:18.734934+00', 'School, Stanley Primary', '', 'Stanley Primary School', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10359, NULL, '2013-02-14 00:47:24.018787+00', 'Henricksen, Jill', '', 'Jill Henricksen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10408, NULL, '2012-01-20 12:54:18.739989+00', 'Taylor, Alec', '', 'Alec Taylor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10389, NULL, '2012-01-20 12:54:18.69167+00', 'Emerson, Pamela', '', 'Pamela Emerson', 'Belfast, N. Ireland', 'pamelaemerson5@hotmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11701, '2018-09-09 20:50:24.955808+00', '2018-09-09 23:56:23.238681+00', 'RSCDS Wirral Children''s Class', '', 'RSCDS Wirral Children''s Class', 'Wirral', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10412, NULL, '2012-01-20 12:54:18.747717+00', 'Couvillion, Yvonne', '', 'Yvonne Couvillion', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10377, NULL, '2018-10-29 16:40:40.036051+00', 'MacLennan-Brown, Iain', '', 'Iain MacLennan-Brown', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10414, NULL, '2012-01-20 12:54:18.752802+00', 'Marshall, Valerie', '', 'Valerie Marshall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10407, NULL, '2018-10-29 16:40:59.526044+00', 'Club, Scone SCD', '', 'Scone SCD Club', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10417, NULL, '2012-01-20 12:54:18.759333+00', 'Johnson, Linnea', '', 'Linnea Johnson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10418, NULL, '2012-01-20 12:54:18.762779+00', 'Normand-Harris, David', '', 'David Normand-Harris', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10436, NULL, '2012-01-20 12:54:18.822205+00', 'Stewart, Ann', '', 'Ann Stewart', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10437, NULL, '2012-01-20 12:54:18.825482+00', 'Austin, Lilian', '', 'Lilian Austin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10438, NULL, '2012-01-20 12:54:18.82876+00', 'Kerby, Pauline', '', 'Pauline Kerby', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10439, NULL, '2012-01-20 12:54:18.832045+00', 'Austin, David', '', 'David Austin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10440, NULL, '2012-01-20 12:54:18.83534+00', 'Hancock, Margery', '', 'Margery Hancock', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10422, NULL, '2012-01-20 12:54:18.776271+00', 'Pelletier, Sylvain', '', 'Sylvain Pelletier', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10443, NULL, '2012-01-20 12:54:18.845145+00', 'Sanders, Margaret', '', 'Margaret Sanders', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10424, NULL, '2012-01-20 12:54:18.782834+00', 'Robson, Rachel', '', 'Rachel Robson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10444, NULL, '2012-01-20 12:54:18.848415+00', 'Barrowman, Meg', '', 'Meg Barrowman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10445, NULL, '2012-01-20 12:54:18.851686+00', 'Williams, Norrie', '', 'Norrie Williams', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10425, NULL, '2012-01-20 12:54:18.786105+00', 'Jones, Liz', '', 'Liz Jones', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10446, NULL, '2012-01-20 12:54:18.854954+00', 'Proven, Walter', '', 'Walter Proven', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10426, NULL, '2012-01-20 12:54:18.789378+00', 'Garside, Linda', '', 'Linda Garside', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10427, NULL, '2012-01-20 12:54:18.79266+00', 'Shibasaki, Yoshi', '', 'Yoshi Shibasaki', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10447, NULL, '2012-01-20 12:54:18.858213+00', 'Morley, Jill', '', 'Jill Morley', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10430, NULL, '2012-01-20 12:54:18.8025+00', 'Howard, Lori', '', 'Lori Howard', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10448, NULL, '2012-01-20 12:54:18.861483+00', 'Society, Waverley Scottish', '', 'Waverly Scottish Society', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10431, NULL, '2012-01-20 12:54:18.80578+00', 'Carapanos, Julia', '', 'Julia Carapanos', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10449, NULL, '2012-01-20 12:54:18.86483+00', 'Crawford, William', '', 'William Crawford', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10450, NULL, '2012-01-20 12:54:18.868115+00', 'MacLellan, Norma', '', 'Norma MacLellan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10452, NULL, '2012-01-20 12:54:18.875146+00', 'Club, Keighley SCD', '', 'Keighley SCD Club', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10453, NULL, '2012-01-20 12:54:18.878534+00', 'Godwin, Christine', '', 'Chris Godwin (Christine)', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10454, NULL, '2012-01-20 12:54:18.881848+00', 'Baldwin, Mimi', '', 'Mimi Baldwin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10455, NULL, '2012-01-20 12:54:18.885188+00', 'Oliver, J', '', 'J Oliver', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10472, NULL, '2012-01-20 12:54:18.941982+00', 'Seager, Diane', '', 'Diane Seager', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10456, NULL, '2012-01-20 12:54:18.888475+00', 'Dancers, Argyll', '', 'Argyll Dancers', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10393, NULL, '2015-03-14 18:11:01.507178+00', 'Branch, Canberra', '', 'Canberra Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10433, NULL, '2017-02-27 14:07:27.912715+00', 'Wallace, Frances', '', 'Frances Wallace', '', 'drywall@optusnet.com.au', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10384, NULL, '2015-03-14 18:11:13.075412+00', 'Kerr, Aileen', '', 'Aileen Kerr', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10410, NULL, '2015-03-14 18:11:15.214496+00', 'MacGregor, EB Van Otterloo and Kevin', '', 'EB Van Otterloo and K MacGregor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10339, NULL, '2015-03-14 18:11:19.192432+00', 'Muir, Judith', '', 'Judith Muir', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10420, NULL, '2015-09-24 04:27:34.400184+00', 'Herbold & Twhigg', '', 'Herbold & Twhigg', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10419, NULL, '2015-03-14 18:11:19.356253+00', 'Murphy, Nancy', '', 'Nancy Murphy', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10416, NULL, '2015-03-14 18:11:20.049289+00', 'O''Brien, Pat & Susie Langdon Kass', '', 'S L Kass & P O''Brien', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10423, NULL, '2015-03-14 18:11:22.453545+00', 'Reeves, Michael', '', 'Michael Reeves', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10475, NULL, '2015-03-14 18:11:23.731643+00', 'RSCDS and ABF', '', 'RSCDS and ABF', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10421, NULL, '2015-03-14 18:11:28.424853+00', 'Wallace, Melinda', '', 'Melinda Wallace', '', '', 1, 0, 0, 0, 3343, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10411, NULL, '2015-03-14 18:11:29.87261+00', 'Wood, McCarty, Van Otterloo &', '', 'McCarty, Van Otterloo & Wood', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10387, NULL, '2015-03-29 01:08:57.338613+00', 'Mulholland, Lucy', '', 'Lucy Mulholland', 'Belfast area, N. Ireland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10429, NULL, '2019-09-16 23:56:07.704751+00', 'Dancers, New World', '', 'New World Dancers', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10371, NULL, '2016-03-21 16:34:43.766014+00', 'Townshend, Irene', '', 'Irene Townshend', 'Edmonton, AB, CA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10428, NULL, '2016-06-10 21:29:51.103843+00', 'Wallace, Paterson, Thomas and', '', 'Paterson, Thomas and Wallace', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10457, NULL, '2016-08-31 23:56:10.202955+00', 'Gent, Ian Thomson and Morag', '', 'Ian Thomson and Morag Gent', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10397, NULL, '2017-03-31 09:10:31.10046+00', 'Kinnon-Brettle, Rob', '', 'Rob Kinnon-Brettle', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10442, NULL, '2018-01-19 15:13:59.261161+00', 'New Kilpatrick Country Dance Club', 'New Kilpatrick CDC', 'New Kilpatrick Country Dance Club', 'Bearsden, UK', '', 0, 1, 0, 0, NULL, 1982, 0, NULL, '');
INSERT INTO 'person' VALUES (10432, NULL, '2019-08-23 23:56:27.605468+00', 'Wyrick, Steve', '', 'Steve Wyrick', '', '', 0, 0, 1, 1, NULL, 0, 2019, NULL, '');
INSERT INTO 'person' VALUES (10458, NULL, '2012-01-20 12:54:18.895161+00', 'Ahearne, Richie', '', 'Richie Ahearne', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10476, NULL, '2012-01-20 12:54:18.9552+00', 'Bennett, Richard', '', 'Richard Bennett', 'Salt Spring Island, BC, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10459, NULL, '2012-01-20 12:54:18.898442+00', 'Inwood, June', '', 'June Inwood', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10460, NULL, '2012-01-20 12:54:18.901745+00', 'Watson, Stan', '', 'Stan Watson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10477, NULL, '2012-01-20 12:54:18.958491+00', 'Mrs Gibson of Edinburgh', '', 'Mrs Gibson of Edinburgh', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10461, NULL, '2012-01-20 12:54:18.905032+00', 'Cornell, Sue', '', 'Sue Cornell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11647, '2018-06-23 13:12:58.984147+00', '2018-06-23 13:12:58.984147+00', 'Pustelnik, Frederik', '', 'Frederik Pustelnik', 'Denmark', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10434, NULL, '2013-12-09 00:51:24.460058+00', 'Group, Herrington SCD', '', 'Herrington SCD Group', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10479, NULL, '2012-01-20 12:54:18.965134+00', 'Denza, Luigi', '', 'Luigi Denza', '', '', 0, 0, 1, 0, NULL, 1846, 1922, NULL, '');
INSERT INTO 'person' VALUES (10462, NULL, '2012-01-20 12:54:18.908315+00', 'Wallace, Dan', '', 'Dan Wallace', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10463, NULL, '2012-01-20 12:54:18.911667+00', 'Morrow, Les', '', 'Les Morrow', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10481, NULL, '2012-01-20 12:54:18.971729+00', 'Lindsay, Ruth', '', 'Ruth Lindsay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10482, NULL, '2012-01-20 12:54:18.975009+00', 'Davis, Nancy', '', 'Nancy Davis', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10484, NULL, '2012-01-20 12:54:18.981589+00', 'Trotier, Kelli', '', 'Kelli Trotier', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10466, NULL, '2012-01-20 12:54:18.922156+00', 'Johnstone, Margaret', '', 'Margaret Johnstone', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10485, NULL, '2012-01-20 12:54:18.984935+00', 'Smith, Gerry', '', 'Gerry Smith', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10467, NULL, '2012-01-20 12:54:18.92547+00', 'Glennie, Kerith', '', 'Kerith Glennie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10486, NULL, '2012-01-20 12:54:18.98823+00', 'Truman, Norman', '', 'Norman Truman', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10469, NULL, '2012-01-20 12:54:18.932062+00', 'Sato, Hitomi', '', 'Hitomi Sato', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10471, NULL, '2012-01-20 12:54:18.938665+00', 'Kondo, Sachiko', '', 'Sachiko Kondo', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10488, NULL, '2012-01-20 12:54:18.994955+00', 'Brogan, Mac', '', 'Mac Brogan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10490, NULL, '2012-01-20 12:54:19.001989+00', 'Weibye, Miriam', '', 'Miriam Weibye', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10491, NULL, '2012-01-20 12:54:19.006252+00', 'Cundill, Alan', '', 'Alan Cundill', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10493, NULL, '2012-01-20 12:54:19.021344+00', 'Nilsson, Erika', '', 'Erika Nielson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10494, NULL, '2012-01-20 12:54:19.024697+00', 'Kleine-Albers, Jennifer', '', 'Jennifer Kleine-Albers', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10480, NULL, '2012-01-20 12:54:18.968442+00', 'Rubio, Jesus Gonzalez', '', 'Jesus Gonzalez Rubio', '', '', 0, 0, 1, 0, 10480, 0, 1874, NULL, '');
INSERT INTO 'person' VALUES (10512, NULL, '2012-01-20 12:54:19.089311+00', 'Martin, Lesley', '', 'Lesley Martin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10495, NULL, '2012-01-20 12:54:19.031023+00', 'Mackintosh, Gillian', '', 'Gillian Mackintosh', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10513, NULL, '2012-01-20 12:54:19.091845+00', 'Davidson, V', 'V Davidson', 'V Davidson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10514, NULL, '2012-01-20 12:54:19.094377+00', 'Robertson, Iain', 'Iain Robertson', 'Iain Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10515, NULL, '2012-01-20 12:54:19.096915+00', 'EMO Dancers (Local Dance Group)', 'EMO Dancers', 'EMO Dancers', 'Essen Germany', 'info@emodancers.de', 0, 1, 0, 0, NULL, 1994, 0, NULL, '');
INSERT INTO 'person' VALUES (10497, NULL, '2012-01-20 12:54:19.038495+00', 'Mackintosh, Gillian & Smail, Anna', '', 'Gillian Mackintosh & Anna Smail', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10516, NULL, '2012-01-20 12:54:19.099593+00', 'Kölling, Arnulf', '', 'Arnulf Kölling', 'Essen Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10498, NULL, '2012-01-20 12:54:19.042226+00', 'Smail, Anna', '', 'Anna Smail', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10517, NULL, '2012-01-20 12:54:19.102165+00', 'Kölbl, Dirk', '', 'Dirk Kölbl', 'Essen Germany', 'dirk_koelbl@gmx.de', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10499, NULL, '2012-01-20 12:54:19.049353+00', 'Stanway, Toby', '', 'Toby Stanway', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10519, NULL, '2012-01-20 12:54:19.107495+00', 'Martin, F', '', 'F Martin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10500, NULL, '2012-01-20 12:54:19.05364+00', 'Vivino, Maureen', 'Maureen Vivino', 'Maureen Vivino', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10520, NULL, '2012-01-20 12:54:19.11004+00', 'Gunn, Gordon', '', 'Gordon Gunn', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10521, NULL, '2012-01-20 12:54:19.112585+00', 'Blair, M', '', 'M Blair', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10502, NULL, '2012-01-20 12:54:19.057005+00', 'Stewart-Robertson', '', 'Stewart-Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10522, NULL, '2012-01-20 12:54:19.115143+00', 'Peace, B', '', 'B Peace', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10504, NULL, '2012-01-20 12:54:19.06389+00', 'MacIntyre, Duncan', '', 'Duncan MacIntyre', '', '', 0, 0, 1, 0, NULL, 1767, 1807, NULL, '');
INSERT INTO 'person' VALUES (10523, NULL, '2012-01-20 12:54:19.117673+00', 'Barenberg, R', '', 'R Barenberg', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10524, NULL, '2012-01-20 12:54:19.120208+00', 'Larson, Grey', '', 'Grey Larson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10505, NULL, '2012-01-20 12:54:19.067191+00', 'Brechin, Sandy', '', 'Sandy Brechin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10525, NULL, '2012-01-20 12:54:19.122748+00', 'MacPhail, Iain and Friends', '', 'Iain MacPhail and Friends', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10526, NULL, '2012-01-20 12:54:19.125275+00', 'Salldin, Ranger', '', 'Ranger Salldin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10509, NULL, '2012-01-20 12:54:19.080381+00', 'MacLean, Dougie', '', 'Dougie MacLean', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10528, NULL, '2012-01-20 12:54:19.130369+00', 'Goodwin, Ron', 'Ron Goodwin', 'Ron Goodwin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10529, NULL, '2012-01-20 12:54:19.132903+00', 'Reader, Ralph', 'Ralph Reader', 'Ralph Reader', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10530, NULL, '2012-01-20 12:54:19.13544+00', 'Wrubel and Gilbert', 'Wrubel and Gilbert', 'Wrubel and Gilbert', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10532, NULL, '2012-01-20 12:54:19.140493+00', 'Butterfield', 'Butterfield', 'Butterfield', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10547, NULL, '2012-01-20 12:54:19.178528+00', 'Cameron''s, James West Coast Band', 'James Cameron', 'James Cameron''s West Coast Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10548, NULL, '2012-01-20 12:54:19.181282+00', 'Lillie, Bob and the Kelvin Band', 'Bob Lillie Band', 'Bob Lillie and the Kelvin Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10549, NULL, '2012-01-20 12:54:19.183859+00', 'MacKay, Curly and his Scottish Dance Band', 'Curly MacKay''s Band', 'Curly MacKay and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10534, NULL, '2012-01-20 12:54:19.145551+00', 'Schwartz, J / Jerome, W', '', 'J Schwartz / W Jerome', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10506, NULL, '2015-03-14 18:11:09.090195+00', 'Grant, Aonghas', '', 'Aonghas Grant', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10508, NULL, '2015-03-14 18:11:15.386769+00', 'MacIntyre, Sandy', '', 'Sandy MacIntyre', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10518, NULL, '2015-03-14 18:11:22.033211+00', 'Queens Own', '', 'Queens Own', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10507, NULL, '2017-03-03 13:44:45.244791+00', 'McDonald, Malcolm', '', 'Malcolm McDonald', '', '', 0, 0, 1, 0, NULL, 1750, 0, NULL, '');
INSERT INTO 'person' VALUES (10492, NULL, '2017-09-30 21:28:55.54153+00', 'Smith, Brian', '', 'Brian Smith', '', '', 1, 0, 0, 0, NULL, 0, 2016, NULL, '');
INSERT INTO 'person' VALUES (10496, NULL, '2019-05-06 21:49:43.739575+00', 'Ferguson, Kirsten', '', 'Kirsten Ferguson', '', '', 1, 0, 0, 0, 11807, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10550, NULL, '2012-01-20 12:54:19.186397+00', 'Graves, Alfred', '', 'Alfred Graves', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10551, NULL, '2012-01-20 12:54:19.188938+00', 'Vancouver Fiddle Orchestra', 'VFO', 'Vancouver Fiddle Orchestra', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10535, NULL, '2012-01-20 12:54:19.148074+00', 'Mathewson, A.R.M.', '', 'A.R.M. Mathewson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10552, NULL, '2012-01-20 12:54:19.191475+00', 'Graham, Peter', '', 'Peter Graham', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10536, NULL, '2012-01-20 12:54:19.1506+00', 'Howie, J', '', 'J Howie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10554, NULL, '2012-01-20 12:54:19.196743+00', 'Morbidelli, C', '', 'C Morbidelli', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10537, NULL, '2012-01-20 12:54:19.153146+00', 'Heykens, Jonny', '', 'Jonny Heykens', '', '', 0, 0, 1, 0, NULL, 1884, 1945, NULL, '');
INSERT INTO 'person' VALUES (10555, NULL, '2012-01-20 12:54:19.19991+00', 'Donny & Diane''s Highland Ceilidh Band', 'Donny & Diane''s Band', 'Donny & Diane''s Highland Ceilidh Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10538, NULL, '2012-01-20 12:54:19.155673+00', 'Laurenson, Edith', '', 'Edith Laurenson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10556, NULL, '2012-01-20 12:54:19.203241+00', 'Morrison, Murdo', '', 'Murdo Morrison', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10539, NULL, '2012-01-20 12:54:19.15819+00', 'Daly, Bryan', '', 'Bryan Daly', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10557, NULL, '2012-01-20 12:54:19.206522+00', 'Morrison, P/M D', '', 'P/M D Morrison', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10540, NULL, '2012-01-20 12:54:19.160761+00', 'Miller, Shona', '', 'Shona Miller', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10558, NULL, '2012-01-20 12:54:19.209883+00', 'McIntyre, G M', '', 'G M McIntyre', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10559, NULL, '2012-01-20 12:54:19.213185+00', 'Santa, E', '', 'E Santa', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10560, NULL, '2012-01-20 12:54:19.216482+00', 'MacMillan, Roddy', '', 'Roddy MacMillan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10541, NULL, '2012-01-20 12:54:19.163305+00', 'Strathmore Ceilidh Band, The', 'Strathmore Band', 'The Strathmore Ceilidh Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10561, NULL, '2012-01-20 12:54:19.219773+00', 'MacLeod, P/M Peter', '', 'P/M Peter MacLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10542, NULL, '2012-01-20 12:54:19.165838+00', 'Carnegie, Scott', '', 'Scott Carnegie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10543, NULL, '2012-01-20 12:54:19.16837+00', 'Cook, W', '', 'W Cook', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10562, NULL, '2012-01-20 12:54:19.223075+00', 'Montréal Branch RSCDS', 'Montréal RSCDS', 'Montréal Branch RSCDS', 'Montréal, Quebec, Canada', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10544, NULL, '2012-01-20 12:54:19.170897+00', 'Ritchie, James', '', 'James Ritchie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10545, NULL, '2012-01-20 12:54:19.173441+00', 'McPherson, L', '', 'L McPherson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10546, NULL, '2012-01-20 12:54:19.175991+00', 'Starr, Will with the Archie Duncan Quintet', 'Will Starr and Band', 'Will Starr with the Archie Duncan Quintet', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10563, NULL, '2012-01-20 12:54:19.226385+00', 'Koeppler, Dagmar', '', 'Dagmar Koeppler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10564, NULL, '2012-01-20 12:54:19.229672+00', 'Stewart, Catherine', '', 'Catherine Stewart', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10565, NULL, '2012-01-20 12:54:19.232989+00', 'Link, Norah', '', 'Norah Link', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10566, NULL, '2012-01-20 12:54:19.236287+00', 'Hunter, June', '', 'June Hunter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10567, NULL, '2012-01-20 12:54:19.239589+00', 'Speirs, Betty', '', 'Betty Speirs', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10553, NULL, '2012-01-20 12:54:19.194003+00', 'Chuchuk, Raymond', '', 'Raymond Chuchuk', '', '', 0, 0, 1, 1, 10553, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10569, NULL, '2012-01-20 12:54:19.246214+00', 'Ramshaw, L / Bentley, S W / Bentley, M / Innes, G', '', 'Ramshaw, L / Bentley, S W / Bentley, M / Innes, G', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10570, NULL, '2012-01-20 12:54:19.249587+00', 'Innes, Gary', '', 'Gary Innes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10571, NULL, '2012-01-20 12:54:19.252876+00', 'Morrison, Fred', '', 'Fred Morrison', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10572, NULL, '2012-01-20 12:54:19.256199+00', 'Melville, Colin', '', 'Colin Melville', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10573, NULL, '2012-01-20 12:54:19.259533+00', 'Iachini, Michael', '', 'Michael Iachini', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10574, NULL, '2012-01-20 12:54:19.26282+00', 'DeMarse, Fred', '', 'Fred DeMarse', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10575, NULL, '2012-01-20 12:54:19.266112+00', 'Caplin, Mark', '', 'Mark Caplin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11648, '2018-06-23 13:13:53.973379+00', '2018-06-23 13:13:53.973379+00', 'Dam, Christoffer', '', 'Christoffer Dam', 'Denmark', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10587, NULL, '2012-01-20 12:54:19.305732+00', 'Danielson, Linda', '', 'Linda Danielson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10588, NULL, '2012-01-20 12:54:19.309024+00', 'Wagstaff, Jean', '', 'Jean Wagstaff', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10589, NULL, '2012-01-20 12:54:19.312318+00', 'Shaw, John L', '', 'John L. Shaw', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10590, NULL, '2012-01-20 12:54:19.31561+00', 'McLeod van Nus, Margaret', '', 'Margaret McLeod van Nus', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10591, NULL, '2012-01-20 12:54:19.318899+00', 'Van Meter Hord', '', 'Van Meter Hord', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10592, NULL, '2012-01-20 12:54:19.322179+00', 'Moore, Valerie K', '', 'Valerie K Moore', 'Vancouver, WA  USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1902, NULL, '2013-01-24 15:34:39.163488+00', 'Reith, James D', '', 'James D Reith', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10594, NULL, '2012-01-20 12:54:19.328753+00', 'Burger, Robert J', '', 'Robert J Burger', 'Vancouver WA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10596, NULL, '2012-01-20 12:54:19.335464+00', 'Barnes, John', '', 'John Barnes', 'Dublin, Ireland', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10598, NULL, '2012-01-20 12:54:19.34204+00', 'Altman, Jeff', '', 'Jeff Altman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10599, NULL, '2012-01-20 12:54:19.345325+00', 'Scobie, Anne', '', 'Anne Scobie', 'Brussels', 'annescobie@scarlet.be', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10597, NULL, '2012-01-20 12:54:19.338755+00', 'Williams, Craig and Jody', '', 'Craig and Jody Williams', 'Ottawa?', '', 1, 0, 0, 0, 2774, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (277, NULL, '2012-09-08 23:02:41.444762+00', 'Mozart Allan', '', 'Mozart Allan', 'Glasgow', '', 0, 1, 0, 0, NULL, 0, 0, NULL, 'This is not really a person but the name of a music publishing company.');
INSERT INTO 'person' VALUES (10593, NULL, '2015-03-14 18:11:05.280236+00', 'Dennis, Linda Mae', '', 'Linda Mae Dennis', 'Vancouvr WA, USA', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10657, '2012-09-08 21:54:19.556743+00', '2015-03-14 18:11:13.246201+00', 'Klann, Diane', '', 'Diane Klann', 'Akron, OH, USA', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10577, NULL, '2018-10-29 16:41:43.888322+00', 'Gatherer, Nigel', '', 'Nigel Gatherer', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10586, NULL, '2015-04-02 20:56:38.937033+00', 'RSCDS Southwest Washington State Branch', 'RSCDS SW Washington, USA', 'RSCDS Southwest Washington State Branch', 'Vancouver WA, USA', '', 0, 0, 0, 0, 1628, 2008, 0, NULL, 'Created 30 november 2008 (information from the Branch secretary)');
INSERT INTO 'person' VALUES (11313, '2016-08-05 13:28:29.883721+00', '2016-08-05 23:56:22.127697+00', 'Smith, Jim', '', 'Jim Smith', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10580, NULL, '2018-10-26 20:30:14.222406+00', 'White, Peter / Stirrat, George B', '', 'Peter White / George B Stirrat', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10578, NULL, '2018-10-29 16:42:03.939416+00', 'Cochrane, Joyce', '', 'Joyce Cochrane', 'UK', 'jcochrane@jcochrane.karoo.co.uk', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10579, NULL, '2018-10-29 16:42:28.478855+00', 'Heubach, Merrill', '', 'Merrill Heubach', 'Lunenburg, NS, Canada', 'nika@eastlink.ca', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10582, NULL, '2013-09-13 13:16:38.694719+00', 'Hodgson, Andrew', '', 'Andrew Hodgson', 'Cape Town, South Africa', 'andrew@hodgson.za.net', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10584, NULL, '2014-03-18 10:35:50.555226+00', 'Funhoff, Gabrielle', '', 'Gabrielle Funhoff', 'Kettwig, Germany', 'parbleuoui@aol.com', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10595, NULL, '2014-05-09 22:08:18.812538+00', 'Skinner, Carole', '', 'Carole Skinner', 'Toronto(?), Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10642, '2012-08-13 08:24:18.694017+00', '2012-08-14 05:32:16.739442+00', 'Newman, Robert', '', 'Robert Newman', 'San Gabriel Valley Branch, CA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Was  a teacher of the Branch');
INSERT INTO 'person' VALUES (2113, NULL, '2012-08-20 22:05:26.224164+00', 'Tress, Carola', '', 'Carola Tress', 'Schluechtern, Germany', 'info@kuckucksnest.com', 1, 0, 0, 0, 10451, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10646, '2012-08-23 16:07:36.614259+00', '2012-08-23 16:07:36.614269+00', 'Rousseau, Mylène', '', 'Mylène Rousseau', 'Paris, France', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10606, '2012-02-22 22:59:09.958174+00', '2012-02-22 22:59:09.958184+00', 'Marjorie Duffield''s Pupils', '', 'Marjorie Duffield''s Pupils', 'West Lothian', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10645, '2012-08-19 11:49:57.180498+00', '2012-08-19 11:49:57.180509+00', 'Senior, Robert', '', 'Robert Senior', 'Stamford, UK', 'randm.senior@tiscali.co.uk', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11649, '2018-06-23 13:14:54.694963+00', '2018-06-23 13:14:54.694963+00', 'Nielsen, Rasmus', '', 'Rasmus Nielsen', 'Denmark', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10611, '2012-03-09 20:31:14.723896+00', '2012-03-09 20:34:25.29261+00', 'Macclesfield Children', '', 'Children of the Macclesfield SCD Group ', 'Macclesfield, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'The children of Macclesfield Scottish Country Dance Group devised the dance 18! 18! for the 18th Wigan Thistle society festival of dance for young people.  Teacher J F Bradbury

');
INSERT INTO 'person' VALUES (382, NULL, '2012-04-08 07:23:48.12494+00', 'Tang, Shengzhang', '', 'Shengzhang Tang', 'Massachusetts and New York', 'stang@pipeline.com', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Updated 6 april 2012');
INSERT INTO 'person' VALUES (10568, NULL, '2021-03-02 17:58:34.26613+00', 'Boyd, Holly', '', 'Holly Boyd', 'Montréal, Canada', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10613, '2012-04-15 20:07:06.990417+00', '2012-04-15 20:07:06.990427+00', 'Taylor, Alex', '', 'Alex Taylor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10651, '2012-09-04 00:27:05.237067+00', '2012-10-28 14:09:01.611873+00', 'Bracht, Manuela', '', 'Manuela Bracht', 'Essen, Germany', 'Manuela.Bracht@gmx.net', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Member of Peter/Bracht and Montag/Bracht');
INSERT INTO 'person' VALUES (1613, NULL, '2012-08-31 20:41:33.964285+00', 'Peterson, Iain', '', 'Iain Peterson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Some sources spell his name as "Ian".');
INSERT INTO 'person' VALUES (10649, '2012-08-31 22:30:08.51814+00', '2012-08-31 22:30:08.518151+00', 'Copland, Neil', '', 'Neil Copland', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10653, '2012-09-07 10:16:20.555548+00', '2012-09-07 10:24:17.422276+00', '[any]', '', '[any]', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10654, '2012-09-07 13:26:35.239966+00', '2012-09-07 13:26:35.239978+00', 'Lanyi, Eva', '', 'Eva Lanyi', 'Alexandria, Northern Virginia , USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'source: http://rscds-greaterdc.org/nova_dances.html');
INSERT INTO 'person' VALUES (10610, '2012-03-08 16:52:23.647145+00', '2012-10-28 14:09:56.344989+00', 'Peter, J', '', 'J. Peter', 'Essen, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Member of Peter/Bracht');
INSERT INTO 'person' VALUES (10652, '2012-09-04 22:11:19.582629+00', '2015-03-14 18:11:20.458148+00', 'Page, David', '', 'David Page', 'Nottingham, UK', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (240, NULL, '2018-08-08 20:40:47.603308+00', 'MacGregor-Brown, James', '', 'James MacGregor-Brown', '', '', 1, 0, 1, 0, NULL, 1936, 2018, NULL, 'From <<https://mccleisterfuneralhome.ca/tribute/details/2897/James-MacGregor-Brown/obituary.html>>, via Randal Oulton:



> MACGREGOR-BROWN, James - Feb. 1936 - Jan. 2018 Peacefully in his sleep

> at the Brantford General Hospital on January 4th, 2018 in his 82nd year.

> Beloved son of the late Mary (nee Gardener) and Robert Brown; dear

> brother of Janet Finnessey of Nuneaton, England. James was born in

> Glasgow, Scotland and educated in Scotland and France. James taught

> Modern Languages at Pauline Johnson Collegiate from 1968 until his

> retirement. Jim was a world traveller, often with his sister. He will be

> dearly missed by many friends and former students.');
INSERT INTO 'person' VALUES (10607, '2012-03-04 20:33:42.994604+00', '2017-11-15 10:06:33.298407+00', 'Quarrie, David', '', 'David Quarrie', 'Hamburg, Germany', 'drquarrie@mac.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2874, NULL, '2017-11-15 10:06:55.015321+00', 'Quarrie, Avril', '', 'Avril Quarrie', 'Hamburg, Germany', 'alquarrie@mac.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10581, NULL, '2015-10-11 23:56:23.588967+00', 'Stitz, Ilona', '', 'Ilona Stitz', 'Germany', 'ilona.stitz@gmail.com', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3342, NULL, '2017-11-10 16:32:50.125863+00', 'Quarrie, Avril & David', '', 'Avril and David Quarrie', 'Hamburg, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10609, '2012-03-08 15:46:14.778257+00', '2012-10-28 14:11:01.738909+00', 'Peter / Bracht', '', 'Peter / Bracht', 'Essen, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Consists of J. Peter and Manuela Bracht');
INSERT INTO 'person' VALUES (10608, '2012-03-08 15:39:29.13977+00', '2012-10-28 14:11:53.736069+00', 'Montag / Bracht', '', 'Montag / Bracht', 'Essen, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Consists of Holger Montag and Manuela Bracht.');
INSERT INTO 'person' VALUES (10702, '2013-01-05 17:03:07.834412+00', '2013-01-05 17:03:07.834424+00', 'Harling, K', '', 'K Harling', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10703, '2013-01-05 17:09:09.761855+00', '2013-01-05 17:09:09.761866+00', 'Wood, Inga', '', 'Inga Wood', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10689, '2012-12-31 16:29:07.426932+00', '2012-12-31 16:29:07.426943+00', 'Stevenson, Pat', '', 'Pat Stevenson', 'Perth, Western Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10659, '2012-09-16 15:28:29.3059+00', '2012-09-16 15:52:51.376344+00', 'Lindsay, Jim and his Band', 'Jim Lindsay', 'Jim Lindsay and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10076, NULL, '2012-09-16 16:00:41.337203+00', 'Lindsay, Jim and Johnstone, Muriel', 'Lindsay/Johnstone', 'Jim Lindsay and Muriel Johnstone', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10725, '2013-01-23 12:32:26.818974+00', '2013-01-23 12:32:26.818986+00', 'Masterton, Margaret', '', 'Margaret Masterton', 'West Lothian', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11654, '2018-07-01 10:28:38.654303+00', '2018-07-01 10:43:09.76324+00', 'Pitzal, Ute and Robertson, Garry', '', 'Ute Pitzal and Garry Robertson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10727, '2013-01-23 13:11:30.774263+00', '2013-01-23 13:11:30.774274+00', 'Buchanan, Gerard', '', 'Gerard Buchanan', 'West Lothian?', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10728, '2013-01-23 13:21:06.296515+00', '2013-01-23 13:21:06.296526+00', 'Lawson, Alex', '', 'Alex J Lawson', 'West Lothian?', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Could this be the same person as Alexis Lawson?');
INSERT INTO 'person' VALUES (10730, '2013-01-24 15:18:23.215904+00', '2013-01-24 15:18:23.215916+00', 'David Rorie Society', '', 'David Rorie Society', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (269, NULL, '2012-04-19 13:56:59.008056+00', 'Milligan, Jean', '', 'Jean Milligan', '', '', 1, 1, 0, 0, NULL, 1886, 1978, NULL, '##>>

The entry for Miss Milligan in *The Biographical Dictionary of Scottish Women* reads:



{{quote}}

… born Glasgow 9 July 1886, died Glasgow 28 July 1978. Inspirational teacher and advocate of traditional Scottish dance. Daughter of Isabella Aitchison, teacher and Dr. James Milligan LL. D. Rector, Glasgow High School for Girls.



{{quote}}

The fifth of six children, Jean Milligan was educated at her father’s school subsequently qualifying in Physical Training at Kingsfield College, Dartford. Appointed Assistant Instructress at Dundas Vale Training College (subsequently Jordanhill), Glasgow in 1909, she immediately showed her interest in traditional dance and music. Saw war service as

a VAD nurse in Malta. Appointed Principal Instructress in Physical Training at Jordanhill, and, until her retirement from that post in 1948, had an influential role in the national provision and development of physical education in Scotland.



{{quote}}

In 1923, she met Mrs Ysobel Stewart of Fasnacloich (n. Campbell of Inverneill, 1882-1968), Head of Training for Girl Guides in Scotland who was keen to promote Scottish Country Dancing among young people. With others, they convened a meeting in Glasgow in November 1923 when the Scottish Country Dance Society was formed. With Miss Milligan as its principal teacher and technical adviser, the Society produced books of dance instruction, devised a teacher-training programme through its branches and founded a Summer School at St Andrews which, except for wartime, has been held annually since 1927 and now hosts some 1,000 dancers. Compiled the popular 101 Scottish Country Dances and a manual of Country Dancing – Won’t You Join the Dance.



{{quote}}

After the Second World War, she promoted Scottish Country Dancing throughout the world, travelling extensively to support and encourage new branches of the Society. By the 80th Anniversary in 2003, the, by now, Royal Scottish Country Dance Society comprised 166 branches and 448 affiliated groups in 41 countries.



{{quote}}

In 1973, voted The Evening Times Scotswoman of the Year and in 1977 Aberdeen University conferred on her the honorary degree of Doctor of Laws. The Earl of Mansfield summarised her neatly as »a woman with a vision and with the ability and tenacity to grasp it and make it become reality«. (in MacFadyen & Adams, 1983 p.7)

##<<



For a full biography of Miss Milligan see

*Dance with your Soul*

by Dr Alastair MacFadyen and Mrs Florence H Adams published by RSCDS');
INSERT INTO 'person' VALUES (80, NULL, '2012-05-08 23:23:21.271139+00', 'Clindinning, Wesley', '', 'Wesley Clindinning', 'Ontario', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Wes is a former director of TAC summer school');
INSERT INTO 'person' VALUES (10615, '2012-04-29 09:11:04.953554+00', '2012-04-29 09:11:04.953564+00', 'Hall, Genny', '', 'Genny Hall', 'Tokoroa, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (947, NULL, '2012-05-02 10:07:25.806596+00', 'Moore, John & Finley, Eric', '', 'John Moore & Eric Finley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2990, NULL, '2012-05-07 21:11:20.196311+00', 'MacMichael, Agnes D', '', 'Agnes D MacMichael', 'West Lothian Branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Could be the same person as Agnes D Martin.  Needs to be checked');
INSERT INTO 'person' VALUES (3715, NULL, '2012-12-14 21:06:17.021265+00', 'Bristow, Isobel (Issy)', '', 'Issy Bristow', 'Ribble Valley Branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1276, NULL, '2021-07-25 16:53:11.679479+00', 'Conrad, Adrian', '', 'Adrian Conrad', 'Croydon, England', 'adrian_conrad@yahoo.co.uk', 1, 1, 0, 0, NULL, 0, 0, NULL, 'All my dances are available in MS Word softcopy on application to my e-mail address.  Adrian.



NB they have now been published on the MiniCrib website. See <<http://www.minicrib.org.uk/Publications/AConrad.The.Odd.Half-dozen.pdf>>.');
INSERT INTO 'person' VALUES (10648, '2012-08-28 09:59:55.729774+00', '2021-11-10 23:49:16.657862+00', 'Peart, Amanda', '', 'Amanda Peart', 'Baston, Lincolnshire, UK', 'amandapeart@thesundayclass.org.uk', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Amanda runs/is "The Sunday Class" ');
INSERT INTO 'person' VALUES (898, NULL, '2012-05-07 21:11:43.948761+00', 'Martin, Agnes D', '', 'Agnes Martin', 'West Lothian Branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Could be the same person as Agnes D MacMichael.  Needs to be checked');
INSERT INTO 'person' VALUES (10636, '2012-06-17 14:28:14.801207+00', '2012-06-17 14:28:14.801218+00', 'Edey, Tim', 'T Edey', 'Tim Edey', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10618, '2012-05-22 12:27:10.758779+00', '2012-05-22 12:27:10.75879+00', 'Scobie, Daphne', 'Daphne Scobie', 'Daphne Scobie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10619, '2012-06-12 13:15:11.070352+00', '2012-06-12 13:15:11.070362+00', 'Newton, Anne', '', 'Anne Newton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10620, '2012-06-12 13:21:20.721932+00', '2012-06-12 13:21:20.721943+00', 'Baker-Glenn, Robert', '', 'Robert Baker-Glenn', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11650, '2018-06-23 13:15:57.485192+00', '2018-06-23 13:15:57.485192+00', 'Bech, Mathaeus', '', 'Mathaeus Bech', 'Denmark', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10624, '2012-06-12 13:32:13.171921+00', '2012-06-12 13:32:13.171932+00', 'Cowell, Hugh', '', 'Hugh Cowell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10628, '2012-06-12 13:45:41.02144+00', '2012-06-12 13:45:41.021451+00', 'Arrol, Tom', '', 'Tom Arrol', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10630, '2012-06-12 13:52:36.432686+00', '2012-06-12 13:52:36.432697+00', 'Arrol, Betty', '', 'Betty Arrol', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11651, '2018-06-23 13:21:53.347747+00', '2018-06-23 13:21:53.347747+00', 'DuK', 'DuK', 'DuK', 'Denmark', 'dukfolkmusic@gmail.com', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10633, '2012-06-15 05:19:08.114249+00', '2012-06-15 05:19:08.114261+00', 'Tamás Hámori and Klára Lovrics', '', 'Tamás Hámori and Klára Lovrics', 'Budapest', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2688, NULL, '2012-06-15 05:35:11.309683+00', 'Turi, Gábor', '', 'Gábor Turi', 'Budapest, Hungary', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10635, '2012-06-17 14:23:18.238408+00', '2012-06-17 14:23:18.238419+00', 'Traub, Terry', 'Terry Traub', 'Terry Traub', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10638, '2012-07-03 18:22:36.586216+00', '2012-07-03 18:22:36.586227+00', 'Sayer, Eileen', '', 'Eileen Sayer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11652, '2018-06-30 22:33:25.764124+00', '2018-06-30 22:33:25.764124+00', 'Lambert, Les', '', 'Les Lambert', 'Kilbarchan, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11653, '2018-07-01 10:23:29.576442+00', '2018-07-01 10:23:29.576442+00', 'Pitzal, Ute', '', 'Ute Pitzal', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10627, '2012-06-12 13:40:30.619578+00', '2014-09-06 15:55:32.809065+00', 'Robertson, Ann', '', 'Ann Robertson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10639, '2012-07-23 11:27:59.878554+00', '2012-07-23 23:05:22.014902+00', 'Giles, Peter', '', 'Peter Giles', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10643, '2012-08-15 08:16:25.243691+00', '2012-08-15 08:16:25.243701+00', 'Whitley, Philip', '', 'Philip Whitley', 'Edinburgh, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3593, NULL, '2015-02-21 12:51:23.731921+00', 'Paterson, Irene', '', 'Irene Paterson', 'Mukilteo, WA, US', 'eimacpat@gmail.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10623, '2012-06-12 13:30:44.763395+00', '2015-03-14 18:10:58.553507+00', 'Allen-Friend, Jonathan', '', 'Jon Allen-Friend', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10605, '2012-02-12 20:49:50.660426+00', '2015-03-14 18:11:03.141963+00', 'Cash, Johnny', '', 'Johnny Cash', '', '', 0, 0, 1, 0, NULL, 1932, 2003, NULL, 'A world famous Country and Western singer who wrote the music and the words which go with it for Fourty Shades of Green in the 1960''s following a visit to Ireland');
INSERT INTO 'person' VALUES (10614, '2012-04-23 09:11:58.856254+00', '2015-03-14 18:11:04.569776+00', 'Crowe, Bobby Scottish Dance Band / Danelaw Country Dance Band', 'Bobby Crowe / Danelaw Band', 'Bobby Crowe SDB / Danelaw Band', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10634, '2012-06-17 14:10:31.214857+00', '2015-03-14 18:11:09.580925+00', 'Grosjean, Deby Benton', 'D B Grosjean', 'Deby Benton Grosjean', 'San Francisco, CA, US', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (401, NULL, '2017-02-14 09:44:27.379515+00', 'Wallace, Ron', '', 'Ron Wallace', 'Santa Rosa, CA USA', 'ronaldcwallace@gmail.com', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3025, NULL, '2012-09-16 15:27:48.614884+00', 'Lindsay, Jimmy and his Scottish Dance Band', 'Jimmy Lindsay', 'Jimmy Lindsay and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'Not to be confused with Jim Lindsay and his Band, which is a completely different band.');
INSERT INTO 'person' VALUES (10679, '2012-12-28 13:22:35.895039+00', '2012-12-28 13:22:35.89505+00', 'Cullivoe Band, The', 'Cullivoe', 'The Cullivoe Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'Members are (2011):

  Ivor Scollay - Lead Accordion

  Bryan Gear - Fiddle

  Matthew Scollay - 2nd Accordion

  Graeme Garrick - Drums

  Martin Henderson - Piano');
INSERT INTO 'person' VALUES (10680, '2012-12-28 13:32:18.428228+00', '2012-12-28 13:32:18.42824+00', 'Creighton, Ian', '', 'Ian Creighton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10681, '2012-12-28 13:43:35.426574+00', '2012-12-28 13:43:35.426584+00', 'Hawick, Drewie', '', 'Drewie Hawick', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10682, '2012-12-28 14:38:10.049396+00', '2012-12-28 14:38:10.049408+00', 'Wills, Bob', '', 'Bob Wills', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10683, '2012-12-28 14:40:11.490016+00', '2012-12-28 14:40:11.490027+00', 'Moore, Tiny', '', 'Tiny Moore', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10685, '2012-12-28 15:34:19.355258+00', '2012-12-28 15:34:19.355269+00', 'Moran, M', '', 'M Moran', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10687, '2012-12-28 17:08:06.587161+00', '2012-12-28 17:08:06.587172+00', 'Wilton, David', '', 'David Wilton', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10688, '2012-12-31 16:21:22.126822+00', '2012-12-31 16:21:22.126833+00', 'Saunders, Audrey', '', 'Audrey Saunders', 'Perth, Western Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3580, NULL, '2023-02-03 09:39:43.495646+00', 'Pierson, Brian', '', 'Brian Pierson', 'Staines. UK', 'brianjohnpierson@gmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (563, NULL, '2012-10-16 08:03:20.936779+00', 'MacLachlan, Janet T', '', 'Janet T MacLachlan', 'Canada', '', 1, 0, 0, 0, NULL, 1928, 2003, NULL, 'An obituary by Anne Sutherland can be found on <<https://sites.google.com/site/wohdadance/founder|the Western Ontario Highland Dancers'' Association>>''s web site. It says



> Janet (Jenny) T. MacLachlan was an artist, historian and pillar of

> resource and knowledge in the Highland and Scottish Country Dance 

> communities in Canada, the United States, and in Scotland. […]

>  Jenny has also published books on the histories of rare and

> lesser-known Scottish Dances collected throughout North America and

> Scotland. She worked hard to enrich the Scottish Dance heritage in

> North America, producing many exceptional highland dancers that have 

> gone on to teaching and judging careers.



Many of the dances in the RSCDS'' <<ddpub:Book 24>> were »collected by Jenny MacLachlan«.');
INSERT INTO 'person' VALUES (1471, NULL, '2012-10-21 07:04:04.379059+00', 'Gent, Iain Charles', '', 'Iain Charles Gent', 'Linlithgow', 'iain@gentj.freeserve.co.uk', 0, 0, 1, 0, NULL, 1947, 0, NULL, '');
INSERT INTO 'person' VALUES (10665, '2012-10-23 22:50:56.702819+00', '2012-10-23 22:50:56.70283+00', 'Henderson, Hamish', '', 'Hamish Henderson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10690, '2012-12-31 16:38:32.643693+00', '2012-12-31 16:38:32.643705+00', 'Glen, David', '', 'David Glen', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10666, '2012-11-29 07:20:44.139697+00', '2012-11-29 07:20:44.139709+00', 'Simpson, Eann', '', 'Eann Simpson', '', '', 0, 0, 1, 0, NULL, 0, 1990, NULL, 'First name variously spelt "Ian" or "Iain"; correct spelling could not be confirmed.



Year of death is approximate.');
INSERT INTO 'person' VALUES (3795, NULL, '2012-12-07 17:26:17.879368+00', 'Torme, Mel & Wells, Bob', '', 'Mel Torme & Bob Wells', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10644, '2012-08-15 09:11:36.493622+00', '2020-10-02 18:49:03.221504+00', 'Coupe, Rosemary', '', 'Rosemary Coupe', 'Burnaby (Vancouver), BC, CA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (796, NULL, '2021-01-08 22:28:15.211501+00', 'Hunter, Margaret', '', 'Margaret Hunter', 'Edinburgh', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Miss M. Hunter');
INSERT INTO 'person' VALUES (1556, NULL, '2021-02-25 14:52:53.431791+00', 'Clement, Bill', 'Bill Clement', 'Bill Clement', '', '', 1, 0, 1, 1, NULL, 1923, 2012, NULL, 'A tribute to Bill by Jeremy Hill appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2013/09/120821Reel281.pdf#page=6|issue 281 of The Reel>>.  



Obituary from <<http://www.scotsman.com/news/obituaries/obituary-bill-clement-mbe-inspirational-and-gifted-teacher-had-great-love-of-piping-1-2375306|The Scotsman>>');
INSERT INTO 'person' VALUES (10621, '2012-06-12 13:23:00.248861+00', '2021-02-25 16:41:05.871091+00', 'Anderson, Stuart', '', 'Stuart Anderson', '', '', 1, 0, 0, 0, NULL, 1958, 2021, NULL, '');
INSERT INTO 'person' VALUES (10670, '2012-12-17 23:27:04.602343+00', '2012-12-17 23:27:04.602353+00', 'Webb, Jo', '', 'Jo Webb', 'Winchester', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10671, '2012-12-17 23:29:26.451751+00', '2012-12-17 23:29:26.451767+00', 'Johnson, Mike', '', 'Mike Johnson', 'Winchester', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10672, '2012-12-17 23:44:02.349697+00', '2012-12-17 23:44:02.349708+00', 'Young, Alison', '', 'Alison Young', 'Winchester', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10674, '2012-12-18 00:03:41.317005+00', '2012-12-18 00:03:41.317016+00', 'Winchester Branch', '', 'Winchester Branch', 'Winchester', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10692, '2013-01-02 15:30:59.384059+00', '2013-01-02 15:30:59.38407+00', 'Ramsay, BA', '', 'BA Ramsay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10693, '2013-01-03 11:11:13.939237+00', '2013-01-03 11:11:13.939249+00', 'Mann, W', '', 'W Mann', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10694, '2013-01-03 11:14:17.941985+00', '2013-01-03 11:14:17.941996+00', 'McCarfrae, M', '', 'M McCarfrae', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10696, '2013-01-04 16:06:46.432151+00', '2013-01-04 16:06:46.432162+00', 'Chafe, Pat', '', 'Pat Chafe', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10697, '2013-01-04 16:33:22.008381+00', '2013-01-04 16:33:22.008393+00', 'Verch, April', '', 'April Verch', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10698, '2013-01-05 11:36:20.777496+00', '2013-01-05 11:41:49.899279+00', 'Four Queensferry School Pupils', '', 'Four Queensferry School Pupils', 'Queensferry', '', 1, 0, 0, 0, NULL, 2009, 2009, NULL, 'A group of four pupils of Queensferry School in 2009');
INSERT INTO 'person' VALUES (10700, '2013-01-05 16:07:49.133473+00', '2013-01-05 16:07:49.133484+00', 'Holzmann, A', '', 'A Holzmann', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10701, '2013-01-05 16:14:21.432564+00', '2013-01-05 16:14:21.432576+00', 'Rosas, J', '', 'J Rosas', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10704, '2013-01-05 17:36:39.543388+00', '2013-01-05 17:36:39.543399+00', 'McGinn, M', '', 'M McGinn', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10705, '2013-01-05 17:42:33.925647+00', '2013-01-05 17:42:33.925658+00', 'Tait, R W / Peterson, L', '', 'R W Tait/L Peterson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10706, '2013-01-06 21:53:41.946653+00', '2013-01-06 21:53:41.946664+00', 'Traditional Music and Song Association of Scotland (TMSA)', 'TMSA', 'Traditional Music and Song Association of Scotland (TMSA)', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10662, '2012-10-02 09:53:36.956513+00', '2015-03-14 18:11:00.04856+00', 'Barnett, J', '', 'J Barnett', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10663, '2012-10-15 22:05:43.917278+00', '2015-03-14 18:11:03.750494+00', 'Cleveland Heights Group Scottish Country Dancers', '', 'Cleveland Heights Group', 'Cleveland, USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10677, '2012-12-28 13:14:38.988275+00', '2015-03-14 18:11:08.029598+00', 'Garrick, Graeme', '', 'Graeme Garrick', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, 'Member of Cullivoe Band (2011)');
INSERT INTO 'person' VALUES (10676, '2012-12-28 13:13:13.670835+00', '2015-03-14 18:11:08.154707+00', 'Gear, Bryan', '', 'Bryan Gear', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, 'Member of Cullivoe Band (2011)');
INSERT INTO 'person' VALUES (10678, '2012-12-28 13:16:13.565697+00', '2015-03-14 18:11:10.679272+00', 'Henderson, Martin', '', 'Martin Henderson', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, 'Member of Cullivoe Band (2011)');
INSERT INTO 'person' VALUES (10673, '2012-12-17 23:59:11.462107+00', '2015-03-14 18:11:11.065342+00', 'Hogg, Alison', '', 'Alison Hogg', 'Winchester', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2331, NULL, '2015-03-14 18:11:14.214276+00', 'Lindsay, Jimmy', '', 'Jimmy Lindsay', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, 'Not to be confused with Jim Lindsay, who is a different person.');
INSERT INTO 'person' VALUES (2912, NULL, '2015-03-14 18:11:24.423732+00', 'Scollay, Ivor', '', 'Ivor Scollay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Member of Cullivoe Band (2011)');
INSERT INTO 'person' VALUES (10675, '2012-12-28 13:10:53.830154+00', '2015-03-14 18:11:24.452468+00', 'Scollay, Matthew', 'M. Scollay', 'Matthew Scollay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Member of Cullivoe Band (2011)');
INSERT INTO 'person' VALUES (10669, '2012-12-17 23:18:43.18074+00', '2015-03-14 18:11:26.091749+00', 'Speakman, Marian', '', 'Marian Speakman', 'Winchester?', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10699, '2013-01-05 11:46:12.246577+00', '2015-10-24 08:16:20.653098+00', 'Maiolo, Lea', '', 'Lea Maiolo', 'Seattle, WA, USA', '', 1, 0, 0, 0, 10794, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1394, NULL, '2016-11-24 05:13:40.79738+00', 'Lataille, Jane', '', 'Jane Lataille', 'Los Alamos, NM , USA', 'none@none.us', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Had a small class; wrote many dances for small numbers of dancers.



Phone (505) 661-8317 ');
INSERT INTO 'person' VALUES (10667, '2012-12-03 23:23:30.818445+00', '2018-12-07 17:40:45.543601+00', 'Miller, Lawrence', '', 'Larry Miller', 'Delaware Valley Branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10668, '2012-12-17 23:15:56.816895+00', '2018-12-07 17:41:05.370421+00', 'Morgan, Maggie', '', 'Maggie Morgan', 'Winchester?', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11702, '2018-09-11 07:04:57.202769+00', '2019-06-04 15:33:14.839518+00', 'Wepner, Beatrix & Turi, Gábor', '', 'Beatrix Wepner / Gábor Turi', '', '', 1, 0, 0, 0, NULL, 2018, 0, NULL, '');
INSERT INTO 'person' VALUES (10707, '2013-01-06 22:09:12.433184+00', '2013-01-06 22:09:12.433194+00', 'Highland Music Trust', 'Highland Music Trust', 'Highland Music Trust', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10708, '2013-01-13 23:06:24.653758+00', '2013-01-13 23:06:24.653769+00', 'De Lange, Wim', '', 'Wim de Lange', 'Delft, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10709, '2013-01-16 12:28:27.352467+00', '2013-01-16 12:28:27.352479+00', 'Fielding, Marie & Friends', '', 'Marie Fielding & Friends', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10710, '2013-01-16 13:07:32.23866+00', '2013-01-16 13:07:32.238672+00', 'Rogers, E W', '', 'E W Rogers', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10711, '2013-01-16 13:14:02.979694+00', '2013-01-16 13:14:02.979706+00', 'Meyer, George W.', '', 'George W. Meyer', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10713, '2013-01-16 13:21:26.070691+00', '2013-01-16 14:35:57.922623+00', 'Fielding, Marie & Colgan, Bobby', '', 'Marie Fielding & Bobby Colgan', '', '', 0, 0, 0, 1, 10713, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10719, '2013-01-22 00:11:40.04638+00', '2013-01-22 00:11:40.046391+00', 'Becky Spiro Green', '', 'Becky Spiro Green', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10720, '2013-01-22 00:18:40.399123+00', '2013-01-22 00:18:40.399133+00', 'Wood, Jen', '', 'Jen Wood', 'Edingburgh, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10721, '2013-01-22 13:39:47.238798+00', '2013-01-22 13:39:47.238809+00', 'Cant, Mary', '', 'Mary Cant', 'UK', 'mary.cant@btinternet.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10722, '2013-01-23 11:28:50.900922+00', '2013-01-23 11:28:50.900933+00', 'Sim, Shirley', '', 'Shirley Sim', 'West Lothian', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10723, '2013-01-23 11:34:01.050191+00', '2013-01-23 11:34:01.050202+00', 'Reid, Grace', '', 'Grace Reid', 'West Lothian', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10724, '2013-01-23 12:24:27.836985+00', '2013-01-23 12:24:27.836997+00', 'Fairgrieve, Margaret', '', 'Margaret Fairgrieve', 'West Lothian', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12028, '2021-03-13 21:02:00.046615+00', '2023-01-18 23:00:12.768195+00', 'Ewan, Bill', '', 'Bill Ewan', '', '', 0, 0, 1, 1, NULL, 0, 2023, NULL, '');
INSERT INTO 'person' VALUES (10732, '2013-01-31 10:17:47.031854+00', '2013-01-31 10:17:47.031865+00', 'Shepherd, Allan', '', 'Allan Shepherd', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10733, '2013-02-01 09:20:22.218459+00', '2013-02-01 09:20:22.21847+00', 'Lee, Lesley', '', 'Lesley Lee', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10734, '2013-02-01 09:27:53.469889+00', '2013-02-01 09:27:53.469901+00', 'Carmichael, Hoagy', '', 'Hoagy Carmichael', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'This is presumably not the famous jazz musician and composer of standards such as »Stardust«, who died in 1981 at age 82.');
INSERT INTO 'person' VALUES (10735, '2013-02-01 10:40:38.352343+00', '2013-02-01 10:40:38.352354+00', 'Tyler, Sue', '', 'Sue Tyler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10737, '2013-02-02 16:28:31.312275+00', '2013-02-02 16:28:31.312287+00', 'Hamilton / Holland', '', 'Hamilton / Holland', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2509, NULL, '2013-02-05 13:19:58.582771+00', 'Douglas, Blair', '', 'Blair Douglas', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10738, '2013-02-05 13:22:37.497465+00', '2013-02-05 13:22:37.497476+00', 'Walker, P/M Gordon', '', 'P/M Gordon Walker', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10739, '2013-02-05 13:30:07.080234+00', '2013-02-05 13:30:07.080245+00', 'Sinclair, Sileas', '', 'Sileas Sinclair', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10740, '2013-02-05 13:31:39.462222+00', '2013-02-05 13:31:39.462234+00', 'Ackroyd, Ronald', '', 'Ronald Ackroyd', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2329, NULL, '2013-02-05 13:35:59.994154+00', 'Balloch, P/M John', '', 'P/M John Balloch', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10741, '2013-02-05 14:12:37.960938+00', '2013-02-05 14:12:37.960949+00', 'Sinclair, Neil/Sinclair, Sileas', '', 'Neil Sinclair/Sileas Sinclair', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10716, '2013-01-21 23:55:51.45199+00', '2021-04-01 21:38:45.652165+00', 'Irvine, Connie', '', 'Connie Irvine', '', '', 1, 0, 0, 0, NULL, 0, 2020, NULL, '');
INSERT INTO 'person' VALUES (10743, '2013-02-05 14:32:49.589245+00', '2013-02-05 14:32:49.589256+00', 'Liddell, Stuart/MacColl, Angus', '', 'Stuart Liddell/Angus MacColl', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10744, '2013-02-05 15:42:26.479991+00', '2013-02-05 15:42:26.480002+00', 'Liddall, Stuart', '', 'Stuart Liddell', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10745, '2013-02-05 15:45:24.131522+00', '2013-02-05 15:45:24.131533+00', 'Connellan, Thomas', '', 'Thomas Connellan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10746, '2013-02-05 15:57:29.70925+00', '2013-02-05 15:57:29.709261+00', 'MacColl, Angus John/Wells, Finlay', '', 'Angus John MacColl/Finlay Wells', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10747, '2013-02-05 16:06:52.15489+00', '2013-02-05 16:06:52.154901+00', 'Liddell, S/Provan, D/Bell, C/Wells, F', '', 'Stuart Liddell/David Provan/Cameron Bell/Finlay Weels', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (838, NULL, '2013-02-09 00:54:42.230603+00', 'Gracie, Laura', '', 'Laura Gracie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Was 11 when she wrote Doughnuts Reel');
INSERT INTO 'person' VALUES (10749, '2013-02-10 21:08:57.808074+00', '2013-02-10 21:08:57.808085+00', 'RSCDS Herefordshire Branch', '', 'RSCDS Herefordshire Branch', 'Herefordshire, UK', '', 0, 1, 0, 0, NULL, 1967, 0, NULL, '');
INSERT INTO 'person' VALUES (10715, '2013-01-21 23:51:19.208275+00', '2018-12-07 17:41:26.502749+00', 'Shipman, Dianna', '', 'Dianna L. Shipman', 'Houston, TX', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2171, NULL, '2013-02-18 02:27:00.529007+00', 'Anderson, Ian''s Scottish Country Dance Band', 'Ian Anderson', 'Ian Anderson''s Scottish Country Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (2032, NULL, '2013-02-18 02:29:21.886157+00', 'Atholl Players, The', 'Atholl Players', 'The Atholl Players', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (10146, NULL, '2013-02-18 02:32:06.923007+00', 'Bell, George and his Band', 'George Bell', 'George Bell and his Band', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (10717, '2013-01-22 00:00:12.875913+00', '2013-10-14 09:25:56.978852+00', 'Grierson, Ruth', '', 'Ruth Grierson', 'Newcastle, UK', '', 1, 0, 0, 0, NULL, 1999, 0, NULL, 'date of birth approximate');
INSERT INTO 'person' VALUES (10695, '2013-01-04 15:17:13.260432+00', '2013-02-18 02:33:29.817036+00', 'Bentley, Susan Worland & Friends', 'Bentley & Friends', 'Susan Worland Bentley & Friends', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (10381, NULL, '2013-02-18 02:35:34.440836+00', 'Blair, Jimmy and his TV-Jigtime Band', 'Jimmy Blair Jigtimeband', 'Jimmy Blair and his TV-Jigtime Band', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (2093, NULL, '2013-02-18 02:38:05.026776+00', 'Border Country Dance Band', 'Border Country Dance', 'Border Country Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (10750, '2013-02-18 22:07:58.94744+00', '2013-02-18 22:07:58.947452+00', 'Martin, Christine', '', 'Christine Martin', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, 'Collector of tunes.');
INSERT INTO 'person' VALUES (10751, '2013-02-21 16:00:39.915965+00', '2013-02-21 16:00:39.915976+00', 'Cambridge University Strathspey & Reel Club', 'CUSRC', 'Cambridge University Strathspey & Reel Club', 'Cambridge, UK', '', 0, 1, 0, 0, NULL, 0, 0, NULL, 'This Wiki is now static; no new dances are being added.



website: http://cusarc.soc.srcf.net/wiki/Main_Page');
INSERT INTO 'person' VALUES (10296, NULL, '2015-03-14 18:11:00.838576+00', 'Blair, Jimmy SDB / Archie Duncan Quintet / Rob Gordon SDB', 'Various', 'Jimmy Blair SDB / Archie Duncan Quintet / Rob Gordon SDB', '', '', 0, 0, 0, 0, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (10736, '2013-02-01 10:48:36.420603+00', '2015-03-14 18:11:13.807891+00', 'Lee, David', '', 'David Lee', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10742, '2013-02-05 14:19:22.839622+00', '2015-03-14 18:11:14.071821+00', 'Liddell, Stuart/Sinclaire, Neil/Sinclaire, Sileas', '', 'Stuart Liddell/Neil Sinclair/Sileas Sinclair', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3690, NULL, '2015-03-14 18:11:22.076302+00', 'Quint, Robb', '', 'Robb Quint', 'Thousand Oaks, CA, USA.', 'Volleyballjerry@aol.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10731, '2013-01-29 13:31:48.965412+00', '2015-03-14 18:11:25.333467+00', 'Sibley, Gail and Bennett, Richard', '', 'Gail Sibley and Richard Bennett', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10718, '2013-01-22 00:06:16.137724+00', '2016-01-12 03:27:35.281427+00', 'Crabb-Wyke, Rosemary', '', 'Rosemary Crabb-Wyke', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3449, NULL, '2016-06-26 15:02:54.900069+00', 'MariGold', '', 'Mari Gold', 'Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Marigold is the pseudonym of a dancer in the Eastern Netherlands');
INSERT INTO 'person' VALUES (10752, '2013-02-22 15:35:09.798639+00', '2013-02-22 15:35:09.79865+00', 'Carleton, Harry / Thomas Craig', '', 'Harry Carleton/Thomas Craig', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10753, '2013-02-22 15:50:45.10276+00', '2013-02-22 15:50:45.102771+00', 'Johansen, Arnstein', '', 'Arnstein Johansen', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10758, '2013-02-27 13:31:36.528883+00', '2013-02-27 13:31:36.528894+00', 'Hunter, Trevor', '', 'Trevor Hunter', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10759, '2013-03-05 15:53:57.983432+00', '2013-03-05 15:53:57.983436+00', 'Kowalczik, Judith', '', 'Judith Kowalczik', 'Oldenburg, DE', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10762, '2013-03-14 10:14:29.708769+00', '2013-03-14 10:14:29.708774+00', 'Rawlings, Trisha', '', 'Trisha Rawlings', 'Oxford, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10761, '2013-03-14 10:11:40.092395+00', '2013-03-14 10:16:05.798821+00', 'Rawlings, Mick', '', 'Mick Rawlings', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10760, '2013-03-14 09:42:34.157719+00', '2013-03-14 10:16:48.113598+00', 'Rawlings, Mick & Trisha', '', 'Mick & Trisha Rawlings', 'Oxford, UK', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10763, '2013-03-16 13:31:13.988467+00', '2013-03-16 13:31:13.988473+00', 'Pearce, Sophie', '', 'Sophie Pearce', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2328, NULL, '2013-04-10 09:56:33.529516+00', 'MacLeod, Bobby and his Band', 'Bobby MacLeod', 'Bobby MacLeod and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3444, NULL, '2013-03-24 14:56:16.9506+00', 'Willitt, Edward', '', 'Edward (Ted) Willitt', 'Bishops Stortford', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3165, NULL, '2013-03-26 22:44:24.140583+00', 'Wright, Peter', '', 'Peter Wright', 'Bristol', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10766, '2013-04-01 10:34:12.822726+00', '2013-04-01 10:34:12.822731+00', 'Gawler, Ross', '', 'Ross Gawler', 'Australia ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10767, '2013-04-02 10:54:55.869475+00', '2013-04-02 10:54:55.86948+00', 'McLatchie, Sheena', '', 'Sheena McLatchie', 'Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10773, '2013-04-04 16:06:27.631112+00', '2013-04-04 16:06:27.631117+00', 'Shinton, Maureen', '', 'Maureen Shinton', 'Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3661, NULL, '2018-03-22 13:45:53.707199+00', 'Gräff, Zoltán', '', 'Zoltán Gräff', 'Budapest, Hungary', 'zotyo@zotyo.hu', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10775, '2013-04-08 10:31:38.735545+00', '2013-04-08 10:31:38.73555+00', 'McGown, Jeanette', '', 'Jeanette McGown', 'Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2418, NULL, '2018-05-15 23:51:42.377188+00', 'Gray, J / Risk, L / Petrov, S', 'Gray / Petrov / Risk', 'J Gray / L Risk / S Petrov', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1618, NULL, '2013-04-10 09:14:55.02367+00', 'Beltrami, W / Coir, A', '', 'W Beltrami & A Coir', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (229, NULL, '2013-04-10 09:17:19.87492+00', 'Little, Mr and Mrs W', '', 'Mr and Mrs W Little', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2584, NULL, '2022-12-23 23:21:46.390555+00', 'Anderson, David and his Scottish Dance Band', 'David Anderson Band', 'David Anderson and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10712, '2013-01-16 13:18:17.368635+00', '2022-12-21 10:47:40.76202+00', 'Monaco, James Vincent & McCarthy, Joseph', 'Monaco/McCarthy', 'James V. Monaco & Joseph McCarthy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (420, NULL, '2013-04-10 09:51:13.105719+00', 'Winchester, Mrs Douglas', '', 'Mrs Douglas Winchester', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10602, '2012-02-06 12:16:03.654078+00', '2013-04-10 09:52:09.555087+00', 'Smith, Dave', 'Smith', 'Dave Smith', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1258, NULL, '2013-04-10 09:52:54.619416+00', 'Phythian, George', '', 'George Phythian', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (118, NULL, '2013-04-10 09:56:49.593597+00', 'Eder, W Ernst', '', 'W Ernst Eder', '', 'Eder-E@rmc.ca', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (532, NULL, '2013-04-10 10:00:35.848077+00', 'Adam, S / Gardner, J / Wood, B', '', 'S Adam / J Gardner / B Wood', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2970, NULL, '2013-04-10 10:01:06.563754+00', 'Hankes, Ron & McCormick, John', '', 'Hankes, Ron & McCormick, John', 'Milwaukee, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (174, NULL, '2013-04-10 10:01:26.243606+00', 'Hay, R A and J', '', 'R A and J Hay', 'Perth', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3464, NULL, '2013-04-10 10:02:40.153529+00', 'McKerron, D / Clark, P / Evans, A / Weatherby, W', 'Edin. Branch', 'D McKerron / P Clark / A Evans / W Weatherby', 'Edinburgh', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10776, '2013-04-12 11:26:04.567993+00', '2013-04-12 11:26:04.567999+00', 'Pearson, Maddy', '', 'Maddy Pearson', 'Perth, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10830, '2013-08-10 15:07:59.994727+00', '2013-08-10 15:07:59.994727+00', 'Kefalas, Glenys', '', 'Glenys Kefalas', 'Napier, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10777, '2013-04-12 11:27:09.86126+00', '2013-04-12 11:27:09.861265+00', 'Pearce, Sophie / Pearson, Maddy', '', 'Sophie Pearce / Maddy Pearson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10778, '2013-04-13 21:44:49.417094+00', '2013-04-13 21:44:49.417101+00', 'Brown, Malcolm and Norgate, Martin', '', 'Malcolm Brown and Martin Norgate', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10780, '2013-04-29 13:47:36.75407+00', '2013-04-29 13:47:36.754076+00', 'Ichikawa, Yoko', '', 'Yoko Ichikawa', 'Japan', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10832, '2013-08-10 15:38:57.425622+00', '2013-08-10 15:38:57.425622+00', 'Kellett, Dave', '', 'Dave Kellett', 'Napier, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10779, '2013-04-29 13:39:02.551943+00', '2013-05-01 20:53:49.014005+00', 'Saitama Branch', '', 'Saitama Branch', 'Japan', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2765, NULL, '2014-11-06 20:56:59.928186+00', 'Spägele, Sybille', '', 'Sybille Spägele', 'Germany', 'macrudi@t-online.de', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10784, '2013-05-20 15:41:36.789415+00', '2013-05-20 15:41:36.78942+00', 'Givan, Alexander', '', 'Alexander Givan', 'Kelso, Scotland', '', 0, 0, 1, 0, NULL, 1752, 1803, NULL, 'Information from http://tunearch.org .');
INSERT INTO 'person' VALUES (10785, '2013-05-24 13:55:31.61319+00', '2013-05-24 13:55:31.613196+00', 'McAdam, Kathleen', '', 'Kathleen McAdam', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10787, '2013-05-27 16:35:43.556915+00', '2013-05-27 16:35:43.55692+00', 'Perry, Jill', '', 'Jill Perry', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10788, '2013-05-27 16:41:51.516255+00', '2013-05-27 16:41:51.51626+00', 'Gratiot, Sara', '', 'Sara Gratiot', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10790, '2013-05-27 16:49:37.82372+00', '2013-05-27 16:49:37.823725+00', 'Branstrom, Bob', '', 'Bob Branstrom', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10791, '2013-05-27 16:51:29.232296+00', '2013-05-27 16:51:29.232302+00', 'Stroh, Marian', '', 'Marian Stroh', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10792, '2013-05-27 16:53:48.828566+00', '2013-05-27 16:53:48.828571+00', 'McKelvy, Witsie', '', 'Witsie McKelvy', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2533, NULL, '2013-05-27 21:53:30.567913+00', 'Zbinden, Eveline', '', 'Eveline Zbinden', 'Berne, Switzerland', 'eveline.zbinden@gmx.ch', 1, 0, 0, 0, NULL, 1975, 0, NULL, '');
INSERT INTO 'person' VALUES (10846, '2013-08-24 13:24:44.222984+00', '2013-08-24 13:24:44.222984+00', 'Booz, David', '', 'David Booz', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10769, '2013-04-02 19:18:47.946853+00', '2015-03-14 18:11:02.536842+00', 'Byers, Heather', '', 'Heather Byers', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10768, '2013-04-02 19:13:21.614746+00', '2015-03-14 18:11:03.826823+00', 'Cochran, Margaret', '', 'Margaret Cochran', 'Ballarat, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10772, '2013-04-03 20:46:11.910163+00', '2015-03-14 18:11:16.365214+00', 'MacTier, Mary', '', 'Mary MacTier', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10771, '2013-04-03 20:42:07.939247+00', '2015-03-14 18:11:17.250772+00', 'McFarland, Jeanne', '', 'Jeanne McFarland', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10781, '2013-04-29 13:48:40.3415+00', '2015-03-14 18:11:19.527139+00', 'Nagamine, Mayumi', '', 'Mayumi Nagamine', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10783, '2013-04-29 14:14:06.874833+00', '2015-03-14 18:11:26.93774+00', 'Tamura, Taeko', '', 'Taeko Tamura ', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10770, '2013-04-02 19:21:34.946928+00', '2015-03-14 18:11:27.275391+00', 'Thomas, Lis', '', 'Lis Thomas', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10782, '2013-04-29 14:03:47.124434+00', '2015-03-14 18:11:30.056149+00', 'Yamaguchi, Akira', '', 'Akira Yamaguchi', 'Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10765, '2013-04-01 10:30:10.977711+00', '2018-12-07 17:41:47.937631+00', 'Weeks, Elizabeth', '', 'Elizabeth Weeks', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10789, '2013-05-27 16:45:50.496504+00', '2015-10-29 23:27:44.446786+00', 'Henderson, Linda', '', 'Linda Henderson', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11687, '2018-08-25 08:39:07.5124+00', '2018-08-25 23:56:03.174766+00', 'Allsop, Emma', '', 'Emma Allsop', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11680, '2018-08-25 08:23:39.083474+00', '2018-08-25 23:56:03.225045+00', 'Allsop, Fiona', '', 'Fiona Allsop', 'Stonehaven Kincardineshire', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10774, '2013-04-05 13:30:07.723161+00', '2018-12-07 17:42:11.050245+00', 'Campbell, Lilian', '', 'Lilian Campbell', 'Australia ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1540, NULL, '2013-05-28 09:48:20.30607+00', 'Hastings, John', '', 'John Hastings', 'Edinburgh, Scotland', '', 0, 0, 1, 0, NULL, 1932, 2013, NULL, 'See obituary in <<http://www.scotsman.com/the-scotsman/obituaries/obituary-john-hastings-scottish-country-dance-musician-and-composer-1-2945167|The Scotsman>>. Note that the obituary mentions the tune »<<ddt:John Murray of Lochee|John Murray of Lochiel>>«, but the overwhelming majority of people appear to spell the place »Lochee«.');
INSERT INTO 'person' VALUES (10793, '2013-05-27 22:21:00.525023+00', '2013-05-30 21:28:28.083324+00', 'Brooks, Chris', '', 'Chris Brooks', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11657, '2018-07-04 12:00:47.589342+00', '2018-07-04 12:00:47.589342+00', 'Köppler, Ulrike', '', 'Ulrike Köppler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10798, '2013-06-20 18:02:38.27091+00', '2013-06-20 18:02:38.270919+00', 'Cannell, Melvin', '', 'Melvin Cannell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10800, '2013-07-03 18:37:01.230921+00', '2013-07-03 18:37:01.230928+00', 'McElduff, Aidan', '', 'Aidan McElduff', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10801, '2013-07-03 18:39:59.165562+00', '2013-07-03 18:39:59.165568+00', 'Cowan, Heather', '', 'Heather Cowan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10802, '2013-07-03 18:46:51.069546+00', '2013-07-03 18:46:51.069552+00', 'Beattie, Ruth and Ainsworth, Maureen', '', 'Ruth Beattie and Maureen Ainsworth', 'Glasgow', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10803, '2013-07-03 18:50:11.131567+00', '2013-07-03 18:50:11.131574+00', 'Ewington, Susan', '', 'Susan Ewington', 'Glasgow', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10804, '2013-07-03 18:53:13.448986+00', '2013-07-03 18:53:13.448992+00', 'Beattie, Ruth', '', 'Ruth Beattie', 'gl', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10805, '2013-07-03 21:49:25.702303+00', '2013-07-03 21:49:25.702309+00', 'Huenger, Tobias', '', 'Tobias Huenger', 'Hude, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10806, '2013-07-03 22:11:18.841262+00', '2013-07-03 22:11:18.841268+00', 'Bromann, Carlyn', '', 'Carlyn Bromann', 'Chicago, IL, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10807, '2013-07-03 22:49:09.267387+00', '2013-07-03 22:49:09.267393+00', 'Henricksen, Jill / Stewart, Kathy', '', 'Jill Hendricksen/Kathy Stewart', 'Ayr, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10808, '2013-07-13 19:52:34.582692+00', '2013-07-13 19:52:34.582698+00', 'Chennault', '', 'Chennault', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2082, NULL, '2013-07-19 23:44:49.200997+00', 'Patterson, Andrew', '', 'Andrew Patterson', 'Rotorua, New Zealand', 'andy@pat.gen.nz', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10809, '2013-07-20 13:15:46.859295+00', '2013-07-20 13:15:46.859302+00', 'Naughton, Ed', '', 'Ed Naughton', 'St. Andrews', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10813, '2013-07-31 20:20:52.647721+00', '2013-07-31 20:20:52.647721+00', 'Krug, Ron', '', 'Ron Krug', 'Winnipeg', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10814, '2013-08-02 10:20:23.072813+00', '2013-08-02 10:20:23.072813+00', 'Wallace, Christine', '', 'Christine Wallace', 'Winnipeg', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10817, '2013-08-02 16:11:40.536823+00', '2013-08-02 16:11:40.536823+00', 'Even, John', '', 'John Ewen', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10818, '2013-08-02 19:12:29.165406+00', '2013-08-02 19:12:29.165406+00', 'Ashworth, Diana', '', 'Diana Ashworth', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10819, '2013-08-02 19:15:32.034622+00', '2013-08-02 19:15:32.034622+00', 'Brayson, Janet', '', ' Janet Brayson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10820, '2013-08-02 19:17:45.357025+00', '2013-08-02 19:17:45.357025+00', 'Watson, Noel', '', 'Noel Watson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10821, '2013-08-02 19:27:32.265131+00', '2013-08-02 19:27:32.265131+00', 'Porteous, Hugh', '', 'Hugh Porteous', 'Sheffield', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10822, '2013-08-05 11:04:07.337013+00', '2013-08-05 11:04:07.337013+00', 'MacLachlan, J', '', 'J MacLachlan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10823, '2013-08-06 13:35:45.740056+00', '2013-08-06 13:35:45.740056+00', 'Gray, James and Petrov, Susie', 'J Gray & S Petrov ', 'James Gray and Susie Petrov', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10824, '2013-08-07 15:32:06.963216+00', '2013-08-07 15:32:06.963216+00', 'de Ceuster, Truus', '', 'Truus de Ceuster', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10828, '2013-08-07 20:38:51.82896+00', '2013-08-07 20:38:51.82896+00', 'Fröhling, H / Haramis, J / Schröder, D', 'Fröhling/Haramis/Schröder', 'H Fröhling / J Haramis / D Schröder', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10829, '2013-08-10 15:05:44.876941+00', '2013-08-10 15:05:44.876941+00', 'Napier SCD Club', '', 'Napier SCD Club', 'Napier, New Zealand', '', 0, 1, 0, 0, NULL, 1953, 0, NULL, '');
INSERT INTO 'person' VALUES (1548, NULL, '2020-07-10 08:18:00.880995+00', 'MacLellan, John A', '', 'John McLellan', 'UK', '', 0, 0, 1, 0, 1548, 1921, 0, NULL, '');
INSERT INTO 'person' VALUES (10811, '2013-07-24 15:01:04.300798+00', '2020-09-22 16:43:51.472856+00', 'McKernan, Janet. A.', '', 'Janet. A. McKernan', 'Minnesota, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (349, NULL, '2021-01-02 10:52:43.942935+00', 'Simmonds, Ian', '', 'Ian Simmonds', 'Wellington, New Zealand', 'simmonds@actrix.gen.nz', 1, 0, 0, 0, NULL, 0, 0, NULL, 'A fine interview with Ian, discussing his dance "<<ddd:Oriel Strathspey#5111>>" (Book 32) can be found as a video for that dance and on youtube at 

<<http://youtu.be/mCz7g98eh3M>>.');
INSERT INTO 'person' VALUES (10831, '2013-08-10 15:10:04.329812+00', '2013-08-10 15:10:04.329812+00', 'Twort, Allan', '', 'Allan Twort', 'Napier, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10812, '2013-07-31 15:03:12.477044+00', '2013-08-19 15:59:11.741848+00', 'Horsman, D', '', 'D Horsman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10833, '2013-08-10 15:44:36.021362+00', '2013-08-10 15:44:36.021362+00', 'Morgan, Peggy-Anne', '', 'Peggy-Anne Morgan', 'Napier, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11683, '2018-08-25 08:28:22.790945+00', '2018-08-25 23:56:10.137651+00', 'Davidson, Mike and Frances', '', 'Mike and Frances Davidson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3597, NULL, '2013-08-18 21:48:40.048493+00', 'Ayland, Sue', '', 'Sue Ayland', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10835, '2013-08-20 11:49:20.673425+00', '2013-08-20 11:49:20.673425+00', 'RSCDS Toronto Association', '', 'RSCDS Toronto Association', 'Toronto, Canada', '', 0, 1, 0, 0, NULL, 1957, 0, NULL, '');
INSERT INTO 'person' VALUES (10837, '2013-08-20 22:28:14.489921+00', '2013-08-20 22:28:14.489921+00', 'Baker, Ron', '', 'Ron Baker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10838, '2013-08-20 22:34:11.165969+00', '2013-08-20 22:34:11.165969+00', 'Marsh, Kay', '', 'Kay Marsh', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10839, '2013-08-20 22:55:05.981635+00', '2013-08-20 22:55:05.981635+00', 'Webster, May', '', 'May Webster', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10840, '2013-08-23 17:24:50.214649+00', '2013-08-23 17:24:50.214649+00', 'Oshinowo, Jane', '', 'Jane Oshinowo', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10841, '2013-08-23 17:35:41.908147+00', '2013-08-23 17:35:41.908147+00', 'Smith, Douglas', '', 'Douglas Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10842, '2013-08-24 12:24:41.398933+00', '2013-08-24 12:24:41.398933+00', 'Sinopoli, Heather', '', 'Heather Sinopoli', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10843, '2013-08-24 12:32:56.452015+00', '2013-08-24 12:32:56.452015+00', 'Leibold, George W.', '', 'George W. Leibold', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10844, '2013-08-24 12:51:28.66433+00', '2013-08-24 12:51:28.66433+00', 'Paterson, Ian', '', 'Ian Paterson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10845, '2013-08-24 13:14:19.594364+00', '2013-08-24 13:14:19.594364+00', 'Logan, Grant', '', 'Grant Logan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10826, '2013-08-07 20:37:11.171954+00', '2015-03-14 18:11:07.623371+00', 'Fröhling, Heike', '', 'Heike Fröhling', 'Bonn, DE', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10796, '2013-06-20 13:40:03.297079+00', '2015-03-14 18:11:10.072286+00', 'Hammond, Debbie', '', 'Debbie Hammond', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10825, '2013-08-07 20:36:37.719079+00', '2015-03-14 18:11:10.165061+00', 'Haramis, Jelena', '', 'Jelena Haramis', 'Bonn, DE', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (671, NULL, '2018-01-20 00:56:12.970128+00', 'Harris, Christopher', '', 'Christopher Harris', '', 'scd@chris-harris.ch', 1, 1, 0, 0, NULL, 1948, 0, NULL, '');
INSERT INTO 'person' VALUES (10827, '2013-08-07 20:37:42.889846+00', '2015-03-14 18:11:24.372736+00', 'Schröder, Daniela', '', 'Daniela Schröder', 'Hamburg, DE', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10799, '2013-06-23 18:52:30.781692+00', '2015-03-14 18:11:25.206316+00', 'Shepherd, Ian', '', 'Ian Shepherd', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10815, '2013-08-02 15:54:19.410327+00', '2015-03-14 23:18:32.754189+00', 'Lynch, Robin', '', 'Robin Lynch', 'Winnipeg', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10797, '2013-06-20 17:58:40.597859+00', '2015-09-05 21:08:06.173741+00', 'St Ronan''s Scottish Country Dance Club, Innerleithen', '', 'St Ronan''s Scottish Country Dance Club, Innerleithen', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10794, '2013-06-04 12:21:40.262748+00', '2015-10-24 08:17:45.504185+00', 'Thorin, Lea', '', 'Lea Thorin', 'Seattle, WA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10847, '2013-08-24 13:33:14.059121+00', '2013-08-24 13:33:14.059121+00', 'Forand, Marie-Therese', '', 'Marie-Therese Forand', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3180, NULL, '2013-09-05 10:58:47.662395+00', 'Campbell-Colquhoun, Martin', '', 'Martin Campbell-Colquhoun', 'Adelaide, Australia', 'martincc@bigpond.net.au', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10849, '2013-09-11 19:30:29.60821+00', '2013-09-11 19:36:40.814457+00', 'Eunson, David', '', 'David Eunson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10850, '2013-09-11 19:59:18.529436+00', '2013-09-11 19:59:18.529436+00', 'Green, M', '', 'M Green', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10852, '2013-09-11 21:54:21.556318+00', '2013-09-11 21:54:21.556318+00', 'Bradley, Simon', '', 'Simon Bradley', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11686, '2018-08-25 08:33:54.031551+00', '2018-08-25 23:56:11.120573+00', 'Dunnottar School Children', '', 'Children Dunnottar School ', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10860, '2013-09-20 14:53:35.631102+00', '2013-09-20 14:53:35.631102+00', 'Barton, Jennifer', '', 'Jennifer Barton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10861, '2013-09-20 14:57:19.826017+00', '2013-09-20 14:57:19.826017+00', 'Williford, Jane', '', 'Jane Williford', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10862, '2013-09-20 15:41:12.335233+00', '2013-09-20 15:41:12.335233+00', 'Chennault, Elizabeth', '', 'Elizabeth Chennault', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10863, '2013-09-20 17:01:06.100221+00', '2013-09-20 17:01:06.100221+00', 'Hallenbeck, Judi', '', 'Judi Hallenbeck', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10864, '2013-09-25 16:02:34.214108+00', '2013-09-25 16:02:34.214108+00', 'Martina Christine Rudolph', 'Martina Christine Rudolph', 'Martina Christine Rudolph', 'Frankfurt, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10865, '2013-09-29 21:58:31.620599+00', '2013-09-29 21:58:31.620599+00', 'MacLaughlan, Ian', '', 'Ian MacLaughlan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10868, '2013-10-14 08:06:49.395921+00', '2013-10-14 08:06:49.395921+00', 'Charlotte Mitchell and Emma Olley', 'Charlotte Mitchell and Emma Olley', 'Charlotte Mitchell and Emma Olley', 'Castle Douglas', '', 1, 0, 0, 0, NULL, 1999, 0, NULL, '');
INSERT INTO 'person' VALUES (10870, '2013-10-14 08:56:50.260945+00', '2013-10-14 08:56:50.260945+00', 'Hexham Abbey Dancers', '', 'Hexham Abbey Dancers', 'Hexham, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10474, NULL, '2013-10-14 09:07:53.954331+00', 'Allsop, Emma & Blair, Heather', 'Allsop & Blair', 'Emma Allsop & Heather Blair', 'Airyhall', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10867, '2013-10-14 08:01:47.701543+00', '2013-10-14 09:27:54.531117+00', 'Eilidh Thomson and Elie Stevens', 'Eilidh Thomson and Elie Stevens', 'Eilidh Thomson and Elie Stevens', 'Castle Douglas', '', 1, 0, 0, 0, NULL, 1999, 0, NULL, 'Date of birth approximate');
INSERT INTO 'person' VALUES (10869, '2013-10-14 08:24:18.973302+00', '2013-10-14 09:28:36.129228+00', 'Barrie, Joanna', '', 'Joanna Barrie', 'Lockerbie', '', 1, 0, 0, 0, NULL, 1998, 0, NULL, 'Date of birth approximate');
INSERT INTO 'person' VALUES (10871, '2013-10-14 09:03:05.254278+00', '2013-10-14 09:30:47.629959+00', 'Ashleigh and Amy Oliver', '', 'Ashleigh and Amy Oliver', 'Castle Douglas', '', 1, 0, 0, 0, NULL, 1999, 0, NULL, 'Date of birth approximate');
INSERT INTO 'person' VALUES (10872, '2013-10-14 09:38:25.024615+00', '2013-10-14 09:38:25.024615+00', 'Connolly, Dora', '', 'Dora Connolly', 'Newcastle', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10873, '2013-10-14 09:45:42.384352+00', '2013-10-14 09:45:42.384352+00', 'Horn, Jenni', '', 'Jenni Horn', 'Stonehaven', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10875, '2013-10-14 10:19:35.796408+00', '2013-10-14 10:19:35.796408+00', 'Jackson, Susanna', '', 'Susanna Jackson', 'darlington?', '', 1, 0, 0, 0, NULL, 1998, 0, NULL, 'Date of birth approximate');
INSERT INTO 'person' VALUES (10877, '2013-10-14 11:54:50.654015+00', '2013-10-14 11:54:50.654015+00', 'Kendrick, Chloe', '', 'Chloe Kendrick', 'Darlington?', '', 1, 0, 0, 0, NULL, 1998, 0, NULL, 'Date of birth approximate');
INSERT INTO 'person' VALUES (10878, '2013-10-14 12:00:04.383951+00', '2013-10-14 12:00:04.383951+00', 'Greenhalf, Madeleine', '', 'Madeleine Greenhalf', 'Leeds', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10883, '2013-10-14 22:14:21.179984+00', '2013-10-14 22:14:21.179984+00', 'Bulloch, Arthur', '', 'Arthur Bulloch', 'edinburgh', '', 1, 0, 0, 0, NULL, 2000, 0, NULL, 'The date of birth is approximate.');
INSERT INTO 'person' VALUES (10879, '2013-10-14 13:24:52.847506+00', '2013-10-14 13:31:33.791615+00', 'McGeoch, Stuart', '', 'Stuart McGeoch', 'Troqueer, Dumfries', '', 1, 0, 0, 0, NULL, 1997, 0, NULL, 'Year of birth is approximate');
INSERT INTO 'person' VALUES (10881, '2013-10-14 15:50:39.387235+00', '2013-10-14 15:50:39.387235+00', 'McRobbie, Rebecca', '', 'Rebecca McRobbie', 'Stonehaven', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10874, '2013-10-14 10:10:54.397345+00', '2013-10-14 22:32:03.590337+00', 'Huseyinoglu, Alice', '', 'Alice Huseyinoglu', 'Darlington', '', 1, 0, 0, 0, NULL, 2001, 0, NULL, 'Year of birth approximate.



Her first name can also be Ayla.');
INSERT INTO 'person' VALUES (10885, '2013-10-14 22:39:58.023695+00', '2013-10-14 22:39:58.023695+00', 'Helen Wilson and Rachel Norwood', '', 'Helen Wilson and Rachel Norwood', 'Darlington', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10886, '2013-10-14 22:50:19.920037+00', '2013-10-14 22:50:19.920037+00', 'Troqueer School SCD Club', '', 'Troqueer School SCD Club', 'Troqueer', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10887, '2013-10-14 22:56:35.545375+00', '2013-10-14 22:56:35.545375+00', 'Bruce, Hayley', '', 'Hayley Bruce', 'Dumfries', '', 1, 0, 0, 0, NULL, 1993, 0, NULL, 'Date of birth is approximate');
INSERT INTO 'person' VALUES (10891, '2013-10-29 02:02:21.364659+00', '2013-10-29 02:02:21.364659+00', 'Bennett, Mike', '', 'Mike Bennett', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10892, '2013-10-29 02:09:19.079181+00', '2013-10-29 02:09:19.079181+00', 'Burns, John', '', 'John Burns', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10921, '2014-03-16 11:45:36.331612+00', '2014-03-16 11:45:36.331612+00', 'Brodie, F', '', 'F Brodie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10888, '2013-10-28 23:59:51.268217+00', '2013-10-31 19:04:56.534775+00', 'Dyke, Paula', '', 'Paula Dyke', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10889, '2013-10-29 00:07:10.346177+00', '2021-11-22 11:02:18.182894+00', 'Harland, Pat', '', 'Pat Harland', 'Collingham, Nottinghamshire, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Formerly Bingham, Nottinghamshire, UK');
INSERT INTO 'person' VALUES (10894, '2013-11-12 18:48:14.734702+00', '2013-11-12 18:48:14.734702+00', 'Knooihuizen, Remco', '', 'Remco Knooihuizen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10922, '2014-03-16 12:06:19.546665+00', '2014-03-16 12:06:19.546665+00', 'Walker, G', '', 'G Walker', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10946, '2014-04-11 20:28:34.3956+00', '2014-04-11 20:28:34.3956+00', 'Shakespeare, Wendy', '', 'Wendy Shakespeare', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10948, '2014-04-17 09:50:47.061062+00', '2014-04-17 09:50:47.061062+00', 'Johnson, Claire', '', 'Claire Johnson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10876, '2013-10-14 11:47:51.648945+00', '2015-03-14 18:11:03.453157+00', 'Charlotte Mitchell, Hex and Eilidh Thomson', '', 'Charlotte Mitchell, Hex and Eilidh Thomson', 'Castle Douglas', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10856, '2013-09-13 10:17:40.815217+00', '2015-03-14 18:11:04.451952+00', 'Craven, Norma', '', 'Norma Craven', 'Pretoria', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10882, '2013-10-14 22:00:30.373398+00', '2015-03-14 18:11:05.848495+00', 'Drysdale, Amy', '', 'Amy Drysdale', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2408, NULL, '2015-03-14 18:11:07.589655+00', 'Friedman-Shedlov, Lara', '', 'Lara Friedman-Shedlov', 'Minneapolis, USA', 'lfriedmanshedlov@gmail.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10935, '2014-03-25 15:41:12.575176+00', '2015-03-14 18:11:10.054968+00', 'Hamm/Bennet', 'Hamm/Bennet', 'Hamm/Bennet', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (781, NULL, '2015-03-14 18:11:11.677674+00', 'Hutton, Freddy G', '', 'Freddy G Hutton', '', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10851, '2013-09-11 21:17:14.749992+00', '2015-03-14 18:11:16.926876+00', 'McCann, Leo', '', 'Leo McCann', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10855, '2013-09-13 10:15:27.442996+00', '2015-03-14 18:11:19.646181+00', 'Nelson, Ryan', '', 'Ryan Nelson', 'PRetoria', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10893, '2013-10-29 02:38:49.801646+00', '2015-03-14 18:11:24.387474+00', 'Schubert, Franz Peter', '', 'Franz Schubert', 'Vienna, Austria', '', 0, 0, 1, 0, NULL, 1797, 1828, NULL, '');
INSERT INTO 'person' VALUES (10884, '2013-10-14 22:25:05.930277+00', '2015-03-14 18:11:24.670519+00', 'Selkirk Senior Girls', '', 'Selkirk Senior Girls', 'Selkirk', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Senior Girls (ages 1-17) of the Selkirk Girls Country Dancing Club');
INSERT INTO 'person' VALUES (11681, '2018-08-25 08:25:14.836083+00', '2018-08-25 23:56:17.984546+00', 'Lawson, Linda', '', 'Linda Lawson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10859, '2013-09-18 16:35:57.510374+00', '2018-12-08 10:15:59.990165+00', 'RSCDS Houston & District Branch', 'RSCDS Houston', 'RSCDS Houston & District Branch', 'Houston, Texas, USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10880, '2013-10-14 14:29:05.536454+00', '2018-12-08 10:16:24.009704+00', 'Jennings, Alexandra', '', 'Alexandra Jennings', 'Darlington', '', 1, 0, 0, 0, NULL, 1995, 0, NULL, 'Date of birth is approximate');
INSERT INTO 'person' VALUES (10896, '2013-11-16 20:56:12.204932+00', '2013-11-16 20:56:12.204932+00', 'Brown, Bert', '', 'Bert Brown', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'From issue 356 by Paul Maloney: Douglas Henderson wrote "The Tartan Waistcoat" and published it in Scottish Dance Archives (September 1972, No. 2). He said: "Recommended tune:- Ann Caithness (composed Bert Brown, arranged Nan Main)." I wrote to Laird Brown, son of Bobby Brown, and asked whether Bobby was "Bert" and had written "Ann Caithness". Laird said that his father had NOT written the tune and that he knew nothing about Bert Brown.



This "Bert Brown" has been added as a new person on the basis of this information; nothing more is known about him yet.  Eric Ferguson, 13-11-16');
INSERT INTO 'person' VALUES (3717, NULL, '2018-04-04 16:42:50.708061+00', 'MacKenzie, Betty', '', 'Betty MacKenzie', 'Aberdeen', '', 1, 0, 0, 0, NULL, 0, 2017, NULL, 'Also danced in Nerja, Spain.');
INSERT INTO 'person' VALUES (10900, '2013-12-06 01:06:54.014244+00', '2013-12-06 01:06:54.014244+00', 'Pusey, Rachel', '', 'Rachel Pusey', 'Seattle, WA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10901, '2013-12-10 13:57:18.071207+00', '2013-12-10 13:57:18.071207+00', 'MacGillivray, Patricia', '', 'Patricia MacGillivray', 'Bristol', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10903, '2013-12-10 19:16:12.506923+00', '2013-12-10 19:16:12.506923+00', 'MacGillivray, Stephen', '', 'Stephen MacGillivray', 'Bristol', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10904, '2013-12-10 19:17:58.487381+00', '2013-12-10 19:17:58.487381+00', 'Toomer, Heather', '', 'Heather Toomer', 'Bristol', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10905, '2013-12-10 19:30:43.588804+00', '2013-12-10 19:30:43.588804+00', 'Fish, Pat', '', 'Pat Fish', 'Bristol, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11679, '2018-08-25 08:20:27.105885+00', '2018-08-25 23:56:28.274429+00', 'Stonehaven Branch RSCDS', 'Stonehaven', 'RSCDS Stonehaven Branch', 'Stonehaven, Kincardineshire', '', 0, 1, 0, 0, NULL, 1948, 0, NULL, '');
INSERT INTO 'person' VALUES (10909, '2013-12-21 22:59:49.620218+00', '2013-12-22 18:29:33.565591+00', 'Wong, Darrick', '', 'Darrick Wong', 'Oregon', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10910, '2013-12-22 23:07:00.319569+00', '2013-12-22 23:07:00.319569+00', 'Gibson, Holly', '', 'Holly Gibson', 'Oregon', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11688, '2018-08-25 08:40:54.701969+00', '2018-08-25 23:56:29.890955+00', 'Walker, Gill and Black, Michelle', '', 'Gill Walkerand Michelle Black', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1760, NULL, '2014-02-03 11:31:56.392099+00', 'Brunken, Elaine', '', 'Elaine Brunken', 'USA', 'elainerb@aol.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10914, '2014-02-06 14:08:43.34559+00', '2014-02-06 14:08:43.34559+00', 'Bremner, G', 'G Bremner', 'G Bremner', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3477, NULL, '2014-02-10 10:06:26.711837+00', 'Gibson, S', '', 'S Gibson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10103, NULL, '2014-02-15 18:38:29.00611+00', 'Frew, Bobby', 'Bobby Frew', 'Bobby Frew', '', '', 0, 0, 1, 0, NULL, 0, 2000, NULL, '');
INSERT INTO 'person' VALUES (1673, NULL, '2014-03-06 01:16:27.869471+00', 'Mathieson, Robert P/M', '', 'P/M Robert Mathieson', '', '', 0, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10917, '2014-03-09 09:04:16.463602+00', '2014-03-09 09:04:16.463602+00', 'RSCDS Falkirk', '', 'RSCDS Falkirk', 'Falkirk', '', 0, 1, 0, 0, NULL, 0, 0, NULL, 'Publisher of the 2001 CD booklet');
INSERT INTO 'person' VALUES (10918, '2014-03-10 08:12:53.781904+00', '2014-03-10 08:12:53.781904+00', 'Sweeley, Charles', '', 'Charles Sweeley', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10919, '2014-03-13 17:47:54.139404+00', '2014-03-13 17:47:54.139404+00', 'Willson, Meredith', 'Willson', 'Meredith Willson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10920, '2014-03-16 10:00:59.072347+00', '2014-03-16 10:00:59.072347+00', 'Pictish Players, The', 'Pictish', 'The Pictish Players', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10925, '2014-03-16 15:31:27.369838+00', '2014-03-16 15:31:27.369838+00', 'Taki, Rentaro/Nobarasha', 'Taki/Nobarasha', 'Rentaro Taki/Nobarasha', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10926, '2014-03-16 15:34:28.210381+00', '2014-03-16 15:34:28.210381+00', 'Von Weber, C M/Nobarasha', 'Von Weber/Nobarasha', 'C M Von Weber/Nobarasha', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10927, '2014-03-16 15:41:27.560973+00', '2014-03-16 15:41:27.560973+00', 'Hirai, Yasuzaburo/Nobarasha', 'Hirai/Nobarasha', 'Yasuzaburo Hirai/Nobarasha', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10928, '2014-03-16 15:44:12.128071+00', '2014-03-16 15:44:12.128071+00', 'Kainuma, Minoru/Nobarasha', 'Kainuma/Nobarasha', 'Minoru Kainuma/Nobarasha', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10929, '2014-03-16 15:47:06.58171+00', '2014-03-16 15:47:06.58171+00', 'Okano, Sadaichi/Nobarasha', 'Okano/Nobarasha', 'Sadaichi Okano/Nobarasha', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10930, '2014-03-17 22:59:58.951778+00', '2014-03-17 23:39:25.80009+00', 'McRanor, Ellen', '', 'Ellen McRanor', 'Florida, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10931, '2014-03-19 08:22:50.951846+00', '2014-03-19 08:22:50.951846+00', 'Scottish Fiddle Orchestra', '', 'Scottish Fiddle Orchestra', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10933, '2014-03-20 13:06:26.387786+00', '2014-03-20 13:06:26.387786+00', 'Shaw, Bevin', '', 'Bevin Shaw', 'Wanganui, New Zealand', 'bevin.shaw@xtra.co.nz', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10936, '2014-03-26 14:13:04.004634+00', '2014-03-26 14:13:04.004634+00', 'Mackay, Jim Scottish Dance Band', 'Jim Mackay', 'Jim Mackay Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10939, '2014-03-26 15:24:42.758689+00', '2014-03-26 15:24:42.758689+00', 'Douglas, Ronnie', 'Ronnie Douglas', 'Ronnie Douglas', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2646, NULL, '2018-09-14 18:03:04.529772+00', 'Porteous, James', '', 'James Porteous', '', '', 0, 0, 1, 0, NULL, 1762, 1847, NULL, 'For a biography see https://tunearch.org/wiki/Biography:James_Porteous');
INSERT INTO 'person' VALUES (10941, '2014-03-26 15:59:09.211276+00', '2014-03-26 16:34:04.549867+00', 'Mackay, John', 'John Mackay', 'John Mackay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3211, NULL, '2014-03-31 10:01:30.218914+00', 'MacCallum, John', '', 'John MacCallum', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10944, '2014-04-03 08:26:31.280731+00', '2014-04-03 08:26:31.280731+00', 'Harcus, Bob', '', 'Bob Harcus', '', 'bobharcus@btinternet.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11083, '2015-02-20 14:19:19.929807+00', '2015-02-20 14:19:19.929807+00', 'Bryer, C.', '', 'C. Bryer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (958, NULL, '2023-01-27 11:27:07.210339+00', 'Ackers, Rita', '', 'Rita Ackers', 'Liverpool, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10640, '2012-07-23 23:04:22.323261+00', '2021-05-08 22:49:48.37814+00', 'Steel, Jacob', '', 'Jacob Steel', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Contributor to the CUSRC ReelWiki collection of dances');
INSERT INTO 'person' VALUES (10854, '2013-09-12 22:23:56.77787+00', '2021-07-24 07:39:10.288039+00', 'Gray, Alex and James', '', 'Alex and James Gray', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10945, '2014-04-11 20:14:26.370655+00', '2014-04-11 20:14:26.370655+00', 'Harvey, Pat', '', 'Pat Harvey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10915, '2014-02-06 17:36:58.365062+00', '2015-03-14 18:08:35.000635+00', 'Lindsay, J & Smith, K & Johnstone, M', 'Lindsay/Smith/Johnstone', 'Lindsay/Smith/Johnstone', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10923, '2014-03-16 12:14:59.107992+00', '2015-03-14 18:10:58.681281+00', 'Anderson, B', '', 'B Anderson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11703, '2018-09-13 12:04:31.625662+00', '2018-09-13 12:17:17.951565+00', 'Finogenova, Catherine', '', 'Catherine Finogenova', 'Switzerland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10898, '2013-11-25 19:15:31.443627+00', '2015-03-14 18:11:13.380728+00', 'Kohn, Livia', '', 'Livia Kohn', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10937, '2014-03-26 14:26:06.034851+00', '2015-03-14 18:11:15.43791+00', 'Mackay, Jim', 'Jim Mackay', 'Jim Mackay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10943, '2014-03-28 09:20:10.202642+00', '2015-03-14 18:11:21.194878+00', 'Porter, Sue and Rooney, Di', '', 'Sue Porter and Di Rooney', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10902, '2013-12-10 19:12:30.133796+00', '2019-03-09 20:38:39.971516+00', 'Savill, Barbara', '', 'Barbara Savill', 'Bristol', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Before her marriage Barbara was known as Barbara de Winton');
INSERT INTO 'person' VALUES (10942, '2014-03-27 23:39:59.519848+00', '2015-03-14 18:11:26.756668+00', 'Sutherland, Nora', '', 'Nora Sutherland', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10938, '2014-03-26 15:02:31.401539+00', '2015-03-14 18:11:27.367006+00', 'Thomson, Bruce', 'Bruce Thomson', 'Bruce Thomson', '', '', 0, 0, 1, 0, NULL, 1930, 0, NULL, '');
INSERT INTO 'person' VALUES (1437, NULL, '2015-03-14 18:11:29.162905+00', 'White, Peter', '', 'Peter White', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10899, '2013-11-27 04:08:27.267098+00', '2015-09-24 04:24:02.282945+00', 'Fischer, Carola & Lange, Anika', '', 'Carola Fischer / Anika Lange', 'Schluechtern, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10932, '2014-03-19 11:15:37.294419+00', '2015-09-24 04:25:39.478346+00', 'Shand, Sir Jimmy & Jimmy Shand Jnr', 'Sir Jimmy Shand & Shand Jnr', 'Sir Jimmy Shand & Jimmy Shand Jnr', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1167, NULL, '2017-04-12 23:56:19.127154+00', 'Price, Peter', '', 'Peter Price', 'Norwood, USA', 'peter.price1672@gmail.com', 1, 1, 0, 0, NULL, 1952, 0, NULL, '');
INSERT INTO 'person' VALUES (11704, '2018-09-15 10:15:06.249809+00', '2018-09-15 23:56:29.058599+00', 'Williams, John', '', 'John Williams', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10916, '2014-02-06 18:06:47.953999+00', '2018-09-16 10:00:33.440137+00', 'Thoumire, Simon', 'S Thoumire', 'Simon Thoumire', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10949, '2014-04-17 22:11:54.463577+00', '2014-04-17 22:12:01.507805+00', 'Bellinghausen, Tom', '', 'Tom Bellinghausen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Source: Programme of The 2014 Highland Mist Ball (St. Louis, Missouri) on Saturday, JUN 28.');
INSERT INTO 'person' VALUES (10950, '2014-05-02 15:20:04.696483+00', '2014-05-02 15:20:04.696483+00', 'Kean, Elizabeth', '', 'Elizabeth Kean', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (227, NULL, '2018-07-06 15:37:54.053906+00', 'Ligtmans, Frans', '', 'Frans Ligtmans', 'Nuenen, Netherlands', '', 1, 1, 0, 0, NULL, 1932, 2018, NULL, 'Frans Ligtmans, was born 3 April 1932 in Zierikzee in the province of Zeeland of the Netherlands.



In 1977 she was among the founding member of The Thistle Club of Eindhoven.



Starting from just one set of 8 dances at its peak The Thistle Club had about 50 dancers. Frans gave lessons to beginners, advanced and children. She led Preliminary Teachers Courses on the continent, wrote dances and did the choreography and rehearsals for demonstrations.



Sadly, Frans'' health kept her from dancing in later life. She died on 16 January 2018.



There is an obituary at <<http://www.thistleclub.nl/in-memoriam.html|The Thistle Club>> webpage.');
INSERT INTO 'person' VALUES (10953, '2014-05-09 09:08:34.226163+00', '2014-05-09 09:08:34.226163+00', 'Allsop, Emma & Jullian Louis', '', 'Emma Allsop & Jullian Louis', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10957, '2014-05-09 21:55:10.039508+00', '2014-05-09 21:55:10.039508+00', 'Howe, Carol', '', 'Carol Howe', 'Grimsby, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3067, NULL, '2014-05-21 22:33:53.637523+00', 'Brown, Bobby and The Scottish Accent', 'Bobby Brown', 'Bobby Brown and The Scottish Accent', 'Mississauga, CANADA', '', 0, 0, 0, 1, NULL, 1974, 0, NULL, 'Band created 1974.  On the death of Bobby Brown on May 3rd, 2011, the band “Bobby Brown and the Scottish Accent” changed its name to “Scotch Mist”, At the changeover, one CD, "Eight Bars of Magic", was produced using the name “Laird Brown with the Scottish Accent”, but the band never used that name in any other context.  Both bands were based in Toronto, Canada.  ');
INSERT INTO 'person' VALUES (10955, '2014-05-09 21:09:32.623389+00', '2014-05-21 22:44:16.414885+00', 'Scotch Mist', 'Scotch Mist', 'Scotch Mist', '', '', 0, 1, 0, 1, NULL, 2011, 0, NULL, 'The band "Bobby Brown and the Scottish Accent" was the vision of Bobby Brown (July 13 1941-May 3 2011).   

On his death, the band changed its name to “Scotch Mist”, and the same day Stef Hutka joined it as fiddler.  At the changeover, one CD, "Eight Bars of Magic", was produced using the name “Laird Brown with the Scottish Accent”, but the band never used that name in any other context.  Both bands were based in Toronto, Canada.  

For the last 3 years the band has continued the tradition of playing for Scottish Country Dance Music and workshops throughout North America.  



The current (5/2014) members are: <BR>

Lead Accordion: Laird Brown <BR>

Violin: Stefanie Hutka <BR>

2nd Accordion: Kerry D. Boax <BR>

Piano: Donny Wood <BR>

Drums: Warren Beesley <BR>

Bass: Rob Wolanski



When writing tunes, Laird uses the name “Laird J. Brown”. ');
INSERT INTO 'person' VALUES (2965, NULL, '2014-05-21 22:45:39.932558+00', 'Brown, Laird J', '', 'Laird Brown', 'Canada', '', 0, 0, 1, 1, NULL, 0, 0, NULL, 'All but 4 of these 15 tunes also appear as tunes in the album "Eight bars of Magic" by "Laird Brown with The Scottish Accent (2010)".  It is clear that this Laird J Brown is the same person as the Laird Brown of that band.');
INSERT INTO 'person' VALUES (10963, '2014-06-09 19:39:37.540772+00', '2014-06-09 19:39:37.540772+00', 'Robson, Barbara', '', 'Barbara Robson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10964, '2014-06-09 19:43:54.510229+00', '2014-06-09 19:43:54.510229+00', 'Quarmby, Mary', '', 'Mary Quarmby', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10965, '2014-06-09 19:46:24.511742+00', '2014-06-09 19:46:24.511742+00', 'Scott, Fred', '', 'Fred Scott', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10966, '2014-06-09 19:52:57.47577+00', '2014-06-09 19:52:57.47577+00', 'Southgate, Chris', '', 'Chris Southgate', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10967, '2014-06-09 19:58:16.44241+00', '2014-06-09 19:58:16.44241+00', 'Spoun, Hilary', '', 'Hilary Spoun', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11003, '2014-09-18 15:56:29.60862+00', '2014-09-18 15:56:29.60862+00', 'Orr, Tom and his Band', '', 'Tom Orr and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11004, '2014-09-28 20:33:12.621821+00', '2014-09-28 20:33:12.621821+00', 'Ridgway, Ken', '', 'Ken Ridgway', 'Bracknell', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11005, '2014-09-29 00:43:05.316723+00', '2014-09-29 00:43:05.316723+00', 'Bridport Scottish Dancers', '', 'Bridport Scottish Dancers', 'Bridport, England', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11006, '2014-09-29 13:07:51.669544+00', '2014-09-29 13:07:51.669544+00', 'Dawson, Robert', '', 'Robert Dawson', 'Bridport, England', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10968, '2014-06-09 20:14:05.322304+00', '2019-05-22 23:56:16.689701+00', 'Manning, Barbara', '', 'Barbara Manning', 'Hemel Hempstead,  UK', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10972, '2014-07-11 12:48:29.322357+00', '2014-07-11 12:48:29.322357+00', 'Berry, Graham', '', 'Graham Berry', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11080, '2015-02-14 17:31:17.683873+00', '2015-02-14 17:31:17.683873+00', 'Jappy, H', '', 'H Jappy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10913, '2014-01-22 10:28:51.568232+00', '2020-02-08 12:55:09.942031+00', 'Prade, Hans', '', 'Hans Prade', 'Freiburg, DE', '', 1, 1, 0, 0, NULL, 0, 2019, NULL, '');
INSERT INTO 'person' VALUES (10958, '2014-05-09 22:15:00.269441+00', '2021-10-20 15:07:22.696932+00', 'Collins, Andrew and Mairi', '', 'Andrew and Mairi Collins', 'Oakville, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10974, '2014-07-21 10:55:12.272455+00', '2014-07-21 10:55:12.272455+00', 'Steiner, Ilana', '', 'Ilana Steiner', 'Vienna, Austria', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10975, '2014-07-27 12:22:45.715795+00', '2014-07-27 12:22:45.715795+00', 'Ross-shire Printing & Publishing Co. Ltd.', '', 'Ross-shire Printing & Publishing Co. Ltd.', 'Dingwall, UK', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10976, '2014-07-27 22:14:17.027124+00', '2014-07-27 22:14:17.027124+00', 'Fouler, Enid', '', 'Enid Fouler', 'San Diego Branch (in 1986)', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10977, '2014-07-30 13:58:05.484419+00', '2014-07-30 13:58:05.484419+00', 'MacNeil, A', '', 'A MacNeil', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10978, '2014-07-30 14:38:37.775464+00', '2014-07-30 14:38:37.775464+00', 'Powrie, Bill', '', 'Bill Powrie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10960, '2014-05-10 00:23:17.464958+00', '2015-03-14 18:11:02.024795+00', 'Brown, Laird + Wood, Donald G', '', 'Laird Brown + Donald G Wood', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10970, '2014-06-18 14:02:59.362782+00', '2015-03-14 18:11:13.929371+00', 'Letchworth Garden City Scottish Country Dance Club', '', 'Letchworth Garden City SCDC', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10954, '2014-05-09 09:14:13.913396+00', '2015-03-14 18:11:20.267095+00', 'Orr, Tom', '', 'Tom Orr', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10934, '2014-03-21 23:52:58.231822+00', '2015-05-11 23:56:03.818859+00', 'Blim, Dan', '', 'Dan Blim', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10961, '2014-05-26 20:47:55.859209+00', '2015-07-21 23:56:22.126479+00', 'Schuckelt, Holger', '', 'Holger Schuckelt', 'Dresden, DE', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11215, '2015-09-24 04:00:22.583674+00', '2015-09-24 04:00:22.583674+00', 'Finan, Julia', '', 'Julia Finan', 'Vienna, Austria', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10980, '2014-08-11 15:25:23.513581+00', '2014-08-11 15:25:23.513581+00', 'Holliday, Dr John', 'John Holliday', 'Dr John Holliday', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10982, '2014-08-19 07:11:14.558258+00', '2014-08-19 07:11:14.558258+00', 'Cathcart, Iain and his Band', 'Iain Cathcart', 'Iain Cathcart and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10983, '2014-08-19 07:26:34.131243+00', '2014-08-19 07:26:34.131243+00', 'Richards, Henry Brinley', '', 'Henry Brinley Richards', '', '', 0, 0, 1, 0, NULL, 1817, 1885, NULL, 'See <<http://en.wikipedia.org/wiki/Henry_Brinley_Richards|Wikipedia>> for details.');
INSERT INTO 'person' VALUES (10984, '2014-08-19 07:33:24.179165+00', '2014-08-19 07:33:24.179165+00', 'á Becket Sr., Thomas', '', 'Thomas á Becket Sr.', '', '', 0, 0, 1, 0, NULL, 1808, 1890, NULL, '');
INSERT INTO 'person' VALUES (10986, '2014-08-19 09:03:47.175262+00', '2014-08-19 09:03:47.175262+00', 'MacNaughtan, Adam', '', 'Adam MacNaughtan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Frequently misspelled »MacNaughton«.');
INSERT INTO 'person' VALUES (10987, '2014-08-19 09:12:56.380345+00', '2014-08-19 09:12:56.380345+00', 'Love, William', '', 'William Love', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10988, '2014-08-24 14:56:43.124694+00', '2014-08-24 14:56:43.124694+00', 'Coates, Eric', '', 'Eric Coates', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10236, NULL, '2014-08-24 15:16:52.765084+00', 'Gordon, P/M J', 'P/M J Gordon', 'P/M J Gordon', '', '', 0, 0, 1, 0, 10236, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1920, NULL, '2014-08-25 10:08:43.022857+00', 'Bryson, P/M Willie', '', ' P/M Willie Bryson', '', '', 0, 0, 1, 0, 1920, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10991, '2014-08-26 16:22:28.819566+00', '2014-08-26 16:22:28.819566+00', 'Brown, Abigail', '', 'Abigail Brown', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10993, '2014-08-26 20:38:24.561053+00', '2014-08-26 20:41:36.394416+00', 'Young Ladies Of The CSCDS', '', 'Young Ladies Of The CSCDS', 'Charlotte, NC, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10836, '2013-08-20 11:53:15.450285+00', '2014-08-27 21:21:22.672111+00', 'Noble, Jean', '', 'Jean Noble', 'Toronto, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'There is some further information at Dick Oakes'' <<http://www.phantomranch.net/folkdanc/folktchr.htm|Master Folk Dance Teacher Biographies>>: <<http://www.phantomranch.net/folkdanc/teachers/noble_j.htm>>');
INSERT INTO 'person' VALUES (10996, '2014-08-30 23:22:25.943854+00', '2014-08-30 23:22:25.943854+00', 'Rafferty, Anne', '', 'Anne Rafferty', 'Falkirk ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11001, '2014-09-09 13:40:19.895775+00', '2014-09-09 13:40:19.895775+00', 'Bonn/Cologne Dancers', '', 'Bonn/Cologne Dancers', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11007, '2014-09-29 13:19:19.046556+00', '2014-09-29 13:19:19.046556+00', 'Ashby, John & Hilary', '', 'John & Hilary Ashby', 'Bridport, england', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10969, '2014-06-17 01:40:32.844953+00', '2014-09-29 20:39:41.075937+00', 'Ingram, Karin and Matthews, Tricia', 'Ingram and Matthews', 'Karin Ingram and Tricia Matthews', 'Glasgow', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11011, '2014-10-01 21:59:39.841815+00', '2014-10-01 21:59:39.841815+00', 'Robertson, Garry', '', 'Garry Robertson', 'Edinburgh', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11012, '2014-10-01 22:18:15.930665+00', '2014-10-01 22:18:15.930665+00', 'Andrews, Jill', '', 'Jill Andrews', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11014, '2014-10-01 22:36:08.055155+00', '2014-10-01 22:36:08.055155+00', 'Nolan, Andrew', '', 'Andrew Nolan', 'Edinburgh', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11015, '2014-10-01 23:26:45.228072+00', '2014-10-01 23:26:45.228072+00', 'Harry, Elizabeth Anne', '', 'Elizabeth A Harry', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11016, '2014-10-02 00:51:59.066033+00', '2014-10-02 00:51:59.066033+00', 'Bews, Jon', '', 'Jon Bews', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11018, '2014-10-04 00:11:10.945528+00', '2014-10-04 00:11:10.945528+00', 'Ford, Val', '', 'Val Ford', 'Bridport, England', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11019, '2014-10-04 00:43:12.297701+00', '2014-10-04 00:43:12.297701+00', 'Meadley, Tony', '', 'Tony Meadley', 'Bridport, England', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11021, '2014-10-04 01:01:09.202404+00', '2014-10-07 08:12:41.385516+00', 'McIntosh, Marion', '', 'Marion McIntosh', 'Westerton', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1492, NULL, '2014-11-09 01:10:49.163378+00', 'Watson, James (Jim)', '', 'James (Jim) Watson', '', '', 0, 0, 1, 0, NULL, 1869, 0, NULL, 'A little bit of information about James Watson can be found <<http://genforum.genealogy.com/watson/messages/8683.html|here>>.');
INSERT INTO 'person' VALUES (11032, '2014-11-10 20:32:12.528718+00', '2014-11-10 20:32:12.528718+00', 'Bethray, Sandra', '', 'Sandra Bethray', 'Norwalk, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11023, '2014-10-07 21:46:43.580383+00', '2014-10-07 21:46:43.580383+00', 'Hart, Mary / Porteous, Joyce & Hugh', '', 'Mary Hart / Joyce & Hugh Porteous', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11024, '2014-10-07 22:40:16.825421+00', '2014-10-07 22:40:16.825421+00', 'Keegan, Louise', '', 'Louise Keegan', '', '', 1, 0, 0, 0, NULL, 0, 2014, NULL, '');
INSERT INTO 'person' VALUES (11022, '2014-10-06 22:58:57.187404+00', '2015-03-14 18:11:14.667446+00', 'Lush, Jim', '', 'Jim Lush (Jimmy)', 'Dorset, England', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Also calls himself "Jimmy Lush"');
INSERT INTO 'person' VALUES (10981, '2014-08-11 22:00:49.81726+00', '2016-12-01 23:57:14.912664+00', 'Meikle, George / Simpson, Gordon', 'Meikle & Simpson', 'George Meikle / Gordon Simpson', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'Gordon Simpson died june 2016');
INSERT INTO 'person' VALUES (10989, '2014-08-24 17:33:30.746119+00', '2015-03-14 18:11:21.811612+00', 'Pryor, Arthur', 'A Pryor', 'Arthur Pryor', '', '', 0, 0, 1, 0, NULL, 1869, 1942, NULL, '');
INSERT INTO 'person' VALUES (10994, '2014-08-29 13:29:59.731815+00', '2020-04-12 23:57:01.738051+00', 'Shand, James', '', 'James Shand', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, 'James was Mrs. Annie Shand''s husband (Aberdeenshire)');
INSERT INTO 'person' VALUES (10979, '2014-08-11 14:45:10.982156+00', '2020-06-16 18:14:33.469787+00', 'MacFadyen, Susan and her Scottish Dance Band', 'Susan MacFadyen', 'Susan MacFadyen and her Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (723, NULL, '2020-09-12 20:28:54.725365+00', 'Vandegrift, Elinor M', '', 'Elinor M Vandegrift', 'Seattle WA  USA', 'elinor3@frontier.com', 1, 0, 0, 0, NULL, 0, 0, NULL, 'There is some further information at Dick Oakes'' <<http://www.socalfolkdance.org/master_teachers.htm|Master Folk Dance Teacher Biographies>>: <<http://www.socalfolkdance.org/master_teachers/vandegrift_em.htm>>');
INSERT INTO 'person' VALUES (392, NULL, '2020-12-22 00:48:59.868637+00', 'Thurston, Hugh A', '', 'Hugh A Thurston', 'Vancouver', '', 1, 1, 0, 0, NULL, 1922, 2006, NULL, 'Hugh Thurston''s full name was Hugh Ansfrid Thurston.



There is a very informative entry at Dick Oakes'' <<http://www.socalfolkdance.org/master_teachers.htm|Master Folk Dance Teacher Biographies>>: <<http://www.socalfolkdance.org/master_teachers/thurston_h.htm>>');
INSERT INTO 'person' VALUES (2371, NULL, '2015-03-14 18:11:23.156019+00', 'Robertson, Judith W', '', 'Judith W Robertson', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10998, '2014-08-31 14:22:10.848711+00', '2015-03-14 18:11:26.194886+00', 'Stafford & District Caledonian Society', 'Stafford & District', 'Stafford & District Caledonian Society', 'Stafford & District , UK', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11017, '2014-10-02 01:13:44.405002+00', '2015-03-25 09:44:09.897321+00', 'Munro, Graeme and his Band', 'Graeme Munro', 'Graeme Munro and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10995, '2014-08-30 23:08:02.61327+00', '2015-09-03 23:56:02.959688+00', 'Bardill/Prince', '', 'Bardill/Prince', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11010, '2014-09-29 13:44:11.248274+00', '2017-03-15 04:51:16.352671+00', 'Guilbert, Martine', '', 'Martine Guilbert', 'Louannec, Brittany, France', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11660, '2018-07-13 10:01:41.848402+00', '2018-07-13 10:20:54.910358+00', 'Kakovkina, Irina', '', 'Irina Kakovkina', 'Kirov, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11662, '2018-07-13 10:04:59.389876+00', '2018-07-13 10:21:20.106757+00', 'Zhdanova, Olga and Solodiankina, Anastasia', '', 'Olga Zhdanova and Anastasia Solodiankina', 'Kirov, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11663, '2018-07-13 10:07:33.894041+00', '2018-07-13 10:21:40.698973+00', 'Novoselov, Victor', '', 'Victor Novoselov', 'Kirov, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11738, '2018-10-19 20:35:01.351508+00', '2018-10-19 23:56:07.639206+00', 'Davies, Janice', '', 'Janice Davies', 'RSCDS Hereford', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11658, '2018-07-13 09:46:18.469473+00', '2018-07-13 23:56:10.709756+00', 'Flying Scotsman SCD Club', '', 'Flying Scotsman SCD Club', 'Kirov, Russia', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11661, '2018-07-13 10:03:57.182115+00', '2018-07-13 23:56:26.841327+00', 'Solodiankina, Anastasia', '', 'Anastasia Solodiankina', 'Kirov, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11008, '2014-09-29 13:32:17.946457+00', '2018-12-08 23:15:40.82376+00', 'Hughes, Patricia', '', 'Patricia Hughes', 'Bridport, England', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10992, '2014-08-26 19:35:16.796453+00', '2018-12-09 13:44:41.643647+00', 'Ritzau, Erika', '', 'Erika Ritzau', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11025, '2014-10-19 09:02:29.581452+00', '2014-10-19 09:02:29.581452+00', 'Reyswood, Bob', '', 'Bob Reyswood', 'Blue Mountains SCD, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11026, '2014-10-19 09:21:31.619139+00', '2014-10-19 09:21:31.619139+00', 'Carter, Gillian', '', 'Gillian Carter', 'Sydney, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11027, '2014-10-19 09:50:03.708824+00', '2014-10-19 09:50:03.708824+00', 'Wales, Helen', '', 'Helen Wales', 'Sydney, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11028, '2014-10-19 15:51:42.551859+00', '2014-10-19 15:51:42.551859+00', 'Shunmugam, Govindasamy (Govin)', '', 'Shunmugam Govindasamy (Govin)', 'Sydney, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11030, '2014-10-19 16:54:03.499521+00', '2014-10-19 16:54:03.499521+00', 'Darby, Michael', '', 'Michael Darby', 'Sydney, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11033, '2014-11-18 23:29:39.988118+00', '2014-11-18 23:29:39.988118+00', 'Thomson, Mary Ellen', '', 'Mary Ellen Thomson', 'Mary Ellen Thomson', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10686, '2012-12-28 16:43:07.479489+00', '2014-11-06 17:16:31.995258+00', 'Meldrum, P/M Robert', '', 'P/M Robert Meldrum', '', '', 0, 0, 1, 0, 10686, 1851, 1942, NULL, 'Robert Meldrum was Pipe Major of the 93rd Highlanders in the 1870ies.



At Piptunes.ca there is a nice <<http://www.pipetunes.ca/composers.asp?pg=Details&composerID=245|informative page>> about him as well as some <<http://www.pipetunes.ca/displayproduct.asp?catID=146&tuneID=1558|mp3 samples>> of his tunes.');
INSERT INTO 'person' VALUES (1694, NULL, '2014-11-06 17:31:59.016797+00', 'MacColl, John', 'John MacColl', 'John MacColl', '', '', 0, 0, 1, 0, NULL, 1860, 1943, NULL, 'At Piptunes.ca there is a nice <<http://www.pipetunes.ca/composers.asp?pg=Details&composerID=19|informative page>> about him as well as some <<http://www.pipetunes.ca/browseproducts.asp?catID=146&searchComposer=19|mp3 samples>> of his tunes.');
INSERT INTO 'person' VALUES (11031, '2014-11-06 17:46:47.26233+00', '2014-11-06 17:46:47.26233+00', 'Copeland, Jimmy', '', 'Jimmy Copeland', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2843, NULL, '2014-11-07 08:58:14.599567+00', 'Crawford, John', '', 'John Crawford', 'Freuchie, Scotland', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'There is a nice <<http://boxandfiddlearchive.weebly.com/john-crawford.html|informative page>> about him at the Box and Fiddle archive.');
INSERT INTO 'person' VALUES (11085, '2015-02-20 16:33:50.995321+00', '2015-02-20 16:33:50.995321+00', 'McFadden, June', '', 'June McFadden', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11086, '2015-02-21 13:24:46.479031+00', '2015-02-21 13:24:46.479031+00', 'Durnin, Cheryl', '', 'Cheryl Durnin', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11664, '2018-07-13 10:11:06.997522+00', '2018-07-13 10:22:03.601318+00', 'Teterin, Mikhail', '', 'Mikhail Teterin', 'Kirov, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10997, '2014-08-31 00:11:21.467956+00', '2014-11-24 09:02:05.479233+00', 'Carroll, Sandra', '', 'Sandra Carroll ', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11034, '2014-12-03 02:45:43.072453+00', '2014-12-03 02:45:43.072453+00', 'Wu, Frank', '', 'Frank Wu', 'RSCDS Orange County Branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11689, '2018-08-26 11:23:50.475246+00', '2018-08-26 11:23:50.475246+00', 'Gardelle, Laure', '', 'Laure Gardelle', 'Lyon (France)', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11087, '2015-02-21 15:13:06.859299+00', '2015-02-21 15:13:06.859299+00', 'MacLean, Gary', '', 'Gary MacLean', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11088, '2015-02-21 16:26:48.127532+00', '2015-02-21 16:26:48.127532+00', 'Reynolds, Gregory', '', 'Gregory Reynolds', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1679, NULL, '2014-12-09 01:24:49.940831+00', 'Stalker, Jack', '', 'Jack Stalker', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Band leader.



Jack Stalker’s outstanding service to Scottish country dance music was recognised in 2011 by presenting him with a Branch Award of the West Lothian Branch.');
INSERT INTO 'person' VALUES (387, NULL, '2014-12-11 15:00:46.828781+00', 'Laurie, John', '', 'John Laurie', '', '', 1, 0, 0, 0, NULL, 0, 2014, NULL, '');
INSERT INTO 'person' VALUES (3531, NULL, '2014-12-17 15:51:19.939324+00', 'Wilson, Dianne', '', 'Dianne Wilson', '', 'wilsonscotia@sbcglobal.net', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11037, '2015-01-02 17:23:00.979506+00', '2015-01-02 17:23:00.979506+00', 'Pérez-Peterkin, Fiona', '', 'Fiona Pérez-Peterkin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11039, '2015-01-08 15:09:06.232889+00', '2015-01-08 15:09:06.232889+00', 'Tappan, Jan', '', 'Jan Tappan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11040, '2015-01-08 15:11:18.376068+00', '2015-01-08 15:11:18.376068+00', 'Tappan, Jan and "The Committee"', '', 'Jan Tappan and "The Committee"', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11041, '2015-01-10 11:18:50.740683+00', '2015-01-10 11:18:50.740683+00', 'Lang, John', '', 'John Lang', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2770, NULL, '2015-01-10 14:43:32.393532+00', 'Crowe, Ken', '', 'Ken Crowe', '', '', 1, 0, 0, 0, 2770, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11042, '2015-01-10 14:52:38.774469+00', '2015-01-10 14:52:38.774469+00', 'White Rock Scottish Country Dance Club', 'White Rock SCD Club', 'White Rock Scottish Country Dance Club', 'White Rock, B.C. Canada', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11706, '2018-09-15 19:58:09.213975+00', '2018-09-15 23:56:28.192919+00', 'Walker, Caroline', '', 'Caroline Walker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11044, '2015-01-17 18:04:12.937566+00', '2015-01-17 18:05:10.185846+00', 'Zadworny, Margaret & Campbell, Barbara', '', 'Margaret Zadworny & Barbara Campbell', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11045, '2015-01-18 10:04:10.626012+00', '2015-01-18 10:04:10.626012+00', 'Campbell, Barbara', '', 'Barbara Campbell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11046, '2015-01-18 15:37:25.883594+00', '2015-01-18 15:37:25.883594+00', 'Goodall, Allan', '', 'Allan Goodall', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11047, '2015-01-20 10:53:05.850481+00', '2015-01-20 10:53:05.850481+00', 'Frost, Malcolm & Baranyai, Ann', '', 'Malcolm Frost & Ann Baranyai', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11048, '2015-01-21 09:36:26.504143+00', '2015-01-21 09:36:26.504143+00', 'Darbyshire, David', '', 'David Darbyshire', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11084, '2015-02-20 15:45:49.783634+00', '2015-02-20 15:45:49.783634+00', 'Young, Mary Rose', '', 'Mary Rose Young', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11089, '2015-02-21 17:08:22.914381+00', '2015-02-21 17:08:22.914381+00', 'Connors, Deborah', '', 'Deborah Conners', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11090, '2015-02-21 17:32:14.680095+00', '2015-02-21 17:32:14.680095+00', 'Hoag, Elaine and Hoffmann, Michael', '', 'Elaine Hoag and Michael Hoffmann', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11091, '2015-02-21 17:43:22.414013+00', '2015-02-21 17:43:22.414013+00', 'Williams, Jody', '', 'Jody Williams', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11092, '2015-02-21 18:00:53.599515+00', '2015-02-21 18:00:53.599515+00', 'Lambert, Tony', '', 'Tony Lambert', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11093, '2015-02-21 18:22:59.939234+00', '2015-02-21 18:22:59.939234+00', 'Hoag, Elaine', '', 'Elaine Hoag', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11094, '2015-02-22 22:50:31.955782+00', '2015-02-22 22:50:31.955782+00', 'Carse, Wendy', '', 'Wendy Carse', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11029, '2014-10-19 16:20:23.833835+00', '2021-04-05 09:47:56.722636+00', 'Charlton, Pat', '', 'Pat Charlton', 'Sydney, Australia', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11095, '2015-02-24 07:49:42.344403+00', '2015-02-24 07:49:42.344403+00', 'Harcombe, Maurice', '', 'Maurice Harcombe', 'Murringo, NSW, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11096, '2015-02-24 14:10:44.10904+00', '2015-02-24 14:10:44.10904+00', 'Lambert, Ruth', '', 'Ruth Lambert', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11097, '2015-02-25 15:11:54.210673+00', '2015-02-25 15:11:54.210673+00', 'Smith, Catherine', '', 'Catherine Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11098, '2015-02-25 15:30:06.431481+00', '2015-02-25 15:30:06.431481+00', 'Duncan, Colin', '', 'Colin Duncan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11099, '2015-02-25 15:56:15.899918+00', '2015-02-25 15:56:15.899918+00', 'Plummer, Margret', '', 'Margret Plummer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11038, '2015-01-05 23:14:00.794093+00', '2015-03-14 18:11:25.704228+00', 'Smarzik, Jane', '', 'Jane Smarzik', 'Ottawa, Canada', '', 0, 0, 0, 0, 400, 0, 0, NULL, 'Former name: Jane Wallace');
INSERT INTO 'person' VALUES (10632, '2012-06-15 05:11:56.617022+00', '2017-10-22 12:55:01.530908+00', 'Molnár, Zsolt', '', 'Zsolt Molnár', 'Budapest, Hungary', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Member of the Budapest Scottish Dance Club');
INSERT INTO 'person' VALUES (3694, NULL, '2016-05-18 09:00:10.976527+00', 'Jennings, Gillian', '', 'Gillian Jennings', 'Birmingham area, UK', 'gilljenn2@talktalk.net', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11713, '2018-09-18 20:26:40.989632+00', '2018-09-18 23:56:13.023972+00', 'Hoepner, Lieberman, Mattingly, Keeling', '', 'Hoepner, Lieberman, Mattingly and Keeling', 'USA  RSCDS Central Iowa Branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Also members: Gayle Hoepner and Kate Keeling (not listed yet as individual devisers)');
INSERT INTO 'person' VALUES (11736, '2018-10-19 15:06:20.244449+00', '2018-10-19 23:56:22.999806+00', 'Rintoul, Morna and Smith, Fran', '', 'Morna Rintoul and Fran Smith', 'RSCDS Branch Herefordshire', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3101, NULL, '2015-01-22 22:59:46.104558+00', 'Gregg, Robert A.', '', 'Robert Gregg', 'New Haven, USA', '', 1, 1, 0, 0, NULL, 1918, 2012, NULL, 'From: http://obits.mlive.com

Dr. Robert A. Gregg, a resident of Woodbridge, Connecticut since 1973 has died at the age of 94. Dr. Gregg was born in Dundee, Michigan on March 8, 1918. He received a BA from Adrian College, Adrian, Michigan, and a PhD in chemistry from the University of Michigan. He was a member of Phi Beta Kappa, and was awarded an honorary Doctor of Science.

In 1942 he joined the research staff of the United States Rubber Co., later to become Uniroyal. Some of his early work on fundamental polymer chemistry has become standard textbook chemistry.

He is credited with inventing chemical processes which made steel-belted radial tires safe. Steel belted radial tires were invented by Firestone, but the claims and judgments against Firestone due to the failure of their tires, sometimes resulting in loss of life, so damaged the company that it was absorbed by a Japanese company in 1988. Uniroyal tires experienced no such difficulties. For this work he was awarded the Maurice Chamberland Award by the New Haven Section of the American Chemical Society, an award made "for work enhancing societal well being through the application of chemistry".

He invented spandex.

He also invented a chemical foaming agent now widely used in the making of shock-absorbing foam rubber in a wide variety of products, from running shoes to hammer handles.

Since retiring in 1984, as President of the Woodbridge Land Trust he led the towns effort to purchase undeveloped tracts of land, thereby preserving them from development, providing outdoor recreation and preserving the character of the town. And he was active with the American Chestnut Foundation in its effort to restore the chestnut tree to the landscape, through cross-breeding to produce a disease-resistant tree. He served as a Director of the Connecticut Chapter of the Foundation since 2004. One of the parcels preserved by the Land Trust is now the site of an experimental chestnut plantation.

Finally, his will endows a Chair in the Chemistry Department at the University of Michigan.

He will be interred in Brookside Cemetery, Tecumseh, Michigan at 1PM Wednesday, December 12. A memorial service will be held at First Church of Christ, Woodbridge at 11AM Saturday, December 15th. He is survived by his wife Jean Westerman Gregg, and their son Timothy of Carmel, NY.

Memorial donations may be made to The Woodbridge Land Trust, Inc., P.O. Box 3699, Woodbridge, CT 06525.



Published in Ann Arbor News from Dec. 7 to Dec. 9, 2012

- See more at: http://obits.mlive.com/obituaries/annarbor/obituary.aspx?pid=161533580#sthash.dxUZAfwV.dpuf');
INSERT INTO 'person' VALUES (11049, '2015-01-27 15:06:14.761367+00', '2015-01-27 15:06:14.761367+00', 'Ebling, Verena', '', 'Verena Ebling', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3349, NULL, '2015-01-29 12:12:05.481914+00', 'Readerlear, Donald', '', 'Donald Readerlear', 'New Zealand', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11050, '2015-01-29 13:10:03.253378+00', '2015-01-29 13:10:03.253378+00', 'Penman, Sharlene', '', 'Sharlene Penman', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11051, '2015-01-31 16:31:02.086494+00', '2015-01-31 16:31:02.086494+00', 'Leptick, Penny', '', 'Penny Leptick', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11052, '2015-01-31 16:41:34.429339+00', '2015-01-31 16:41:34.429339+00', 'Gomersall, Margaret', '', 'Margaret Gomersall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11054, '2015-01-31 17:39:01.076515+00', '2015-01-31 17:39:01.076515+00', 'Craigan, Leslie', '', 'Leslie Craigan', 'Ontario', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11053, '2015-01-31 17:36:01.527791+00', '2015-01-31 17:39:39.276349+00', 'McLennan, Marie', '', 'Marie McLennan', 'Ontario', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11055, '2015-01-31 17:41:12.364644+00', '2015-01-31 17:41:12.364644+00', 'Hodgins-Sloan, Judy', '', 'Judy Hodgins-Sloan', 'Ontario', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11056, '2015-01-31 17:43:22.735963+00', '2015-01-31 17:43:22.735963+00', 'Watson, Robert', '', 'Robert Watson', 'Ontario', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11057, '2015-01-31 17:44:05.630137+00', '2015-01-31 17:44:05.630137+00', 'Watson, Linda', '', 'Linda Watson', 'Ontario', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11058, '2015-01-31 17:45:20.485184+00', '2015-01-31 17:45:20.485184+00', 'Auksi, Peter', '', 'Peter Auksi', 'Ontario', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (233, NULL, '2015-02-01 10:41:30.19195+00', 'RSCDS London (Canada) Branch', '', 'RSCDS London (Canada) Branch', '', '', 0, 1, 0, 0, 233, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11059, '2015-02-03 16:49:30.760865+00', '2015-02-03 16:49:30.760865+00', 'Chambers, Sheila', '', 'Sheila Chambers', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11060, '2015-02-03 17:22:40.309701+00', '2015-02-03 17:22:40.309701+00', 'Wilson, Martin arr. Pat Clark', '', 'Martin Wilson arr. Pat Clark', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11062, '2015-02-05 12:17:36.671892+00', '2015-02-05 12:17:36.671892+00', 'Vollmar, Stephan', '', 'Stephan Vollmar', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11063, '2015-02-05 12:29:16.735706+00', '2015-02-05 12:29:16.735706+00', 'Cresswell, Lilo', '', 'Lilo Cresswell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11064, '2015-02-05 12:40:06.892301+00', '2015-02-05 12:40:06.892301+00', 'Däther, Michael', '', 'Michael Däther', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11066, '2015-02-05 13:01:06.645961+00', '2015-02-05 13:01:06.645961+00', 'Halak, Simon', '', 'Simon Halak', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11659, '2018-07-13 09:51:57.424645+00', '2018-07-13 10:20:32.473289+00', 'Kiselev, Artem', '', 'Artem Kiselev', 'Kirov, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11068, '2015-02-05 13:28:27.586946+00', '2015-02-05 13:28:27.586946+00', 'Reil, Rita', '', 'Rita Reil', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (151, NULL, '2015-02-05 15:21:15.834803+00', 'Gradon, Sheila', '', 'Sheila Gradon', 'Australia', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (703, NULL, '2015-02-06 17:53:27.72861+00', 'Gallamore, Sandy', '', 'Sandy Gallamore', '', 'AGallamore@aol.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11070, '2015-02-09 13:11:23.772034+00', '2015-02-09 13:11:23.772034+00', 'Houghton, Robert', '', 'Robert Houghton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11072, '2015-02-09 15:14:26.789317+00', '2015-02-09 15:16:19.264791+00', 'Ternes, Ellen & Warner, Judy', '', 'Ellen Ternes & Judy Warner', 'Frederick, MD, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11073, '2015-02-09 16:54:45.014897+00', '2015-02-09 16:54:45.014897+00', 'Laidlaw, Elaine', '', 'Elaine Laidlaw', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11074, '2015-02-09 16:56:12.667162+00', '2015-02-09 16:56:12.667162+00', 'Downey, Fiona', '', 'Fiona Downey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11075, '2015-02-09 16:59:03.558982+00', '2015-02-09 16:59:55.261422+00', 'Henderson, Kathleen & Members of Featherston SCD Club', '', 'Kathleen Henderson & Members of Featherston SCD Club', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11076, '2015-02-09 18:06:38.404151+00', '2015-02-09 18:06:38.404151+00', 'Carterton SCD Club', '', 'Carterton SCD Club', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11665, '2018-07-16 23:48:55.549317+00', '2018-07-16 23:56:17.620877+00', 'Houghton, Patricia', '', 'Pat Houghton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (54, NULL, '2015-02-14 14:07:21.834586+00', 'Brown, May', '', 'May Brown', 'Western Australia', '', 1, 0, 0, 0, NULL, 1911, 2011, NULL, 'May died peacefully on 14 June 2011.  May was a life member of the RSCDS Western Australia Branch and the deviser of several dances.');
INSERT INTO 'person' VALUES (11079, '2015-02-14 14:28:19.090964+00', '2015-02-14 14:28:19.090964+00', 'Donaldson, Richard', '', 'Richard Donaldson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11035, '2014-12-03 05:49:39.595993+00', '2021-02-21 19:52:39.86648+00', 'Collin, Gaye', '', 'Gaye Collin', 'Lower Hutt, New Zealand', '', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Married to Damon Collin');
INSERT INTO 'person' VALUES (11081, '2015-02-14 18:06:07.750672+00', '2015-02-14 18:06:07.750672+00', 'Fleming Youngman, Barbara', '', 'Barbara Fleming Youngman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2901, NULL, '2015-02-17 12:29:36.130735+00', 'Porteous, Joyce & Hugh', '', 'Joyce & Hugh Porteous', '', 'joyce@porteous.me.uk', 1, 0, 0, 0, NULL, 0, 0, NULL, 'second e-mail: hugh@porteous.me.uk ');
INSERT INTO 'person' VALUES (11082, '2015-02-20 14:18:22.926636+00', '2015-02-20 14:18:22.926636+00', 'Crozier, Karla', '', 'Karla Crozier', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1763, NULL, '2015-03-14 18:11:05.619691+00', 'Donaldson, Liz', '', 'Liz Donaldson', '', 'liz@us.net', 1, 0, 1, 1, 1088, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11077, '2015-02-09 22:59:53.159825+00', '2015-04-02 20:56:32.314321+00', 'Halpenny, Tom', '', 'Tom Halpenny', 'Ridgefield, Washington, USA', 'tomh@gtcinternet.com', 1, 0, 0, 0, NULL, 0, 0, NULL, 'april 2015: secretary of RSCDS Southwest Washington State Branch');
INSERT INTO 'person' VALUES (11069, '2015-02-05 13:38:08.90727+00', '2017-05-23 21:20:55.918707+00', 'Munich Scottish Association', 'MSA', 'Munich Scottish Association', 'Munich, Germany', '', 0, 1, 0, 0, NULL, 1973, 0, NULL, 'The Munich Scottish Association (MSA) was founded in 1973.');
INSERT INTO 'person' VALUES (11667, '2018-07-17 16:17:24.798298+00', '2018-07-17 23:56:13.575115+00', 'Henderson, Paul', '', 'Paul Henderson', 'Edinburgh', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11065, '2015-02-05 12:47:45.397109+00', '2019-01-15 11:20:37.35099+00', 'Schmidkonz, Angelika', '', 'Angelika Schmidkonz', 'Duesseldorf, Germany (ex-Munich & Bochum)', 'angelikaschmidkonz@web.de', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11101, '2015-02-26 14:41:34.28478+00', '2015-02-26 14:41:34.28478+00', 'Franssen, H W', '', 'H W Franssen', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1089, NULL, '2015-02-26 21:57:29.038997+00', 'Scott, Simon', '', 'Simon Scott', '', 'simon.scott@telus.net', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11102, '2015-02-27 10:02:44.357074+00', '2015-02-27 10:02:44.357074+00', 'Roxburgh, Selkirk & Peebles Branch RSCDS', '', 'Roxburgh, Selkirk & Peebles Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 1957, 0, NULL, '');
INSERT INTO 'person' VALUES (11103, '2015-02-27 10:09:04.572916+00', '2015-02-27 10:09:04.572916+00', 'Bryce, Lyn', '', 'Lyn Bryce', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11104, '2015-02-27 10:19:24.19725+00', '2015-02-27 10:19:24.19725+00', 'Mitchell, Jimmy', '', 'Jimmy Mitchell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3471, NULL, '2015-02-27 10:26:55.316573+00', 'Sharp, Julia', '', 'Julia Sharp', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11105, '2015-02-27 10:52:06.958508+00', '2015-02-27 10:52:06.958508+00', 'Blackwood, Dan', '', 'Dan Blackwood', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11106, '2015-02-27 11:48:09.493193+00', '2015-02-27 11:48:09.493193+00', 'Brown, Anne M', '', 'Anne M Brown', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11107, '2015-02-27 12:10:02.872254+00', '2015-02-27 12:10:02.872254+00', 'Mrs Coyne, Maisie', '', 'Mrs Maisie Coyne', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11108, '2015-02-27 12:28:58.158278+00', '2015-02-27 12:28:58.158278+00', 'Gattonside Prelim Class 2002', '', 'Gattonside Prelim Class 2002', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3557, NULL, '2018-07-17 23:56:04.351872+00', 'Brockbank, Ian & Caroline', '', 'Ian & Caroline Brockbank', 'Edinburgh', '', 0, 0, 0, 0, 3557, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11109, '2015-02-28 13:20:20.226993+00', '2015-02-28 13:20:20.226993+00', 'Lorn Branch RSCDS', '', 'Lorn Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2245, NULL, '2015-03-03 21:58:14.917509+00', 'Fuell, Lee & Lindsay, Patricia', '', 'Lee Fuell & Patricia Lindsay', 'Cincinnati', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11111, '2015-03-10 00:13:40.736643+00', '2015-03-10 00:13:40.736643+00', 'Lange, Anika', '', 'Anika Lange', 'Scluechtern, Grmany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11112, '2015-03-11 10:06:24.856859+00', '2015-03-11 10:06:24.856859+00', 'Bonn/Cologne Chicks', '', 'Bonn/Cologne Chicks', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3696, NULL, '2015-03-12 10:10:16.280636+00', 'Richardson, Frances', '', 'Frances Richardson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11113, '2015-03-13 08:28:06.617195+00', '2015-03-13 08:28:06.617195+00', 'Burns, Maggie', '', ' Maggie Burns', 'Sunderland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Source: http://www.scottish-country-dancing-dictionary.com/dance-crib/freshwater-bay.html');
INSERT INTO 'person' VALUES (10272, NULL, '2015-03-14 18:05:52.351297+00', 'Ainswood, Mickie and Jimmy Blue', '', 'Mickie Ainswood and Jimmy Blue', '', '', 0, 0, 0, 1, NULL, 0, 1, NULL, '');
INSERT INTO 'person' VALUES (11666, '2018-07-17 00:01:18.638685+00', '2018-07-17 23:56:12.064204+00', 'Grant, Donald', '', 'Donald Grant', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Early 19th century.');
INSERT INTO 'person' VALUES (10380, NULL, '2015-03-14 18:09:35.340127+00', 'Lindsey, Joyce & Gary & Lindsay, Patty & Fuell, Lee', '', 'Joyce & Gary Lindsey, Patty Lindsay and Lee Fuell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3370, NULL, '2015-03-14 18:09:57.398236+00', 'Lindsay, Patricia / Lindsey Gary & Joyce', '', 'Patricia / Lindsey Gary & Joyce Lindsay', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1578, NULL, '2015-03-14 18:10:58.196562+00', 'Adamson, Deirdre', '', 'Deirdre Adamson', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1904, NULL, '2015-03-14 18:10:58.513121+00', 'Allan, William', '', 'William Allan', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10858, '2013-09-13 13:12:07.273084+00', '2015-03-14 18:10:59.221921+00', 'Arnold, Anna-Marie', '', 'Anna-Marie Arnold', 'Pretoria', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2720, NULL, '2015-03-14 18:10:59.63133+00', 'Axelrod, Karen', '', 'Karen Axelrod', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2335, NULL, '2015-03-14 18:10:59.762146+00', 'Baker, Elke', '', 'Elke Baker', '', 'bakerez1@aol.com', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (538, NULL, '2015-03-14 18:10:59.935677+00', 'Barbour, Hilary', '', 'Hilary Barbour', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1501, NULL, '2015-03-14 18:11:00.110103+00', 'Barron, Neil', '', 'Neil Barron', '', 'neilbarron@hotmail.com', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3109, NULL, '2015-03-14 18:11:00.719551+00', 'Black', '', 'Black', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11067, '2015-02-05 13:10:47.829793+00', '2015-03-14 18:11:01.052083+00', 'Bollans, Sue', '', 'Sue Bollans', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10985, '2014-08-19 07:44:37.881552+00', '2015-03-14 18:11:01.212947+00', 'Boswell, Sir Alexander', '', 'Sir Alexander Boswell', '', '', 0, 0, 0, 0, NULL, 1775, 1822, NULL, 'Son of James Boswell of Auchinleck (friend and biographer of Dr Samuel Johnson).');
INSERT INTO 'person' VALUES (10661, '2012-10-02 09:45:34.184227+00', '2015-03-14 18:11:01.403857+00', 'Bradford, Don', '', 'Don Bradford', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2499, NULL, '2015-03-14 18:11:02.739985+00', 'Campbell, Colin', '', 'Colin Campbell', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10576, NULL, '2015-03-14 18:11:04.368056+00', 'Craig Chamberlain and Lara Friedman-Shedlov', 'Chamberlain and Shedlov', 'Craig Chamberlain and Lara Friedman-Shedlov', 'USA', 'lfriedmanshedlov@gmail.com', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2208, NULL, '2015-03-14 18:11:04.656755+00', 'Cruickshanks, Ian', '', 'Ian Cruickshanks', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3650, NULL, '2015-03-14 18:11:05.721119+00', 'Douglas, John Scottish Dance Band', 'John Douglas', 'John Douglas Scottish Dance Band', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (117, NULL, '2015-03-14 18:11:06.071707+00', 'East Ivanhoe Group', '', 'East Ivanhoe Group', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3779, NULL, '2015-03-14 18:11:06.611657+00', 'Farr, Ian & Hill, Jeremy', '', 'Ian Farr & Jeremy Hill', '', 'ianafarr@gmail.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10834, '2013-08-18 21:20:09.148414+00', '2015-03-14 18:11:07.185924+00', 'Föhrenbach, Sybille', '', 'Sybille Föhrenbach', '', '', 0, 0, 0, 0, 2765, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1113, NULL, '2015-03-14 18:11:07.728005+00', 'Fuell, Lee', '', 'Lee Fuell (= Donald L Fuell, Jr)', 'Dayton, OH; RSCDS-Cincinnati Group', 'fuell@mindspring.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (635, NULL, '2021-02-25 13:06:20.978363+00', 'Brown, Malcolm', '', 'Malcolm Brown', 'Dunnington, York, UK', 'mlamontbrown@btopenworld.com', 1, 1, 0, 0, NULL, 0, 0, NULL, 'An article by Malcolm on his background and opinions about dancing appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-302-Electronic.pdf#page=13|issue 302 of The Reel>>.');
INSERT INTO 'person' VALUES (318, NULL, '2020-05-25 09:41:32.840932+00', 'Quinnell, Cliff', '', 'Cliff Quinnell', 'Sydney, NSW, SE Qld and Picton, NZ', '', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Test');
INSERT INTO 'person' VALUES (10287, NULL, '2015-09-24 04:19:01.93567+00', 'Dobiasch, Lotte', '', 'Lotte Dobiasch', 'Vienna, Austria', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10478, NULL, '2016-05-04 09:05:10.916356+00', 'van den Berg, Wil', '', 'Wil van den Berg', 'Almere, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3221, NULL, '2017-07-27 16:27:24.121186+00', 'Anderson, Marian & Hodgson, Isobelle', '', 'Marian Anderson & Isobelle Hodgson', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (908, NULL, '2016-05-27 22:08:36.638076+00', 'Bankart, Patrick G.', '', 'Patrick G. Bankart', 'London? UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11100, '2015-02-26 12:42:13.337258+00', '2017-09-30 15:17:36.299616+00', 'Macleod, Norma', '', 'Norma Macleod', 'Stirling Branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (442, NULL, '2017-11-14 00:56:03.873698+00', 'Bremner, Robert', '', 'Robert Bremner', '', '', 1, 1, 1, 0, NULL, 1720, 1789, NULL, '');
INSERT INTO 'person' VALUES (1415, NULL, '2018-02-10 23:15:12.716379+00', 'Brown, Alasdair', '', 'Alasdair Brown', 'York UK', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11691, '2018-08-27 23:08:58.726167+00', '2018-08-27 23:40:59.002858+00', 'Hartley, Jennie', '', 'Jennie Hartley', 'Watford and W. Herts Sc. Society', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2623, NULL, '2018-12-07 17:34:53.609218+00', 'Brown, Helen C.N.', '', 'Helen C.N. Brown', 'York', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11110, '2015-03-09 08:38:57.111544+00', '2018-12-08 23:17:18.511509+00', 'Lawmon, Kathy', '', 'Kathy Lawmon', 'Portsmouth, UK', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2454, NULL, '2015-03-14 18:11:09.558606+00', 'Gronstedt, Karl', '', 'Karl Gronstedt', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1173, NULL, '2015-03-14 18:11:09.669473+00', 'Guilcher, Yvon', '', 'Yvon Guilcher', 'Paris', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (168, NULL, '2015-03-14 18:11:09.949306+00', 'Hamilton, Graham W', '', 'Graham W Hamilton', '', 'graham@craigellachie.demon.co.uk', 1, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (758, NULL, '2015-03-14 18:11:09.999107+00', 'Hamilton, Jo', '', 'Jo Hamilton', 'San Francisco', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10413, NULL, '2015-03-14 18:11:10.034407+00', 'Hamilton, Peggy et al.', '', 'Peggy Hamilton et al', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2693, NULL, '2015-03-14 18:11:10.730137+00', 'Hendrie, Roy', '', 'Roy Hendrie', '', 'roy@hendrie.freeserve.co.uk', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2848, NULL, '2015-03-14 18:11:10.883291+00', 'Hewitt, Bernie', '', 'Bernie Hewitt', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1987, NULL, '2015-03-14 18:11:12.796221+00', 'Keech, Diana', '', 'Diana Keech', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1829, NULL, '2015-03-14 18:11:13.295253+00', 'Knight, David Andrew', '', 'David Andrew Knight', '', 'drop_a_line@davidknight.us', 1, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10176, NULL, '2015-03-14 18:11:13.412678+00', 'Kokai, H / Murayama, Y / Aoyama, R / Clement, B', '', 'Kokai, H / Murayama, Y / Aoyama, R / Clement, B', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2763, NULL, '2015-03-14 18:11:13.490271+00', 'Kurnick, Janet', '', 'Janet Kurnick', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2029, NULL, '2015-03-14 18:11:14.734998+00', 'Macadians, The', 'Macadians', 'The Macadians', 'Nova Scotia', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'Members (received feb. 2015)

Duncan Keppie (Accordion)

Peter Giles & Clara Whitman (Fiddle)

Maggie Keppie (Percussion & Voice)

Rob Kehler (Keyboard)

');
INSERT INTO 'person' VALUES (1428, NULL, '2015-03-14 18:11:15.020351+00', 'MacEachern, Neil and his Scottish Dance Band', 'Neil MacEachern', 'Neil MacEachern and his Scottish Dance Band', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3058, NULL, '2015-03-14 18:11:15.811647+00', 'MacLeod, Bobby', 'Bobby MacLeod', 'Bobby MacLeod', '', '', 0, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3095, NULL, '2015-03-14 18:11:16.481643+00', 'Mannert, Clemens', '', 'Clemens Mannert', 'Munich, Germany', 'Clemens.Mannert@gmx.de', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10065, NULL, '2015-03-14 18:11:17.01779+00', 'McCollum, Frank', 'Frank McCollum', 'Frank McCollum', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11043, '2015-01-11 18:40:36.217711+00', '2015-03-14 18:11:17.959241+00', 'McPhedran, Donald', '', 'Donald McPhedran', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1268, NULL, '2015-03-14 18:11:24.331871+00', 'Schneider, Douglas', '', 'Douglas Schneider', '', 'ParadiseMO@aol.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2340, NULL, '2015-03-14 18:11:27.057521+00', 'Taylor, John', '', 'John Taylor', '', 'john.taylor@kla-tencor.com', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1309, NULL, '2015-03-14 18:11:28.098692+00', 'Veranth, Martha Morrison', '', 'Martha Morrison Veranth', 'Salt Lake City, USA', 'mcmv72@alum.wellesley.edu', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10962, '2014-06-09 19:36:08.208626+00', '2015-03-14 18:11:29.018124+00', 'West Suffolk branch of the Alzheimer''s Society', '', 'West Suffolk branch of the Alzheimer''s Society', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10009, NULL, '2015-03-14 18:11:29.411779+00', 'Williams, Nicholas', 'Nicholas Williams', 'Nicholas Williams', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3750, NULL, '2015-03-19 06:22:08.333848+00', 'Kafoozalum', 'Kafoozalum', 'Kafoozalum', 'London, UK', 'peter@kafoozalum.co.uk', 0, 0, 0, 1, NULL, 1978, 0, NULL, 'Home:	020 8581 0359

Mobile:	07973 250918

Address:	20 Charles Street, Hillingdon Heath, Middlesex  UB10 0SY



Kafoozalum  is based in London, but plays all over the place:

    Birmingham in the North

    Brighton in the South

    Norwich in the East

    Exeter in the West

and everywhere in between');
INSERT INTO 'person' VALUES (10019, NULL, '2015-03-25 10:06:14.794688+00', 'Petrov, Susie and Ensembles', 'Susie Petrov', 'Petrov, Susie and Ensembles', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11197, '2015-09-03 21:00:09.572816+00', '2015-09-03 21:00:09.572816+00', 'Watt, Andrew', '', 'Andrew Watt', 'Aberdeen, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11211, '2015-09-22 20:28:25.983454+00', '2015-09-22 23:56:16.579817+00', 'Matcham, Iain', '', 'Iain Matcham', 'Lower Hutt SCD club, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10290, NULL, '2015-09-24 04:15:40.875434+00', 'Seybold, Beate', '', 'Beate Seybold', 'Berlin, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Beate Seybold danced in various locations including Vienna (Austria) and Berlin (Germany).



Together with Sonja Schroeder, she was the co-founder of the Berlin Hopalots dance group in 2001.');
INSERT INTO 'person' VALUES (10291, NULL, '2015-09-24 04:16:26.942216+00', 'Finan, Robert & Kelemen, Julia & Wepner, Beatrix', '', 'Robert Finan, Julia Kelemen and Beatrix Wepner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11217, '2015-09-24 04:13:30.258471+00', '2015-09-24 23:56:01.696586+00', 'Adam, Martin', '', 'Martin Adam', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11214, '2015-09-24 03:59:34.767588+00', '2015-09-24 23:56:09.448212+00', 'Finan, Robert', '', 'Robert Finan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2973, NULL, '2021-09-08 08:21:18.662971+00', 'Ronald, Chris', '', 'Chris Ronald', 'Quorn, Leicestershire, UK', 'cjr878@gmail.com', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Formerly of Edgewater, NJ, US');
INSERT INTO 'person' VALUES (2980, NULL, '2021-10-18 14:17:46.260343+00', 'Rayner, Trevor', '', 'Trevor Rayner', 'Skye & New Zealand', '', 1, 1, 0, 0, NULL, 1942, 2017, NULL, '');
INSERT INTO 'person' VALUES (11213, '2015-09-24 03:58:36.570309+00', '2015-09-24 23:56:14.127401+00', 'Kelemen, Julia', '', 'Julia Kelemen', 'Vienna, Austria', '', 1, 0, 0, 0, 11215, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11668, '2018-07-19 09:51:25.078834+00', '2018-07-19 23:56:10.077216+00', 'Flack, James', '', 'James Flack', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11307, '2016-07-11 19:29:47.368066+00', '2016-07-11 19:30:06.112995+00', 'Wood, Geoffrey', '', 'Geoffrey Wood', 'San Francisco', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11670, '2018-07-19 09:59:27.525964+00', '2018-07-19 23:56:25.553742+00', 'Stolte, Yolande', '', 'Yolande Stolte', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11316, '2016-08-21 20:42:33.289939+00', '2016-08-21 23:56:22.291883+00', 'Smail, Alan', '', 'Alan Smail', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11115, '2015-04-08 13:52:30.772061+00', '2017-09-07 09:10:27.174896+00', 'van Leersum, Sjoerd & Kowalczik, Judith & Markowski, Marion & von Franken-Welz, Herbert', 'Sjoerd van Leersum & Friends', 'Sjoerd van Leersum & Judith Kowalczik & Marion Markowski & Herbert von Franken-Welz', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1713, NULL, '2017-08-23 18:47:59.919829+00', 'Linden, Lilian', '', 'Lilian Linden', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11139, '2015-06-04 09:49:05.955648+00', '2018-05-03 23:56:15.811636+00', 'Luxton-Esler, Amy', '', 'Amy Luxton-Esler', 'Auckland, NZ', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1742, NULL, '2015-03-19 06:47:58.491606+00', 'Armstrong, Jack', '', 'Jack Armstrong', '', '', 0, 0, 1, 0, NULL, 1904, 1978, NULL, 'Bandleader of Barnstormers dance band 

Numerous radio and tv broadcasts in 1950''s and 1960''s 

Piper to Duke of Northumberland from 1948');
INSERT INTO 'person' VALUES (10128, NULL, '2015-03-25 09:49:25.109116+00', 'Cunningham, David', 'David Cunningham', 'David Cunningham', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3049, NULL, '2015-03-25 09:51:36.44434+00', 'Renton, John and his Scottish Dance Band', 'John Renton', 'John Renton and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1575, NULL, '2015-03-25 09:59:03.014126+00', 'Muir, Ian T', 'Ian T Muir', 'Ian T Muir', 'Prestwick, Scotland', 'Iannemuir@aol.com', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11669, '2018-07-19 09:56:11.426714+00', '2018-07-19 23:56:05.722374+00', 'Campbell, Fiona', '', 'Fiona Campbell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11129, '2015-05-06 12:18:17.727855+00', '2015-05-06 12:18:17.727855+00', 'McLaughlin, Julia', '', 'Julia McLaughlin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11130, '2015-05-06 12:25:06.442816+00', '2015-05-06 12:25:06.442816+00', 'Billmers, Matt', '', 'Matt Bilmers', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11131, '2015-05-06 14:20:07.466016+00', '2015-05-06 14:20:07.466016+00', 'Goldstein, Ilene', '', 'Ilene Goldstein', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11114, '2015-03-19 23:53:52.021664+00', '2015-10-02 17:13:49.6162+00', 'József, Zsófia', '', 'Zsófia József', 'Budapest, Hungary', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11117, '2015-04-12 15:23:14.564129+00', '2015-04-12 15:23:14.564129+00', 'Schärich, Christian', '', 'Christian Schärich', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11116, '2015-04-08 14:07:17.851543+00', '2015-04-12 23:56:17.377886+00', 'Mitschker, Janneke & Huenger, Tobias', '', 'Janneke Mitschker & Tobias Huenger', 'Oldenburg, DE', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11118, '2015-04-20 13:12:09.022479+00', '2015-04-20 13:12:09.022479+00', 'Norgate, Martin', '', 'Martin Norgate', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11132, '2015-05-07 10:33:48.498172+00', '2015-05-07 10:33:48.498172+00', 'Northampton Class of Boston Branch', '', 'Northampton Class of Boston Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11121, '2015-04-21 22:16:18.167127+00', '2015-04-21 23:56:03.913489+00', 'Black, Mary', '', 'Mary Black', 'Edinburgh', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'A dance author in the Edinburgh Ladies'' Club Jubilee Book 1996');
INSERT INTO 'person' VALUES (11120, '2015-04-21 22:11:36.725954+00', '2015-04-21 23:56:13.660967+00', 'Kidney, Sheila', '', 'Sheila Kidney', 'Edinburgh', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'A dance author in the 1996 Ladies'' Club Jubilee Book');
INSERT INTO 'person' VALUES (11122, '2015-04-21 22:30:32.862574+00', '2015-04-21 23:56:19.687653+00', 'Polson, Jean', '', 'Jean Polson', 'Edinburgh', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'A dance author for the RSCDS Ladies'' Club Jubilee Book 1936 - 1996.');
INSERT INTO 'person' VALUES (11123, '2015-04-23 09:36:18.53686+00', '2015-04-23 09:36:18.53686+00', 'Cameron, Mrs J Dunoon', '', 'Mrs J Dunoon Cameron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11124, '2015-04-23 09:38:18.854595+00', '2015-04-23 09:38:18.854595+00', 'Cameron, P/M John', '', 'P/M John Cameron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11126, '2015-05-02 10:03:13.682496+00', '2015-05-02 10:04:02.489532+00', 'Burton, Samantha', '', 'Samantha Burton', 'London, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11127, '2015-05-04 08:05:17.761763+00', '2015-05-04 08:05:17.761763+00', 'Clark, Kathy', '', 'Kathy Clark', 'Delaware, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11133, '2015-05-08 19:06:16.491467+00', '2015-05-08 19:06:16.491467+00', 'Hanson, Lou', '', 'Lou Hanson', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11134, '2015-05-12 14:32:45.45578+00', '2015-05-12 23:56:11.057+00', 'Hasekamp, Uta', '', 'Uta Hasekamp', 'Bonn, DE', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11135, '2015-05-14 08:56:51.320199+00', '2015-05-14 08:56:51.320199+00', 'Strutt, Catherine', '', 'Catherine Strutt', 'Australia', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11136, '2015-05-14 09:02:16.894401+00', '2015-05-14 09:02:16.894401+00', 'Duncan, Chris & Strutt, Catherine', '', 'Chris Duncan & Catherine Strutt', 'Australia', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11138, '2015-06-02 13:40:40.209887+00', '2015-06-02 23:56:21.477259+00', 'Ruth, Viola R', '', 'Viola R Ruth', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11140, '2015-06-10 10:07:29.794359+00', '2015-06-10 23:56:18.243132+00', 'Oyama, Yoshiki', '', 'Yoshiki Oyama', 'Japan, ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Alba SCD group');
INSERT INTO 'person' VALUES (11142, '2015-06-19 09:12:30.57859+00', '2015-06-19 23:56:09.699204+00', 'Ebling, V/Hallmann, M', '', 'V Ebling/M Hallmann', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11144, '2015-06-19 10:48:15.149875+00', '2015-06-19 23:56:03.441394+00', 'Ainslie, Ross', '', 'Ross Ainslie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11146, '2015-06-19 11:39:24.957423+00', '2015-06-19 23:56:05.373203+00', 'Bordeleau, Michel', '', 'Michel Bordeleau', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11145, '2015-06-19 10:58:32.780842+00', '2015-06-19 23:56:07.051279+00', 'Carroll, Liz', '', 'Liz Carroll', 'Chicago, IL, USA', 'lizfiddle@gmail.com', 0, 0, 1, 0, NULL, 1956, 0, NULL, '');
INSERT INTO 'person' VALUES (11143, '2015-06-19 10:42:19.159175+00', '2015-06-19 23:56:10.415682+00', 'Fisher, David', '', 'David Fisher', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11141, '2015-06-19 09:11:29.251414+00', '2015-06-19 23:56:12.583838+00', 'Hallmann, Maria', '', 'Maria Hallmann', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11147, '2015-06-19 11:43:12.692859+00', '2015-06-19 23:56:20.728371+00', 'Orr, Dennis', '', 'Dennis Orr', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11148, '2015-06-19 11:57:24.496087+00', '2015-06-19 23:56:26.427184+00', 'Vallely, Niall', '', 'Niall Vallely', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11196, '2015-09-03 20:48:37.201001+00', '2015-09-03 23:56:04.9279+00', 'Bruce, Kathleen', '', 'Kathleen Bruce', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11199, '2015-09-04 09:40:26.824811+00', '2015-09-04 09:40:26.824811+00', 'McLellan, Donald', '', 'Donald McLellan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11205, '2015-09-20 15:17:43.887879+00', '2015-09-20 15:17:43.887879+00', 'McDevitt, Mary Ann', '', 'Mary Ann McDevitt', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11200, '2015-09-07 00:15:52.893474+00', '2015-09-07 23:56:14.520038+00', 'Leary, Deborah', '', 'Deborah Leary', 'Norwood, New Jersey', '', 1, 0, 0, 0, NULL, 1959, 0, NULL, '');
INSERT INTO 'person' VALUES (11201, '2015-09-09 15:57:07.273522+00', '2015-09-09 23:56:08.574371+00', 'Dublin Scottish Country Dance Club', '', 'Dublin Scottish Country Dance Club', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11693, '2018-08-28 17:52:02.762176+00', '2018-08-28 23:56:07.734977+00', 'Cooper, Carolyn', '', 'Carolyn Cooper', 'Bath, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11203, '2015-09-20 14:47:55.509663+00', '2015-09-20 14:47:55.509663+00', 'Beattie, Gillian', '', 'Gillian Beattie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11204, '2015-09-20 14:52:53.079586+00', '2015-09-20 14:52:53.079586+00', 'Brand, Anne', '', 'Anne Brand', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11206, '2015-09-20 15:26:42.57176+00', '2015-09-20 15:26:42.57176+00', 'Moen, Alison', '', 'Alison Moen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11207, '2015-09-20 15:53:03.47086+00', '2015-09-20 15:53:03.47086+00', 'Shearman, Katherine', '', 'Katherine Shearman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11208, '2015-09-20 16:33:19.14592+00', '2015-09-20 16:33:19.14592+00', 'Conings, Catherine', '', 'Catherine Conings', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11164, '2015-07-21 14:35:47.16182+00', '2015-09-21 20:10:50.678971+00', 'Schuckelt, Geraldine & Holger', '', 'Geraldine & Holger Schuckelt', 'Dresden, DE', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11209, '2015-09-21 21:55:46.864618+00', '2015-09-21 23:56:20.634635+00', 'Reid, Trish', '', 'Trish Reid', ' Chester Caledonian Scottish Country Dance society', 'edandtrish@btinternet.com', 1, 0, 0, 0, NULL, 0, 0, NULL, 'source: http://www.chestercally.org.uk/links.php');
INSERT INTO 'person' VALUES (11705, '2018-09-15 10:47:43.895197+00', '2018-09-15 23:56:22.74493+00', 'Riddell, Donald', '', 'Donald Riddell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10114, NULL, '2021-01-05 16:02:48.653365+00', 'Dewhurst, Chris, Julie & Nick', 'C, J & N Dewhurst', 'Dewhurst, Chris, Julie & Nick', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11210, '2015-09-22 18:47:15.427917+00', '2015-09-22 23:56:20.152801+00', 'Pollard, Monica', '', 'Monica Pollard', 'Portland, OR', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11137, '2015-06-02 11:50:46.858372+00', '2016-05-18 02:25:43.668539+00', 'Watson, Eileen M', '', 'Eileen M Watson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1054, NULL, '2016-10-10 15:25:27.665452+00', 'Petrov, Susanne', 'Susie Petrov', 'Susanne Petrov', 'Cambridge, MA', 'spetrov@shore.net', 1, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11708, '2018-09-17 18:23:13.77267+00', '2018-09-17 18:23:13.77267+00', 'Talbot, Margret', '', 'Margret Talbot', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11717, '2018-09-19 14:02:16.76633+00', '2018-09-19 14:02:16.76633+00', 'Paton, Ron', '', 'Ron Paton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1842, NULL, '2015-06-28 15:02:49.724059+00', 'Jenkins, Peter', '', 'Peter Jenkins', 'Middlesex, UK', 'peter@kafoozalum.co.uk', 0, 0, 1, 1, NULL, 0, 0, NULL, 'Leader of Kafoozalum website http://www.kafoozalum.co.uk



Publication: The Kafoozalum Tunes. Details at http://www.kafoozalum.co.uk/tunebook.html



All compositions - including The Kafoozalum Tunes - available (free) in abc format at http://abcnotation.com/searchTunes?q=site:www.kafoozalum.co.uk&f=c&o=a&s=0



Additonal information:

20 Charles Street

Hillingdon Heath

Middlesex

UB10 0SY

Home:	020 8581 0359

Mobile:	07973 250918



Other tunes, all from "The Kafoozalum Tunes" publication, as are the three currently displayed, are accessible through JC''s Tunefinder: A Minor Catastrophe Altered Jig The Apprentice (or "Road to the Heath") Ayrshire Bacon But NOT Morrismen Cat''s Cradle Connor O'' Denis Drear Life The Humours of Hillingdon Jacki''s Jig The Last Buss The Loss of Much One Mor The Promised Land Siobhan Cottage Splash! All the way to Beckenham At the top of the Steppes The Band Wagon Cheers The Cyclist''s Hornpipe Diminished Resposibility Dog Walk Mrs L. P. Fogg Pearl of Welwyn Phumblin'' The Spa Weekend The Stuttering Loom Light Meter Rant Silky Blue Summer A Virgin from Waverley Lesley''s Welcome Return from Canada One for Roger! Peter Jenkins'' compliments to Ron Fiske Puddles Simply Rosie The White Barn (Chicken Rarebit) The Facelift Hugh & Cry



Other compositions not in that publication but available from http://www.kafoozalum.co.uk/ABC.txt (which does not seem to be picked up by JC''s tunefinder yet!) in abc format



The Beast of Drumnadrochit Have you seen it? Sabotage Highland Toenail Streak! ECML McGonagall Pinkasaurus Pure Invention It takes two to Tango Elderberry Bubblegum Slate of Hand The Snowball Jig Glaw Cymreig (Welsh Rain) Mr. Merton of Puns



http://abcnotation.com/searchTunes?q=site:www.kafoozalum.co.uk&f=c&o=a&s=0 gives all my compositions ');
INSERT INTO 'person' VALUES (11149, '2015-07-06 18:15:22.635997+00', '2015-07-06 18:15:22.635997+00', 'RSCDS International Branch', 'RSCDS IB', 'RSCDS International Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11150, '2015-07-07 10:21:57.693127+00', '2015-07-07 10:21:57.693127+00', 'Neves, Isabel', '', 'Isabel Neves', 'Rio Demouro, Portugal', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11153, '2015-07-07 14:21:59.502557+00', '2015-07-07 14:21:59.502557+00', 'Kocian, Philippe', '', 'Philippe Kocian', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11169, '2015-08-16 15:23:25.695402+00', '2019-08-04 23:56:10.36048+00', 'Georgii, Mikael', '', 'Mikael Georgii', 'Hungary', 'er_mi_georgii@hotmail.com', 1, 0, 1, 0, NULL, 0, 0, NULL, 'Information found in issue 764');
INSERT INTO 'person' VALUES (11157, '2015-07-20 13:40:18.927035+00', '2015-07-20 13:40:18.927035+00', 'Dall, Ian', '', 'Ian Dall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11158, '2015-07-20 13:50:05.606126+00', '2015-07-20 13:50:05.606126+00', 'Bould, Kate', '', 'Kate Bould', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11159, '2015-07-20 14:06:59.406786+00', '2015-07-20 14:06:59.406786+00', 'Porteous, Joyce', '', 'Joyce Porteous', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11160, '2015-07-20 14:30:57.070285+00', '2015-07-20 14:30:57.070285+00', 'Harries, Jane', '', 'Jane Harries', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11161, '2015-07-20 15:42:08.755904+00', '2015-07-20 15:42:08.755904+00', 'Oliver, Fiona', '', 'Fiona Oliver', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11694, '2018-08-28 18:00:21.054293+00', '2018-08-28 23:56:15.245695+00', 'Hobson, George', '', 'George Hobson', 'Bath, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11163, '2015-07-21 14:34:51.816817+00', '2015-07-21 23:56:22.091467+00', 'Schuckelt, Geraldine', '', 'Geraldine Schuckelt', 'Dresden, DE', '', 1, 1, 0, 0, NULL, 1963, 0, NULL, '');
INSERT INTO 'person' VALUES (11171, '2015-08-19 14:50:36.925505+00', '2018-09-18 23:56:12.143476+00', 'Harrington, Dennis', '', 'Dennis Harrington', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11152, '2015-07-07 10:30:54.771134+00', '2019-07-22 23:56:20.04786+00', 'Petersen, Christian R', '', 'Christian R Petersen', 'Lynge, Denmark', 'dancetide@gmail.com', 1, 1, 0, 0, 11152, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11128, '2015-05-04 10:44:47.730153+00', '2022-06-05 18:51:17.134311+00', 'Henry, Puka & Angus', '', 'Puka & Angus Henry', 'Wulagi, Greater Darwin, NT, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11166, '2015-07-31 13:58:19.430699+00', '2015-07-31 23:56:10.599079+00', 'Grant, Christine', '', 'Christine Grant', 'Forres Branch, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11151, '2015-07-07 10:28:44.127163+00', '2017-02-22 01:52:03.305957+00', 'Bradley, Luke', '', 'Luke Bradley', 'Morges, Switzerland, now London', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11167, '2015-07-31 14:04:27.81354+00', '2015-07-31 23:56:12.736087+00', 'Ibbotson, Tom & Lindsey', '', 'Tom & Lindsey Ibbotson', 'Cambridge Branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11170, '2015-08-18 15:47:44.868635+00', '2015-08-18 23:56:23.74025+00', 'Stacey, Moira & Keith', '', 'Moira & Keith Stacey', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11172, '2015-08-19 15:00:53.731216+00', '2015-08-19 15:01:24.471592+00', 'Khachaturian, Aram', '', 'Aram Khachaturian', '', '', 0, 0, 1, 0, 11172, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11173, '2015-08-19 16:03:00.785672+00', '2015-08-19 16:03:00.785672+00', 'Strauss, Johann Snr', '', 'Johann Strauss Snr', '', '', 0, 0, 1, 0, NULL, 1804, 1849, NULL, '');
INSERT INTO 'person' VALUES (11174, '2015-08-19 16:10:34.498548+00', '2015-08-19 16:10:34.498548+00', 'MacCuish, Alasdair', '', 'Alasdair MacCuish', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11183, '2015-08-29 11:04:01.009203+00', '2015-08-29 11:04:01.009203+00', 'Bennett, Marion', '', 'Marion Bennett', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11184, '2015-08-29 12:00:13.158049+00', '2015-08-29 12:00:13.158049+00', 'Dickson, Emma', '', 'Emma Dickson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11185, '2015-08-29 12:03:21.309777+00', '2015-08-29 12:03:21.309777+00', 'Skene, Màrtainn', '', 'Màrtainn Skene', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11186, '2015-08-29 12:06:13.56966+00', '2015-08-29 12:06:13.56966+00', 'Maxwell, Gavin', '', 'Gavin Maxwell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11187, '2015-08-29 13:58:48.34062+00', '2015-08-29 14:01:12.235672+00', 'Kondo, Yuko', '', 'Yuko Kondo', 'Japan', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11176, '2015-08-24 15:08:55.781079+00', '2015-08-26 23:56:06.841991+00', 'Cormick, Gord', '', 'Gord Cormick', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11175, '2015-08-24 15:07:24.093772+00', '2015-08-26 23:56:13.617577+00', 'Isnor, Maureen', '', 'Maureen Isnor', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11177, '2015-08-24 15:10:27.04276+00', '2015-08-26 23:56:16.984576+00', 'Manson, Ian', '', 'Ian Manson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11178, '2015-08-24 15:12:23.968389+00', '2015-08-26 23:56:21.815819+00', 'Reid, Catherine', '', 'Catherine Reid', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11179, '2015-08-24 15:17:56.954831+00', '2015-08-26 23:56:21.891724+00', 'Reid, Scott', '', 'Scott Reid', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11180, '2015-08-24 15:22:44.79296+00', '2015-08-26 23:56:26.808105+00', 'Walton, Margaret', '', 'Margaret Walton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11189, '2015-08-29 15:05:03.90908+00', '2015-08-29 15:05:03.90908+00', 'Kageyama, Toyoko & Oyama, Shigeko & Otake, Kana', '', 'Toyoko Kageyama & Shigeko Oyama & Kana Otake', 'Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11192, '2015-08-31 11:23:35.652867+00', '2015-08-31 11:23:35.652867+00', 'Bizet, Georges', '', 'Georges Bizet', '', '', 0, 0, 1, 0, NULL, 1838, 1875, NULL, '');
INSERT INTO 'person' VALUES (11190, '2015-08-29 17:50:03.068188+00', '2015-08-31 23:56:20.194747+00', 'Otake, Kana & Kasama, Akiko', '', 'Kana Otake & Akiko Kasama', 'Japan', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11193, '2015-09-03 12:52:44.155599+00', '2015-09-03 13:06:08.998871+00', 'Gibson, John G', '', 'John G Gibson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11194, '2015-09-03 20:37:18.635718+00', '2015-09-03 20:37:18.635718+00', 'Ewen, Edna', '', 'Edna Ewen', 'Aberdeen, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11195, '2015-09-03 20:43:49.050152+00', '2015-09-03 20:43:49.050152+00', 'Watson, Eileen', '', 'Eileen Watson', 'Aberdeen, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11198, '2015-09-04 09:08:17.168637+00', '2015-09-04 09:08:17.168637+00', 'Lawrence, John', '', 'John Lawrence', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11181, '2015-08-26 08:35:57.04091+00', '2020-04-25 11:13:05.281687+00', 'Telle, Roland', '', 'Roland Telle', 'Saint Quay Perros, Brittany, France', 'roland.telle@strathspey.fr', 1, 0, 0, 0, NULL, 1945, 0, NULL, '');
INSERT INTO 'person' VALUES (11188, '2015-08-29 14:05:01.039169+00', '2020-05-29 23:56:55.781756+00', 'Otake, Kana', '', 'Kana Otake', 'Japan', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11165, '2015-07-27 12:57:15.348269+00', '2021-02-28 10:44:21.377407+00', 'Martlew, Bar', '', 'Bar Martlew', '', '', 1, 0, 0, 0, NULL, 1943, 2015, NULL, 'An interview with and obituary of Bar Martlew appeared in The Reel <<https://www.rscdslondon.org.uk/wp-content/uploads/2013/09/121122Reel282.pdf#page=5|issue 282>> and <<https://www.rscdslondon.org.uk/wp-content/uploads/2015/12/151020-Reel-293.pdf#page=6|issue 293>>.');
INSERT INTO 'person' VALUES (11154, '2015-07-07 15:14:17.981227+00', '2016-07-10 10:13:40.821427+00', 'Ibbotson, Lindsey', '', 'Lindsey Ibbotson', 'Cambridge, UK', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11218, '2015-09-24 04:37:22.849251+00', '2015-09-24 04:37:22.849251+00', 'Stevenson, James (Jim)', '', 'James (Jim) Stevenson', 'Glen Cove, NY, USA', '', 0, 0, 0, 0, 2692, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2692, NULL, '2015-09-24 04:37:59.208318+00', 'Stevenson-Mathews, James (Jim)', '', 'James (Jim) Stevenson-Mathews', 'Glen Cove, NY, USA', '', 1, 0, 1, 0, NULL, 0, 0, NULL, ' James Stevenson-Mathews has published tunes under the name  James Stevenson earlier, e.g. in "The Tin Woodman and other dances".

He is typically addressed as Jim. Thus, one may also find  tunes/dances of him as Jim Stevenson(-Mathews).');
INSERT INTO 'person' VALUES (11216, '2015-09-24 04:05:27.695836+00', '2015-09-24 23:56:09.339239+00', 'Fergusson, Veronica', '', 'Veronica Fergusson', 'Vienna, Austria', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11212, '2015-09-24 03:56:44.463832+00', '2015-09-24 23:56:11.78296+00', 'Hamelbeck, Felix', '', 'Felix Hamelbeck', 'Vienna, Austria', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11219, '2015-10-01 10:53:56.456963+00', '2015-10-01 10:53:56.456963+00', 'Hodgson, Heather', '', 'Heather Hodgson', 'Cape Town, South Africa', 'heather.hodgson@uct.ac.za', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11220, '2015-10-02 14:09:57.293978+00', '2015-10-02 14:09:57.293978+00', 'Hodgson, Andrew & Heather', '', 'Andrew & Heather Hodgson', 'Cape Town, South Africa', 'andrew@hodgson.za.net', 1, 0, 0, 0, 10585, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3039, NULL, '2015-10-17 23:54:33.858391+00', 'Whitehead, Robert & the Danelaw Band', 'Robert Whitehead', 'Robert Whitehead & the Danelaw Band', '', 'info@robertwhitehead.co.uk', 0, 1, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10647, '2012-08-24 20:52:16.776495+00', '2015-10-21 14:01:43.445928+00', 'Breest, Anja', '', 'Anja Breest', 'Köln, Germany', 'anja.breest@girards.de', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Former name: Anja Girards');
INSERT INTO 'person' VALUES (11221, '2015-10-23 09:00:19.806542+00', '2015-10-23 23:56:08.133836+00', 'Enoch, Lesley', '', 'Lesley Enoch', 'Leeds', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2873, NULL, '2015-11-01 19:57:25.764526+00', 'Clark, Kathy & Meyer, Robin', '', 'Clark, Kathy & Meyer, Robin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Spelling changed from Meyers to Meyer, as this is how Robin''s surmane name is spelt on the original text of "Kabin Fever"');
INSERT INTO 'person' VALUES (11223, '2015-11-05 10:20:05.47502+00', '2015-11-06 00:56:02.522627+00', 'Andrews, Donald', '', 'Don Andrews', 'Leeds', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11224, '2015-11-07 02:18:32.858611+00', '2015-11-08 00:56:11.525098+00', 'Gregory, John', '', 'John Gregory', 'Tawa SCD Club, NZ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2705, NULL, '2015-11-08 21:39:04.141694+00', 'Upton, Charles', '', 'Charles Upton', '', 'minicrib@care4free.net', 1, 0, 0, 0, NULL, 0, 2015, NULL, 'Charles Upton was the originator of MiniCrib - the "database" of dance cribs used by so many dancers and dance groups around the world.

He also was a long time active member of Deeside Caledonian Society, Wirral, UK.  



Charles Upton passed away on Wednesday 4th November 2015.');
INSERT INTO 'person' VALUES (3282, NULL, '2015-11-30 00:56:23.854612+00', 'Thomson, Ian', '', 'Ian Thomson', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11226, '2015-12-15 14:40:56.993425+00', '2015-12-16 00:56:04.561317+00', 'Bradshaw, Diane', '', 'Diane Bradshaw', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11227, '2015-12-15 14:45:41.820292+00', '2015-12-16 00:56:25.826579+00', 'Wells, Andrea', '', 'Andrea Wells', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11228, '2015-12-15 14:49:18.457787+00', '2015-12-16 00:56:26.214913+00', 'Williams, Charlotte (Dunn)', '', 'Charlotte Williams', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11229, '2015-12-18 11:33:49.29301+00', '2015-12-19 00:56:26.441372+00', 'Woods, Sheila', '', 'Sheila Woods', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11230, '2015-12-30 18:45:28.320563+00', '2015-12-30 18:45:28.320563+00', 'Thomson, Grant', '', 'Grant Thomson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11231, '2016-01-01 13:07:09.887317+00', '2016-01-01 13:07:09.887317+00', 'Convery, Hazel', '', 'Hazel Convery', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11232, '2016-01-13 23:29:06.97993+00', '2016-01-13 23:35:52.667663+00', 'Rossen, Jette', '', 'Jette Rossen', 'Brussels, Belgium', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11233, '2016-01-17 11:19:43.950108+00', '2016-01-17 11:19:43.950108+00', 'Cottle, Alan', '', 'Alan Cottle', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Publishes on the Minicrib site');
INSERT INTO 'person' VALUES (11237, '2016-02-29 01:15:41.183611+00', '2018-03-23 11:08:40.716962+00', 'Landon, Murrough', '', 'Murrough Landon', 'London, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11236, '2016-01-27 16:25:42.837553+00', '2016-01-27 16:25:42.837553+00', 'Burgy, Florence', '', 'Florence Burgy', 'Geneva, Switzerland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (35, NULL, '2016-01-28 09:25:59.201837+00', 'Boehmer, Marie', '', 'Marie Boehmer', 'Canada', '', 1, 1, 0, 0, NULL, 1915, 2010, NULL, 'An obituary of Marie Boehmer can be found at

http://www.lifenews.ca/announcement/1921546-boehmer-marie-barker



*The Waterloo Region Record* had an obituary at:

http://www.catch21.ca/Life/Lifetimes/article/690474 but that is no longer accessible.



 

');
INSERT INTO 'person' VALUES (11240, '2016-03-06 11:01:15.420818+00', '2016-03-06 11:01:15.420818+00', 'Dawson, Val', '', 'Val Dawson', 'Bodmin, UK', 'Valdawson128@btinternet.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11238, '2016-03-01 00:14:06.836981+00', '2016-03-01 00:14:11.329164+00', 'Bezzant, Margaret', '', 'Margaret Bezzant', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11239, '2016-03-06 10:18:35.820526+00', '2016-03-06 11:01:45.400042+00', 'Richmond, Harry', '', 'Harry Richmond', 'Liskeard, UK', 'harry.richmond@yahoo.co.uk', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11696, '2018-08-28 18:44:09.916258+00', '2018-08-28 23:56:14.530693+00', 'Harraway, Peter', '', 'Peter Harraway', 'Bath, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11241, '2016-03-06 11:42:47.925924+00', '2016-03-07 00:56:20.868464+00', 'Roberts, George', '', 'George Roberts', 'Cornwall, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2022, NULL, '2016-03-13 13:00:49.452893+00', 'Bond, Paul', '', 'Paul Bond', 'Rotherham, England', '', 1, 1, 0, 0, NULL, 0, 2016, NULL, 'Paul Bond, Hon. President of RSCDS Sheffield branch, passed away during the night from March 12 to March 13, 2016. 



If you did not know him personally then you may have know him for the CardCribs he produced for many years, the crib sheets for Summer School that he produced for many years or the Yorkshire and NE England dance diary that, again, he produced for many years.

');
INSERT INTO 'person' VALUES (11242, '2016-03-31 13:35:42.313564+00', '2016-03-31 13:35:42.313564+00', 'Fettes, J F', '', 'J F Fettes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11297, '2016-07-04 19:47:36.25663+00', '2016-07-04 23:56:11.454881+00', 'Highet, Allan', '', 'Allan Highet', 'Humberside, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11308, '2016-07-11 19:37:02.648572+00', '2016-07-11 23:56:23.933985+00', 'Thompson, Lucy', '', 'Lucy Thompson', 'Ribble Valley Branch, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3745, NULL, '2016-07-21 10:12:16.914337+00', 'Hutton, Claude', '', 'Claude Hutton', 'Canada', 'cwhutton@shaw.ca', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Claude had danced only for about ten years however SCD had become a passion. He was successful in his Preliminary Exam in Scotland in 2004 and has begun to teach. He was president of the Saskatchewan Branch during the centennial year 2005.

(Information from the RSCDS Saskatchewan Branch Centennial Collection 2005)');
INSERT INTO 'person' VALUES (11311, '2016-08-05 13:27:58.072301+00', '2016-08-05 13:27:58.072301+00', 'Donaldson, Dorothy & Smith, Jim', '', 'Dorothy Donaldson / Jim Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11310, '2016-08-05 13:26:57.145374+00', '2016-08-05 23:56:07.380778+00', 'Donaldson, Dorothy', '', 'Dorothy Donaldson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11309, '2016-08-05 13:25:52.486293+00', '2016-08-05 23:56:22.093911+00', 'Smith, Jim', '', 'Jim Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11314, '2016-08-15 21:06:05.536652+00', '2016-09-12 23:56:03.197595+00', 'Band, Scott', '', 'Scott Band', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11315, '2016-08-17 18:06:20.711027+00', '2016-08-17 23:56:14.321766+00', 'MacKay, Eric H', '', 'Eric MacKay', 'Mountville, PA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11319, '2016-08-22 14:03:00.523562+00', '2016-08-22 23:56:25.217627+00', 'Wilcox, Louise', '', 'Louise Wilcox', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11374, '2016-09-18 09:35:46.898959+00', '2016-09-18 23:56:08.811096+00', 'Favel, Janet', '', 'Janet Favel', 'Otago, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11707, '2018-09-17 17:58:35.402656+00', '2018-09-17 23:56:25.132407+00', 'Smyth, Anne M.', '', 'Anne M. Smyth', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11718, '2018-09-21 13:06:23.6245+00', '2018-09-21 23:56:09.267715+00', 'Fee, Penny', '', 'Penny Fee', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11225, '2015-12-08 10:51:44.057403+00', '2018-12-11 00:56:19.658748+00', 'Monteiro, Isabel', '', 'Isabel Monteiro', 'Lisbon, Portugal', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11253, '2016-05-13 14:55:26.649054+00', '2016-05-13 23:56:08.138158+00', 'Eaton, Isobel', '', 'Isobel Eaton', 'Hunter Valley, Australia', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3261, NULL, '2016-05-15 20:02:52.191647+00', 'Martin, Marie', '', 'Marie Martin', 'Christchurch, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Member of Hoon Hay SCDC');
INSERT INTO 'person' VALUES (2169, NULL, '2021-10-04 16:04:01.981428+00', 'Glasspool, Terry & Hall, Sue', '', 'Terry Glasspool & Sue Hall', 'Vestal, NY, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11243, '2016-04-05 21:21:14.678497+00', '2016-04-05 21:21:14.678497+00', 'McGibbon, William', '', 'William McGibbon', 'Edinburgh, Scotland', '', 0, 0, 0, 0, NULL, 1690, 1756, NULL, 'William McGibbon (1690-1757) was a life-long Edinburgh native, born to a professional oboist of some reputation named Malcolm McGibbon. As a teenager he traveled to London to study with William Corbett, taking tutelage in violin and composition. He returned to Edinburgh sometime after 1716, and next is mentioned on the roster of the Edinburgh Music Society in the winter of 1726-27. He concertized regularly, and eventually became an employee of the Society where he became concertmaster. He composed in the classical style, producing three concerti, an overture (now lost), four sets of six sonatas (for two violins/flutes with basso continuo), six sonatas for flute/violin and basso continuo, six sonatas for two flutes, three collections of Scots tunes, and folktune variations for solo violin. McGibbon not only realized a salary and fees from concertizing with the Society, but he also sold copies of the parts of his compositions to the orchestra. The Society, however, also played Scottish music along with classical fare, the Scottish influences can be found in the technically proficient violinist''s compositions, many of which include elements of traditional fiddling incorporated into classical violin technique and composition forms.

(information from http://tunearch.org)');
INSERT INTO 'person' VALUES (550, NULL, '2016-04-16 17:29:35.87272+00', 'Brockbank, Ian', '', 'Ian Brockbank', 'Edinburgh', 'Ian@scottishdance.net', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (375, NULL, '2018-07-23 10:31:36.886762+00', 'Stirling Branch RSCDS', '', 'Stirling Branch RSCDS', '', '', 1, 1, 0, 0, NULL, 1927, 0, NULL, 'In the past the Stirling Branch used the name "Stirlingshire Branch", e.g. printed in their 1987 publication "Scottish Country Dances".



The Branch has been founded in 1927.');
INSERT INTO 'person' VALUES (11245, '2016-04-18 10:45:50.44261+00', '2016-04-18 23:56:06.151919+00', 'Chadwick, Rachel', '', 'Rachel Chadwick', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11246, '2016-04-18 11:33:29.155994+00', '2016-04-18 23:56:09.433714+00', 'Flachmann, Anja', '', 'Anja Flachmann', 'Bielefeld, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11248, '2016-04-18 11:40:17.758274+00', '2016-04-18 23:56:09.452701+00', 'Flachmann, Anja & Röhricht Birgit', '', 'Anja Flachmann & Birgit Röhricht', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11247, '2016-04-18 11:34:44.581584+00', '2016-04-18 23:56:22.807732+00', 'Röhricht, Birgit', '', 'Birgit Röhricht', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11244, '2016-04-18 10:31:40.401382+00', '2016-04-18 23:56:23.753776+00', 'Senior, Margaret', '', 'Margaret Senior', 'Stamford, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3446, NULL, '2016-04-25 15:59:00.938269+00', 'McKenzie, Ian', '', 'Ian McKenzie', 'Stockton on Tees, UK', '', 1, 0, 0, 0, NULL, 0, 2016, NULL, 'Ian McKenzie from Stockton-on-Tees has died aged 87.   Ian was active on the Country dance scene for over 50 years.  Being a founder member of the Teesside Branch, he and his wife Joan traveled all over the UK and overseas to dance, with friends frae ‘a’ the airts.  Ian will be remembered by many dancers.



On SCDDB his surname was formerly misspelt "MacKenzie".  Corrected 2016-04-24.  Eric');
INSERT INTO 'person' VALUES (11249, '2016-04-26 11:30:10.763914+00', '2016-04-26 23:56:11.789668+00', 'Hermey, Damaris', '', 'Damaris Hermey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11250, '2016-05-01 21:43:54.657927+00', '2016-05-01 23:56:22.003283+00', 'Saturensky, Shirley', '', 'Shirley Saturensky', 'USA (Anaheim, CA?)', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11292, '2016-06-30 18:09:24.765441+00', '2016-06-30 18:09:24.765441+00', 'Barnett, Vic', '', 'Vic Barnett', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3746, NULL, '2016-07-21 10:22:34.782316+00', 'Gibson, Jean', '', 'Jean Gibson', 'Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Jean began dancing in England many years ago with Derek Haynes. She has danced and taught in both Great Britain and Canada. She was fully certificated in 1997.

<BR>(Information from the RSCDS Saskatchewan Branch Centennial Collection 2005)');
INSERT INTO 'person' VALUES (11304, '2016-07-11 16:12:43.712804+00', '2016-07-11 19:14:31.605973+00', 'Fish, Peter', '', 'Peter Fish', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11698, '2018-08-28 19:52:31.283379+00', '2018-08-28 23:56:25.065985+00', 'Rawlings, Rosamund', '', 'Rosamund Rawlings', 'Bath, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10908, '2013-12-19 11:03:34.562568+00', '2019-02-28 00:56:17.614378+00', 'Mckenzie, Iain', '', 'Iain Mckenzie', 'Mackay, Qld, Australia', '', 0, 0, 1, 1, NULL, 0, 0, NULL, 'Accordion player');
INSERT INTO 'person' VALUES (2998, NULL, '2016-07-21 10:23:54.95496+00', 'Williams, Craig', '', 'Craig Williams', 'Ottawa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Craig was born and lived IN Saskatoon until 2000 when work forced him to move to Ottawa. He began Scottish Country Dance in 1990 and began to show a distinct talent for creating dances soon after. He was successful in his Preliminary Exam in 2004.

<BR>(Information from the RSCDS Saskatchewan Branch Centennial Collection 2005)');
INSERT INTO 'person' VALUES (3642, NULL, '2016-07-21 10:22:01.116048+00', 'Ogilvie, Olive', '', 'Olive Ogilvie', 'Saskatchewan', '', 1, 0, 0, 0, NULL, 1930, 2006, NULL, 'Olive Ogilvie was a dedicated teacher and dancer of the RSCDS Saskatchewan Branch. She was born November 5, 1930 in Dundee, Scotland and died October 31, 2006 in Regina, Saskatchewan (Canada).



Olive was married to <<http://my.strathspey.org/dd/person/3643/|George Ogilvie>>, another active member of the Saskatchewan Branch.



There is an <<http://rscdssask.org/In_Memoriam/olive_ogilvie.htm|comprehensive obituary>> at the Saskatchewan Branch home page.');
INSERT INTO 'person' VALUES (3643, NULL, '2016-07-21 10:22:25.385934+00', 'Ogilvie, George', '', 'George Ogilvie', 'Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'George has been dancing for many years. A native of Scotland, in 1978 he assisted his wife in establishing Tayside Scottish Country Dancers in Regina. He and <<http://my.strathspey.org/dd/person/3642/|Olive>> successfully started SCD In Yorkton and Moose Jaw.

George served as secretary of the Saskatchewan Branch for many years. He continues to support <<http://my.strathspey.org/dd/person/3642/|his wife>> in her teaching.

<BR>(Information from the RSCDS Saskatchewan Branch Centennial Collection 2005)');
INSERT INTO 'person' VALUES (11312, '2016-08-05 13:28:11.045602+00', '2016-08-05 23:56:07.417967+00', 'Donaldson, Dorothy', '', 'Dorothy Donaldson', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11300, '2016-07-10 22:18:50.155284+00', '2016-08-19 14:36:33.251278+00', 'Sweetman, Katy', '', 'Katy Sweetman', 'Brighton and Hove', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11317, '2016-08-21 22:51:58.0262+00', '2016-08-21 23:56:17.36296+00', 'Mitchell, Stephen', '', 'Stephen Mitchell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11320, '2016-08-22 14:06:52.690199+00', '2016-08-22 23:56:17.908619+00', 'Msika, Joshua', '', 'Joshua Msika', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11322, '2016-08-22 21:34:52.489298+00', '2016-08-22 23:56:04.642723+00', 'Bright, Marla', '', 'Marla Bright', 'Northern Virginia, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11323, '2016-08-25 13:16:09.628014+00', '2016-08-25 13:28:01.052663+00', 'Gray, Margaret', '', 'Margaret Gray', 'Cromarty, Scotland', 'margaretgray40@btinternet.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11321, '2016-08-22 21:03:13.529707+00', '2016-10-04 23:56:10.86598+00', 'Cobb, Patti', '', 'Patti Cobb', 'USA', '', 1, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11426, '2016-12-14 22:50:02.193328+00', '2016-12-15 00:56:20.127383+00', 'Rox, John', '', 'John Rox', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11260, '2016-05-16 21:40:18.48504+00', '2016-05-16 23:56:04.195673+00', 'Bolte, Ralf', '', 'Ralf Bolte', 'Mainhausen, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11271, '2016-06-19 10:23:27.431125+00', '2016-06-19 23:56:23.152734+00', 'Stanaway, Peter', '', 'Peter Stanaway', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11258, '2016-05-15 20:01:39.264419+00', '2016-05-15 23:56:11.940131+00', 'Hawkins, Brian', '', 'Brian Hawkins', 'Christchurch, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Member of Hoon Hay SCDC');
INSERT INTO 'person' VALUES (11257, '2016-05-15 20:00:19.823225+00', '2018-12-08 23:19:06.802806+00', 'Miller, Clifton', '', 'Clifton Miller', 'Christchurch, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Member of Hoon Hay SCDC');
INSERT INTO 'person' VALUES (11254, '2016-05-15 19:42:11.30804+00', '2016-05-15 23:56:12.623216+00', 'Hoon Hay Scottish Country Dance Club, The', 'Hoon Hay SCDC', 'Hoon Hay SCDC', 'Christchurch, New Zealand', '', 0, 1, 0, 0, NULL, 1987, 0, NULL, '');
INSERT INTO 'person' VALUES (11264, '2016-06-04 15:43:05.516638+00', '2018-12-08 23:19:27.412274+00', 'Andrews, Colin', '', 'Colin Andrews', 'Crediton, Devon, UK', '', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Active Morris, EFDSS and other dancing musician, dancer and dance author.');
INSERT INTO 'person' VALUES (11695, '2018-08-28 18:13:48.097719+00', '2018-08-28 23:56:14.194176+00', 'Hall, June', '', 'June Hall', 'Bath, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11270, '2016-06-19 10:15:45.384826+00', '2018-10-25 08:45:15.274067+00', 'Austen, Malcolm', '', 'Malcolm Austen', 'Harwell, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10293, NULL, '2016-05-31 22:31:20.073138+00', 'Schmidt, Heiko A', '', 'Heiko A Schmidt', 'Vienna, Austria', '', 1, 0, 0, 0, NULL, 1969, 0, NULL, 'Heiko Schmidt has danced in dance groups in various location like Heidelberg (Germany), Berlin (Germany) and Vienna (Austria).');
INSERT INTO 'person' VALUES (11265, '2016-06-05 09:31:28.488914+00', '2018-12-08 23:22:25.33575+00', 'Ott, Gitta', '', 'Gitta Ott', 'Erlangen, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11272, '2016-06-22 23:13:26.283986+00', '2018-12-08 23:25:30.639025+00', 'Young Scottish Dancers Association RSCDS', '', 'Young Scottish Dancers Association RSCDS', 'Scotland', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11251, '2016-05-12 16:16:53.439625+00', '2016-06-06 00:26:51.542731+00', 'Hamilton, James Stanley ''Jimmy''', 'Jimmy Hamilton', 'James Stanley ''Jimmy'' Hamilton', 'Ayrshire', '', 0, 0, 1, 0, NULL, 1904, 0, NULL, 'Jimmy (James Stanley) Hamilton was born at Tarholm near Annbank in 1904. He was married to Mary Hamilton of Auchincruive. Their son Stan (also James Stanley) Hamilton was born 1928 in Ayrshire.



Jimmy Hamilton was fiddler and a fisher. Jimmy had his own Scottish Country Dance Band that played at the Pavilion and the Gaiety in Ayr.



In 1966 Jimmy and Mary Hamilton moved from Auchincruive to Canada to be with their son Stan who had emigrated to Canada in 1957.

By 1968  Jimmy and Mary Hamilton moved back to Ayr.



Jimmy died in Ayr after a heart attack.



According to the <<http://boxandfiddlearchive.weebly.com/stan-hamilton.html|Box and Fiddle archive>> and Iain Boyd''s book <<http://my.strathspey.org/dd/publication/600/|All Kinds Of Everything>>, Jimmy Hamilton was the composer of the tune <<http://my.strathspey.org/dd/tune/1086/|Mary Hamilton of Auchincruive>> that is named after his wife.



(Sources: <<https://thesession.org/tunes/12052|The Session>>, <<http://boxandfiddlearchive.weebly.com/stan-hamilton.html|Box and Fiddle archive>>, and obituary in <<http://www.dancescottish.ca/archives-set%26link.html|Toronto Set+Link>> Oct 2007)');
INSERT INTO 'person' VALUES (11266, '2016-06-06 00:31:09.695138+00', '2016-06-06 23:56:12.380953+00', 'Johnston, Susan', '', 'Susan Johnston', 'Basingstoke, England', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11268, '2016-06-13 07:45:35.224897+00', '2016-06-13 23:56:10.412535+00', 'Gardner, Mary', '', 'Mary Gardner', 'Brechin', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11273, '2016-06-23 21:05:58.810874+00', '2018-10-30 22:04:23.338631+00', 'Lawrence, Bryan', '', 'Bryan Lawrence', 'Dundee', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11255, '2016-05-15 19:56:18.273987+00', '2018-12-08 23:18:24.534553+00', 'Wignall, Betty', '', 'Betty Wignall', 'Christchurch, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Member of Hoon Hay SCDC');
INSERT INTO 'person' VALUES (11276, '2016-06-23 22:20:07.83004+00', '2016-06-23 22:20:07.83004+00', 'Clark, Gill', '', 'Gill Clark', 'Auchterhouse by Dundee', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11256, '2016-05-15 19:58:41.47544+00', '2018-12-08 23:18:45.466131+00', 'Hawkins, Esther', '', 'Esther Hawkins', 'Christchurch, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Née Boyd.

Member of Hoon Hay SCDC');
INSERT INTO 'person' VALUES (11261, '2016-05-27 21:21:29.61443+00', '2019-02-19 21:39:34.520917+00', 'Geneva Scottish Country Dance Club', 'Geneva SCD Club', 'Geneva SCD Club', 'Geneva, Switzerland', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11279, '2016-06-26 14:35:11.590195+00', '2016-06-26 14:35:11.590195+00', 'Burgerhout, Marlies', '', 'Marlies Burgerhout', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11278, '2016-06-26 14:10:19.754637+00', '2016-06-26 23:56:26.338579+00', 'Rowan Tree Dancers, The', '', 'The Rowan Tree Dancers', 'Epe and environs, Netherlands', '', 0, 1, 0, 0, NULL, 1975, 0, NULL, '');
INSERT INTO 'person' VALUES (11281, '2016-06-30 09:39:26.337927+00', '2016-06-30 09:39:26.337927+00', 'Millar, Hilda', '', 'Hilda Millar', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11290, '2016-06-30 18:06:20.953849+00', '2016-06-30 18:06:20.953849+00', 'Richardson, Hilary', '', 'Hilary Richardson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11291, '2016-06-30 18:07:51.178793+00', '2016-06-30 18:07:51.178793+00', 'Calder, Mike', '', 'Mike Calder', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11293, '2016-06-30 18:10:52.894306+00', '2016-06-30 18:10:52.894306+00', 'de Lacy, Lillian and Greg', '', 'Lillian and Greg de Lacy', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11294, '2016-06-30 18:11:48.731783+00', '2016-06-30 18:11:48.731783+00', 'Chaney, Sue', '', 'Sue Chaney', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11287, '2016-06-30 17:38:24.589294+00', '2016-06-30 23:56:22.188398+00', 'Sharp, Andrew', '', 'Andrew Sharp', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11284, '2016-06-30 17:35:10.925694+00', '2016-06-30 23:56:05.621508+00', 'Calder, Mike and Barbara', '', 'Mike and Barbara Calder', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11282, '2016-06-30 09:43:10.556656+00', '2016-06-30 23:56:06.248359+00', 'Chaney, Clive', '', 'Clive Chaney', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11288, '2016-06-30 17:41:06.193671+00', '2016-06-30 23:56:14.09048+00', 'Lamb, Macushla', '', 'Macushla Lamb', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11283, '2016-06-30 17:33:09.389385+00', '2016-06-30 23:56:19.454664+00', 'Paterson, Pat', '', 'Pat Paterson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11280, '2016-06-30 09:34:46.683965+00', '2016-06-30 23:56:22.973804+00', 'Southsea Reel Club', '', 'Southsea Reel Club', 'Southsea, UK', '', 0, 1, 0, 0, NULL, 1955, 0, NULL, '');
INSERT INTO 'person' VALUES (11285, '2016-06-30 17:35:59.527537+00', '2016-06-30 23:56:24.984582+00', 'Ward, Nicola', '', 'Nicola Ward', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11289, '2016-06-30 18:04:50.098983+00', '2016-06-30 23:56:26.223986+00', 'Young, Jenny', '', 'Jenny Young', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11296, '2016-07-04 15:03:08.2418+00', '2016-07-04 15:03:08.2418+00', 'Wood, Moira', '', 'Moira Wood', 'Humbeerside, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11275, '2016-06-23 22:15:05.156246+00', '2018-12-08 23:25:55.697491+00', 'Re, Andrea', '', 'Andrea Re', 'Falkirk and Dundee', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11298, '2016-07-04 22:05:35.0873+00', '2016-07-04 23:56:15.330416+00', 'MacLeod''s, Bobby Highland Dance Band', '', 'Bobby MacLeod''s Highland Dance Band', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11277, '2016-06-23 22:24:27.345143+00', '2018-12-08 23:26:25.465533+00', 'Tragham, Norma', '', 'Norma Tragham', 'Dundee', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11267, '2016-06-09 13:30:01.803505+00', '2019-06-03 23:57:46.848202+00', 'Mungall, Tom III', '', 'Tom Mungall, III', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11295, '2016-06-30 18:12:50.186463+00', '2019-10-10 20:54:47.093352+00', 'Beaton, Pauline', '', 'Pauline Beaton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11259, '2016-05-15 20:08:05.653457+00', '2019-09-02 22:29:11.904384+00', 'Martin (NZ), John', '', 'John Martin (NZ)', 'Christchurch, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Member of Hoon Hay SCDC');
INSERT INTO 'person' VALUES (11318, '2016-08-22 07:43:59.25514+00', '2016-08-22 07:43:59.25514+00', 'Cant, Christine', '', 'Christine Cant', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11263, '2016-05-27 21:35:58.542902+00', '2017-02-22 23:55:05.745793+00', 'Taillard, Jessica Cuerq', '', 'Jessica Cuerq Taillard', 'Geneva, Switzerland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (628, NULL, '2016-09-02 18:47:52.303537+00', 'Mills, Andrew ''Andy''', '', 'Andrew ''Andy'' Mills', 'Virginia Beach, VA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Andy Mills is originally from NZ, but since about 1990 he lived in the USA. Currently he lives in Virginia Beach, VA.



When he devised the two dances "Andrew''s Dance" and "The Thrang Wynd", he went by the name Andrew Mills. However, for the last 40 years, he has only ever been known as Andy Mills.



(Source: Andy Mills, 2016)');
INSERT INTO 'person' VALUES (11354, '2016-09-12 23:24:21.745561+00', '2019-02-21 00:56:20.910625+00', 'Piquemal, Kévin', '', 'Kévin Piquemal', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11326, '2016-09-04 09:35:37.200709+00', '2016-09-04 09:53:15.122514+00', 'Thomson, Ella', '', 'Ella Thomson', 'RSCDS Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Date of death not known');
INSERT INTO 'person' VALUES (11325, '2016-09-04 09:22:16.987473+00', '2018-12-08 23:26:49.891083+00', 'Cahill,John', '', 'John Cahill', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11329, '2016-09-04 10:08:14.123566+00', '2016-09-04 10:08:14.123566+00', 'Gotfried, Roberta', '', 'Roberta Gotfried', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2395, NULL, '2016-09-04 10:15:21.751649+00', 'Imbrie, Andrew', '', 'Andrew Imbrie', 'Los Angeles, USA', 'mail@andysherryl.net', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11330, '2016-09-04 10:30:20.11812+00', '2016-09-04 10:30:31.6691+00', 'Hartung, Bill', '', 'Bill Hartung', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11331, '2016-09-04 10:38:15.685717+00', '2016-09-04 10:38:29.162145+00', 'Prest, Audrey Ramsay', '', 'Audrey Ramsay Prest', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11332, '2016-09-04 10:55:47.267576+00', '2016-09-04 10:56:07.273845+00', 'Johnson, Carol', '', 'Carol Johnson', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11334, '2016-09-04 11:06:41.19433+00', '2016-09-04 11:06:41.19433+00', 'Kenney, Deresa', '', 'Deresa Kenney', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11335, '2016-09-04 12:00:12.485715+00', '2016-09-04 12:00:34.311629+00', 'Husman, Laura', '', 'Laura Husman', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11336, '2016-09-04 12:04:08.41594+00', '2016-09-04 12:04:18.644296+00', 'Clarke, Anne', '', 'Anne Clarke', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11337, '2016-09-04 12:11:48.436826+00', '2016-09-04 12:12:00.064595+00', 'Harmon, Bob', '', 'Bob Harmon', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11338, '2016-09-04 12:14:01.968599+00', '2016-09-04 12:14:13.902734+00', 'Halverson, Gail', '', 'Gail Halverson', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11328, '2016-09-04 09:54:00.029082+00', '2016-09-04 23:56:08.78924+00', 'Fisher, Doris', '', 'Doris Fisher', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (86, NULL, '2016-09-05 08:36:29.368356+00', 'Corson, Mina', '', 'Mina Corson', 'Edinburgh, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Mina Corson is a deviser of dances, the most popular of which is probably Miss Allie Anderson. She still resides in Edinburgh.



She taught and examined for the RSCDS at St Andrews Summer School and internationally.  This could be confirmed by the RSCDS. She

visited South Africa and Winnipeg. She was a member of the 1950s international demonstration team with Jean Yates and Alice Mann Stanley, among others one

such visit was to Nice in 1952.



She was also involved with the Edinburgh Fancy for several years.



(source: Janet Hardy, her niece, 2016)');
INSERT INTO 'person' VALUES (11697, '2018-08-28 19:51:54.08288+00', '2018-08-28 23:56:20.855947+00', 'McNair, Eleanor', '', 'Eleanor McNair', 'Bath, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11339, '2016-09-05 22:36:16.783323+00', '2016-09-05 23:56:03.579232+00', 'Birtha, Becky', '', 'Becky Birtha', 'Delaware', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11342, '2016-09-08 23:07:20.698352+00', '2016-09-08 23:07:20.698352+00', 'Paris Branch RSCDS', '', 'Paris Branch RSCDS', 'Paris branch', '', 0, 1, 0, 0, NULL, 1984, 0, NULL, '');
INSERT INTO 'person' VALUES (11341, '2016-09-08 22:56:39.559477+00', '2016-09-08 23:56:13.503856+00', 'Latour, Pascaline', '', 'Pascaline Latour', 'Paris branch', '', 0, 0, 1, 0, NULL, 1987, 0, NULL, '');
INSERT INTO 'person' VALUES (11343, '2016-09-09 08:52:41.626082+00', '2016-09-09 08:52:46.659658+00', 'Allen, Brian', '', 'Brian Allen', 'Paris branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11344, '2016-09-09 08:53:50.756497+00', '2016-09-09 08:53:50.756497+00', 'Rousseau, Antoine', '', 'Antoine Rousseau', 'Paris branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11346, '2016-09-09 08:57:29.007683+00', '2016-09-09 08:57:29.007683+00', 'Raymond, Hervé', '', 'Hervé Raymond', 'Paris branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11347, '2016-09-09 08:58:35.175611+00', '2016-09-09 08:58:35.175611+00', 'Wilkinson, Emmy', '', 'Emmy Wilkinson', 'Paris branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11348, '2016-09-09 08:59:51.140247+00', '2016-09-09 08:59:51.140247+00', 'Bascle, Bénédicte', '', 'Bénédicte Bascle', 'Paris branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11349, '2016-09-09 09:00:59.09148+00', '2016-09-09 09:00:59.09148+00', 'Lefèvre, Corentin', '', 'Corentin Lefèvre', 'Paris branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11350, '2016-09-09 09:02:00.170775+00', '2016-09-09 09:02:00.170775+00', 'Ferber, Mathias', '', 'Mathias Ferber', 'Paris branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11345, '2016-09-09 08:56:19.470095+00', '2016-09-09 09:03:24.893284+00', 'Fromherz, Aymeric', '', 'Aymeric Fromherz', 'Paris branch', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11358, '2016-09-14 12:56:46.666099+00', '2016-09-14 23:56:06.395684+00', 'Corrigan, Jeff', '', 'Jeff Corrigan', 'Sacramento, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11351, '2016-09-12 22:45:14.761953+00', '2016-09-12 23:56:03.269723+00', 'Band, Scott and his Scottish Country Dance Band', 'Scott Band', 'Scott Band and his Scottish Country Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11355, '2016-09-12 23:37:09.628545+00', '2016-09-12 23:56:05.814669+00', 'Carcary, Steven', '', 'Steven Carcary', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11352, '2016-09-12 23:00:27.045995+00', '2016-09-12 23:56:15.331638+00', 'Lees, Ian', '', 'Ian Lees', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11353, '2016-09-12 23:18:28.626557+00', '2016-09-12 23:56:22.037567+00', 'Robertson, Tom B', '', 'Tom B Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11357, '2016-09-14 11:28:13.776129+00', '2016-09-14 11:28:37.843235+00', 'Ferguson, Donna', '', 'Donna Ferguson', 'Kimbolton, Ohio, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11359, '2016-09-14 13:41:03.332764+00', '2016-09-14 13:41:25.814964+00', 'Eccles, Peter', '', 'Peter Eccles', 'Boston area, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11361, '2016-09-16 13:30:16.805686+00', '2016-09-16 13:30:16.805686+00', 'Fleri, Ward', '', 'Ward Fleri', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11299, '2016-07-10 09:44:12.627002+00', '2018-10-29 16:43:57.568886+00', 'Latour, Aliénor', '', 'Aliénor Latour', 'Paris branch', '', 1, 0, 1, 0, NULL, 1988, 0, NULL, '');
INSERT INTO 'person' VALUES (11365, '2016-09-16 17:55:13.237721+00', '2016-09-16 17:55:13.237721+00', 'LaTourette, James and Sharon', '', 'James and Sharon LaTourette ', 'New Mexico, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11366, '2016-09-16 18:30:50.23107+00', '2016-09-16 23:56:14.420267+00', 'Kellogg, Martin', '', 'Martin Kellogg', 'New Mexico Branch, USA', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11368, '2016-09-16 18:50:06.146213+00', '2016-09-16 18:50:25.594697+00', 'Thayer, James', '', 'James Thayer', 'New Mexico, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11370, '2016-09-16 19:08:58.062127+00', '2016-09-16 19:08:58.062127+00', 'Davis, Jeff', '', 'Jeff Davis', 'Colorado, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11367, '2016-09-16 18:36:24.787507+00', '2016-09-16 19:09:32.891844+00', 'Davis, Jeff and Linda', '', 'Jeff and Linda Davis', 'New Mexico, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11372, '2016-09-16 19:40:49.878351+00', '2016-09-16 19:40:49.878351+00', 'Thompson, Loretta', '', 'Loretta Thompson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11371, '2016-09-16 19:24:52.046043+00', '2016-09-16 19:57:10.317023+00', 'Conklin, Beth & Dawson, Glenda', '', 'Beth Conklin & Glenda Dawson', 'Arizona, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11364, '2016-09-16 17:41:54.812577+00', '2016-09-16 23:56:06.812062+00', 'Cartwright, Courtney', '', 'Courtney Cartwright', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11363, '2016-09-16 16:50:21.960494+00', '2016-09-16 23:56:22.44446+00', 'RSCDS New Mexico Branch', '', 'RSCDS New Mexico Branch', 'New Mexico, USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11327, '2016-09-04 09:43:06.95267+00', '2018-12-08 23:28:06.546734+00', 'Allen, Alice M.', '', 'Alice M. Allen', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11340, '2016-09-05 23:03:44.357556+00', '2017-09-29 23:56:16.706057+00', 'McLaughlin, Marshall', '', 'Marshall McLaughlin', 'Hot Springs, NC USA', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1533, NULL, '2016-09-28 16:21:59.029266+00', 'Rankine, Andrew', '', 'Andrew Rankine', '', '', 0, 0, 1, 1, NULL, 1930, 1985, NULL, 'Andrew Rankine (1930-1985) was a Scottish accordionist, band leader and composer.



He was born 1930 in Aberdeen and grew up in Menstrie. He started playing the accordion only at the age of 16, but had his first broadcast about five years later in 1951. He was leading a band until 1960 when he moved to Whitley Bay and in 1963 to Leicester. Finally, in 1984 he left for California and establish The Scottish Heritage Centre close to The Queen Mary at Longed Beach. 



A year later, in 1985, Andrew Rankine died of a heart attack being only 53 years of age.



For more information see the page about Andrew Rankine at the <<http://boxandfiddlearchive.weebly.com/andrew-rankine1.html|Box and Fiddle archive>>.');
INSERT INTO 'person' VALUES (1615, NULL, '2016-09-28 16:25:08.67208+00', 'Gonnella, Ron', 'Ron Gonnella', 'Ron Gonnella', '', '', 0, 1, 1, 1, NULL, 0, 1994, NULL, 'There is a long article about Ron Gonnella at the <<http://boxandfiddlearchive.weebly.com/mar-1994.html|box and fiddle archive>>.');
INSERT INTO 'person' VALUES (11375, '2016-09-30 23:14:23.017996+00', '2016-09-30 23:15:52.616794+00', 'Maeso, Mary and Jerónimo', '', 'Mary and Jerónimo Maeso', 'Madrid, Spain', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (166, NULL, '2016-10-16 20:44:29.83774+00', 'Hamilton Branch RSCDS', '', 'Hamilton (Ont.) Branch RSCDS', 'Ontario, Canada', '', 0, 1, 0, 0, NULL, 1954, 0, NULL, 'website: http://www.rscdshamilton.org/');
INSERT INTO 'person' VALUES (11360, '2016-09-16 09:12:36.211647+00', '2021-03-02 09:54:23.863987+00', 'Karolak, Sheila', '', 'Sheila Karolak', 'Pittsburgh, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11377, '2016-10-03 23:24:39.687471+00', '2016-10-03 23:56:11.500709+00', 'Ferrie, Michael', '', 'Michael Ferrie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11382, '2016-10-03 23:55:15.27313+00', '2016-10-03 23:56:18.561399+00', 'Mabus, Joel', '', 'Joel Mabus', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11378, '2016-10-03 23:36:04.14199+00', '2016-10-03 23:56:19.786817+00', 'MacQueen, James', '', 'James MacQueen', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11381, '2016-10-03 23:54:14.101557+00', '2016-10-03 23:56:22.281813+00', 'Mohr, Rick', '', 'Rick Mohr', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11379, '2016-10-03 23:45:15.516168+00', '2016-10-03 23:56:26.418486+00', 'Rodier, Annie', '', 'Annie Rodier', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11380, '2016-10-03 23:48:46.426378+00', '2016-10-03 23:56:32.733983+00', 'Zentz, Robert', '', 'Robert Zentz', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11376, '2016-10-03 23:20:00.10917+00', '2016-10-04 00:20:53.201782+00', 'StringFire!', '', 'StringFire!', 'Oakland, CA, US', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11385, '2016-10-04 15:03:29.075377+00', '2016-10-04 15:03:29.075377+00', 'Herbold, Bruce and Cobb, Patti', '', 'Bruce Herbold and Patti Cobb', 'San Francisco, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11692, '2018-08-28 08:42:20.035794+00', '2018-08-28 23:56:29.692373+00', 'Vanderwal, Ann', '', 'Ann Vanderwal', 'Calgary, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11388, '2016-10-04 23:34:57.521934+00', '2016-10-04 23:56:10.735219+00', 'Closser, Herbold, Newitt, Stringfire!', '', 'Closser, Herbold, Newitt, Stringfire!', 'San Francisco, USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11387, '2016-10-04 15:59:17.157264+00', '2016-10-04 23:56:10.773173+00', 'Closser,Kristi', '', 'Kristi Closser', 'San Francisco, USA', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11384, '2016-10-04 00:05:41.72033+00', '2016-10-04 23:56:19.739389+00', 'Ievins, Erik', '', 'Erik Ievins', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11383, '2016-10-03 23:58:19.759868+00', '2016-10-04 23:56:32.933535+00', 'White, James', '', 'James White', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11389, '2016-10-08 23:56:01.851396+00', '2016-10-08 23:56:25.073769+00', 'Taylor, W', '', 'W Taylor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11392, '2016-10-09 01:53:48.54024+00', '2016-10-09 01:53:48.54024+00', 'Cohen, George M', '', 'George M Cohen', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11394, '2016-10-09 01:58:05.516949+00', '2016-10-09 02:02:38.784835+00', 'Lloyd Webber, Andrew & Rice, Tim', '', 'Andrew Lloyd Webber & Tim Rice', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11397, '2016-10-09 02:23:35.694037+00', '2016-10-09 02:23:35.694037+00', 'Hodgson, Alex', '', 'Alex Hodgson', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11393, '2016-10-09 01:55:46.603495+00', '2016-10-09 23:56:10.401489+00', 'Grown, Nacio Herb', '', 'Nacio Herb Grown', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11395, '2016-10-09 02:00:13.085829+00', '2016-10-09 23:56:14.133814+00', 'Lloyd Webber, Andrew', '', 'Andrew Lloyd Webber', '', '', 0, 0, 1, 0, NULL, 1948, 0, NULL, '');
INSERT INTO 'person' VALUES (11391, '2016-10-09 01:48:32.775532+00', '2016-10-09 23:56:16.678772+00', 'McNair, Arthur', '', 'Arthur McNair', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11396, '2016-10-09 02:01:49.160541+00', '2016-10-09 23:56:20.149548+00', 'Rice, Tim', '', 'Tim Rice', '', '', 0, 0, 1, 0, NULL, 1944, 0, NULL, '');
INSERT INTO 'person' VALUES (11390, '2016-10-09 00:02:02.168145+00', '2016-10-09 23:56:24.062329+00', 'Turnock, Marion', '', 'Marion Turnock', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11399, '2016-10-11 22:14:52.207961+00', '2016-10-11 22:14:52.207961+00', 'Burden, Les', '', 'Les Burden', 'Bude, Cornwall, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11398, '2016-10-11 00:43:26.927569+00', '2016-10-11 23:56:04.543471+00', 'Brunken, Elaine / Johnstone, Muriel', '', 'Brunken, Elaine / Johnstone, Muriel', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11402, '2016-10-25 02:50:48.85637+00', '2016-10-25 23:56:05.642189+00', 'Brown, Mary', '', 'Mary Brown', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11401, '2016-10-25 02:48:54.126144+00', '2016-10-25 23:56:09.518165+00', 'Eisley, Sue', '', 'Sue Eisley', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11400, '2016-10-25 02:47:44.404774+00', '2016-10-25 23:56:15.401678+00', 'Kinsman, Suzie', '', 'Suzie Kinsman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11404, '2016-10-30 12:55:05.069296+00', '2016-10-30 12:55:05.069296+00', 'Glanville, Eric R', '', 'Eric R Glanville', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11407, '2016-10-30 17:43:13.153823+00', '2016-10-30 17:43:54.216069+00', 'Philip, Margaret', '', 'Margaret Philip', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11408, '2016-10-30 17:52:13.267228+00', '2016-10-30 17:52:13.267228+00', 'Kirkpatrick, Ian', '', 'Ian Kirkpatrick', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1926, NULL, '2016-10-30 20:28:10.616126+00', 'Barkla, Cecile M C', '', 'Cecile M C Barkla', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11410, '2016-10-30 22:19:40.106788+00', '2016-10-30 22:19:40.106788+00', 'Philip, M', '', 'M. Philip', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11403, '2016-10-30 11:18:55.958909+00', '2016-10-31 00:56:06.195494+00', 'Castle Douglas and District RSCDS', '', 'Castle Douglas and District RSCDS', 'Castle Douglas, UK', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11411, '2016-10-30 23:19:26.821507+00', '2016-10-31 00:56:06.479847+00', 'Christie, Wm', '', 'Wm Christie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2409, NULL, '2016-10-31 00:56:20.973016+00', 'Paterson, Alan', '', 'Alan Paterson', 'Berne, Switzerland', 'alan@paterson.ch', 1, 0, 1, 0, NULL, 1953, 0, NULL, '');
INSERT INTO 'person' VALUES (11405, '2016-10-30 13:00:34.653126+00', '2016-10-31 00:56:21.662928+00', 'Prise, F C', '', 'F C Prise', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11409, '2016-10-30 17:57:53.375462+00', '2016-10-31 00:56:25.251048+00', 'Spurgin, Maureen', '', 'Maureen Spurgin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11406, '2016-10-30 17:31:33.311913+00', '2016-10-31 00:56:28.940966+00', 'Yamauchi, Tatsuya', '', 'Tatsuya Yamauchi', 'Japan', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11413, '2016-11-04 01:16:36.658645+00', '2016-11-04 08:45:43.828258+00', 'Macdougall, Louise', '', 'Louise Macdougall', 'Darlington, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11414, '2016-11-06 17:07:19.03753+00', '2016-11-07 00:56:07.054174+00', 'Cooper, Roger', '', 'Roger Cooper', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11416, '2016-11-06 17:28:51.256212+00', '2016-11-20 23:50:45.066114+00', 'Smith, Marmie', '', 'Marmie Smith', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11418, '2016-12-14 22:23:42.275068+00', '2016-12-15 00:56:04.164694+00', 'Brooks, Randy', '', 'Randy Brooks', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11423, '2016-12-14 22:37:06.723265+00', '2016-12-15 00:56:07.4786+00', 'Eaton, Chris', '', 'Chris Eaton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11422, '2016-12-14 22:35:37.170581+00', '2016-12-15 00:56:08.172841+00', 'Finer, Jem & MacGowan, Shane', 'Finer/MacGowan', 'Jem Finer & Shane MacGowan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11425, '2016-12-14 22:45:25.719225+00', '2016-12-15 00:56:12.915582+00', 'Lake, Greg', '', 'Greg Lake', '', '', 0, 0, 1, 0, NULL, 1947, 2016, NULL, '');
INSERT INTO 'person' VALUES (11419, '2016-12-14 22:26:26.892944+00', '2016-12-15 00:56:13.596859+00', 'Livingston, Jay & Evans, Ray', 'Livingston/Evans', 'Jay Livingston & Ray Evans', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11424, '2016-12-14 22:40:45.001559+00', '2016-12-15 00:56:21.470254+00', 'Smart, Henry T', '', 'Henry T Smart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11420, '2016-12-14 22:27:42.709499+00', '2016-12-15 00:56:22.231802+00', 'Stove, Magnus', '', 'Magnus Stove', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11417, '2016-12-14 22:17:03.905875+00', '2016-12-15 00:56:24.620579+00', 'Wilson, Meredith', '', 'Meredith Wilson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11412, '2016-10-31 20:46:28.116148+00', '2018-02-08 20:16:31.589205+00', 'Rose, Jane and Brian', '', 'Jane and Brian Rose', 'Berkhamsted, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11421, '2016-12-14 22:32:47.584745+00', '2016-12-15 00:56:03.465539+00', 'Blane, Ralph & Martin, Hugh', 'Blane/Martin', 'Ralph Blane & Hugh Martin', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11429, '2016-12-14 23:01:44.081682+00', '2016-12-15 00:56:05.838319+00', 'Connor, Tommy', '', 'Tommy Connor', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11428, '2016-12-14 22:56:02.604942+00', '2016-12-15 00:56:08.984253+00', 'Gauntlett, Henry John', '', 'Henry John Gauntlett', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11435, '2016-12-14 23:23:12.654958+00', '2016-12-15 00:56:10.009018+00', 'Gruber, Franz Xaver', '', 'Franz Xaver Gruber', '', '', 0, 0, 1, 0, NULL, 1787, 1863, NULL, '');
INSERT INTO 'person' VALUES (11434, '2016-12-14 23:16:54.968854+00', '2016-12-15 00:56:10.581778+00', 'Harris, Rolf & Brown, John', 'Harris/Brown', 'Rolf Harris & John Brown', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11431, '2016-12-14 23:04:20.529153+00', '2016-12-15 00:56:10.787871+00', 'Heattie, Bob', '', 'Bob Heattie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11430, '2016-12-14 23:03:12.289845+00', '2016-12-15 00:56:15.360491+00', 'McCartney, Paul', '', 'Paul McCartney', '', '', 0, 0, 1, 0, NULL, 1942, 0, NULL, '');
INSERT INTO 'person' VALUES (11427, '2016-12-14 22:52:41.670502+00', '2016-12-15 00:56:19.279152+00', 'Redmond, John & Cavanagh, James & Weldon, Frank', 'Redmond/Cavanagh/Weldon', 'John Redmond, James Cavanagh & Frank Weldon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11433, '2016-12-14 23:09:04.944809+00', '2016-12-15 00:56:22.6443+00', 'Taylor, Irving & Brooks, Dudley & Stanley, Hal', 'Taylor/Brooks/Stanley', 'Irving Taylor, Dudley Brooks & Hal Stanley', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11432, '2016-12-14 23:06:59.327081+00', '2016-12-15 00:56:24.972285+00', 'Wood, Roy', '', 'Roy Wood', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10327, NULL, '2016-12-17 21:21:22.309939+00', 'Linklater-Shirras, M', '', 'M Linklater-Shirras', 'RSCDS Inverness', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '"Link" as she was affectionately known was very active in the Inverness Branch over the years as a dancer and in her roles as treasurer and secretary.');
INSERT INTO 'person' VALUES (11440, '2017-01-05 10:51:42.862558+00', '2017-01-06 00:56:02.207564+00', 'Anderson, Jinty', '', 'Jinty Anderson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11438, '2017-01-05 09:54:39.362466+00', '2017-01-06 00:56:04.421761+00', 'Brunskill, Patrick', '', 'Patrick Brunskill', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11439, '2017-01-05 10:06:24.021101+00', '2017-01-06 00:56:05.755495+00', 'Clarke, Ruth', '', 'Ruth Clarke', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11436, '2017-01-05 09:05:13.465512+00', '2017-01-06 00:56:18.631603+00', 'Rankin, Lyn', '', 'Lyn Rankin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2468, NULL, '2017-01-18 08:04:32.670878+00', 'Turner, John and the Fiddletree Band', 'John Turner & Fiddletree', 'John Turner and the Fiddletree Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11441, '2017-01-20 01:56:26.926964+00', '2017-01-21 00:56:05.061677+00', 'Bulteel, Angela & Tony', '', 'Angela & Tony Bulteel', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11443, '2017-01-22 15:25:34.387424+00', '2017-01-22 15:25:34.387424+00', 'McLendon Gawlas, Donna', '', 'Donna McLendon Gawlas', 'Atlanta, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11445, '2017-01-22 15:28:31.57407+00', '2017-01-22 15:28:31.57407+00', 'Tumlin, Susan', '', 'Susan Tumlin', 'Atlanta, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11447, '2017-01-22 21:15:26.293708+00', '2017-01-23 00:56:07.039838+00', 'Cox, Claude', '', 'Claude Cox', 'Atlanta, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11442, '2017-01-22 15:18:23.376241+00', '2017-01-23 00:56:09.878129+00', 'Gemmell, Barbara', '', 'Barbara Gemmell', 'Atlanta, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11446, '2017-01-22 15:29:40.324331+00', '2017-01-23 00:56:14.48994+00', 'Linz, Werner', '', 'Werner Linz', 'Atlanta, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11444, '2017-01-22 15:26:55.08244+00', '2017-01-23 00:56:21.301468+00', 'Ray, Rhonda', '', 'Rhonda Ray', 'Atlanta, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11448, '2017-01-30 23:33:42.756836+00', '2017-01-31 00:56:11.69131+00', 'Hill, Valerie', '', 'Valerie Hill', 'Frederick SCDG, Maryland, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1731, NULL, '2017-02-12 12:48:19.386169+00', 'Sharpe, Charles', '', 'Charles Sharpe', '', '', 0, 0, 1, 0, NULL, 1750, 1813, NULL, 'According to <<http://tunearch.org/wiki/Annotation:Mr._Sharpe%27s_Delight|tunearch.org>>:



> Sharpe was the son of William Kirkpatrick of Ailsland, a younger brother

> of Sir Thomas Kirkpatrick, 3rd Baronet of Closeburn. On inheriting Hoddom

> Castle, Dumfriesshire, in the Borders, Charles changed his name to

> Sharpe, the name of his uncle’s line, from whom he inherited the estate.

> He set to work on the castle, repairing and improving it, and adding

> several rooms. Sharpe had a reputation as an excellent violinist, and also

> composed music and verse. He was a friend and correspondent of Robert 

> Burns.



Sometimes spelled “Sharp” (without the final “e”).');
INSERT INTO 'person' VALUES (11450, '2017-02-13 11:35:24.899415+00', '2017-02-13 11:35:24.899415+00', 'Oswald, David', '', 'David Oswald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11452, '2017-02-13 14:11:23.472788+00', '2017-02-14 00:56:10.205551+00', 'Harper, Addie Jr', '', 'Addie Harper Jr', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Identical to Addie Harper? (without Jr)');
INSERT INTO 'person' VALUES (11451, '2017-02-13 11:47:49.953953+00', '2017-02-14 00:56:22.504604+00', 'Tween, James', '', 'James Tween', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11453, '2017-02-15 15:47:54.771413+00', '2017-02-15 15:47:54.771413+00', 'Lyall, A', '', 'A Lyall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11262, '2016-05-27 21:32:30.339766+00', '2017-02-22 01:53:14.168913+00', 'Anderson, Colin', '', 'Colin Anderson', 'France and Geneva', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11454, '2017-02-25 16:48:52.724008+00', '2017-02-26 00:56:06.684172+00', 'Conder, Elizabeth', '', 'Lizzy Conder', 'London, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11460, '2017-03-01 23:54:35.413296+00', '2017-03-02 00:57:13.311976+00', 'Levy, Bertram', '', 'Bertram Levy', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11461, '2017-03-02 00:34:19.677954+00', '2017-03-02 00:56:09.209607+00', 'Bigney, Sam', '', 'Sam Bigney', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11457, '2017-03-01 23:07:26.280312+00', '2017-03-02 00:56:46.984202+00', 'Gitlitz, Paul', '', 'Paul Gitlitz', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11455, '2017-03-01 10:00:53.278083+00', '2017-03-02 00:57:15.175684+00', 'Livingston, Marty', '', 'Marty Livingston', 'Austin, TX', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11459, '2017-03-01 23:51:22.383625+00', '2017-03-02 00:57:15.726335+00', 'Loewe, Frederick', '', 'Frederick Loewe', '', '', 0, 0, 1, 0, NULL, 1901, 1988, NULL, '');
INSERT INTO 'person' VALUES (11462, '2017-03-02 00:42:04.98885+00', '2017-03-02 00:58:28.832617+00', 'Wyeth, Helen', '', 'Helen Wyeth', 'Auckland, NZ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3368, NULL, '2017-03-08 01:32:08.39153+00', 'Flying Ghillies Scottish Country Dancers, The', '', 'The Flying Ghillies Scottish Country Dancers', 'Dayton, OH, USA', '', 1, 1, 0, 0, NULL, 2001, 0, NULL, 'Established in 2001, the Flying Ghillies Scottish Country Dancers are the Dayton, Ohio “twig” of the Cincinnati Branch of the Royal Scottish Country Dance Society.');
INSERT INTO 'person' VALUES (11437, '2017-01-05 09:49:53.296545+00', '2018-12-11 18:17:05.697203+00', 'Campbell, Peter B J', '', 'Peter B J Campbell', 'Belfast, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11543, '2017-10-28 19:58:50.330839+00', '2017-10-28 23:56:16.623634+00', 'Meister, Albrecht', '', 'Albrecht Meister', 'Chemnitz, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11581, '2018-01-12 22:12:19.179141+00', '2018-01-13 17:01:12.668254+00', 'Allen, Randall', '', 'Randall Allen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11584, '2018-01-13 11:53:27.047569+00', '2018-01-13 17:23:48.28158+00', 'Tavener, Janet', '', 'Janet Tavener', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11463, '2017-03-03 00:49:51.051664+00', '2019-10-24 23:56:17.550287+00', 'Marchand, Bevan', '', 'Bevan Marchand', 'Oxford, UK', 'highlandbevan@yahoo.com', 1, 0, 1, 0, NULL, 0, 0, NULL, 'My dances are Copyright Bevan Marchand 1998-2006. Permission is granted to freely reproduce and distribute, providing no charge is made. I hope you enjoy them!');
INSERT INTO 'person' VALUES (11592, '2018-01-19 13:22:00.730722+00', '2018-01-20 00:56:11.845682+00', 'Gradon, John', '', 'John Gradon', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11458, '2017-03-01 23:43:34.28609+00', '2023-01-13 00:56:44.658208+00', 'Rankine, John Morris', '', 'John Morris Rankine', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11449, '2017-02-02 20:37:02.955707+00', '2022-08-07 19:56:50.984532+00', 'MacDonald, Fiona', '', 'Fiona Macdonald', 'Inverness, Scotland', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11464, '2017-03-10 16:05:52.782833+00', '2017-03-11 00:56:16.624331+00', 'Minicrib', '', 'Minicrib', 'Wirral, UK', 'minicrib@minicrib.org.uk', 0, 1, 0, 0, NULL, 0, 0, NULL, 'The late Charles Upton started publishing SCD cribs under the name of Minicribs.  His work is now being continued by David Haynes and his team.  Minicribs are one of the crib collections included in SCDDB.



As the website http://www.minicrib.org.uk/publish.html is open for anyone to publish dance descriptions, SCDDB now classifies that website as a "publication", so that links can be made to those original descriptions.');
INSERT INTO 'person' VALUES (11466, '2017-03-12 23:39:33.538929+00', '2017-03-12 23:39:42.625601+00', 'Haworth, Jim', '', 'Jim Haworth', 'Manchester, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Member of the ASHMERG Scottish Country Dance Society, Greater Manchester, UK');
INSERT INTO 'person' VALUES (11467, '2017-03-12 23:41:53.279078+00', '2017-03-13 00:56:07.412996+00', 'Eckersley, Brian', '', 'Brian Eckersley', 'Manchester, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Member of the ASHMERG Scottish Country Dance Society, Greater Manchester, UK');
INSERT INTO 'person' VALUES (11469, '2017-03-24 15:03:03.646262+00', '2017-03-24 15:03:03.646262+00', 'Bickerton, David', '', 'David Bickerton', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11470, '2017-03-31 08:57:43.587893+00', '2017-03-31 23:56:09.794876+00', 'Gay Gordons (Manchester)', '', 'Gay Gordons (Manchester)', 'Manchester ', '', 0, 1, 0, 0, NULL, 2007, 0, NULL, '');
INSERT INTO 'person' VALUES (11471, '2017-03-31 09:02:24.630152+00', '2017-03-31 23:56:23.482766+00', 'Taylor, David', '', 'David Taylor', 'Manchester', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11473, '2017-04-03 17:46:24.464124+00', '2017-04-03 17:46:24.464124+00', 'Dowling, Kira', '', 'Kira Dowling', 'Canberra, Australia', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (244, NULL, '2017-04-05 09:13:50.450808+00', 'Mackey, Ronald', '', 'Ronald Mackey', 'London', 'Ron.Mackey@BTInternet.COM', 1, 0, 0, 0, NULL, 0, 2008, NULL, 'Unfortunately, Ron Mackay died in July 2008. 

(Thus, the email address is not valid anymore.)');
INSERT INTO 'person' VALUES (11583, '2018-01-13 11:09:36.590989+00', '2020-11-14 10:35:00.021574+00', 'Gray, Ian and Hawkins, Nicky', '', 'Gray, I. and Hawkins, N.', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11699, '2018-08-29 20:29:01.119513+00', '2021-04-12 17:10:41.985745+00', 'Bruynooghe, Liz', '', 'Liz Bruynooghe', 'Nantwich, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11465, '2017-03-10 20:41:22.584123+00', '2021-10-18 14:03:11.169264+00', 'Numeus, Gunnar', '', 'Gunnar Numeus', 'Gothenburg, Sweden', '', 1, 1, 0, 0, NULL, 0, 2021, NULL, '');
INSERT INTO 'person' VALUES (11476, '2017-04-05 09:51:29.9378+00', '2017-04-05 23:56:09.611592+00', 'Goodhart, Al', '', 'Al Goodhart', 'USA', '', 0, 0, 1, 0, NULL, 1905, 1955, NULL, 'Al Goodhart lived from January 26, 1905 to November 30, 1955. During his lifetime he was a radio announcer, vaudeville pianist and special materials writer.



He collaborated, among others, with Al Hoffman, Maurice Sigler, Mann Curtis, Sammy Lerner, Ed Nelson, Kay Twomey and Allan Roberts.');
INSERT INTO 'person' VALUES (11475, '2017-04-05 09:38:28.201986+00', '2017-04-05 23:56:22.630628+00', 'Sigler, Maurice', '', 'Maurice Sigler', '', '', 0, 0, 1, 0, NULL, 1901, 1961, NULL, 'Maurice Sigler was an American composer, lyricist, conductor and producer.



For more information see <<http://www.songwritershalloffame.org/notable_writers/C5039|songwriters hall of fame>> or <<https://en.wikipedia.org/wiki/Maurice_Sigler|Wikipedia>>.');
INSERT INTO 'person' VALUES (11474, '2017-04-05 09:32:40.390106+00', '2017-04-05 23:56:22.748527+00', 'Sigler, Maurice / Goodhart, Al', '', 'Maurice Sigler / Al Goodhart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11548, '2017-11-06 18:34:58.006353+00', '2017-11-07 00:56:14.841679+00', 'Johnstone, Jenna', '', 'Jenna Johnstone', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11547, '2017-11-06 18:31:39.940686+00', '2017-11-07 00:56:17.005449+00', 'MacGlashan, John', '', 'John MacGlashan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Lived around the turn of the 19th century. May or may not have been related to <<ddp:MacGlashan, Alexander|Alexander MacGlashan>>.');
INSERT INTO 'person' VALUES (11478, '2017-04-12 20:23:21.048519+00', '2017-04-12 23:56:05.988588+00', 'Clede, Heather', '', 'Heather Clede', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11479, '2017-04-12 20:29:15.667608+00', '2017-04-12 23:56:06.04379+00', 'Clede, Tiffany', '', 'Tiffany Clede', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11477, '2017-04-12 13:50:20.887155+00', '2017-04-12 23:56:15.333286+00', 'MacQueen, Sarah', '', 'Sarah MacQueen', 'USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11472, '2017-04-01 16:32:12.114307+00', '2019-05-12 23:56:23.925323+00', 'Scott, Lynne', '', 'Lynne Scott', '? Grenoble, FR', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11542, '2017-10-28 19:58:29.818166+00', '2017-10-28 23:56:10.851746+00', 'Helle, Kristina', '', 'Kristina Helle', 'Chemnitz, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11540, '2017-10-28 19:57:34.956799+00', '2017-10-28 23:56:16.689062+00', 'Meister, Undine', '', 'Undine Meister', 'Chemnitz, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11544, '2017-10-28 20:01:24.986929+00', '2017-10-28 23:56:23.407849+00', 'Undine Meister & Gabriele Schrader-Ladewig & Kristina Helle & Albrecht Meister & Thomas Groß', 'U Meister & G Schrader-Ladewig & K Helle & A Meister & T Groß', 'Undine Meister & Gabriele Schrader-Ladewig & Kristina Helle & Albrecht Meister & Thomas Groß', 'Chemnitz, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Undine Meister & Gabriele Schrader-Ladewig & Kristina Helle & Albrecht Meister & Thomas Groß');
INSERT INTO 'person' VALUES (11545, '2017-10-30 20:02:55.060574+00', '2017-10-30 20:02:55.060574+00', 'Chamoin, Patrick', '', 'Patrick Chamoin', 'Paris, France', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11562, '2017-11-13 02:05:57.470985+00', '2017-11-13 02:06:47.666978+00', 'Pestana, Karen', '', 'Karen Pestana', 'Windsor, Connecticut, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11549, '2017-11-06 18:37:09.144966+00', '2017-11-07 00:56:22.291196+00', 'Reid, Jim', '', 'Jim Reid', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11550, '2017-11-06 18:46:39.912363+00', '2017-11-07 00:56:06.989982+00', 'Connolly, William J', '', 'William J Connolly', '', '', 0, 0, 1, 0, NULL, 1942, 0, NULL, 'Famous Scottish comedian, actor, musician and TV/radio presenter better known as <<https://en.wikipedia.org/wiki/Billy_Connolly|Billy Connolly>>.');
INSERT INTO 'person' VALUES (11551, '2017-11-08 14:42:04.900082+00', '2017-11-08 14:42:04.900082+00', 'Chrisholm, Angus', '', 'Chrisholm, Angus', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11552, '2017-11-09 20:08:29.099851+00', '2017-11-10 00:56:06.896051+00', 'Cordes, David', '', 'David Cordes', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11553, '2017-11-10 16:36:52.817155+00', '2017-11-10 16:36:52.817155+00', 'Montgomerie, Hugh', '', 'Hugh Montgomerie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11554, '2017-11-10 17:11:45.975467+00', '2017-11-10 17:11:45.975467+00', 'Young, Jas', '', 'Jas Young', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11555, '2017-11-10 17:33:22.623233+00', '2017-11-10 17:33:22.623233+00', 'Kamikura, Natty', '', 'Natty Kamikura', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11556, '2017-11-10 17:39:23.045546+00', '2017-11-10 17:39:23.045546+00', 'Darge, James', '', 'James Darge', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11557, '2017-11-10 17:44:19.258816+00', '2017-11-10 17:44:19.258816+00', 'Wood, Donny', '', 'Donny Wood', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11559, '2017-11-10 19:20:19.205237+00', '2017-11-10 19:20:19.205237+00', 'Beaton, Kinnon', '', 'Kinnon Beaton', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11560, '2017-11-10 19:23:19.058028+00', '2017-11-10 19:23:19.058028+00', 'Allard, Joseph', '', 'Joseph Allard', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11561, '2017-11-10 19:42:14.905574+00', '2017-11-10 19:42:14.905574+00', 'Stewart, Wendy', '', 'Wendy Stewart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11563, '2017-11-13 02:41:13.038432+00', '2017-11-14 00:56:03.066393+00', 'Bethray, Aidan', '', 'Aidan Bethray', 'Stamford, Connecticut, USA', '', 1, 0, 0, 0, NULL, 2007, 0, NULL, '');
INSERT INTO 'person' VALUES (11546, '2017-11-04 17:44:44.742722+00', '2017-11-14 00:56:18.738094+00', 'McLachlan, Jean', '', 'Jean McLachlan', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11564, '2017-11-14 10:47:08.918621+00', '2017-11-14 10:47:08.918621+00', 'Collett (18C), T', '', 'T Collett (18C)', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11565, '2017-11-20 15:23:34.438444+00', '2017-11-21 00:56:17.294402+00', 'McNeil, Kathy', '', 'Kathy McNeil', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11566, '2017-11-23 13:07:30.544482+00', '2017-11-23 13:07:30.544482+00', 'Pyke, Jan', '', 'Jan Pyke', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11567, '2017-11-23 13:15:35.407406+00', '2017-11-23 13:15:35.407406+00', 'Bowater, Sue', '', 'Sue Bowater', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11569, '2017-11-25 16:26:38.878177+00', '2017-11-26 00:56:11.221708+00', 'Hardie, William', '', 'William Hardie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11587, '2018-01-14 16:57:33.761102+00', '2018-01-14 16:59:14.862537+00', 'Plank, Graeme', '', 'Graeme Plank', 'Christchurch, NZ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11594, '2018-01-22 19:34:08.834042+00', '2018-01-23 02:30:08.228502+00', 'De Angelis, Loreto', '', 'Loreto De Angelis', 'Rome (Italy)', 'lrt.dngls@gmail.com', 1, 0, 0, 0, NULL, 1951, 0, NULL, '');
INSERT INTO 'person' VALUES (860, NULL, '2017-04-22 00:28:52.694697+00', 'Hinchcliffe, Audrey', '', 'Audrey Hinchcliffe', 'Leeds, UK', '', 1, 0, 0, 0, NULL, 0, 2014, NULL, 'Audrey Hinchcliffe was member of the Leeds Branch of the RSCDS. 

As secretary of the Branch she was also involved in the organization of the Leeds Festival ran by the club. 

Later she was made Honorary President.



At some point she moved to Foxhill Court, North of Leeds. In her flat there she hosted people and most of the Bands who came from Scotland to play.



Jimmy Shand, Sr., composed a tune named "<<http://my.strathspey.org/dd/tune/1135/|Miss Audrey Hinchcliffe''s Strathspey>>", John Mitchell devised a <<http://my.strathspey.org/dd/dance/285/|dance with the same name>> published in the <<http://my.strathspey.org/dd/publication/459/|Whetherly Book 9>>, and John Drewry wrote the dance "<<http://my.strathspey.org/dd/dance/2321/|Foxhill Court>>" for her which is published in his <<http://my.strathspey.org/dd/publication/207/|Canadian Book>>.



For more information there is a Tribute to Audrey Hinchcliffe in the Leeds Newsletter 74, August 2014 (available at <<http://www.rscdsleeds.org.uk/newsletters.html|http://www.rscdsleeds.org.uk/newsletters.html>>).');
INSERT INTO 'person' VALUES (11480, '2017-05-06 23:53:35.305306+00', '2017-05-06 23:56:22.321356+00', 'Smith, Isabelle', '', 'Isabelle Smith', 'New York, NY. USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11481, '2017-05-07 00:17:18.191541+00', '2017-05-07 23:56:21.567504+00', 'Smith, Isabelle & Ogburn, William', '', 'Isabelle Smith & William Ogburn', 'New York, USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11482, '2017-05-09 18:04:48.525346+00', '2017-05-09 18:04:48.525346+00', 'Ashmerg SCD Group', '', 'Ashmerg SCD Group', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11485, '2017-05-19 17:10:39.629506+00', '2017-05-19 23:56:05.198566+00', 'Cameron, Donald', '', 'Donald Cameron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11484, '2017-05-19 08:51:34.880812+00', '2017-05-19 23:56:07.331274+00', 'David Knight, Dan Emery & Dave Wiesler', '', 'David Knight, Dan Emery & Dave Wiesler', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11483, '2017-05-19 08:46:50.580949+00', '2017-05-19 23:56:08.45625+00', 'Emery, Dan', '', 'Dan Emery', 'New Haven', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11486, '2017-05-27 16:16:54.589468+00', '2017-05-27 16:16:54.589468+00', 'Wakeman, Larry', '', 'Larry Wakeman', 'San Francisco Branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11488, '2017-06-04 22:43:30.724993+00', '2017-06-04 22:45:12.568527+00', 'Aitken, John', '', 'John Aitken', 'UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11489, '2017-06-04 22:46:40.997772+00', '2017-06-04 23:56:09.301868+00', 'Goodloe, Vicky & Aitken, John', '', 'Vicky Goodloe & John Aitken', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11490, '2017-06-05 22:53:26.409767+00', '2017-06-05 22:53:26.409767+00', 'Walker, Anne', '', 'Anne Walker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11491, '2017-06-05 22:54:42.805705+00', '2017-06-05 22:54:42.805705+00', 'Spencer, Alice', '', 'Alice Spencer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11558, '2017-11-10 17:51:34.309542+00', '2021-10-20 15:06:53.18838+00', 'Collins, Mairi', '', 'Mairi Collins', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11492, '2017-06-05 23:06:10.072558+00', '2017-06-05 23:06:10.072558+00', 'RSCDS Cheltenham Branch', 'RSCDS Cheltenham', 'RSCDS Cheltenham', 'Cheltenham, UK', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11493, '2017-06-07 09:06:08.995422+00', '2017-06-07 09:06:08.995422+00', 'Cozens, Sylvia', '', 'Sylvia Cozens', 'Bingham', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11494, '2017-06-07 09:06:53.819294+00', '2017-06-07 09:06:53.819294+00', 'Cozens, Godfrey', '', 'Godfrey Cozens', 'Bingham', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11495, '2017-06-07 09:08:01.334423+00', '2017-06-07 23:56:06.067821+00', 'Cozens, Sylvia+Godfrey', '', 'Sylvia+Godfrey Cozens', 'Bingham', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3372, NULL, '2017-06-10 01:45:32.512655+00', 'Schneckenburger, Lissa & Pixton, Tom', 'Schneckenburger/Pixton', 'Lissa Schneckenburger & Tom Pixton', 'USA', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'The lineup for the CD ''Scottish in Salem'' in 2003 was Lissa Schneckenburger (fiddle), Tom Pixton (piano/accordion), Howard Lasnick and Paul Henle (percussion), and Barbara Pixton (bass).');
INSERT INTO 'person' VALUES (11498, '2017-06-17 08:37:13.366371+00', '2017-06-17 08:43:04.339306+00', 'Taylor, Larry E.', '', 'Larry E. Taylor', '', 'larryetaylor@hotmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1762, NULL, '2017-07-07 09:19:46.883248+00', 'Riddell, John (or Joseph)', '', 'John Riddell', '', '', 0, 0, 1, 0, NULL, 1718, 1795, NULL, 'Sometimes referred to as “Joseph Riddell”. “John” seems to be the more widely used name.');
INSERT INTO 'person' VALUES (11497, '2017-06-16 16:19:59.741952+00', '2017-06-16 23:56:21.656319+00', 'Morozova, Elizaveta', '', 'Elizaveta Morozova', 'Saint Petersburg', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3345, NULL, '2017-07-13 21:29:57.931428+00', 'Thomson, Gordon', '', 'Gordon Thomson', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Gordon writing to Peter Dixon in 2017:  Before retiring to Skye in 2009 I had danced in Suffolk and surrounding areas for about 20 years.  Gillian''s Strathspey was devised for Gillian Barella who taught a class in Nacton, Suffolk.  Ask Miriam and Return to Shieldaig were devised in memory of Miriam Lochner, who you probably knew as she danced a lot in Cambridge. (Return to Shieldaig reflects her elegance in dance; Ask Miriam reflects her fun in dance).  An T-Uibhisteach Tapaidh was written for the 60th birthday of Calean Maclean, ''an agile man from Uist'', who dances at our class in Skeabost on Skye.  A local musician, Blair Douglas, wrote four new tunes for Calean''s dance and recorded them. ');
INSERT INTO 'person' VALUES (11500, '2017-06-18 15:01:59.983278+00', '2017-06-18 23:56:16.370048+00', 'Miles, Patricia', '', 'Patricia Miles', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11502, '2017-06-18 16:07:35.521705+00', '2017-06-18 23:56:16.475788+00', 'Miller, Jean', '', 'Jean Miller', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11501, '2017-06-18 16:03:23.63328+00', '2017-06-18 23:56:18.649341+00', 'Porter, Ed', '', 'Ed Porter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11499, '2017-06-18 13:59:21.397164+00', '2017-06-18 23:56:20.097832+00', 'RSCDS Nova Scotia Branch', 'Nova Scotia', 'RSCDS Nova Scotia Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11306, '2016-07-11 19:22:54.236556+00', '2017-06-25 00:53:48.394289+00', 'Scott, Nicola', '', 'Nicola Scott', 'Birmingham area, UK', 'info@nicolascott.dance', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11731, '2018-10-13 21:26:41.314937+00', '2018-10-13 23:56:24.277233+00', 'Peat, Mick', '', 'Mick Peat', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11504, '2017-07-16 11:37:10.824608+00', '2017-07-16 23:56:02.36403+00', 'Bailey, Ethan', '', 'Ethan Bailey', 'Santa Rosa, CA, US', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11507, '2017-07-16 11:44:40.261077+00', '2017-07-16 23:56:02.876892+00', 'Beckinsale, Elizabeth', '', 'Elizabeth Beckinsale', 'Somerset, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11508, '2017-07-16 11:58:35.21863+00', '2017-07-16 23:56:13.700977+00', 'Luthi, Helena Strandberg', '', 'Helena Strandberg Luthi', 'Gothenburgh, SE', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11505, '2017-07-16 11:41:15.804629+00', '2017-07-16 23:56:17.50075+00', 'Nicol, Andy', '', 'Andy Nicol', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11537, '2017-10-22 21:54:42.550016+00', '2017-10-22 21:55:21.557012+00', 'Sutherland, Hector', '', 'Hector Sutherland', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3045, NULL, '2017-07-27 16:18:34.572186+00', 'McLaren, Nicol & The Glencraig Scottish Dance Band', 'Nicol McLaren', 'Nicol McLaren & The Glencraig Scottish Dance Band', 'Pitlochry, Scotland', '', 0, 0, 0, 1, 10209, 1983, 0, NULL, 'Nicol McLaren formed The Glencraig Scottish Dance Band in 1983.



For Line-ups on different CDs see the entry of the <<https://my.strathspey.org/dd/person/10209/|The Glencraig Scottish Dance Band>>.

');
INSERT INTO 'person' VALUES (10223, NULL, '2017-07-27 15:13:27.306424+00', 'Mancini, Henry', '', 'Henry Mancini', 'Los Angeles, USA', '', 0, 0, 1, 0, NULL, 1924, 1994, NULL, 'Henry Mancini was an American composer, conductor, arranger and musician. 

He is best remembered for his film and television scores. 

He won 4 Academy Awards, a Golden Globe, and 20 Grammy Awards. In addition he was awarded a posthumous Grammy Lifetime Achievement Award in 1995.



Among his best known works are "The Pink Panther Theme" (the theme to "The Pink Panther" film series"), "Moon River" (to the movie "Breakfast at Tiffany''s") and the theme for the Peter Gunn television series.



Also posthumously in April 2004, he was honored by the US Postal Service presenting a stamp commemorating his lifetime achievements in film music, and to celebrate the 40th anniversary of the film The Pink Panther.



For an overview about Henry Mancini''s live and achievements have a look the <<http://www.henrymancini.com/|official website>> and his <<https://en.wikipedia.org/wiki/Henry_Mancini|Wikipedia entry>>.');
INSERT INTO 'person' VALUES (11595, '2018-01-25 11:57:23.427586+00', '2018-01-25 11:57:23.427586+00', 'Flett, Stanley', '', 'Stanley Flett', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11596, '2018-01-30 01:25:09.504983+00', '2018-01-31 00:56:20.959681+00', 'Oldsen, Lars and Riekje', '', 'Lars and Riekje Oldsen ', 'Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11487, '2017-05-29 07:34:14.120372+00', '2022-07-06 23:45:23.955074+00', 'Zhdanova, Olga', '', 'Olga Zhdanova', 'Kirov, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3419, NULL, '2017-08-23 18:43:37.116803+00', 'Macfarlane, Peter', '', 'Peter Macfarlane', 'Addison, VT, USA', 'mail@ottercreeksmallcraft.com', 0, 0, 1, 1, NULL, 0, 0, NULL, 'Peter Macfarlane grew up in the United Kingdom, where he developed his characteristic Scottish fiddle style. There he played regularly for Scottish dances and weddings, including performing in Continental Europe.



During this time he also recorded the CD "Invercauld" (2003) together with Lilian Linden on the Piano.



The collaboration with Lilian Linden ended when Peter emigrated to Vermont, USA in 2003.



Together with Viveka Fox, Aaron Marcus and Hollis Easter he plays in the band <<http://www.frostandfireband.com/|Frost and Fire>> that was formed in 2010 and is playing for Scottish, contra and other dances.



In addition, Peter is the co-founder and musical director of the <<http://www.cvsfc.org|Champlain Valley Scottish Fiddle Club>>.');
INSERT INTO 'person' VALUES (3806, NULL, '2017-07-28 03:52:57.131674+00', 'Nelson, Steve & Rollins, Walter ''Jack''', '', 'Steve Nelson & Walter ''Jack'' Rollins', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Wrote together the song <<https://en.wikipedia.org/wiki/Frosty_the_Snowman|Frosty the Snowman>>');
INSERT INTO 'person' VALUES (11511, '2017-07-28 03:34:56.276689+00', '2017-07-28 04:00:42.226869+00', 'Rollins, Walter ''Jack''', '', 'Walter ''Jack'' Rollins', 'Keyser, USA', '', 0, 0, 1, 0, NULL, 1909, 1973, NULL, '');
INSERT INTO 'person' VALUES (10209, NULL, '2017-07-27 16:28:04.452146+00', 'Glencraig Scottish Dance Band, The', 'Glencraig', 'The Glencraig Scottish Dance Band', 'Pitlochry, Scotland', '', 0, 0, 0, 1, NULL, 1983, 0, NULL, 'Nicol McLaren formed The Glencraig Scottish Dance Band in 1983.



Line-ups on different CDs:



- "The Sunday Class Christmas CD" (2016):

Nicol McLaren (lead accordion),

Neil Caul (2nd accordion),

Gordon Howe (fiddle),

Isobelle Hodgson (piano),

John Sinton (double bass),

David Bell (drums) and

Alex Hodgson (bells &amp; whistles)



- "Old Time Dances - Ah''m Dancin''" (2012): 

Nicol McLaren (lead accordion), 

Gordon Howe (fiddle), 

Neil Caul (second accordion), 

Isobelle Hodgson (piano),

John Sinton (double bass) and 

Robert Simpson (drums).



- "Scottish Country Dances - Ah''m Askin''" (2010):

Nicol McLaren (lead accordion), 

Gordon Howe (fiddle), 

Neil Caul (2nd accordion), 

Isobelle Hodgson (piano), 

John Sinton (bass) and 

David Bell (drums).



- "RSCDS Book 20" (2008):

Nicol McLaren (lead accordion), 

Neil Caul (2nd accordion),

Gordon Howe (fiddle), 

David Bell (drums),

Isobelle Hodgson (piano) and

John Sinton (double bass).



- "The Reel Party - Are Ye Askin''?" (2007): 

Nicol McLaren (lead accordion), 

Isobelle Hodgson (piano), 

Gordon Howe (fiddle), 

Neil Caul (2nd accordion), 

John Sinton (double bass) and 

David Bell (drums).



- "The Glencraig Scottish Dance Band - The Ceilidh - Are Ye Dancin''?" (2006): 

Nicol McLaren (lead accordion), 

Isobelle Hodgson (piano), 

Davie Bell (drums), 

Gordon Howe (fiddle), 

Neil Caul (2nd accordion) and 

John Sinton (double bass). 



- "Clashmadin Volume One" (2000):

Nicol McLaren (accordion), 

Neil Caul (accordion), 

Gordon Howe (fiddle), 

Maureen Rutherford (piano), 

David Bell (drums) and 

Suzanne Croy (bass).



- "Note ''n'' Away" (1998):

Nicol McLaren (accordion), 

Neil Caul (accordion), 

Maureen Rutherford (piano, vocals), 

Gordon Howe (fiddle), 

Suzanne Gray (bass) and 

David Bell (drums).



- "Craigievar Dances" (1997):

Nicol McLaren (accordion), 

Neil Caul (accordion), 

Maureen Rutherford (piano), 

Gordon Howe (fiddle), 

Suzanne Gray (bass) and 

David Bell (drums)



');
INSERT INTO 'person' VALUES (11513, '2017-07-28 03:39:11.538321+00', '2017-07-28 04:03:17.174293+00', 'Haldeman, Oakley', '', 'Oakley Haldeman', 'Mesa, USA', '', 0, 0, 1, 0, NULL, 1909, 1986, NULL, '');
INSERT INTO 'person' VALUES (11568, '2017-11-24 16:00:24.603131+00', '2020-01-19 21:57:33.783733+00', 'Robertson, Ian & Johnstone, Muriel', '', 'Ian Robertson & Muriel Johnstone', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'Ian Roberton is playing Accordion and Fiddle, while Muriel Johnstone plays piano and bass.');
INSERT INTO 'person' VALUES (11496, '2017-06-16 16:00:36.580254+00', '2021-05-08 22:47:14.906623+00', 'McIntosh, Edmund', '', 'Edmund McIntosh', 'Cambridge, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11503, '2017-06-18 16:20:42.76883+00', '2021-09-06 20:05:41.380145+00', 'Lajoie, Suzanne', '', 'Suzanne Lajoie', 'Eastern Passage, NS, Canada', '', 1, 0, 0, 0, NULL, 0, 2019, NULL, '');
INSERT INTO 'person' VALUES (11510, '2017-07-27 16:27:02.157568+00', '2017-07-27 23:56:11.359141+00', 'Hodgson, Isobelle', '', 'Isobelle Hodgson', 'Pitlochry, Scotland', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11512, '2017-07-28 03:38:44.484378+00', '2017-07-28 04:05:06.081721+00', 'Autry, Gene', '', 'Gene Autry', 'Los Angeles, USA', '', 0, 0, 1, 0, NULL, 1907, 1998, NULL, '');
INSERT INTO 'person' VALUES (11572, '2017-12-01 16:00:38.597598+00', '2017-12-01 16:22:58.931757+00', 'Gurtner, Roger', '', 'Roger Gurtner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11156, '2015-07-19 12:57:52.623038+00', '2017-07-28 04:17:26.514831+00', 'Handel, George Frideric', 'G F Handel', 'George Frideric Handel', 'London, UK', '', 0, 0, 1, 0, NULL, 1685, 1759, NULL, 'George Frideric (or Frederick) Handel born as Georg Friedrich H&auml;ndel was a German and later British baroque composer.');
INSERT INTO 'person' VALUES (11539, '2017-10-28 19:56:59.809937+00', '2017-10-28 23:56:10.017184+00', 'Groß, Thomas', '', 'Thomas Groß', 'Chemnitz, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11514, '2017-08-03 16:57:43.533443+00', '2017-08-05 23:56:23.330526+00', 'Stern, Ulla', '', 'Ulla Stern', 'Breetz, Germany', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11541, '2017-10-28 19:58:03.977215+00', '2017-10-28 23:56:20.80616+00', 'Schrader-Ladewig, Gabriele', '', 'Gabriele Schrader-Ladewig', 'Chemnitz, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (104, NULL, '2017-08-21 12:51:27.304109+00', 'Dix, Ann', '', 'Ann Dix', '', '', 1, 1, 0, 0, NULL, 1942, 2013, NULL, 'Ann Dix was awarded the RSCDS Scroll of Honour, which was proclaimed at the Society AGM on Saturday November 2nd, 2013, unfortunately the day after her death. 





In St Andrews there is a park bench in Kinburn Park, close to the St Andrews Museum, that is dedicated to the memory of Ann Dix. It states: <em>"In fond memory of Ann Dix (1942-2013), much loved by her sons Simon and Tim, her family and her friends. Her enthusiasm and thoughtfulness will be missed by all, including her many Scottish country dancing friends here and around the world."</em>

There are two pictures of the bench in the <<http://rscds-bhs.org.uk/gallery.html|photo gallery>> of the <<http://rscds-bhs.org.uk/|Berks/Hants/Surrey Border Branch>> webpage.');
INSERT INTO 'person' VALUES (11570, '2017-11-26 19:56:27.539686+00', '2017-11-27 00:56:14.928629+00', 'Lehmann, Viktor', '', 'Viktor Lehmann', 'Heidelberg, DE', '', 1, 0, 0, 0, NULL, 1967, 0, NULL, '');
INSERT INTO 'person' VALUES (11571, '2017-11-27 18:40:13.41013+00', '2017-11-27 18:40:13.41013+00', 'Deep Cove Scottish Country Dance Club, The', 'Deep Cove SCD Club', 'The Deep Cove Scottish Country Dance Club', 'North Vancouver, BC', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11579, '2017-12-19 00:05:39.519779+00', '2017-12-19 00:56:19.002711+00', 'Pirie, P/M James Warden', '', 'P/M James Warden Pirie', '', '', 0, 0, 1, 0, NULL, 1904, 0, NULL, '');
INSERT INTO 'person' VALUES (11573, '2017-12-01 16:27:15.905674+00', '2017-12-01 16:27:15.905674+00', 'Beeson, Pauline and Gurtner, Roger', 'P. Beeson and R. Gurtner', 'Pauline Beeson and Roger Gurtner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11574, '2017-12-01 16:31:02.281872+00', '2017-12-01 16:31:02.281872+00', 'Evans, Keith', '', 'Keith Evans', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11576, '2017-12-09 18:14:01.546071+00', '2017-12-09 18:14:01.546071+00', 'Wheater, Laura', '', 'Laura Wheater', 'New Jersey, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11577, '2017-12-18 16:00:25.178954+00', '2017-12-18 16:00:25.178954+00', 'Paterson-Traxler, Gwen', '', 'Gwen Paterson-Traxler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11578, '2017-12-18 21:19:51.036644+00', '2017-12-18 21:19:51.036644+00', 'Pot, Tiny', '', 'Tiny Pot', 'Roosendaal, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10435, NULL, '2018-10-17 21:59:53.999311+00', 'Dickson, Ian', '', 'Ian Dickson', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11528, '2017-09-26 21:17:23.491695+00', '2018-08-17 22:06:47.58074+00', 'Kislukhina, Evgeniya', '', 'Evgeniya Kislukhina', 'Moscow, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11593, '2018-01-19 13:52:56.629379+00', '2018-01-20 00:56:13.212436+00', 'Heidelberg SchloB Dancers', '', 'Heidelberg SchloB Dancers', 'Heidelberg, Germany', '', 1, 1, 0, 0, NULL, 1988, 0, NULL, 'The name relates to the many tourist coming to Heidelberg and wanting to see Heidelberg Castle (Heidelberger Schlo&szlig;). If they cannot find their way there, you often get asked "Could you tell me where the SchloB is?" - not being aware that the ''&szlig;'' ist not a ''B'' but should in fact be pronounced like ''ss''.



...often an obvious answer would be: "If you look up from your map you could actually see it..."');
INSERT INTO 'person' VALUES (1199, NULL, '2018-05-19 15:54:20.195755+00', 'Agnew, Peter', '', 'Peter Agnew', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '“A house-painter to trade, and a poet by chance, Peter Agnew was a native of Perth, and lived in the South Street in 1793. Very early in life he gave evidence of being possessed of rare musical talent, and learned to play on the violin, an instrument over which he soon obtained an almost complete mastery, and with which he lived to charm the ills of many a luckless day. On the completion of his ''prentice time Agnew went to Glasgow, and from thence, in a few years, to London, from whence he again, after a few more years, returned to the commercial capital of his native Caledonia, where he wore out the bulk of his after-lease. His life appears to have been a somewhat chequered one, the grim visage of poverty frequently staring him in the face, and, if not actually sconcing herself at his fireside, being represented there on an occasion by her foster-friend, the beagle. An excellent violinist, a fair landscape painter, a capital singer of songs, a pleasing writer of verses, and an entertaining story-teller, perhaps Peter Agnew had too many accomplishments to be eminently successful in any.”  – Robert Ford, *The Harp of Perthshire* (1893)');
INSERT INTO 'person' VALUES (11586, '2018-01-13 18:54:08.503598+00', '2022-07-06 23:45:05.809998+00', 'Zhubrina, Svetlana', '', 'Svetlana Zhubrina', 'Kirov, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11515, '2017-08-23 16:11:23.99335+00', '2017-08-24 09:48:47.73178+00', 'Frost and Fire', '', 'Frost and Fire', 'Burlington, VT, USA', 'booking@frostandfireband.com', 0, 0, 0, 0, NULL, 2010, 0, NULL, 'Viveka Fox, Peter Macfarlane, Aaron Marcus and Hollis Easter are the members of the band "Frost and Fire". Having played informally together on stage in 2010, the band was actually formed in 2011. They play for Scottish, contra and other dances. "Frost and Fire" is based in Burlington, Vermont in the US.





The following information is taken from the <<http://www.frostandfireband.com/bio/|band''s webpage>>:



Frost and Fire began taking shape in July 2010 at the Champlain Valley Folk Festival in Burlington, VT. Viveka and Peter invited Aaron and Hollis to join them on stage, and as the dancers whirled and cheered, their shared energy kindled this new collaboration. As winter swept across the North, we stayed in touch, thinking about tunes and new directions.



Fast forward to the blazing summer heat of 2011, which found us on stage making music drawn from all points of the compass, our faces lit with joy and laughter, surrounded by dancers aflame with energy. At the band’s first gig in Rochester, VT, the dancing ran long into the evening–neither dancers nor band were ready for the music to stop.



Frost and Fire takes its name from T. S. Eliot’s Quartet 4, Little Gidding:



   <P><EM>“Midwinter spring is its own season

    <BR>Sempiternal though sodden towards sundown,

    <BR>Suspended in time, between pole and tropic.

    <BR>When the short day is brightest, with frost and fire,

    <BR>The brief sun flames the ice, on pond and ditches,

    <BR>In windless cold that is the heart’s heat,

    <BR>Reflecting in a watery mirror

    <BR>A glare that is blindness in the early afternoon.

    <BR>And glow more intense than blaze of branch, or brazier,

    <BR>Stirs the dumb spirit: no wind, but pentecostal fire

    <BR>In the dark time of the year. Between melting and freezing

    <BR>The soul’s sap quivers.”</EM></P>');
INSERT INTO 'person' VALUES (3749, NULL, '2017-08-23 22:01:48.265909+00', 'Invercauld Scottish Dance Band', 'Invercauld Band', 'Invercauld Scottish Dance Band', 'Jersey, Channel Islands', '', 0, 0, 0, 1, NULL, 1997, 0, NULL, 'Some information from the band''s webpage and other sources:



The Invercauld Scottish Dance Band consists of Lilian Linden (piano) and friends (fiddles, accordion, drums).



In October 1997, Lilian Linden formed a Scottish dance band (now called the Invercauld Scottish Dance Band). The band has played for Scottish Country Dances and Balls, New Year''s Eve Dances, St Andrew''s Nights, Burns'' Nights, Weddings, Ceilidhs, Concerts, Charity Dances, and other fund-raising events, as well as Reeling Dances for Reelers, Parties and other functions with a Scottish flavour.



At some point it came to choosing a name for the band. The name "The Invercauld Scottish Dance Band" relates to Lilian''s Scottish ancestors, the Farquharsons of Invercauld, which have been traced back to the sixteenth century, to the start of the Farquharson Clan.



The line-up  Peter Macfarlane / Lilian Linden can be seen in the continuity from beginnings in 1997 to the Invercauld Scottish Dance Band, as the CD recorded by the two musicians already carries the catalog number "Invercauld001". The collaboration with Peter Macfarlane ended when he emigrated to the US in 2003.



The band has previously played extensively in and around London, Surrey, Hampshire and the Home Counties, and occasionally in Oxford, Cambridge, Kent, Sussex and Wiltshire. They have also played further afield in the UK and Europe, including Scotland, Belgium, Luxembourg, Norway, Guernsey and Jersey.



Since summer 2009 Lilian and the Invercauld Scottish Dance Band are based and play in Jersey in the Channel Islands, since Lilian''s move back there. However, the band will also continue to play in the UK and further afield.');
INSERT INTO 'person' VALUES (11518, '2017-08-26 23:41:21.169453+00', '2017-08-26 23:56:08.486342+00', 'Craib, Billy', '', 'Billy Craib', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11517, '2017-08-26 23:18:20.884529+00', '2017-08-26 23:56:24.527027+00', 'Siozade, Raymond', '', 'Raymond Siozade', '', '', 0, 0, 1, 0, NULL, 1930, 1986, NULL, '');
INSERT INTO 'person' VALUES (493, NULL, '2017-08-28 10:35:41.320559+00', 'Stephens, Graeme', '', 'Graeme Stephens', 'Kirkcaldy, Scotland', '', 1, 0, 0, 0, NULL, 0, 1994, NULL, 'Obituary published in RSCDS Bulletin 73, 1995');
INSERT INTO 'person' VALUES (11519, '2017-08-31 10:16:14.610741+00', '2017-08-31 21:59:29.147101+00', 'Osborne, John', '', 'John Osborne', 'Orpington & District Caledonian Society', '', 1, 0, 0, 0, NULL, 0, 2017, NULL, '');
INSERT INTO 'person' VALUES (11523, '2017-09-11 22:53:30.395177+00', '2017-09-11 23:56:24.022082+00', 'Weitzel, Norbert', '', 'Norbert Weitzel', 'Heidelberg, DE', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11532, '2017-09-26 23:28:45.015227+00', '2018-12-12 11:37:41.365522+00', 'Kovaleva, Anna', '', 'Anna Kovaleva', 'Moscow, Russia', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11525, '2017-09-24 14:59:26.687345+00', '2017-09-24 15:01:26.82444+00', 'Fairbairn, James', '', 'James Fairbairn', 'The Caledonian Club, Belgravia, London', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11529, '2017-09-26 21:40:09.479435+00', '2017-09-26 23:56:03.4852+00', 'Beylinson, Julia', '', 'Julia Beylinson', 'Nizhniy Novgorod, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11531, '2017-09-26 23:12:00.113565+00', '2017-09-26 23:56:03.906878+00', 'Bochkova, E', '', 'E Bochkova', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11530, '2017-09-26 23:03:34.71063+00', '2017-09-26 23:56:08.609408+00', 'Foreman, David', '', 'David Foreman', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11527, '2017-09-26 21:15:45.66051+00', '2017-09-26 23:56:09.099021+00', 'Garbuzov, Vladimir', '', 'Vladimir Garbuzov', 'Nizhniy Novgorod, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11526, '2017-09-26 20:53:04.046362+00', '2017-09-26 23:56:19.258436+00', 'Quick Scotch', '', 'Quick Scotch', 'Nizhniy Novgorod, Russia', '', 0, 1, 0, 0, NULL, 2009, 0, NULL, 'The Russian Scottish country dance group Quick Scotch was founded in 2009.



Since then they have organized a number of dancing events that inspired them to devise some of the dances included in this book "Book of Records".');
INSERT INTO 'person' VALUES (1650, NULL, '2017-09-27 23:56:08.064707+00', 'Doig, Alex', '', 'Alex Doig', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, 'Alex Doig was a drummer who played with Jim MacLeod’s Dance Band in the 1970s. 



He composed tunes like "Tam O'' Shanter" (but there is more that one tune with that name). 



John Drewry dedicated a dance to him that is called "Alex Doig''s Jig", but which is also know as "The Dunblane Drummer". Furthermore, there is tunes carying his name ("Alex Doig''s Jig").');
INSERT INTO 'person' VALUES (2390, NULL, '2017-09-27 03:46:47.641398+00', 'Sinton, John', '', 'John Sinton', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, 'John Sinton played double bass in Jim Macleod''s band.



John Drewry has dedicated a dance to him, "The Big Fiddle".');
INSERT INTO 'person' VALUES (11533, '2017-10-01 19:48:43.063892+00', '2017-10-01 23:56:16.568949+00', 'McLaughlin, Anne', '', 'Anne McLaughlin', 'Hot Springs, NC USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11536, '2017-10-20 16:10:18.101914+00', '2017-10-20 16:10:18.101914+00', 'Bollett', '', 'Professor Bollett', 'Sydney Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11535, '2017-10-20 12:22:52.349271+00', '2017-10-20 23:56:10.18179+00', 'HarperCollins Publishers', 'HarperCollins', 'HarperCollins Publishers', 'Glasgow, UK', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11538, '2017-10-22 22:14:25.411232+00', '2017-10-22 22:14:25.411232+00', 'Maclellan, William', '', 'William Maclellan', 'Glasgow, Scotland', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11580, '2017-12-24 07:56:53.144566+00', '2017-12-25 00:56:25.086845+00', 'Tayside Country Dance Group', '', 'Tayside Country Dance Group', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11588, '2018-01-14 17:08:41.751358+00', '2018-01-14 17:08:41.751358+00', 'Harris, Isobel and Cameron, Ashlee', '', 'Harris, I and Cameron, A', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11589, '2018-01-14 17:17:32.628143+00', '2018-01-14 17:17:32.628143+00', 'McMurtry, Margaret', '', 'Margaret McMurtry', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11590, '2018-01-14 17:22:31.719393+00', '2018-01-14 17:22:31.719393+00', 'Lindsay, Sue', '', 'Sue Lindsay', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (135, NULL, '2018-01-16 00:13:15.753786+00', 'Fryer, Cliff', '', 'Cliff Fryer', 'Harrow, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Cliff Fryer was HDCS (Harrow and District Caledonian Society) President in 1989-90, 1990-91, 1995-96, 2003-04');
INSERT INTO 'person' VALUES (11591, '2018-01-18 22:37:43.050569+00', '2018-01-19 00:56:24.941241+00', 'Scottish Dance Group of Monaco', '', 'Scottish Dance Group of Monaco', 'Monaco', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11522, '2017-09-05 20:49:05.336499+00', '2022-08-21 23:56:39.81257+00', 'McLellan, John', '', 'John McLellan', 'Pretoria, S. Africa', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1382, NULL, '2018-07-31 13:03:25.770861+00', 'Torfason, Louis (Torf)', '', 'Torf', 'Austin, Texas', 'torf@io.com', 1, 0, 0, 0, NULL, 0, 2018, NULL, 'Louis Torfason typically only uses his nickname Torf to sign his dances.



Unfortunately, Torf died in morning of 24 July 2018.



Torf got a Branch Award by the Houston + District Branch during the term 2012-2013.');
INSERT INTO 'person' VALUES (11598, '2018-02-08 20:14:14.137496+00', '2018-02-08 20:21:03.334211+00', 'Rose, Brian', '', 'Brian Rose', 'Berkhamsted, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11599, '2018-02-15 17:11:50.318598+00', '2018-02-16 00:56:14.563052+00', 'Jacques, Abraham', '', 'Abe Jacques', 'Charlotte, NC, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11700, '2018-08-30 09:18:57.107379+00', '2018-08-30 09:18:57.107379+00', 'Orgeret, Christiane', '', 'Christiane Orgeret', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11721, '2018-09-30 14:43:59.14471+00', '2018-09-30 17:48:59.912394+00', 'Neill, Elizabeth', '', 'Elizabeth Neill', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3617, NULL, '2018-09-18 22:24:36.686288+00', 'Lieberman, Linda', '', 'Linda Lieberman', 'USA  RSCDS Central Iowa Branch', '', 1, 0, 1, 0, NULL, 0, 0, NULL, 'Also known as Linda Lewis Lieberman.');
INSERT INTO 'person' VALUES (11715, '2018-09-18 22:31:22.065736+00', '2018-09-18 22:31:22.065736+00', 'Hawkins, Matt', '', 'Matt Hawkins', 'Alabama, USA', '', 0, 0, 0, 0, NULL, 0, 0, NULL, 'Matt Hawkins, who is now a space scientist in Huntsville, Al. He was a fine leader while at ISU of the Celtic Dance Society and a regular at all Scottish events, English Country dance, and contra dance.');
INSERT INTO 'person' VALUES (11723, '2018-10-05 19:32:36.140443+00', '2018-10-05 23:56:12.254727+00', 'Hayburn, Gordon', '', 'Gordon Hayburn', 'Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11710, '2018-09-18 16:22:31.977331+00', '2018-09-18 23:56:12.046884+00', 'Harrington, Charlie', '', 'Charlie Harrington', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11714, '2018-09-18 22:23:17.005964+00', '2018-09-18 23:56:12.360772+00', 'Hawkins, Matt', '', 'Matt Hawkins', 'Alabama, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Matt Hawkins, who is now a space scientist in Huntsville, Al. He was a fine leader while at ISU of the Celtic Dance Society and a regular at all Scottish events, English Country dance, and contra dance.');
INSERT INTO 'person' VALUES (11712, '2018-09-18 20:08:56.012441+00', '2018-09-18 23:56:23.002343+00', 'RSCDS Central Iowa Branch', 'RSCDS Iowa ', 'RSCDS Central Iowa Branch', 'USA,  Central Iowa ', '', 1, 1, 0, 0, NULL, 1991, 0, NULL, '');
INSERT INTO 'person' VALUES (11709, '2018-09-18 16:18:04.11181+00', '2018-09-19 07:58:13.988816+00', 'Mattingly, Andrea', '', 'Andrea Mattingly', 'USA  RSCDS Central Iowa Branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11716, '2018-09-18 23:08:27.060427+00', '2018-09-19 08:45:44.250474+00', 'Droessler Meyer, Sue', '', 'Sue Droessler Meyer', 'USA  RSCDS Central Iowa Branch', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11719, '2018-09-25 11:07:49.203631+00', '2018-09-25 23:56:05.194415+00', 'Briggs, Michael & Norma', '', 'Michael & Norma Briggs', 'Wisconsin, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11720, '2018-09-28 19:30:46.896681+00', '2018-09-28 23:56:12.322615+00', 'Herman, Dorothee', '', 'Dorothee Herman', 'Tübingen, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (993, NULL, '2018-10-12 18:52:04.373161+00', 'Lyon, Maureen', '', 'Maureen Lyon', 'White Rock Scottish Country Dance Club, Surrey, BC.  ', 'plyon1@telus.net', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11724, '2018-10-06 13:42:18.676661+00', '2018-10-10 22:40:12.847368+00', 'Johnston, Renée', '', 'Renée Johnston', 'Dundee, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11725, '2018-10-12 14:20:30.432747+00', '2018-10-12 14:21:19.330311+00', 'Besant, Mabel J', '', 'Mabel J Besant', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11726, '2018-10-12 15:37:26.723843+00', '2018-10-12 15:37:26.723843+00', 'Carpenter, T', '', 'T Carpenter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11722, '2018-09-30 15:40:53.823791+00', '2018-10-13 20:29:16.492034+00', 'Russell, Ron', '', 'Ron Russell', 'Taunton Caledonian Society', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11362, '2016-09-16 13:32:58.142665+00', '2019-08-06 20:03:18.165891+00', 'Ogburn, William', '', 'William Ogburn', 'NYC, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2948, NULL, '2018-10-15 23:56:21.519858+00', 'Morrison, Dennis', '', 'Dennis Morrison', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11732, '2018-10-15 15:09:44.314554+00', '2018-10-15 23:56:29.004987+00', 'Thomson, Helen', '', 'Helen Thomson', 'RSCDS Branch Herefordshire', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11733, '2018-10-17 00:05:02.518381+00', '2018-10-17 23:56:29.289532+00', 'Williams, Stuart', '', 'Stuart Williams', 'RSCDS Wirral', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11734, '2018-10-18 15:26:18.400606+00', '2018-10-19 23:56:13.921691+00', 'Inglis, Flora', '', 'Flora Inglis', 'RSCDS Branch Herefordshire', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11735, '2018-10-19 13:44:56.296578+00', '2018-10-19 23:56:10.513+00', 'Gambling, Maurice and Kolodziejczyk, Kim', '', 'Maureen Gambling and Kim Kolodziejczyk', 'RSCDS Cheshire', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11728, '2018-10-12 20:04:58.72085+00', '2018-10-27 23:56:23.155588+00', 'Paterson-Traxler, Gwen and Reiser, Meinhard', '', 'Gwen Paterson-Traxler and Meinhard Reiser', 'Stuttgart, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11727, '2018-10-12 20:01:26.070969+00', '2018-10-27 23:56:24.452878+00', 'Reiser, Meinhard', '', 'Meinhard Reiser', 'Stuttgart, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1811, NULL, '2018-11-13 22:41:15.687268+00', 'Pattullo, Gordon', 'Gordon Pattullo', 'Gordon Pattullo', '', '', 0, 1, 1, 1, NULL, 0, 0, NULL, 'NB some sources misspell the name as Patullo.');
INSERT INTO 'person' VALUES (11730, '2018-10-13 21:18:34.326991+00', '2018-12-08 23:30:44.725475+00', 'Warren, Brian', '', 'Brian Warren', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1486, NULL, '2018-08-17 16:49:15.316769+00', 'MacDonald, Malcolm', '', 'Malcolm MacDonald', 'Inver, Perthshire, UK', '', 0, 1, 1, 0, NULL, 1750, 0, NULL, 'This composer and musician was also known as Malcom M’Donald.



Scanned online versions of the four Collections of Strathspey Reels he published between 1788 and likely 1797 are available at <<http://hms.scot/fiddle/author/12/|Historical Music of Scotland (HMS)>>.



Some bibliographical notes from the _Biographical Sketches of Early Scottish Musicians and Musicsellers_ (by John Glen, from a forward to *The Glen Collection of Scottish Dance Music*, Edinburgh, 1891) - here obtained from <<https://tunearch.org/wiki/Biography:Malcolm_MacDonald|Tunearch.org>>:



Malcom M’Donald published four collections of Strathspey Reels, &c. The first of these, as its title-page indicates, was entirely made up of his own exclusive compositions; but the subsequent three contain a number of tunes which are unquestionably the productions of other musicians. Many of the tunes composed by, or attributed to M’Donald, are of that strange wild nature so characteristic of the compositions of Daniel Dow.



Of M’Donald’s personal history little or no authentic information can be obtained. The place of his birth is unknown. His second and subsequent collections, however, bear on them that, at the time of their appearance, he resided “at Dunkeld.” The present editor has been informed that his residence was at Inver, in the Parish of Little Dunkeld; and in the list of Subscribers to Niel Gow’s Second Collection, we find the entry “Mr. Malcolm Macdonald, Inver.”



In a footnote appended to M’Donald’s Reel “Lady Haddo,” in Part II of The Beauties of Niel Gow (a work published by Nathaniel Gow), we are informed that M’Donald played the violoncello to Niel after the death of the latter’s brother Donald Gow.



M’Donald is said to have died at Inver, but we can find no record of the date of his death. He is supposed, however, to have predeceased Niel Gow by a few years. The Parish Registers of the locality were burned or otherwise destroyed about the beginning of the present century, for the supposed purpose of preventing information being procured regarding the ages of persons required to join the Volunteers, Fencibles, or Militia of that period. ');
INSERT INTO 'person' VALUES (11739, '2018-10-19 21:17:31.377797+00', '2018-10-19 23:56:25.611085+00', 'Smith, Fran', '', 'Fran Smith', 'RSCDS Hereford', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11737, '2018-10-19 15:14:10.01655+00', '2018-10-20 17:31:28.164344+00', 'Robinson, John and Mainwaring, Pat', '', 'Pat Mainwaring and John Robinson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (344, NULL, '2018-10-24 20:56:15.648325+00', 'Scottish National Dance Company', 'SNDC', 'Scottish National Dance Company', 'Reading, UK', '', 0, 1, 0, 0, NULL, 0, 2010, NULL, 'The SNDC (Scottish National Dance Company) offered Scottish Dance descriptions, books and music by mail order, world wide.



Unfortunately, the shop was closed down in 2010. The remaining stock was sold in a clearance sale about October/November 2010.



Hence, the old web page (http://www.sndc.co.uk/) and old email address (kelpi@sndc.i-way.co.uk) of the SNDC is not active anymore.');
INSERT INTO 'person' VALUES (11269, '2016-06-19 09:56:29.185962+00', '2018-10-25 23:56:12.614826+00', 'Harwell Scottish Country Dance Club', 'Harwell SCDC', 'Harwell SCDC', 'Harwell, UK', '', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Harwell Caledonian Society became Harwell Scottish Country Dance Club');
INSERT INTO 'person' VALUES (10748, '2013-02-06 11:09:58.554169+00', '2018-10-26 20:29:11.631116+00', 'Stirrat, George and his Scottish Dance Band', 'George Stirrat', 'George Stirrat and his Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (188, NULL, '2018-10-28 10:35:48.038197+00', 'Hunter Valley Branch RSCDS', '', 'Hunter Valley Branch RSCDS', 'Australia', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10489, NULL, '2018-10-29 16:41:20.520359+00', 'Tokyo Scottish Bluebell Club', '', 'Tokyo Scottish Bluebell Club', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11774, '2019-01-17 19:51:57.289732+00', '2019-01-17 19:51:57.289732+00', 'Axford, Joan', '', 'Joan Axford', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11770, '2019-01-17 09:40:16.612359+00', '2019-01-18 00:56:03.913622+00', 'Beaver, Sue', '', 'Sue Beaver', 'Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10912, '2014-01-06 00:50:18.453443+00', '2018-10-29 16:43:21.010471+00', 'Freemantle, Reuben', '', 'Reuben Freemantle', 'Newbury, Berkshire RG14.', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Reuben Freemantle is the publisher of <<http://www.scottish-country-dancing-dictionary.com|Scottish Country Dancing Dictionary>> and the author of the MaxiCrib Dance Instructions in there.');
INSERT INTO 'person' VALUES (11303, '2016-07-11 16:05:15.068996+00', '2018-10-29 16:44:17.996611+00', 'Orgeret, Raphaëlle', '', 'Raphaëlle Orgeret', 'Lyon, France', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2847, NULL, '2018-10-30 10:37:58.626046+00', 'Girards, Anja', '', 'Anja Girards', 'Cologne, Germany', 'anja.breest@girards.de', 1, 0, 0, 0, 10647, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11742, '2018-10-30 22:19:59.740598+00', '2018-10-30 22:27:31.46165+00', 'Nelson, Sidney', '', 'Sidney Nelson', '', '', 0, 0, 1, 0, NULL, 1800, 1862, NULL, 'https://en.wikipedia.org/wiki/Sidney_Nelson');
INSERT INTO 'person' VALUES (10585, NULL, '2018-12-07 17:39:01.059111+00', 'Hodgson, Andrew and McBurnie, Heather', 'H. McBurnie and A. Hodgson', 'Heather McBurnie and Andrew Hodgson', 'South Africa', 'andrew@hodgson.za.net', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11743, '2018-11-09 18:37:52.623784+00', '2018-11-10 00:56:36.18178+00', 'Pasadena Recorders', 'Pasadena Recorders', 'Pasadena Recorders', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11744, '2018-11-10 13:30:31.373762+00', '2018-11-11 00:56:14.439542+00', 'Hodgson, Val', '', 'Val Hodgson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1916, NULL, '2018-11-13 23:19:54.993684+00', 'Kerr, James S', '', 'James S Kerr', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, 'See http://www.nigelgatherer.com/books/kerr/kmm.html for lists of tunes in the various Kerr publications.');
INSERT INTO 'person' VALUES (11745, '2018-11-15 00:20:49.217109+00', '2018-11-15 00:56:16.682617+00', 'Hart, Peter', '', 'Peter Hart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Nom-de-plume for Frederik Peter Hargreaves (according to https://www.discogs.com/artist/681488-Peter-Hart).');
INSERT INTO 'person' VALUES (10616, '2012-05-01 22:15:48.50048+00', '2018-12-07 17:39:20.367311+00', 'Rae, Isabel and Macrae, Margaret', '', 'Isabel Rae and Margaret MacRae', 'West Lothian, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Consists of Isabel Rae and Margaret MacRae');
INSERT INTO 'person' VALUES (11746, '2018-11-20 23:29:55.909593+00', '2018-11-22 00:56:07.070709+00', 'Clarkson, John (senior)', '', 'John Clarkson (senior)', '', '', 0, 1, 1, 0, NULL, 0, 1812, NULL, '');
INSERT INTO 'person' VALUES (11748, '2018-11-23 18:01:02.186239+00', '2018-11-24 00:56:15.369979+00', 'Innes-Russell, W & Williamson, John', '', 'W Innes-Russell & John Williamson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11747, '2018-11-23 17:56:08.70857+00', '2018-11-24 00:56:30.923681+00', 'Williamson, John', '', 'John Williamson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10650, '2012-09-02 21:23:56.318467+00', '2018-12-07 17:39:51.37231+00', 'Derek''s Composition Class 2003/1', 'Class 2003/1', 'Derek''s Composition Class 2003/1', 'Summer School', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'A group from Derek Haynes composition class at Summer School, St Andrews, 1st week 2003');
INSERT INTO 'person' VALUES (11168, '2015-07-31 14:22:31.279149+00', '2018-12-19 16:55:08.471163+00', 'Members of Tucson Branch and Seven Pipers Scottish Society country dance class', 'Tucson Branch & Seven Pipers Scottish Society', 'Members of Tucson Branch and Seven Pipers Scottish Society C.D. class', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11750, '2018-12-03 15:54:24.243214+00', '2018-12-04 00:56:16.717199+00', 'Imrie, Alex', '', 'Alex Imrie', 'Dunf', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11751, '2018-12-03 15:58:22.690848+00', '2018-12-04 00:56:28.158607+00', 'Shearer, Margaret', '', 'Margaret Shearer', 'Dunfermline', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11752, '2018-12-03 16:01:35.838523+00', '2018-12-04 00:56:31.498576+00', 'Welch, Sandra', '', 'Sandra Welch', 'Dunfermlineermline', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1447, NULL, '2018-12-06 19:04:09.095194+00', 'Surenne, John Thomas', '', 'John Surenne', '', '', 0, 0, 1, 0, NULL, 1814, 1878, NULL, 'In issue 1329 (http://my.strathspey.org/dd/issue/1329/) Finlay Forbes describes Surenne as a collector rather than a composer.');
INSERT INTO 'person' VALUES (11755, '2018-12-06 12:26:11.007269+00', '2018-12-07 00:56:09.416004+00', 'Cullen, Linda', '', 'Linda Cullen', 'Dunfermline', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11757, '2018-12-06 12:30:48.413671+00', '2018-12-07 00:56:15.854394+00', 'Hewitt, Fhi', '', 'Fhi Hewitt', 'Dunfermline', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11759, '2018-12-06 13:01:41.480404+00', '2018-12-07 00:56:17.380666+00', 'Johnston, Janet', '', 'Janet Johnston', 'Stirling', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11845, '2019-07-25 09:46:49.999245+00', '2019-07-25 10:38:42.976679+00', 'Hanson, Agne', '', 'Agne Hanson', 'Stockholm, Sweden', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11758, '2018-12-06 12:32:44.994155+00', '2018-12-07 00:56:31.580746+00', 'Stephen, Moira', '', 'Moira Stephen', 'West Lothian', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10951, '2014-05-08 08:42:55.021122+00', '2018-12-07 09:23:20.219368+00', 'Rose, Keith', '', 'Keith Rose', 'Bedford, UK', 'keith@krose.plus.com', 1, 0, 0, 0, NULL, 1950, 0, NULL, '');
INSERT INTO 'person' VALUES (3736, NULL, '2018-12-07 17:36:02.885447+00', 'Peutherer et al., Marion', '', 'Marion Peutherer et al.', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Ginette & Peter Cass, Marion & Brian Peutherer and Zoë Thirlaway,

Newcastle Reelers.');
INSERT INTO 'person' VALUES (10853, '2013-09-12 11:15:41.458275+00', '2018-12-08 10:15:36.749104+00', 'Reungsuwan, Urisa', '', 'Urisa  Reungsuwan', 'Pretoria', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11119, '2015-04-21 22:03:02.661023+00', '2018-12-08 23:17:50.039474+00', 'Thomson, Irene and Ewan, Margaret', '', 'Irene Thomson and Margaret Ewan', 'edinburgh', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Dance authors of Edinburgh Ladies'' Club in 1996');
INSERT INTO 'person' VALUES (10924, '2014-03-16 14:37:18.302141+00', '2018-12-09 13:44:15.062462+00', 'Nakamura, Hachidai & Rokosuke Ei', 'Nakamura & Ei', 'Hachidai Nakamura & Rokosuke Ei', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11761, '2018-12-10 15:37:56.392755+00', '2018-12-11 00:56:25.853893+00', 'Steiner, Max', '', 'Max Steiner', '', '', 0, 0, 1, 0, NULL, 1888, 1971, NULL, '');
INSERT INTO 'person' VALUES (11762, '2018-12-11 18:13:46.926237+00', '2018-12-11 18:13:46.926237+00', 'Campbell, Peter', '', 'Peter Campbell', 'Greensboro NC, USA', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11763, '2018-12-12 17:20:27.690836+00', '2018-12-12 17:35:27.240012+00', 'Jeffery, Christine', '', 'Christine Jeffery', 'Oxfordshire, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11764, '2018-12-16 00:54:22.353011+00', '2018-12-16 01:18:23.924471+00', 'Hulsroj, Luisa', '', 'Luisa Hulsroj', 'Cambridge, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3699, NULL, '2018-12-14 00:23:44.22041+00', 'McMillan, James A.', '', 'James McMillan', 'Glasgow', '', 1, 1, 0, 0, NULL, 0, 2017, NULL, 'Familiarly known as "Jimmie".');
INSERT INTO 'person' VALUES (11749, '2018-12-03 15:39:07.614748+00', '2018-12-19 00:50:41.138765+00', 'Dunfermline Branch RSCDS', '', 'Dunfermline Branch', 'Dunfermline', '', 0, 1, 0, 0, NULL, 1929, 0, NULL, '');
INSERT INTO 'person' VALUES (11766, '2019-01-04 16:08:19.307783+00', '2019-01-04 16:09:51.198295+00', 'McCourt, Vincent', '', 'Vincent McCourt', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2915, NULL, '2019-01-06 00:04:31.364436+00', 'Macdonald, Lorna & Mackintosh, Gillian', '', 'Lorna Macdonald & Gillian Mackintosh', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Lorna Smith is née Macdonald');
INSERT INTO 'person' VALUES (11756, '2018-12-06 12:28:42.124042+00', '2019-05-13 16:24:24.238628+00', 'Priestley, Margo', '', 'Margo Priestley', 'Edinburgh', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11852, '2019-08-11 20:51:27.11564+00', '2019-08-11 23:56:12.086008+00', 'Harmon, Jan', '', 'Jan Harmon', 'California, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11848, '2019-08-11 20:18:33.570332+00', '2019-08-11 23:56:14.660166+00', 'Kiser, Cynthia', '', 'Cynthia Kiser', 'California, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11853, '2019-08-11 21:01:20.281963+00', '2019-08-11 23:56:20.551773+00', 'Perry, Andy', '', 'Andy Perry', 'California, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2489, NULL, '2019-01-07 15:30:32.587693+00', 'Snowdon, Charles T', '', 'Charles T Snowdon', '', 'snowdon@doit.wisc.edu', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Casual Name:  Chuck');
INSERT INTO 'person' VALUES (11767, '2019-01-10 11:02:56.76529+00', '2019-01-11 00:56:10.013782+00', 'Fisher, Dr A C', '', 'Dr A C Fisher', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11768, '2019-01-10 20:31:38.357639+00', '2019-01-11 00:56:16.552136+00', 'Lockhart, Teresa', '', 'Teresa Lockhart', 'Toronto, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (380, NULL, '2019-04-01 21:33:29.528543+00', 'Teachers Association Canada', '', 'Teachers Association Canada', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11821, '2019-06-14 20:09:53.731288+00', '2019-06-14 20:09:53.731288+00', 'Brahms, Johannes', '', 'Johannes Brahms', '', '', 0, 0, 1, 0, NULL, 1833, 1897, NULL, '');
INSERT INTO 'person' VALUES (11801, '2019-04-06 00:33:14.543581+00', '2019-04-10 22:17:48.034727+00', 'McEdward, Ray', '', 'Ray McEdward', 'San Diego', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11760, '2018-12-06 13:03:42.569821+00', '2020-07-05 09:23:53.769959+00', 'Welch, Sandra', '', 'Sandra Welch', 'Dunfermline', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10583, NULL, '2021-01-02 11:00:32.896189+00', 'Unit 3 class, week 2, S.School 2009', '', 'Unit 3 class of week 2 at the 2009 Summer School', 'Summer School 2009', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11765, '2018-12-16 01:17:58.614457+00', '2022-08-12 09:50:49.648051+00', 'Frisby, Saskia', '', 'Saskia Frisby', 'Cambridge, UK', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11753, '2018-12-03 16:02:59.790309+00', '2022-11-28 00:56:04.870656+00', 'Austin, Alison', '', 'Alison Austin', 'Dunfermline', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11771, '2019-01-17 10:50:10.314131+00', '2019-01-18 00:56:12.022323+00', 'Gray, Gerry', '', 'Gerry Gray', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11772, '2019-01-17 10:51:39.156663+00', '2019-01-18 00:56:22.916836+00', 'Porter, Brenda and Gray, Gerry', '', 'Brenda Porter and Gerry Gray', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11773, '2019-01-17 11:07:58.017354+00', '2019-01-18 00:56:24.315377+00', 'Richards, Ron', '', 'Ron Richards', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11775, '2019-01-22 14:37:48.341015+00', '2019-01-22 14:37:48.341015+00', 'Latour, Anne-Laure', '', 'Anne-Laure Latour', 'Paris, France', '', 0, 0, 1, 0, NULL, 1990, 0, NULL, '');
INSERT INTO 'person' VALUES (2031, NULL, '2019-01-29 22:41:17.896649+00', 'Silverberg, Alice / Rubin, Karl', '', 'Alice Silverberg & Karl Rubin', 'Erlangen, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11777, '2019-01-29 22:40:11.008731+00', '2019-01-29 23:16:38.334703+00', 'Silverberg, Alice', '', 'Alice Silverberg', 'California, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11776, '2019-01-29 12:05:23.251198+00', '2019-01-30 00:56:07.898632+00', 'Dewdney, Andrew', '', 'Andrew Dewdney', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11778, '2019-02-08 11:28:36.605576+00', '2019-02-09 00:56:02.987417+00', 'Barret, Marie-Laure', '', 'Marie-Laure Barret', '', 'marielaure.barret@mail.com', 1, 0, 0, 0, NULL, 1962, 0, NULL, '');
INSERT INTO 'person' VALUES (11779, '2019-02-13 21:17:36.472617+00', '2019-02-13 21:22:29.803567+00', 'Frisa, Gayle', '', 'Gayle Frisa', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10795, '2013-06-14 05:48:15.601418+00', '2019-02-17 08:01:09.827488+00', 'McGinley, Helen', '', 'Helen McGinley', 'Dublin SCD Club and RSCDS International Branch', 'nellifant@ymail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Helen writes:  Helen Bonar was my own name. From August 1995 until November 2012 I was Helen Beaney. In November 2012 I married Jack McGinley and took his name (hence Mrs McGinley''s Strathspey).');
INSERT INTO 'person' VALUES (3517, NULL, '2019-02-17 11:59:27.699794+00', 'Beaney, Helen', '', 'Helen Beaney', 'Dublin SCD Club and RSCDS International Branch', '', 1, 0, 0, 0, 10795, 0, 0, NULL, 'Helen writes: Helen Bonar was my own name. From August 1995 until November 2012 I was Helen Beaney. In November 2012 I married Jack McGinley and took his name (hence Mrs McGinley''s Strathspey).');
INSERT INTO 'person' VALUES (2560, NULL, '2019-02-17 11:59:32.530107+00', 'Bonar, Helen', '', 'Helen Bonar', '', '', 1, 0, 0, 0, 10795, 0, 0, NULL, 'Helen writes: Helen Bonar was my own name. From August 1995 until November 2012 I was Helen Beaney. In November 2012 I married Jack McGinley and took his name (hence Mrs McGinley''s Strathspey).');
INSERT INTO 'person' VALUES (11780, '2019-02-19 15:00:43.850415+00', '2019-02-19 15:00:43.850415+00', 'Cunin, Claire', '', 'Claire Cunin', 'Lyon, France', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11782, '2019-02-20 14:23:17.700827+00', '2019-02-20 14:23:46.676506+00', 'RSCDS Cornwall Branch', '', 'RSCDS Cornwall Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11787, '2019-02-21 00:34:09.940018+00', '2019-02-21 00:56:07.621852+00', 'Cunin, Claire and Jeannerod, Nicolas', '', 'Claire Cunin and Nicolas "Niols" Jeannerod', 'Lyon and Paris', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11789, '2019-02-21 08:59:58.171597+00', '2019-02-21 09:01:18.517707+00', 'Cooper, Elizabeth and Roger', '', 'Elizabeth and Roger Cooper', 'Birmingham, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11788, '2019-02-21 08:58:58.740322+00', '2019-02-22 00:56:06.741757+00', 'Cooper, Elizabeth', '', 'Elizabeth Cooper', 'Birmingham, UK', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11794, '2019-03-04 17:22:42.475472+00', '2019-03-05 09:50:22.13504+00', 'Farquhar, Ana', '', 'Anna Farquhar', 'Banchory', 'annafarquhar880@msn.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11791, '2019-02-24 10:35:27.199498+00', '2019-02-28 00:56:04.195723+00', 'Black Bear Duo, The', 'Black Bear Duo', 'The Black Bear Duo', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11795, '2019-03-05 22:06:33.441929+00', '2019-03-06 00:56:02.749853+00', 'Ayers, Cheryl', '', 'Cheryl Ayers', 'Bristol, UK', 'cheryl.ayers@me.com', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Teacher of the Westbury SCD group');
INSERT INTO 'person' VALUES (1531, NULL, '2019-03-08 17:07:09.344531+00', 'Ford, Tommy', '', 'Tommy Ford', '', '', 0, 0, 1, 1, NULL, 1931, 2017, NULL, 'Tommy Ford played Lead accordion in Jim MacLeod''s band.



There is an obituary at https://boxandfiddlearchive.weebly.com/tommy-ford-2017.html');
INSERT INTO 'person' VALUES (11797, '2019-03-08 18:16:14.209902+00', '2019-03-08 18:16:14.209902+00', 'Iberian Peninsula Scottish Country Dance Group', 'IPSCDG', 'Iberian Peninsula SCD Group', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11798, '2019-03-08 19:55:21.414567+00', '2019-03-08 19:55:21.414567+00', 'Guild, Malcolm', '', 'Malcolm Guild', 'Isle of Man', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10008, NULL, '2019-03-11 19:47:39.120207+00', 'Joueurs de Bon Accord, Les', 'Les Joueurs de Bon Accord', 'Les Joueurs de Bon Accord', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11800, '2019-03-26 22:43:55.200893+00', '2019-03-26 22:43:55.200893+00', 'Chapman, John', '', 'John Chapman ', 'UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11799, '2019-03-14 01:05:47.200813+00', '2019-04-09 23:56:09.962977+00', 'Gordon, Ralph', '', 'Ralph Gordon', 'USA', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11844, '2019-07-25 09:44:17.224588+00', '2019-07-25 23:56:03.921486+00', 'Beijer, Michaela', '', 'Michaela Beijer', 'Stockholm, Sweden', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11802, '2019-04-12 16:04:19.202406+00', '2019-04-12 23:56:10.132518+00', 'Gosney, Rita', '', 'Rita Gosney', 'Bracknell, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11803, '2019-04-12 16:05:08.666584+00', '2019-04-12 23:56:17.101636+00', 'McCaffrey-Talbot, Kathy', '', 'Kathy McCaffrey-Talbot', 'Bracknell, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11804, '2019-04-12 16:06:06.510461+00', '2019-04-12 23:56:17.186052+00', 'McCaffrey-Talbot, Kathy & Gosney, Rita', '', 'Kathy McCaffrey-Talbot & Rita Gosney', 'Bracknell, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11822, '2019-06-14 20:13:15.43117+00', '2019-06-14 20:13:15.43117+00', 'Liszt, Franz', '', 'Franz Liszt', '', '', 0, 0, 1, 0, NULL, 1811, 1866, NULL, '');
INSERT INTO 'person' VALUES (11823, '2019-06-14 20:36:31.208163+00', '2019-06-14 20:36:31.208163+00', 'Stevenson, Savourna', '', 'Savourna Stevenson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11807, '2019-05-06 21:26:36.455351+00', '2019-05-06 22:40:32.022886+00', 'Ferguson-Jones, Kirsten', '', 'Kirsten Ferguson-Jones', 'Aurora Scottish Dance and Music', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11786, '2019-02-20 23:09:33.669569+00', '2021-04-30 17:59:18.481757+00', 'Marchand, Célie', '', 'Célie Marchand', 'Méaudre (Vercors) France', 'meaudre.reel@gmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11783, '2019-02-20 20:47:22.402882+00', '2021-06-11 23:56:22.944077+00', 'Flett, Thomas Muirhead', '', 'Tom Flett', 'Sheffield, UK', '', 0, 0, 0, 0, NULL, 1923, 1976, NULL, '');
INSERT INTO 'person' VALUES (11781, '2019-02-19 15:13:08.843981+00', '2021-11-20 17:32:25.416147+00', 'Jeannerod, Nicolas', '', 'Nicolas "Niols" Jeannerod', 'Paris, France', '', 1, 0, 1, 0, NULL, 0, 0, NULL, 'Known as Niols');
INSERT INTO 'person' VALUES (11808, '2019-05-09 13:06:51.202871+00', '2019-05-09 13:06:51.202871+00', 'Purdie, Suzanne', '', 'Suzanne Purdie', 'Edinburgh, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11809, '2019-05-12 09:19:02.137501+00', '2019-05-12 09:19:02.137501+00', 'McGrath, Andy', '', 'Andy McGrath', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11825, '2019-06-14 20:50:25.462244+00', '2019-06-14 20:50:25.462244+00', 'Slaney, Ivor', '', 'Ivor Slaney', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11824, '2019-06-14 20:48:45.919561+00', '2019-06-14 23:56:08.462849+00', 'Farnon, Robert', '', 'Robert Farnon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11810, '2019-05-14 23:26:12.402069+00', '2019-05-15 23:56:03.594244+00', 'Berg Gray, Jamie', '', 'Jamie Berg Gray', 'Oslo, Norway', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11806, '2019-04-28 08:36:25.060402+00', '2019-05-19 08:04:41.880382+00', 'Tait, Bill', '', 'Bill Tait', 'Dingwall, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11811, '2019-05-21 16:14:06.687561+00', '2019-05-21 16:17:10.95283+00', 'Gellatly, Peter', '', 'Peter Gellatly', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11812, '2019-05-21 16:18:22.581013+00', '2019-05-21 16:18:22.581013+00', 'Robertson, Alison and Gellatly, Peter', '', 'Alison Robertson & Peter Gellatly', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1434, NULL, '2019-06-23 09:13:47.335724+00', 'Fergusson, William', '', 'William Fergusson', '', '', 0, 0, 1, 0, NULL, 1885, 1949, NULL, 'There is a brief biography at <<https://pipetunes.ca/composer/william-fergusson/>>');
INSERT INTO 'person' VALUES (11813, '2019-05-22 12:19:06.568824+00', '2019-05-22 12:19:53.11096+00', 'Martlew, Barbara & Martlew, Ken', 'Bar & Ken Martlew', 'Barbara Martlew & Ken Martlew', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3459, NULL, '2019-05-22 23:56:16.77884+00', 'Manning, Barbara & Martlew, Ken', 'Manning & Martlew', 'Barbara Manning & Ken Martlew', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11815, '2019-06-01 16:07:07.736585+00', '2019-06-01 16:07:07.736585+00', 'Gera, Dániel', '', 'Dániel Gera', 'Budapest, Hungary', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11816, '2019-06-01 16:12:24.008928+00', '2019-06-01 23:56:17.889651+00', 'Lilik, Márta', '', 'Márta Lilik', 'Budapest, Hungary', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11818, '2019-06-03 17:48:56.773897+00', '2019-06-03 23:56:03.220053+00', 'Bagoly, Vilmos', '', 'Vilmos Bagoly', 'Budapest, Hungary', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11819, '2019-06-04 09:14:16.59186+00', '2019-06-04 23:56:12.970884+00', 'Kaczur, Csilla', '', 'Csilla Kaczur', 'Budapest, Hungary', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2957, NULL, '2019-06-13 16:19:51.244659+00', 'Bell, John', '', 'John Bell', 'Desborough, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Has also lived in Cairns, Australia.');
INSERT INTO 'person' VALUES (11793, '2019-02-28 00:00:19.865876+00', '2022-10-25 23:57:00.962256+00', 'Smith, Anna', '', 'Anna Smith', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11835, '2019-07-17 19:21:37.071879+00', '2019-07-17 23:56:21.46451+00', 'San Gabriel Valley Branch RSCDS', 'San Gabriel Valley', 'San Gabriel Valley Branch RSCDS', 'Los Angeles, USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11827, '2019-06-26 21:51:21.499367+00', '2019-06-26 21:51:21.499367+00', 'Bain, Sheila', '', 'Sheila Bain', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11828, '2019-06-26 22:40:05.903374+00', '2019-06-26 22:40:05.903374+00', 'Trattles, Helen', '', 'Helen Trattles', 'Wirral, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (640, NULL, '2019-06-27 11:41:52.055714+00', 'Johnston, John A', '', 'John A Johnston', 'Irvine, Ayrshire, Scotland', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11829, '2019-06-27 21:49:30.008279+00', '2019-06-27 21:49:30.008279+00', 'Robichaud, Angus', '', 'Angus Robichaud', 'New Brunswick, Canada', '', 0, 0, 1, 0, NULL, 1915, 2005, NULL, '');
INSERT INTO 'person' VALUES (2166, NULL, '2019-06-27 21:56:02.851746+00', 'Robichaud, Gerry', '', 'Gerry Robichaud', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11830, '2019-07-03 17:38:54.181119+00', '2019-07-03 23:56:03.27648+00', 'Bennett, Ray', '', 'Ray Bennett', 'Winchester, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11832, '2019-07-03 18:01:50.89767+00', '2019-07-03 23:56:03.676669+00', 'Bird, Janet', '', 'Janet Bird', 'Winchester, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11833, '2019-07-03 18:09:31.966667+00', '2019-07-03 23:56:07.027772+00', 'Cummins, Christine', '', 'Christine Cummins', 'Winchester, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11831, '2019-07-03 17:45:46.291809+00', '2019-07-03 23:56:26.512338+00', 'Williams, Eileen', '', 'Eileen Williams', 'Winchester, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11834, '2019-07-13 21:33:18.094803+00', '2019-07-13 23:56:08.248901+00', 'Faulkener, Mollie', '', 'Mollie Faulkener', 'Vancouver, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11836, '2019-07-22 21:18:05.319188+00', '2019-07-23 00:20:52.331783+00', 'Christian Petersen and Gunnar Numeus', '', 'Christian Petersen and Gunnar Numeus', 'Copenhagen and Gothenburg', '', 0, 1, 0, 0, NULL, 0, 0, NULL, 'These publishers decided to fulfil a dream that they both had, to collect and publish dances devised by Scandinavians or people who live or had lived in Scandinavia.  The dacnes date back to the 1980s. (SC Dancer, no 28, April 2019)');
INSERT INTO 'person' VALUES (11837, '2019-07-24 10:54:55.244527+00', '2019-07-24 10:54:55.244527+00', 'Olsen, Ilse Zelmer', '', 'Ilse Zelmer Olsen', 'Copenhagen, Denmark', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11838, '2019-07-24 18:37:38.178976+00', '2019-07-24 23:56:14.226868+00', 'Kjellander, Roland', '', 'Roland Kjellander', 'Gothenburg, Sweden', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11839, '2019-07-24 18:38:42.619653+00', '2019-07-24 23:56:14.293431+00', 'Kjellander, Roland & Numeus, Gunnar', '', 'Roland Kjellander & Gunnar Numeus', 'Gothenburg, Sweden', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11840, '2019-07-24 20:34:02.980817+00', '2019-07-24 23:56:25.352877+00', 'Vestli, Kristian', '', 'Kristian Vestli', 'Oslo, Norway', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11841, '2019-07-25 08:15:47.157978+00', '2019-07-25 08:24:24.024233+00', 'Frimodig, Anna', '', 'Anna Frimodig', 'Stockholm, Sweden', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11843, '2019-07-25 09:32:19.340585+00', '2019-07-25 09:32:19.340585+00', 'Champness, Pat', '', 'Pat Champness', 'Stockholm, Sweden', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11846, '2019-07-25 11:24:51.165666+00', '2019-07-25 23:56:17.50482+00', 'McGillivray, Troy', '', 'Troy McGillivray', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11842, '2019-07-25 08:27:55.903924+00', '2019-07-25 23:56:22.729012+00', 'Schmölder-Hanson, Elke', '', 'Elke Schmölder-Hanson', 'Stockholm, Sweden', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11847, '2019-08-06 09:06:32.398735+00', '2019-08-06 09:06:32.398735+00', 'Porter, Gordon', '', 'Gordon Porter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3461, NULL, '2019-08-06 23:56:21.349642+00', 'Murray, Evelyn M E', '', 'Evelyn M E Murray', 'Boston, MA', '', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Evelyn Murray-Lenthall is now again using her maiden name Evelyn Murray.');
INSERT INTO 'person' VALUES (11850, '2019-08-11 20:30:55.765322+00', '2019-08-11 23:56:06.65244+00', 'Clark, Tina', '', 'Tina Clark', 'California, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11851, '2019-08-11 20:44:42.209178+00', '2019-08-11 23:56:11.391878+00', 'Green, Gary T', '', 'Gary T Green', 'California, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11854, '2019-08-12 07:59:39.874029+00', '2019-08-12 23:56:05.220188+00', 'Caltech SCD Class', '', 'Caltech SCD Class', 'California, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11857, '2019-08-12 08:49:16.802772+00', '2019-08-12 23:56:08.390443+00', 'Eagle Rock Class, The', '', 'The Eagle Rock Class', 'California, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11856, '2019-08-12 08:32:24.508035+00', '2019-08-12 23:56:10.190859+00', 'Gaskell, Lisa', '', 'Lisa Gaskell', 'California, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11855, '2019-08-12 08:09:31.658936+00', '2019-08-12 23:56:18.600505+00', 'McDonald, Alfred', '', 'Alfred McDonald', 'California, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11879, '2019-09-16 21:03:36.346053+00', '2019-09-16 23:56:23.217147+00', 'Powell, Rose', '', 'Rose Powell', 'Vancouver, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11859, '2019-08-21 22:35:57.441791+00', '2019-08-21 23:56:06.938836+00', 'Crawfurd, R Julian', '', 'R Julian Crawfurd', 'Perthshire, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11860, '2019-08-21 22:38:24.951779+00', '2019-08-21 23:56:07.037384+00', 'Crawfurd, R J & Young, Margaret', 'Crawfurd & Young', 'R J Crawfurd & Margaret Young', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11878, '2019-09-16 07:01:35.863052+00', '2019-09-16 23:56:28.075414+00', 'Tcheng, Zoe', '', 'Zoe Tcheng', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11880, '2019-09-21 10:20:08.875989+00', '2019-09-21 10:20:08.875989+00', 'Morshead, Ian', '', 'Ian Morshead', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11862, '2019-08-23 16:01:49.228113+00', '2019-08-23 23:56:27.61728+00', 'Wyrick, Steve and Julie', '', 'Steve and Julie Wyrick', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11861, '2019-08-23 16:00:33.704401+00', '2019-08-26 23:56:52.804219+00', 'Wyrick, Julie', '', 'Julie Wyrick', '', '', 1, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11864, '2019-08-30 12:56:36.562365+00', '2019-08-30 13:06:20.61378+00', 'Leifer, David W', '', 'David Leifer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11881, '2019-09-26 10:06:39.688068+00', '2019-09-26 10:06:39.688068+00', 'Johnston, Pamela', '', 'Pamela Johnston', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11817, '2019-06-02 23:29:38.310112+00', '2020-04-03 12:57:36.081306+00', 'Briscoe, Mel and Ellie', '', 'Mel and Ellie Briscoe', 'Alexandria, Virginia ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1846, NULL, '2021-07-24 23:56:25.82248+00', 'Gray, James', 'James Gray', 'W James A Gray', '', '', 1, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11865, '2019-08-30 18:20:07.891016+00', '2019-08-30 23:56:10.575115+00', 'Gibson, Myra', '', 'Myra Gibson', 'Lanark, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11869, '2019-09-01 22:06:59.461125+00', '2019-09-01 23:56:12.710859+00', 'Hughes, Lynda', '', 'Lynda Hughes', 'Liddington Scottish Country Dancing Group', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11868, '2019-09-01 13:56:56.917368+00', '2019-09-01 23:56:17.616082+00', 'McKnight, Paul', '', 'Paul McKnight', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Source: Minicrib');
INSERT INTO 'person' VALUES (11870, '2019-09-02 11:37:02.578855+00', '2019-09-02 11:37:02.578855+00', 'Howell, Graham', '', 'Graham Howell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11871, '2019-09-02 16:14:48.401033+00', '2019-09-02 23:56:10.311287+00', 'Gordon, Bryan', '', 'Bryan Gordon', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11872, '2019-09-03 20:52:47.122905+00', '2019-09-04 07:37:29.660061+00', 'McManamon, Michael', '', 'Michael McManamon', 'Fowlis SCD Group', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11873, '2019-09-05 09:50:28.999133+00', '2019-09-05 09:50:28.999133+00', 'Ferguson, Sheena', '', 'Sheena Ferguson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2743, NULL, '2019-09-05 23:56:21.397078+00', 'McKerron, Doreen', '', 'Doreen McKerron', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11886, '2019-09-26 22:29:52.959157+00', '2019-09-26 22:29:52.959157+00', 'Petyt, Sue and Stacey, Moira', '', 'Sue Petyt and Moira Stacey', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11875, '2019-09-13 16:40:00.023941+00', '2019-09-13 16:40:12.450737+00', 'Carnes, Paula', '', 'Paula Carnes', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11877, '2019-09-16 06:45:19.926922+00', '2019-09-16 23:56:16.58625+00', 'Lewis, Victoria', '', 'Victoria Lewis', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11882, '2019-09-26 10:19:40.043871+00', '2019-09-26 23:56:09.594945+00', 'Ellis, Mary', '', 'Mary Ellis', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11885, '2019-09-26 14:24:13.542442+00', '2019-09-26 23:56:11.265027+00', 'Gaul, Linda and Rooney, Di', '', 'Linda Gaul and Di Rooney', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11883, '2019-09-26 10:41:04.607954+00', '2019-09-26 23:56:12.298765+00', 'Gray, Dorothy', '', 'Dorothy Gray', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11887, '2019-10-13 18:04:27.704274+00', '2019-10-13 23:56:18.75759+00', 'Meiklejohn, Lilian', '', 'Lilian Meiklejohn', 'Inverness RSCDS', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Branch Honorary President in 2019');
INSERT INTO 'person' VALUES (11889, '2019-10-16 03:59:58.758488+00', '2019-10-16 04:00:32.027417+00', 'Scodel, Ruth', '', 'Ruth Scodel', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11888, '2019-10-16 03:26:05.481217+00', '2019-10-16 04:00:53.895544+00', 'Hellmann, Joan', '', 'Joan Hellmann', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (954, NULL, '2019-10-21 14:50:45.178927+00', 'Kass, Susie Langdon', '', 'Susie Langdon Kass', 'San Francisco', '', 1, 1, 0, 0, NULL, 0, 2019, NULL, '');
INSERT INTO 'person' VALUES (11891, '2019-10-24 16:05:24.049697+00', '2019-10-24 16:05:24.049697+00', 'Oxford University Scottish Dance Society', 'OUSDS', 'Oxford University Scottish Dance Society', 'Oxford, UK', 'scottish.dance@studentclubs.ox.ac.uk', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11892, '2019-10-24 16:19:53.424227+00', '2019-10-24 16:19:53.424227+00', 'Herrick, Tim', '', 'Tim Herrick', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11893, '2019-10-24 16:23:54.294439+00', '2019-10-24 16:23:54.294439+00', 'McConnachie, Moray', '', 'Moray McConnachie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11895, '2019-10-24 16:48:14.210934+00', '2019-10-24 16:48:14.210934+00', 'Thomson, Andrew', '', 'Andrew Thomson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11894, '2019-10-24 16:33:09.027116+00', '2019-10-24 23:56:17.726326+00', 'Marshall, Jeremy', '', 'Jeremy Marshall', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11805, '2019-04-17 08:37:48.335331+00', '2019-10-24 23:56:25.522701+00', 'Stainer, Alice', '', 'Alice Stainer', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11896, '2019-10-25 09:58:01.449315+00', '2019-10-25 23:56:09.909733+00', 'Fowler, Enid', '', 'Enid Fowler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11897, '2019-10-25 10:28:56.561855+00', '2019-10-25 23:56:18.777603+00', 'Moody, Jeanne', '', 'Jeanne Moody', 'San Diego, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11901, '2019-10-28 20:53:18.29136+00', '2019-10-28 20:53:18.29136+00', 'Goerke, Rachel', '', 'Rachel Goerke', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11904, '2019-10-28 22:43:23.429014+00', '2019-10-28 22:44:43.886443+00', 'Reavey, Helen', '', 'Helen Reavey', 'Melbourne, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11899, '2019-10-28 18:17:06.34631+00', '2019-10-29 00:56:10.860051+00', 'Greenbank, Susan', '', 'Susan Greenbank', 'Melbourne, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11902, '2019-10-28 21:30:39.868353+00', '2019-10-29 00:56:17.069139+00', 'Marks, Ian', '', 'Ian Marks', 'Melbourne, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11900, '2019-10-28 18:39:47.468272+00', '2019-10-29 00:56:24.179821+00', 'Smith, John E', '', 'John E Smith', 'Melbourne, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11903, '2019-10-28 21:44:42.32915+00', '2019-10-29 00:56:27.723763+00', 'Wrigley, Sarah', '', 'Sarah Wrigley', 'Melbourne, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11898, '2019-10-28 18:08:21.975903+00', '2019-10-29 10:51:21.307863+00', 'Vincent, Campbell', '', 'Campbell Vincent', 'Melbourne, Australia', '', 1, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3159, NULL, '2019-11-03 19:55:22.717243+00', 'Sullivan, Anthony', '', 'Anthony Sullivan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1959, NULL, '2019-11-03 23:38:03.35503+00', 'Cameron, Charles', '', 'Charles Cameron', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'There is some information about Charles Cameron in <<https://boxandfiddlearchive.weebly.com/captain-craig-brown.html|this article>> about his tune <<ddt:Captain Craig Brown#4415>>.');
INSERT INTO 'person' VALUES (1529, NULL, '2019-11-04 12:08:09.361586+00', 'Wallace, John', 'J Wallace', 'John Wallace', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Although mostly referred to just as J Wallace it seems likely he was John Wallace judging by this <<https://boxandfiddlearchive.weebly.com/cts-empress.html|this Box and Fiddle article>>.');
INSERT INTO 'person' VALUES (2541, NULL, '2019-11-21 18:21:34.765188+00', 'Woods, Harry M.', '', 'Harry M. Woods', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1684, NULL, '2019-11-05 00:19:41.656846+00', 'Scott, J', '', 'J Scott', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'First name John, but probably not identical to dance deviser <<ddp:John Scott#549>>.');
INSERT INTO 'person' VALUES (10907, '2013-12-19 10:46:49.299102+00', '2019-11-05 14:44:16.925894+00', 'Walduck, Francis', '', 'Francis Walduck', 'Brisbane RSCDS, Queensland, Australia', '', 1, 1, 0, 0, NULL, 1949, 2016, NULL, '');
INSERT INTO 'person' VALUES (3374, NULL, '2019-11-06 19:15:41.60996+00', 'Lasnik, Howard', '', 'Howard Lasnik', 'USA', 'hlasnik@verizon.net', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1360, NULL, '2019-11-08 00:52:14.698282+00', 'Hill, Jeremy', '', 'Jeremy Hill', '', 'hilljgj@ntlworld.comOBSOLETE', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11656, '2018-07-04 11:59:50.958653+00', '2019-11-11 01:07:19.368003+00', 'Ebling, V/Köppler, U', 'Ebling & Köppler', 'V Ebling/U Köppler', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3678, NULL, '2019-11-14 09:15:59.576225+00', 'Irvine Valley Scottish Dance Quartet', 'Irvine Valley', 'Irvine Valley Scottish Dance Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'In their set of four Favourite SCDs albums, the band''s name is given as Irvine Valley Scottish Dance Quartet for volumes 2 and 3.');
INSERT INTO 'person' VALUES (11905, '2019-11-15 23:18:00.873846+00', '2019-11-15 23:18:00.873846+00', 'Patterson, Désirée', '', 'Désirée Patterson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10757, '2013-02-27 13:14:17.222356+00', '2019-11-21 18:17:27.883951+00', 'Bayes, Nora & Norworth, Jack', '', 'Nora Bayes & Jack Norworth', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10756, '2013-02-27 13:09:57.608426+00', '2019-11-21 18:20:10.77893+00', 'King, Irving', '', 'Irving King', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Pseudonym for James Campbell & Reginald Connelly.');
INSERT INTO 'person' VALUES (3040, NULL, '2019-11-21 19:06:00.528432+00', 'Lothian Scottish Dance Band', 'Lothian Band', 'Lothian Scottish Dance Band', '', 'Lothian@btinternet.com', 0, 0, 0, 1, NULL, 0, 0, NULL, 'Some of their albums give the credit as George Meikle and the Lothian Scottish Dance Band.');
INSERT INTO 'person' VALUES (11906, '2019-11-26 10:44:28.508933+00', '2019-11-26 10:51:21.782749+00', 'Lost Sheep', '', 'Lost Sheep', 'Bochum, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Dance group in the Ruhr district.');
INSERT INTO 'person' VALUES (11876, '2019-09-16 00:57:32.814796+00', '2020-02-13 22:41:07.755179+00', 'Schultz, Sandee', '', 'Sandee Schultz', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11609, '2018-03-15 16:41:41.87581+00', '2020-05-20 18:10:32.989415+00', 'Oldsen, Riekje', '', 'Riekje Oldsen', 'Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11890, '2019-10-23 21:21:32.189386+00', '2020-06-04 21:17:48.421421+00', 'Totton, Chris', '', 'Chris Totton', 'Lower Hutt, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11874, '2019-09-06 20:46:59.834359+00', '2021-09-08 08:22:17.429521+00', 'Ronald, Sue', '', 'Sue Ronald', 'Quorn, Leicestershire, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Formerly of Edgewater, NJ, US');
INSERT INTO 'person' VALUES (11908, '2019-11-28 17:08:52.940426+00', '2019-11-29 00:56:12.022854+00', 'Crucius, Holger', '', 'Holger Crucius', 'Bochum, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11907, '2019-11-28 17:08:23.651949+00', '2019-11-29 00:56:23.340883+00', 'Grimberg, Susanne', '', 'Susanne Grimberg', 'Bochum, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11909, '2019-11-28 17:11:08.097053+00', '2019-11-29 00:56:23.359935+00', 'Grimberg, Susanne & Crucius, Holger', '', 'S. Grimberg & H. Crucius', 'Bochum, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11911, '2019-12-02 23:44:12.862616+00', '2019-12-02 23:54:58.969774+00', 'Nisbet, Wally', '', 'Wally Nisbet', 'Oakville, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11910, '2019-12-02 23:43:51.868669+00', '2019-12-02 23:59:20.442774+00', 'Finney, Jim', '', 'Jim Finney', 'Oakville, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1623, NULL, '2019-12-03 18:13:02.452797+00', 'Cooper, Ronald', '', 'Ronald Cooper', 'Lerwick, Shetland', '', 0, 0, 1, 0, NULL, 1934, 1982, NULL, 'For a short biography see <<https://boxandfiddlearchive.weebly.com/ronnie-cooper-1982.html|this Box and Fiddle article>>.');
INSERT INTO 'person' VALUES (11912, '2019-12-12 10:51:36.766737+00', '2019-12-12 10:51:36.766737+00', 'Landrieau, Danièle', '', 'Danièle Landrieau', 'Paris, France', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (338, NULL, '2019-12-13 13:16:19.323291+00', 'San Francisco Branch RSCDS', '', 'San Francisco Branch RSCDS', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2018, NULL, '2019-12-14 17:27:11.036511+00', 'Keppie, Maggie & Duncan', '', 'Maggie & Duncan Keppie', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, 'See <<http://www.minicrib.org.uk/Keppie.html>> for PDFs of all publications by Duncan and Maggie Keppie.');
INSERT INTO 'person' VALUES (1873, NULL, '2019-12-14 17:27:30.714083+00', 'Keppie, Maggie', '', 'Maggie Keppie', '', '', 1, 1, 1, 0, NULL, 0, 0, NULL, 'See <<http://www.minicrib.org.uk/Keppie.html>> for PDFs of all publications by Duncan and Maggie Keppie.');
INSERT INTO 'person' VALUES (11690, '2018-08-26 23:25:41.553527+00', '2019-12-18 00:33:11.371916+00', 'Gilmour, Christopher', '', 'Christopher Gilmour', 'Dance Scottish Cape Town', 'christopher.gilmour@uct.ac.za', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11913, '2019-12-19 21:02:03.050871+00', '2019-12-19 21:07:13.209281+00', 'Inglis, Gail', '', 'Gail Inglis', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2085, NULL, '2019-12-20 19:49:19.488843+00', 'Brown, Bobby', '', 'Bobby Brown', 'Mississauga, CANADA', '', 0, 0, 1, 1, NULL, 1941, 2011, NULL, 'There is a biography about Bobby Brown at <<http://www.scotchmist.ca/bobby-brown-bio.html|Scotchmist.ca>> and another article about him at <<https://boxandfiddlearchive.weebly.com/may-2011.html>>.');
INSERT INTO 'person' VALUES (1677, NULL, '2020-01-20 22:36:21.819477+00', 'Hunter, Willie', 'William Hunter', 'Willie Hunter', '', '', 0, 0, 1, 0, NULL, 1933, 1994, NULL, 'Generally known as Willie but sometimes referenced as William.



There is an obituary in <<https://boxandfiddlearchive.weebly.com/willie-hunter-1994.html|this Box and Fiddle page>>.');
INSERT INTO 'person' VALUES (11575, '2017-12-01 17:10:39.062912+00', '2019-12-31 13:34:16.055323+00', 'Park and friends, Annie', '', 'Annie Park & Friends', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11235, '2016-01-19 11:09:45.16111+00', '2019-12-31 16:08:10.989787+00', 'Franklin, Michael', '', 'Michael Franklin', 'Ripon in North Yorkshire', 'mcfranklin28@gmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11863, '2019-08-23 16:58:28.92879+00', '2022-02-18 21:17:17.472318+00', 'MacInnes, Ruth and Jamieson, Peter', '', 'Ruth MacInnes and Peter Jamieson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Ruth MacInnes and Peter Jamieson are joint devisers');
INSERT INTO 'person' VALUES (2733, NULL, '2020-01-04 23:08:06.037133+00', 'Boston Hospitality', 'Boston Hosp.', 'Boston Hospitality', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1795, NULL, '2020-01-20 23:21:54.575771+00', 'Robertson, James Blair', '', 'James Blair Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Pipe major of the Scots Guards.');
INSERT INTO 'person' VALUES (2061, NULL, '2020-01-04 23:13:03.476702+00', 'Paddledoo', 'Paddledoo', 'Paddledoo', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'The site <<http://www.paddledoo.com/>> lists recordings rooted in Scottish music since 1987.



The main musician is Ed Pearlman, many others have taken part in the recordings.



As mentioned in <<https://my.strathspey.org/dd/issue/1969/|issue 1969>> their album is also mentioned with the band name given as <<ddp:Boston Hospitality>>.



');
INSERT INTO 'person' VALUES (11914, '2020-01-04 23:38:33.5857+00', '2020-01-04 23:38:33.5857+00', 'Morrison, Andrew', '', 'Andrew Morrison', 'Nottingham, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11916, '2020-01-10 14:40:53.001382+00', '2020-01-10 14:40:53.001382+00', 'Zamarski, Krzysztof', '', 'Krzysztof Zamarski', 'Cambridge, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2947, NULL, '2020-01-15 23:02:08.293899+00', 'Robertson, Alison & Crawford, Ian', '', 'Alison Robertson & Ian Crawford', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11918, '2020-01-20 23:35:20.575852+00', '2020-01-20 23:35:20.575852+00', 'Robertson, Margaret', '', 'Margaret Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1644, NULL, '2020-01-20 23:37:51.72846+00', 'Robertson, Arthur Scott', '', 'Arthur Scott Robertson', 'Shetland, UK', '', 0, 0, 1, 0, NULL, 1911, 2000, NULL, '');
INSERT INTO 'person' VALUES (2028, NULL, '2020-06-27 22:28:05.116353+00', 'Watkins, Evelyn', '', 'Evelyn Watkins', 'Toronto', '', 1, 0, 0, 0, 78, 0, 0, NULL, 'Phone (647) 717 2239');
INSERT INTO 'person' VALUES (11917, '2020-01-20 10:24:34.144029+00', '2020-01-20 10:24:34.144029+00', 'Glendinning, Charlie', '', 'Charlie Glendinning', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11155, '2015-07-09 00:32:00.776908+00', '2020-01-20 22:17:53.619702+00', 'Robson, Maureen', '', 'Maureen Robson', 'Tawa, Wellington, New Zealand.', '', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Maureen Robson was tutor of the Tawa SCD Club in Tawa, Wellington, New

Zealand for 38 years until November 2019.');
INSERT INTO 'person' VALUES (11919, '2020-01-21 06:59:05.338059+00', '2020-01-21 06:59:39.412752+00', 'Tkacheva, Yulia', '', 'Yulia Tkacheva', 'Moscow, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1515, NULL, '2020-01-21 10:41:00.730202+00', 'Robertson, P/M James R', 'P/M J Robertson', 'P/M James R Robertson', 'Banff', '', 0, 0, 1, 1, NULL, 0, 0, NULL, 'Gordon Highlanders.');
INSERT INTO 'person' VALUES (2938, NULL, '2021-10-18 13:34:49.333991+00', 'Gillies, Pam', '', 'Pam Gillies', '', '', 1, 0, 0, 0, NULL, 0, 2021, NULL, '');
INSERT INTO 'person' VALUES (1033, NULL, '2020-01-25 14:12:39.425743+00', 'Hodgkin, John', '', 'John Hodgkin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Also known as John P. Hodgkin');
INSERT INTO 'person' VALUES (1631, NULL, '2020-06-17 15:12:05.041666+00', 'Robertson, Ian', '', 'Ian Robertson', 'UK', 'ibrobertson@btinternet.com', 0, 1, 1, 1, NULL, 0, 0, NULL, 'Ian was formerly entered in the database as "Ian B Robertson" but he prefers not to use his middle initial.');
INSERT INTO 'person' VALUES (11964, '2020-07-10 08:21:13.793008+00', '2020-07-10 08:21:13.793008+00', 'MacKenzie, John M', '', 'John M MacKenzie', 'UK', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11965, '2020-07-11 06:29:53.194474+00', '2020-07-11 06:29:53.194474+00', 'Williamson, Mary Ann', '', 'Mary Ann Williamson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11920, '2020-01-23 23:36:23.396553+00', '2021-07-11 00:54:48.476021+00', 'Graham-Raad, Scot', '', 'Scot Graham-Raad', 'Rochester, NY (USA)', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1598, NULL, '2020-01-26 22:38:39.440066+00', 'Rennie, Adam', '', 'Adam Rennie', '', '', 0, 0, 1, 0, NULL, 1897, 1960, NULL, 'There is a short biography in <<https://boxandfiddlearchive.weebly.com/adam-rennie.html|this Box and Fiddle article>>.');
INSERT INTO 'person' VALUES (2786, NULL, '2020-02-02 09:11:47.903507+00', 'Kokai, Hiroko', '', 'Hiroko Kokai', '', '', 0, 0, 1, 0, NULL, 1954, 0, NULL, '');
INSERT INTO 'person' VALUES (1516, NULL, '2020-02-05 10:04:41.937931+00', 'Marshall, William', '', 'William Marshall', '', '', 0, 1, 1, 0, NULL, 1748, 1833, NULL, 'A compilation of several volumes of Marshall''s tunes is available <<https://www.worldcat.org/title/marshalls-scottish-melodies-airs-strathspeys-reels-jigs-c-for-the-violin-being-a-compilation-of-four-volumes-published-separately-in-the-19th-century-by-various-houses/oclc/5792599|here>>. It is not clear if this is the same as any of the publications listed for him in the database as they only contain a few of these tunes and have more abbreviated titles.');
INSERT INTO 'person' VALUES (10656, '2012-09-08 09:24:21.884106+00', '2020-02-07 12:17:21.077098+00', 'McIntyre, Eddie', '', 'Eddie McIntyre', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11921, '2020-02-27 10:39:31.474775+00', '2020-02-28 00:56:43.943072+00', 'Legge, Bill (William)', '', 'Bill Legge', 'Banffshire, Scotland', 'tbb692@aol.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11922, '2020-02-28 11:31:07.851697+00', '2020-02-28 11:31:07.851697+00', 'Tischmacher, Mathilde', '', 'Mathilde Tischmacher', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11937, '2020-03-29 12:04:30.748889+00', '2020-03-29 12:12:09.470329+00', 'Jorgensen, Kathy', '', 'Kathy Jorgensen', 'Salinas, California, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11061, '2015-02-03 17:34:18.488431+00', '2020-03-01 13:53:05.758456+00', 'Roberts, Hugh', '', 'Hugh Roberts', 'Edinburgh and the Lothians', '', 1, 0, 0, 0, NULL, 0, 2001, NULL, '');
INSERT INTO 'person' VALUES (11935, '2020-03-29 11:33:23.059388+00', '2020-03-29 12:13:10.477557+00', 'Cook, Heather', '', 'Heather Cook', 'Manchester, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11923, '2020-03-02 15:26:47.236588+00', '2020-03-02 15:33:17.146543+00', 'Garrett, Jill & Stoddard, Ralph', '', 'Jill Garrett & Ralph Stoddard', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11924, '2020-03-11 11:26:07.389818+00', '2020-03-12 00:56:07.110512+00', 'Birdsall, Beth', '', 'Beth Birdsall', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11936, '2020-03-29 11:49:35.437183+00', '2020-03-29 23:56:48.679791+00', 'Mitchell, Alison', '', 'Alison Mitchell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11926, '2020-03-23 17:46:34.46048+00', '2020-03-23 17:46:34.46048+00', 'Bonacini, Maria Elena', '', 'Maria Elena Bonacini', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10684, '2012-12-28 14:53:43.699088+00', '2020-03-23 22:35:46.940263+00', 'Robertson, A. S.', '', 'A. S. Robertson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Possible duplicate of <<ddp:# 1644>>?');
INSERT INTO 'person' VALUES (10890, '2013-10-29 00:26:13.372415+00', '2020-03-23 23:08:01.005176+00', 'Senior, Robert and Margaret', '', 'Robert and Margaret Senior', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2203, NULL, '2020-09-28 22:23:47.403527+00', 'Hamilton, Peggy', '', 'Peggy Hamilton', 'Stockton, CA, USA', 'shadowcatdancer@me.com', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Peggy Hamilton is a Board Member of the Sacramento, California branch of the RSCDS.



second e-address:  ShadowCatDancing@sbcglobal.net');
INSERT INTO 'person' VALUES (11984, '2020-10-06 14:09:24.359389+00', '2020-10-06 23:56:11.02697+00', 'Brown, Alasdair & Duncan', '', 'Alasdair & Duncan Brown', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11985, '2020-10-10 21:12:12.15518+00', '2020-10-10 21:12:12.15518+00', 'Watters, Robert (Bob)', '', 'Bob Watters', 'Toronto, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11915, '2020-01-05 10:59:51.130403+00', '2022-07-06 23:47:35.713809+00', 'Gorelova, Irina', '', 'Irina Gorelova', 'Cheboksary, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10971, '2014-06-27 14:03:33.339197+00', '2020-03-24 00:00:59.785014+00', 'Dugan, Ray', '', 'Ray Dugan', 'Waterloo, Ontario, Canada', 'rayandsylvia@sympatico.ca', 1, 1, 0, 0, NULL, 0, 2020, NULL, 'Dr. John Raymond Dugan (Ray), a retired professor of French at the University of Waterloo, in Waterloo, Ontario, Canada, has been involved with Scottish Country Dancing since the early 1980’s. He received his full RSCDS teaching certificate in Toronto in 1997. Since then, he has taught classes with the Kitchener-Waterloo branch of the RSCDS and the Caledonian Scottish Country Dancers of Stratford, Ontario.



He has also been a guest teacher with various other groups, including Halburton, Ontario; Paris, France; and Sarasota, Florida. He and his wife Sylvia live in Waterloo, Ontario with their much beloved English Springer Spaniel, Murphy.

');
INSERT INTO 'person' VALUES (11938, '2020-03-29 13:26:45.1059+00', '2020-03-29 23:57:03.967182+00', 'Smith, Ted', '', 'Ted Smith', 'Melbourne, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11927, '2020-03-23 17:51:49.431626+00', '2020-03-24 08:56:48.643916+00', 'Holmes, Shona', '', 'Shona Holmes', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11928, '2020-03-24 22:03:45.142263+00', '2020-03-24 22:03:45.142263+00', 'Cashmore, Pauline and Ferrier, George', '', 'Pauline Cashmore and George Ferrier', 'Croydon, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11929, '2020-03-24 22:12:00.443192+00', '2020-03-24 22:12:00.443192+00', 'Neuffer, Dave', '', 'Dave Neuffer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11930, '2020-03-24 22:18:28.667107+00', '2020-03-24 22:18:28.667107+00', 'Lee, Jenny Lauren', '', 'Jenny Lauren Lee', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11931, '2020-03-24 22:23:38.812607+00', '2020-03-24 22:23:38.812607+00', 'Adelstein, Rachel', '', 'Rachel Adelstein', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11932, '2020-03-25 00:37:30.135334+00', '2020-03-25 00:37:30.135334+00', 'Yu, Xiaowen', '', 'Xiaowen Yu', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11933, '2020-03-25 00:56:25.1235+00', '2020-03-25 00:56:25.1235+00', 'McDaniel, Stephanie', '', 'Stephanie McDaniel', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11925, '2020-03-23 17:37:11.144864+00', '2020-03-25 00:56:49.420846+00', 'Messner, Bob', '', 'Bob Messner', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11934, '2020-03-25 08:10:04.321502+00', '2020-03-25 10:26:28.990308+00', 'Newfield-Plunkett Bowman, Hannah', '', 'Hannah Newfield-Plunkett Bowman', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11940, '2020-03-30 02:05:44.875+00', '2020-03-30 23:56:32.798635+00', 'Hoffman, Amy', '', 'Amy Hoffman', 'USA   California?', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11939, '2020-03-30 00:38:05.347337+00', '2020-03-30 23:56:49.776898+00', 'Milne, Kelly', '', 'Kelly Milne', 'USA   California?  ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3355, NULL, '2020-03-31 12:04:28.409093+00', 'Bänninger, Minnie', '', 'Minnie Bänninger', 'Brütten, Switzerland', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11963, '2020-07-06 19:03:55.630898+00', '2020-07-06 23:56:52.475513+00', 'Murray, Joan', '', 'Joan Murray', 'Helensburgh, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11966, '2020-07-12 12:19:49.473208+00', '2020-07-12 23:56:09.19695+00', 'Brewer, Silvia', '', 'Silvia Brewer', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3583, NULL, '2020-12-29 17:02:53.486975+00', 'Turner, Moira J', '', 'Moira Turner', 'Chesterfield (Greater Richmond), Virginia, USA', 'MoiraJTurner@aol.com', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Freely downloadable recordings of music for many of Moira Turner''s dances can be found at <<http://www.fiddletree-music.com/johnturner/scdrecordings.html>>');
INSERT INTO 'person' VALUES (11968, '2020-07-16 23:14:39.543988+00', '2020-07-16 23:14:39.543988+00', 'Colon, Lucas', '', 'Lucas Colon', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11969, '2020-07-24 09:09:56.622362+00', '2020-07-25 03:52:56.58416+00', 'Solera Ureña, José R.', '', 'José R. Solera Ureña', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11970, '2020-07-28 21:16:41.669358+00', '2020-07-28 21:16:41.669358+00', 'Smith, Julia', '', 'Julia Smith', 'New South Wales, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (352, NULL, '2020-07-31 21:16:19.58658+00', 'Skelton, Barry', '', 'Barry Skelton', '', 'barry.skelton@xtra.co.nz', 1, 1, 0, 0, NULL, 0, 0, NULL, 'A very nice video of Barry explaining his dance "Pelorus Jack" and the music is attached to that dance, and is also accessible on youtube at

<<http://youtu.be/qIg2H6gew7Y>>');
INSERT INTO 'person' VALUES (11967, '2020-07-13 09:40:34.549807+00', '2020-09-30 23:57:08.207133+00', 'Steinbach,Kirsten', '', 'Kirsten Steinbach', 'Freiburg, Germany', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11972, '2020-07-31 15:58:22.842844+00', '2020-07-31 23:57:01.800085+00', 'Risk, Laura and Williams, Nicholas', '', 'Laura Risk and Nicholas Williams', 'Montreal, Canada', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11973, '2020-08-01 20:03:10.411035+00', '2020-08-01 23:56:47.625241+00', 'Prior, Mary', '', 'Mary Prior', 'Leicester, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11975, '2020-08-03 07:53:19.00938+00', '2020-08-03 07:53:19.00938+00', 'Rynne, Donna', '', 'Donna Rynne', 'Perth, W Australiia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11974, '2020-08-02 17:41:48.240015+00', '2020-08-07 15:12:15.790864+00', 'Kajino, Yoshie', '', 'Yoshie Kajino', 'Fujisawa, Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11971, '2020-07-31 09:43:28.217297+00', '2020-09-30 23:56:32.521632+00', 'Heckmann, Jens', '', 'Jens Heckmann', 'Freiburg, Germany', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11784, '2019-02-20 21:00:36.647328+00', '2020-08-24 09:17:29.54099+00', 'Flett, Joan', '', 'Joan Flett', '', '', 1, 0, 0, 0, NULL, 1923, 2016, NULL, 'This <<https://youtu.be/qgkRZ1H0lko|video>> from 1993 shows Joan Flett describing the dance collecting expeditions with her husband Tom.');
INSERT INTO 'person' VALUES (11976, '2020-08-21 21:28:34.556141+00', '2020-08-28 20:48:56.489827+00', 'Trapp, Sue', '', 'Sue Trapp', 'Connecticut, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (129, NULL, '2021-03-03 20:29:21.700588+00', 'Foss, Hugh', '', 'Hugh Foss', '', '', 1, 1, 1, 0, NULL, 1902, 1971, NULL, 'Hugh Rose Foss was born in Kobe, Japan, on 13 May 1902. One of five children of the Rt Revd Hugh Foss, Bishop of Osaka, he went to Hoylake and Marlborough College (a boarding school in Wiltshire that at the time catered for the sons of Church of England clergy) and in 1924 graduated from Christ''s College, Cambridge with a degree in mathematics.



After university, Foss joined the “Government Code and Cipher School” – the precursor of today''s GCHQ, the UK''s equivalent to the NSA – as a cryptanalyst. During World War II he worked at Bletchley Park, distinguishing himself in various ways, including as the first person to break one day''s worth of German Enigma traffic in November 1940 – the day in question was 8 May 1940, which cryptographers today refer to as “Foss''s Day” (Foss had been working on early versions of the German cipher machine, which used to be commercially available, since the late 1920s). A fluent Japanese speaker since his childhood in Kobe, he not only broke the Japanese naval attaché cipher in 1934 (together with Oliver Strachey) but also headed the Japanese Naval Section of Bletchley Park from 1942 to 1945. Foss also worked with US Navy cryptographers on deciphering Japanese communications – to do so, he was sent to Washington, DC, towards the end of 1943, where his tall and thin stature, red hair and beard, combined with his predilection for wearing sandals, earned him the nickname “Lend-Lease Jesus”.



After the war, Foss stayed with GCHQ until he retired in 1953. He moved to Dalry, near Castle Douglas, in Scotland in 1955 and died at his home there on 23 December 1971.



Hugh Foss became interested in SCD in the mid-1930s and joined the Chelsea Reel Club in London. Even at Bletchley Park, he ran a SCD class and put on regular dances (including a full-dress affair on St Andrew''s Night). Later in life he served as President and Committee Chairman of RSCDS London Branch and it was during this time and through his initiative that the London Branch newsletter, *The Reel* was founded; Hugh also served as its second editor. Being a mathematician by training, Foss excelled at devising new dances whose inventiveness and precision remain unchallenged to this day, but he also contributed greatly to the “theoretical” aspects of SCD, writing articles that expounded on various topics of interest. Many patterns that are taken for granted in modern dances, such as five-couple dances with couples 1 and 3 starting simultaneously, were pioneered by Foss. He was also the first to introduce the concept of “fugues”, patterned on the type of musical composition, to SCD.



Hugh Foss was a first-rate independent thinker, and it comes as no great surprise that his relationship to the leadership of the (R)SCDS was not always simple. He used to encourage research and experimentation (in issue 100 of *The Reel*, he reminisces that



> At that time [1951], Scottish Country Dancing had no free press.

> Many words were spoken, but none written. The S.C.D.S. Bulletin

> gave only the official view and rarely dealt with research. “The Reel”

> was free to be controversial,  […]



and he frequently exhorted dancers to “roll back the carpet” and try new things). It is perhaps telling that, in spite of Foss''s devising over 150 dances, some of which became very popular indeed, it took the Society until 2007 to acknowledge his contribution to SCD by (re-)publishing three of his most well-known creations: <<ddd:Fugal Fergus>>, <<ddd:John McAlpin>> and <<ddd:Polharrow Burn>>, and later re-issuing his book <<ddpub:Dances to Song Tunes#156>>.



The <<https://www.bletchleypark.org.uk/cms/record_attachments/1776.pdf|Bletchley Alphabet>> mentions Hugh Foss:



> _F_ is for Foss – six foot in his shoes  

> Seen in a kilt, but nir tartan troos  

> If on a Friday a stroll you will take  

> You''ll find him dancing a reel by the lake.



<<http://www.oxforddnb.com/view/article/75595|Hugh Foss>> in the *Oxford Dictionary of National Biography*  

<<https://www.bletchleypark.org.uk/roll-of-honour/3153|Hugh Foss>> in the <<https://www.bletchleypark.org.uk/|Bletchley Park web site>>''s “Roll of Honour”



Although Hugh’s interest in new Scottish dances became clear during his editorship of The Reel, the vast bulk of his own dances did not emerge in print until after he had retired in 1956 and moved to Dalry in Scotland. The one book of his dances that appeared before was the <<ddpub:#152|Angus Fitchet Album>>, published by J. S. Kerr around 1955, for which he was asked to fit dances to tunes composed by <<ddp:Fitchet, Angus#1554>>, then a well-known Scottish fiddler and bandleader. From that book, Hugh’s dance <<ddd:J. B. Milne#3172>> has remained popular to the present day.

But although that book must have proved popular – it was re-issued twice – it was clear that music publishers were not comfortable with the artwork challenges of complicated Scottish dance diagrams. So starting about 1963, Hugh began producing his own books and leaflets. He also produced <<ddpub:#155|sheets and leaflets>> featuring dances by other devisors, gave advice on publication, and published at least one album solely of music, <<ddpub:The Ashley Album#341>> with tunes by <<ddp:Main, Nan#1607>>.



Apart from publishing many dance instructions, Hugh also wrote books about SCD and its history, for example <<http://www.rscds-swws.org/news/stories/Foss-SCD-Evolution.pdf|Notes on Evolution in Scottish Country Dancing>>.

He also wrote many articles for The Reel which were later gathered into leaflets called <<ddpub:#406|Roll Back the Carpet>> and We Agree to Differ.



Given Hugh Foss’s close association with *The Reel*, many articles in it over the years have been connected with him, his role in RSCDS London Branch and his dances.

Two recent articles by <<ddp:Conrad, Adrian#1276>>  in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-302-Electronic.pdf#page=8|issue 302>> and <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/05/Reel-303-electronic.pdf#page=8|issue 303>> focus on Hugh’s legacy to SCD, and at the end of the second article is an index to other earlier ones, notably the fine biography of Hugh in <<https://www.rscdslondon.org.uk/wp-content/uploads/2017/09/Reel-200.pdf#page=8|issue 200>> by its editor Andrew Kellett.

');
INSERT INTO 'person' VALUES (2677, NULL, '2021-10-04 16:03:46.737437+00', 'Glasspool, Terry', '', 'Terry Glasspool', 'Vestal, NY, USA', 'tglasspool@stny.rr.com', 1, 1, 0, 0, NULL, 0, 0, NULL, 'His former website is accessible via the <<https://web.archive.org/web/20050221032222/http://home.stny.rr.com/glasshall/dances.html|wayback machine>> archive.');
INSERT INTO 'person' VALUES (51, NULL, '2020-04-04 21:25:20.10934+00', 'Briscoe, Melbourne', '', 'Melbourne Briscoe', '', 'mail@briscoe.com', 1, 1, 0, 0, NULL, 0, 0, NULL, ' Melbourne Briscoe is typically addressed as Mel Briscoe');
INSERT INTO 'person' VALUES (1585, NULL, '2020-04-07 14:51:06.477748+00', 'Crowe, Robert Forsyth', '', 'Robert Forsyth Crowe', '', '', 0, 0, 1, 1, NULL, 0, 2014, NULL, 'Also known as Bobby Crowe.



There is a <<https://boxandfiddlearchive.weebly.com/bobby-crowe-2014.html|Box and Fiddle article>> about him.');
INSERT INTO 'person' VALUES (11941, '2020-04-09 22:13:50.81499+00', '2020-04-09 22:13:50.81499+00', 'Tanner, Jamie', '', 'Jamie Tanner', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1502, NULL, '2020-04-21 23:26:37.470809+00', 'Johnstone, Muriel A', 'Muriel Johnstone', 'Muriel A Johnstone', 'Pitlochry, Perthshire', 'murieljohnstone@scotscores.com', 1, 1, 1, 1, NULL, 0, 0, NULL, '##>>

A long interview with Muriel was included in the first issue of the Society magazine, *The Scottish country dancer*, in the Autumn of 2005. The introduction to that article reads:



Muriel Johnstone, the most prolific composer of Scottish country dance music ever, and one of the Society’s best-loved musicians, grew up in the Ayrshire port of Ardrossan in a family steeped in country dancing and country dance music. Both her parents were dancers. Her mother, Dorothy Johnstone, the well-known class musician, played at Summer School for many years. Muriel started ballet at the age of three, but from the age of eight till she went to university, she attended the branch children’s class, taught by Ann Hughes.  



Her branch was North West Ayrshire, founded by Alastair Aitkenhead as a young man straight out of Jordanhill. Muriel then studied music at Edinburgh University, dancing with New Scotland. She then trained as a teacher at Moray House College of Education. While there she took her preliminary Certificate, but it was not till 1990 that she took her Full Certificate. From 1977 till 2002 Muriel was responsible for arranging the Society’s music. After living in the States for some years, she and her husband and fellow teacher, Bill Zobel, moved to Canada.  In 2011, Muriel and Bill returned to Scotland and now reside in Pitlochry, Perthshire.

  

Note April 2020: Muriel and Bill have the website https://scotscores.com, where more information is available







');
INSERT INTO 'person' VALUES (10714, '2013-01-21 23:45:10.154829+00', '2020-09-30 10:13:15.318553+00', 'Lomath, James', '', 'James Lomath', 'San Francisco, USA', '', 1, 0, 0, 0, NULL, 0, 2018, NULL, 'James Lomath died in Santa Monica, California on June 16, 2018. An obituary was published in San Francisco newsletter, The Reel and Strathspeyper, Vol 55 No 1, Sept/Oct 2018

<<https://rscds-sf.org/newsletters/pdf/2018.09.pdf>>.');
INSERT INTO 'person' VALUES (11983, '2020-09-30 15:04:12.876098+00', '2020-09-30 23:57:08.220652+00', 'Steinbach, Kirsten and Heckmann, Jens', '', 'Kirsten Steinbach and Jens Heckmann', 'Freiburg, Germany', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3545, NULL, '2020-10-05 23:56:45.37702+00', 'Little, Hope', '', 'Hope Little', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (210, NULL, '2020-04-26 09:02:35.360586+00', 'Keppie, John Duncan', '', 'John Duncan Keppie', '', 'johnduncankeppie@gmail.com', 1, 1, 1, 1, NULL, 0, 0, NULL, 'See <<http://www.minicrib.org.uk/Keppie.html>> for PDFs of all publications by Duncan and Maggie Keppie.');
INSERT INTO 'person' VALUES (594, NULL, '2020-04-26 16:34:40.651183+00', 'Spain, Diane', '', 'Diane Spain', 'Oak Park, California, US', 'spain@zetetix.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11942, '2020-05-07 08:41:42.145221+00', '2020-05-07 23:00:56.147154+00', 'Uren, Katherine', '', 'Katherine Uren', 'Auckland, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11943, '2020-05-08 14:06:32.951733+00', '2020-05-08 14:06:32.951733+00', 'Uren, Andrew', '', 'Andrew Uren', 'Auckland, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11944, '2020-05-08 14:07:27.665605+00', '2020-05-08 14:08:15.562654+00', 'Uren, Katherine and Andrew', '', 'Katherine and Andrew Uren', 'Auckland, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11945, '2020-05-08 18:43:22.501852+00', '2020-05-08 23:56:58.733879+00', 'Pinkman, Robert P/M', '', 'P/M Robert Pinkman', '', '', 0, 0, 1, 0, NULL, 1953, 2012, NULL, 'Known as Rab Pinkman.');
INSERT INTO 'person' VALUES (2461, NULL, '2020-05-09 18:04:52.83178+00', 'Martin-Hardie, Margaret', '', 'Margaret Martin-Hardie', '', '', 0, 0, 1, 0, NULL, 1832, 1905, NULL, '');
INSERT INTO 'person' VALUES (443, NULL, '2020-05-28 07:52:09.622235+00', 'Button and Whittaker', '', 'Button and Whittaker', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, 'Also spelled as "Button and Whitaker" with a single t. For more information see issue <<http://my.strathspey.org/dd/issue/1628/>>.');
INSERT INTO 'person' VALUES (2334, NULL, '2020-05-09 23:56:45.879396+00', 'MacLaren, A', '', 'A MacLaren', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11946, '2020-05-09 22:44:07.251714+00', '2020-05-09 23:56:49.462484+00', 'McElney (nee Gibbs), Shelley', '', 'Shelley McElney (nee Gibbs)', 'Born in Canada, now St Andrews', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11947, '2020-05-11 20:00:47.169654+00', '2020-05-11 20:00:47.169654+00', 'Anderson, A', '', 'A Anderson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'It is not know if this is the same person as <<ddp:#10139>>.');
INSERT INTO 'person' VALUES (11948, '2020-05-16 17:32:07.448242+00', '2020-05-16 17:45:29.35824+00', 'Graziani, Samuele', '', 'Samuele Graziani', 'Bologna, Italy', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (980, NULL, '2020-05-20 19:27:18.474789+00', 'Vries, Ruud de', '', 'Ruud de Vries', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11950, '2020-05-20 19:32:24.765747+00', '2020-05-20 19:32:24.765747+00', 'Walker, D', '', 'D Walker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11949, '2020-05-20 19:28:25.966141+00', '2020-05-20 23:57:15.13219+00', 'Vries, Ruud and Elly de', '', 'Ruud and Elly de Vries', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11951, '2020-05-21 09:36:50.905639+00', '2020-05-21 09:36:50.905639+00', 'Wilson, Patricia', '', 'Patricia Wilson', 'North Berwick', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11952, '2020-05-26 20:04:42.548937+00', '2020-05-26 23:56:33.823004+00', 'Hunter, Charlie and Alastair', '', 'Charlie and Alastair Hunter', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11953, '2020-05-29 10:23:28.529265+00', '2020-05-29 23:56:08.337929+00', 'Bluebell Scottish Country Dance Trio', 'Bluebell SCD Trio', 'Bluebell SCD Trio', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11954, '2020-05-29 10:24:20.202269+00', '2020-05-29 23:57:03.582815+00', 'Saito, Fumitaka', '', 'Fumitaka Saito', 'Tokyo', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11286, '2016-06-30 17:37:19.544791+00', '2020-06-04 19:42:07.951539+00', 'J. A. Copeland', '', 'Copeland, J. A.', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'First name Jen (attribute of MiniCrib for A Jig for Julian).');
INSERT INTO 'person' VALUES (11955, '2020-06-04 20:49:01.892625+00', '2020-06-04 20:49:01.892625+00', 'Beaumont, Peter', '', 'Peter Beaumont', 'Wellington, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11585, '2018-01-13 11:59:41.134514+00', '2020-06-04 21:11:21.868347+00', 'Miller, Neville', '', 'Neville Miller', 'Kerikeri, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11957, '2020-06-04 21:03:03.978715+00', '2020-06-04 23:56:23.532024+00', 'Foster, Peter', '', 'Peter Foster', 'Canberra, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11956, '2020-06-04 20:55:30.37867+00', '2020-06-04 23:56:29.024383+00', 'Gunning, Brian', '', 'Brian Gunning', 'Canberra, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11958, '2020-06-11 19:05:21.635962+00', '2020-06-11 19:05:21.635962+00', 'McKerron, D / Clark, P / Evans, A', '', 'D McKerron / P Clark / A Evans', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11959, '2020-06-11 19:52:28.643597+00', '2020-06-11 19:52:28.643597+00', 'Richardson, B / McLeod, D / Wilson, I', '', 'B Richardson / D McLeod / I Wilson', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'Bill Richardson, Derek McLeod, Iain Wilson');
INSERT INTO 'person' VALUES (11960, '2020-06-11 20:08:39.351629+00', '2020-06-11 20:08:39.351629+00', 'Clement, B / Richardson, B / Wilson, I', '', 'B Clement / B Richardson / I Wilson', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1463, NULL, '2020-06-11 23:56:41.094933+00', 'McLeod, Derek', '', 'Derek McLeod', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11961, '2020-06-16 18:13:35.686318+00', '2020-06-16 18:13:35.686318+00', 'Brown, Ilona', '', 'Ilona Brown', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11962, '2020-06-16 18:13:57.653892+00', '2020-06-16 18:14:57.98359+00', 'MacFadyen, Susan', '', 'Susan MacFadyen', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11415, '2016-11-06 17:20:20.314529+00', '2020-06-16 18:35:56.017085+00', 'Francis, Richard', '', 'Richard Francis', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1042, NULL, '2020-07-04 23:56:24.76875+00', 'Fordyce, A Bruce', '', 'A Bruce Fordyce', '', '', 1, 1, 1, 1, NULL, 1925, 2004, NULL, '');
INSERT INTO 'person' VALUES (11977, '2020-08-25 09:29:39.417128+00', '2020-08-25 09:29:39.417128+00', 'Lusky, Hans-Georg', '', 'Hans-Georg Lusky', 'Frankfurt, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10451, NULL, '2020-08-25 23:56:24.298637+00', 'Fischer, Carola', '', 'Carola Fischer', 'Schluechtern, Germany', 'info@kuckucksnest.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11978, '2020-08-26 14:03:03.12092+00', '2020-08-26 23:56:35.471755+00', 'Hyde, Loralee', '', 'Loralee Hyde', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11979, '2020-08-26 14:04:26.024119+00', '2020-08-26 23:56:35.485898+00', 'Hyde, Loralee & Robson, Maureen', '', 'Loralee Hyde & Maureen Robson', 'New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11980, '2020-08-27 20:24:54.001033+00', '2020-08-27 23:57:03.276294+00', 'RSCDS Twin Cities Branch Members', '', 'RSCDS Twin Cities Branch Members', '', '', 1, 0, 0, 0, NULL, 1975, 0, NULL, '');
INSERT INTO 'person' VALUES (3359, NULL, '2020-09-01 08:32:59.794521+00', 'Shakespeare, Bob', '', 'Bob Shakespeare', 'Coventry, UK', '', 0, 0, 1, 0, NULL, 1942, 2020, NULL, '');
INSERT INTO 'person' VALUES (10473, NULL, '2020-09-06 10:55:51.462839+00', 'Kefelas, Glenys', '', 'Glenys Kefelas', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Likely duplicate of <<ddp:#10830>>');
INSERT INTO 'person' VALUES (10786, '2013-05-27 16:33:40.370188+00', '2020-09-06 11:36:52.013836+00', 'Reznick, Greg', '', 'Greg Reznick', 'San Francisco', '', 1, 0, 0, 0, NULL, 1955, 2018, NULL, 'There is a <<https://youtu.be/DHwRtMgPQfI|video tribute to Greg Reznick>> made by <<ddp:#11877>>.');
INSERT INTO 'person' VALUES (11982, '2020-09-13 21:31:52.423485+00', '2020-09-13 21:32:13.204198+00', 'Kynaston, Nathaniel', '', 'Nathaniel Kynaston', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Active in the early 18th century as a deviser or dances and composer of tunes. But otherwise little is known of him (according to https://www.folkmusic.net/htmfiles/webrevs/wgs298cd.htm).');
INSERT INTO 'person' VALUES (1476, NULL, '2020-09-19 22:03:50.588441+00', 'Pringle, John', '', 'John Pringle', '', '', 0, 0, 1, 0, NULL, 1770, 0, NULL, 'This information about John Pringle has been distilled from issues <<https://my.strathspey.org/dd/issue/2174/|2174>> and <<https://my.strathspey.org/dd/issue/2175/|2175>>.



He was born in 1770, probably in the Borders, but settled in Edinburgh. He was a fiddler and composer and also described as a dancing master. He was half brother to John Howison who was also a fiddler.



He published two collections of tunes 1801 and 1802. Some of these were used for SCD and some for step dance, eg Robinslaw, for Highland Ladies (Rene Fidler). He was credited with writing the tune for "Dance to your Daddy, my bonny Babby", still a popular Tyneside folk song.



He accompanied Lord Minto to Calcutta but unfortunately died shortly after arriving though the exact date is not known.');
INSERT INTO 'person' VALUES (96, NULL, '2020-09-27 08:38:03.127085+00', 'Dee, Sally', '', 'Sally Dee', 'Cambridge, MA, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'See also the website <<http://www.pixton.org/scottishinsalem/sally.html>> set up in her honour by some of her friends.');
INSERT INTO 'person' VALUES (11981, '2020-08-31 20:26:55.426283+00', '2023-01-04 22:26:57.875602+00', 'Gerrie, Blair', '', 'Blair Gerrie', 'Toronto, Canada', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (98, NULL, '2023-02-03 22:51:42.16619+00', 'Deeside Caledonian Society', '', 'Deeside Caledonian Society', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, 'This was the group where <<ddp:Upton, Charles#2705>>, creator of MiniCribs, used to dance.



Sadly after running for 65 years the group closed down in November 2022 (information from <<ddp:Haynes, David#11000|David Haynes>> of the current <<ddp:MiniCrib#11464>> team).');
INSERT INTO 'person' VALUES (3589, NULL, '2020-10-11 17:06:55.053466+00', 'Young, Marion', '', 'Marion Young', 'Dunfermline, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11986, '2020-10-11 17:15:21.962113+00', '2020-10-11 17:15:21.962113+00', 'Ansell, P', '', 'P Ansell', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11987, '2020-10-11 17:34:00.119881+00', '2020-10-11 23:56:51.345963+00', 'McIntosh, Mary', '', 'Mary McIntosh', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11988, '2020-10-18 09:39:09.874177+00', '2020-10-18 09:39:29.282083+00', 'Williams, Graham', '', 'Graham Williams', 'Whitby, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11991, '2020-10-29 17:53:48.749654+00', '2020-10-30 00:56:51.859368+00', 'MacNiven, Duncan', '', 'Duncan MacNiven', 'Kilchoman, Islay', '', 0, 0, 1, 0, NULL, 1880, 1955, NULL, 'Duncan MacNivan and his brother Charles were born in Wester Ross, but moved later to their fathers home island, Islay. 



They were known as Bàird Chill-Chomain or Kilchoman Bards.



For more information see https://www.islayinfo.com/islay-bards-duncan-charles-macniven-kilchoman.html');
INSERT INTO 'person' VALUES (11990, '2020-10-29 16:53:45.432301+00', '2020-10-30 00:56:55.808719+00', 'Mclaren Hay, Jacca R A', '', 'Jacca R A Mclaren Hay', 'Stirling', '', 0, 0, 1, 0, NULL, 1896, 1993, NULL, 'Jacca Robina Alison Mclaren Hay and the Hay family used to run Hay’s Music Store in Stirling. (see e.g. https://www.smithartgalleryandmuseum.co.uk/hays-music-store-stirling/)



The piano duo Jenna and Jacca Hay played and recorded records in the mid of the 20th century, some recordings can be found online at https://raretunes.org/jenna-and-jacca-hay-2/



She died at the age of 97 and was burried at Ballengeich Cemetery in Stirling. ');
INSERT INTO 'person' VALUES (11992, '2020-10-31 10:41:17.418594+00', '2020-10-31 10:41:17.418594+00', 'Pryde, Jimmy', '', 'P/M Jimmy Pryde', 'Bowden, Scotland', '', 0, 0, 1, 0, NULL, 1929, 2009, NULL, 'For obituaries see <<https://www.pipesdrums.com/article/Jimmy-Pryde-1929-2009/|here>> and <<https://www.heraldscotland.com/news/12385103.jimmy-pryde/|here>>.');
INSERT INTO 'person' VALUES (11993, '2020-10-31 10:46:06.633503+00', '2020-10-31 10:46:06.633503+00', 'Green, Philip', '', 'Philip Green', 'UK', '', 0, 0, 1, 0, NULL, 1911, 1982, NULL, 'See also <<https://en.wikipedia.org/wiki/Philip_Green_(composer)>>.');
INSERT INTO 'person' VALUES (11989, '2020-10-29 16:44:34.685846+00', '2020-10-30 00:56:16.162771+00', 'Chatt, Robert', '', 'Robert Chatt', 'Wark', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11995, '2020-11-08 12:15:39.428529+00', '2020-11-08 12:15:39.428529+00', 'Unsworth, Ken', '', 'Ken Unsworth', 'Merseryside, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Ken is Lancashire & Cheshire Federation of Scottish Societies Chieftain and a member of West Derby Caledonian Society (Liverpool).');
INSERT INTO 'person' VALUES (11994, '2020-10-31 11:04:11.309409+00', '2020-11-01 00:56:43.37605+00', 'Logan & co', '', 'Logan & co', 'Scotland', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11456, '2017-03-01 12:08:13.553772+00', '2020-11-07 11:03:57.342636+00', 'Chennault, Elizabeth', '', 'Elizabeth Chennault', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Name found as dance author on the programme of the September Dance Party, Saturday, September 21, 2013,  Austin, TX. There the name is "Channault" but the Danciemation video has "Chennault".');
INSERT INTO 'person' VALUES (11996, '2020-11-08 12:16:27.30011+00', '2020-11-08 12:16:27.30011+00', 'Ross, Stuart & Unsworth, Ken', '', 'Stuart Ross & Ken Unsworth', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11997, '2020-11-09 05:05:18.629975+00', '2020-11-09 05:05:18.629975+00', 'Walter, Cord', '', 'Cord Walter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10729, '2013-01-23 13:40:32.956846+00', '2021-01-23 13:56:39.157295+00', 'Reid, Liz', '', 'Liz Reid', 'West Lothian?', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3384, NULL, '2021-01-23 13:57:29.736146+00', 'Reid, L', '', 'L Reid', 'N. Wales', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'The deviser of <<ddd:Forty-five Years On>> is given as Lorna Reid. It is not certain if this is the same person as the deviser of <<ddd:Diamond Jubilee 2012>> attributed simply to "L Reid".');
INSERT INTO 'person' VALUES (313, NULL, '2021-02-18 13:40:17.183721+00', 'Priddey, Barry', '', 'Barry Priddey', 'RSCDS Sutton Coldfield ', '', 1, 1, 0, 0, NULL, 1928, 1996, NULL, 'An article about Barry Priddey, by Frances Richardson, appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2020/10/Reel-313-Electronic.pdf#page=12|issue 313 of The Reel>>.');
INSERT INTO 'person' VALUES (527, NULL, '2021-07-30 12:49:25.366325+00', 'Cass, John', '', 'John Cass', 'Newcastle, UK', '', 1, 0, 0, 0, NULL, 1922, 2020, NULL, '');
INSERT INTO 'person' VALUES (12000, '2020-11-14 14:20:10.079037+00', '2020-11-14 14:20:10.079037+00', 'Uren, Emma', '', 'Emma Uren', 'Auckland, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11998, '2020-11-10 07:33:08.853087+00', '2020-11-11 00:56:42.636521+00', 'Johnston, Roderick Roddy', '', 'Roddy Johnston', 'Maxton, Borders', 'roderick.johnston@icloud.com', 0, 1, 1, 0, NULL, 0, 0, NULL, 'Information printed in the book “Winds of Change” (2018):



Roderick (Roddy) Johnston. was brought up in Corby, possibly better known as Little Scotland, Roddy studied the classical accordion from age of 10 and graduated through the British College of Accordionists exam structure to Final Grade. In the ’60s he was regional accordion champion and won a place in the finals of the All British Accordion Championships. He was also a member of the UK Champion Accordion Orchestra. After completing his studies he taught the accordion for a number of years before a change of career took him away from music.



Since returning to the accordion his love of Scottish Traditional Music has determined his musical direction. He attended Musician courses run by the RSCDS and now plays for local branch dance classes and at St Andrews RSCDS Summer School. Roddy also plays the Scottish Small Pipes. He now resides near St.Boswells, in the Scottish Borders, in sight of the Eildon Hills.');
INSERT INTO 'person' VALUES (10973, '2014-07-11 12:57:16.974698+00', '2020-11-11 00:56:48.967253+00', 'Lynn, Seonaid', '', 'Seonaid Lynn', 'Edinburgh', '', 0, 1, 1, 0, NULL, 0, 0, NULL, 'Information printed in the book “Winds of Change” (2018):



Seonaid Lynn was born in Edinburgh, learning piano and violin from an early age. Growing up in a home full of song and dance, her love of music, particularly traditional music, stemmed from what she heard around her. Moving to the Scottish Borders for work, Seonaid continued her interest in traditional music, focussing on singing. She performed regularly at Folk Clubs and events throughout Scotland and her love of singing continues. In 2010 she founded, and continues to run, an adult choir in Edinburgh. Choral conducting is a major interest and a skill she continues to develop.



Seonaid’s interest in playing for dancing grew after she moved back to Edinburgh and she attended her first RSCDS Summer School at St Andrews in 2007. She now plays fiddle for her local dance group and at the RSCDS St Andrews Summer School.

');
INSERT INTO 'person' VALUES (11999, '2020-11-10 07:33:47.672037+00', '2020-11-11 00:56:48.985135+00', 'Lynn, Seonaid & Johnston, Roddy', 'Lynn & Johnston', 'Seonaid Lynn & Roddy Johnston', '', 'roderick.johnston@icloud.com', 0, 1, 0, 0, NULL, 0, 0, NULL, 'Seonaid Lynn and Roddy Johnston play regularly together for RSCDS dances and Ceilidhs. They have been fortunate enough to play for Clubs and dances across the UK, France and Canada. Both also enjoy dancing when the opportunity arises. (information printed in their book “Winds of Change”, 2018)



Furthermore, Seonaid and Roddy have published two booklets of tunes together, namely “Winds of Change” in 2018 and "The Border Connection" in September 2020.



For more information on the two, please see their SCDDB entries.');
INSERT INTO 'person' VALUES (12002, '2020-11-14 14:32:17.116872+00', '2020-11-14 14:32:17.116872+00', 'Charles, Hughie', '', 'Hughie Charles', '', '', 0, 0, 1, 0, NULL, 1907, 1995, NULL, '');
INSERT INTO 'person' VALUES (12003, '2020-11-14 14:35:16.850962+00', '2020-11-14 14:35:16.850962+00', 'Parker, Ross & Charles, Hughie', '', 'Ross Parker & Hughie Charles', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12001, '2020-11-14 14:29:13.136484+00', '2020-11-15 00:57:04.763422+00', 'Parker, Ross', '', 'Ross Parker', '', '', 0, 0, 1, 0, NULL, 1914, 1974, NULL, '');
INSERT INTO 'person' VALUES (175, NULL, '2020-11-15 20:35:22.173775+00', 'Haynes, Derek', '', 'Derek Haynes', 'Carnforth, Lancashire, UK', '', 1, 1, 0, 0, NULL, 1932, 2005, NULL, '##>>

The citation by Liverpool Branch supporting the award of the Society’s Scroll of Honour to Derek in 2003 can be summarised:



{{quote}}

Derek Haynes began Scottish country dancing in 1953 and in 1954 joined Liverpool Branch where he became a Branch teacher, committee member and treasurer. As well as taking a regular class, Derek taught both country and Highland dancing at many day and weekend schools throughout the UK and at the Society’s Summer and Winter Schools.



{{quote}}

Derek was also a deviser of Scottish country dances and, in addition to three published by the RSCDS, he produced several collections of dances sold in aid of cancer charities.



{{quote}}

Derek died in April 2005 and was the subject of a two pages of reminiscence and appreciation in the first issue of the Society magazine, *The Scottish Country Dancer*, in Autumn 2005.

##<<');
INSERT INTO 'person' VALUES (12004, '2020-11-17 19:53:35.702899+00', '2020-11-17 19:53:35.702899+00', 'Cottle, Alan & McKenna, Lesley', '', 'Alan Cottle & Lesley McKenna', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1643, NULL, '2020-11-21 21:13:49.428564+00', 'Elmes, Peter', '', 'Peter Elmes', 'Wellington, New Zealand', '', 0, 0, 1, 1, NULL, 0, 2020, NULL, 'Some tributes from New Zealand SCD clubs on his retirement in 2018 from 50 years of playing his button accordion can be found at:



- <<http://www.johnsonvillescd.org.nz/2018/12/20/peter-elmes-photo-history/>>

- <<http://www.johnsonvillescd.org.nz/2018/12/20/farewell-peter-elmes/>>

- <<http://www.johnsonvillescd.org.nz/2018/12/20/tribute-peter-elmes/>>');
INSERT INTO 'person' VALUES (12005, '2020-11-22 18:03:45.432707+00', '2020-11-23 00:56:30.665283+00', 'Goldthorpe, Elaine', '', 'Elaine Goldthorpe', 'Auckland, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11369, '2016-09-16 18:55:48.727001+00', '2020-12-02 10:45:39.188838+00', 'Engel-Wilson, Carolyn', '', 'Carolyn Engel- Wilson', 'Phoenix, AZ, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12006, '2020-12-03 21:33:48.895536+00', '2020-12-03 21:33:48.895536+00', 'Pitcurr, J Smith', '', 'J Smith Pitcurr', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12007, '2020-12-04 11:05:33.217917+00', '2020-12-04 11:05:33.217917+00', 'Jackson, John', '', 'John Jackson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (13, NULL, '2020-12-05 18:21:03.283277+00', 'Attwood, Jean', '', 'Jean Attwood', 'Formerly Loughborough, UK', '', 1, 1, 0, 0, NULL, 1934, 2008, NULL, 'Anybody who wishes to purchase any of her dance books should contact Johnnie and Margaret Gibb on 01509 890514.



There is some biographical information in the <<https://dances.e-cribs.org/Alexander_Leaflets_Foreword.pdf|forward to the Alexander leaflets>>.');
INSERT INTO 'person' VALUES (2813, NULL, '2020-12-28 19:27:07.563052+00', 'Cape Town Branch RSCDS', '', 'Cape Town Branch RSCDS', 'Cape Town, South Africa', '', 0, 1, 0, 0, NULL, 0, 0, NULL, 'A list of dances written by and for members of Cape Town and other South African branches can be found at <<http://www.scd.za.net/home/dance-instructions>>.');
INSERT INTO 'person' VALUES (12008, '2020-12-28 20:15:40.455026+00', '2020-12-28 20:15:40.455026+00', 'Hodgson, Val & Williams, Jen', '', 'Val Hodgson & Jen Williams', 'Cape Town, South Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (824, NULL, '2020-12-31 20:22:13.748658+00', 'Mill, Charlie', '', 'Charlie Mill', 'Dundee, Scotland', '', 1, 1, 0, 0, NULL, 1940, 2004, NULL, '');
INSERT INTO 'person' VALUES (41, NULL, '2021-01-02 10:46:20.5609+00', 'Grayson, Moggie', '', 'Moggie Grayson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Moggie Grayson was formerly listed <<https://my.strathspey.org/dd/issue/2214/|incorrectly>> as "Maggie".');
INSERT INTO 'person' VALUES (3383, NULL, '2021-01-03 00:57:20.70871+00', 'Turner, John', '', 'John Turner', 'Chesterfield (Greater Richmond), Virginia, USA', '', 0, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12009, '2021-01-03 11:57:24.013764+00', '2021-01-03 11:57:24.013764+00', 'Fiddletree Music', '', 'Fiddletree Music', 'Virginia, USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, 'Fiddletree Music Co. Inc.');
INSERT INTO 'person' VALUES (10073, NULL, '2021-01-05 19:26:35.097273+00', 'Knight, A', 'A Knight', 'A Knight', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Presumed to be Andrew Knight who is given as the composer of The Braid Burn in the instructions for <<ddd:February Gold#16106>>.');
INSERT INTO 'person' VALUES (2894, NULL, '2021-01-16 14:44:18.754133+00', 'Sparling, Gordon', '', 'Gordon Sparling', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'When contacted in early 2021, Gordon confirmed being the deviser of his two dances, but he does not have any original instructions himself; it was so long ago that he can’t even remember how they went. The dances were never tried out at his local dance group.

');
INSERT INTO 'person' VALUES (12010, '2021-01-18 20:34:16.695547+00', '2021-01-19 11:59:02.92437+00', 'Gordon-Harvey, Rosemary', '', 'Rosemary Gordon-Harvey', 'Edinburgh, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Rosemary Gordon-Harvey was the Edinburgh RSCDS Branch Secretary for a period in the 1980s.');
INSERT INTO 'person' VALUES (12011, '2021-01-22 10:56:25.030589+00', '2021-01-22 10:56:25.030589+00', 'Collins, Andrew', '', 'Andrew Collins', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1135, NULL, '2021-01-27 16:39:20.900638+00', 'Miskoe, Sylvia', '', 'Sylvia Miskoe', 'Concord, NH, USA', 'SMiskoe@aol.com', 1, 1, 1, 1, NULL, 0, 0, NULL, 'Music play an important part in Silvia''s life from early on. With about 10 years of age she learned the piano. In college time she started playing the accordion and was playing for square and contra dancing.



She joined the NH Scottish Dancers in 1954. At that time it was common to dance to recordings from Scotland. Even in the early 1970 when there was a growing number of good musicians around, Scottish dancers still resisted hiring locals, preferring their recordings from Scotland. There was the opinion prevailing that to play SCD music you needed to be a born Scot.

Finally, Silvia and others were able to convince the Branch to hire Angus Mackinnon, a well known Scottish band leader, to give a workshop about how to play for Scottish Country Dancing.



After that, four musicians, Silvia (accordion), Cal Howard (bass), Allan Chertok (drums), and Ralph Jones (flute), founded the first SCD band on East Coast, which was later named The White Cockade.



Please also read Silvia''s <<https://www.mainefiddlecamp.org/interview-with-sylivia-miskoe/|interview at the Maine Fiddle Camp>> for lots of interesting information.');
INSERT INTO 'person' VALUES (2042, NULL, '2021-01-27 17:05:32.028796+00', 'White Cockade Scottish Country Dance Band, The', 'White Cockade', 'The White Cockade Scottish Country Dance Band', 'Concord, NH, USA', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'Cal Howard, Allan Chertok, Ralph Jones and Sylvia Miskoe formed a band, eventually named The White Cockade. According an interview by Sylvia, they were the first, and for a while, the only Scottish Country Dance Band on the East Coast.



Main members of the band were Sylvia Miskoe (accordion), Ralph Thompson and Vince O''Donnell (fiddles), Ralph Jones (flute), Cal Howard (Bass), RP Hale (piano and hammer dulcimer) and Allan Chertok (drums).');
INSERT INTO 'person' VALUES (1264, NULL, '2021-01-28 18:48:37.50137+00', 'Burrage, Priscilla / Stein, Ben', '', 'Priscilla Burrage / Ben Stein', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12012, '2021-01-27 14:53:48.915121+00', '2021-01-27 14:53:48.915121+00', 'Thompson, Ralph', '', 'Ralph Thompson', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'Ralph Thompson was playing fiddle in the White Cockade Scottish Country Dance Band.');
INSERT INTO 'person' VALUES (480, NULL, '2021-01-27 16:46:53.308809+00', 'Burrage, Priscilla', '', 'Priscilla Burrage', 'Essex, VT, USA', 'pburrage@zoo.uvm.edu', 1, 1, 0, 0, NULL, 1929, 2009, NULL, 'Priscilla was born in Framingham, MA, on December 10, 1929 as Priscilla Margaretta Maurer. She was raised in Margaretville, NY. She graduated from MIT in 1951. She was first married to Milton Raymond and then in 1962 Peter Burrage. She was working for IBM in Poughkeepsie, NY, and Essex, VT, from which she retired in 1991. 



In Scottish country dancing she became a teacher and taught in Burlington, Middlebury and elsewhere for about 40 years. Furthermore, she devised several dozen dances, many of them were published in her own books (together with <<https://my.strathspey.org/dd/person/58/|Sylvia Miskoe>>) <<https://my.strathspey.org/dd/publication/672/|Kitchen Capers>> (1992) and <<https://my.strathspey.org/dd/publication/787/|Cross-Country Capers>> (1996) and other collections of dances.



Priscilla M. Burrage of Essex passed away on June 22, 2009, after fighting cancer for several years.



For more information, see the following <<https://www.legacy.com/obituaries/burlingtonfreepress/obituary.aspx?n=priscilla-m-burrage&pid=128810629|obituary>>.');
INSERT INTO 'person' VALUES (12013, '2021-01-27 14:56:50.778306+00', '2021-01-27 14:56:50.778306+00', 'Jones, Ralph', '', 'Ralph Jones', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'Ralph Jones was playing the flute in the White Cockade Scottish Country Dance Band.');
INSERT INTO 'person' VALUES (12015, '2021-01-27 15:14:52.052774+00', '2021-01-27 15:14:52.052774+00', 'Hale, RP', '', 'RP Hale', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'RP Hale was also playing piano and hammer dulcimer in the White Cockade Scottish Country Dance Band.');
INSERT INTO 'person' VALUES (12014, '2021-01-27 15:01:03.132716+00', '2021-01-27 15:17:42.998026+00', 'Chertok, Allan', '', 'Allan Chertok', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'Allan Chertok was also playing piano in the White Cockade Scottish Country Dance Band.');
INSERT INTO 'person' VALUES (1932, NULL, '2021-01-27 16:19:13.172971+00', 'O''Donnell, Vince', '', 'Vince O''Donnell', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, 'Vince O''Donnell was also playing fiddle in the White Cockade Scottish Country Dance Band.');
INSERT INTO 'person' VALUES (12016, '2021-02-03 13:10:57.350377+00', '2021-02-04 00:56:56.961008+00', 'Peet, Blaine', '', 'Blaine Peet', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12048, '2021-04-19 10:42:42.919977+00', '2021-04-19 10:42:42.919977+00', 'Méaudre Reel', '', 'Méaudre Reel', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12019, '2021-02-05 16:24:41.238197+00', '2021-02-05 16:36:02.486058+00', 'Beylinson, J & Garbuzov, V', '', 'J. Beylinson & V. Garbuzov', 'Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (346, NULL, '2021-02-07 09:56:42.775007+00', 'Shearer, A N', '', 'A N Shearer', 'Kilsyth, Stirlingshire', '', 1, 0, 0, 0, NULL, 1920, 2010, NULL, 'Kilsyth was originally in Stirlingshire, but since the 1975 boundary changes is now in North Lanarkshire.



According to the extra info for <<ddd:#6689>> Miss A N Shearer was also known as Nana.');
INSERT INTO 'person' VALUES (3111, NULL, '2021-02-08 12:50:04.806987+00', 'Grant, Frances', '', 'Frances Grant', 'Kilmorack, Scotland', '', 1, 0, 0, 0, NULL, 0, 2019, NULL, 'Frances Grant was dance teacher for the Kilmorack class for almost 3 decades and founding member of Glen Orrin Dancers.');
INSERT INTO 'person' VALUES (455, NULL, '2021-02-14 11:48:24.614275+00', 'Skillern, Thomas', '', 'Thomas Skillern', 'London, UK', '', 1, 1, 0, 0, NULL, 0, 1800, NULL, '*Information from <<https://my.strathspey.org/dd/issue/2226/|issue 2226>>:*



This would be Thomas Skillern, died 1800, music publisher based in London. Not to be confused with his nephew Thomas Skillern (1776-1849), also a London based music publisher under the partnership Skillern & Challoner. Anything published 1800 or earlier is the uncle, anything after 1805 is the nephew.');
INSERT INTO 'person' VALUES (1213, NULL, '2021-02-14 17:35:02.550481+00', 'Wishart, Anne & Williamson, John', '', 'Anne Wishart & John Williamson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (440, NULL, '2021-02-16 14:14:25.314309+00', 'Campbell, Ann', '', 'Ann Campbell', 'Brampton, Ontario.', 'ann.campbell@rogers.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (315, NULL, '2021-02-16 19:28:15.95547+00', 'Queen, Alex T', '', 'Alex T Queen', 'Southport, UK', '', 1, 0, 0, 0, NULL, 1919, 1995, NULL, 'An article about Alex Queen, written by his son David, appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2020/08/Reel-312-electronic.pdf#page=10|The Reel issue 312>>.');
INSERT INTO 'person' VALUES (1836, NULL, '2021-02-18 05:16:08.033775+00', 'Moyes, Fred', 'Fred Moyes', 'Fred Moyes', '', 'fmmusic@sympatico.ca', 1, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2683, NULL, '2021-02-18 17:56:19.86439+00', 'Sturrock, John M', '', 'John M Sturrock', 'Cupar, Fife', 'John.M.Sturrock@btinternet.com', 1, 0, 0, 0, NULL, 1938, 2017, NULL, 'An outline of John’s life can be seen in Lives Remembered in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/05/Reel-303-electronic.pdf#page=15|The Reel 303>>.');
INSERT INTO 'person' VALUES (1205, NULL, '2021-02-18 18:02:55.874975+00', 'Meyer, Owen', '', 'Owen Meyer', 'London, UK', '', 1, 0, 0, 0, NULL, 1937, 2018, NULL, 'Obituary published in Scottish Country Dancer Issue 28, April 2019.



There is also an article about him in the Lives Remembered section of <<https://www.rscdslondon.org.uk/wp-content/uploads/2019/02/Reel-306-electronic.pdf#page=14|The Reel 306>>.');
INSERT INTO 'person' VALUES (1709, NULL, '2021-02-18 19:20:27.258106+00', 'Whitehead, Robert', '', 'Robert Whitehead', '', '', 0, 1, 1, 1, NULL, 0, 0, NULL, 'There is an <<https://www.rscdslondon.org.uk/wp-content/uploads/2019/11/Reel-309-electronic.pdf#page=7|article by Robert Whitehead in issue 309>> of The Reel.');
INSERT INTO 'person' VALUES (3086, NULL, '2021-02-25 14:55:28.212515+00', 'Winter, Jim', '', 'Jim Winter', 'Tunbridge Wells', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'An article on Jim by Pat Noble appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2016/09/2016-05-09-Reel-296.pdf#page=9|issue 296 of The Reel>>.');
INSERT INTO 'person' VALUES (44, NULL, '2021-03-02 17:56:58.558809+00', 'Boyd, Iain', '', 'Iain Boyd', 'Wellington, New Zealand', 'iain_boyd@yahoo.com', 1, 1, 0, 0, NULL, 0, 0, NULL, 'An article by Iain on his early days and dance devising can be found in <<https://www.rscdslondon.org.uk/wp-content/uploads/2020/10/Reel-313-Electronic.pdf#page=9|The Reel 313>>.');
INSERT INTO 'person' VALUES (951, NULL, '2021-02-19 18:57:21.753944+00', 'Brown, Helen', '', 'Helen Brown', 'London', '', 1, 0, 0, 0, NULL, 1927, 2020, NULL, 'An article remembering the life of Helen Ursula Brown appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2020/10/Reel-313-Electronic.pdf#page=16|issue 313 of The Reel>>.');
INSERT INTO 'person' VALUES (12020, '2021-02-19 12:04:15.592979+00', '2021-02-20 04:33:36.678907+00', 'Webb, Stephen and Michon, Nicole', '', 'Stephen Webb (and Nicole Michon)', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12021, '2021-02-23 01:21:34.637317+00', '2021-02-23 01:21:34.637317+00', 'Yahn, Shelby', '', 'Shelby Yahn', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2197, NULL, '2021-02-24 19:56:54.396681+00', 'Martlew, Ken', 'Ken Martlew', 'Ken Martlew', 'Hemel Hempstead, England', 'kenmartlew@aol.com', 1, 0, 1, 1, NULL, 0, 0, NULL, 'An article by Ken on his background and opinions about dancing appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2020/05/Reel-311A-electronic.pdf#page=14|issue 311 of The Reel>>.');
INSERT INTO 'person' VALUES (2626, NULL, '2021-02-24 20:01:03.299333+00', 'Finley, Eric', '', 'Eric Finley', 'Ayrshire', 'ericfinley579@btinternet.com', 1, 0, 1, 0, NULL, 0, 0, NULL, 'An article by Eric on his background and opinions about dancing appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2019/02/Reel-306-electronic.pdf#page=12|issue 306 of The Reel>>.





');
INSERT INTO 'person' VALUES (11182, '2015-08-29 11:02:28.872125+00', '2021-02-25 13:12:57.719216+00', 'Williamson, William', '', 'William Williamson', '', '', 1, 1, 1, 0, NULL, 0, 0, NULL, 'An article by William on his background and opinions about dancing appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/05/Reel-303-electronic.pdf#page=13|issue 303 of The Reel>>.');
INSERT INTO 'person' VALUES (812, NULL, '2021-02-25 13:23:37.075499+00', 'Rousseau, Phillipe', '', 'Phillipe Rousseau', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'An article by Philippe on his background and opinions about dancing appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/08/Reel-304-electronic.pdf#page=11|issue 304 of The Reel>>.');
INSERT INTO 'person' VALUES (2856, NULL, '2021-02-25 13:45:42.470066+00', 'Thomson, Frank', '', 'Frank Thomson', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, 'An article by Frank on his background and opinions about dancing appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2019/05/Reel-307-electronic.pdf#page=13|issue 307 of The Reel>>.');
INSERT INTO 'person' VALUES (10658, '2012-09-16 15:26:34.52003+00', '2021-02-25 13:51:22.662111+00', 'Lindsay, Jim', 'Jim Lindsay', 'Jim Lindsay', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, 'An article by Jim on his background and opinions about dancing appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2020/02/Reel-310-electronic.pdf#page=7|issue 310 of The Reel>>.  



Not to be confused with Jimmy Lindsay, who is a different person.');
INSERT INTO 'person' VALUES (11009, '2014-09-29 13:39:01.090324+00', '2021-02-25 14:13:48.056374+00', 'Prior, Ann', '', 'Ann Prior', 'Bridport, England', '', 1, 0, 0, 0, NULL, 1928, 2020, NULL, 'A tribute to Ann, Bridport Club Founder, by Caroline Morgan-Smith appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2020/10/Reel-313-Electronic.pdf#page=17|issue 313 of The Reel>>.');
INSERT INTO 'person' VALUES (11582, '2018-01-13 10:39:03.437849+00', '2021-05-23 20:17:05.892262+00', 'Deroles, Kathryn', '', 'Kathryn Deroles', 'Matapouri, Northland, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Formerly of Levin, New Zealand.');
INSERT INTO 'person' VALUES (2118, NULL, '2021-06-08 20:41:51.122357+00', 'Gould, Mary-Jane', '', 'Mary-Jane Gould', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (308, NULL, '2021-07-30 04:16:27.753277+00', 'Petyt, Sue', '', 'Sue Petyt', 'Scarborough, North Yorkshire, UK', 'suepetyt@icloud.com', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Website http://www.suepetyt.me.uk/.  Many dance descriptions available.

NB this website will soon disappear. Options for moving it are being investigated...



Formerly in Lochmaben, now Scarborough, North Yorkshire.');
INSERT INTO 'person' VALUES (12051, '2021-07-30 12:48:24.457926+00', '2021-07-30 12:52:27.306938+00', 'Cass, Patricia & Cass, John', '', 'Patricia and John Cass', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (434, NULL, '2021-07-30 18:58:21.051105+00', 'Rhodes, Harry & Jean', '', 'Harry and Jean Rhodes', ' Bethel, Gwynedd, Wales', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1444, NULL, '2021-07-30 21:18:18.476451+00', 'Anderson, J (19C)', '', 'J Anderson (19C)', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'John Anderson');
INSERT INTO 'person' VALUES (12052, '2021-08-02 02:50:36.804742+00', '2021-08-02 02:50:36.804742+00', 'Kingsland, Arthur', '', 'Arthur Kingsland', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1231, NULL, '2021-08-04 12:19:15.375911+00', 'Robertson, Colin', '', 'Colin Robertson', '', 'scotdance@comcast.net', 1, 1, 0, 0, NULL, 0, 2021, NULL, 'Other activities: Historical Scottish dance research.



An <<https://www.rscdslondon.org.uk/wp-content/uploads/2020/02/Reel-310-electronic.pdf#page=9|article in The Reel issue 310>> that Colin wrote about The Sailor''s Hornpipe also contains a little biographical information about him.');
INSERT INTO 'person' VALUES (2487, NULL, '2021-08-09 08:56:32.838758+00', 'Shaw, Pat', '', 'Pat Shaw', '', '', 1, 0, 1, 0, NULL, 1917, 1977, NULL, 'Full name: Patrick Noel Shuldham-Shaw. Mainly known for English country dances: see <<http://www.patshaw.info/>>.');
INSERT INTO 'person' VALUES (884, NULL, '2021-10-11 21:59:22.752192+00', 'Brenchley, John', '', 'John Brenchley', 'Perth, WA, Australia', 'jbrenchley@iinet.net.au', 1, 0, 0, 0, NULL, 0, 0, NULL, 'An article by John on his early days and dance devising can be found in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/11/Reel-305-electronic.pdf#page=9|The Reel 305>>.');
INSERT INTO 'person' VALUES (356, NULL, '2021-11-08 11:22:11.689622+00', 'Skipper, Ann', '', 'Ann Skipper', '', '', 1, 1, 0, 0, NULL, 1925, 2009, NULL, 'Information about Ann Skipper''s death was reported in <<https://my.strathspey.org/dd/issue/2434/|issue 2434>> and <<https://my.strathspey.org/dd/issue/2645/|issue 2645>>.');
INSERT INTO 'person' VALUES (270, NULL, '2021-02-25 17:38:29.701489+00', 'Mitchell, John W', '', 'John W Mitchell', '', '', 1, 1, 0, 0, NULL, 1931, 2013, NULL, 'Obituary published in Scottish Country Dancer, No 16, April 2013:



John Mitchell John Mitchell was introduced to SCD in 1947 and joined the Leeds Branch of the RSCDS in 1963. He was an active member of London Branch from 1966 to the time of his death. He also helped to found the Sussex Association of Scottish Societies, and as its first Chairman he organised an annual Charity Ball, the first day schools in Sussex, and the Sussex Open Air Scottish Dancing Festival, as well as the first teachers’ training courses in the area. A fellow dancer, Pat Hunter, said at John’s memorial, ‘He was nearly always on the floor for each dance – if you could get into his set, or were asked to be his partner, you knew you had arrived as a dancer!’

John gained his SCD teaching certificate in 1972 and taught for the Hangleton SCD Club (which eventually became the Brighton and Hove Branch of the RSCDS) and later the Aldrington Club. Acording to Pat Hunter, his teaching was meticulous in its attention to detail.

The same attention to detail showed in John’s extensive research into the history of SCD. He corresponded with Hugh Foss and Hugh Thurston, wrote many erudite articles for the London Reel, and frequently contributed letters to Scottish Country Dancer (see his last letter in this issue). John was also a prolific writer of new dances and probably devised more new Scottish country dances than anyone else: a total of 827. These were compiled in the Whetherly series, 24 collections published between 1974 and 1990. They included Caddam Wood, The Dundee City Police Jig, Iona Cross, The Cooper’s Wife, and Lord High Admiral.

John was a Fellow of the Society of Antiquaries of Scotland, a Life Governor of the Royal Scottish Corporation, a founder of Scots International, a member of the Scottish Tartan Society, and a Guild Brother of the Incorporation of Wrights of the City of Glasgow. So he was intensely interested in all things Scottish, and worked hard to further interest and participation in SCD. Our sympathy goes to John’s wife Dheirdre and their daughter Alison. 





');
INSERT INTO 'person' VALUES (12035, '2021-04-14 09:32:38.062838+00', '2021-06-22 23:56:34.918424+00', 'Lanvin, Victor', '', 'Victor Lanvin', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (589, NULL, '2021-02-26 00:08:10.284395+00', 'Mayr, Susi', '', 'Susi Mayr', 'Vienna, Austria', '', 1, 0, 0, 0, NULL, 1956, 2012, NULL, 'Susi Mayr was an excellent dancer and teacher of both scottish country dancing and Step Dancing. She was a co-founder of the <<http://www.rscdsvienna.org/|RSCDS Vienna Branch>> and the driving force behind the founding of the <<https://www.rscds-ib.org/|International Branch>>.



Furthermore, she organized the <<https://scdkaleidoscope1.strathspey.org/|SCD Kaleidoscope>> in 2009, the first international conference with presentations and discussions covering many different aspects related to SCD. It was a conference for SCD dancers, teachers and musicians from around the world. The <<https://scdkaleidoscope1.strathspey.org/|conference page>> is still online.



On 7th July 2012 she lost the battle against cancer at an age of only 55 years.



The <<https://www.rscds-ib.org/index.php?page=6|Susi Mayr Fund>> of the International Branch to promote the enjoyment and appreciation of Scottish Country Dancing and its music worldwide is also named after her. 



Tributes and obituaries to Susi have appeared in <<https://www.rscds.org/about/members-magazine|The Scottish Country Dancer 15>>,  on the page of <<https://www.rscds-ib.org/index.php?page=6|The Susi Mayr Fund>> and <<https://www.rscdslondon.org.uk/wp-content/uploads/2013/09/120821Reel281.pdf#page=6|issue 281 of The Reel>>.');
INSERT INTO 'person' VALUES (10629, '2012-06-12 13:50:38.510506+00', '2021-02-28 17:23:44.618555+00', 'Ainsworth, Maureen', '', 'Maureen Ainsworth', '', '', 1, 0, 0, 0, NULL, 1950, 2014, NULL, 'A tribute to Maureen Joyce (née Ainsworth) appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2014/09/140422-Reel-288.pdf#page=13|issue 288>> of The Reel magazine.



Her dances were published under the name Ainsworth. Later in life she married again to Frank Joyce.');
INSERT INTO 'person' VALUES (499, NULL, '2021-02-26 18:13:33.844843+00', 'Anderson, David (19C)', '', 'David Anderson (19C)', '', '', 1, 0, 0, 0, NULL, 1850, 1911, NULL, 'Years of birth and death are not known exactly.



A series of articles about David Anderson by J.F and T.M.Flett were published in <<ddpub:#480>> starting from <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-029-October-1966.pdf#page=4|issue 29>>.');
INSERT INTO 'person' VALUES (777, NULL, '2021-02-28 17:32:44.037501+00', 'Birdsall, G Dale', '', 'G Dale Birdsall', 'Middlebury, Vermont, US', 'gdbirdsall@yahoo.com', 1, 1, 0, 0, NULL, 0, 0, NULL, 'Formerly of Cincinnati, now Vermont.');
INSERT INTO 'person' VALUES (1778, NULL, '2021-03-03 00:56:19.655722+00', 'Forbes, Stuart', '', 'Stuart Forbes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Stuart is a fiddler and part of the Craigievar Band. Information on the band see <<https://www.rscdslondon.org.uk/wp-content/uploads/2014/02/131120-Reel-286.pdf#page=8|issue No 286 of The Reel>>');
INSERT INTO 'person' VALUES (1649, NULL, '2021-03-03 00:57:08.12615+00', 'Walker, Chris', '', 'Chris Walker', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, 'Accordionist and Leader of Silver Cross Band.  

A profile of the _Silver Cross Band_ can be found <<https://www.rscdslondon.org.uk/wp-content/uploads/2017/08/2017-05-21-Reel-300.pdf#page=9|issue 300 of The Reel>>.');
INSERT INTO 'person' VALUES (12034, '2021-04-10 18:05:34.76687+00', '2021-04-10 18:05:55.870258+00', 'Bailey, Jared W.', '', 'Jared W. Bailey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1229, NULL, '2021-04-13 22:27:23.039664+00', 'Gillies, Margaret', '', 'Margaret Gillies', 'Broadford, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Margaret Gillies took the Broadford class for many years till her retirement in 1993.');
INSERT INTO 'person' VALUES (12040, '2021-04-16 15:42:28.597491+00', '2021-04-16 15:42:28.597491+00', 'Cook, Andrew', '', 'Andrew Cook', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12041, '2021-04-17 18:19:51.445533+00', '2021-04-30 17:59:45.748392+00', 'Bouaouaja-Morvan, Alexandra', '', 'Alexandra Bouaouaja-Morvan', '', 'meaudre.reel@gmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (101, NULL, '2021-04-18 18:18:09.389629+00', 'Dickson, John Bowie', '', 'John Bowie Dickson', 'Edinburgh, Scotland', '', 1, 1, 0, 0, NULL, 1919, 1998, NULL, 'A short obituary of John Bowie Dickson was published in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-226-December-1998-February-1999.pdf#page=8|The Reel issue 226>>.');
INSERT INTO 'person' VALUES (11521, '2017-09-05 20:46:18.747424+00', '2021-07-03 23:56:33.682497+00', 'Joubert, Christof', '', 'Christof Joubert', 'Pretoria, S. Africa', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12049, '2021-06-02 16:05:56.073889+00', '2021-06-02 16:06:28.796523+00', 'Hellinghuizer, Els', '', 'Els Hellinghuizer', 'Netherlands', '', 1, 0, 0, 0, 3135, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12050, '2021-06-07 16:00:16.201057+00', '2021-06-07 16:06:07.094991+00', 'Waite, Melva', '', 'Melva Waite', 'Ngaio, Wellington, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3200, NULL, '2021-06-08 20:41:19.544114+00', 'Bruns, Lily', '', 'Lily Bruns', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11785, '2019-02-20 21:03:37.386312+00', '2021-06-11 23:56:22.883834+00', 'Flett, Joan and Tom', '', 'Joan & Tom Flett', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, 'For a description of Tom and Joan Flett''s dance collecting activities see <<https://www.sheffield.ac.uk/alumni/our_alumni/obituary-archive/tom-joan-flett-tribute|this obituary>>. There is also an <<https://insteprt.co.uk/flett-mss/|online collection of their manuscripts>>.



A long article by the Fletts was published in four parts in several issues of <<ddpub:Thistle, The#480>>:

<<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-029-October-1966.pdf#page=4|issue 29>>,

<<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-030-December-1966.pdf#page=6|issue 30>>,

<<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-031-February-1967.pdf#page=4|issue 31>>,

<<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-032-May-1967.pdf#page=5|issue 32>>.');
INSERT INTO 'person' VALUES (10959, '2014-05-09 22:22:42.513617+00', '2021-03-04 12:22:20.03988+00', 'MacCuish Bark, Deirdre', '', 'Deirdre MacCuish Bark', 'Mississauga, Canada', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12022, '2021-03-07 15:24:14.011259+00', '2021-03-07 15:24:14.011259+00', 'Hankes, Diana', '', 'Diana Hankes', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12023, '2021-03-07 16:39:57.030467+00', '2021-03-07 16:39:57.030467+00', 'Hankes, Diana and Phipps, Ken', '', 'Diana Hankes and Ken Phipps', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12037, '2021-04-14 09:42:10.761741+00', '2021-04-14 09:42:10.761741+00', 'Kiernan, Shannon', '', 'Shannon Kiernan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12025, '2021-03-12 22:17:08.336948+00', '2021-03-12 22:22:50.046943+00', 'Sanders, Christopher', '', 'Christopher Sanders', 'Glasgow, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12024, '2021-03-12 16:39:48.605768+00', '2021-03-13 00:56:44.241186+00', 'MacLachlan, Ewen', '', 'Ewen MacLachlan', '', '', 1, 0, 0, 0, NULL, 1799, 1879, NULL, '');
INSERT INTO 'person' VALUES (12026, '2021-03-13 20:03:41.357512+00', '2021-03-13 20:03:41.357512+00', 'Hewitt, Lindsay', '', 'Lindsay Hewitt', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12027, '2021-03-13 20:32:27.653082+00', '2021-03-13 20:32:44.228737+00', 'O''Donnell, Bill', '', 'Bill O''Donnell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12029, '2021-03-13 21:46:28.715672+00', '2021-03-13 21:52:13.002651+00', 'Monument, Cath', '', 'Cath Monument', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Alderney and District Caledonian Society.');
INSERT INTO 'person' VALUES (146, NULL, '2021-03-17 22:22:22.993211+00', 'Goldring, Roy', '', 'Roy Goldring', 'Ilkley, Yorkshire', '', 1, 1, 1, 0, NULL, 0, 2007, NULL, '##>>

Roy died in 2007. The following obituary originally appeared in The Society magazine, *The Scottish country dancer* in April 2008  



Roy was born in south west England where he spent his childhood. When old enough he was drafted into the armed forces. It was during this time that he was flown to Egypt and vowed he would never fly again. He stuck to this vow only relenting to fly to Canada and Norway recently to teach dancing in those countries. His return to civilian life saw him in the Civil Service and moving about the country. In Birmingham he met and married Doreen. When in Surrey they took up Scottish country dancing after trying the English version first. More moves to Newcastle and Harrogate and two sons later, he finally came to Ilkley and joined the Leeds Branch.  



The Ilkley Club started life in the Goldring lounge and when the evening institute class was in danger of being closed for lack of a qualified teacher, Roy and Doreen went to Summer School *[in 1977]* to obtain their certificates. Subsequently he became a committee member and Chairman of Leeds Branch. Along with his interest in Scottish country dancing, he played golf, listened to music from classical to jazz and amassed great knowledge in works of art.  



In the thirty years Roy lived in Ilkley, he emerged as one of our greatest creators of dances and it is in this respect that we will all, and future generations too, remember him. His knowledge of music allowed him to marry his dances to some wonderful tunes. His dances are great to dance – not too complicated but always with some new formation and extremely danceable. There are not many programmes that do not contain at least one of his dances.  

##<<

Thank you Roy for the wonderful legacy you have left us in Scottish country dancing.  



Brenda Burnell





The London Branch magazine *The Reel* has an <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-203-February-April-1993.pdf#page=5|article by Roy Goldring in issue 203>> on devising dances.

Some personal reflections on Roy Goldring by his nephew Richard appear in *The Reel* <<https://www.rscdslondon.org.uk/wp-content/uploads/2017/08/2017-05-21-Reel-300.pdf#page=14|issue 300>>.

');
INSERT INTO 'person' VALUES (2599, NULL, '2021-03-17 22:27:18.708326+00', 'Steed, Dee', '', 'Dee Steed', 'Bristol, UK', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '*From the Friendship Dances book (1998):*

Dee Steed is treasurer for a Charity in Bristol. Originally from Amersham where she started dancing as a child. She has danced and taught in Bristol for many years. Her speciality is teaching children but she enjoys her connection with adult demonstration teams.');
INSERT INTO 'person' VALUES (12030, '2021-03-27 20:29:36.126573+00', '2021-03-27 20:35:40.60866+00', 'Lapa Group Members', 'Lapa Group', 'Lapa Group Members', 'Lisbon, Portugal', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (693, NULL, '2021-03-28 13:15:51.327291+00', 'Williams, Roberta Riegel', '', 'Roberta Riegel Williams', 'Minneapolis, USA', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12031, '2021-03-31 20:08:51.942059+00', '2021-03-31 20:08:51.942059+00', 'Halliday, Hazel', '', 'Hazel Halliday', 'Singapore', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11324, '2016-08-31 20:29:53.96497+00', '2021-04-03 11:18:51.158422+00', 'Mackintosh, Gillian, Garden Richardson, Phyllis & Walker, Rosalind', '', 'Gillian Mackintosh, Phyllis Garden Richardson & Rosalind Walker', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2944, NULL, '2021-04-03 23:57:10.020018+00', 'Thomson, Frank and his Scottish Dance Band', 'Frank Thomson', 'Frank Thomson and his Scottish Dance Band', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1551, NULL, '2021-04-05 23:56:58.37298+00', 'Powrie, Ian', '', 'Ian Powrie', '', '', 0, 1, 1, 1, NULL, 1923, 2011, NULL, 'A brief biography and discography may be found at <<http://www.nigelgatherer.com/perf/fiddlers/ian_powrie.html>>.



The <<https://www.youtube.com/user/IanPowrieMusic/videos|Ian Powrie Music youtube channel>> has a few short videos of Ian Powrie playing including an <<https://youtu.be/rNgysjtF2CQ|excerpt>> from a longer film "Legend of the Fiddle: The Ian Powrie Story".');
INSERT INTO 'person' VALUES (12032, '2021-04-06 21:28:14.86547+00', '2021-04-06 21:36:49.127898+00', 'Faulkner, Mollie', '', 'Mollie Faulkner', 'Bellingham, Washington, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (934, NULL, '2021-04-07 20:47:06.308321+00', 'Richards, Laura & Gilchrist, Hannah', '', 'Richards & Gilchrist', 'Leeds, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Laura Richards and Hannah Gilchrist, aged 9 and 8 respectively, were members of the Leeds Branch children''s class in 1993.');
INSERT INTO 'person' VALUES (12043, '2021-04-19 08:37:56.985913+00', '2021-04-19 23:56:03.497512+00', 'Algoud, Manon', '', 'Manon Algoud', '', '', 0, 0, 0, 0, NULL, 2005, 0, NULL, '');
INSERT INTO 'person' VALUES (12042, '2021-04-18 00:18:51.358097+00', '2021-04-30 17:58:03.94002+00', 'Marchand, Célie & Jamault, Maëlle', '', 'Célie Marchand & Maëlle Jamault', '', 'meaudre.reel@gmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Méaudre Reel');
INSERT INTO 'person' VALUES (12047, '2021-04-19 10:38:43.645658+00', '2021-04-30 18:00:06.073651+00', 'Algoud, Manon & Baron, Romane & Depay, Faustine & Duchene, Aurore', '', 'Manon Algoud & Romane Baron & Faustine Depay & Aurore Duchene', '', 'meaudre.reel@gmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12046, '2021-04-19 10:32:28.049729+00', '2021-04-30 18:00:24.841922+00', 'Le Duc, Manon & Marchand, Lise & Mélé Angevin, Lilia', '', 'Manon Le Duc & Lise Marchand & Lilia Mélé Angevin', '', 'meaudre.reel@gmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12045, '2021-04-19 09:15:21.556088+00', '2021-04-30 18:00:41.717291+00', 'Algoud,Manon & Depay, Faustine & Piccarreta, Eva & Le Duc, Manon & Marchand, Lise', 'Méaudre Reel', 'Manon Algoud & Faustine Depay & Eva Piccarreta & Manon Le Duc & Lise Marchand', '', 'meaudre.reel@gmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12044, '2021-04-19 08:38:49.023385+00', '2021-04-30 18:01:04.053798+00', 'Algoud, Manon & Marchand, Lise', '', 'Manon Algoud & Lise Marchand', '', 'meaudre.reel@gmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12039, '2021-04-15 08:50:40.242093+00', '2021-04-30 18:01:22.719511+00', 'Marchand, Lise', '', 'Lise Marchand', '', 'meaudre.reel@gmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3382, NULL, '2021-05-12 09:48:07.291479+00', 'Town House Posse', '', 'Town House Posse', 'Dunfermline, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12036, '2021-04-14 09:36:49.629641+00', '2021-06-23 23:56:37.642315+00', 'Lanvin, Anne', '', 'Anne Lanvin', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3776, NULL, '2021-06-25 20:53:38.238073+00', 'Mueller-Franz, Martina', '', 'Martina Mueller-Franz', 'Langenfeld, Germany', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12053, '2021-08-15 11:10:53.983598+00', '2021-08-15 11:10:53.983598+00', 'St John''s Scottish Country Dancing Club', '', 'St John''s Scottish Country Dancing Club', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10204, NULL, '2021-08-16 00:14:07.250072+00', 'Brown, Laird with The Scottish Accent', 'Laird Brown', 'Laird Brown with The Scottish Accent', '', '', 0, 0, 0, 1, 10955, 2010, 0, NULL, 'On the death of Bobby Brown on May 3rd, 2011, the band “Bobby Brown and the Scottish Accent” changed its name to “Scotch Mist”, and the same day Stef Hutka joined it as fiddler.  At the changeover, one CD, "Eight Bars of Magic", was produced using the name “Laird Brown with the Scottish Accent”, but the band never used that name in any other context.  Both bands were based in Toronto, Canada.  When writing tunes, Laird uses the name “Laird J. Brown”.  



Look at http://www.scotchmist.ca/  for more information.



');
INSERT INTO 'person' VALUES (12055, '2021-08-19 20:04:57.347792+00', '2021-08-19 20:04:57.347792+00', 'Barnett, Allen', '', 'Allen BArnett', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12057, '2021-08-19 22:46:39.480125+00', '2021-08-19 22:46:39.480125+00', 'Caskie MBE, John M', '', 'John M Caskie MBE', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12056, '2021-08-19 20:10:52.005301+00', '2021-08-19 23:56:50.614858+00', 'Murray, Mike', '', 'Mike Murray', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12066, '2021-09-15 20:03:28.668376+00', '2021-09-15 23:56:33.811955+00', 'Hedge, Lydia & Hughes, Maurice Gilbert', '', 'Lydia Hedge & Maurice Gilbert Hughes', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12060, '2021-08-20 23:45:48.470229+00', '2021-08-20 23:45:48.470229+00', 'Archibald, Alice', '', 'Alice Archibald', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12059, '2021-08-20 13:20:59.811703+00', '2021-08-20 23:56:28.632261+00', 'Horne, Sarah', '', 'Sarah Horne', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12063, '2021-08-23 22:49:06.443884+00', '2021-09-15 23:56:36.31084+00', 'Hughes, Maurice Gilbert', '', 'Maurice Gilbert Hughes', '', '', 1, 1, 1, 0, NULL, 0, 0, NULL, 'Locations: both Northern Ireland and Canada.');
INSERT INTO 'person' VALUES (12061, '2021-08-20 23:58:15.376601+00', '2021-08-20 23:58:15.376601+00', 'Hepburn, Doris', '', 'Doris Hepburn', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12062, '2021-08-21 00:07:15.772957+00', '2021-08-21 00:07:15.772957+00', 'Robb, Anne', '', 'Anne Robb', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10285, NULL, '2021-08-22 03:30:56.982469+00', 'Vienna Branch RSCDS', 'RSCDS Vienna', 'Vienna Branch RSCDS', 'Vienna, Austria', '', 1, 1, 0, 0, NULL, 1989, 0, NULL, '');
INSERT INTO 'person' VALUES (4, NULL, '2021-08-22 03:37:40.795831+00', 'Adelaide Branch RSCDS', '', 'Adelaide Branch RSCDS', 'Adelaide, Australia', '', 0, 1, 0, 0, NULL, 1952, 0, NULL, '');
INSERT INTO 'person' VALUES (30, NULL, '2021-08-22 03:53:47.602923+00', 'Berks/Hants/Surrey Border Branch (RSCDS)', 'BHS Border Branch', 'Berks/Hants/Surrey Border Branch (RSCDS)', 'Berkshire/Hampshire/Surrey Border, UK', '', 0, 1, 0, 0, NULL, 1977, 0, NULL, '');
INSERT INTO 'person' VALUES (11356, '2016-09-14 09:25:32.995911+00', '2021-09-16 11:22:19.794835+00', 'Hedge, Lydia', '', 'Lydia Hedge', 'Halifax, Nova Scotia, Canada', 'lydiahedge@accesswave.ca', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12065, '2021-09-13 07:16:48.535023+00', '2021-09-19 11:47:44.636275+00', 'Rembold, Charly', '', 'Charly Rembold', '', '', 1, 0, 0, 0, NULL, 0, 2011, NULL, '');
INSERT INTO 'person' VALUES (12077, '2021-10-16 23:07:34.062798+00', '2021-10-16 23:56:06.574379+00', 'Barnes, P/M D', '', 'P/M D Barnes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12064, '2021-09-04 09:29:48.346561+00', '2021-09-04 23:56:40.093731+00', 'Lumsden, Norma', '', 'Norma Lumsden', 'Toronto, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3225, NULL, '2021-09-19 22:43:47.622136+00', 'St. John''s (Newfoundland) Branch RSCDS', 'St. John''s (Newfoundland)', 'St. John''s (Newfoundland) Branch RSCDS', 'St. John''s, Canada', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12068, '2021-09-27 17:00:16.389462+00', '2021-09-27 23:56:57.773396+00', 'Ramsay, Wayne', '', 'Wayne Ramsay', 'Kalamazoo, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Name taken from the rather muffled audio on this video <<https://youtu.be/hv_YZtDSEc4>> so may be misspelled.');
INSERT INTO 'person' VALUES (2963, NULL, '2021-09-05 11:07:50.753248+00', 'Shand, Annie', '', 'Annie Shand', 'Aberdeen, Scotland', '', 0, 1, 1, 0, NULL, 1872, 1936, NULL, 'More information about Annie Shand can be found at <<https://www.blogs.hss.ed.ac.uk/revival-fiddle/2015/03/08/annie-shand-1872-1936-negroid-corybantism-old-national-dances-scotland/|Edinburgh University>>. Furthermore, a page at <<https://raretunes.org/annie-shand/|RateTunes>> has information and three recordings of hers from 1929/1930 online.');
INSERT INTO 'person' VALUES (10373, NULL, '2021-09-08 08:21:48.452157+00', 'Ronald, Chris & Sue', '', 'Chris & Sue Ronald', 'Quorn, Leicestershire, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Formerly of Edgewater, NJ, US.');
INSERT INTO 'person' VALUES (1755, NULL, '2021-09-11 16:40:08.710159+00', 'McNeill, Archibald', '', 'Archibald McNeill', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Also referred to as ‘Blind Archie’ MacNeill in <<https://bagpipe.news/2020/07/13/memories-of-london-greats/>> which mentions his tune for David Ross. Web references to him variously use McNeill or MacNeill.');
INSERT INTO 'person' VALUES (12067, '2021-09-15 21:37:03.14492+00', '2021-09-15 21:37:27.271522+00', 'Gay Gordons (London)', '', 'Gay Gordons (London)', 'London', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12070, '2021-09-30 20:35:55.323983+00', '2021-09-30 20:35:55.323983+00', 'Manclark, Bill', '', 'Bill Manclark', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12069, '2021-09-30 19:15:27.603132+00', '2021-09-30 23:56:23.741853+00', 'Galloway, Ewan and MacFadyan, Shona', '', 'Ewan Galloway and Shona MacFadyan', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12058, '2021-08-20 12:20:20.744179+00', '2021-09-30 23:56:40.141064+00', 'MacFadyen, Shona', '', 'Shona MacFadyen', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12071, '2021-10-02 04:03:43.419956+00', '2021-10-02 04:03:43.419956+00', 'Gale, Brenda', '', 'Brenda Gale', 'Jersey', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12072, '2021-10-05 22:05:17.279944+00', '2021-10-05 22:11:14.920822+00', 'McQuaide, Lannie', '', 'Lannie McQuaide', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12074, '2021-10-11 22:37:40.062492+00', '2021-10-11 23:57:01.795058+00', 'Redmond, Evelyn', '', 'Evelyn Redmond', 'Belfast, Northern Ireland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12073, '2021-10-11 22:07:53.009627+00', '2021-10-11 23:57:08.054893+00', 'Sides, Patricia', '', 'Patricia Sides', 'Belfast, Northern Ireland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12076, '2021-10-12 07:51:10.50683+00', '2021-10-12 07:51:10.50683+00', 'Harley, Linda', '', 'Linda Harley', 'Belfast, Northern Ireland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12075, '2021-10-12 07:47:53.276247+00', '2021-10-12 23:57:15.866469+00', 'Warwick, Matthew', '', 'Matthew Warwick', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1910, NULL, '2021-10-16 22:42:25.403031+00', 'MacLeod, P/M Donald', '', 'P/M Donald MacLeod', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'For a longer list of his tunes than are currently entered in the database see <<https://www.kinnairdbagpipes.com/ckfinder/userfiles/files/DonaldMacLeodBooks.pdf>>.');
INSERT INTO 'person' VALUES (12078, '2021-10-16 23:15:57.67059+00', '2021-10-16 23:56:43.562657+00', 'MacDonald, Allan', '', 'Allan MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Published two books of tunes under the titles Moidard Collection Volumes 1 & 2.



It is not clear if this is the same person as <<ddp:Moidart, A#2657>>.');
INSERT INTO 'person' VALUES (3621, NULL, '2021-10-17 09:43:22.832294+00', 'More, R', '', 'R More', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Possibly the Bobby More referred to as the composer of the tune <<ddt:Robert Mitchell More#14524>> in the CD insert of the album <<dda:Joy of Sets#1082>>?');
INSERT INTO 'person' VALUES (12079, '2021-10-21 18:27:35.653301+00', '2021-10-21 18:27:35.653301+00', 'Broquié, Vincent', '', 'Vincent Broquié', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12080, '2021-10-28 15:28:06.670769+00', '2021-10-28 15:28:06.670769+00', 'Oliver, Andrew', '', 'Andrew Oliver', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (373, NULL, '2021-11-01 17:18:06.632709+00', 'Longman & Broderip (18C)', '', 'Longman & Broderip (18C)', 'London, UK', '', 1, 0, 0, 0, NULL, 0, 1798, NULL, 'According to <<https://my.strathspey.org/dd/issue/2644/|issue 2644>> Longman & Broderip were active in London in the second half of 18th century as publishers and musical instrument sellers. They were based in Cheapside and Haymarket until going bankrupt in 1798.');
INSERT INTO 'person' VALUES (12082, '2021-11-05 19:57:26.273253+00', '2021-11-05 19:58:14.666924+00', 'McDonald, Duncan', '', 'Duncan McDonald', 'Wellington, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12083, '2021-11-05 20:02:23.971937+00', '2021-11-05 20:02:23.971937+00', 'McDonald, Mary', '', 'Mary McDonald', 'Wellington, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12084, '2021-11-05 20:34:52.957417+00', '2021-11-05 20:34:52.957417+00', 'Oliver, Ann', '', 'Ann Oliver', 'Wellington, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12085, '2021-11-18 12:19:32.341766+00', '2021-11-18 12:19:32.341766+00', 'Napier, Clare', '', 'Clare Napier', '', '', 1, 0, 0, 0, NULL, 1984, 0, NULL, '');
INSERT INTO 'person' VALUES (12086, '2021-11-23 07:09:10.969796+00', '2021-11-23 07:09:10.969796+00', 'Hood, Christina', '', 'Christina Hood', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3179, NULL, '2021-12-03 00:56:37.289151+00', 'Joubert, Wouter', '', 'Wouter Joubert', 'Pretoria, South Africa', 'wouterj2305@gmail.com', 1, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12087, '2021-12-04 17:09:37.83165+00', '2021-12-05 00:56:38.055001+00', 'Lang Syne Publications', 'Lang Syne', 'Lang Syne Publications', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1416, NULL, '2021-12-08 23:46:47.774347+00', 'Kohler', '', 'Kohler', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Probably the Köhler responsible for several tune collections?');
INSERT INTO 'person' VALUES (10625, '2012-06-12 13:34:09.009057+00', '2021-12-16 22:15:50.018603+00', 'Rose, Jane', '', 'Jane Rose', 'Berkhamsted, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'RSCDS Qualified Teacher.  

Taught beginners, intermediate and advanced classes at Berkhamsted Strathspey & Reel Club from September 2004 to 2019. Taking a sabbatical year 2019-20.  

London Branch Beginners, September 2013 to June 2018.



Also taught at:  

Argyll Day School and Tunbridge Wells Day School (29/3/14)  

Birmingham RSCDS Day School 4th March 2017  

Cheltenham RSCDS Day School 22nd April 2017  

Intermediates & Advanced at Summer School week 3 2017  

RSCDS York Branch Day School 6th October 2018  

RSCDS Somerset Branch Day School 2nd March 2019  

Beginners & Low Impact Very Advanced at Summer School week 3 2019  

Barcelona Dancers weekend 6th June 2020 - postponed until 2022  

Summer School week 2 2020  

Aberdeen Dancers away weekend in Perth 4-6th September 2020 - postponed until 2022  

Norwich RSCDS Day School 21st November 2020



RSCDS Courses Attended:  

Tutors Course at Summer School week 1 2018  

DPA Assessors Course weekend in May 2019



Courses organised and run:  

Tutor for 2-day Teaching Skills Courses in Autumn 2018 and planned for Jan/Feb 2022  

RSCDS Teachers course for Units 2-5 November 2019 – August 21 (100% candidates passed)



Other:  

Chairperson of SERTA (South East Region Teachers’ Association) 2017-2021  

Chairperson of RSCDS Herts and Border Branch 2020-2024  

Member of London RSCDS branch  

Member of RSCDS International branch  

Regular attendee at UK Summer and Winter Schools  

Member of team presenting Winter School afternoon "walk through of dances" 2016-2018 & 2020  

Attendee of New Zealand Summer School 2019/20  

Written and presented paper to SERTA, RSCDS Summer School and RSCDS AGM weekend forums - topic “Teaching, and Keeping, Beginners”  

Seconded to RSCDS Business Plan working party 2016-19  

Mentor to a number of candidates taking all levels of RSCDS teachers’ examinations  

Co Ordinator of Berkhamsted Strathspey & Reel Club Day Schools from 2010-2018 & 2020  

Co Ordinator of RSCDS Book 5 video project by Berkhamsted Strathspey & Reel Club  

');
INSERT INTO 'person' VALUES (12089, '2022-01-05 17:41:24.876212+00', '2022-01-06 01:56:16.845229+00', 'Galve, Marcela', '', 'Marcela Galve', 'Buenos Aires, Argentina', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (197, NULL, '2022-01-21 14:16:12.890609+00', 'Jay, Morton', '', 'Morton Jay', 'Sydney', '', 1, 1, 0, 0, NULL, 1925, 2020, NULL, '');
INSERT INTO 'person' VALUES (10612, '2012-03-13 15:05:44.284796+00', '2022-01-06 15:43:41.287593+00', 'McWilliam, Martin', '', 'Martin McWilliam', 'Sandhatten, Germany', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12090, '2022-01-05 17:42:49.216627+00', '2022-01-07 01:56:16.909185+00', 'Galve, Marcela and Grimoldi, Maria', '', 'Marcela Galve and María S. Grimoldi', 'Buenos Aires, Argentina', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12088, '2022-01-05 17:40:38.710738+00', '2022-01-07 01:56:19.368317+00', 'Grimoldi, Maria', '', 'Maria S. Grimoldi', 'Buenos Aires, Argentina', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12091, '2022-01-07 14:13:10.834687+00', '2022-01-07 14:13:10.834687+00', 'Morgan, Fiona', '', 'Fiona Morgan', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (531, NULL, '2022-01-10 20:05:11.005589+00', 'Grant, Bob', '', 'Bob Grant', 'Edinburgh, UK', '', 1, 0, 0, 0, NULL, 1935, 2021, NULL, '');
INSERT INTO 'person' VALUES (12092, '2022-01-11 11:42:20.943794+00', '2022-01-11 11:46:45.714757+00', 'Thomson, Jean', '', 'Jean Thomson', 'Gloucestershire, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (82, NULL, '2022-01-13 10:41:37.516962+00', 'Clowes, Roy', '', 'Roy Clowes', 'Ormskirk, Lancashire, UK', '', 1, 1, 0, 0, NULL, 0, 1988, NULL, 'Roy''s involvement with the <<ddpub:Scottish Dance Archives#436>> are mentioned in <<https://www.rscdslondon.org.uk/wp-content/uploads/2019/08/Reel-308-electronic.pdf#page=11|The Reel #208>>.



Roy wrote a series of five articles for *<<ddpub:#73|The Reel>>* under the general title _Thinking about Dances_. Each considers one aspect of devising dances and is illustrated by one of his own dances. See the following links:  



1. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-106-December-1968-January-1969.pdf#page=3|Thinking of Dances>> (<<ddd:Jig on the Bridge#3264>>)

2. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-107-February-April-1969.pdf#page=3|From Long to Square>> (<<ddd:Kyle Strathspey#3551>>)

3. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-108-May-July-1969.pdf#page=3|Standing Still and Moving Figures>> (<<ddd:Mile Down the Road, A#4373>>)

4. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-109-August-October-1969.pdf#page=3|Progressions>> (<<ddd:Laird''s Medley, The#3663>>)

5. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-110-November-1969-January-1970.pdf#page=5|Longer Sequences – Bigger Sets>> (<<ddd:Tapsalteerie#6464>>)');
INSERT INTO 'person' VALUES (12094, '2022-01-16 21:44:04.231074+00', '2022-01-16 21:46:45.689211+00', 'Faurschou, Diane', '', 'Diane Faurschou', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12093, '2022-01-16 21:33:39.363596+00', '2022-01-16 21:47:26.144534+00', 'Williams, David', '', 'David Williams', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12095, '2022-01-16 21:55:46.369934+00', '2022-01-16 21:55:46.369934+00', 'Kerr, Joe', '', 'P/M Joe Kerr', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (421, NULL, '2022-01-17 01:56:51.228027+00', 'Winnipeg Branch RSCDS', '', 'Winnipeg Branch RSCDS', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12096, '2022-01-19 00:44:12.057331+00', '2022-01-19 00:52:26.985809+00', 'McDonald, James', '', 'James McDonald', 'Enumclaw, Washington, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12097, '2022-01-19 00:44:41.546705+00', '2022-01-19 00:53:26.419544+00', 'McDonald, Pat', '', 'Pat McDonald', 'Enumclaw, Washington, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (306, NULL, '2022-01-20 22:32:37.078371+00', 'Perth and Perthshire Branch RSCDS', 'Perth Branch', 'Perth and Perthshire Branch RSCDS', 'Perth, Scotland', '', 0, 1, 0, 0, NULL, 0, 0, NULL, 'This is the branch including Perth, Scotland. The branch for Perth, Australia is <<ddp:Western Australia Branch RSCDS#412>>.');
INSERT INTO 'person' VALUES (12098, '2022-01-21 23:09:25.030057+00', '2022-01-21 23:09:25.030057+00', 'Smalley, D.', '', 'D. Smalley', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12099, '2022-01-22 20:38:46.289631+00', '2022-01-23 01:56:49.262783+00', 'Rogers, Roy & Evans, Dale', '', 'Roy Rogers & Dale Evans', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12104, '2022-01-27 18:43:45.990827+00', '2022-01-27 18:43:45.990827+00', 'James, Sue', '', 'Sue James', 'Perth, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12105, '2022-01-27 18:44:24.152564+00', '2022-01-27 18:44:24.152564+00', 'MacVarish Clark, Theresa', '', 'Theresa MacVarish Clark', 'Perth, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11619, '2018-03-31 11:14:07.916767+00', '2022-01-27 18:47:49.760774+00', 'Purcell, E', '', 'E Purcell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'There are tunes named after "Elizabeth Purcell" so possibly that is the first name of this composer?');
INSERT INTO 'person' VALUES (12100, '2022-01-27 18:38:16.820187+00', '2022-01-27 18:53:01.001633+00', 'Edwards, Dorothy', '', 'Dorothy Edwards', 'Perth, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12101, '2022-01-27 18:39:00.352603+00', '2022-01-27 18:54:38.054423+00', 'Macdonald, Janet', '', 'Janet Macdonald', 'Perth, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12102, '2022-01-27 18:39:58.538448+00', '2022-01-27 19:16:32.055947+00', 'Bisset, Carol', '', 'Carol Bisset', 'Perth, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12103, '2022-01-27 18:41:20.154754+00', '2022-01-27 19:17:21.793161+00', 'Carswell, Linda', '', 'Linda Carswell', 'Perth, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2664, NULL, '2022-01-27 19:18:07.356825+00', 'Craig, Elsie', '', 'Elsie Craig', 'Perth, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1190, NULL, '2022-11-20 15:18:38.599717+00', 'Lawson, Nan', '', 'Nan Lawson', 'Glasgow Branch', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12106, '2022-01-27 19:07:56.737245+00', '2022-01-27 19:18:22.618692+00', 'Baldie, Jean', '', 'Jean Baldie', 'Perth, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2595, NULL, '2022-01-27 19:20:40.520463+00', 'MacDonald, J', '', 'J MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Possible duplicate of <<ddp:#10060>>?');
INSERT INTO 'person' VALUES (10060, NULL, '2022-01-27 19:20:54.467486+00', 'MacDonald, J', 'MacDonald J', 'MacDonald J', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Possible duplicate of <<ddp:#2595>>?');
INSERT INTO 'person' VALUES (12107, '2022-01-28 00:14:05.555673+00', '2022-01-28 00:14:05.555673+00', 'Marlow, Rita', '', 'Rita Marlow', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12108, '2022-01-28 00:16:46.847197+00', '2022-01-28 00:16:46.847197+00', 'Russell, Gill & Marlow, Rita', '', 'Gill Russell & Rita Marlow', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12109, '2022-01-30 21:18:34.109429+00', '2022-01-31 01:56:33.718452+00', 'Leeds Scottish Country Dance Club', 'Leeds SCDC', 'Leeds SCDC', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12110, '2022-02-03 23:29:28.406735+00', '2022-02-03 23:29:28.406735+00', 'Adams, Raewyn', '', 'Raewyn Adams', 'Paeroa, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Information from <<https://youtu.be/6cYox6TvmRA|this youtube video>>.');
INSERT INTO 'person' VALUES (11301, '2016-07-11 16:00:31.813857+00', '2022-02-06 20:36:56.371762+00', 'Shankland, Rachel', '', 'Rachel Shankland', 'Edinburgh, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (105, NULL, '2022-02-10 19:59:08.759445+00', 'Donald, Robert', '', 'Bob Donald', 'Liverpool, UK', '', 1, 1, 0, 0, NULL, 1932, 0, NULL, 'Bob Donald has contributed to Scottish Country Dancing as all of the following:



- a historian and archivist of SCD;



- an SCD teacher and member of demonstration teams in the Merseyside area;



-  the editor and publisher of numerous dances of <<ddp:Foss, Hugh#129>>, taken from the notes left after Hugh''s death in 1971. These dances formed the book <<ddpub:#160|The Rose Collection>>, published in 1978.



- a devisor of dances, including two published through <<ddpub:Scottish Dance Archives#436>> (see below) and others in his own booklet <<ddpub:#228|The Green Lochan and 11 other Scottish dances>>, of which perhaps <<ddd:Gavin''s Reel>> (5C) is best known;



- the co-founder and operator of <<ddpub:Scottish Dance Archives#436>>, jointly with the late <<ddp:Clowes, Roy#82>>. During its 10 years (mostly the 1970s) this service helped in the testing and publishing of 190 newly devised SCD, on behalf of numerous devisors. More details can be found under the “Extra Info” tab in the separate entry for this;



- the provider over some years in the 1970s, with his wife Mamie (born 1936), of the "Hugh Foss (Formby)" mail-order service for distributing instructions (then all in hardcopy) for SCD outside the RSCDS remit. Bob and Mamie took over the distribution service which Hugh Foss had set up and which Hugh''s widow Alison had briefly continued after Hugh''s death. (Subsequently another organisation "<<ddp:Scottish National Dance Company#344>>"  - SNDC - continued this role until the online era began.);



- as the creator, again with Mamie, of the former website  www.dancearchives.co.uk, which provided an online catalogue to their extensive archive of SCD instructions and related literature. The hardcopy documents of this archive have been deposited with the Music Department of Edinburgh Central Library as the Donald Collection. For the online website Bob also prepared online-viewable transcripts of some 250 dances. That website is no longer operational because in 2020 the site was placed in the care of RSCDS London Branch; it is now accessible at the link <<https://www.rscdslondon.org.uk/scottish-dance-archives/>>.');
INSERT INTO 'person' VALUES (3327, NULL, '2022-02-15 12:39:38.062604+00', 'Galbraith, Ian', '', 'Ian Galbraith', '', '', 1, 0, 0, 0, NULL, 1925, 2022, NULL, '');
INSERT INTO 'person' VALUES (12112, '2022-02-11 10:53:53.52914+00', '2022-02-11 11:04:47.783425+00', 'Park, Preston', '', 'Preston Park', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1936, NULL, '2022-05-23 08:05:23.321941+00', 'Fox, Viveka', '', 'Viveka Fox', '', '', 0, 0, 1, 0, NULL, 1953, 0, NULL, 'The instructions for <<ddd:Alison''s Round Reel#7338>> spell the name as "Vivika Fox". To be checked...');
INSERT INTO 'person' VALUES (12132, '2022-05-26 16:59:15.30586+00', '2022-05-26 16:59:15.30586+00', 'Schoonover, Jen', '', 'Jen Schoonover', 'Boston, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12133, '2022-05-26 21:44:37.708189+00', '2022-05-26 23:57:08.747047+00', 'Wilson, Sheila E.', '', 'Sheila Wilson', 'New York city, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (785, NULL, '2022-02-15 14:43:27.969795+00', 'Russell, Gill', '', 'Gill Russell', 'Ashtead, UK', '', 1, 0, 0, 0, NULL, 1937, 2021, NULL, 'Information from an eulogy provided by Maggie Westley:



Gillian was born in London on 24th June 1937. Post war, the family settled in Putney where Gill attended Putney High School from 1948 to 1955. 

Sadly her father died in 1949. Her mother later remarried, and her stepfather became a much-loved character. He encouraged her love of music, choral singing and the piano, which stayed with her throughout her life.



At some point, Gill  discovered the Royal Scottish Country Dance Society, which proved to be a very important part of her leisure activities. She took an active role in forming a group called the Cairngorm Dancers, organizing weekend schools and Hogmanay breaks.



In 1987, Gill and <<https://my.strathspey.org/dd/person/12107/|Rita Marlow>>, who had met through Scottish Country Dance, decided to sell their London flats, and buy a home to share “until retirement”. The arrangement worked extremely well, and Ashtead proved to be the ideal home. 



The move to Ashtead encouraged involvement with a local group – The Wallington Scottish Association, and so the dancing continued. Dancers from the area provided enjoyable entertainment for Gill, other Residents and Staff at The Red House for their Burns’ Night celebrations. 



She was rather strict with display teams. Male Scottish dancers were told to wear dark underpants beneath kilts if taking part in displays, especially when dancing on a stage. Travelling to France with one group, it was reported that she did check their attire!



Gill’s stroke, which resulted in her needing constant care and assistance proved difficult for her. However, caring and loving the delightful Staff at The Red House proved to be. The COVID-19 outbreak was not helpful either – she did miss her visitors.



According to Maggie Westley, Gill was a qualified RSCDS teacher but didn’t really like teaching too much.



Gill Russell also wrote a couple of dances like "<<ddd:Polesden Lacey>>", "<<ddd:Cobham Hornpipe>>", "<<ddd:Millennium>>" and "<<ddd:The Almo Rant>>" (the latter together with <<https://my.strathspey.org/dd/person/12107/|Rita Marlow>>).');
INSERT INTO 'person' VALUES (12113, '2022-02-17 09:15:27.137576+00', '2022-02-17 09:15:27.137576+00', 'Job, Clémentine', '', 'Clémentine Job', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12114, '2022-02-17 09:16:19.94274+00', '2022-02-17 09:16:59.427427+00', 'Dejean, Anne & Job, Clémentine', '', 'Anne Dejean & Clémentine Job', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10077, NULL, '2022-02-18 10:16:16.182405+00', 'Jamieson, R', 'R Jamieson', 'R Jamieson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Probably the same as <<ddp:Ronald G Jamieson#1645>> especially as each is attributed a Debbie Ann(e) tune with slightly different spellings. To be investigated...');
INSERT INTO 'person' VALUES (1645, NULL, '2022-02-18 10:17:13.889628+00', 'Jamieson, Ronald G', '', 'Ronald G Jamieson', 'Shetland', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Son of Frank Roland Jameson.  Usually called "Ronnie".



Probably the same as <<ddp:R Jamieson#10077>> especially as each is attributed a Debbie Ann(e) tune with slightly different spellings. To be investigated...');
INSERT INTO 'person' VALUES (12115, '2022-02-18 21:16:44.670296+00', '2022-02-18 21:16:44.670296+00', 'MacInnes, Ruth', '', 'Ruth MacInnes', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12116, '2022-02-18 21:16:50.436652+00', '2022-02-18 21:16:50.436652+00', 'Jamieson, Peter', '', 'Peter Jamieson', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (116, NULL, '2022-02-22 14:15:13.68779+00', 'Duthie, John M', '', 'John M Duthie', '', '', 1, 1, 0, 0, NULL, 1873, 1951, NULL, '');
INSERT INTO 'person' VALUES (471, NULL, '2022-02-26 18:06:29.463464+00', 'Charles, John A', '', 'John A Charles', 'Kawerau, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12117, '2022-03-02 00:10:50.436437+00', '2022-03-02 00:10:50.436437+00', 'Bailie, Peter', '', 'Peter Bailie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2528, NULL, '2022-03-04 12:19:16.381654+00', 'McDonald, M Donalda', '', 'M Donalda McDonald', 'Toronto, Canada', '', 1, 0, 0, 0, NULL, 1933, 2022, NULL, 'There is an obituary in the February 2022 edition of the Toronto <<ddpub:Set and Link#1290>> magazine and some further reminiscences in the March 2022 edition.');
INSERT INTO 'person' VALUES (12137, '2022-06-07 19:59:02.843227+00', '2022-06-07 19:59:02.843227+00', 'Savitskaya, Inna', '', 'Inna Savitskaya', 'Appleby, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12136, '2022-05-31 09:58:11.842697+00', '2022-05-31 10:56:19.075336+00', 'Hamlyn, Barbara', '', 'Barbara Hamlyn', 'Adelaide, Australia', '', 0, 0, 0, 0, 12135, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12135, '2022-05-31 09:57:58.082755+00', '2022-05-31 23:56:42.715007+00', 'Lupton (nee Hamlyn), Barbara', '', 'Barbara Lupton (nee Hamlyn)', 'Adelaide, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Barbara Lupton is identical to Barbara Hamlyn');
INSERT INTO 'person' VALUES (12134, '2022-05-31 09:49:25.600146+00', '2022-05-31 23:57:15.268857+00', 'Wednesday Group Burnside Dancers', 'Wednesday Burnside Dancers', 'Wednesday Group Burnside Dancers', ' Adelaide, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2865, NULL, '2022-06-05 18:51:05.822545+00', 'Henry, Angus', '', 'Angus Henry', 'Wulagi, Greater Darwin, NT, Australia', 'anguka@internode.on.net', 1, 1, 0, 0, NULL, 1934, 0, NULL, '');
INSERT INTO 'person' VALUES (12140, '2022-06-07 20:19:34.272917+00', '2022-06-07 20:19:34.272917+00', 'SCDC Clara and SCDC Saltire', '', 'SCDC Clara and SCDC Saltire', 'Japan', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12144, '2022-06-07 21:09:07.050297+00', '2022-06-07 21:10:33.686602+00', 'Oyama, Kaoru', '', 'Kaoru Oyama', 'Funabashi, Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12145, '2022-06-07 21:23:00.9289+00', '2022-06-07 21:54:56.111543+00', 'Gou, Shinroku', '', 'Shinroku Gou', 'Tokai, Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12147, '2022-06-07 22:12:50.327738+00', '2022-06-07 22:13:29.485467+00', 'Takemoto, Mitsuo', '', 'Mitsuo Takemoto', 'Tokai, Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12148, '2022-06-07 22:25:11.941757+00', '2022-06-07 22:29:41.197555+00', 'Higashikawa, Hiroko', '', 'Hiroko Higashikawa', 'Tokai, Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12149, '2022-06-07 22:32:09.336102+00', '2022-06-07 22:32:49.391926+00', 'Arai, Keiko', '', 'Keiko Arai', 'Hatchobori, Tokyo, Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12146, '2022-06-07 21:56:08.795878+00', '2022-06-07 23:56:02.805163+00', 'Akamatsu, Yoko', '', 'Yoko Akamatsu', 'Tokai, Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11790, '2019-02-24 10:32:42.661661+00', '2022-06-07 23:56:52.132713+00', 'Nixon, Emma', '', 'Emma Nixon', 'Australia', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12142, '2022-06-07 20:34:11.196573+00', '2022-06-07 23:57:00.450804+00', 'RSCDS Tokai Branch', '', 'RSCDS Tokai Branch', 'Tokai, Japan', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12138, '2022-06-07 20:18:25.178702+00', '2022-06-07 23:57:01.532573+00', 'SCDC Clara', '', 'SCDC Clara', 'Japan', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12139, '2022-06-07 20:18:45.853288+00', '2022-06-07 23:57:01.556052+00', 'SCDC Saltire', '', 'SCDC Saltire', 'Japan', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12141, '2022-06-07 20:25:58.412667+00', '2022-06-07 23:57:07.509082+00', 'Takahashi, Yoko', '', 'Yoko Takahashi', 'Tokai, Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12150, '2022-06-08 09:25:00.079682+00', '2022-06-08 09:45:57.92909+00', 'Masaka, Shiho', '', 'Shiho Masaka', 'Tokai, Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12143, '2022-06-07 21:01:58.315606+00', '2022-06-08 11:14:34.708351+00', 'Okumura, Shoko', '', 'Shoko Okumura', 'Tokyo, Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12118, '2022-03-20 12:28:29.512677+00', '2022-03-20 12:28:29.512677+00', 'Portland and SW Washington Branches', '', 'Portland and SW Washington Branches', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (312, NULL, '2022-03-21 01:56:47.124444+00', 'Portland OR Branch', '', 'Portland OR Branch', 'Portland, Oregon, USA', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11162, '2015-07-21 08:02:18.485063+00', '2022-03-09 12:04:09.892621+00', 'Freinbichler, Regina', '', 'Regina Freinbichler', 'Salzburg, Austria', '', 1, 1, 0, 0, NULL, 1975, 2022, NULL, 'After long suffering from cancer she has died on 5th March 2022 far too early in the age of 46.



Born in Salzburg on 6th August 1975, Regina was a sporty person from early ages onwards. She did gymnastics already as a child and did artistic gymnastics actively until the age of 16. Later she became a trainer of gymnastics.



Later she studied history, English and mathematics to become a teacher. During her study she did a 10-month stay in Glasgow. She was deeply impressed by Scotland, Scottish culture and especially Scottish dancing. 

 

In 2008 Regina was the founder of "The Flying Scotsman Scottish Dancers Salzburg" inside her gymnastics sports club Turnverein Maxglan. 

She also organized Dance Workshops in Salzburg with excellent teachers like Ron Wallace in 2011.

Due to her health conditions she had to hand over the group to Katrin Edelmann in February 2020. Katrin leads on the group as "<<https://www.facebook.com/cuillinscottishdancers/|Cuillin Scottish Dancers>>" in Salzburg now independant of the sports club.



Regina has devised a number of dances. One of them is "<<ddd:Between Yews and Willows>>", a dance she wrote on the context of her illness. The dance leaflet contains her "<<https://www.turnverein-maxglan.at/ovarian-cancer-appeal-for-scottish-country-dancers/|Ovarian Cancer Appeal for Scottish Country Dancers>>". 



Nine of her dances she has released in a PDF collection called "Own Dances" which is currently available at <<https://www.turnverein-maxglan.at/reginas-dances/>> where also videos of five of the dances can be viewed. 



Furthermore, in 2015 Regina wrote and published the book "<<https://www.turnverein-maxglan.at/scottish-country-dancing-book/|Scottish Country Dancing with Beginners>>" sharing her thoughts and experiences on teaching new dancers and mixed level groups. The book contains a lot of material including another seven dances of hers and is available at <<http://rscdsleeds.uk/index.php?id_product=813&controller=product&search_query=Scottish+Country+Dancing+with+beginners&results=577|Leeds Branch Shop>>.



Besides Scottish dancing and gymnastics she was deeply involved in the production of the magazine "<<https://www.turnverein-maxglan.at/schottland-zeitschrift/|Wir bringen Schottland nach Salzburg>>" (= We bring Scotland to Salzburg) which was released several times a year and so far reached 13 issues.



Even in the last days of her life in hospice she was devoted to her fascination about Scotland. She was working on a book called "Faszination Schottland" (in German) which is about to be published mid-March 2022. Sadly, she did not live long enough to see it happen herself.');
INSERT INTO 'person' VALUES (208, NULL, '2022-03-21 01:56:50.779236+00', 'RSCDS Southwest Washington State Branch', 'Kelso Scottish Country Dancers', 'Kelso Scottish Country Dancers', 'Kelso, WA, USA ', '', 1, 1, 0, 0, NULL, 1985, 0, NULL, '');
INSERT INTO 'person' VALUES (11632, '2018-04-25 20:58:54.284465+00', '2022-03-10 23:41:07.256509+00', 'Dyke, Ray', '', 'Ray Dyke', 'SE Hertfordshire, UK', '', 1, 0, 0, 0, NULL, 0, 2022, NULL, '');
INSERT INTO 'person' VALUES (3683, NULL, '2022-04-02 23:56:09.292608+00', 'Brady, Luke', 'Luke Brady', 'Luke Brady', '', '', 0, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11013, '2014-10-01 22:24:38.750879+00', '2022-04-03 18:56:19.349759+00', 'Clement, Atsuko', '', 'Atsuko Clement', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'An article by Atsuko on her background and opinions about dancing appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2020/10/Reel-313-Electronic.pdf#page=8|issue 313 of The Reel>>.');
INSERT INTO 'person' VALUES (10664, '2012-10-18 12:54:08.961771+00', '2022-04-05 19:02:51.303109+00', 'Hamilton, Derek', 'D. Hamilton', 'Derek Hamilton', 'Galston, UK', '', 0, 0, 1, 0, NULL, 0, 2022, NULL, '');
INSERT INTO 'person' VALUES (1698, NULL, '2022-04-07 18:44:01.636866+00', 'Boyd, Colin J.', '', 'Colin J. Boyd', 'Nova Scotia', '', 0, 0, 1, 0, NULL, 1891, 1975, NULL, '');
INSERT INTO 'person' VALUES (2243, NULL, '2022-04-07 19:13:49.273284+00', 'Chisholm, Angus', '', 'Angus Chisholm', 'Cape Breton, CA', '', 0, 0, 1, 0, NULL, 1908, 1979, NULL, '');
INSERT INTO 'person' VALUES (2232, NULL, '2022-04-07 19:17:49.315277+00', 'Chisholm, John (Jack)', 'Jack Chisholm', 'John “Jack” Chisholm', '', '', 0, 0, 1, 0, NULL, 1922, 1983, NULL, '');
INSERT INTO 'person' VALUES (1934, NULL, '2022-04-07 19:33:31.20533+00', 'Cooper, Isaac', '', 'Isaac Cooper', 'Banff, UK', '', 0, 0, 1, 0, NULL, 1754, 1810, NULL, '');
INSERT INTO 'person' VALUES (1781, NULL, '2022-04-07 19:49:09.29857+00', 'Dow, Daniel(Donald)', '', 'Daniel(Donald) Dow', '', '', 0, 0, 1, 0, NULL, 1732, 1783, NULL, 'Mr Dow''s first name is sometimes given as “Daniel” and sometimes as “Donald”. Both of these are acceptable translations of the Gaelic “Domhnull”.');
INSERT INTO 'person' VALUES (1897, NULL, '2022-04-07 19:52:27.169565+00', 'Duff, Archibald', '', 'Archibald Duff', 'Aberdeen', '', 0, 0, 1, 0, NULL, 1770, 1840, NULL, 'Years of birth and death are approximate.');
INSERT INTO 'person' VALUES (10510, NULL, '2022-04-07 20:26:28.174048+00', 'Gow, Andrew', '', 'Andrew Gow', '', '', 0, 0, 1, 0, NULL, 1760, 1803, NULL, '');
INSERT INTO 'person' VALUES (1656, NULL, '2022-04-07 20:45:15.865833+00', 'Hendry, Bill', 'Bill Hendry', 'Bill Hendry', '', '', 0, 0, 1, 1, NULL, 0, 1995, NULL, '');
INSERT INTO 'person' VALUES (1633, NULL, '2022-04-07 20:47:04.449519+00', 'Holland, Jerry', '', 'Jerry Holland', 'Cape Breton, CA', '', 0, 0, 1, 0, NULL, 1955, 2009, NULL, '');
INSERT INTO 'person' VALUES (1567, NULL, '2022-04-07 23:56:09.601339+00', 'Burns, Felix', '', 'Felix Burns', '', '', 0, 0, 1, 0, NULL, 1864, 1920, NULL, '');
INSERT INTO 'person' VALUES (1662, NULL, '2022-04-07 23:56:38.833379+00', 'Macdonald, Keith Norman', '', 'Keith Norman Macdonald', '', '', 0, 1, 1, 0, NULL, 0, 0, NULL, 'Editor of the late 19th c. <<ddpub:Skye Collection>>.');
INSERT INTO 'person' VALUES (12124, '2022-05-03 20:36:23.129584+00', '2022-05-03 20:36:23.129584+00', 'Grimsey, Judy', '', 'Judy Grimsey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1445, NULL, '2022-04-16 18:24:12.264951+00', 'de Vroome, Rik', '', 'Rik de Vroome', 'Aalst-Waalre, Netherlands', '', 1, 1, 1, 0, NULL, 1946, 2022, NULL, 'In June 2021 Rik published his final dance book "Dances for Friends Seven".');
INSERT INTO 'person' VALUES (10325, NULL, '2022-04-18 11:43:35.010354+00', 'MacKay, Susan', '', 'Susan MacKay', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12121, '2022-04-18 21:17:05.68776+00', '2022-04-18 23:56:24.58121+00', 'Geoghegan, Irene', '', 'Irene Geoghegan', 'Dundee, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2370, NULL, '2022-04-24 11:44:30.057456+00', 'Thompson, E', '', 'E Thompson', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Thought to be a misspelling duplicate of <<ddp:Thomson, Eileen#1565>> (see <<https://my.strathspey.org/dd/issue/2762/|issue 2762>>. This entry should be deleted once this is confirmed.');
INSERT INTO 'person' VALUES (2793, NULL, '2022-04-26 23:33:37.65402+00', 'Taylor, Ruth', '', 'Ruth Taylor', 'Ontario, CA', 'rtaylor@ripnet.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2101, NULL, '2022-04-27 23:56:50.580112+00', 'Stott, James', '', 'Jim Stott', 'Aberdeen', '', 1, 1, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12123, '2022-04-30 18:47:25.456693+00', '2022-04-30 18:47:25.456693+00', 'Cooper, Nigel', '', 'Nigel Cooper', 'Cambridge, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12126, '2022-05-03 21:49:39.207703+00', '2022-05-03 23:56:18.990974+00', 'Edelmann, Katrin', '', 'Katrin Edelmann', 'Salzburg, Austria', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11858, '2019-08-12 09:09:39.715904+00', '2022-05-03 23:56:22.853045+00', 'Galloway, Ewan', '', 'Ewan Galloway', '', '', 1, 1, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12125, '2022-05-03 20:38:48.572138+00', '2022-05-03 23:56:30.500101+00', 'Horne, Sarah and Grimsey, Judy', '', 'Sarah Horne and Judy Grimsey', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12127, '2022-05-08 23:16:28.114664+00', '2022-05-08 23:16:28.114664+00', 'Picavet, Dominique', '', 'Dominique Picavet', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12128, '2022-05-08 23:17:02.691535+00', '2022-05-08 23:17:02.691535+00', 'Bibard, Gilbert', '', 'Gilbert Bibard', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12129, '2022-05-08 23:18:14.168485+00', '2022-05-08 23:18:14.168485+00', 'Picavet, Dominique & Bibard, Gilbert', '', 'Dominique Picavet & Gilbert Bibard', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12119, '2022-04-15 15:49:07.498154+00', '2022-07-06 23:46:47.20711+00', 'Kovaleva, Irina', '', 'Irina Kovaleva', 'Novosibirsk, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12130, '2022-05-20 21:13:52.391726+00', '2022-05-20 21:13:52.391726+00', 'Mouncer, Gill', '', 'Gill Mouncer', 'Leicester, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12131, '2022-05-25 22:03:14.672913+00', '2022-05-25 22:03:14.672913+00', 'Collin, Damon', '', 'Damon Collin', 'Lower Hutt, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11234, '2016-01-18 14:47:58.208748+00', '2022-05-25 22:04:08.736414+00', 'Collin, Gaye & Damon', '', 'Gaye & Damon Collin', 'Lower Hutt, New Zealand', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2766, NULL, '2022-08-17 19:26:04.519082+00', 'McKinnell, Sue', '', 'Sue McKinnell', 'Naperville, Illinois, USA', 'luvscd@suedan.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1543, NULL, '2022-12-26 21:42:01.508818+00', 'Lawrie, Willie', '', 'Willie Lawrie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'This entry conflates two people: see <<https://my.strathspey.org/dd/issue/2754/>>. To be sorted out...  

This entry will finally be the one for the accordion player, grandson of Pipe Major William (Willie) Lawrie <<ddp:Lawrie, P/M William#12248>>');
INSERT INTO 'person' VALUES (1438, NULL, '2022-12-21 15:03:10.523996+00', 'MacDonald, D', '', 'D MacDonald', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Composer of fiddle tune(s). Not the same as <<ddp:#12243>>.');
INSERT INTO 'person' VALUES (12151, '2022-06-08 09:29:15.21081+00', '2022-06-08 09:45:33.046263+00', 'Kondo, Masahiro', '', 'Masahiro Kondo', 'Yokohama, Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12154, '2022-06-17 22:35:27.116292+00', '2022-06-17 22:35:27.116292+00', 'Guildford SCDC', '', 'Guildford SCDC', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12153, '2022-06-17 15:31:44.366194+00', '2022-06-17 23:56:29.357482+00', 'Gray, Mary D', '', 'Gray, Mary D', 'Hoboken, New Jersey, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12120, '2022-04-15 15:49:57.087936+00', '2022-06-19 17:07:44.231541+00', 'Szakolczai, Ildikó', '', 'Ildikó Szakolczai', 'Budapest, Hungary', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12122, '2022-04-29 20:31:22.514517+00', '2022-06-21 15:50:31.228184+00', 'MacFadyen, Susan & Shona and Galloway, Ewan', '', 'Susan & Shona MacFadyen and Ewan Galloway', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12168, '2022-07-06 23:34:24.041381+00', '2022-07-06 23:56:58.257803+00', 'Salmin, Evgeny', '', 'Evgeny Salmin', 'Cheboksary, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1215, NULL, '2022-06-25 08:41:45.1481+00', 'MacKay, Mamie', '', 'Mamie MacKay', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Originally added as the deviser of <<ddd:Quite Contrary>> and originally assumed the same as the "<<ddp:Mackay, Maymie#12155>>" attributed as deviser of <<ddd:Lads of Lawers>>. However these are two different people (email confirmation from Sue James).



');
INSERT INTO 'person' VALUES (12155, '2022-06-25 08:37:49.783742+00', '2022-06-25 08:42:54.581322+00', 'Mackay, Maymie B F', '', 'Maymie Mackay', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Not the same person as "<<ddp:MacKay, Mamie#1215>>".');
INSERT INTO 'person' VALUES (12156, '2022-06-25 16:55:05.03307+00', '2022-06-25 17:15:31.340754+00', 'Brown, Leonard', '', 'Leonard Brown', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (883, NULL, '2023-01-20 10:23:57.119276+00', 'Schiehallion SCD Band', 'Schiehallion', 'Schiehallion SCD Band', 'Vancouver, BC, Canada', '', 1, 0, 0, 1, NULL, 0, 0, NULL, 'The band was formed in 1975 and travelled widely in Western Canada and North West USA.');
INSERT INTO 'person' VALUES (2806, NULL, '2022-06-25 23:56:59.689227+00', 'Trafford, Sheila', '', 'Sheila Trafford', '', '', 1, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12170, '2022-07-07 09:26:39.229852+00', '2022-07-07 09:26:39.229852+00', 'Kuznetsova, Natalya', '', 'Natalya Kuznetsova', 'Moscow, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12158, '2022-06-26 16:38:04.900742+00', '2022-06-27 23:56:12.874226+00', 'Candia, Charly', '', 'Charly Candia', 'Buenos Aires, Argentina', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12159, '2022-06-26 16:40:49.485981+00', '2022-06-27 23:57:06.017101+00', 'Stott, James and Candia, Charly', '', 'James Stott and Charly Candia', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11509, '2017-07-16 12:03:58.921755+00', '2022-07-03 01:24:09.074821+00', 'Dejean, Anne', '', 'Anne Dejean', 'Lyon, FR', '', 1, 1, 0, 0, NULL, 0, 2022, NULL, '');
INSERT INTO 'person' VALUES (12169, '2022-07-07 09:23:06.034146+00', '2022-07-07 09:39:06.580968+00', 'Lepekhova, Elena', '', 'Elena Lepekhova', 'Moscow, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12160, '2022-07-05 07:54:43.48736+00', '2022-07-05 23:56:54.958245+00', 'Queen, David G. & Queen, Catherine', '', 'David G. Queen & Catherine Queen', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12161, '2022-07-05 22:30:05.707498+00', '2022-07-05 23:56:58.598066+00', 'RSCDS Moscow Branch', '', 'RSCDS Moscow Branch', 'Moscow, Russia', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12162, '2022-07-05 22:42:03.856369+00', '2022-07-06 23:41:45.022456+00', 'Yarmarkina, Ekaterina', '', 'Ekaterina Yarmarkina', 'Saint Petersburg, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12163, '2022-07-05 22:50:02.549069+00', '2022-07-06 23:42:39.644666+00', 'Prytkova, Elena', '', 'Elena Prytkova', 'Voronezh, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12164, '2022-07-05 22:54:29.10952+00', '2022-07-06 23:43:19.588669+00', 'Lyfenko, Nikita', '', 'Nikita Lyfenko', 'Moscow, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12165, '2022-07-05 22:58:26.421177+00', '2022-07-06 23:43:51.665885+00', 'Kazakova, Yulia', '', 'Yulia Kazakova', 'Saratov, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12166, '2022-07-06 11:18:13.155701+00', '2022-07-06 23:44:24.315766+00', 'Dutikov, Dmitry', '', 'Dmitry Dutikov', 'Miass, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12167, '2022-07-06 22:50:29.429107+00', '2022-07-06 23:46:09.668041+00', 'Oleinikov, Pavel', '', 'Pavel Oleinikov', 'Ufa, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10810, '2013-07-24 14:43:14.361606+00', '2022-07-06 23:48:29.901063+00', 'Kargapoltsev, Sergey', '', 'Sergey Kargapoltsev', 'Saint Petersburg, Russia', 'robroyway@gmail.com', 1, 0, 0, 0, NULL, 0, 0, NULL, 'From a posting on 8x32');
INSERT INTO 'person' VALUES (12018, '2021-02-05 16:22:46.714183+00', '2022-07-06 23:49:25.612464+00', 'Zaitseva, T & Kislukhina, E', '', 'T. Zaitseva & E. Kislukhina', 'Moscow, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12017, '2021-02-05 16:21:38.485735+00', '2022-07-06 23:49:57.047562+00', 'Zaitseva, Tatiana', '', 'Tatiana Zaitseva', 'Moscow, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12176, '2022-07-13 07:17:38.507053+00', '2022-07-14 07:47:19.487767+00', 'Hill, Derek', '', 'Derek Hill', 'Canada', '', 1, 0, 0, 1, NULL, 0, 0, NULL, 'Derek Hill was the drummer with the Schiehallion SCD Band formed in 1975.



He also, together with Ian Price, devised the dance "The Hollyburn Jig" in 1976 for which Ian has composed the tune.



Unfortunately he has died a few years back (stated 2022).');
INSERT INTO 'person' VALUES (10503, NULL, '2022-12-21 10:35:23.872493+00', 'Pinewoods 2010 Musicians', 'Pinewoods 2010 Musicians', 'Pinewoods 2010 Musicians', '', '', 0, 0, 0, 1, 10503, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12172, '2022-07-13 07:10:33.960453+00', '2022-07-13 23:56:08.142919+00', 'Brady, Ian', '', 'Ian Brady', '', '', 1, 0, 0, 1, NULL, 0, 0, NULL, 'Ian Brady played accordion with the Schiehallion SCD Band formed in 1975.');
INSERT INTO 'person' VALUES (2767, NULL, '2022-12-23 12:57:50.231498+00', 'McKinnell, Sue & Newfield, Mady', 'McKinnell/Newfield', 'Sue McKinnell & Mady Newfield', 'Chicago', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12256, '2023-01-21 22:22:08.395187+00', '2023-01-22 00:56:33.40296+00', 'Jularbo, Carl', '', 'Carl Jularbo', 'Sweden', '', 0, 0, 1, 0, NULL, 1893, 1966, NULL, 'Swedish accordion virtuoso');
INSERT INTO 'person' VALUES (10249, NULL, '2022-07-13 23:56:08.175306+00', 'Brady, Luke / Muir, Ian / Lyon, Andrew', 'Brady/Muir/Lyon', 'Luke Brady, Ian Muir, Andrew Lyon', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12174, '2022-07-13 07:12:10.509668+00', '2022-07-13 23:56:13.343187+00', 'Collin, Celia', '', 'Celia Collin', '', '', 1, 0, 0, 1, NULL, 0, 0, NULL, 'Celia Collin is a violinist and was playing with the Schiehallion SCD Band formed in 1975 and later with the Tartan Players.');
INSERT INTO 'person' VALUES (12247, '2022-12-26 19:25:16.63944+00', '2022-12-27 00:56:56.256311+00', 'Silver, David / Gourlay, Ian', 'Silver/Gourlay', 'David Silver & Ian Gourlay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12157, '2022-06-25 17:27:52.824994+00', '2022-12-31 17:38:28.520532+00', 'Marian Anderson and Iain MacPhail''s Dance Bands', 'Marian and Iain', 'Marian Anderson and Iain MacPhail''s Dance Bands', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, 'These two bands recorded the CD Newcastle''s 70th Anniversary');
INSERT INTO 'person' VALUES (815, NULL, '2023-01-04 11:24:49.344655+00', 'Clark, Peter J', 'Peter Clark', 'Peter J Clark', 'Dumfries', 'kd@pjclark3.plus.com', 1, 1, 0, 0, NULL, 0, 0, NULL, 'This seems to be the husband to <<ddp:Clark, Pat#1582>>.');
INSERT INTO 'person' VALUES (12251, '2023-01-04 15:14:24.471012+00', '2023-01-04 15:16:37.018108+00', 'Donald, Robert & Donald, Mamie', '', 'Bob & Mamie Donald', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, 'They ran www.dancearchives.co.uk and the content of that website lives on as "The Donald Collection".  

More infos here: <<https://my.strathspey.org/dd/publication/436/>>');
INSERT INTO 'person' VALUES (12253, '2023-01-05 12:42:40.667672+00', '2023-01-05 12:42:40.667672+00', 'Porter, Emily', '', 'Emily Porter', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10755, '2013-02-22 16:01:18.758726+00', '2022-12-21 11:24:06.868514+00', 'Fisher, Mark & Goodwin, Joe & Shay, Larry', 'Fisher/Goodwin/Shay', 'Mark Fisher, Joe Goodwin & Larry Shay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Mark Fisher (* 24 March 1895 in Philadelphia; † 2 Jan 1948 in Long Lake, Illinois)

Joe Goodwin (6 Jun 1889;  † 31 Jul 1943)  

Larry Shay (né Lawrence Fredrick Schaetzlein; 10 Aug 1897 Chicago; † 22 Feb 1988 Newport Beach, California)');
INSERT INTO 'person' VALUES (998, NULL, '2022-07-13 08:58:16.238221+00', 'Price, Ian / Hill, Derek', '', 'Price, Ian / Hill, Derek', '', '', 1, 0, 0, 0, NULL, 1976, 1976, NULL, 'Ian Price and Derek Hill, both members of the Schiehallion SCD Band formed in 1975 have together devised the dance "The Hollyburn Jig" in 1976 for which Ian has composed the tune.



Unfortunately Derek has died a few years back (stated in 2022).');
INSERT INTO 'person' VALUES (50, NULL, '2022-07-13 14:49:57.439377+00', 'Brandon, Mary Shoolbraid', '', 'Mary Shoolbraid Brandon', 'Honolulu & Los Angeles, USA', 'dbbrand@ibm.net', 1, 1, 1, 0, NULL, 1925, 2016, NULL, 'Mary Shoolbraid was born April 6, 1925 into a dancing family in Leslie, Fife.



She got her RSCDS Teacher''s certificate in Scotland. Then in 1955 she moved to Vancouver, Canada. There she formed adult and children SCD classes. In 1961 also her brother <<https://my.strathspey.org/dd/person/1764/| Murray Shoolbraid>> joined her in Vancouver.



She also played a role in bringing Miss Milligan over for her first visit to Vancouver. Her visits then led to the founding of Vancouver Branch in 1964 with Mary as one of the first commitee members.

She also was the 1st teacher of the Gleneagles Club in West Vancouver.



In 1965 she met David Brandon from Los Angeles. End of 1966 they married and Mary moved to LA. Mary and David were leading figures in the Los Angeles Branch which David helped founding earlier in 1966. She also widely promoted SCD in Southern California as far south as San Diego.



In the early 1970s they moved to Hawaii due to David''s work, where they founded the Hawaii Branch in 1973.



They also travelled to Japan. While Mary gave workshops and

mentored teacher candidates, David helped in the formation of the

Tokyo Branch 1984. 



Later Mary and David hosted Miss Milligan when she visited the Pacific Islands on her last tour to the US and Canada. 



Mary and David returned to Los Angeles after more than 20 years on Hawaii.



Mary received the RSCDS Scroll of Honour In 1987 for her contributions and devotion to the Branches of Vancouver, Los Angeles, San Diego,

Hawaii and Tokyo. 



During her dancing life Mary has devised a large number of dances many of which have been published in her books "Dances With a Difference, Vol I", "Memories of Fife", "The Emigrant Scot" and the "Honolulu Book" of the Hawaii Branch. Furthermore Mary was appointed one of the first RSCDS examiners for North America.



Mary died on March 9, 2016.



There is a very informative article by Simon Scott about her dancing life in the May-Aug/2016 issue of the <<https://rscdsvancouver.org/resources/the-white-cockade/white-cockade-20152016/|White Cockade>> released by the Vancouver branch. Furthermore, the booklet <<https://archive.rscds.org/index.php/scottish-country-dancing-in-vancouver-history|A History of SCD in Vancouver>> provides many more information on Mary and her involvement in SCD and the Vancouver Branch over the years.');
INSERT INTO 'person' VALUES (12177, '2022-07-13 15:13:40.659926+00', '2022-07-13 15:15:15.471628+00', 'Brandon, David', '', 'David Brandon', 'Los Angeles, USA', '', 1, 0, 0, 0, NULL, 0, 2002, NULL, 'David Brandon was involved in founding a number of RSCDS Branches, like those of Los Angeles, Hawaii and Tokyo.



In 1966, the year he helped founding the LA branch, he married <<https://my.strathspey.org/dd/person/50/|Mary Shoolbraid>> and she moved from Vancouver to Los Angeles. 



Due to his work Mary and David moved to Hawaii in the early 1970s where they founded the Hawaii Branch in 1973. After his retirement in 1991 they moved back to LA. Here David was involved and teaching SCD classes in South Pasadena, West Los Angeles, and Simi Valley.



David received the RSCDS Scroll of Honour in 1996.



David died on May 1, 2002.');
INSERT INTO 'person' VALUES (10203, NULL, '2022-12-25 21:56:43.474576+00', 'Claribel', '', 'Charlotte Alington Barnard (Claribel)', '', '', 0, 0, 1, 0, NULL, 1830, 1869, NULL, 'Claribel was the pseudonym for Charlotte  Alington Barnard (23 December 1830 in Louth, Lincolnshire – 30 January 1869 in Dover)');
INSERT INTO 'person' VALUES (3009, NULL, '2022-12-26 19:33:38.278818+00', 'MacLeod, Jim and his Band', 'Jim Macleod', 'Jim MacLeod and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'Musician who played in the band (not necessarily all simultaneously and possibly incomplete) were:  



Jim Macleod - Piano and vocal  

Tommy Ford - accordion  

Jim Cleland - accordion  

Hebbie Gray - fiddle  

Jimmy Macfarlane - fiddle, tin whistle  

John Sinton - bass  

Robin Brock - bass

Alex Doig - drums  

Alex McMullan - drums  

Billy Thom - drums  

P/M Jimmy Mortimer - pipes  

Stan Saunders - bass  

George Hill - guitar  

  

John Drewry wrote dances dedicated to several members of the band like "Alex Doig''s Jig", "Tommy Ford''s Fancy" or "The Big Fiddle" (for John Stinton).');
INSERT INTO 'person' VALUES (12257, '2023-01-23 16:51:26.921897+00', '2023-01-24 11:31:40.449492+00', 'Adams, Susan', '', 'Susan Adams', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12033, '2021-04-07 23:26:48.430967+00', '2023-01-26 00:56:07.225458+00', 'Bootland, Niall', '', 'Niall Bootland', 'Glasgow, Scotland', '', 1, 0, 1, 0, NULL, 0, 0, NULL, 'Former president of the Oxford University Scottish Dance Society.

');
INSERT INTO 'person' VALUES (12258, '2023-01-25 12:36:53.889591+00', '2023-01-26 00:56:23.893529+00', 'Hart, Elidh', '', 'Elidh Hart', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12259, '2023-01-25 13:32:59.117586+00', '2023-01-26 00:56:50.553405+00', 'Ryan, William Bradley', '', 'William Bradley Ryan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'In 1883 he collated Ryan’s ‘Mammoth Collection of 1050 Reels and Jigs, Hornpipes, Clogs, Walk-arounds, Essences, Strathspeys, Highland Flings and Contra Dances’');
INSERT INTO 'person' VALUES (12219, '2022-12-09 21:30:55.977365+00', '2023-01-27 10:41:21.406283+00', 'Foss, Hugh (Formby)', '', 'Hugh Foss (Formby)', '', '', 0, 0, 0, 0, NULL, 0, 0, NULL, 'These are the successors of Hugh Foss.



See also the extensive history in the extra info for the <<ddpub:Scottish Dance Archives#436>>.');
INSERT INTO 'person' VALUES (2863, NULL, '2023-02-17 16:50:06.33831+00', 'Robertson, Alison', '', 'Alison Robertson', 'Hamilton and Clydesdale Branch', 'danceteach2013@gmail.com', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12175, '2022-07-13 07:13:21.639689+00', '2022-07-13 23:56:09.2633+00', 'Browne, Davene', '', 'Davene Browne', 'Vancouver, Canada', '', 1, 0, 0, 1, NULL, 1924, 2020, NULL, 'Davene was born as Davene Kelly in 10 January 1924 in Saskatchewan, Canada. She first learned to play the tuba and later the string bass. She was playing with a number of bands and orchestras including the New Westminster

Symphony Orchestra and the Vancouver Philharmonic Orchestra.

At the Vancouver Philharmonic she got to know Celia Collin encouraging her to also play Scottish music and they both joined the Schiehallion SCD Band formed by Ian Price and Ian Brady in 1975, playing together with Ian Brady, Derek Hill and Murray Shoolbraid. They played together for about 12 year mainly in western Canada and also Washington state.



After 1990 she also joined the the Vancouver Fiddle Orchestra (VFO, formed by Ian Price and Tom Scott) and played with other SCD bands like Scuttlebutt, (Ewan

''Sudsy'' Clark, fiddle; Kristi Lind, piano; Janet Wright, guitar) and the "Tartan Players" (Julie Smith, piano; again with Celia Collin, fiddle; Carole Berger, flute; later Deborah Jones and Lucasz Wieczorek, both fiddle, replacing Celia).



She was regarded a great mentor to new musicians, pointing out the things they got write rather than mistakes.



In the end she played SCD music for about 40 years.



At some time she gave her double Bass to Janet Wright who is now the leader of the Vancouver Fiddle Orchestra.



Davene Browne died in 2020.



There are two very nice and informative obituaries by Janet Wright and Ian Price in the Nov-Dec/2020 issue of the <<https://rscdsvancouver.org/resources/the-white-cockade/white-cockade-20202021/|White Cockade>> released by the Vancouver branch and additional information in the <<https://www.vancouverceilidh.org/?page_id=12648|Vancouver 2020/21 Ceilidh Newsletter #2>>. ');
INSERT INTO 'person' VALUES (1764, NULL, '2022-07-13 23:56:55.547579+00', 'Shoolbraid, Murray', '', 'Murray Shoolbraid', 'Salt Spring Island, Canada', 'gmhshoolbraid@gmail.com', 1, 1, 1, 1, NULL, 1931, 2020, NULL, 'Murray Shoolbraid was a piano player.



He was born November 10, 1931 in Kinglassie, Fife. 



Already in Scotland he provided the musical accompaniment on the piano for the many classes his mother was teaching.



In 1961 he moved to Vancouver, Canada, joining his sister  <<https://my.strathspey.org/dd/person/50/|Mary Shoolbraid Brandon>>. He got actively involved with the SCD groups in the region that Mary had started.



Besides composing many tunes and having written a dance, Murray Shoolbraid played piano with the a number of bands, namely the "Schiehallion SCD Band" formed in 1975, “The Teuchters”; the “Vancouver Ceilidh Band” and Victoria-based “Barley Bree”. 

He is said, that he could transpose music to any key. This was very advantageous because many of the pianos he encountered were frequently off pitch.



In 1980 his family moved to Salt Spring Island.



He died on February 26, 2020 after a short illness.



There is an informative obituary on <<https://saltspringexchange.com/2020/03/11/obituary-murray-shoolbraid/|Salt Spring Exchange>>.');
INSERT INTO 'person' VALUES (12180, '2022-07-15 17:50:33.106803+00', '2022-07-15 23:56:25.126067+00', 'Grant, A/Taylor, B', '', 'Anne Grant & Bob Taylor', 'Fochabers, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12179, '2022-07-15 17:43:18.832913+00', '2022-07-15 23:56:29.420354+00', 'Hinz, Wolf-Peter', '', 'Wolf-Peter Hinz', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12178, '2022-07-15 13:24:37.866322+00', '2022-07-15 23:57:06.884453+00', 'Wissenbach, Knut', '', 'Knut Wissenbach', 'Niederheimbach, DE', '', 1, 0, 0, 0, NULL, 1965, 0, NULL, '');
INSERT INTO 'person' VALUES (3647, NULL, '2022-07-19 14:24:48.489891+00', 'Dean, Douglas J', '', 'Douglas J Dean', '', '', 1, 1, 0, 0, NULL, 1933, 2022, NULL, '');
INSERT INTO 'person' VALUES (12181, '2022-07-21 09:23:33.783211+00', '2022-07-21 09:23:33.783211+00', 'Zeltins, Victoria', '', 'Victoria Zeltins', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12182, '2022-07-27 13:25:30.513985+00', '2022-07-27 13:25:30.513985+00', 'Morrison, Stuart', '', 'Stuart Morrison', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11792, '2019-02-26 11:45:24.786571+00', '2022-07-27 13:38:55.056992+00', 'Laing, Alexander', '', 'Alexander Laing', '', '', 0, 0, 1, 0, NULL, 1792, 1868, NULL, 'List of tunes found at <<https://petermacfiehistorian.net.au/publications/on-the-fiddle/manuscript-tunes/>>');
INSERT INTO 'person' VALUES (12183, '2022-07-27 13:33:13.970014+00', '2022-07-27 23:56:59.543763+00', 'Stewart, Donald', '', 'Donald Stewart', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (645, NULL, '2022-08-04 23:56:52.670242+00', 'Ross, Alan', '', 'Alan Ross', '', 'Alansband@sky.com', 0, 0, 1, 0, NULL, 0, 0, NULL, 'In addition to composing  tunes I am an accordionist and bandleader.');
INSERT INTO 'person' VALUES (402, NULL, '2022-07-29 11:48:18.077264+00', 'Wallin, Joseph', '', 'Joseph Wallin', 'Dartmouth, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'There was some further information at Dick Oakes'' <<https://socalfolkdance.org/master_teachers.htm|Folk Dance Master Teacher Biographies>>:



- <<https://socalfolkdance.org/master_teachers/wallin_j.htm|Joe Wallin''s Biography>> by Dick Oakes

- The Biographies had been hosted at phantomranch.net in the past before they moved to socalfolkdance.org. A copy can still be found through the <<https://web.archive.org/web/20160320185737/http://www.phantomranch.net/folkdanc/teachers/wallin_j.htm|Internet Archive>>');
INSERT INTO 'person' VALUES (12185, '2022-07-30 12:25:07.548757+00', '2022-07-30 12:25:07.548757+00', 'New, Segedi, Glasspool', '', 'New, Segedi, Glasspool', 'NY, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12184, '2022-07-30 12:24:22.039997+00', '2022-07-30 12:29:52.162165+00', 'New, Lois', '', 'Lois New', 'Albany, NY, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12186, '2022-08-03 13:10:12.046942+00', '2022-08-03 13:10:12.046942+00', 'Kaiho, Masao', '', 'Masao Kaiho', 'Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12187, '2022-08-06 15:49:56.321077+00', '2022-08-06 23:56:24.123673+00', 'Gregg, Hubert', '', 'Hubert Gregg', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12188, '2022-08-07 08:27:16.704259+00', '2022-08-07 23:56:18.270741+00', 'Dunn, Matt', '', 'Matt Dunn', 'Paris, France', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12189, '2022-08-07 08:28:59.589107+00', '2022-08-07 23:57:02.732815+00', 'Wilkinson, Emmy & Dunn, Matt', '', 'Emmy Wilknson & Matt Dunn', 'Paris, France', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11520, '2017-09-05 20:44:37.424863+00', '2022-08-14 23:56:32.707335+00', 'Joubert, Liebet', '', 'Liebet Joubert', 'Pretoria, S.Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (725, NULL, '2022-10-13 07:41:58.180782+00', 'Laidlaw, Ruary', '', 'Ruary Laidlaw', 'New Zealand', 'ruarylaidlaw@gmail.com', 1, 1, 0, 0, NULL, 0, 0, NULL, 'In addition to publishing books of dances, Ruary has also published "For a Year and A Day - A guide for Teaching Beginners and Elementary Dancers". He writes:  

*It provides a programme for teaching Beginners and Elementary dancers the 64 steps and formations of Scottish Country Dancing at these levels. It also provides a list of dances for each of the 64 steps and formations that a teacher can use to teach each one of these, carefully arranged in a sequence that builds on what has gone before - there are no sudden surprises where there is something more difficult suddenly appearing alongside the focus.*');
INSERT INTO 'person' VALUES (12243, '2022-12-21 14:56:35.250715+00', '2022-12-21 15:03:39.672523+00', 'Macdonald, Doug', '', 'Doug Macdonald', 'Claremont, California, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Deviser of dances. Not the same as <<ddp:#1438>>.');
INSERT INTO 'person' VALUES (12248, '2022-12-26 21:40:22.288052+00', '2022-12-26 21:55:41.02105+00', 'Lawrie, P/M William (Willie)', 'P/M Lawrie', 'P/M William (Willie) Lawrie', 'Ballachulish', '', 0, 0, 1, 0, NULL, 1881, 1916, NULL, 'Grandfather to accordionist <<ddp:Lawrie, Willie#1543>>. P/M Lawrie was a famous bagpipe composer.');
INSERT INTO 'person' VALUES (12245, '2022-12-26 18:53:26.533304+00', '2022-12-27 00:56:55.974114+00', 'Short, Frank', 'Frank Short', 'Frank Short', 'Birmingham', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12249, '2023-01-04 11:17:35.522998+00', '2023-01-04 11:58:33.760809+00', 'Chevens, Maureen A.', 'M. Chevens', 'Maureen A. Chevens', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1343, NULL, '2023-01-04 15:03:17.622289+00', 'Clowes, Roy & Donald, Bob', '', 'Roy Clowes & Bob Donald', '', '', 1, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10346, NULL, '2023-01-04 22:47:55.245673+00', 'Vreke, Gerrit', '', 'Gerrit Vreke', 'Geldermalsen, Netherlands', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11222, '2015-10-25 12:57:36.938459+00', '2023-01-05 12:20:25.960662+00', 'Halpenny, Liza', '', 'Liza Halpenny', 'Ridgefield, Washington, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12254, '2023-01-17 22:04:42.514647+00', '2023-01-17 22:04:42.514647+00', 'Wood, Keith', '', 'Keith Wood', 'Sydney, Australia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12255, '2023-01-21 10:04:37.788288+00', '2023-01-21 10:04:37.788288+00', 'RSCDS Forres', '', 'RSCDS Forres', 'Forres, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (743, NULL, '2022-08-19 16:19:39.938866+00', 'Milligan, Alex', '', 'Alex Milligan', '', '', 1, 1, 0, 0, NULL, 0, 2022, NULL, 'Jacquy Milligan, Alex''s wife, writes in <<https://my.strathspey.org/dd/issue/2858/|issue 2858>> that:



Alex obtained his Dance teacher''s certificate from RSCDS and taught both children and adults for circa 60 years.

He entered teams in festivals - and ran the dancing part of the Edinburgh Competitive Festival for several years.

He demonstrated Scottish Country Dancing at many venues in Edinburgh and also at various festivals abroad.

Latterly his Club focused on older dancers and was a great social venue.



And by email:  "Alex was a passionate Scottish Country Dance ''fanatic'' right from age 15 till the day he died. We played Captain Bain’s Tribute (composed by him) and Dancing the Baby at his funeral (and had feet tapping as he had requested)."



(_Note:_ According to the <<ddd:Captain Bain''s Tribute>> dance leaflet in SDA, the eponymous tune was written by John MacGregor.)');
INSERT INTO 'person' VALUES (3325, NULL, '2022-10-20 22:24:22.223242+00', 'Webb, Stephen', '', 'Stephen Webb', 'Hemel Hempstead, UK', 'stphnwbb@gmail.com', 1, 0, 0, 0, NULL, 1945, 0, NULL, 'Fully Certificated (St Andrews) August 1977 examined by Jean Milligan.  

RSCDS London Branch Award June 2021.  

BSRC The Bateson Medal April 2022.  

');
INSERT INTO 'person' VALUES (12195, '2022-08-21 18:11:00.745318+00', '2022-08-21 18:11:00.745318+00', 'Bakker, Adam', '', 'Adam Bakker', 'London, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12190, '2022-08-21 16:39:43.056811+00', '2022-08-21 23:56:03.329585+00', 'Alexander, Jack/Walsh, Tom/Finlay, D.', '', 'Jack Alexander/Tom Walsh/D. Finlay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12193, '2022-08-21 17:06:29.705485+00', '2022-08-21 23:56:21.886328+00', 'Gahan, G. Wilkie', '', 'G. Wilkie Gahan', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12191, '2022-08-21 16:45:21.213895+00', '2022-08-21 23:56:33.465372+00', 'Lawrie, Angus', '', 'Angus Lawrie', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12192, '2022-08-21 16:46:25.78086+00', '2022-08-21 23:56:37.556369+00', 'MacPhee, Donald', '', 'Donald MacPhee', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12194, '2022-08-21 17:12:21.007522+00', '2022-08-21 23:56:37.995854+00', 'Marshall', '', 'Marshall', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'NOT William Marshall (18c fiddle composer)');
INSERT INTO 'person' VALUES (12200, '2022-08-22 23:25:38.112755+00', '2022-08-22 23:56:06.68414+00', 'Bernstein, Leonard', '', 'Leonard Bernstein', '', '', 0, 0, 1, 0, NULL, 1918, 1990, NULL, '');
INSERT INTO 'person' VALUES (12196, '2022-08-22 22:57:11.538109+00', '2022-08-22 23:56:28.638844+00', 'Highfield Ceilidh Band, The', 'Highfield CB', 'The Highfield Ceilidh Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12199, '2022-08-22 23:15:00.03248+00', '2022-08-22 23:56:36.931496+00', 'MacAlpine', '', 'MacAlpine', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12198, '2022-08-22 23:13:28.889222+00', '2022-08-22 23:56:36.960538+00', 'MacArthur, M', '', 'M MacArthur', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12197, '2022-08-22 23:02:27.467008+00', '2022-08-22 23:56:53.569648+00', 'Ross, D', '', 'D Ross', 'Cockenzie, UK', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2885, NULL, '2022-08-29 14:28:06.811908+00', 'Knight, David / Donaldson, Liz / Gordon, Ralph', '', 'David Knight, Liz Donaldson & Ralph Gordon', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12201, '2022-08-30 18:14:38.309522+00', '2022-08-30 18:39:30.388986+00', 'Yanagawa, Momo', '', 'Momo Yanagawa', 'Tokai, Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12202, '2022-08-30 18:42:29.025896+00', '2022-08-30 18:45:55.101284+00', 'Inokuchi, Hidehiko', '', 'Hidehiko Inokuchi', 'Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12203, '2022-08-31 09:27:56.952534+00', '2022-08-31 09:42:02.806791+00', 'Kajino, Yukio', '', 'Yukio Kajino', 'Yamato, Japan', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12204, '2022-09-17 20:44:20.540537+00', '2022-09-17 23:56:47.345901+00', 'Murray, Michael', '', 'Michael Murray', 'Mid-Argyll, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12205, '2022-09-19 08:13:58.177846+00', '2022-09-19 08:13:58.177846+00', 'Osgarby, David', '', 'David Osgarby', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12206, '2022-09-19 21:13:07.50834+00', '2022-09-19 21:13:07.50834+00', 'Unit 2&3 Summer School class 2022', '', 'Unit 2&3 Summer School class 2022', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10947, '2014-04-14 21:24:09.218505+00', '2022-09-19 21:25:00.916035+00', 'Unit 2&3 Summer School class 2010', '', 'Unit 2&3 Summer School class 2010', 'St. Andrewes', '', 1, 0, 0, 0, NULL, 2010, 2010, NULL, '');
INSERT INTO 'person' VALUES (12207, '2022-09-20 06:54:22.684459+00', '2022-09-20 23:56:37.180187+00', 'Lower Hutt SCD Club', '', 'Lower Hutt SCD Club', 'Lower Hutt, Wellington, NZ', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2161, NULL, '2022-10-01 20:07:49.982369+00', 'Healy, James & Marilyn', '', 'James & Marilyn Healy', 'Perth', 'The_Healys@compuserve.com', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Jim died in 2022');
INSERT INTO 'person' VALUES (12208, '2022-10-01 15:14:20.7214+00', '2022-10-01 23:56:31.676653+00', 'Joubert, Wouter & Liebet', '', 'Wouter & Liebet Joubert', 'Pretoria, South Africa', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3323, NULL, '2022-10-18 01:40:12.016191+00', 'Ferguson, Eric', '', 'Eric Ferguson', 'Zeist, Netherlands', 'e.ferguson@antenna.nl', 1, 0, 0, 0, NULL, 1931, 0, NULL, 'Also SCDDB editor.

Phone +31 6 19000911');
INSERT INTO 'person' VALUES (12209, '2022-11-18 12:03:18.40327+00', '2022-11-18 12:03:18.40327+00', 'Atholl SCD Club', '', 'Atholl SCD Club', 'Atholl, Scotland', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12210, '2022-11-18 12:07:32.776217+00', '2022-11-18 20:00:45.528651+00', 'Nuttall, John', '', 'John Nuttall', 'Atholl, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12211, '2022-11-18 20:01:27.802874+00', '2022-11-18 20:01:27.802874+00', 'Nuttall, Alison', '', 'Alison Nuttall', 'Atholl, Scotland', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12212, '2022-11-27 11:54:26.10222+00', '2022-11-28 00:56:04.889867+00', 'Austin, Bill', '', 'Bill Austin', 'Dunfermline', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (439, NULL, '2022-11-30 23:46:02.656107+00', 'Malcolm, Marie', '', 'Marie Malcolm', 'Wellington, NZ', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Information received by email (in 2022): "Marie Malcolm passed away a few years ago".');
INSERT INTO 'person' VALUES (12213, '2022-12-01 12:51:55.284815+00', '2022-12-01 12:52:42.831967+00', 'Liu, Charles', '', 'Charles Liu', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3051, NULL, '2022-12-02 11:44:50.042949+00', 'Holmes, Ian and his Band', 'Ian Holmes', 'Ian Holmes and his Band', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12214, '2022-12-02 22:05:14.214298+00', '2022-12-02 22:13:13.184491+00', 'Pierson, Marion', '', 'Marion Pierson', 'Staines, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12215, '2022-12-02 22:05:55.936737+00', '2022-12-02 22:13:33.965851+00', 'Pierson, Brian & Marion', '', 'Brian & Marion Pierson', 'Staines, UK', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1917, NULL, '2022-12-03 20:24:45.932187+00', 'Smith, T Morton', '', 'T Morton Smith', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Thne instructions for the dance <<ddd:Make Up The Quarrel#4110>> say that its music of the same name was composed by R Morton Smith (the deviser). So this separate entry for T Morton Smith may be a mistake?');
INSERT INTO 'person' VALUES (12216, '2022-12-08 15:44:45.68204+00', '2022-12-08 15:44:45.68204+00', 'McInnes, Bob', '', 'Bob McInnes', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (587, NULL, '2022-12-22 20:25:08.284672+00', 'Gratiot, Sara & Douglas, Paul', '', 'Sara Gratiot & Paul Douglas', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12246, '2022-12-26 19:24:08.819516+00', '2022-12-27 00:56:56.238512+00', 'Silver, David', 'David Silver', 'David Silver', '', '', 0, 0, 1, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1582, NULL, '2023-01-04 11:25:15.803204+00', 'Clark, Pat', '', 'Pat Clark', 'Dumfries', '', 1, 1, 1, 0, NULL, 0, 2022, NULL, 'This seems to be the wife to <<ddp:Clark, Peter J#815>>');
INSERT INTO 'person' VALUES (12250, '2023-01-04 15:11:32.396369+00', '2023-01-04 15:16:46.279386+00', 'Donald, Mamie', '', 'Mamie Donald', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, 'Wife of <<ddp:Donald, Robert#105>>. She ran businesses with him and contributed to the so called "Donald Collection", coming from their former website www.dancearchives.co.uk.  

More information in the extra note section here:  

<<https://my.strathspey.org/dd/publication/436/>>');
INSERT INTO 'person' VALUES (12252, '2023-01-05 12:42:15.095174+00', '2023-01-05 12:42:15.095174+00', 'Gerrie, Tristan', '', 'Tristan Gerrie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10990, '2014-08-25 15:43:46.270608+00', '2023-01-08 00:56:22.368211+00', 'Georgeson/Anderson', '', 'Tom Georgeson/Tom Anderson MBE', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'In 1948, Tammy formed and led the Islesburgh Dance Band which was to retain its popularity until disbanded twenty years later ; the band members over the years read like a ‘who’s-who’ of Shetland musicians – Tammy, Winnie Leslie (now Leask), Alice Sutherland (now Nicolson), Violet Scott (now Tulloch), Joan Stevenson (now Russell), Pearl Deyall, Larry Peterson, Lowrie Fraser, Stewart and Marjory Smith, Peter Leith, Tom Georgeson, John Kerr, Drew Robertson, Frankie Sinclair and Peerie Willie.



(http://boxandfiddlearchive.weebly.com/dr-tom-anderson-mbe.html)');
INSERT INTO 'person' VALUES (11002, '2014-09-12 20:10:10.089369+00', '2023-01-08 15:08:52.88069+00', 'Watt, George T', '', 'George T Watt', 'Dundee, Scotland', 'georgetwatt@hotmail.com', 1, 1, 0, 0, NULL, 1948, 0, NULL, 'George Watt has devised quite a number of dances most of which are published in his book  "The Round ''O'' Book of Scottish Country Dances".



George started dancing already at the age of 4.');
INSERT INTO 'person' VALUES (108, NULL, '2022-12-08 21:11:29.1823+00', 'Drewry, John', '', 'John Drewry', 'Aberdeen', '', 1, 1, 0, 0, NULL, 1923, 2014, NULL, 'There was an obituary of John Drewry in <<http://www.scotsman.com/|The Scotsman>>: see  <<https://www.scotsman.com/news/obituaries/obituary-john-drewry-scottish-dance-deviser-and-academic-1532036>>.



##>>

In a masterly piece of understatement, the citation by Aberdeen Branch supporting the award of the Society’s Scroll of Honour to John in 1999 begins:  

»John is recognised world-wide as a deviser of dances and several of his dances have been published by the Society«. This, however, is typical of John’s own modesty.

##<<



He was born 14 July 1923 in Melton Mowbray, Leicestershire. He died aged 90 on 18 June 2014 in Aberdeen.



Chris Ronals writes, on 27 feb. 2018:  Drewry fans may like to know that an index of his dances has just been placed by the Teachers'' Association (Canada) on their website.  It can be seen at <<https://tac-rscds.org/index.php/special-topic/index-of-john-drewry-s-dances>>  



An article on John by Stephen Webb appeared in <<https://www.rscdslondon.org.uk/wp-content/uploads/2014/09/140908-Reel-289.pdf#page=12|issue 289 of The Reel>>.');
INSERT INTO 'person' VALUES (12228, '2022-12-19 23:04:03.172628+00', '2022-12-19 23:16:36.387441+00', 'Scotia Dance and Music Publishers, New York', '', 'Scotia Dance and Music Publishers, New York', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12217, '2022-12-08 22:57:40.635061+00', '2022-12-08 23:04:04.292377+00', 'Harling, John', '', 'John Harling', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Also known as Johnny Harling.');
INSERT INTO 'person' VALUES (3150, NULL, '2022-12-09 00:16:58.540465+00', 'Johnstone, Duncan', '', 'Duncan Johnstone', 'Glasgow', '', 0, 0, 1, 0, NULL, 1925, 1999, NULL, '');
INSERT INTO 'person' VALUES (12218, '2022-12-08 23:48:28.90737+00', '2022-12-09 00:56:35.229293+00', 'Lawrie, Ian', '', 'Ian Lawrie', '', '', 0, 0, 1, 0, NULL, 1913, 1987, NULL, 'Some information on Ian Lawrie can be found here.

https://boxandfiddlearchive.weebly.com/willie-lawrie.html');
INSERT INTO 'person' VALUES (11071, '2015-02-09 13:15:17.938383+00', '2022-12-20 00:56:13.412563+00', 'Cole Jr., Jack E.', '', 'Jack E. Cole Jr.', 'New York NY', '', 0, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12220, '2022-12-10 19:07:48.994485+00', '2022-12-10 19:07:48.994485+00', 'Glasspool, Terry & Merkens, Luitgard', '', 'Terry Glasspool & Luitgard Merkens', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Luitgard Merkens is associated with the SCD Group in Münster/Germany.');
INSERT INTO 'person' VALUES (3547, NULL, '2022-12-20 00:56:14.243339+00', 'Cooper, Glen A', '', 'Glen A Cooper', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12221, '2022-12-10 22:57:06.423894+00', '2022-12-11 00:57:03.983818+00', 'von Tilzer, Harry & Sterling, Andrew B.', '', 'Harry von Tilzer, Andrew B. Sterling', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Harry von Tilzer (1872-1946), Andrew B. Sterling (1874 - 1955)');
INSERT INTO 'person' VALUES (10999, '2014-08-31 16:44:12.219904+00', '2022-12-11 12:39:22.736576+00', 'McLaughlin, Marjorie', '', 'Marjorie McLaughlin', 'San Diego', '', 0, 0, 0, 0, NULL, 0, 0, NULL, 'This entry is meant for the teacher who as of now did not devise any dances or compose any tunes.');
INSERT INTO 'person' VALUES (11078, '2015-02-13 14:36:03.072561+00', '2022-12-11 12:43:04.106968+00', 'McLaughlin, Marshall & Anne', 'M & A McLaughlin', 'Marshall & Anne McLaughlin', 'Hot Springs, NC USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, 'Published their dance "Thank You Jack" in "The Petronella Paper" (May-August 2010) of the Atlanta Branch');
INSERT INTO 'person' VALUES (12222, '2022-12-13 22:23:23.68967+00', '2022-12-13 22:23:23.68967+00', 'Newbiggin, Florence', '', 'Florence Newbiggin', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (3152, NULL, '2022-12-16 21:00:38.586486+00', 'McKay, Ray & Maxwell, Joseph', '', 'Ray McKay & Joseph Maxwell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12224, '2022-12-16 20:58:29.259291+00', '2022-12-17 00:56:42.072076+00', 'Maxwell, Joseph (Joe)', 'Joseph Maxwell', 'Joseph Maxwell', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12223, '2022-12-16 20:58:06.254097+00', '2022-12-17 00:56:43.467481+00', 'McKay, Ray', 'Ray McKay', 'Ray McKay', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2549, NULL, '2022-12-18 11:20:00.484187+00', 'Olcott, Chauncey & Graff Jr., George & Ball, Ernest', 'Graff/Ball/Olcott', 'Chauncey Olcott, George Graff, Jr. & Ernest Ball', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2249, NULL, '2022-12-18 17:53:45.54656+00', 'Box, Elton / Cox, Desmond / Butler, Ralph / Roberts, Paddy', 'Box/Cox/Butler/Roberts', 'Elton Box, Desmond Cox, Ralph Butler & Paddy Roberts', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12225, '2022-12-18 21:19:28.581381+00', '2022-12-18 21:19:28.581381+00', 'Madison Scottish Country Dancers', 'MSCD', 'Madison Scottish Country Dancers', 'Madison, USA', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12226, '2022-12-18 22:24:50.115057+00', '2022-12-18 22:24:50.115057+00', 'Burchick, Rhona', '', 'Rhona Burchick', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12227, '2022-12-18 22:29:50.97839+00', '2022-12-18 22:29:50.97839+00', 'Beattie, David', '', 'David Beattie', '', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (1862, NULL, '2022-12-19 10:03:11.59186+00', 'Briggs, Michael', 'Mike Briggs', 'Michael Briggs', 'Wisconsin, USA', 'brigglaw@earthlink.net', 1, 0, 1, 0, NULL, 1935, 2019, NULL, '<<https://www.cressfuneralservice.com/obituary/Michael-Briggs|Obituary>>');
INSERT INTO 'person' VALUES (2723, NULL, '2022-12-19 10:13:08.839012+00', 'Trinkaus-Randall, Gregor', '', 'Gregor Trinkaus-Randall', '', '', 1, 1, 0, 0, NULL, 1946, 2019, NULL, '<<https://www.lehmanreen.com/notices/Gregor-Trinkaus-Randall|Obituary>>');
INSERT INTO 'person' VALUES (10754, '2013-02-22 15:59:00.803795+00', '2022-12-19 22:24:36.925376+00', 'Muir, Lewis F. & Gilbert, L. Wolfe', 'Muir/Wolfe', 'Lewis F. Muir & L. Wolfe Gilbert', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Louis Wolfe Gilbert (August 31, 1886 – July 12, 1970)  

Lewis F. Muir, born Louis Meuer (May 30, 1883 – December 3, 1915)');
INSERT INTO 'person' VALUES (2320, NULL, '2022-12-19 22:35:30.949733+00', 'Woods, Harry & Dixon, Mort', 'Woods/Dixon', 'Harry Woods & Mort Dixon', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'Mort Dixon (* 20 March 1892 in New York City; † 23 March 1956 in Bronxville, New York)  

Harry MacGregor Woods (* 4 Nov 1896 in North Chelmsford, Massachusetts as Henry MacGregor Woods; † 14 Jan 1970 in Glendale, Arizona) ');
INSERT INTO 'person' VALUES (12229, '2022-12-20 10:55:21.426881+00', '2022-12-21 00:56:06.896482+00', 'Berry, Chu', 'Chu Berry', 'Chu Berry', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12236, '2022-12-20 20:29:07.389372+00', '2022-12-21 00:56:08.461421+00', 'Boutelje, Phil & Winfree, Dick', 'Boutelje/Winfree', 'Phil Boutelje & Dick Winfree', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12235, '2022-12-20 20:25:15.068225+00', '2022-12-21 00:56:14.788103+00', 'Cox, Jimmy', 'Jimmy Cox', 'Jimmy Cox', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12231, '2022-12-20 15:17:32.204791+00', '2022-12-21 00:56:17.567574+00', 'Donaldson, Walter', 'Walter Donaldson', 'Walter Donaldson', '', '', 0, 0, 1, 0, NULL, 1893, 1947, NULL, '');
INSERT INTO 'person' VALUES (12230, '2022-12-20 15:13:41.746233+00', '2022-12-21 00:56:19.21873+00', 'Ellington, Duke', 'Duke Ellington', 'Duke Ellington', '', '', 0, 0, 1, 0, NULL, 1899, 1974, NULL, '');
INSERT INTO 'person' VALUES (12237, '2022-12-20 20:32:21.127689+00', '2022-12-21 00:56:36.383463+00', 'Lovelady, William (Bill)', 'Bill Lovelady', 'Bill Lovelady', '', '', 0, 0, 1, 0, NULL, 1945, 0, NULL, '');
INSERT INTO 'person' VALUES (12233, '2022-12-20 20:20:16.811254+00', '2022-12-21 00:56:48.454193+00', 'Palmer, Jack & Williams, Spencer', 'Palmer/Williams', ' Jack Palmer & Spencer Williams', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12234, '2022-12-20 20:23:14.227616+00', '2022-12-21 00:56:51.688486+00', 'Razaf, Andy & Redman, Don', 'Razaf/Redman', 'Andy Razaf & Don Redman', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12232, '2022-12-20 19:56:06.542596+00', '2022-12-21 00:56:58.237381+00', 'Smith, Clarence "Pinetop"', 'Clarence Smith', 'Clarence "Pinetop" Smith', '', '', 0, 0, 1, 0, NULL, 1904, 1929, NULL, '');
INSERT INTO 'person' VALUES (12238, '2022-12-21 10:32:57.42768+00', '2022-12-21 10:32:57.42768+00', 'Anderson, Paul', 'Paul Anderson', 'Paul Anderson', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, 'Most likely not identical to Paul Anderson (composer).');
INSERT INTO 'person' VALUES (12240, '2022-12-21 10:34:24.063699+00', '2022-12-22 00:56:40.884066+00', 'MacNintch, Mike', 'Mike MacNintch', 'Mike MacNintch', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (11849, '2019-08-11 20:19:29.21432+00', '2022-12-21 14:57:53.013568+00', 'Kiser, Cynthia & Macdonald, Doug', '', 'Cynthia Kiser & Doug Macdonald', 'California, USA', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12239, '2022-12-21 10:34:02.339817+00', '2022-12-22 00:56:10.862431+00', 'Buda, Rosalind', 'Rosalind Buda', 'Rosalind Buda', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12242, '2022-12-21 10:45:58.387756+00', '2022-12-22 00:56:46.024321+00', 'Monaco, James Vincent & Jerome, William', 'Monaco/Jerome', 'James V. Monaco & William Jerome', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12241, '2022-12-21 10:34:43.039024+00', '2022-12-22 00:56:51.40005+00', 'Pixton, Barbara', 'Barbara Pixton', 'Barbara Pixton', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (242, NULL, '2022-12-22 17:24:32.473324+00', 'MacNab, Mary Isdale', '', 'Mary Isdale MacNab', 'Vancouver, Canada', '', 1, 1, 0, 0, NULL, 1889, 1966, NULL, 'See also <<ddpub:Scottish Dances collected by Mary Isdal MacNab>> (RSCDS publication) and its

precursors, <<ddpub:MacNab Dances Vol 1>> and <<ddpub:MacNab Dances Vol 2>>.



<<https://www.rscdslondon.org.uk/mary-isdale-macnab-dances/|RSCDS London Branch>>

operates <<https://www.rscdslondon.org.uk/mary-isdale-macnab-dances/|The Mary Isdale MacNab Collection>>,

which includes scans of many of the dances associated with Mrs MacNab

as originally published, as well as videos.



Spelling

--------



As reported in <<https://my.strathspey.org/dd/issue/2305/|issue 2305>> Mary Isdale MacNab is the correct spelling of her name. However some RSCDS publications and therefore the original SCDDB entry had her middle name as "Isdal".



General Notes

-------------



In the interest of correctness we should like to point out that while the database may give the impression

that Mrs MacNab was a “deviser” of dances, the extent to which she was personally involved in the creation of

much of the

material associated with her is difficult to pin down with any certainty. Without doubt the main publications of “MacNab dances” put out by the RSCDS (see above)

list her as a “collector”, but the actual provenance of the dances in

question is impossible to ascertain, and sometimes the claimed origin of a dance does seem quite far-fetched.

The fact that most of these dances are obviously quite unlike the rest of the traditional SCD repertoire also raises legitimate questions as to their actual origins.



Based on this and in the absence of hard evidence to the contrary,

it is not entirely unreasonable to conjecture that Mary Isdale MacNab did make at least some of the dances up herself, or

changed them considerably prior to publication.

Certainly “arranging” collected dances to conform to one''s perception

of an idealised “correct” version, sometimes modifying

them extensively in the process,

was something that in MacNab''s time was not generally frowned upon. The Society used to do it, too.

On the other hand, inventing entirely new dances from whole cloth (especially very unusual rococo ones)

was much less accepted.

Hence in some circumstances it might make a certain amount of sense to endow a newly

devised dance with a fanciful yet impossible-to-verify back story, in order to give it more street credibility.



As an extreme POV, to some the “MacNab dances” effectively

represent the <<https://en.wikipedia.org/wiki/Ossian|Poems of Ossian>> of the SCD world.



Collecting vs. Devising

-----------------------



For technical reasons, the database does not support a “dance collector” category, and

most of the “MacNab dances” are credited to that prolific deviser of dances, “Unknown”, simply because that

information is not available to us. As a result of this, most of the dances associated with Mrs MacNab aren''t listed

on the “Dances” tab of her detail page, but must be accessed through the RSCDS publications linked above, the

entries on the “Publications” tab (including the “Dance(s) collected by Mary Isdale MacNab” pseudo-publication), and/or the RSCDS London Branch resource

mentioned above.



“Missing MacNabberies”

---------------------



On the London Branch site there is also a

<<https://www.rscdslondon.org.uk/wp-content/uploads/2021/05/List-of-The-Missing-MacNaberries-including-previously-unpublished-and-connected-dances-210512.pdf|list of more than 50 dance titles>> purportedly mentioned in correspondence by Mary Isdale MacNab but about which no details or descriptions are known. If more information about any of these dances turns up we''d be happy to

<<mailto:scddb-submissions@strathspey.org|add them>> to the database.





Biography

---------



*The following brief biography was provided by <<ddp:Webb, Stephen#3325>>.*



Mary Isdale (for this was her maiden name) was born in 1889 in Govan, SW Glasgow and was taught highland dancing as a child by E E Henderson. She and her family emigrated to Vancouver, Canada in 1907. In 1920 she married Allan MacNab from Lochgoilhead, their son is called Gordon. Mrs MacNab started teaching highland dancing from 1910, not confining herself to teaching the standard répertoire for highland dancing competitions she also collected, and eventually taught other less common dances.



Her collecting started, when she was encouraged by some elderly highland ladies in Vancouver to learn some of the dances they knew as children. She found that other people were also willing to teach dances to her, and her mother encouraged her to write down what she learned. Most of her collecting was done up to the mid 1940s. She collected step-dances, sword-dances, quadrilles, figure dances both country and highland resulting in a large collection.

Because her collecting simply involved writing down descriptions in note form told to her or from seeing dances danced it was not unusual for Mrs MacNab to have to reconstruct the dances as she believed, using her dance expertise, that would have been, often working on a dance with her dancing class to see it all fitted. In recording the dance description Mrs MacNab would also note down from whom the dance was collected and any associated story attached to it thus, bringing the dance to life and often establishing a provenance.



Mrs MacNab was an extraordinarily unique teacher and dance collector without whose dedication many old and very interesting dances would have been lost. <<ddd:MacDonald of Sleat#4014>>, <<ddd:McKenzie of Seaforth#15781>>, <<ddd:Hebridean Weaving Lilt#2846>>, inter alia come to mind.

Mrs MacNab gained her RSCDS Teaching Certificate when she first visited St Andrew’s Summer School to teach in 1948 the first of her nine sets of dances.

Her forte though, was making dance programmes for festivals and gatherings when she would create a historical and balanced dancing spectacle. One such concert for which she was famous in Vancouver was the annual ‘Gathering of the Clans’. A particular favourite devised dance included was the spectacular, The Brooch of Lorne. Once in 1964 even taking a team to perform at the Royal Edinburgh Military Tattoo. Mary Isdale MacNab died in November 1966; the Scottish dancing world losing one of its greatest advocates, exponents and ambassadors.



The above synopsis is an abbreviated outline of Mrs MacNab’s dancing life, the reader is invited to see the full version in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-033-November-1967.pdf|The Thistle No 33>>. Also, an excellent article on Mrs MacNab by Rosemary Coupe (with some information provided by Mary Murray) can be found in RSCDS Bulletin Issue 82, November 2004.

Another article is in <<https://www.rscdslondon.org.uk/wp-content/uploads/2016/05/16-02-28-Reel-295.pdf#page=8|issue 295>> of The Reel.



A summary of the dances collected and/or arranged and/or choreographed by Mary Isdale MacNab is given on the <<https://www.rscdslondon.org.uk/mary-isdale-macnab-dances/|London Branch website>>.');
INSERT INTO 'person' VALUES (12244, '2022-12-24 11:23:28.794771+00', '2022-12-24 11:23:28.794771+00', 'Carlisle and Border Branch', 'CarlisleBranch', 'Carlisle and Border Branch', '', '', 0, 1, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12260, '2023-01-31 17:29:16.113012+00', '2023-01-31 18:12:09.610751+00', 'Howie, Elizabeth', '', 'Elizabeth Howie', 'North Ayrshire', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (2054, NULL, '2023-02-20 00:56:24.774836+00', 'Hamilton, James Stanley ''Stan''', 'Stan Hamilton', 'James Stanley ''Stan'' Hamilton', '', '', 0, 0, 1, 1, NULL, 1928, 2007, NULL, 'James Stanley ''Stan'' Hamilton was born 1928 in Ayrshire as the son of James Stanley ''Jimmy'' Hamilton and Mary Hamilton of Auchincruive.



Stan Hamilton played Piano and played together with his childhood friend Bobby Frew (Accordion), his father Jimmy Hamilton (Fiddle), John McCroskie (Drums) and others.



In 1957 Stan emigrated to Canada along with his wife Anne and Bobby Frew.



In Canada he played with Bobby Frew and Bobby Brown (also originally from Scotland, joining 1961 to 1974, when left to form his own band). 

Stan formed the band Stan Hamilton & The Clansmen, later named <<http://my.strathspey.org/dd/person/2053/|Stan Hamilton & The Flying Scotsmen>>.



He received the RSCDS Scroll of Honour in 2005.



Stan Hamilton passed away 4 September, 2007.



(Sources: <<https://thesession.org/tunes/12052|The Session>>, <<http://boxandfiddlearchive.weebly.com/stan-hamilton.html|Box and Fiddle archive>>, and obituary in <<http://www.dancescottish.ca/archives-set%26link.html|Toronto Set+Link>> Oct 2007)');
INSERT INTO 'person' VALUES (2053, NULL, '2023-02-20 00:56:24.868132+00', 'Hamilton, Stan and his Flying Scotsmen', 'Stan Hamilton', 'Stan Hamilton and his Flying Scotsmen', '', '', 0, 0, 0, 1, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12261, '2023-02-20 15:24:09.967698+00', '2023-02-20 16:33:40.882096+00', 'Holmes, Marian Jennifer', '', 'Marian Jennifer Holmes', 'Naramata, BC, Canada', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12262, '2023-02-22 00:14:29.472016+00', '2023-02-22 00:14:29.472016+00', 'Gorelova, I and Salmin, E', '', 'I. Gorelova and E. Salmin', 'Cheboksary, Russia', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (12263, '2023-02-27 16:09:28.877588+00', '2023-02-27 16:14:04.175099+00', 'Valvona, Judy', '', 'Judy Valvona', 'Isle of Wight', '', 1, 0, 0, 0, NULL, 0, 0, NULL, '');
INSERT INTO 'person' VALUES (10063, NULL, '2023-02-28 14:41:39.569234+00', 'Muir, Ian', 'Ian Muir', 'Ian Muir', '', '', 0, 0, 1, 0, NULL, 0, 0, NULL, 'The SCD world is lucky to have two musicians called Ian Muir both of whom also compose tunes:  

<<ddp:Muir, Ian R#1590>> (Craigellachie)  

<<ddp:Muir, Ian T#1575>> (Prestwick)  



This entry should ideally not be used for either of them. If database editors come across any tunes with composer only given as "Ian Muir" they should try and find out which one it actually was and only enter it here if they are not able to do so.');


--
INSERT INTO 'personurl' VALUES (1, 'http://rscdsclevelandhts.org/', 10, 10663);
INSERT INTO 'personurl' VALUES (3, 'http://www.thesundayclass.org.uk/', 10, 10648);
INSERT INTO 'personurl' VALUES (4, 'http://www.scotchmist.ca/', 10, 10955);
INSERT INTO 'personurl' VALUES (5, 'http://www.scotchmist.ca/', 10, 10204);
INSERT INTO 'personurl' VALUES (6, 'http://www.iaincathcart.com/', 10, 10982);
INSERT INTO 'personurl' VALUES (7, 'http://en.wikipedia.org/wiki/Sir_Alexander_Boswell,_1st_Baronet', 100, 10985);
INSERT INTO 'personurl' VALUES (8, 'http://www.allmusic.com/artist/arthur-pryor-mn0000932442/biography', 10, 10989);
INSERT INTO 'personurl' VALUES (9, 'http://bridportscottishdancers.org.uk/', 10, 11005);
INSERT INTO 'personurl' VALUES (10, 'http://www.grahamg.com/', 10, 3034);
INSERT INTO 'personurl' VALUES (11, 'http://www.skara-brae.co.uk/index.htm#About', 10, 11022);
INSERT INTO 'personurl' VALUES (13, 'http://www.kafoozalum.co.uk/', 10, 3750);
INSERT INTO 'personurl' VALUES (14, 'http://www.bstk.hu/', 10, 11114);
INSERT INTO 'personurl' VALUES (15, 'http://www.lizcarroll.com/', 10, 11145);
INSERT INTO 'personurl' VALUES (16, 'http://www.moirastacey.com/', 10, 11170);
INSERT INTO 'personurl' VALUES (17, 'http://www.dublin-scd.com/', 10, 11201);
INSERT INTO 'personurl' VALUES (18, 'http://eddywest.nz/', 10, 411);
INSERT INTO 'personurl' VALUES (19, 'http://greengingerband.co.uk/', 10, 2696);
INSERT INTO 'personurl' VALUES (20, 'http://my.strathspey.org/u/murrough/', 10, 11237);
INSERT INTO 'personurl' VALUES (21, 'http://www.sportsground.co.nz/hoonhayscottish/', 10, 11254);
INSERT INTO 'personurl' VALUES (22, 'http://www.rscdssask.org/In_Memoriam/olive_ogilvie.htm', 10, 3642);
INSERT INTO 'personurl' VALUES (23, 'http://www.rscdsorlandobranch.org/', 10, 298);
INSERT INTO 'personurl' VALUES (24, 'http://www.rscdsexeter.org.uk/', 10, 3563);
INSERT INTO 'personurl' VALUES (25, 'http://www.bonnygreen.co.uk/welcome.htm', 10, 11264);
INSERT INTO 'personurl' VALUES (27, 'http://www.viveladanse.nl/', 10, 3645);
INSERT INTO 'personurl' VALUES (28, 'https://dublinscdclub.wordpress.com/dances/', 10, 10795);
INSERT INTO 'personurl' VALUES (29, 'http://www.geocities.ws/highlandbevan/Sdances.html', 10, 11463);
INSERT INTO 'personurl' VALUES (30, 'http://www.rscdscincinnati.org/fg-main/', 10, 3368);
INSERT INTO 'personurl' VALUES (31, 'http://www.songwritershalloffame.org/notable_writers/C5039', 10, 11475);
INSERT INTO 'personurl' VALUES (32, 'https://en.wikipedia.org/wiki/Maurice_Sigler', 10, 11475);
INSERT INTO 'personurl' VALUES (33, 'https://en.wikipedia.org/wiki/Al_Goodhart', 10, 11476);
INSERT INTO 'personurl' VALUES (34, 'http://scots.in.france.pagesperso-orange.fr/', 10, 17);
INSERT INTO 'personurl' VALUES (35, 'http://www.munichscottish.de/', 10, 11069);
INSERT INTO 'personurl' VALUES (36, 'http://www.cheltenhamrscds.btck.co.uk/', 10, 11492);
INSERT INTO 'personurl' VALUES (38, 'http://www.henrymancini.com/', 10, 10223);
INSERT INTO 'personurl' VALUES (39, 'https://en.wikipedia.org/wiki/Henry_Mancini', 20, 10223);
INSERT INTO 'personurl' VALUES (40, 'http://www.glencraigsdb.co.uk/', 10, 10209);
INSERT INTO 'personurl' VALUES (41, 'https://en.wikipedia.org/wiki/Gene_Autry', 10, 11512);
INSERT INTO 'personurl' VALUES (42, 'https://en.wikipedia.org/wiki/Oakley_Haldeman', 10, 11513);
INSERT INTO 'personurl' VALUES (43, 'https://en.wikipedia.org/wiki/Walter_E._Rollins', 10, 11511);
INSERT INTO 'personurl' VALUES (44, 'https://en.wikipedia.org/wiki/Steve_Nelson_(songwriter)', 10, 1691);
INSERT INTO 'personurl' VALUES (45, 'https://en.wikipedia.org/wiki/George_Frideric_Handel', 10, 11156);
INSERT INTO 'personurl' VALUES (47, 'http://www.frostandfireband.com/', 10, 11515);
INSERT INTO 'personurl' VALUES (46, 'http://ottercreeksmallcraft.com/', 10, 3419);
INSERT INTO 'personurl' VALUES (48, 'http://www.invercauldband.com/', 10, 1713);
INSERT INTO 'personurl' VALUES (54, 'http://matthew-maclennan.co.uk/about-matthew/', 10, 11610);
INSERT INTO 'personurl' VALUES (50, 'http://www.invercauldband.com/', 10, 3749);
INSERT INTO 'personurl' VALUES (51, 'http://www.collins.co.uk/', 10, 11535);
INSERT INTO 'personurl' VALUES (52, 'http://www.thistleclub.nl/', 10, 3198);
INSERT INTO 'personurl' VALUES (53, 'http://www.scd-heidelberg.de/', 10, 11593);
INSERT INTO 'personurl' VALUES (55, 'http://www.sehscottishdance.org/', 10, 11633);
INSERT INTO 'personurl' VALUES (56, 'https://docs.google.com/document/d/1C-ZM2mVJ1SmswTfxgpaO65tuekOIQqiRO_bPF5MjM4M/edit', 10, 17);
INSERT INTO 'personurl' VALUES (57, 'http://colinrobertson.net/', 10, 1231);
INSERT INTO 'personurl' VALUES (12, 'http://www.rscds-stirling.org/', 10, 375);
INSERT INTO 'personurl' VALUES (58, 'http://hms.scot/fiddle/author/12/', 10, 1486);
INSERT INTO 'personurl' VALUES (59, 'http://homepages.ecs.vuw.ac.nz/~downey/dances.html', 10, 2682);
INSERT INTO 'personurl' VALUES (26, 'https://harwellscdc.mno.org.uk/', 10, 11269);
INSERT INTO 'personurl' VALUES (60, 'http://my.strathspey.org/u/keithrose/', 10, 10951);
INSERT INTO 'personurl' VALUES (61, 'https://www.genevascdc.com/EN/index.shtml', 10, 11261);
INSERT INTO 'personurl' VALUES (62, 'http://www.emmanixon.com.au/blackbearduo/', 10, 11791);
INSERT INTO 'personurl' VALUES (63, 'http://www.tac-rscds.org/', 10, 380);
INSERT INTO 'personurl' VALUES (64, 'https://www.matsmelin.com/scottish-social-dances-devised-by-mats-melin/', 10, 264);
INSERT INTO 'personurl' VALUES (65, 'https://ousds.web.ox.ac.uk/', 10, 11891);
INSERT INTO 'personurl' VALUES (66, 'http://halshawmusic.co.uk/', 10, 3159);
INSERT INTO 'personurl' VALUES (67, 'https://ruhrball.wordpress.com/about/', 10, 11906);
INSERT INTO 'personurl' VALUES (68, 'https://rscds-sf.org/', 10, 338);
INSERT INTO 'personurl' VALUES (69, 'http://www.paddledoo.com/', 10, 2061);
INSERT INTO 'personurl' VALUES (70, 'https://edpearlman.net/bostonhospitality.html', 10, 2733);
INSERT INTO 'personurl' VALUES (71, 'http://www.scottishdance.ru/', 10, 11919);
INSERT INTO 'personurl' VALUES (2, 'https://www.thistleradio.com/', 10, 10716);
INSERT INTO 'personurl' VALUES (72, 'https://my.strathspey.org/profile/Roland/', 10, 11181);
INSERT INTO 'personurl' VALUES (73, 'http://www.timdoodle.com/scd/', 10, 2924);
INSERT INTO 'personurl' VALUES (74, 'http://www.scd.za.net/', 10, 2813);
INSERT INTO 'personurl' VALUES (75, 'http://web.archive.org/web/20010826010906/http://www.geocities.com/dancingduff/index.html', 10, 2811);
INSERT INTO 'personurl' VALUES (76, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-302-Electronic.pdf#page=13', 10, 635);
INSERT INTO 'personurl' VALUES (84, 'https://www.rscdslondon.org.uk/wp-content/uploads/2016/09/2016-05-09-Reel-296.pdf#page=9', 10, 3086);
INSERT INTO 'personurl' VALUES (77, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/05/Reel-303-electronic.pdf#page=13', 10, 11182);
INSERT INTO 'personurl' VALUES (78, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/08/Reel-304-electronic.pdf#page=11', 10, 812);
INSERT INTO 'personurl' VALUES (79, 'https://www.rscdslondon.org.uk/wp-content/uploads/2018/11/Reel-305-electronic.pdf#page=11', 10, 15);
INSERT INTO 'personurl' VALUES (80, 'https://www.rscdslondon.org.uk/wp-content/uploads/2019/05/Reel-307-electronic.pdf#page=13', 10, 2856);
INSERT INTO 'personurl' VALUES (81, 'https://www.rscdslondon.org.uk/wp-content/uploads/2020/02/Reel-310-electronic.pdf#page=7', 10, 10658);
INSERT INTO 'personurl' VALUES (82, 'https://www.rscdslondon.org.uk/wp-content/uploads/2020/10/Reel-313-Electronic.pdf#page=8', 10, 11013);
INSERT INTO 'personurl' VALUES (83, 'https://www.rscdslondon.org.uk/wp-content/uploads/2020/10/Reel-313-Electronic.pdf#page=17', 10, 11009);
INSERT INTO 'personurl' VALUES (85, 'https://www.rscdslondon.org.uk/wp-content/uploads/2013/09/120821Reel281.pdf#page=6', 10, 1556);
INSERT INTO 'personurl' VALUES (86, 'https://www.rscdslondon.org.uk/wp-content/uploads/2014/09/140908-Reel-289.pdf#page=12', 10, 108);
INSERT INTO 'personurl' VALUES (87, 'https://www.rscdslondon.org.uk/wp-content/uploads/2016/12/Reel-297.pdf#page=8', 10, 127);
INSERT INTO 'personurl' VALUES (89, 'https://www.rscds-ib.org/index.php?page=6', 10, 589);
INSERT INTO 'personurl' VALUES (90, 'https://www.rscdslondon.org.uk/wp-content/uploads/2013/09/120821Reel281.pdf#page=6', 10, 589);
INSERT INTO 'personurl' VALUES (91, 'https://scdkaleidoscope1.strathspey.org/', 10, 589);
INSERT INTO 'personurl' VALUES (93, 'https://sites.google.com/site/thefollyofrogues/home', 10, 11496);
INSERT INTO 'personurl' VALUES (94, 'https://sites.google.com/site/dancesforthebrave/home', 10, 10640);
INSERT INTO 'personurl' VALUES (96, 'https://rscds-delft.nl/anne-miek.html', 10, 1049);
INSERT INTO 'personurl' VALUES (97, 'https://rscds-delft.nl/aad.html', 10, 1500);
INSERT INTO 'personurl' VALUES (92, 'https://suepetyt.e-cribs.org/', 10, 308);
INSERT INTO 'personurl' VALUES (98, 'https://rscds-delft.nl/francien.html', 10, 2917);
INSERT INTO 'personurl' VALUES (100, 'https://rscds-delft.nl/lily.html', 10, 3200);
INSERT INTO 'personurl' VALUES (101, 'https://rscds-delft.nl/mary-jane.html', 10, 2118);
INSERT INTO 'personurl' VALUES (102, 'https://rscds-delft.nl/petra.html', 10, 2918);
INSERT INTO 'personurl' VALUES (95, 'https://rscds-delft.nl/', 10, 2916);
INSERT INTO 'personurl' VALUES (103, 'https://rscdssask.org/', 10, 2930);
INSERT INTO 'personurl' VALUES (104, 'https://www.eecis.udel.edu/~harvey/scottish.html', 10, 2975);
INSERT INTO 'personurl' VALUES (105, 'http://www.patshaw.info/dances/', 10, 2487);
INSERT INTO 'personurl' VALUES (106, 'http://www.rscdsleeds.org.uk/', 10, 223);
INSERT INTO 'personurl' VALUES (107, 'http://www.rscdsvienna.org/', 10, 10285);
INSERT INTO 'personurl' VALUES (108, 'https://www.aberdeenrscds.co.uk/', 10, 2850);
INSERT INTO 'personurl' VALUES (109, 'https://www.rscdsadelaide.org.au/', 10, 4);
INSERT INTO 'personurl' VALUES (110, 'https://rscds-atlanta.org/', 10, 12);
INSERT INTO 'personurl' VALUES (111, 'https://www.ayr-rscds.com/', 10, 16);
INSERT INTO 'personurl' VALUES (112, 'https://www.rscdsbanffshire.co.uk/', 10, 3648);
INSERT INTO 'personurl' VALUES (113, 'http://www.rscdsbath.co.uk/', 10, 25);
INSERT INTO 'personurl' VALUES (114, 'http://www.rscdsbelfast.org/', 10, 569);
INSERT INTO 'personurl' VALUES (115, 'http://www.rscds-bhs.org.uk/', 10, 30);
INSERT INTO 'personurl' VALUES (116, 'http://www.birmingham-rscds.org.uk/', 10, 32);
INSERT INTO 'personurl' VALUES (117, 'http://www.rscdsboston.org/', 10, 37);
INSERT INTO 'personurl' VALUES (118, 'http://www.wessex-scd.org.uk/bournemouth-rscds/', 10, 40);
INSERT INTO 'personurl' VALUES (119, 'http://www.rscdsbristol.info/', 10, 3164);
INSERT INTO 'personurl' VALUES (120, 'https://www.rscds.org/branches-and-groups/guildford-scottish-country-dance-club', 10, 12154);
INSERT INTO 'personurl' VALUES (121, 'https://sites.google.com/site/laidlaw/', 10, 725);
INSERT INTO 'personurl' VALUES (122, 'https://suedan.com/dances/index.php', 10, 2766);
INSERT INTO 'personurl' VALUES (123, 'https://www.reeltimedancing.com/home', 10, 725);
INSERT INTO 'personurl' VALUES (124, 'http://keith-wood.name/mydances.html', 10, 12254);


--
INSERT INTO 'phrasing' VALUES (1, 'AABB');
INSERT INTO 'phrasing' VALUES (3, 'AABA');
INSERT INTO 'phrasing' VALUES (4, 'ABABAB');
INSERT INTO 'phrasing' VALUES (5, 'ABAB');
INSERT INTO 'phrasing' VALUES (6, 'ABABB');
INSERT INTO 'phrasing' VALUES (7, 'A16A16');
INSERT INTO 'phrasing' VALUES (8, 'ABCD');
INSERT INTO 'phrasing' VALUES (9, 'AABAB');
INSERT INTO 'phrasing' VALUES (10, 'A16B16');
INSERT INTO 'phrasing' VALUES (11, 'AABBAB');
INSERT INTO 'phrasing' VALUES (12, 'AABC');
INSERT INTO 'phrasing' VALUES (13, 'ABBABB');
INSERT INTO 'phrasing' VALUES (14, 'AABBB');
INSERT INTO 'phrasing' VALUES (15, 'AABBA');
INSERT INTO 'phrasing' VALUES (16, 'ABA');
INSERT INTO 'phrasing' VALUES (17, 'AABAA');
INSERT INTO 'phrasing' VALUES (18, 'ABB');
INSERT INTO 'phrasing' VALUES (19, 'ABC');
INSERT INTO 'phrasing' VALUES (20, 'ABCABC');
INSERT INTO 'phrasing' VALUES (21, 'AAB');
INSERT INTO 'phrasing' VALUES (22, 'ABAABA');
INSERT INTO 'phrasing' VALUES (23, 'AB');
INSERT INTO 'phrasing' VALUES (25, 'AABBBB');
INSERT INTO 'phrasing' VALUES (26, 'AABBAABB');
INSERT INTO 'phrasing' VALUES (27, 'ABABA');
INSERT INTO 'phrasing' VALUES (28, 'ABBBB');
INSERT INTO 'phrasing' VALUES (29, 'AABBAA');
INSERT INTO 'phrasing' VALUES (30, 'AABBCC');
INSERT INTO 'phrasing' VALUES (31, 'ABBCC');
INSERT INTO 'phrasing' VALUES (32, 'ABAAB');
INSERT INTO 'phrasing' VALUES (33, 'AA');
INSERT INTO 'phrasing' VALUES (34, 'ABCC');
INSERT INTO 'phrasing' VALUES (35, 'AABBCB');
INSERT INTO 'phrasing' VALUES (36, 'AAB12');
INSERT INTO 'phrasing' VALUES (37, 'A16BB');
INSERT INTO 'phrasing' VALUES (38, 'ABCBB');
INSERT INTO 'phrasing' VALUES (39, 'AABBC');
INSERT INTO 'phrasing' VALUES (40, 'AABCB');
INSERT INTO 'phrasing' VALUES (41, 'AABABA');
INSERT INTO 'phrasing' VALUES (42, 'A16');
INSERT INTO 'phrasing' VALUES (43, 'ABABC');
INSERT INTO 'phrasing' VALUES (44, 'ABCBC');
INSERT INTO 'phrasing' VALUES (45, 'AAB16');


--
INSERT INTO 'progression' VALUES (1, '2341');
INSERT INTO 'progression' VALUES (2, '2413');
INSERT INTO 'progression' VALUES (3, 'OnceOnly');
INSERT INTO 'progression' VALUES (4, 'ChangePtnr');
INSERT INTO 'progression' VALUES (5, '3421');
INSERT INTO 'progression' VALUES (6, '53412');
INSERT INTO 'progression' VALUES (7, '24153');
INSERT INTO 'progression' VALUES (9, '234561');
INSERT INTO 'progression' VALUES (10, '31524');
INSERT INTO 'progression' VALUES (11, '3142');
INSERT INTO 'progression' VALUES (12, '236145');
INSERT INTO 'progression' VALUES (13, '4123');
INSERT INTO 'progression' VALUES (14, '3412');
INSERT INTO 'progression' VALUES (15, '4312');
INSERT INTO 'progression' VALUES (16, '23451');
INSERT INTO 'progression' VALUES (17, '231');
INSERT INTO 'progression' VALUES (18, '312');
INSERT INTO 'progression' VALUES (19, '43521');
INSERT INTO 'progression' VALUES (20, '24531');
INSERT INTO 'progression' VALUES (21, '25413');
INSERT INTO 'progression' VALUES (8, 'Canon');
INSERT INTO 'progression' VALUES (49, '546132');
INSERT INTO 'progression' VALUES (51, '615324');
INSERT INTO 'progression' VALUES (52, '2134');
INSERT INTO 'progression' VALUES (53, 'Becket');
INSERT INTO 'progression' VALUES (22, '2143');
INSERT INTO 'progression' VALUES (82, '3x,4x,2x,1x');
INSERT INTO 'progression' VALUES (25, '231645');
INSERT INTO 'progression' VALUES (26, '25134');
INSERT INTO 'progression' VALUES (83, '345612');
INSERT INTO 'progression' VALUES (28, '4321');
INSERT INTO 'progression' VALUES (31, '34251');
INSERT INTO 'progression' VALUES (32, '531642');
INSERT INTO 'progression' VALUES (33, '45123');
INSERT INTO 'progression' VALUES (34, '465213');
INSERT INTO 'progression' VALUES (35, '51234');
INSERT INTO 'progression' VALUES (36, '2416375');
INSERT INTO 'progression' VALUES (37, '54132');
INSERT INTO 'progression' VALUES (38, '45231');
INSERT INTO 'progression' VALUES (39, '254163');
INSERT INTO 'progression' VALUES (40, '53124');
INSERT INTO 'progression' VALUES (41, '23514');
INSERT INTO 'progression' VALUES (42, '213');
INSERT INTO 'progression' VALUES (44, '31452');
INSERT INTO 'progression' VALUES (84, '1x,4x,3x,2x');
INSERT INTO 'progression' VALUES (46, 'Top Moves');
INSERT INTO 'progression' VALUES (47, '362514');
INSERT INTO 'progression' VALUES (48, '43152');
INSERT INTO 'progression' VALUES (55, '41253');
INSERT INTO 'progression' VALUES (56, '3756214');
INSERT INTO 'progression' VALUES (57, '41532');
INSERT INTO 'progression' VALUES (58, '34512');
INSERT INTO 'progression' VALUES (59, '35214');
INSERT INTO 'progression' VALUES (60, '264513');
INSERT INTO 'progression' VALUES (85, '2713456');
INSERT INTO 'progression' VALUES (62, '541632');
INSERT INTO 'progression' VALUES (86, '561234');
INSERT INTO 'progression' VALUES (87, '2351674');
INSERT INTO 'progression' VALUES (66, '7563412');
INSERT INTO 'progression' VALUES (67, '645312');
INSERT INTO 'progression' VALUES (88, '235164');
INSERT INTO 'progression' VALUES (69, '365214');
INSERT INTO 'progression' VALUES (89, '312564');
INSERT INTO 'progression' VALUES (72, '456789123');
INSERT INTO 'progression' VALUES (30, 'Other');
INSERT INTO 'progression' VALUES (73, '654132');
INSERT INTO 'progression' VALUES (74, '456312');
INSERT INTO 'progression' VALUES (90, '241635');
INSERT INTO 'progression' VALUES (76, '21');
INSERT INTO 'progression' VALUES (91, '412563');
INSERT INTO 'progression' VALUES (92, '35421');
INSERT INTO 'progression' VALUES (79, '536124');
INSERT INTO 'progression' VALUES (80, '2x,3x,4x,1x');
INSERT INTO 'progression' VALUES (81, '3x,2x,1x,4x');
INSERT INTO 'progression' VALUES (93, '54213');
INSERT INTO 'progression' VALUES (94, '2,3,1x');
INSERT INTO 'progression' VALUES (54, 'Nonprogressive');
INSERT INTO 'progression' VALUES (95, '53412');
INSERT INTO 'progression' VALUES (97, '2x,3,4x,1');
INSERT INTO 'progression' VALUES (98, '452613');
INSERT INTO 'progression' VALUES (99, '2x,4x,1,3');
INSERT INTO 'progression' VALUES (100, '3x,1x,2x');
INSERT INTO 'progression' VALUES (101, '2,1x,3');
INSERT INTO 'progression' VALUES (102, '3,1,4x,2x');
INSERT INTO 'progression' VALUES (103, '2,4,1x,3x');
INSERT INTO 'progression' VALUES (104, '612345');
INSERT INTO 'progression' VALUES (106, '456231');


--
INSERT INTO 'publication' VALUES (15, '2002-12-31 23:00:00+00', '2018-03-21 23:24:16.869735+00', 'Book 15', 'RSCDS XV', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1949);
INSERT INTO 'publication' VALUES (48, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.144654+00', 'Unicef Circle, The', 'Unicef C.', 146, 1, 1, 0, 1, 104, '2009-03-15 10:41:39+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (49, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.153058+00', 'Dance(s) Collected by Miss Milligan', 'Miss Milligan', 269, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (57, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.208188+00', 'Four Scottish Country Dances', 'Priddey: 4 SCD', 313, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1, '2002-12-31 23:00:00+00', '2018-03-21 23:24:42.407253+00', 'Book 1', 'RSCDS I', 319, 1, 1, 0, 1, 103, '2009-03-13 14:24:23+00', 0, '', 1, 1924);
INSERT INTO 'publication' VALUES (43, '2002-12-31 23:00:00+00', '2012-01-20 13:06:34.19711+00', 'Four Step Dances', 'RSCDS 4 step', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 0000);
INSERT INTO 'publication' VALUES (2, '2002-12-31 23:00:00+00', '2018-03-21 23:25:21.129167+00', 'Book 2', 'RSCDS II', 319, 1, 1, 0, 1, 103, '2009-03-13 14:24:33+00', 0, '', 1, 1926);
INSERT INTO 'publication' VALUES (42, '2002-12-31 23:00:00+00', '2012-01-20 13:06:35.856035+00', 'Two Traditional Solos', 'RSCDS 2 trad solos', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 0000);
INSERT INTO 'publication' VALUES (4, '2002-12-31 23:00:00+00', '2018-03-21 23:25:47.115049+00', 'Book 4', 'RSCDS IV', 319, 1, 1, 0, 1, 103, '2009-03-13 14:24:50+00', 0, '', 1, 1927);
INSERT INTO 'publication' VALUES (8, '2002-12-31 23:00:00+00', '2013-04-24 01:29:01.725246+00', 'Book 8', 'RSCDS VIII', 319, 1, 1, 0, 1, 103, '2009-03-13 14:25:18+00', 0, '', 1, 1932);
INSERT INTO 'publication' VALUES (9, '2002-12-31 23:00:00+00', '2013-04-24 01:29:21.902729+00', 'Book 9', 'RSCDS IX', 319, 1, 1, 0, 1, 103, '2009-03-13 14:25:26+00', 0, '', 1, 1934);
INSERT INTO 'publication' VALUES (64, '2002-12-31 23:00:00+00', '2013-04-10 08:11:16.267612+00', 'Alexander Dances Book 2', 'Alexander 2', 13, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (71, '2002-12-31 23:00:00+00', '2014-04-08 10:45:25.651755+00', 'Alexander Dances Book 9', 'Alexander 9', 13, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (67, '2002-12-31 23:00:00+00', '2013-04-10 08:13:02.43947+00', 'Alexander Dances Book 5', 'Alexander 5', 13, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (68, '2002-12-31 23:00:00+00', '2013-04-10 08:13:35.926441+00', 'Alexander Dances Book 6', 'Alexander 6', 13, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (69, '2002-12-31 23:00:00+00', '2013-04-10 08:13:51.491026+00', 'Alexander Dances Book 7', 'Alexander 7', 13, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (70, '2002-12-31 23:00:00+00', '2013-04-10 08:14:02.950319+00', 'Alexander Dances Book 8', 'Alexander 8', 13, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (10, '2002-12-31 23:00:00+00', '2013-04-24 01:25:48.130488+00', 'Book 10', 'RSCDS X', 319, 1, 1, 0, 1, 103, '2009-03-13 14:25:35+00', 0, '', 1, 1935);
INSERT INTO 'publication' VALUES (11, '2002-12-31 23:00:00+00', '2013-04-24 01:27:38.266771+00', 'Book 11', 'RSCDS XI', 319, 1, 1, 0, 1, 103, '2009-03-13 14:25:44+00', 0, '', 1, 1936);
INSERT INTO 'publication' VALUES (6, '2002-12-31 23:00:00+00', '2018-03-21 23:25:59.491297+00', 'Book 6', 'RSCDS VI', 319, 1, 1, 0, 1, 103, '2009-03-13 14:25:00+00', 0, '', 1, 1930);
INSERT INTO 'publication' VALUES (7, '2002-12-31 23:00:00+00', '2013-04-24 01:28:43.843941+00', 'Book 7', 'RSCDS VII', 319, 1, 1, 0, 1, 103, '2009-03-13 14:25:12+00', 0, '', 1, 1931);
INSERT INTO 'publication' VALUES (75, '2002-12-31 23:00:00+00', '2013-07-23 18:04:45.796251+00', 'Dunedin Dances Book 1', 'Dunedin 1', 113, 1, 1, 0, 1, 146, '2009-06-06 19:19:30+00', 0, '', 0, 1986);
INSERT INTO 'publication' VALUES (65, '2002-12-31 23:00:00+00', '2014-04-07 14:15:58.152575+00', 'Alexander Dances Book 3', 'Alexander 3', 13, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (66, '2002-12-31 23:00:00+00', '2014-05-05 22:22:19.001154+00', 'Alexander Dances Book 4', 'Alexander 4', 13, 1, 0, 1, 1, 160, '2014-05-05 22:18:51+00', 1, '', 0, 0000);
INSERT INTO 'publication' VALUES (5, '2002-12-31 23:00:00+00', '2018-03-21 23:26:12.809728+00', 'Book 5', 'RSCDS V', 319, 1, 1, 0, 1, 103, '2009-03-13 14:24:55+00', 0, '', 1, 1929);
INSERT INTO 'publication' VALUES (1106, '2012-05-09 14:11:56.890135+00', '2015-02-17 21:44:41.356313+00', 'Dancing on Air', 'Dancing on Air', 340, 1, 1, 1, 1, NULL, NULL, 0, 'WARNING:  A new version has been published; at least the dance "Mrs.Jappy''s Measure" has been changed.  ', 0, 2011);
INSERT INTO 'publication' VALUES (32, '2002-12-31 23:00:00+00', '2018-03-21 23:32:49.915796+00', 'Book 32', 'RSCDS XXXII', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1984);
INSERT INTO 'publication' VALUES (76, '2002-12-31 23:00:00+00', '2019-08-28 10:48:43.557133+00', 'Dunedin Dances Book 2', 'Dunedin 2', 113, 1, 1, 0, 1, 146, '2009-06-06 19:19:41+00', 0, '', 0, 1989);
INSERT INTO 'publication' VALUES (30, '2002-12-31 23:00:00+00', '2018-03-21 23:32:17.132744+00', 'Book 30', 'RSCDS XXX', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1981);
INSERT INTO 'publication' VALUES (29, '2002-12-31 23:00:00+00', '2018-03-21 23:32:03.251879+00', 'Book 29', 'RSCDS XXIX', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1979);
INSERT INTO 'publication' VALUES (28, '2002-12-31 23:00:00+00', '2018-03-21 23:31:54.489882+00', 'Book 28', 'RSCDS XXVIII', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1977);
INSERT INTO 'publication' VALUES (27, '2002-12-31 23:00:00+00', '2018-03-21 23:31:43.587777+00', 'Book 27', 'RSCDS XXVII', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1975);
INSERT INTO 'publication' VALUES (26, '2002-12-31 23:00:00+00', '2018-03-21 23:31:32.027409+00', 'Book 26', 'RSCDS XXVI', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1972);
INSERT INTO 'publication' VALUES (53, '2002-12-31 23:00:00+00', '2016-02-26 22:11:16.53501+00', 'Scottish Country Dance Leaflets', 'RSCDS Lflts', 319, 1, 0, 0, 1, NULL, '2016-02-26 22:11:16.534219+00', 0, '', 1, 0000);
INSERT INTO 'publication' VALUES (62, '2002-12-31 23:00:00+00', '2016-06-20 22:36:16.709648+00', 'Complete Andrew Rankine Collection, The', 'Complete Rankine', 289, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1279, '2015-08-29 16:03:28.705519+00', '2018-04-29 04:17:56.4817+00', 'Happy Tartan', '', 11187, 1, 1, 0, 1, 202, '2018-04-29 04:17:56.477773+00', 0, '', 0, 2014);
INSERT INTO 'publication' VALUES (14, '2002-12-31 23:00:00+00', '2018-03-21 23:27:51.156571+00', 'Book 14', 'RSCDS XIV', 319, 1, 1, 0, 1, 2310, '2015-06-19 20:34:51+00', 0, '', 1, 1947);
INSERT INTO 'publication' VALUES (17, '2002-12-31 23:00:00+00', '2018-03-21 23:28:29.112421+00', 'Book 17 - Coronation Book', 'RSCDS XVII', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1953);
INSERT INTO 'publication' VALUES (18, '2002-12-31 23:00:00+00', '2018-03-21 23:29:37.730732+00', 'Book 18', 'RSCDS XVIII', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1955);
INSERT INTO 'publication' VALUES (19, '2002-12-31 23:00:00+00', '2018-03-21 23:29:55.96969+00', 'Book 19', 'RSCDS XIX', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1957);
INSERT INTO 'publication' VALUES (20, '2002-12-31 23:00:00+00', '2018-03-21 23:30:10.946534+00', 'Book 20', 'RSCDS XX', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1959);
INSERT INTO 'publication' VALUES (21, '2002-12-31 23:00:00+00', '2018-03-21 23:30:32.667042+00', 'Book 21', 'RSCDS XXI', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1961);
INSERT INTO 'publication' VALUES (22, '2002-12-31 23:00:00+00', '2018-03-21 23:30:46.315022+00', 'Book 22', 'RSCDS XXII', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1963);
INSERT INTO 'publication' VALUES (23, '2002-12-31 23:00:00+00', '2018-03-21 23:30:57.347261+00', 'Book 23', 'RSCDS XXIII', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1967);
INSERT INTO 'publication' VALUES (24, '2002-12-31 23:00:00+00', '2018-03-21 23:31:07.938643+00', 'Book 24', 'RSCDS XXIV', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1968);
INSERT INTO 'publication' VALUES (25, '2002-12-31 23:00:00+00', '2018-03-21 23:31:22.291327+00', 'Book 25', 'RSCDS XXV', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1970);
INSERT INTO 'publication' VALUES (34, '2002-12-31 23:00:00+00', '2018-03-21 23:33:27.180286+00', 'Book 34 Scottish Country Dances', 'RSCDS XXXIV', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1986);
INSERT INTO 'publication' VALUES (35, '2002-12-31 23:00:00+00', '2018-03-21 23:33:37.956646+00', 'Book 35 Scottish Country Dances', 'RSCDS XXXV', 319, 1, 1, 0, 1, 72, '2009-03-14 14:22:33+00', 0, '', 1, 1988);
INSERT INTO 'publication' VALUES (36, '2002-12-31 23:00:00+00', '2018-03-21 23:33:56.148807+00', 'Book 36 (Frae A'' The Airts, Vol 1)', 'RSCDS XXXVI', 319, 1, 1, 0, 1, 72, '2009-03-14 14:23:05+00', 0, '', 1, 1990);
INSERT INTO 'publication' VALUES (37, '2002-12-31 23:00:00+00', '2018-03-21 23:34:06.43677+00', 'Book 37 (Frae A'' The Airts, Vol 2)', 'RSCDS XXXVII', 319, 1, 1, 0, 1, 72, '2009-03-14 14:23:21+00', 0, '', 1, 1992);
INSERT INTO 'publication' VALUES (38, '2002-12-31 23:00:00+00', '2018-03-21 23:34:21.995822+00', 'Book 38 Eight Modern Scottish Country Dances', 'RSCDS XXXVIII', 319, 1, 1, 0, 1, 85, '2009-03-24 11:42:04+00', 0, '', 1, 1994);
INSERT INTO 'publication' VALUES (1100, '2012-02-07 10:19:38.532221+00', '2019-09-30 23:14:31.565687+00', 'Colin Dewar Collection, The', 'Dewar Coll.', 10603, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 2001);
INSERT INTO 'publication' VALUES (16, '2002-12-31 23:00:00+00', '2020-06-03 07:46:48.307261+00', 'Book 16', 'RSCDS XVI', 319, 1, 1, 0, 1, 1893, '2020-05-27 02:38:30+00', 0, '', 1, 1951);
INSERT INTO 'publication' VALUES (61, '2002-12-31 23:00:00+00', '2021-03-16 21:16:28.07001+00', 'MacNab Dances Vol 2', 'MacNab 2', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1987);
INSERT INTO 'publication' VALUES (39, '2002-12-31 23:00:00+00', '2021-06-06 20:50:52.740661+00', '99 More Scottish Country Dances', 'RSCDS 99', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 1963);
INSERT INTO 'publication' VALUES (72, '2002-12-31 23:00:00+00', '2021-06-23 03:59:32.623643+00', 'London Jubilee Book (1979), The', 'London Jub. 79', 235, 1, 0, 0, 1, 117, '2010-02-06 16:49:50+00', 0, '', 0, 1979);
INSERT INTO 'publication' VALUES (85, '2002-12-31 23:00:00+00', '2021-06-23 04:00:17.571352+00', 'London Jubilee Book (1989), The', 'London Jub. 89', 235, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1989);
INSERT INTO 'publication' VALUES (50, '2002-12-31 23:00:00+00', '2021-07-03 21:15:25.082112+00', 'Miss Milligan''s Miscellany Volume I', 'MMM I', 319, 1, 0, 0, 1, 103, '2009-03-13 14:26:13+00', 0, 'According to <<https://my.strathspey.org/dd/issue/2500/|issue 2500>> the second edition dates from December 1995 and was revised in 1996. There is no date on the first edition. Though volume II was published in 1977.', 1, 0000);
INSERT INTO 'publication' VALUES (52, '2002-12-31 23:00:00+00', '2018-04-14 16:32:26.053874+00', 'Five Scottish Country Dances 1982', 'RSCDS 5/1982', 319, 1, 1, 0, 1, NULL, '2016-02-26 22:08:20+00', 0, '', 1, 1982);
INSERT INTO 'publication' VALUES (92, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.505695+00', 'Craigievar Book of Scottish Dances', 'Craigievar 1', 127, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (82, '2002-12-31 23:00:00+00', '2022-12-18 17:55:05.622014+00', 'Golden Jubilee 1937-1987', 'St A: Golden Jubilee', 367, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1987);
INSERT INTO 'publication' VALUES (46, '2002-12-31 23:00:00+00', '2022-12-08 16:56:27.669192+00', 'Three Recently Devised Dances', 'RSCDS 3 recent', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 1976);
INSERT INTO 'publication' VALUES (93, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.515223+00', 'Ayr Branch Dances', 'Ayr Branch', 16, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (94, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.523671+00', 'Clans Book', 'Swirles: Clans', 377, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (96, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.540696+00', 'To Celebrate 21 Years', 'Argyll: celebrate 21', 8, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (97, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.54911+00', 'Ashbourne Collection', 'Ashbourne', 11, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (98, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.557567+00', 'Silver Jubilee Miscellany', 'Leam. Spa Silver', 221, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (99, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.566201+00', 'Halsway Manor', 'Halsway Manor', 333, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1460, '2018-07-17 16:07:20.818684+00', '2018-07-19 10:16:40.668931+00', 'New Scotland 70th Anniversary Dance Book (1947-2017)', 'New Scotland 70th', 1751, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (81, '2002-12-31 23:00:00+00', '2018-09-16 10:30:21.00979+00', 'Silver Jubilee 25 - Leeds Branch', '', 223, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1987);
INSERT INTO 'publication' VALUES (101, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.583284+00', 'Peterhead Quatercentenary Collection', 'Peterhead 400', 601, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (108, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.645906+00', '10 Social Dances', 'Goldring 10 soc.', 146, 1, 1, 0, 1, 104, '2009-03-15 10:37:14+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (109, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.654203+00', 'Saint Dunstan''s Revised Book', 'St Dunstan''s', 377, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (116, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.71566+00', 'Craigievar Book 2', 'Craigievar 2', 127, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (117, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.724002+00', 'Green Lady Book, The', 'Green Lady', 313, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (119, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.741752+00', 'Banchory Book of SCDs', 'Banchory', 165, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (131, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.845356+00', 'Dance(s) from SNDC', 'SNDC', 344, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (135, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.881064+00', 'Merrylea Collection', 'Merrylea', 247, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (123, '2002-12-31 23:00:00+00', '2014-06-03 18:44:24.430185+00', 'Anniversary Tensome', 'Anniversary 10sm', 313, 1, 0, 1, 1, 160, '2014-06-03 18:44:24.427965+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (105, '2002-12-31 23:00:00+00', '2014-05-30 15:51:06.011737+00', 'Golden Oriole Book of Scottish Country Dances, The', 'Golden Oriole', 313, 1, 0, 1, 1, 160, '2009-07-15 05:01:35+00', 3, '', 0, 0000);
INSERT INTO 'publication' VALUES (107, '2002-12-31 23:00:00+00', '2014-06-03 18:44:34.047448+00', 'Capercaillie Book', 'Capercaillie', 313, 1, 0, 0, 1, 160, '2014-06-03 18:44:34.045233+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (100, '2002-12-31 23:00:00+00', '2014-06-03 18:44:42.901262+00', 'Fairy Bridge Book', 'Fairy Bridge', 313, 1, 0, 0, 1, 160, '2014-06-03 18:44:42.899042+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (139, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.914877+00', 'Greenwood Collection', 'Greenwood', 199, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (133, '2002-12-31 23:00:00+00', '2017-01-20 05:07:02.693249+00', 'Twelve More Social Dances', 'Goldring 12more', 146, 1, 1, 1, 1, 104, '2009-03-15 10:40:46+00', 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (58, '2002-12-31 23:00:00+00', '2015-03-27 16:39:04.739829+00', 'Birmingham Book 1986 - Eight Scottish Country Dances', 'Birmingham 8 SCD 1986', 32, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1986);
INSERT INTO 'publication' VALUES (79, '2002-12-31 23:00:00+00', '2015-03-27 23:59:48.089805+00', 'Diamond Jubilee 1925-1985', 'Dundee Diamond 1985', 112, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (132, '2002-12-31 23:00:00+00', '2016-02-27 00:24:14.678034+00', 'Imperial Book of Scottish Country Dances Vol V', 'Imperial V', 192, 1, 0, 0, 1, NULL, NULL, 0, 'An original copy, published in 1993, is inscribed that it contains the winning dances from the annual competition for the Jace McConachie Memorial Sword from 1984 - 1993. ', 0, 1993);
INSERT INTO 'publication' VALUES (136, '2002-12-31 23:00:00+00', '2018-01-19 10:36:42.852793+00', 'Whiteadder Collection', 'Whiteadder', 340, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1993);
INSERT INTO 'publication' VALUES (126, '2002-12-31 23:00:00+00', '2016-02-26 13:56:02.588949+00', 'Grampian Collection of Scottish Country Dances', 'Grampian', 251, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1963);
INSERT INTO 'publication' VALUES (54, '2002-12-31 23:00:00+00', '2016-02-26 22:07:54.453795+00', 'Book of Graded Scottish Country Dances', 'RSCDS Graded', 319, 1, 1, 0, 1, NULL, '2016-02-26 22:07:54.452998+00', 0, '', 1, 1960);
INSERT INTO 'publication' VALUES (45, '2002-12-31 23:00:00+00', '2016-02-26 22:09:46.306318+00', 'Golden Jubilee Dances', 'RSCDS GJ', 319, 1, 1, 0, 1, NULL, '2016-02-26 22:09:46.305536+00', 0, '', 1, 1973);
INSERT INTO 'publication' VALUES (55, '2002-12-31 23:00:00+00', '2016-02-26 22:11:29.685614+00', 'Scottish Country Dances for Children', 'RSCDS Children', 319, 1, 0, 0, 1, NULL, '2016-02-26 22:11:29.684837+00', 0, '', 1, 1981);
INSERT INTO 'publication' VALUES (134, '2002-12-31 23:00:00+00', '2017-01-20 04:39:38.103771+00', '3 Anniversary Dances', 'Goldring 3 Anniv', 146, 1, 0, 0, 1, 104, '2009-03-15 10:38:52+00', 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (88, '2002-12-31 23:00:00+00', '2016-10-12 12:23:35.349247+00', 'Edinburgh Diamond Jubilee Dances 1984', 'Edinb. Diamond Jub. 1984', 119, 1, 0, 0, 1, 1978, '2016-10-12 12:23:35.347398+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (112, '2002-12-31 23:00:00+00', '2016-06-22 13:14:12.480284+00', 'Croydon and District Book 1989', 'Croydon', 92, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1989);
INSERT INTO 'publication' VALUES (84, '2002-12-31 23:00:00+00', '2016-09-09 22:07:48.111898+00', 'Dances of an Island Clan', 'Island Clan', 355, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (115, '2002-12-31 23:00:00+00', '2018-01-19 10:35:04.683399+00', 'Allanton Collection, The', 'Allanton', 340, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1990);
INSERT INTO 'publication' VALUES (104, '2002-12-31 23:00:00+00', '2018-01-12 20:03:12.283667+00', 'Lone Sheiling Book of SCD, The', 'Lone Sheiling', 313, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (106, '2002-12-31 23:00:00+00', '2018-01-12 20:02:06.068061+00', 'Whaup''s Nest Book, The', 'Whaup''s Nest', 313, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (90, '2002-12-31 23:00:00+00', '2018-01-12 20:34:09.175159+00', 'Phantom Piper Book of SCD, The', 'Phantom Piper', 313, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (80, '2002-12-31 23:00:00+00', '2018-01-17 11:43:18.307547+00', '50th Anniversary Collection of Scottish Country Dances (1947-1997) [New Scotland]', 'New Scotland 50', 1751, 1, 1, 1, 1, 157, '2012-02-13 22:34:57+00', 0, 'Published in 1997, on the 50th Anniversary of their founding in 1947.', 0, 1997);
INSERT INTO 'publication' VALUES (113, '2002-12-31 23:00:00+00', '2018-02-13 14:08:21.692516+00', 'Life Begins at Forty', 'Life b.a. 40', 289, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1990);
INSERT INTO 'publication' VALUES (140, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.923245+00', 'Ridings Collection, The', 'Ridings', 353, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (128, '2002-12-31 23:00:00+00', '2020-03-15 14:16:16.843236+00', 'Imperial Book of Scottish Country Dances Vol II', 'Imperial II', 192, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1971);
INSERT INTO 'publication' VALUES (130, '2002-12-31 23:00:00+00', '2020-03-15 14:17:23.600541+00', 'Imperial Book of Scottish Country Dances Vol IV', 'Imperial IV', 192, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1984);
INSERT INTO 'publication' VALUES (144, '2002-12-31 23:00:00+00', '2020-04-21 16:05:36.464743+00', 'Lifeboat Dances', 'Lifeboat', 248, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1955);
INSERT INTO 'publication' VALUES (40, '2002-12-31 23:00:00+00', '2021-06-06 20:53:32.117547+00', 'Introducing Scottish Country Dancing', 'RSCDS intro.', 319, 1, 0, 1, 1, NULL, NULL, 0, 'Reprinted 1973.', 1, 1968);
INSERT INTO 'publication' VALUES (127, '2002-12-31 23:00:00+00', '2021-03-22 02:09:06.059446+00', 'Imperial Book of Scottish Country Dances Vol I', 'Imperial I', 192, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1966);
INSERT INTO 'publication' VALUES (73, '2002-12-31 23:00:00+00', '2021-04-19 19:37:52.477752+00', 'Reel, The', 'The Reel', 235, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (143, '2002-12-31 23:00:00+00', '2021-07-25 19:56:04.843254+00', 'Cormorant Scottish Dances Book 1', 'Cormorant 1', 264, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (121, '2002-12-31 23:00:00+00', '2021-08-03 16:59:15.934335+00', 'Southport Book Volume 1', 'Southport 1', 364, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1991);
INSERT INTO 'publication' VALUES (114, '2002-12-31 23:00:00+00', '2021-11-12 15:19:19.275946+00', 'Five Scottish Country Dances (Berks)', 'Berks 5 SCD', 30, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1990);
INSERT INTO 'publication' VALUES (148, '2002-12-31 23:00:00+00', '2012-01-20 12:55:51.992619+00', 'Two Dances', 'Killeen: 2 dances', 212, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (118, '2002-12-31 23:00:00+00', '2012-07-16 16:45:58.809965+00', 'Grand Chain and Allepouss', 'Gr.Ch. & Allepouss', 227, 1, 0, 0, 1, 106, '2011-07-15 19:56:09+00', 3, 'Probably published mid-1990; reprinted jan. 1991.



With thanks to the Thistle Club for many years of pleasure', 0, '1990-00-00');
INSERT INTO 'publication' VALUES (200, '2002-12-31 23:00:00+00', '2018-02-27 21:02:13.644131+00', 'Silver City Book of SCD', 'Silver City', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1968);
INSERT INTO 'publication' VALUES (138, '2002-12-31 23:00:00+00', '2013-02-03 21:29:33.685527+00', 'Liverpool 40th Anniversary', 'Liverpool 40th', 230, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (195, '2002-12-31 23:00:00+00', '2019-01-21 23:30:27.540311+00', 'New Haven Branch RSCDS 12 Dances', 'New Haven 12 dances', 285, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (124, '2002-12-31 23:00:00+00', '2022-01-19 09:51:16.209912+00', 'Twenty SCD by Alec Hay (Book 5)', 'Hay: 20 SCD 5', 2357, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1998);
INSERT INTO 'publication' VALUES (141, '2002-12-31 23:00:00+00', '2022-12-18 11:41:39.883272+00', 'Salute To Bath', 'Salute to Bath', 25, 1, 1, 1, 1, NULL, NULL, 0, 'The title says: "Twelve dances with music for the 40th anniversary of the Bath Branch of the RSCDS"', 0, 1988);
INSERT INTO 'publication' VALUES (161, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.111202+00', 'Tae Gar Ye Loup Book 1', 'Tae Gar Ye Loup', 1586, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (164, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.136317+00', 'Cotswold Gateway Book, The', 'Cotswold Gateway', 89, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (169, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.178456+00', 'Eight Scottish Country Dances', 'Duthie 8 SCD', 116, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (170, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.18677+00', 'Crier, The', 'The Crier', 722, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (172, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.20457+00', 'Kinrossmuir Collection', 'Kinrossmuir', 329, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (178, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.246229+00', 'Dance(s) by Croydon Branch', 'Croydon', 92, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (179, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.253018+00', 'Twenty Two SCD and One Other', '22 + 1', 87, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (160, '2002-12-31 23:00:00+00', '2018-06-14 15:49:07.693852+00', 'Rose Collection of Scottish Dances', 'Rose Collection', 129, 1, 1, 0, 1, NULL, NULL, 0, 'This book, edited by Robert Donald, was the final collection dedicated to the memory and achievement of Hugh Foss. It contains all remaining dances not formally published by him during his life-time.', 0, 1979);
INSERT INTO 'publication' VALUES (184, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.294491+00', 'Island Cottage Collection', 'Island Cottage', 377, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (187, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.319283+00', 'Ten Dances, Mainly For Teaching', 'Townley: 10 dances', 393, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (189, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.337069+00', 'Baldovan Set Dances', 'Baldovan', 176, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (190, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.345326+00', 'Kinclaven Pocket Book of Six Scottish Country Dances', 'Kinclaven Pocket', 176, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (192, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.361867+00', 'Strathclyde Set Dances', 'Strathclyde Set', 342, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (193, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.37012+00', 'Cobham Hall Collection', 'Cobham Hall', 138, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (153, '2002-12-31 23:00:00+00', '2014-04-02 13:54:42.003537+00', 'Kendoon Set of Dances, The', 'Kendoon', 129, 1, 1, 1, 1, 160, '2009-07-15 06:17:15+00', 4, '', 0, 1960);
INSERT INTO 'publication' VALUES (157, '2002-12-31 23:00:00+00', '2014-04-02 15:48:44.897606+00', 'Mantua-Makers Set, The', 'Mantua-Makers', 129, 1, 1, 1, 1, 160, '2009-07-15 06:17:38+00', 4, '', 0, 1968);
INSERT INTO 'publication' VALUES (151, '2002-12-31 23:00:00+00', '2014-03-31 14:58:51.07037+00', 'Castledeen Album of Nine Scottish Country Dances', 'Castledeen', 129, 1, 1, 1, 1, 160, '2009-07-15 06:16:20+00', 4, '', 0, 1965);
INSERT INTO 'publication' VALUES (150, '2002-12-31 23:00:00+00', '2014-04-01 21:16:28.63373+00', 'Waverley Fugues', 'Waverley Fugues', 129, 1, 0, 0, 1, 160, '2013-10-08 13:03:03+00', 4, 'Twelve Scottish Country Dances for demonstrations', 0, 1963);
INSERT INTO 'publication' VALUES (159, '2002-12-31 23:00:00+00', '2014-04-02 16:06:24.063351+00', 'Wagstaff Set, The', 'Wagstaff', 129, 1, 1, 0, 1, 160, '2014-04-02 15:51:39+00', 4, '', 0, 1969);
INSERT INTO 'publication' VALUES (168, '2002-12-31 23:00:00+00', '2016-06-20 23:00:08.662226+00', 'Garioch Book, The', 'Garioch', 89, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (197, '2002-12-31 23:00:00+00', '2016-02-26 22:10:19.447779+00', 'Quincentenary Scottish Country Dances', 'Quincentenary', 108, 1, 1, 1, 1, NULL, '2016-02-26 22:10:19.446079+00', 4, '', 0, 1995);
INSERT INTO 'publication' VALUES (175, '2002-12-31 23:00:00+00', '2016-09-06 08:31:57.41951+00', 'Macaulay Collection Vol 1', 'Macauley 1', 40, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1991);
INSERT INTO 'publication' VALUES (145, '2002-12-31 23:00:00+00', '2016-09-06 08:32:16.823456+00', 'Macaulay Collection Vol 2', 'Macauley 2', 40, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (199, '2002-12-31 23:00:00+00', '2017-01-20 00:46:34.678288+00', 'Rondel Book of SCD', 'Rondel', 108, 1, 0, 0, 1, 108, '2009-04-14 20:55:47+00', 0, '', 0, 1967);
INSERT INTO 'publication' VALUES (206, '2002-12-31 23:00:00+00', '2017-11-06 22:22:36.85391+00', 'Winter Collection (1988)', 'Drewry Winter 88', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1988);
INSERT INTO 'publication' VALUES (174, '2002-12-31 23:00:00+00', '2017-01-20 05:05:42.544709+00', 'Tweeddale Collection', 'Tweeddale', 154, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (173, '2002-12-31 23:00:00+00', '2017-01-21 20:13:10.915591+00', 'Dance Till Dawn', 'Dnc Till Dawn 1', 273, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (176, '2002-12-31 23:00:00+00', '2017-01-21 12:56:16.25586+00', 'Carnforth Collection of SC Dances 2', 'Carnforth 2', 175, 1, 1, 0, 1, 106, '2009-03-13 21:57:57+00', 3, 'First published in November 1991, it was reprinted in March and October 2002.', 0, 1991);
INSERT INTO 'publication' VALUES (186, '2002-12-31 23:00:00+00', '2017-01-21 20:20:21.548713+00', 'Casnewydd Collection', 'Casnewydd', 290, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (196, '2002-12-31 23:00:00+00', '2017-01-23 05:46:46.35887+00', 'Competition Dances 1989', 'York: Competition 89', 426, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1989);
INSERT INTO 'publication' VALUES (147, '2002-12-31 23:00:00+00', '2017-05-29 19:01:18.463811+00', 'Crystal Collection, The', 'Crystal', 224, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (154, '2002-12-31 23:00:00+00', '2017-10-27 11:47:33.895527+00', 'Celtic Brooch, The', 'Celtic Brooch', 129, 1, 1, 0, 1, 1645, '2017-10-26 21:40:36+00', 3, '', 0, 1964);
INSERT INTO 'publication' VALUES (204, '2002-12-31 23:00:00+00', '2017-11-06 22:29:18.830553+00', 'Spring Collection (1988)', 'Drewry Spring 88', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1988);
INSERT INTO 'publication' VALUES (188, '2002-12-31 23:00:00+00', '2012-07-16 16:46:51.476839+00', 'Two By Two', '', 227, 1, 0, 1, 1, 106, '2011-07-15 19:56:46+00', 3, 'On page 9 some notes give details on the dances; this information has been added to the dances.', 0, 1994);
INSERT INTO 'publication' VALUES (215, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.562337+00', 'Fort Worden XX Book', 'Fort Worden 20', 571, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (221, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.612857+00', 'Ormskirk Scottish Dances Book 1', 'Ormskirk 1', 82, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (222, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.621515+00', 'Ormskirk Scottish Dances Book 2', 'Ormskirk 2', 82, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (167, '2002-12-31 23:00:00+00', '2020-05-03 10:56:18.847738+00', 'McGhie''s Seat & Other Scottish Country Dances, The', 'McGhie''s Seat', 99, 1, 0, 0, 1, 35761, '2020-04-22 15:33:03+00', 0, 'This was the fourth publication by Lewis N Derrick in his McGhie series and he now refers to it with the abbreviated colophon ''Mc4''.', 0, 1989);
INSERT INTO 'publication' VALUES (181, '2002-12-31 23:00:00+00', '2021-06-21 22:20:11.760373+00', 'Sussex Martlet Book Vol 1', 'Sussex Mart. 1', 377, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (182, '2002-12-31 23:00:00+00', '2021-06-21 22:20:42.62066+00', 'Sussex Martlet Book Vol 2', 'Sussex Mart. 2', 410, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (183, '2002-12-31 23:00:00+00', '2021-06-21 22:21:09.763022+00', 'Sussex Martlet Book Vol 3', 'Sussex Mart. 3', 410, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (185, '2002-12-31 23:00:00+00', '2021-06-21 22:21:33.15159+00', 'Sussex Martlet Book Vol 4 (1990)', 'Sussex Mart. 4', 378, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (158, '2002-12-31 23:00:00+00', '2021-06-22 16:26:36.568858+00', 'Tunes for Scottish Country Dancing', 'Tunes for SCD', 235, 0, 1, 0, 1, NULL, NULL, 0, 'To celebrate the 75th Anniversary of The Royal Scottish Country Dance Society 1998', 0, 1998);
INSERT INTO 'publication' VALUES (146, '2002-12-31 23:00:00+00', '2021-06-22 18:35:56.78633+00', 'Another Newcastle Collection', 'Newcastle 2', 289, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1993);
INSERT INTO 'publication' VALUES (223, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.629839+00', 'Ormskirk Scottish Dances Book 3', 'Ormskirk 3', 82, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (224, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.638164+00', 'Ormskirk Scottish Dances Book 4', 'Ormskirk 4', 82, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (225, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.646753+00', 'Ormskirk Scottish Dances Book 5', 'Ormskirk 5', 82, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (226, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.655025+00', 'Ormskirk Scottish Dances Book 6', 'Ormskirk 6', 82, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (227, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.663361+00', 'Ormskirk Scottish Dances - Memorial Edition', 'Ormskirk Mem.', 82, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (232, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.704746+00', 'Two Dances with Music', 'Bradford: 2 dances', 46, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (233, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.71301+00', 'Nottingham Lace', 'Nottingham Lace', 48, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (235, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.729778+00', 'Culzean Castle Collection', 'Culzean Castle', 48, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (236, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.738056+00', 'Glenfeshie Book', 'Glenfeshie 1', 94, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (237, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.746294+00', 'Ayton Collection, The', 'Ayton', 372, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (202, '2002-12-31 23:00:00+00', '2022-12-09 21:34:49.32059+00', 'Angus MacLeod', 'Angus MacLeod', 344, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (219, '2002-12-31 23:00:00+00', '2022-12-19 20:25:09.828109+00', 'Hague Silver Jubilee', 'Hague SIlver', 163, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1983);
INSERT INTO 'publication' VALUES (238, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.754544+00', 'Cleveland Collection, The', 'Cleveland', 162, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (240, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.771024+00', 'Carswella Collection Volume 1', 'Carswella 1', 190, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (241, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.779279+00', 'Carswella Collection Volume 2', 'Carswella 2', 190, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (242, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.78763+00', 'York Book of Scottish Country Dances', 'York 1', 211, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (244, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.804561+00', 'York Book of Scottish Country Dances, Book 2', 'York 2', 427, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (245, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.812903+00', 'Morley Dances', 'Morley', 300, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (247, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.829489+00', 'Catriona Williamson', 'C. Williamson', 418, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (248, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.837836+00', 'Scheessel Set', 'Scheessel', 311, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (250, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.854385+00', 'Thirtieth Anniversary SCD', 'Stone: 30th Anniv.', 376, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (251, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.862667+00', 'Wyche Book of Dances', 'Wyche', 75, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (254, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.887478+00', 'Loreburn Set of Dances Volume I', 'Loreburn I', 200, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (258, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.926951+00', 'Aberbrothock Book', 'Aberbrothock', 377, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (149, '2002-12-31 23:00:00+00', '2014-04-01 14:06:02.366083+00', 'Galloway Album', 'Galloway', 129, 1, 1, 1, 1, 160, '2009-07-15 06:16:49+00', 4, '', 0, 1964);
INSERT INTO 'publication' VALUES (210, '2002-12-31 23:00:00+00', '2014-04-28 14:49:02.569662+00', 'Donside Book, The', 'Donside', 108, 1, 0, 0, 1, 160, '2014-04-28 12:59:41+00', 3, '', 0, 1990);
INSERT INTO 'publication' VALUES (156, '2002-12-31 23:00:00+00', '2014-07-11 21:37:20.243304+00', 'Dances To Song Tunes', 'Song Tunes', 129, 1, 1, 1, 1, 160, '2009-07-15 06:16:35+00', 3, '##RSCDS-DI:short:ST', 0, 1966);
INSERT INTO 'publication' VALUES (209, '2002-12-31 23:00:00+00', '2014-05-30 14:55:36.617665+00', 'Deeside Book Part 2', 'Deeside 2', 108, 1, 0, 1, 1, 160, '2014-05-10 08:55:17+00', 3, '', 0, 1981);
INSERT INTO 'publication' VALUES (259, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.933848+00', 'Collection of Four SCD', 'Purdon/Over: 4 SCD', 314, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1462, '2018-07-19 10:36:16.940304+00', '2018-07-19 14:28:07.435993+00', 'Dancing Brolga Collection of Scottish Country Dances - Volume 5, The', '', 10907, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (257, '2002-12-31 23:00:00+00', '2015-09-21 06:23:23.813575+00', 'Friendship Book of Scottish Dances', 'Friendship Bk.', 377, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (214, '2002-12-31 23:00:00+00', '2018-08-03 22:34:57.298853+00', 'Chardon d''Ecosse, Le (10th Anniversary)', 'Chardon d''Ecosse', 220, 1, 0, 0, 1, 202, '2018-08-03 22:34:57.296978+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (231, '2002-12-31 23:00:00+00', '2016-06-20 22:41:25.625452+00', 'Campbell-Stewart Anniversary Collection', 'Campbell-Stewart', 28, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (220, '2002-12-31 23:00:00+00', '2016-06-22 13:27:23.447791+00', 'Dunse Book of four SCD', 'Dunse', 115, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (207, '2002-12-31 23:00:00+00', '2017-01-20 00:44:30.976674+00', 'Canadian Book of Scottish Country Dances, The', 'Canadian', 108, 1, 0, 0, 1, 108, '2010-06-04 22:58:06+00', 0, '', 0, 1977);
INSERT INTO 'publication' VALUES (249, '2002-12-31 23:00:00+00', '2016-06-26 10:17:38.0939+00', 'Four Dances (Gordon)', 'Gordon: 4 dances', 149, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (253, '2002-12-31 23:00:00+00', '2017-01-19 18:14:15.528988+00', 'Score & More, A', '', 340, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 1984);
INSERT INTO 'publication' VALUES (213, '2002-12-31 23:00:00+00', '2017-01-20 00:49:47.750368+00', 'Bankhead Book Part 4', 'Bankhead 4', 108, 1, 0, 0, 1, NULL, '2016-02-26 22:06:33+00', 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (1463, '2018-07-19 10:37:33.187187+00', '2018-07-19 16:10:49.583633+00', 'Dancing Brolga Collection of Scottish Country Dances - Volume 6, The', 'Brolga,  Vol 6', 10907, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (255, '2002-12-31 23:00:00+00', '2017-01-21 13:19:30.746228+00', 'Loreburn Set of Dances Volume II', 'Loreburn II', 200, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1976);
INSERT INTO 'publication' VALUES (260, '2002-12-31 23:00:00+00', '2017-01-21 13:20:40.500239+00', 'Loreburn Dances Book Three', 'Loreburn III', 200, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1989);
INSERT INTO 'publication' VALUES (256, '2002-12-31 23:00:00+00', '2017-04-21 20:35:40.167024+00', 'Leeds Branch Tenth Anniversary Book', '10th Leeds Anniv.', 223, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1972);
INSERT INTO 'publication' VALUES (218, '2002-12-31 23:00:00+00', '2017-11-04 21:50:35.989645+00', 'Tay Bridge Pocket Book', 'Tay Bridge', 176, 1, 0, 0, 1, NULL, NULL, 0, 'Full name:  Tay Bridge Book of 6 Scottish Country Dances', 0, 0000);
INSERT INTO 'publication' VALUES (211, '2002-12-31 23:00:00+00', '2017-11-06 23:31:40.201058+00', 'Bankhead Book Part 1', 'Bankhead 1', 108, 1, 0, 0, 1, NULL, '2016-02-26 22:06:16+00', 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (191, '2002-12-31 23:00:00+00', '2018-01-16 19:56:48.359866+00', 'Scottish Country Dances in Diagrams. Ed. 6', 'Pillings 6', 398, 1, 0, 1, 1, NULL, NULL, 0, 'The very first edition of ''The Wee Green Book'' was published in 1955.', 0, 1992);
INSERT INTO 'publication' VALUES (212, '2002-12-31 23:00:00+00', '2019-06-07 13:19:09.94721+00', 'Bankhead Book Part 3', 'Bankhead 3', 108, 1, 0, 0, 1, NULL, '2016-02-26 22:06:27+00', 0, '', 0, 1993);
INSERT INTO 'publication' VALUES (263, '2002-12-31 23:00:00+00', '2012-01-20 12:55:52.960209+00', 'Reel Occasion, A', 'Reel Occasion', 21, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (269, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.011467+00', 'Music Makers', 'Music Makers', 21, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (270, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.019873+00', 'Goathland Collection', 'Goathland', 21, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (273, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.044967+00', 'Elizabeth Mary''s Book', 'Elizabeth Mary', 377, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (274, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.053312+00', 'Offer Your Hand', 'Offer your Hand', 377, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (252, '2002-12-31 23:00:00+00', '2021-06-12 17:58:42.671469+00', 'Caledonian Country Dances Book 1', 'Caledonian Book1', 222, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (228, '2002-12-31 23:00:00+00', '2021-06-22 18:34:36.017712+00', 'Green Lochan And 11 Other Scottish Dances', 'Green Lochan', 1343, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1971);
INSERT INTO 'publication' VALUES (246, '2002-12-31 23:00:00+00', '2021-08-02 21:34:19.984752+00', 'Annette Cameron Book of Ten SCD', 'Annette Cameron', 418, 1, 0, 0, 1, NULL, NULL, 0, 'In 1971 Arthur Williamson lived in Victoria, Australia (information from <<https://my.strathspey.org/dd/issue/2419/|issue 2419>>).', 0, 1971);
INSERT INTO 'publication' VALUES (276, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.069826+00', 'Ruislip Set', 'Ruislip', 377, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (285, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.144478+00', 'Thistle Collection, The', 'Thistle', 1916, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (299, '2002-12-31 23:00:00+00', '2018-03-19 11:48:53.839013+00', 'Primrose Collection, The', 'Primrose', 2023, 1, 0, 1, 1, 202, '2018-03-19 09:19:21+00', 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (288, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.16983+00', 'National Book', 'National', 9998, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (291, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.186822+00', 'Fair City Book', 'Fair City', 619, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (292, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.195113+00', 'Dances for Friends Two', 'Friends 2', 1445, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (295, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.219954+00', 'Robertson - SCD Book 5', 'Robertson 5', 619, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (323, '2002-12-31 23:00:00+00', '2019-05-16 13:38:26.502481+00', 'Charities Book 5 (Open Door)', 'Open Door', 27, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1993);
INSERT INTO 'publication' VALUES (300, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.261953+00', 'Robertson - SCD Book 4', 'Robertson 4', 619, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (301, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.268381+00', 'Strathspeyper', 'Strathspeyper', 9998, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (302, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.274785+00', 'Dances for Friends and Other People', 'Friends and Others', 1445, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (303, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.28144+00', 'Robertson - SCD Book 2', 'Robertson 2', 619, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (294, '2002-12-31 23:00:00+00', '2022-01-14 10:43:15.503768+00', 'Fleming - 20 SCD', 'Fleming 20 SCD', 631, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1978);
INSERT INTO 'publication' VALUES (243, '2002-12-31 23:00:00+00', '2022-01-14 10:55:24.182361+00', 'Bryn Mawr Booklet of Scottish Dances, The', 'Bryn Mawr', 210, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1970);
INSERT INTO 'publication' VALUES (265, '2002-12-31 23:00:00+00', '2022-01-18 21:47:11.989658+00', 'By Dundonald', 'By Dundonald', 21, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (282, '2002-12-31 23:00:00+00', '2022-05-31 11:02:24.474377+00', 'Piping Shrike Collection, The', 'Piping Shrike', 4, 1, 1, 1, 1, 17, '2018-08-06 05:48:41+00', 0, '', 0, 1998);
INSERT INTO 'publication' VALUES (264, '2002-12-31 23:00:00+00', '2022-01-18 21:54:05.737045+00', 'Dance and Celebration', 'Dance & Celeb.', 21, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (275, '2002-12-31 23:00:00+00', '2022-12-18 20:40:36.749677+00', 'Eastcote Set', 'Eastcote', 377, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (304, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.287876+00', 'Robertson - SCD Book 3', 'Robertson 3', 619, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (305, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.294258+00', 'Ho-ro-gheallaidh', 'Ho-ro-gheallaidh', 9998, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (306, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.300647+00', 'Dartmoor Crib Book', 'Dartmoor', 9998, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (308, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.313694+00', 'Richmond Anniversary Book', 'Richmond Anniv.', 1255, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (319, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.386024+00', 'Duo for Sydney', 'Duo for Sydney', 325, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (320, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.39244+00', 'Carswella Wedding Anniversary', 'Carswella WA', 190, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (267, '2002-12-31 23:00:00+00', '2013-04-10 09:08:13.704478+00', 'Set and Cast Off Volume 2', 'Set & Cast Off 2', 22, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (271, '2002-12-31 23:00:00+00', '2014-09-01 17:13:33.560924+00', 'Burnham Set, The', 'Burnham', 104, 1, 0, 0, 1, 2088, '2014-09-01 14:53:41+00', 0, '', 0, 1979);
INSERT INTO 'publication' VALUES (277, '2002-12-31 23:00:00+00', '2014-11-04 23:27:05.367586+00', 'Jacobite Book of Scottish Country Dances', 'Jacobite', 313, 1, 0, 1, 1, 160, '2013-09-29 00:54:06+00', 3, 'There may be versions of this book around that don''t include the dance, <<ddd:Merry Ploughboy, The>>.', 0, 0000);
INSERT INTO 'publication' VALUES (325, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.424947+00', 'For Special Occasions', 'Smith: Special Occ.', 989, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (326, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.43141+00', 'Price - SCD music', 'Price - SCD music', 9998, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (331, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.465893+00', 'Appin Rant', 'Appin Rant', 9998, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (280, '2002-12-31 23:00:00+00', '2015-02-28 11:54:51.318585+00', 'Rannoch Sheets', 'Rannoch', 344, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1991);
INSERT INTO 'publication' VALUES (312, '2002-12-31 23:00:00+00', '2016-02-26 22:06:44.039775+00', 'Bankhead Book Part 6', 'Bankhead 6', 108, 1, 0, 0, 1, NULL, '2016-02-26 22:06:44.038094+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (307, '2002-12-31 23:00:00+00', '2016-03-08 14:02:33.917986+00', 'Glasgow Diamond Jubilee', 'Glasgow Diamond', 144, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1983);
INSERT INTO 'publication' VALUES (272, '2002-12-31 23:00:00+00', '2016-12-16 13:45:19.197018+00', 'Repeat Prescription', 'Repeat Prescr.', 2753, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (290, '2002-12-31 23:00:00+00', '2016-05-21 15:08:04.946354+00', 'Rainbow Book', 'Rainbow', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (310, '2002-12-31 23:00:00+00', '2016-05-21 15:10:27.413933+00', 'Pink Book, The', 'Pink Book', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (321, '2002-12-31 23:00:00+00', '2017-12-20 02:08:04.116641+00', 'Galloways', 'Galloways', 729, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (315, '2002-12-31 23:00:00+00', '2016-05-26 21:54:48.85209+00', 'Exeter 25th Anniversary', 'Exeter 25th', 3563, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (297, '2002-12-31 23:00:00+00', '2016-09-28 23:49:06.297664+00', 'Let''s All Dance Too', 'Let''s All Dance Too', 170, 1, 0, 1, 1, 2929, '2016-09-28 23:49:06.295894+00', 0, '', 0, 1997);
INSERT INTO 'publication' VALUES (286, '2002-12-31 23:00:00+00', '2017-01-19 18:07:30.242005+00', 'Two Score More', '', 340, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 1987);
INSERT INTO 'publication' VALUES (298, '2002-12-31 23:00:00+00', '2017-03-05 20:28:28.010465+00', 'Stepping Out Part 1 - Basic SCDs for beginners', 'Stepping Out 1', 872, 1, 0, 0, 1, 202, '2017-03-05 20:28:28.006756+00', 0, '', 0, 1997);
INSERT INTO 'publication' VALUES (327, '2002-12-31 23:00:00+00', '2017-07-24 09:57:25.427199+00', 'Bonnie Gallowa''', 'Bonnie Gallowa''', 340, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1997);
INSERT INTO 'publication' VALUES (287, '2002-12-31 23:00:00+00', '2017-03-16 11:11:18.72413+00', 'St. Brendan''s Set, The', 'Saint Brendan', 1228, 1, 0, 0, 1, 3311, '2017-03-15 20:18:05+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (296, '2002-12-31 23:00:00+00', '2018-01-17 10:54:13.305347+00', 'Thursday Night and Other Dances', 'Thursday Night', 737, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1991);
INSERT INTO 'publication' VALUES (334, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.485756+00', '23 SCD tunes', '23 SCD', 1607, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (396, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.007297+00', 'Three Dances for Nora', '3 for Nora', 2359, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (335, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.492263+00', 'David South Collection of SCD Music, The', 'David South', 1899, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (336, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.4987+00', 'Three SCD', 'Holden: 3 SCD', 181, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (341, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.531485+00', 'Ashley Album', 'Ashley', 1607, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (351, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.60096+00', 'Gretchen''s Fancy', 'Gretchen''s Fancy', 2017, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (367, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.768379+00', 'Dance(s) by Rothesay Branch', 'Rothesay Branch', 330, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (330, '2002-12-31 23:00:00+00', '2020-04-23 20:30:06.44714+00', 'Twizell Bridge + The King Over The Water [leaflet]', '', 146, 1, 1, 0, 1, 104, '2009-03-15 10:41:03+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (369, '2002-12-31 23:00:00+00', '2020-07-07 09:24:44.40149+00', 'Ness House Collection, The - Book 2', 'Ness House 2', 344, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1997);
INSERT INTO 'publication' VALUES (311, '2002-12-31 23:00:00+00', '2020-08-07 20:03:21.867293+00', 'Eight New Scottish Country Dances', 'Mill 8 SCD', 824, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (313, '2002-12-31 23:00:00+00', '2021-06-25 22:21:24.885911+00', 'Two Scottish Country Dances', 'Blair: 2 SCD', 33, 1, 0, 0, 1, NULL, NULL, 0, 'Published by the Newcastle and District Branch of the RSCDS.



The order of the two dances in this leaflet is take from <<https://my.strathspey.org/dd/issue/2510/|issue 2510>>.', 0, '1967-00-00');
INSERT INTO 'publication' VALUES (1461, '2018-07-19 10:35:34.746282+00', '2018-07-19 10:51:23.248865+00', 'Dancing Brolga Collection of Scottish Country Dances - Volume 4, The', '', 10907, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (373, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.817915+00', 'Book of Seven (Plus Two), A', 'Bond: 7 + 2', 2022, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (375, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.834222+00', 'Four Other Dances', 'Wood: 4 other', 425, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (381, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.886168+00', 'Seasons Book, The', 'Taeger: Seasons', 2002, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (384, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.910996+00', 'Choicest Scots Tunes', 'Choicest tunes', 1921, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (389, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.949539+00', 'Merrie Melodies, 4th Collection', 'Kerr MM4', 1916, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (391, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.966386+00', 'Merrie Melodies, 2nd Collection', 'Kerr MM2', 1916, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (392, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.974583+00', 'Fiddler''s Tune Book', 'Kerr 1', 2282, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (393, '2002-12-31 23:00:00+00', '2012-01-20 12:55:53.982771+00', 'Linden Collection, The', 'Linden Coll.', 1899, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (359, '2002-12-31 23:00:00+00', '2014-04-08 14:23:29.999998+00', 'Delaware Valley Silver', 'Delaware Valley 25', 2019, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (372, '2002-12-31 23:00:00+00', '2014-10-15 01:54:42.695033+00', 'Kirkbrae Collection of SCDs', 'Kirkbrae 1', 692, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (353, '2002-12-31 23:00:00+00', '2018-09-16 09:22:46.102544+00', 'Gaelic College SCD Book #1: The Sixpenny Reel', 'Sixpenny Reel', 2018, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (345, '2002-12-31 23:00:00+00', '2018-09-17 23:51:12.537017+00', 'Look, We''re Dancing', 'See & Eaton: Look', 2014, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (385, '2002-12-31 23:00:00+00', '2013-01-06 22:00:40.948949+00', 'Kinpurnie Collection, The', 'Kinpurnie', 10600, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (387, '2002-12-31 23:00:00+00', '2013-01-06 22:33:40.459657+00', 'Nineties Collection, The', 'Nineties', 10706, 0, 1, 0, 1, NULL, NULL, 0, 'Over 200 tunes in this collection, Collection edited by Ian Hardie.', 0, 0000);
INSERT INTO 'publication' VALUES (383, '2002-12-31 23:00:00+00', '2022-02-22 14:15:45.689048+00', 'Complete Guide to Scottish Country Dancing, A', 'Complete guide', 2129, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1932);
INSERT INTO 'publication' VALUES (346, '2002-12-31 23:00:00+00', '2022-07-15 18:28:17.58406+00', 'Cameo Collection Book 19', 'Cameo 19', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (347, '2002-12-31 23:00:00+00', '2022-07-15 18:28:29.306375+00', 'Cameo Collection Book 20', 'Cameo 20', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (328, '2002-12-31 23:00:00+00', '2022-12-16 20:44:10.60613+00', 'Hopetoun Suite', 'Hopetoun Suite', 2027, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (344, '2002-12-31 23:00:00+00', '2022-12-18 17:30:57.561373+00', 'Island Bay Collection (2nd edition)', 'Island Bay 2', 194, 1, 0, 1, 1, NULL, NULL, 0, 'This is an expanded edition of <<ddpub:Island Bay Collection#643>> which was originally published in 1984 with just 5 dances. ', 0, 1996);
INSERT INTO 'publication' VALUES (284, '2002-12-31 23:00:00+00', '2022-12-25 23:11:02.899792+00', 'If The Ghillie Fits', 'Ghillie Fits', 355, 1, 1, 0, 1, NULL, NULL, 0, 'Page 8 shows a commemoration: *"To commemorate the Twelfth Clan Parliament At Dunvegan Castle on the Isle of Skye In August 1994 During the Chiefship of John MacLeod of MacLeod XXIX Chief of the Clan"*', 0, 1994);
INSERT INTO 'publication' VALUES (397, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.015444+00', 'Lanchester Collection, The', 'Lanchester', 1193, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (400, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.03986+00', 'Leslie Braes', 'Leslie Braes', 1764, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (366, '2002-12-31 23:00:00+00', '2017-01-23 05:22:48.714993+00', 'Sheaf Book of Scottish Country Dances', 'Sheaf', 1134, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (365, '2002-12-31 23:00:00+00', '2017-03-31 12:11:52.74117+00', 'Stepping Out Part 3 - More advanced SCDs for beginners (Original)', 'Stepping Out 3 Original', 872, 1, 0, 1, 1, 202, '2014-11-03 14:51:22+00', 0, '', 0, 1997);
INSERT INTO 'publication' VALUES (1472, '2018-08-25 08:35:41.644637+00', '2018-09-24 09:10:28.637707+00', 'Platinum Anniversary Dances - RSCDS Stonehaven', 'Stonehaven Platinum', 11679, 1, 1, 0, 1, NULL, NULL, 0, 'There is music for Skatie Shore', 0, 2018);
INSERT INTO 'publication' VALUES (348, '2002-12-31 23:00:00+00', '2016-05-12 07:24:15.078168+00', 'Three For Two', '', 2015, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (343, '2002-12-31 23:00:00+00', '2016-05-12 09:17:13.576908+00', 'Celtic Society, Bicentenary Dance Book', 'Celtic Soc. Univ St A: Bicentenary', 2013, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (363, '2002-12-31 23:00:00+00', '2016-06-20 22:57:09.384686+00', 'Brig o'' Balgownie', 'Brig o'' Balgownie', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1996);
INSERT INTO 'publication' VALUES (355, '2002-12-31 23:00:00+00', '2018-09-16 09:30:27.775454+00', 'Gaelic College SCD Book #3: A Dime a Dozen', 'Dime a Dozen', 2018, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (349, '2002-12-31 23:00:00+00', '2018-01-19 12:13:49.695093+00', 'Twenty SCD by Alec Hay (Book 4)', 'Hay: 20 SCD 4', 2357, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1997);
INSERT INTO 'publication' VALUES (354, '2002-12-31 23:00:00+00', '2018-09-16 09:33:28.966463+00', 'Gaelic College SCD Book #4: A Reel Dozen', 'A Reel Dozen', 2018, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (376, '2002-12-31 23:00:00+00', '2018-09-16 09:37:50.355027+00', 'Gaelic College SCD Book #5: A Dozen More', 'A Dozen More', 2018, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (378, '2002-12-31 23:00:00+00', '2018-09-16 09:46:29.470431+00', 'Gaelic College SCD Book #7: Around a Dozen', 'Around a Dozen', 2018, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (340, '2002-12-31 23:00:00+00', '2019-01-31 01:02:12.510197+00', 'Hermitage Set', 'Hermitage Set', 318, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (390, '2002-12-31 23:00:00+00', '2018-11-15 00:47:27.931012+00', 'Merrie Melodies, 3rd Collection', 'Kerr MM3', 1916, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (332, '2002-12-31 23:00:00+00', '2019-02-09 13:03:14.849535+00', 'Westlothiana', 'Westlothiana', 1359, 1, 1, 0, 1, 604, '2012-02-07 10:15:36+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (360, '2002-12-31 23:00:00+00', '2019-05-16 13:39:30.654918+00', 'Charities Book 9', 'Charities 9', 27, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1997);
INSERT INTO 'publication' VALUES (443, '2002-12-31 23:00:00+00', '2018-03-05 09:31:48.854335+00', 'Downside Collection', 'Downside', 28, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (403, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.064351+00', 'Glayva SCD Dance Sheets', 'Glayva', 385, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (404, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.073376+00', 'Ruthven Collection, The', 'Ruthven', 2419, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (405, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.081562+00', 'Twelve Scottish Country Dances', 'Cosh: 12 SCD', 87, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (437, '2002-12-31 23:00:00+00', '2018-03-21 23:34:42.749003+00', 'Book 40. SC Dances for Young People and New Dancers', 'RSCDS XL', 319, 1, 1, 0, 1, NULL, '2016-02-26 22:07:05.831607+00', 0, '', 1, 1999);
INSERT INTO 'publication' VALUES (407, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.09938+00', 'Moving Collection, A', 'Moving Coll.', 2020, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (408, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.107553+00', 'Ten Sets of Thanks', 'Ten Sets', 2020, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (414, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.157722+00', 'Dance Music of Lindsay Ross, The', 'Lindsay Ross', 1522, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (415, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.165902+00', 'Jim Johnstone Collection, The', 'Jim Johnstone', 1525, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (416, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.17424+00', 'Scottish Violinist, The', 'Scottish Violinist', 1512, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (417, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.182921+00', 'Collection of Fiddle Tunes', 'Fiddle Tunes', 1748, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (418, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.191351+00', 'Collection of Scottish Melodies Reels Strathspeys Vol 2', 'Scottish Melodies 2', 1516, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (419, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.199614+00', 'Scottish Airs, Melodies, Strathspeys, Reels, etc.', 'Scottish Melodies', 1516, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (420, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.215868+00', 'Collection of Strathspeys, Reels..., A', 'Str. Reel Coll.', 1516, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (388, '2002-12-31 23:00:00+00', '2020-05-11 21:35:36.765524+00', 'Merrie Melodies, 1st Collection', 'Kerr MM1', 1916, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (370, '2002-12-31 23:00:00+00', '2020-07-07 09:25:18.493121+00', 'Ness House Collection, The - Book 3', 'Ness House 3', 344, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1997);
INSERT INTO 'publication' VALUES (352, '2002-12-31 23:00:00+00', '2021-03-15 12:38:55.046136+00', 'Feast of Dances, A', 'Vancouver: Feast', 1628, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (364, '2002-12-31 23:00:00+00', '2021-06-01 21:41:24.719869+00', 'Simply Strathspey''s', '', 352, 1, 0, 0, 1, 202, '2021-06-01 06:35:51+00', 0, '', 0, 1996);
INSERT INTO 'publication' VALUES (382, '2002-12-31 23:00:00+00', '2021-06-23 17:26:31.413236+00', 'Dunblane Scottish Country Dances', 'Dunblane SCD', 991, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (342, '2002-12-31 23:00:00+00', '2021-07-03 21:18:20.836108+00', 'Thirty Popular Scottish Country Dances', 'RSCDS 30 popular', 319, 1, 0, 0, 1, NULL, NULL, 0, '<<https://my.strathspey.org/dd/issue/2501/|Issue 2501>> gives dates of various reprints (1997, 1999, 2001, 2002).', 1, 1997);
INSERT INTO 'publication' VALUES (424, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.252288+00', 'Glenshee Collection, (5)', 'Glenshee-86', 87, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (425, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.260788+00', 'Here''s a Health to Him That''s Awa', 'Here''s Health', 3185, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (426, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.269239+00', 'Marking Time, Book 1', 'Marking Time', 1673, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (428, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.286662+00', 'Friendship Dances', 'Friendship', 2599, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (429, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.294821+00', 'Beechwood Collection', 'Beechwood', 2600, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (430, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.303014+00', 'Dunnington Collection Volume 1, The', 'Dunnington 1', 3205, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (433, '2002-12-31 23:00:00+00', '2018-07-25 21:59:31.136302+00', '50th Anniversary Album', 'N Ayrshire 50', 2181, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (440, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.384968+00', 'Balmoral Collection, The', 'Balmoral', 28, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (441, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.39331+00', 'Donaghadee Collection', 'Donaghadee', 28, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (447, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.442932+00', 'Auchinellan Collection, The', 'Auchinellan', 2673, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1464, '2018-07-25 22:20:58.440745+00', '2018-07-26 10:42:50.475825+00', '29 Dances devised by Jean Shaw (North Wales)', 'JeanShaw29', 2886, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (1131, '2013-02-21 16:02:04.921775+00', '2018-08-12 15:09:07.868554+00', 'CUSRC ReelWiki', '', 10751, 1, 0, 0, 0, 106, '2013-02-21 16:10:41+00', 0, 'This Wiki is now static; no new dances are being added.



After the original Wiki site (http://cusarc.soc.srcf.net/wiki/Main_Page) became moribund it was resuscitated by Edmund Croft on his own website (https://sites.google.com/site/thefollyofrogues/cusrc-reelwiki).', 0, '2009-09-01');
INSERT INTO 'publication' VALUES (423, '2002-12-31 23:00:00+00', '2014-10-15 02:02:27.484354+00', 'Kirkbrae Collection, The Second', 'Kirkbrae 2', 692, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1998);
INSERT INTO 'publication' VALUES (442, '2002-12-31 23:00:00+00', '2014-11-18 15:26:46.50547+00', 'Downpatrick Collection', 'Downpatrick', 28, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (438, '2002-12-31 23:00:00+00', '2022-02-05 11:31:52.393689+00', 'Scottish Dance Archives Set Dances', 'SDA set dances', 1343, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (444, '2002-12-31 23:00:00+00', '2022-01-18 21:13:57.02338+00', 'Dundonald Collection', 'Dundonald Coll.', 28, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (350, '2002-12-31 23:00:00+00', '2022-01-22 19:57:24.645228+00', 'Lyndhurst Silver Collection', 'Lyndhurst Silver', 2016, 1, 0, 1, 1, NULL, NULL, 0, '1971-1996', 0, 0000);
INSERT INTO 'publication' VALUES (398, '2002-12-31 23:00:00+00', '2022-12-19 16:39:02.629248+00', 'Graeme Mitchell''s Collection', 'G. Mitchell', 1592, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 1998);
INSERT INTO 'publication' VALUES (402, '2002-12-31 23:00:00+00', '2023-01-20 22:21:37.224299+00', 'Queen''s Visit, The', 'Queen''s Visit', 215, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1984);
INSERT INTO 'publication' VALUES (1465, '2018-08-07 20:12:26.983737+00', '2018-08-07 21:15:28.384075+00', 'Montréal 60th Anniversary', 'Montréal 60', 10562, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (432, '2002-12-31 23:00:00+00', '2016-05-25 16:05:06.153958+00', 'Sutton Collection', 'Sutton Coll.', 815, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (446, '2002-12-31 23:00:00+00', '2016-06-20 22:42:09.263604+00', 'Torwood Collection, The', 'Torwood', 28, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (380, '2006-03-07 23:00:00+00', '2017-01-20 01:50:17.458917+00', 'Dances of the Budapest Scottish Dance Club Vol. 1', 'Budapest Vol. 1', 3659, 1, 0, 0, 0, 274, '2012-10-14 10:21:42+00', 0, '', 0, 2005);
INSERT INTO 'publication' VALUES (427, '2002-12-31 23:00:00+00', '2017-01-20 04:39:53.428618+00', '15 Social Dances', 'Goldring: 15 soc', 146, 1, 1, 0, 1, 104, '2009-03-15 10:38:12+00', 0, '', 0, 1998);
INSERT INTO 'publication' VALUES (413, '2002-12-31 23:00:00+00', '2017-01-21 20:13:46.975527+00', 'Thistle Dubh Medley, The', 'Thistle Dubh', 272, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1997);
INSERT INTO 'publication' VALUES (439, '2002-12-31 23:00:00+00', '2018-01-16 20:39:14.165297+00', 'Starters, a Collection of Forty Scottish Country Dances', 'Starters', 28, 1, 0, 0, 1, NULL, '2015-04-22 17:24:48+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (431, '2002-12-31 23:00:00+00', '2017-10-09 15:54:48.800219+00', 'Dancing Tour, A', 'Dancing Tour', 479, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1999);
INSERT INTO 'publication' VALUES (463, '2002-12-31 23:00:00+00', '2019-09-13 14:26:39.250829+00', 'Whetherly Book 13', 'Whetherly 13', 270, 1, 0, 0, 1, NULL, NULL, 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages.  In this SCDDB record, the dances are numbered in succession, and not by page number.', 0, 1983);
INSERT INTO 'publication' VALUES (445, '2002-12-31 23:00:00+00', '2018-08-20 20:45:28.022128+00', 'Road To Saint Andrews, The', 'Road to St. A.', 28, 1, 0, 0, 1, 202, '2018-08-20 20:45:28.018138+00', 0, '', 0, 1987);
INSERT INTO 'publication' VALUES (410, '2002-12-31 23:00:00+00', '2018-09-16 10:05:40.833722+00', 'Gaelic College SCD Book #9: A Dozen in Hand', 'Dozen Hand', 2018, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (412, '2002-12-31 23:00:00+00', '2018-09-16 10:06:57.886114+00', 'Gaelic College SCD Book #10: Gordon Reels', 'Gordon Reels', 2018, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (466, '2002-12-31 23:00:00+00', '2019-09-13 14:50:27.525446+00', 'Whetherly Book 16', 'Whetherly 16', 270, 1, 0, 1, 1, NULL, NULL, 0, 'In the original book the dances are each printed on one or two pages. In this SCDDB record, the dances are numbered by page number.', 0, 1986);
INSERT INTO 'publication' VALUES (468, '2002-12-31 23:00:00+00', '2019-09-13 15:00:07.840142+00', 'Whetherly Book 18', 'Whetherly 18', 270, 1, 0, 1, 1, NULL, NULL, 0, 'In the original book the dances are each printed on one or two pages. In this SCDDB record, the dances are numbered by page number.', 0, 1986);
INSERT INTO 'publication' VALUES (470, '2002-12-31 23:00:00+00', '2019-09-13 15:11:46.957697+00', 'Whetherly Book 20', 'Whetherly 20', 270, 1, 0, 1, 1, NULL, NULL, 0, 'In the original book the dances are each printed on one or two pages. In this SCDDB record, the dances are numbered by page number.', 0, 1986);
INSERT INTO 'publication' VALUES (450, '2002-12-31 23:00:00+00', '2019-09-15 19:27:12.899981+00', 'Whetherly Scottish Country Dance Sheets', 'Whetherly Sheets', 270, 1, 0, 0, 1, NULL, NULL, 0, 'Numbered by sheet.', 0, 0000);
INSERT INTO 'publication' VALUES (476, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.670019+00', 'Ena Smith Memorial Booklet', 'Ena Smith', 166, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (485, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.729639+00', 'Hendersons Of Ardbrae, The', 'Hendersons', 7, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (491, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.777384+00', 'Kincaid Series of SCD', 'Kincaid', 213, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (492, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.78557+00', '1000 Fiddle Tunes', '1000 Fiddle', 2678, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (475, '2002-12-31 23:00:00+00', '2018-02-27 03:39:29.877309+00', 'Tenth Anniversary Collection', 'Tokyo: 10th Anniv.', 320, 1, 1, 1, 1, 202, '2018-02-27 03:39:29.873727+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (496, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.819386+00', 'Cockleroy Collection', 'Cockleroy', 101, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (500, '2002-12-31 23:00:00+00', '2018-02-27 21:00:08.686653+00', 'Cherry Blossom Book, The', '', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1998);
INSERT INTO 'publication' VALUES (499, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.844579+00', 'Medley For The Millennium, A', 'Cairngorm', 138, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (510, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.954028+00', 'Cameo Collection Book 10', 'Cameo 10', 35, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (511, '2002-12-31 23:00:00+00', '2012-01-20 12:55:54.962504+00', 'Cameo Collection Book 11', 'Cameo 11', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (502, '2002-12-31 23:00:00+00', '2013-04-10 08:15:18.003691+00', 'Cameo Collection Book 2', 'Cameo 2', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (503, '2002-12-31 23:00:00+00', '2013-04-10 08:15:36.775475+00', 'Cameo Collection Book 3', 'Cameo 3', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (481, '2002-12-31 23:00:00+00', '2021-06-20 19:51:26.813955+00', 'Scotland''s Dances', 'Thurston: Scotland', 392, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1954);
INSERT INTO 'publication' VALUES (505, '2002-12-31 23:00:00+00', '2013-04-10 08:16:17.490372+00', 'Cameo Collection Book 5', 'Cameo 5', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (506, '2002-12-31 23:00:00+00', '2013-04-10 08:16:48.597579+00', 'Cameo Collection Book 6', 'Cameo 6', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (507, '2002-12-31 23:00:00+00', '2013-04-10 08:17:08.557272+00', 'Cameo Collection Book 7', 'Cameo 7', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (509, '2002-12-31 23:00:00+00', '2013-04-10 08:18:05.372188+00', 'Cameo Collection Book 9', 'Cameo 9', 35, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (508, '2002-12-31 23:00:00+00', '2013-04-10 08:17:43.815618+00', 'Cameo Collection Book 8', 'Cameo 8', 35, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (489, '2002-12-31 23:00:00+00', '2013-07-23 18:06:19.357982+00', 'Dunedin Dances Book 3', 'Dunedin 3', 113, 1, 1, 1, 1, 146, '2009-06-06 19:20:20+00', 0, '', 0, 1993);
INSERT INTO 'publication' VALUES (519, '2002-12-31 23:00:00+00', '2018-02-27 21:00:46.788388+00', 'Greenburn Book, The', 'Greenburn', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1998);
INSERT INTO 'publication' VALUES (517, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.011826+00', 'Nova Scotia Collection', 'Nova Scotia', 39, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (518, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.020187+00', 'Clipper Ships And Other Dances', 'Clipper Ships', 23, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (520, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.037041+00', 'New Forest Scottish Country Dances Book 3', 'New Forest 3', 284, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (523, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.061824+00', 'Glenfinnan Book', 'Glenfinnan', 233, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (527, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.094816+00', 'Bonspiel Collection of Scottish Country Dances', 'Bonspiel', 249, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (528, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.10345+00', 'Mixture for All, A', 'Mixture', 684, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (490, '2002-12-31 23:00:00+00', '2017-01-20 04:46:06.497253+00', 'Dances from the Seven Year Itch', '7 Year Itch', 2677, 1, 0, 0, 1, 160, '2014-04-03 01:22:42+00', 0, '', 0, 1999);
INSERT INTO 'publication' VALUES (478, '2002-12-31 23:00:00+00', '2016-05-15 11:24:00.643015+00', 'Valleys of Dauphiné', 'Dauphiné', 17, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (494, '2002-12-31 23:00:00+00', '2016-05-21 21:59:05.533403+00', 'Seven Scottish Country Dances', 'Bolton 7', 2578, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1999);
INSERT INTO 'publication' VALUES (495, '2002-12-31 23:00:00+00', '2022-04-25 22:55:29.819838+00', 'Lothian Collection, The', 'Lothian', 101, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (411, '2002-12-31 23:00:00+00', '2022-05-07 21:04:18.024354+00', 'Gaelic College SCD Book #8: The Handy Dozen', 'The Handy Dozen', 2018, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (530, '2002-12-31 23:00:00+00', '2022-07-15 18:28:38.628566+00', 'Cameo Collection Book 21', 'Cameo 21', 35, 1, 0, 0, 1, NULL, NULL, 0, 'The dances may not be listed in the correct order.

', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (525, '2002-12-31 23:00:00+00', '2022-07-15 18:28:49.632992+00', 'Cameo Collection Book 22', 'Cameo 22', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (498, '2002-12-31 23:00:00+00', '2022-12-21 20:54:20.974457+00', 'TAC (Canada) Silver Anniversary Dances', 'TAC SIlver Anniv.', 380, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1984);
INSERT INTO 'publication' VALUES (486, '2002-12-31 23:00:00+00', '2023-01-20 22:19:49.770698+00', 'Martello Tower Book 4', 'Martello Tower 4', 215, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1990);
INSERT INTO 'publication' VALUES (484, '2002-12-31 23:00:00+00', '2023-01-20 22:20:03.191749+00', 'Martello Tower Book 3', 'Martello Tower 3', 215, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1986);
INSERT INTO 'publication' VALUES (483, '2002-12-31 23:00:00+00', '2023-01-20 22:20:17.955214+00', 'Martello Tower Book 2', 'Martello Tower 2', 215, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1984);
INSERT INTO 'publication' VALUES (482, '2002-12-31 23:00:00+00', '2023-01-20 22:21:07.531532+00', 'Martello Tower & Other Dances', 'Martello Tower Book 1', 215, 1, 0, 1, 1, NULL, NULL, 0, 'Further editions were published in 1981 and 1986.', 0, 1980);
INSERT INTO 'publication' VALUES (386, '2002-12-31 23:00:00+00', '2023-01-21 23:40:57.917963+00', 'Leaflet 33 Five Social Dances', 'RSCDS L33', 319, 1, 1, 0, 1, NULL, '2016-02-26 22:10:07+00', 0, '', 1, 1998);
INSERT INTO 'publication' VALUES (514, '2002-12-31 23:00:00+00', '2016-09-04 17:08:37.724072+00', 'Pinewoods Collection Vol 2', 'Pinewoods 2', 37, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (521, '2002-12-31 23:00:00+00', '2017-01-20 05:01:04.4067+00', 'Peerie, The', 'Peerie', 111, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1968);
INSERT INTO 'publication' VALUES (526, '2002-12-31 23:00:00+00', '2017-06-24 10:37:42.66548+00', 'Glasgow Assembly And Other Scottish Dances', 'Glasgow Ass.', 62, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1976);
INSERT INTO 'publication' VALUES (513, '2002-12-31 23:00:00+00', '2017-07-12 23:20:23.294817+00', 'Pinewoods Collection Vol 1', 'Pinewoods 1', 351, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1978);
INSERT INTO 'publication' VALUES (512, '2002-12-31 23:00:00+00', '2017-06-26 01:35:20.714482+00', 'Partners and Sets', 'Partners & Sets', 421, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1974);
INSERT INTO 'publication' VALUES (479, '2002-12-31 23:00:00+00', '2018-09-25 21:25:14.027816+00', 'Whitby Collection, The', 'Whitby', 2675, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1996);
INSERT INTO 'publication' VALUES (504, '2002-12-31 23:00:00+00', '2019-03-14 02:14:00.330321+00', 'Cameo Collection Book 4', 'Cameo 4', 35, 1, 0, 0, 1, 202, '2019-03-14 02:14:00.323372+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (472, '2002-12-31 23:00:00+00', '2019-09-13 15:15:11.412056+00', 'Whetherly Book 22', 'Whetherly 22', 270, 1, 0, 1, 1, NULL, NULL, 0, 'In the original book the dances are each printed on one or two pages. In this SCDDB record, the dances are numbered by page number.', 0, 1988);
INSERT INTO 'publication' VALUES (531, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.130909+00', 'New Forest Scottish Country Dances Book 2', 'New Forest 2', 284, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (532, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.139162+00', 'To Friendship', 'Friendship 1', 259, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (534, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.156658+00', 'Four SCD in Memory of Mary Nixon', 'Mary Nixon', 421, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (596, '2002-12-31 23:00:00+00', '2018-02-27 21:00:35.678414+00', 'Greenburn Book 2, The', 'Greenburn 2', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (537, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.184815+00', 'Hamilton and Clydesdale Book', 'Clydesdale', 2947, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (538, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.193011+00', 'Acme Collection', 'Acme', 520, 1, 1, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (539, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.201481+00', 'Jean Patrick Collection', 'Jean Patrick', 334, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1468, '2018-08-17 16:42:09.072572+00', '2018-08-17 16:42:09.072572+00', 'Second Collection of Strathspey Reels (by Malcolm MacDonald), A', '', 1486, 0, 1, 0, 0, NULL, NULL, 0, '', 0, 1789);
INSERT INTO 'publication' VALUES (541, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.218411+00', 'Fort Worden Decennial Dances', 'Fort Worden 10', 571, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (542, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.226751+00', 'Step Together', 'Springer: Step Tgthr', 366, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (543, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.234956+00', 'In Celebration', 'Merrimack: Celebr.', 266, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (567, '2002-12-31 23:00:00+00', '2018-06-18 11:41:29.869154+00', 'Five Anniversary Dances', '5 Anniv. Edin.', 119, 1, 1, 0, 1, 1978, '2016-10-12 12:23:50+00', 0, '', 0, 1999);
INSERT INTO 'publication' VALUES (590, '2002-12-31 23:00:00+00', '2019-04-15 21:30:20.498837+00', 'Southern Cross Album, The', 'Southern Cross', 44, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1967);
INSERT INTO 'publication' VALUES (546, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.259782+00', 'Kitchener-Waterloo Dances', 'Kitchener-W''Loo', 1010, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (549, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.284617+00', 'New Atholl Collection', 'New Atholl', 147, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (550, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.292816+00', 'Laurel Collection', 'Laurel', 380, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (556, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.343976+00', 'Crimson Heather', 'Crimson Heather', 232, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (557, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.353296+00', 'Ladyslipper Collection', 'Ladyslipper', 390, 1, 1, 0, 1, 203, '2009-10-26 03:42:15+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (558, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.361554+00', 'Don Mills Dances', 'Don Mills', 413, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (560, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.378258+00', 'Bridge Of Earn Collection', 'Bridge of Earn', 417, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (561, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.386671+00', 'Strathearn Collection', 'Strathearn', 417, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (516, '2002-12-31 23:00:00+00', '2021-02-28 17:33:31.22838+00', 'Yankee Sampler, A', 'Yankee', 37, 1, 0, 0, 1, 202, '2018-09-17 06:45:54+00', 0, '', 0, 1976);
INSERT INTO 'publication' VALUES (487, '2002-12-31 23:00:00+00', '2020-08-11 20:37:38.700275+00', 'Sixteen Scottish Country Dances', 'Thurston: 16 SCD', 392, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1967);
INSERT INTO 'publication' VALUES (458, '2002-12-31 23:00:00+00', '2021-06-25 09:43:21.504931+00', 'Whetherly Book 8', 'Whetherly 8', 270, 1, 0, 0, 1, NULL, NULL, 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages.  In this SCDDB record, the dances are numbered in succession, and not by page number.



A revised edition by Alison Mitchell (with assistance of Viktor Lehmann and Angelika Schmidkonz) was re-published online in 2021 as PDF on www.scd-germany.de.', 0, '1980-00-00');
INSERT INTO 'publication' VALUES (524, '2002-12-31 23:00:00+00', '2021-09-21 14:25:19.433961+00', 'Tenth Annual Ball SCD Collection', 'Kitchener - 10th Annual coll', 1010, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (563, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.404655+00', 'Plighted Troth, The', 'Plighted Troth', 296, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (572, '2002-12-31 23:00:00+00', '2019-05-16 13:36:27.378937+00', 'Barnardos Book 2 (later Charities Book 2)', 'Barnardos 2', 27, 1, 0, 0, 1, NULL, NULL, 0, 'The Barnardos Book 2 was later published as the Charities Book 2.', 0, 1990);
INSERT INTO 'publication' VALUES (566, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.42494+00', 'Islands Set, The', 'Islands Set', 276, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (571, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.456713+00', 'In Celebration Of Dance', 'Smith: Celebr. Dance', 361, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (575, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.484371+00', 'Cameo Collection Book 12', 'Cameo 12', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (576, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.490756+00', 'Cameo Collection Book 13', 'Cameo 13', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (577, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.497075+00', 'Cameo Collection Book 14', 'Cameo 14', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (636, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.879888+00', 'Miss Cynthia Mackay - a jig', 'Cynthis Mackay', 2795, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (559, '2002-12-31 23:00:00+00', '2014-10-06 13:06:07.650971+00', 'New Friends', 'New Friends', 395, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (548, '2002-12-31 23:00:00+00', '2014-10-06 13:07:50.610662+00', 'Blue Ribbon Collection', 'Blue Ribbon', 395, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1985);
INSERT INTO 'publication' VALUES (583, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.53525+00', 'Tribute to Norfolk Is.', 'Norfolk Island', 360, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (584, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.541964+00', 'Silver Threads (NZ Branch Twenty-fifth Anniversary)', 'Silver Threads', 287, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (585, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.548409+00', 'Valley Book Of Dances', 'Valley 1', 360, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (587, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.561205+00', 'Strathclyde Album, The', 'Strathclyde', 44, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (597, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.625767+00', 'NZ SC Dancer', 'NZ SC Dancer', 288, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (598, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.632128+00', 'Middle Earth Collection, The', 'Middle Earth', 334, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (536, '2002-12-31 23:00:00+00', '2015-06-02 12:53:16.731076+00', 'Dancing Through Nova Scotia', 'Dnc N. Scotia 1', 164, 1, 0, 0, 1, 105, '2015-06-02 12:53:16.729054+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (540, '2002-12-31 23:00:00+00', '2015-06-02 12:53:25.089339+00', 'Dancing Through Nova Scotia (Vol 2)', 'Dnc N. Scotia 2', 209, 1, 0, 0, 1, 105, '2015-06-02 12:53:25.087612+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (545, '2002-12-31 23:00:00+00', '2022-01-17 10:45:57.14437+00', 'Dance With a Friend: Eleven Dances from the Canadian Prairies', 'Dance With a Friend', 204, 1, 0, 0, 1, NULL, '2016-06-27 18:35:41+00', 0, '', 0, 1990);
INSERT INTO 'publication' VALUES (555, '2002-12-31 23:00:00+00', '2022-01-17 17:38:44.415194+00', 'Vancouver Collection', 'Vancouver', 399, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1986);
INSERT INTO 'publication' VALUES (552, '2002-12-31 23:00:00+00', '2022-04-14 22:28:18.623626+00', 'New York Branch Dances', 'New York', 286, 1, 0, 0, 1, 1558, '2022-04-14 22:28:18.618033+00', 0, '', 0, 1988);
INSERT INTO 'publication' VALUES (581, '2002-12-31 23:00:00+00', '2022-12-12 17:05:06.146346+00', 'Tenth Anniversary Collection', 'Portland: 10', 312, 1, 0, 0, 1, NULL, NULL, 0, 'One of the dances was devised in 1987, that was the basis for our guessed publication date.', 0, 1987);
INSERT INTO 'publication' VALUES (551, '2002-12-31 23:00:00+00', '2018-01-19 14:35:08.128981+00', 'Douglas Henderson Collection', 'Doug. Henderson', 380, 1, 0, 0, 1, NULL, NULL, 0, 'From what the booklet states, the collection must been published after the TAC Summer School in 1987, but this does not necessarily mean that it was published exactly the same year.', 0, 1987);
INSERT INTO 'publication' VALUES (570, '2002-12-31 23:00:00+00', '2016-10-26 10:47:04.87016+00', 'Chicago 10th Anniversary Collection', 'Chicago 10th', 76, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1990);
INSERT INTO 'publication' VALUES (595, '2002-12-31 23:00:00+00', '2016-12-23 22:17:52.018473+00', 'Kilmarnock Album, The', 'Kilmarnock', 44, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1991);
INSERT INTO 'publication' VALUES (593, '2002-12-31 23:00:00+00', '2016-12-23 22:01:05.038738+00', 'Cairdin'' O''t, The', 'The Cairdin'' O''t', 44, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1990);
INSERT INTO 'publication' VALUES (586, '2002-12-31 23:00:00+00', '2016-12-23 22:19:03.488309+00', 'Lord of the Rings Collection, The', 'Lord of the Rings', 44, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (594, '2002-12-31 23:00:00+00', '2016-12-23 22:20:02.77961+00', 'South Gate, The', 'South Gate', 44, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1991);
INSERT INTO 'publication' VALUES (589, '2002-12-31 23:00:00+00', '2016-12-23 22:28:12.518121+00', 'Strathtay Album, The', 'Strathtay', 44, 1, 1, 1, 1, NULL, NULL, 0, 'The Strathtay Album has been re-published in 1985.', 0, 1969);
INSERT INTO 'publication' VALUES (533, '2002-12-31 23:00:00+00', '2017-01-20 04:57:34.37052+00', 'New Brunswick Collection', 'New Brunswick', 133, 1, 0, 0, 1, 201, '2009-10-23 01:57:23+00', 0, '', 0, 1984);
INSERT INTO 'publication' VALUES (565, '2002-12-31 23:00:00+00', '2017-01-20 05:03:17.026302+00', 'Sweyn''s Ey Collection', 'Sweyn''s Ey', 2739, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1998);
INSERT INTO 'publication' VALUES (553, '2002-12-31 23:00:00+00', '2017-01-22 13:36:41.365072+00', 'Scottish Reels are Fun', 'SR are Fun', 2700, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (568, '2002-12-31 23:00:00+00', '2017-06-09 23:05:06.522618+00', '10th Anniversary Book of Dances [Peterborough]', 'Peterbro'' 10', 2745, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (601, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.654278+00', '25th Anniversary Dances', 'Nelson Anniversary', 283, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (602, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.660902+00', 'Ian Johnston Memorial Dances', 'Ian Johnston', 592, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (603, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.66728+00', 'Awatiro Set, The', 'Awatiro', 411, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (605, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.680015+00', 'Kauri Collection', 'Kauri', 14, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (606, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.686901+00', 'Bicentennial Book', 'Sydney: Bicentennial', 379, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (607, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.693238+00', 'Thistle And Vine, The', 'Thistle & Vine', 4, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (613, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.73164+00', 'Celebration Book, The', 'Jay: Celebration', 197, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (614, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.737962+00', 'Celtic Fringe, The', 'Celt. Fringe', 2773, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (615, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.744277+00', 'Kildonan SCD Sheets', 'Kildonan', 418, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (616, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.751452+00', 'Scottish Flavour Vol. 1', 'Scottish Flavour 1', 3645, 1, 0, 0, 1, 116, '2009-04-10 10:31:49+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (618, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.765246+00', 'East Ivanhoe Book', 'East Ivanhoe 1', 117, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (619, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.771666+00', 'East Ivanhoe Book 2 of SCD', 'East Ivanhoe 2', 117, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (620, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.778087+00', 'Light''s Vision', 'Light''s Vision', 94, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (621, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.784428+00', 'Glenfeshie Book II', 'Glenfeshie 2', 94, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (627, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.821419+00', 'Rant, The', 'The Rant', 188, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (628, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.828139+00', 'Jean Garvin Book', 'Jean Garvin', 188, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (629, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.834585+00', 'Edinburgh Lass, The', 'Edinburgh Lass', 197, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (635, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.873565+00', 'Saint Columban Book of SCD for Children', 'Saint Columban', 151, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (591, '2002-12-31 23:00:00+00', '2012-07-16 17:49:42.616766+00', 'Happy to Meet', 'Happy to Meet', 44, 1, 1, 1, 1, NULL, NULL, 0, 'Republished with corrections, 1985.', 0, 1977);
INSERT INTO 'publication' VALUES (637, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.886235+00', 'Just for Fun', 'Just For Fun', 225, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (579, '2002-12-31 23:00:00+00', '2020-05-14 11:10:53.818572+00', 'Cameo Collection Book 16', 'Cameo 16', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (580, '2002-12-31 23:00:00+00', '2020-09-14 09:24:21.261563+00', 'Island Games', 'Island Games', 303, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1991);
INSERT INTO 'publication' VALUES (609, '2002-12-31 23:00:00+00', '2021-07-04 15:38:03.223596+00', 'Southern Stars Book', 'Southern Stars', 156, 1, 0, 0, 1, NULL, NULL, 0, 'ISBN: 0-646-04374-9', 0, 1989);
INSERT INTO 'publication' VALUES (638, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.892552+00', 'Big and Little Sandy''s Book of SCD', 'Big & Little Sandy', 2796, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1469, '2018-08-17 16:48:27.657661+00', '2018-08-17 16:48:27.657661+00', 'Third Collection of Strathspey Reels (by Malcolm MacDonald), A', '', 1486, 0, 1, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (642, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.918569+00', 'Borealis Book, The', 'Borealis', 693, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (644, '2002-12-31 23:00:00+00', '2018-10-01 10:07:51.178537+00', 'Sue McKinnell''s Scottish Country Dances', 'Sue McKinnell', 2766, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (588, '2002-12-31 23:00:00+00', '2014-09-16 10:06:51.931566+00', 'Katherine''s Book', 'Katherine''s Book', 44, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1970);
INSERT INTO 'publication' VALUES (624, '2002-12-31 23:00:00+00', '2014-04-08 14:28:45.535371+00', 'Solstice Party Book, The', 'Solstice', 338, 1, 1, 1, 1, 160, '2014-04-08 14:24:33+00', 1, '', 0, 2000);
INSERT INTO 'publication' VALUES (649, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.968391+00', 'Glen Orrin Collection, The', 'Glen Orrin', 2892, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (650, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.975364+00', 'South African Scottish Country Dance Book, The', 'South African', 2813, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (651, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.981828+00', 'East Africa dances', 'East Africa', 556, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (652, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.988282+00', 'Eight Anniversary Dances', 'Johannesburg 8', 124, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (653, '2002-12-31 23:00:00+00', '2012-01-20 12:55:55.994636+00', '11 More South African Scottish Country Dances', 'South African+', 2813, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (654, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.000989+00', 'Newcastle Half Century 1950-2000, The', 'Newcastle 50', 289, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (659, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.033605+00', 'From the Redwood Forest', 'Redwood', 390, 1, 1, 1, 1, 203, '2009-10-26 03:31:49+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (661, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.04637+00', '3s, 4s & 5s', '3,4,5', 165, 1, 1, 0, 1, NULL, NULL, 0, 'Banchory SCDC', 0, 0000);
INSERT INTO 'publication' VALUES (663, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.059134+00', 'Duisburg Collection, The', 'Duisburg', 9998, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (646, '2002-12-31 23:00:00+00', '2015-07-13 02:48:42.439618+00', 'Collecta Ursis', 'Bears''', 2686, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (600, '2002-12-31 23:00:00+00', '2016-05-11 01:21:03.871814+00', 'All Kinds Of Everything', 'All Kinds of Everything', 44, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1987);
INSERT INTO 'publication' VALUES (623, '2002-12-31 23:00:00+00', '2016-02-26 22:07:14.558525+00', 'Book 41, The Millennium Dances', 'RSCDS XLI', 319, 1, 1, 0, 1, NULL, '2016-02-26 22:07:14.557756+00', 0, '', 1, 2000);
INSERT INTO 'publication' VALUES (662, '2002-12-31 23:00:00+00', '2017-05-02 17:50:04.043463+00', 'Aberdeen Collection, An', 'Aberdeen', 2850, 1, 1, 0, 0, NULL, NULL, 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (611, '2002-12-31 23:00:00+00', '2022-01-14 10:36:21.78007+00', 'Melbourne Dance Book Vol 2', 'Melbourne 2', 262, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1991);
INSERT INTO 'publication' VALUES (641, '2002-12-31 23:00:00+00', '2022-01-14 10:54:26.556722+00', 'Aotearoa Collection', 'Aotearoa', 287, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1983);
INSERT INTO 'publication' VALUES (645, '2002-12-31 23:00:00+00', '2022-07-15 18:29:01.309298+00', 'Cameo Collection Book 23', 'Cameo 23', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (639, '2002-12-31 23:00:00+00', '2023-01-04 23:38:12.375036+00', 'Hunter Valley Book of Dances', 'Hunter Valley', 188, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (657, '2002-12-31 23:00:00+00', '2023-01-20 22:19:18.744114+00', 'Martello Tower Book 6', 'Martello Tower 6', 215, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (633, '2002-12-31 23:00:00+00', '2023-01-20 22:19:34.795804+00', 'Martello Tower Book 5', 'Martello Tower 5', 215, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1999);
INSERT INTO 'publication' VALUES (655, '2002-12-31 23:00:00+00', '2016-05-25 14:29:45.535656+00', 'Wee Hoose on the Prairie', '', 2808, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (648, '2002-12-31 23:00:00+00', '2016-09-02 18:59:29.203428+00', 'Harbour City, The', 'Harbour City', 407, 1, 1, 1, 1, 1570, '2016-09-01 01:47:26+00', 0, '', 0, 1986);
INSERT INTO 'publication' VALUES (634, '2002-12-31 23:00:00+00', '2017-01-20 04:37:44.251403+00', 'Beyond The Black Stump - 16 SCD for Children', 'Beyond the Black Stump', 151, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (632, '2002-12-31 23:00:00+00', '2017-01-20 04:41:48.406686+00', 'Belhaven: Demonstration dance for four couples', 'Belhaven', 129, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1963);
INSERT INTO 'publication' VALUES (630, '2002-12-31 23:00:00+00', '2018-01-19 10:00:22.730936+00', 'Wells House and Other Strathspeys', 'Wells House', 146, 1, 1, 0, 1, 104, '2009-03-15 10:41:57+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (660, '2002-12-31 23:00:00+00', '2017-04-17 14:45:39.863047+00', 'Alamo Collection, The', 'Alamo', 2834, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (608, '2002-12-31 23:00:00+00', '2017-01-23 05:03:40.478973+00', 'Performance Dancing with The Red Thistle Dancers', 'Red Thistle', 2771, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (631, '2002-12-31 23:00:00+00', '2018-01-17 22:27:32.718635+00', 'Two Scottish Country Dances: Miss Jean Raeburn + Wheatly Hills', 'Foss: 2 SCD', 129, 1, 1, 0, 1, 160, '2014-04-02 14:05:29+00', 4, '', 0, 1968);
INSERT INTO 'publication' VALUES (667, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.086531+00', 'Side Steps', 'Side Steps', 366, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (668, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.092901+00', 'Atlanta Fare', 'Atlanta Fare', 12, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (673, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.139572+00', 'California Gold', 'California Gold', 348, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (677, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.172282+00', 'Kaleidoscope', 'Kaleidoscope', 23, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (679, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.189763+00', 'Farewell, My Fancy', 'Farewell M.F.', 62, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (680, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.198926+00', 'Alexander Dances Book 10', 'Alexander 10', 13, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (686, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.236485+00', 'To Friendship, Volume 2', 'Friendship 2', 259, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (709, '2002-12-31 23:00:00+00', '2018-02-27 20:58:26.243243+00', 'Bankhead Book Part 5', 'Bankhead 5', 108, 1, 0, 0, 1, NULL, '2016-02-26 22:06:39+00', 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (692, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.283073+00', 'Craigievar Book 4', 'Craigievar 4', 127, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (694, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.299412+00', 'Lone Star Collection', 'Lone Star', 2929, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (682, '2002-12-31 23:00:00+00', '2018-09-16 10:11:44.162032+00', 'Burns Night in the Annapolis Valley', 'Burns Night / Annapolis', 2018, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (684, '2002-12-31 23:00:00+00', '2013-01-24 15:14:19.733636+00', 'Turkish Set, The', 'Turkish', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (701, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.357046+00', 'Friends & Family', 'Friends & Family', 411, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (705, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.392089+00', 'Saint Marks Collection', 'Saint Marks', 368, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (708, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.420616+00', 'New Forest Scottish Country Dances', 'New Forest 1', 284, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (691, '2002-12-31 23:00:00+00', '2018-12-12 16:43:13.091052+00', 'World Around The Corner, The', 'World .. Corner', 44, 1, 1, 1, 1, 202, '2018-12-12 16:43:13.085141+00', 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (717, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.49523+00', 'Wateraid Set Dances', 'Wateraid', 404, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (704, '2002-12-31 23:00:00+00', '2013-07-23 18:06:57.524654+00', 'Dunedin Dances Book 4', 'Dunedin 4', 113, 1, 1, 0, 1, 146, '2009-06-06 19:20:42+00', 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (676, '2002-12-31 23:00:00+00', '2014-11-16 12:46:28.203805+00', 'Doune Collection No. 2', 'Doune 2', 9, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1998);
INSERT INTO 'publication' VALUES (666, '2002-12-31 23:00:00+00', '2013-07-23 18:18:38.417249+00', 'Dunedin Dances Book 5', 'Dunedin 5', 113, 1, 1, 0, 1, 146, '2009-06-06 19:21:12+00', 0, '', 0, 1999);
INSERT INTO 'publication' VALUES (658, '2002-12-31 23:00:00+00', '2014-09-04 13:28:26.840583+00', 'Reel Friends Book 2', 'Reel Friends 2', 104, 1, 1, 1, 1, 2088, '2014-09-04 13:28:26.83878+00', 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (696, '2002-12-31 23:00:00+00', '2019-11-18 01:21:58.477393+00', 'Stepping Stones', 'Stepping Stones', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1993);
INSERT INTO 'publication' VALUES (665, '2002-12-31 23:00:00+00', '2020-07-14 07:43:54.353668+00', 'Dawning, The', 'Dawning', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1999);
INSERT INTO 'publication' VALUES (656, '2002-12-31 23:00:00+00', '2021-03-10 17:24:52.394093+00', 'Swan River Selection', 'Swan River', 412, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (604, '2002-12-31 23:00:00+00', '2021-06-20 21:04:12.345627+00', 'Blue Book, The', 'Blue Book', 352, 1, 0, 0, 1, 1645, '2021-05-30 09:37:41+00', 0, '', 0, 1991);
INSERT INTO 'publication' VALUES (714, '2002-12-31 23:00:00+00', '2021-06-12 10:20:18.921556+00', 'Rose and Thistle Book', 'Rose & Thistle', 415, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (683, '2002-12-31 23:00:00+00', '2021-08-28 08:18:53.465343+00', 'Beyond 2000', 'Beyond 2000', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (723, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.541331+00', 'Valley Book 2', 'Valley 2', 360, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (720, '2002-12-31 23:00:00+00', '2019-05-16 13:31:33.216335+00', 'Charities Book 7', 'Charities 7', 27, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (728, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.583254+00', 'Dancing in the Haliburton Highlands', 'Haliburton', 67, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (730, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.59963+00', 'Passing the Porter and Other SCD', 'Passing the Porter', 425, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (731, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.60781+00', 'Chicago Collection of Basic Scottish Country Dances', 'Chicago Basic', 361, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (732, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.615989+00', 'Loch Soo Dances', 'Loch Soo', 2796, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (734, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.632318+00', 'Clan MacLeod Dances for Ceilidhs', 'Clan MacLeod Ceilidh', 356, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (745, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.723765+00', 'Summer Collection, Set 10', 'Drewry: Summer 10', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (685, '2002-12-31 23:00:00+00', '2016-01-31 00:33:17.760386+00', 'Pocket: Books 30,Children,5-for-1982,31', '30, Ch, 5-82, 31', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 1984);
INSERT INTO 'publication' VALUES (727, '2002-12-31 23:00:00+00', '2017-04-25 14:27:26.985288+00', 'Memories of Fife', 'Memories of Fife', 50, 1, 1, 1, 1, NULL, NULL, 0, 'Revised Edition 2014', 0, 2014);
INSERT INTO 'publication' VALUES (729, '2002-12-31 23:00:00+00', '2016-06-20 22:45:00.348605+00', 'West Toronto Ball Jigs', 'West Toronto Ball', 409, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (700, '2002-12-31 23:00:00+00', '2016-06-20 22:52:55.49811+00', 'Lion Rampant Book, The', 'Lion Rampant', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (698, '2002-12-31 23:00:00+00', '2016-06-20 22:54:26.5077+00', 'Pohutakawa Book, The', 'Pohutakawa', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1993);
INSERT INTO 'publication' VALUES (697, '2002-12-31 23:00:00+00', '2016-06-20 22:55:06.224636+00', 'Tiki Book, The', 'Tiki', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1993);
INSERT INTO 'publication' VALUES (695, '2002-12-31 23:00:00+00', '2016-06-20 22:55:41.057258+00', 'Kiwi Book, The', 'Kiwi', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1993);
INSERT INTO 'publication' VALUES (712, '2002-12-31 23:00:00+00', '2018-01-19 22:38:18.961461+00', 'Mainhattan Book, The', 'Mainhattan', 228, 1, 0, 0, 1, 1, '2009-03-13 13:54:15+00', 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (722, '2002-12-31 23:00:00+00', '2016-06-20 23:03:23.093057+00', 'Cameo Collection Book 17', 'Cameo 17', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (706, '2002-12-31 23:00:00+00', '2016-12-16 13:46:54.834333+00', 'Magic Medicine', 'Magic Med.', 2753, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (672, '2002-12-31 23:00:00+00', '2017-01-20 04:56:48.333545+00', 'Kitchen Capers', 'Kitchen Capers', 58, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (721, '2002-12-31 23:00:00+00', '2017-01-21 20:13:31.27174+00', 'Dance Till Dawn Once More', 'Dnc till Dawn 2', 272, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (815, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.237937+00', 'Glenshee Collection, (4)', 'Glenshee-91', 87, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (688, '2002-12-31 23:00:00+00', '2022-12-18 11:01:46.077474+00', 'Pocket: Books 32,Leaflets', '32, Lflts', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 1987);
INSERT INTO 'publication' VALUES (693, '2002-12-31 23:00:00+00', '2022-01-16 21:44:47.814619+00', 'Fare Thee Weel a While', 'Fare Thee Weel', 421, 1, 0, 0, 1, NULL, NULL, 0, 'Winnipeg Branch Silver Jubilee Book of Dances 1963-1988', 0, 1988);
INSERT INTO 'publication' VALUES (711, '2002-12-31 23:00:00+00', '2022-12-18 11:01:55.287933+00', 'Pocket: Books 33,34,35', '33, 34, 35', 319, 1, 0, 0, 1, 72, '2009-03-14 14:24:38+00', 0, '', 1, 1988);
INSERT INTO 'publication' VALUES (718, '2002-12-31 23:00:00+00', '2022-12-18 11:02:06.913843+00', 'Pocket: Books 36,37,38', '36, 37, 38', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 1995);
INSERT INTO 'publication' VALUES (671, '2002-12-31 23:00:00+00', '2023-01-18 16:53:32.702432+00', 'Badger''s Sett, The', 'Badgers', 550, 1, 0, 1, 0, 146, '2009-06-06 19:21:51+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (678, '2002-12-31 23:00:00+00', '2019-10-13 19:24:16.364489+00', '25th Anniversary 1966-1991 [Los Angeles]', 'Los Angeles 25th', 236, 1, 1, 1, 1, 104, '2011-08-23 09:50:04+00', 0, '', 0, 1991);
INSERT INTO 'publication' VALUES (746, '2002-12-31 23:00:00+00', '2017-11-06 22:24:09.535539+00', 'Autumn Collection 1984', 'Drewry: Autumn 84', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1984);
INSERT INTO 'publication' VALUES (716, '2002-12-31 23:00:00+00', '2017-11-13 10:11:55.028886+00', 'Baker''s Dozen, The (40th Anniversary)', 'Baker''s 12  (NA)', 292, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (736, '2002-12-31 23:00:00+00', '2018-01-19 12:14:22.129407+00', 'Twenty SCD by Alec Hay (Book 2)', 'Hay: 20 SCD 2', 2357, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (710, '2002-12-31 23:00:00+00', '2018-02-27 20:57:19.613337+00', 'Australian Book', 'Australian', 108, 1, 0, 0, 1, NULL, '2016-02-26 22:06:00+00', 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (880, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.682679+00', 'Jimmy Blair Album', 'Jimmy Blair', 1659, 0, 1, 1, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (713, '2002-12-31 23:00:00+00', '2012-08-20 23:33:54.497862+00', 'Merry Dancers Leaflets', 'Merry Dancers', 228, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (764, '2002-12-31 23:00:00+00', '2018-02-27 20:58:06.55249+00', 'Bankhead Book Part 2', 'Bankhead 2', 108, 1, 0, 0, 1, NULL, '2016-02-26 22:06:22+00', 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (726, '2002-12-31 23:00:00+00', '2013-01-31 00:57:17.693461+00', 'Wasatch Mountain Collection', 'Wasatch Mountain', 336, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (1470, '2018-08-17 16:50:36.201405+00', '2018-08-17 16:50:36.201405+00', 'Fourth Collection of Strathspey Reels (by Malcolm MacDonald), A', '', 1486, 0, 1, 0, 0, NULL, NULL, 0, '', 0, 1797);
INSERT INTO 'publication' VALUES (760, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.846349+00', 'Sunday Brunch', 'Sunday Brunch', 214, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (762, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.860189+00', 'Thistle Dubh Two', 'Thistle Dubh 2', 272, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (767, '2002-12-31 23:00:00+00', '2018-09-16 10:08:07.809798+00', 'Gaelic College SCD Book #11: Three Dozen', 'Three Dozen', 2018, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (765, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.887441+00', 'Allan''s Reels, Strathspeys and General Dance Music', 'Allan''s', 277, 0, 1, 1, 1, NULL, '2011-01-01 04:04:53+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (766, '2002-12-31 23:00:00+00', '2012-01-20 12:55:56.895682+00', 'Jimmy Shand Album of Old Time Dance Music, The', 'Jimmy Shand', 1558, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (768, '2006-03-23 23:00:00+00', '2012-01-20 12:55:56.912527+00', 'Golden Collection, A', 'Hamilton Golden', 166, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (769, '2006-05-11 22:00:00+00', '2012-01-20 12:55:56.920711+00', 'Dances for Friends Five', 'Friends 5', 1445, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (774, '2006-08-24 22:00:00+00', '2012-01-20 12:55:56.964209+00', 'Blackwater Collection of SCD, The', 'Blackwater', 831, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (779, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.006215+00', 'Bobby Macleod''s Country Dance Tunes', 'Bobby MacLeod', 3058, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (780, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.014398+00', 'Snowdon Book, The', 'Snowdon', 434, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (738, '2002-12-31 23:00:00+00', '2013-04-10 09:09:29.719717+00', 'Summer Collection, Set 3', 'Drewry: Summer 3', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (740, '2002-12-31 23:00:00+00', '2013-04-10 09:09:44.252063+00', 'Summer Collection, Set 5', 'Drewry: Summer 5', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (742, '2002-12-31 23:00:00+00', '2013-04-10 09:10:15.770691+00', 'Summer Collection, Set 7', 'Drewry: Summer 7', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (743, '2002-12-31 23:00:00+00', '2013-04-10 09:10:33.370449+00', 'Summer Collection, Set 8', 'Drewry: Summer 8', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (744, '2002-12-31 23:00:00+00', '2013-04-10 09:10:49.1609+00', 'Summer Collection, Set 9', 'Drewry: Summer 9', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (725, '2002-12-31 23:00:00+00', '2014-11-16 12:45:59.445432+00', 'Doune Collection', 'Doune', 9, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (783, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.0365+00', 'Kerr''s Caledonian Collection', 'Kerr''s Caled.', 1916, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (784, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.044698+00', 'Arnside Collection, The', 'Arnside', 534, 1, 0, 1, 1, NULL, '2010-08-18 22:03:53+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (785, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.05288+00', 'Rhone Valley Dances', 'Rhone Valley', 17, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (782, '2002-12-31 23:00:00+00', '2021-02-28 14:10:18.502372+00', 'Milwaukee Scottish Country Dance and Romance', 'Milwaukee', 2971, 1, 0, 1, 1, 202, '2021-02-28 02:22:19+00', 0, '', 0, 2001);
INSERT INTO 'publication' VALUES (674, '2002-12-31 23:00:00+00', '2021-07-11 15:57:31.817371+00', '25 Dances for 25 Years', 'Ottawa 25', 299, 1, 0, 0, 1, NULL, NULL, 0, 'Dances devised by members of the RSCDS Ottawa branch in celebration of the Branch''s 25th anniversary 1991.', 0, 1991);
INSERT INTO 'publication' VALUES (776, '2002-12-31 23:00:00+00', '2021-09-05 10:25:05.597862+00', 'Old Scottish Music collected and adapted for SCD', 'Annie Shand', 2963, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 1932);
INSERT INTO 'publication' VALUES (794, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.128194+00', 'Gatineau Gathering, A', 'Gatineau', 299, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (800, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.169696+00', 'Bruce Collection, The', 'Bruce 1', 1582, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (802, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.180487+00', 'Craigievar Book 3', 'Craigievar 3', 127, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (786, '2002-12-31 23:00:00+00', '2015-03-27 16:34:54.562721+00', 'For Your Dancing Pleasure', 'Kentucky Dancing Pleasure', 437, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (741, '2002-12-31 23:00:00+00', '2015-07-13 16:28:29.836849+00', 'Summer Collection, Set 6', 'Drewry: Summer 6', 108, 1, 0, 0, 1, NULL, '2015-07-13 16:28:29.835117+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (803, '2002-12-31 23:00:00+00', '2015-09-16 03:03:08.013+00', 'Six Scottish Country Dances', 'Cosh: 6 SCD', 87, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1959);
INSERT INTO 'publication' VALUES (751, '2002-12-31 23:00:00+00', '2015-10-04 12:31:31.81022+00', 'Summer Collection 1986', 'Drewry: Summer 86', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1986);
INSERT INTO 'publication' VALUES (777, '2002-12-31 23:00:00+00', '2017-01-20 05:05:53.111209+00', 'Tweeddale Collection, Volume 2', 'Tweeddale 2', 154, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1996);
INSERT INTO 'publication' VALUES (791, '2002-12-31 23:00:00+00', '2016-06-20 22:56:22.448224+00', 'Dances and Dreams', 'Dances and Dreams', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (749, '2002-12-31 23:00:00+00', '2017-11-06 22:21:24.035166+00', 'Summer Collection 1984', 'Drewry:  Summer 84', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1984);
INSERT INTO 'publication' VALUES (699, '2002-12-31 23:00:00+00', '2016-06-20 22:43:48.169885+00', 'Dolphin Book, The', 'Dolphin', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (793, '2002-12-31 23:00:00+00', '2018-01-19 12:14:13.10051+00', 'Twenty SCD by Alec Hay (Book 3)', 'Hay: 20 SCD 3', 2357, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1996);
INSERT INTO 'publication' VALUES (798, '2002-12-31 23:00:00+00', '2016-06-20 23:04:54.952717+00', 'Macramé and 14 Additional SCD', 'Macramé', 441, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (733, '2002-12-31 23:00:00+00', '2017-01-20 00:51:23.893372+00', 'Greenburn Book 3, The', 'Greenburn 3', 108, 1, 0, 0, 1, NULL, '2013-08-09 05:35:16+00', 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (763, '2002-12-31 23:00:00+00', '2017-01-21 12:54:29.305545+00', 'Carnforth Collection of SC Dances 3', 'Carnforth 3', 2, 1, 0, 0, 1, 106, '2009-03-13 21:58:09+00', 3, 'First published in March 1996, it was reprinted in November 2004.', 0, 1996);
INSERT INTO 'publication' VALUES (737, '2002-12-31 23:00:00+00', '2017-05-01 13:03:27.715954+00', 'Summer Collection, Set 2', 'Drewry: Summer 2', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (747, '2002-12-31 23:00:00+00', '2017-11-03 22:01:16.821887+00', '2001: A Dance Odyssey', '', 2936, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (750, '2002-12-31 23:00:00+00', '2017-11-06 22:21:37.459881+00', 'Summer Collection 1985', 'Drewry: Summer 85', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1985);
INSERT INTO 'publication' VALUES (753, '2002-12-31 23:00:00+00', '2017-11-06 22:21:50.357579+00', 'Summer Collection 1988', 'Drewry: Summer 88', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1988);
INSERT INTO 'publication' VALUES (754, '2002-12-31 23:00:00+00', '2017-11-06 22:22:14.508181+00', 'Summer Collection 1989', 'Drewry: Summer 89', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1989);
INSERT INTO 'publication' VALUES (748, '2002-12-31 23:00:00+00', '2017-11-06 22:23:53.811743+00', 'Autumn Collection 1986', 'Drewry: Autumn 86', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1986);
INSERT INTO 'publication' VALUES (790, '2002-12-31 23:00:00+00', '2017-12-20 11:52:10.460265+00', 'Celtic Book, The', 'Celtic Book (Skelton)', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (814, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.231472+00', 'Twenty Two SCD and Two Others', '22 + 2', 87, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (770, '2006-05-11 22:00:00+00', '2022-07-17 13:02:31.445081+00', 'Lochiel Collection, The', 'Lochiel', 725, 1, 0, 0, 1, 2569, '2015-05-25 04:02:15+00', 0, '', 0, 2005);
INSERT INTO 'publication' VALUES (778, '2002-12-31 23:00:00+00', '2022-09-30 16:50:31.995828+00', 'Graded and Social Dances 2 - 23 Dances', 'Goldring Graded 2', 146, 1, 1, 0, 1, 108, '2009-03-18 21:49:27+00', 0, '', 0, 1996);
INSERT INTO 'publication' VALUES (724, '2006-02-16 23:00:00+00', '2022-12-08 22:40:43.069442+00', 'Reel for Alice and Other Social Dances, A', 'Reel for Alice', 146, 1, 1, 1, 1, NULL, '2016-02-26 22:10:42+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (781, '2002-12-31 23:00:00+00', '2022-12-18 11:02:19.140538+00', 'Pocket: Books 39,40,41', '39,40,41', 319, 1, 0, 0, 1, 72, '2009-03-14 14:24:05+00', 0, '', 1, 2001);
INSERT INTO 'publication' VALUES (792, '2002-12-31 23:00:00+00', '2023-01-13 15:16:45.63259+00', 'Alpine Valley Dances', 'Alpine', 17, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (816, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.24435+00', 'Glenshee Collection, (3)', 'Glenshee-91', 87, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (817, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.250889+00', 'Glenshee Collection, (2)', 'Glenshee-91', 87, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (819, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.264276+00', 'Silver Anniversary Book of Dances', 'Silver Anniv.', 3082, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (845, '2002-12-31 23:00:00+00', '2018-02-27 21:02:41.133928+00', 'Stoneywood Collection, The', 'Stoneywood', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2002);
INSERT INTO 'publication' VALUES (881, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.689083+00', 'MacPhail Collection 1', 'MacPhail', 1527, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (882, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.695851+00', 'Sherrit - 4th Collection', 'Sherrit 4', 1538, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (863, '2002-12-31 23:00:00+00', '2018-03-31 22:20:05.838353+00', '20th Anniversary Dance Booklet', 'Portland: 20th', 312, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (830, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.336999+00', 'Pawprints', 'Pawprints', 334, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (831, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.343467+00', 'Dunnington Collection Volume 2, The', 'Dunnington 2', 3205, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (834, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.362473+00', 'Deeside Collection', 'Deeside (Bell)', 28, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (835, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.36886+00', 'Golden Links', 'Golden Links', 28, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (838, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.388118+00', 'Snowdon Book 2', 'Snowdon 2', 434, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (822, '2002-12-31 23:00:00+00', '2013-10-04 11:07:21.578484+00', 'Skye Collection Vol 2, The', 'Skye 2', 357, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2001);
INSERT INTO 'publication' VALUES (787, '2002-12-31 23:00:00+00', '2014-11-16 17:20:40.199381+00', 'Cross-Country Capers', '', 58, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1996);
INSERT INTO 'publication' VALUES (859, '2002-12-31 23:00:00+00', '2018-12-21 09:38:50.060097+00', 'Snowdon Book, The Third Collection', 'Snowdon 3', 434, 1, 0, 0, 0, 202, '2018-12-20 20:19:34+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (827, '2002-12-31 23:00:00+00', '2019-05-16 13:12:04.26614+00', 'Charities Book 11', 'Charities 11', 27, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1999);
INSERT INTO 'publication' VALUES (828, '2002-12-31 23:00:00+00', '2019-05-16 13:12:52.852709+00', 'Charities Book 12', 'Charities 12', 27, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (826, '2002-12-31 23:00:00+00', '2019-05-16 13:17:23.63332+00', 'Charities Book 10', 'Charities 10', 27, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1997);
INSERT INTO 'publication' VALUES (851, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.486426+00', 'Laurieston Collection, The', 'Laurieston', 2673, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (825, '2002-12-31 23:00:00+00', '2019-05-16 13:25:33.807451+00', 'Charities Book 6 (Door Still Open)', 'Charities 6', 27, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (854, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.514905+00', 'Dance Around this One', 'Dance Around', 3225, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (855, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.522437+00', 'Our Kind of Music', 'Our Kind of Music', 3225, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (795, '2002-12-31 23:00:00+00', '2021-03-18 20:44:08.933333+00', 'Saint Andrews of Brampton Book 1', 'Brampton 1', 440, 1, 0, 0, 1, 202, '2021-03-18 20:44:08.924672+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (853, '2002-12-31 23:00:00+00', '2021-09-19 22:39:35.212774+00', 'All Around the Circle', 'All Around', 3225, 1, 1, 1, 1, 104, '2011-08-23 12:52:23+00', 0, '', 0, 2002);
INSERT INTO 'publication' VALUES (755, '2002-12-31 23:00:00+00', '2021-06-20 21:02:59.51663+00', 'Green Book, The', 'Green Book', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1991);
INSERT INTO 'publication' VALUES (757, '2002-12-31 23:00:00+00', '2021-06-20 21:03:24.988984+00', 'Red Book, The', 'Red Book', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1991);
INSERT INTO 'publication' VALUES (789, '2002-12-31 23:00:00+00', '2021-06-23 17:32:43.762745+00', 'For Old Tymes Sake', 'For Old Tymes Sake', 215, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1997);
INSERT INTO 'publication' VALUES (756, '2002-12-31 23:00:00+00', '2021-09-12 14:23:31.010497+00', 'Yellow Book, The', 'Yellow Book', 352, 1, 0, 0, 1, 202, '2021-09-12 14:23:31.00286+00', 0, '', 0, 1992);
INSERT INTO 'publication' VALUES (856, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.528995+00', 'Jolly Mixtures', 'Jolly Mixtures', 165, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (860, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.55491+00', 'Go Out With a Smile', 'Smile', 3257, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (862, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.567565+00', 'Canterbury Tales', 'Canterbury', 3258, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (864, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.58029+00', 'Carrick Collection of SCD - Book 1', 'Carrick 1', 3117, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (773, '2006-07-02 22:00:00+00', '2015-03-27 16:23:53.283419+00', 'Birmingham Diamond Jubilee Dance Book - 1946-2006', 'Birmingham Diamond 2006', 32, 1, 1, 1, 1, 81, '2015-03-11 15:50:07+00', 0, '', 0, 2006);
INSERT INTO 'publication' VALUES (843, '2002-12-31 23:00:00+00', '2019-08-23 00:55:33.799457+00', '50 Anniversary Book of Dances', 'Sydney 50', 379, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2002);
INSERT INTO 'publication' VALUES (818, '2002-12-31 23:00:00+00', '2015-09-16 03:03:57.679512+00', 'Fifteen Scottish Country Dances', 'Cosh: 15 SCD', 87, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1964);
INSERT INTO 'publication' VALUES (805, '2002-12-31 23:00:00+00', '2016-01-31 00:15:48.703514+00', 'Pocket: Books 7,8,9', '7, 8, 9', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 1932);
INSERT INTO 'publication' VALUES (808, '2002-12-31 23:00:00+00', '2016-01-31 00:24:47.870847+00', 'Pocket: Books 16,17,18', '16,17,18', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 1956);
INSERT INTO 'publication' VALUES (809, '2002-12-31 23:00:00+00', '2016-01-31 00:26:29.578811+00', 'Pocket: Books 19,20,21', '19, 20, 21', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 1962);
INSERT INTO 'publication' VALUES (813, '2002-12-31 23:00:00+00', '2016-01-31 00:30:57.744625+00', 'Pocket: Books 28,4-for-1978,29', '28, 4-78, 29', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 1980);
INSERT INTO 'publication' VALUES (857, '2002-12-31 23:00:00+00', '2019-05-16 13:42:01.054859+00', 'Charities Book 13 (Baker''s Dozen)', 'Charities 13', 27, 1, 0, 0, 1, NULL, NULL, 0, 'The Charities Book 13 was originally published as The Baker''s Dozen Book.', 0, 2002);
INSERT INTO 'publication' VALUES (836, '2002-12-31 23:00:00+00', '2016-05-12 00:03:59.336776+00', 'Pleasure of your Company, The', '', 1391, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (797, '2002-12-31 23:00:00+00', '2016-05-29 06:18:40.091408+00', 'Twenty Years Twenty Dances', '', 395, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (832, '2002-12-31 23:00:00+00', '2017-05-19 21:26:57.068614+00', 'Bristol 40th Anniversary Book of SCD, The', 'Bristol 40th', 3164, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2002);
INSERT INTO 'publication' VALUES (829, '2002-12-31 23:00:00+00', '2016-09-06 21:38:22.6859+00', 'Croaghpatrick Collection, The', 'Croaghpatrick', 28, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (821, '2002-12-31 23:00:00+00', '2017-01-21 12:49:18.547542+00', 'Carnforth Collection of SC Dances 5', 'Carnforth 5', 175, 1, 0, 0, 1, 106, '2009-03-13 21:58:24+00', 3, 'First published in March 2002, it was reprinted in March 2003.', 0, 2002);
INSERT INTO 'publication' VALUES (824, '2002-12-31 23:00:00+00', '2017-01-21 13:22:29.531357+00', 'Loreburn Dances Book Four', 'Loreburn IV', 200, 1, 0, 0, 1, NULL, NULL, 0, 'The original publication date seems unknown, but there was a reprinted edition in 2007.', 0, 2007);
INSERT INTO 'publication' VALUES (858, '2002-12-31 23:00:00+00', '2017-04-21 20:48:35.875903+00', 'Leeds Branch, 25th Children''s Festival', 'Leeds Children''s', 223, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2002);
INSERT INTO 'publication' VALUES (849, '2002-12-31 23:00:00+00', '2017-12-03 19:34:45.398643+00', 'Dancing Thistles, The', 'Dancing Thistles', 3208, 1, 0, 1, 1, 202, '2017-12-03 19:34:45.395003+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (842, '2002-12-31 23:00:00+00', '2018-01-19 12:13:28.637545+00', 'Twelve SCD by Alec Hay (Book 6)', 'Hay: 12 SCD 6', 2357, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1997);
INSERT INTO 'publication' VALUES (844, '2002-12-31 23:00:00+00', '2022-07-17 12:58:33.695395+00', 'Dancing Feet', 'Dancing Feet', 725, 1, 0, 0, 1, 2569, '2015-05-25 03:40:11+00', 0, '', 0, 2002);
INSERT INTO 'publication' VALUES (846, '2002-12-31 23:00:00+00', '2022-07-17 12:59:14.911449+00', 'One Step at a Time', 'One Step', 725, 1, 0, 0, 1, 2569, '2015-05-25 03:46:34+00', 0, '', 0, 2004);
INSERT INTO 'publication' VALUES (847, '2002-12-31 23:00:00+00', '2022-07-17 12:59:57.588647+00', 'Saint Abb''s Collection, The', 'St. Abb''s', 725, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (848, '2002-12-31 23:00:00+00', '2022-07-17 13:01:24.670626+00', 'Weird But Wonderful', 'Weird', 725, 1, 0, 0, 1, 2569, '2015-05-25 04:00:00+00', 0, '', 0, 2003);
INSERT INTO 'publication' VALUES (801, '2002-12-31 23:00:00+00', '2022-12-21 21:30:02.102129+00', 'Leaflet 32', 'RSCDS L32', 319, 1, 1, 0, 1, NULL, '2016-02-26 22:10:00+00', 0, 'Publication subtitle: "Four modern dances chosen from a selection submitted by Scottish Local Associations"', 1, 1997);
INSERT INTO 'publication' VALUES (806, '2002-12-31 23:00:00+00', '2022-12-18 11:00:30.02587+00', 'Pocket: Books 10,11,12', '10, 11, 12', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 1941);
INSERT INTO 'publication' VALUES (807, '2002-12-31 23:00:00+00', '2022-12-18 11:00:45.473283+00', 'Pocket: Books 13,14,15', '13, 14, 15', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 1950);
INSERT INTO 'publication' VALUES (812, '2002-12-31 23:00:00+00', '2022-12-18 11:01:19.837368+00', 'Pocket: Books 25,26,27', '25, 26, 27', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 1976);
INSERT INTO 'publication' VALUES (804, '2002-12-31 23:00:00+00', '2022-12-18 11:02:34.899827+00', 'Pocket: Books 4,5,6', '4, 5, 6', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 1930);
INSERT INTO 'publication' VALUES (811, '2002-12-31 23:00:00+00', '2022-12-18 11:04:07.257528+00', 'Pocket: Books Five for 1965,23,24', '5/65, 23, 24', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 1969);
INSERT INTO 'publication' VALUES (870, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.618931+00', 'Gie''s an A', 'Gie''s an A', 1710, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (871, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.625238+00', 'Ringing Strings', 'Ringing Strings', 1710, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (872, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.631803+00', 'Leaside Collection', 'Leaside', 1634, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (875, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.650774+00', 'Fitchet SD Collection', 'Fitchet SD Coll', 1554, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (936, '2004-09-08 22:00:00+00', '2018-02-27 21:02:27.354275+00', 'Stoneywood Collection Volume 2', 'Stoneywood 2', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2004);
INSERT INTO 'publication' VALUES (878, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.669882+00', 'Music for SD Band Vol 1', 'Music for SD', 2362, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (879, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.676352+00', 'Spootiskerry', 'Spootiskerry', 1724, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (850, '2002-12-31 23:00:00+00', '2012-12-31 18:58:52.073398+00', 'Helensburgh Golden Jubilee Dance Book, The', 'Helensburgh Gold', 3209, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (873, '2002-12-31 23:00:00+00', '2013-01-06 19:31:09.833731+00', 'Melrose Collection 1', 'Melrose 1', 1490, 0, 1, 1, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (869, '2002-12-31 23:00:00+00', '2013-01-06 22:19:13.052803+00', 'Harp and Claymore', 'Harp & Claymore', 9998, 0, 1, 1, 1, NULL, NULL, 0, 'Published by Bayley and Ferguson in 1904.  Edited by Gavin Greig.



Aberdeen University Scott Skinner website allows access to all of tunes in this collection.', 0, '1904-00-00');
INSERT INTO 'publication' VALUES (923, '2003-11-18 23:00:00+00', '2018-05-30 10:24:58.505948+00', 'Galloway Hills Set, The', 'Galloway Hills', 129, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (886, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.72135+00', 'Maldon Miscellany', 'Maldon Misc', 3307, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (887, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.727678+00', 'New Zealand 2001', 'NZ 2001', 3307, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (888, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.734139+00', 'Maldon Eightsome', 'Maldon 8', 3307, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (889, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.740456+00', 'Maldon Memories', 'Maldon Mem', 3307, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (917, '2005-01-27 23:00:00+00', '2018-07-25 21:56:50.734285+00', 'Third Kirkbrae Collection, The', 'Kirkbrae 3', 692, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2004);
INSERT INTO 'publication' VALUES (890, '2002-12-31 23:00:00+00', '2012-01-20 12:55:57.747294+00', 'Newburgh Boyhood', 'Newburgh', 3307, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (895, '2003-02-17 23:00:00+00', '2012-01-20 12:55:57.780186+00', 'Awa'' Tae the Borders', 'Ama'' Borders', 273, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (896, '2005-04-14 22:00:00+00', '2012-01-20 12:55:57.786534+00', 'Golden Anniversary Commemorative Booklet', 'Harpenden 50', 3532, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (897, '2003-02-28 23:00:00+00', '2012-01-20 12:55:57.792851+00', 'Glen Orrin Collection 2, The', 'Glen Orrin 2', 2892, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (899, '2003-03-17 23:00:00+00', '2012-01-20 12:55:57.805617+00', '40th Anniversary Collection', '', 2181, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (900, '2003-04-21 22:00:00+00', '2012-01-20 12:55:57.811943+00', 'Happy Dancing', '', 360, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (902, '2003-05-04 22:00:00+00', '2012-01-20 12:55:57.824692+00', 'Bruce Collection, Volume 3, The', 'Bruce 3', 1582, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (904, '2003-05-06 22:00:00+00', '2012-01-20 12:55:57.838435+00', 'Bruce Collection, Volume 2, The', 'Bruce 2', 1582, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (906, '2003-05-14 22:00:00+00', '2012-01-20 12:55:57.851101+00', 'Bothwell Collection, The', 'Bothwell', 9998, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (907, '2003-06-02 22:00:00+00', '2012-01-20 12:55:57.857477+00', 'Valley Book 3', 'Valley 3', 360, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (908, '2003-06-02 22:00:00+00', '2012-01-20 12:55:57.863824+00', 'Skelton Book of 14 SCD', 'Skelton', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (914, '2003-08-28 22:00:00+00', '2012-01-20 12:55:57.901375+00', 'Golden Anniversary Book 1951-2001', '', 124, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (915, '2003-08-28 22:00:00+00', '2012-01-20 12:55:57.908354+00', 'Peaks and Valleys', 'Peaks/Valleys', 17, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (916, '2003-08-28 22:00:00+00', '2012-01-20 12:55:57.914965+00', 'Scots in France', 'Scots in France', 17, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (920, '2003-09-15 22:00:00+00', '2012-01-20 12:55:57.944873+00', 'Double H Collection, The', 'Double H', 553, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (852, '2002-12-31 23:00:00+00', '2020-07-24 06:33:45.716929+00', 'Wee Hoose on the Mississippi', '', 2808, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (921, '2003-10-30 23:00:00+00', '2012-01-20 12:55:57.951266+00', 'Dances for Friends Three', 'Friends 3', 1445, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (922, '2003-11-18 23:00:00+00', '2012-01-20 12:55:57.957573+00', 'Two SCD', 'Clingan 2', 81, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1467, '2018-08-17 16:38:40.348192+00', '2018-08-17 17:06:16.548177+00', 'Collection of Strathspey Reels (by Malcolm MacDonald), A', '', 1486, 0, 1, 0, 0, NULL, NULL, 0, 'The tune list is still incomplete!!!', 0, 1788);
INSERT INTO 'publication' VALUES (892, '2002-12-31 23:00:00+00', '2012-05-03 19:00:58.557101+00', 'ISCA Royal Golden Jubilee Collection', 'ISCA 50', 3313, 1, 0, 0, 1, NULL, '2012-05-03 19:00:58.55356+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (927, '2004-01-26 23:00:00+00', '2012-01-20 12:55:57.991631+00', 'Opening Knight', 'Opening Knight', 1829, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (929, '2004-02-08 23:00:00+00', '2012-01-20 12:55:58.004446+00', 'Gray Collection SCD, Book I', 'Gray 1', 3432, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (933, '2004-07-06 22:00:00+00', '2012-01-20 12:55:58.034769+00', 'Ladies'' Book', 'Ladies', 619, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (937, '2004-10-31 23:00:00+00', '2012-01-20 12:55:58.066348+00', 'Dancers'' Choice 2', 'Dancers'' Choice 2', 3039, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (940, '2004-11-01 23:00:00+00', '2012-01-20 12:55:58.085337+00', 'Dances for Friends Four', 'Friends 4', 1445, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (941, '2004-11-21 23:00:00+00', '2012-01-20 12:55:58.091634+00', 'Alba Smiles Better', 'Alba Smiles', 2937, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (942, '2004-11-25 23:00:00+00', '2012-01-20 12:55:58.097999+00', 'Gray Collection SCD, Book II', 'Gray 2', 3432, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (944, '2004-12-06 23:00:00+00', '2012-01-20 12:55:58.110724+00', 'Corryvrechan Social Dances 2', '', 3479, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (945, '2004-12-13 23:00:00+00', '2012-01-20 12:55:58.117013+00', 'Dance Devisers Days 2001', 'DDD 2001', 3487, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (946, '2005-02-04 23:00:00+00', '2012-01-20 12:55:58.123635+00', 'Gordon''s Dance Booklet No. 1', '', 3345, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (841, '2005-06-19 22:00:00+00', '2016-02-26 22:07:35.141198+00', 'Book 45', 'RSCDS XLV', 319, 1, 1, 0, 1, NULL, '2016-02-26 22:07:35.140439+00', 0, '', 1, 2005);
INSERT INTO 'publication' VALUES (866, '2002-12-31 23:00:00+00', '2016-02-22 21:54:12.646326+00', 'Tweeddale Collection, Volume 3', 'Tweeddale 3', 154, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2002);
INSERT INTO 'publication' VALUES (891, '2002-12-31 23:00:00+00', '2016-02-20 13:57:26.483385+00', 'Charities Book 14', 'Charities 14', 27, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2002);
INSERT INTO 'publication' VALUES (911, '2003-06-26 22:00:00+00', '2016-02-26 22:07:25.309014+00', 'Book 43, Golden Jubilee Dances', 'RSCDS XLIII', 319, 1, 1, 0, 0, NULL, '2016-02-26 22:07:25.307763+00', 0, '', 1, 2003);
INSERT INTO 'publication' VALUES (912, '2003-07-06 22:00:00+00', '2016-07-25 01:15:23.681449+00', 'Gauldry Group, The', 'Gauldry', 48, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (909, '2003-06-02 22:00:00+00', '2016-05-20 19:38:54.979501+00', 'Celebration (Skelton), A', 'Celebration (Skelton)', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (934, '2004-07-06 22:00:00+00', '2016-09-02 19:49:06.252936+00', 'Queen Collection of SCD Vol 1', 'Queen 1', 316, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (910, '2003-06-11 22:00:00+00', '2017-01-23 04:42:26.263764+00', 'Ivy Thew Memorial Collection, The', 'Ivy Thew', 14, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2003);
INSERT INTO 'publication' VALUES (938, '2004-10-31 23:00:00+00', '2017-10-09 15:42:23.095553+00', 'Dancing Tour Volume 2, A', 'Dancing Tour 2', 479, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2004);
INSERT INTO 'publication' VALUES (943, '2004-11-28 23:00:00+00', '2017-07-23 14:36:14.018903+00', 'New Ruthven Collection of SCD, The', 'Ruthven 2', 2419, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2004);
INSERT INTO 'publication' VALUES (885, '2002-12-31 23:00:00+00', '2018-01-19 10:31:43.424162+00', 'Merse Companion Tunebook, The', 'Merse Tunebook', 340, 0, 1, 1, 1, NULL, '2016-11-21 18:33:04+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (883, '2002-12-31 23:00:00+00', '2018-01-19 10:32:52.594813+00', 'Blackadder Companion Tunebook, The', 'Blackadder Tunes', 340, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (884, '2002-12-31 23:00:00+00', '2018-01-19 10:33:28.831032+00', 'Blackadder Collection, The', 'Blackadder', 340, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2002);
INSERT INTO 'publication' VALUES (918, '2003-09-12 22:00:00+00', '2012-12-31 18:56:11.060858+00', 'Fleeting', 'Fleeting', 1829, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (968, '2005-05-03 22:00:00+00', '2018-04-22 04:21:21.623829+00', 'Dunblane Holiday', 'Dunblane Holiday', 308, 1, 0, 0, 1, 202, '2018-04-22 04:21:21.620196+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (952, '2005-03-16 23:00:00+00', '2012-01-20 12:55:58.161558+00', 'Lindisfarne Strathspey & Eight Other SCD', 'Rigby: Lindisfarne', 1047, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (953, '2005-04-10 22:00:00+00', '2012-01-20 12:55:58.167881+00', 'Ruby Anniversary Collection 1964-2004', 'Vancouver Ruby', 399, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (955, '2005-04-13 22:00:00+00', '2012-01-20 12:55:58.180661+00', 'Tayside Dances', '', 2525, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (957, '2005-04-13 22:00:00+00', '2012-01-20 12:55:58.193696+00', 'Best Foot Forward', '', 356, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (959, '2005-04-17 22:00:00+00', '2012-01-20 12:55:58.207552+00', 'Otago Quintet, An', 'Otago 5', 3275, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (960, '2005-04-17 22:00:00+00', '2012-01-20 12:55:58.214098+00', 'Amersham Fair', 'Amersham Fair', 3462, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (969, '2005-05-03 22:00:00+00', '2018-04-22 12:29:02.087911+00', 'Tartan Rainbow', 'Tartan Rainbow', 308, 1, 0, 0, 1, 202, '2018-04-22 12:29:02.084276+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (771, '2006-05-21 22:00:00+00', '2018-08-20 10:19:41.956951+00', '80 Years of Dundee Dancing', 'Dundee 80', 112, 1, 1, 0, 1, 202, '2018-08-20 10:19:41.951281+00', 0, '', 0, 2005);
INSERT INTO 'publication' VALUES (962, '2005-04-17 22:00:00+00', '2012-01-20 12:55:58.227607+00', 'Honolulu Book', '', 183, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (964, '2005-06-28 22:00:00+00', '2012-01-20 12:55:58.240481+00', 'Beyond the Pale', 'Beyond the Pale', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (965, '2005-04-27 22:00:00+00', '2012-01-20 12:55:58.248678+00', 'Forty Popular Scottish Country Dances', '40 Popular', 3578, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (967, '2005-05-01 22:00:00+00', '2012-01-20 12:55:58.265868+00', 'Peterborough 2000 Collection, The', 'Peterborough 2000', 3600, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (971, '2005-05-03 22:00:00+00', '2012-01-20 12:55:58.299511+00', 'Lochmaben Collection 1', 'Lochmaben 1', 308, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (972, '2005-05-03 22:00:00+00', '2012-01-20 12:55:58.307877+00', 'Lochmaben Collection 2', 'Lochmaben 2', 308, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (973, '2005-05-03 22:00:00+00', '2012-01-20 12:55:58.316241+00', 'Lochmaben Collection 3', 'Lochmaben 3', 308, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (974, '2005-05-03 22:00:00+00', '2012-01-20 12:55:58.324398+00', 'Lochmaben Collection 4', 'Lochmaben 4', 308, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (975, '2005-05-03 22:00:00+00', '2012-01-20 12:55:58.332653+00', 'Lochmaben Collection 5', 'Lochmaben 5', 308, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (976, '2005-05-03 22:00:00+00', '2012-01-20 12:55:58.340951+00', 'Lochmaben Collection 6', 'Lochmaben 6', 308, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (978, '2005-06-28 22:00:00+00', '2012-01-20 12:55:58.357371+00', 'Wee County Dances', '', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (948, '2005-02-13 23:00:00+00', '2014-04-07 18:06:51.420847+00', 'Cup of Kindness, A', 'Kindness', 777, 1, 1, 1, 1, 160, '2013-09-28 23:30:43+00', 4, '', 0, 2004);
INSERT INTO 'publication' VALUES (947, '2005-02-13 23:00:00+00', '2014-04-07 18:46:44.639728+00', 'Cup of Cheer, A', 'Cup of Cheer', 777, 1, 0, 1, 1, NULL, NULL, 4, '', 0, 2004);
INSERT INTO 'publication' VALUES (928, '2004-02-07 23:00:00+00', '2013-11-27 03:22:54.601097+00', 'Millennium Dances', '', 286, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2002);
INSERT INTO 'publication' VALUES (932, '2004-07-06 22:00:00+00', '2014-01-20 23:12:59.802786+00', 'Aberlemno Book of Scottish Country Dances, The', 'Aberlemno', 619, 1, 1, 0, 1, 642, '2014-01-20 23:12:59.800123+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (966, '2005-04-28 22:00:00+00', '2014-07-27 12:19:54.854152+00', 'Big Birthday Book 1998, The', 'Big Birthday', 284, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (951, '2005-03-16 23:00:00+00', '2014-08-22 16:56:53.544459+00', 'Nine Scottish Country Dances', 'Rigby: Nine', 1047, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2004);
INSERT INTO 'publication' VALUES (939, '2004-10-31 23:00:00+00', '2014-09-05 15:00:37.035717+00', 'Whisper of the Fyredragon', '', 2961, 1, 1, 1, 1, NULL, NULL, 0, 'Date has been added after consulting Bob McMurtry.', 0, 2004);
INSERT INTO 'publication' VALUES (981, '2005-07-29 22:00:00+00', '2012-01-20 12:55:58.378842+00', 'Dianne Wilson''s Scottish Country Dances', 'Dianne Wilson', 3531, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (984, '2005-08-29 22:00:00+00', '2012-01-20 12:55:58.403737+00', 'Laurieston Collection 2, The', 'Laurieston 2', 2673, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (989, '2005-11-08 23:00:00+00', '2012-01-20 12:55:58.448039+00', 'Dance Devisers Days 2002', 'DDD 2002', 3487, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (950, '2005-03-09 23:00:00+00', '2021-06-22 11:40:16.916668+00', 'Duns Golden Years', 'Duns Golden', 115, 1, 0, 0, 1, NULL, NULL, 0, 'From <<https://my.strathspey.org/dd/issue/2486/|issue 2486>> the publication date is 2003 (or soon after) as it marks the Golden Jubilee of Duns & District Branch 1953 -2003.', 0, 2003);
INSERT INTO 'publication' VALUES (956, '2005-04-13 22:00:00+00', '2021-08-10 17:03:26.014499+00', 'Tayside Collection 1983-2003', '', 2525, 1, 0, 1, 0, 202, '2021-01-23 10:25:45+00', 0, '', 0, 2003);
INSERT INTO 'publication' VALUES (992, '2005-12-21 23:00:00+00', '2012-01-20 12:55:58.476433+00', 'Saint Catherine Book of SCD', 'St. Catherine', 3412, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (997, '2006-10-18 22:00:00+00', '2012-01-20 12:55:58.518704+00', 'Vallin Collection 2', 'Vallin 2', 3718, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (998, '2006-10-22 22:00:00+00', '2012-01-20 12:55:58.526876+00', '25 Years at Westminster', 'Westminster 25', 2793, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1000, '2006-10-29 23:00:00+00', '2012-01-20 12:55:58.543333+00', 'Salvington Selection of SC Dances, A', 'Salvington', 3721, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1002, '2006-11-01 23:00:00+00', '2012-01-20 12:55:58.557528+00', 'Robertson - SCD Book 1', 'Robertson 1', 619, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1003, '2006-11-01 23:00:00+00', '2012-01-20 12:55:58.579445+00', 'Robertson - SCD Book 6', 'Robertson 6', 619, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1004, '2006-11-01 23:00:00+00', '2012-01-20 12:55:58.586818+00', 'Robertson - SCD Book 7', 'Robertson 7', 619, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1005, '2006-11-01 23:00:00+00', '2012-01-20 12:55:58.593258+00', 'Robertson - SCD Book 8', 'Robertson 8', 619, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1006, '2006-11-02 23:00:00+00', '2012-01-20 12:55:58.599619+00', 'Reel Reflections', 'Reel Reflections', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1007, '2006-11-08 23:00:00+00', '2012-01-20 12:55:58.605947+00', 'Dancers'' Tribute, The', 'Dancer''s Tribute', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (935, '2004-09-01 22:00:00+00', '2016-02-26 22:07:30.45956+00', 'Book 44', 'RSCDS XLIV', 319, 1, 1, 0, 0, NULL, '2016-02-26 22:07:30.458819+00', 0, '', 1, 2004);
INSERT INTO 'publication' VALUES (988, '2005-11-08 23:00:00+00', '2015-04-20 17:53:51.209094+00', 'Rodney Rooms Dances Second Set, The', 'Rodney 2', 3647, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (987, '2005-11-08 23:00:00+00', '2015-04-20 17:57:23.666183+00', 'Rodney Rooms Dances, The', 'Rodney 1', 3647, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (970, '2005-05-03 22:00:00+00', '2015-09-14 22:48:50.172973+00', 'Caledonian Caper', '', 308, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (990, '2005-11-08 23:00:00+00', '2016-05-28 11:01:38.30411+00', 'Jubilee Book 1929-2004 [Banffshire]', 'Banff Jubilee', 3648, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (924, '2003-12-04 23:00:00+00', '2018-10-09 10:02:18.709451+00', 'Cane Toad Collection, The', 'Cane Toad', 2682, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2012);
INSERT INTO 'publication' VALUES (983, '2005-08-26 22:00:00+00', '2017-11-06 22:23:38.150523+00', 'New Dances by John Drewry 2005', 'Drewry 2005', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2005);
INSERT INTO 'publication' VALUES (980, '2006-02-16 23:00:00+00', '2018-01-19 10:34:22.644607+00', 'Allanton Companion Tunebook, The', 'Allanton Tunes', 340, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (993, '2006-02-16 23:00:00+00', '2018-01-19 10:35:50.412957+00', 'Whiteadder Companion Tunebook, The', 'Whiteadder Tunes', 340, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (958, '2005-04-13 22:00:00+00', '2019-01-04 11:46:53.935991+00', 'Snowdon Book 4', 'Snowdon 4', 434, 1, 0, 1, 1, 202, '2019-01-04 10:59:54+00', 0, 'Full name:  The Fourth Snowdon Book of Scottish Country Dancing', 0, 0000);
INSERT INTO 'publication' VALUES (1008, '2006-11-10 23:00:00+00', '2012-01-20 12:55:58.612255+00', 'Sisters of the Heart Collection', 'Sisters of Heart', 3726, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (985, '2005-10-19 22:00:00+00', '2012-08-15 22:39:40.398624+00', 'They Stole my Wife From Me Last Night', 'Stole my Wife', 2682, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2012);
INSERT INTO 'publication' VALUES (995, '2006-09-12 22:00:00+00', '2012-09-28 13:37:06.05655+00', 'Petit Chat Celtique, Le', 'Petit Chat', 2961, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2006);
INSERT INTO 'publication' VALUES (1011, '2006-11-19 23:00:00+00', '2012-01-20 12:55:58.631294+00', 'Reynolds Book of Scottish Country Dances', 'Reynolds', 324, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1056, '2011-08-22 22:00:00+00', '2018-04-03 07:18:42.035125+00', 'Many Happy Hours - Pretoria 35th', 'Happy Hours', 3208, 1, 1, 1, 1, 202, '2018-04-02 13:41:25+00', 0, '', 0, 2007);
INSERT INTO 'publication' VALUES (1017, '2007-01-26 23:00:00+00', '2012-01-20 12:55:58.669269+00', 'Milford Collection of SCD', 'Milford', 3761, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1018, '2007-02-01 23:00:00+00', '2012-01-20 12:55:58.675594+00', 'Love Letters from St Andrews', 'Love Letters', 3187, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1049, '2011-08-21 22:00:00+00', '2018-05-13 13:51:10.09541+00', 'Diamond Jubilee Dances - Belfast Branch', 'Belfast Jubilee', 569, 1, 1, 0, 1, NULL, NULL, 0, 'In 2006 we celebrated our 60th Anniversary with a Grand 60th Anniversary Ball in Belfast City Hall.', 0, 2008);
INSERT INTO 'publication' VALUES (1036, '2011-07-04 22:00:00+00', '2012-01-20 12:55:58.798223+00', 'Eight Scottish Country Dances devised by Clemens Mannert', 'Eight Scottish Country Dances', 3095, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1050, '2011-08-21 22:00:00+00', '2012-01-20 12:55:58.906494+00', 'Scottish Country Dances - Canberra 25', 'Canberra 25th', 10393, 1, 0, 0, 1, 104, '2011-08-22 19:11:08+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1026, '2011-03-21 23:00:00+00', '2012-07-16 16:50:34.728072+00', 'Thistle XXX - We Dance Therefore We Dine', 'Thistle XXX', 10316, 1, 1, 0, 1, 342, '2011-03-22 18:15:30+00', 0, '', 0, 2010);
INSERT INTO 'publication' VALUES (977, '2005-05-09 22:00:00+00', '2023-01-20 22:17:47.030431+00', 'Martello Tower Book 7', 'Martello Tower 7', 215, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2005);
INSERT INTO 'publication' VALUES (1042, '2011-07-12 22:00:00+00', '2012-07-16 16:52:04.529255+00', 'Big Apple Collection, The', '', 2973, 1, 1, 1, 0, 106, '2011-07-13 08:10:59+00', 3, '12 Scottish Country Dances with a New York connection.  Chris Ronald, New York, June 2010



Where sold, proceeds from this book will be donated to the TAC Jubilee Scholarship Fund in support of training SCD teachers.



Copies can be obtained from cjr878@gmail.com  and  http://store.tac-rscds.org/



On page 30 the new formation "THE CELTIC CROSS PROGRESSION" is defined.



On page 31 the new formation "LADIES CHAIN FOR THREE COUPLES" is defined.', 0, '2010-06-00');
INSERT INTO 'publication' VALUES (1048, '2011-08-21 22:00:00+00', '2013-11-27 02:52:59.264983+00', 'Seaside Celebration 40th Anniversary', 'Bournemouth 40th', 40, 1, 1, 1, 1, 104, '2011-08-22 13:14:49+00', 1, '', 0, 2005);
INSERT INTO 'publication' VALUES (996, '2006-10-18 22:00:00+00', '2014-11-18 22:44:08.000353+00', 'Vallin Collection 1', 'Vallin 1', 3718, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (986, '2005-11-01 23:00:00+00', '2014-09-05 15:00:07.254559+00', 'Dragonfly', '', 2961, 1, 1, 1, 1, NULL, NULL, 0, 'Date has been added after consulting Bob McMurtry.', 0, 2005);
INSERT INTO 'publication' VALUES (1043, '2011-07-12 22:00:00+00', '2012-07-16 16:52:28.837306+00', 'T.A.C. 50th Anniversary Collection', 'TAC 50th Ann', 380, 1, 1, 1, 1, 1, '2011-07-13 13:07:03+00', 0, '', 0, 2008);
INSERT INTO 'publication' VALUES (1035, '2011-07-04 22:00:00+00', '2012-07-16 16:53:27.741115+00', 'To Be A Wind (Bluebell Silver Jubilee 25 Dances Plus One)', 'To Be A Wind', 10489, 1, 1, 1, 1, 342, '2011-07-05 07:18:08+00', 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (1030, '2011-06-25 22:00:00+00', '2012-11-29 08:46:05.916679+00', 'Book 46', 'RSCDS XLVI', 319, 1, 1, 0, 1, NULL, NULL, 0, 'At the Newcastle Festival 2012, the German Team under the direction of Anselm Lingnau performed a display containing most of the dances in this book (some had to be omitted because of a limit on the length of the performance). Anselm''s detailed notes and choreography together with a video of the actual performance are available <<http://my.strathspey.org/u/anselm/stories/newcastle12/|here>>.', 1, 2010);
INSERT INTO 'publication' VALUES (1023, '2007-09-05 22:00:00+00', '2013-01-12 08:26:35.382632+00', 'Madoma Silver Celebration', 'Madoma Silver', 3781, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2007);
INSERT INTO 'publication' VALUES (1034, '2011-07-04 22:00:00+00', '2013-01-24 12:52:24.40776+00', 'Summer Collection, Set 11', 'Drewry: Summer 11', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1001, '2006-10-31 23:00:00+00', '2013-02-18 23:00:44.628724+00', 'Three Dances 2006', 'RSCDS 3/2006', 319, 1, 1, 0, 1, 85, '2009-03-24 11:39:16+00', 0, '', 1, 2006);
INSERT INTO 'publication' VALUES (1022, '2007-06-29 22:00:00+00', '2013-02-18 22:59:56.26597+00', 'Three dances by Hugh Foss', 'RSCDS 3/Foss', 319, 1, 1, 0, 1, 85, '2009-03-24 11:34:21+00', 0, '', 1, 2007);
INSERT INTO 'publication' VALUES (1038, '2011-07-10 22:00:00+00', '2019-07-17 11:14:55.308081+00', 'Ayr Branch 75th Anniversary Dances', 'Ayr 75th Anniv', 16, 1, 1, 1, 1, 104, '2011-07-11 09:13:33+00', 1, '', 0, 2008);
INSERT INTO 'publication' VALUES (1058, '2011-08-22 22:00:00+00', '2012-01-20 12:55:58.96163+00', 'Chocolate & Champagne - Sacramento 25', 'Sacramento 25', 334, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1059, '2011-08-22 22:00:00+00', '2012-01-20 12:55:58.967956+00', 'Second Sheaf Collection, The - Sheffield', 'Second Sheaf', 1134, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1065, '2011-08-25 22:00:00+00', '2012-01-20 12:55:59.007243+00', 'Trip to Tasmania', 'Trip to Tasmania', 10433, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1060, '2011-08-24 22:00:00+00', '2020-10-18 09:55:07.292983+00', 'Measures of Pleasure', '', 338, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2007);
INSERT INTO 'publication' VALUES (1025, '2010-11-10 23:00:00+00', '2015-06-03 20:45:12.033121+00', 'Vienna Book of Scottish Country Dances', 'Vienna Book', 10285, 1, 1, 1, 1, 342, '2010-11-10 23:33:24+00', 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (1015, '2007-01-02 23:00:00+00', '2018-01-19 15:15:59.104277+00', 'One Tune - Two Dances [leaflet]', '1 tune 2 dances', 215, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2006);
INSERT INTO 'publication' VALUES (1029, '2011-06-14 22:00:00+00', '2017-01-20 04:49:15.499498+00', 'Faculty of Actuaries, The', '', 3779, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2006);
INSERT INTO 'publication' VALUES (1064, '2011-08-25 22:00:00+00', '2019-09-16 00:06:36.448347+00', 'New World Scottish Dancers Collection, Vol 1', 'New World Vol 1', 10429, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1021, '2007-06-22 22:00:00+00', '2016-06-30 22:59:47.995411+00', 'New Glenshee Collection, The', 'New Glenshee', 87, 1, 1, 1, 1, NULL, NULL, 0, 'This book contains 23 dances.  The various other books "Glenshee Collection" (numbers 2,3,4,5) all contain subsets of these 23.', 0, 0000);
INSERT INTO 'publication' VALUES (1051, '2011-08-21 22:00:00+00', '2017-01-23 04:27:08.922956+00', 'Nine New Dances - Glasgow 85', 'Glasgow 85', 144, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2008);
INSERT INTO 'publication' VALUES (1009, '2006-11-10 23:00:00+00', '2017-02-21 01:52:41.276572+00', 'Kangaroo Paw, The', 'Kangaroo Paw', 412, 1, 1, 0, 1, 1645, '2013-11-30 00:12:45+00', 0, '', 0, 2006);
INSERT INTO 'publication' VALUES (1016, '2007-01-25 23:00:00+00', '2017-01-23 04:38:24.04938+00', 'Dookie Bookie, The', 'Dookie Bookie', 262, 1, 0, 0, 1, NULL, '2011-06-24 15:01:07+00', 0, '', 0, 2005);
INSERT INTO 'publication' VALUES (1012, '2006-11-28 23:00:00+00', '2017-03-19 14:30:36.901305+00', 'Aurora 10th Anniversary Book of SCD', 'Aurora 10', 3743, 1, 1, 0, 1, NULL, NULL, 0, 'Created in 1996, Aurora is a group of dancers and musicians based in and around Aberdeen, Scotland, who share an interest in traditional Scottish dance and music.', 0, 2006);
INSERT INTO 'publication' VALUES (1019, '2007-02-27 23:00:00+00', '2017-07-23 14:37:41.26333+00', 'New Ruthven »Winter« Hornpipe Collection, The', 'Ruthven Hornpipes', 2419, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2006);
INSERT INTO 'publication' VALUES (1072, '2011-08-26 22:00:00+00', '2012-01-20 12:55:59.054743+00', 'Vallin Collection 5', 'Vallin 5', 3718, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1073, '2011-08-26 22:00:00+00', '2012-01-20 12:55:59.061166+00', 'Keighley SCD Club 50th Anniversary', 'Keighley 50th', 10452, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1074, '2011-08-26 22:00:00+00', '2012-01-20 12:55:59.067785+00', 'Argyll Dancers 3', 'Argyll 3', 10456, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1076, '2011-08-26 22:00:00+00', '2012-01-20 12:55:59.080537+00', 'Footnotes Two', '', 370, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1081, '2011-08-26 22:00:00+00', '2012-01-20 12:55:59.112496+00', 'Aye Afloat - Portknockie Collection', 'Aye Afloat', 1269, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1083, '2011-08-27 22:00:00+00', '2012-01-20 12:55:59.12619+00', 'Pensioner''s Collection, The', '', 2980, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (95, '2002-12-31 23:00:00+00', '2019-02-09 13:04:24.099674+00', 'West Lothian Branch Book WL50', 'West Lothian 50th', 408, 1, 1, 1, 1, 604, '2012-02-07 10:04:23+00', 3, 'To celebrate the 50th anniversary of the West Lothian Branch of the RSCDS, 29th October 1986.



Pages 14-22 carry an interesting summary of the Branch History', 0, '1986-10-00');
INSERT INTO 'publication' VALUES (1024, '2010-09-21 22:00:00+00', '2013-08-19 11:54:57.106737+00', 'Ribble Valley Book of Scottish Country Dances, The', 'Ribble Valley', 10238, 1, 1, 1, 1, 25, '2010-09-24 14:14:24+00', 0, '', 0, 2010);
INSERT INTO 'publication' VALUES (1183, '2014-07-11 12:49:12.690076+00', '2014-07-27 08:04:42.068089+00', 'Book 48', 'RSCDS XLVIII', 319, 1, 1, 0, 1, 2078, '2014-07-27 08:04:42.067293+00', 0, '', 1, 2014);
INSERT INTO 'publication' VALUES (1111, '2012-07-04 07:40:07.204467+00', '2014-11-10 17:00:51.929864+00', 'Arches of MacGregor and other Scottish Country Dances, The', '', 3101, 1, 0, 1, 1, 160, '2014-04-03 18:18:14+00', 0, '', 0, 2012);
INSERT INTO 'publication' VALUES (1091, '2011-11-10 23:00:00+00', '2012-10-21 12:49:56.508849+00', 'EMO Fifteenth Anniversary', 'EMO 15th Anniversary', 10515, 1, 1, 1, 1, 106, '2011-12-27 00:34:40+00', 1, 'Essen, January 2009.', 0, 2009);
INSERT INTO 'publication' VALUES (1086, '2011-08-28 22:00:00+00', '2013-02-18 23:04:55.692165+00', '5 Dances 2009 including Homecoming Dance', 'RSCDS 5/2009', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 2009);
INSERT INTO 'publication' VALUES (1087, '2011-08-28 22:00:00+00', '2013-02-07 11:53:44.341056+00', 'Kandahar Reel, The', 'Kandahar Reel', 10475, 1, 1, 1, 1, NULL, NULL, 0, '', 1, 2010);
INSERT INTO 'publication' VALUES (1085, '2011-08-28 22:00:00+00', '2013-02-18 23:02:10.585979+00', 'Four Dances 2008', 'RSCDS 4/2008', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 2008);
INSERT INTO 'publication' VALUES (1098, '2012-01-17 23:00:00+00', '2013-02-18 23:01:36.826801+00', 'Scottish Country Dancer (RSCDS magazine) no. 1', 'SCDer#1', 319, 1, 0, 0, 1, 106, '2012-01-18 23:33:28+00', 0, 'Up to #11 (october 2011) this is the only number of the magazine which contained a dance descrption.', 1, 2005);
INSERT INTO 'publication' VALUES (110, '2002-12-31 23:00:00+00', '2012-07-16 16:45:32.514912+00', 'Master Of Earley, The', 'Earley', 227, 1, 0, 1, 1, 106, '2011-07-15 19:56:24+00', 3, '5 Scottish Country Dances devised by Frans Ligtmans



To commemorate the tenth visit of Frank Reid and his Scottish Dance Band.

The Thistle Club, Eindhoven, Netherlands

5 November 1988', 0, '1998-11-00');
INSERT INTO 'publication' VALUES (171, '2002-12-31 23:00:00+00', '2012-07-16 16:46:28.110491+00', 'Thistle Club, The', 'Thistle Club', 227, 1, 0, 1, 1, 106, '2011-07-15 19:56:36+00', 3, '8 Scottish Country Dances



To commemorate the 10th Anniversary of the Thistle Club, founded on 3 October 1977.', 0, '1987-00-00');
INSERT INTO 'publication' VALUES (293, '2002-12-31 23:00:00+00', '2018-04-06 15:32:40.438393+00', '30th Anniversary Dances [Falmouth]', 'Falmouth WH 30', 3564, 1, 0, 0, 1, NULL, NULL, 0, 'Mark Dungey, previous secretary of Falmouth White Heather Club (FWHC) and now secretary of Cornwall RSCDS www.scdcornwall.co.uk, reports:



"The booklet was produced in 1991 by myself to celebrate Falmouth''s 30th anniversary as we forgot to celebrate the 25th! Unfortunately the club folded after 54 years at the end of the 2015 Spring season"

', 0, '1991-00-00');
INSERT INTO 'publication' VALUES (1080, '2011-08-26 22:00:00+00', '2015-02-26 22:33:47.105754+00', 'Branxholm Hall and Lady in Red Collection', 'Scott of Buccleugh', 1089, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2007);
INSERT INTO 'publication' VALUES (56, '2002-12-31 23:00:00+00', '2015-03-27 16:38:29.853535+00', 'Birmingham Book 1973 - Twelve Scottish Country Dances', 'Birmingham 12 SCD 1973 ', 32, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1973);
INSERT INTO 'publication' VALUES (1095, '2011-12-10 23:00:00+00', '2018-10-28 10:19:19.669371+00', 'Just Desserts', 'Just Desserts', 1628, 1, 1, 1, 1, 106, '2011-12-17 21:51:14+00', 0, 'In 2010, on the 25th anniversary, the "Vancouver SC Dancers" converted their group into the "RSCDS Southwest Washington State Branch". ', 0, 2010);
INSERT INTO 'publication' VALUES (1090, '2011-10-26 22:00:00+00', '2015-05-29 15:23:16.487211+00', 'Aurora Second Book of SCD', 'Aurora Bk2', 3743, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (1010, '2006-11-14 23:00:00+00', '2017-06-12 15:16:10.334593+00', 'Always Enough to Dance', 'Always Enough', 3732, 1, 0, 1, 1, 106, '2013-05-28 19:51:15+00', 0, '14 Scottish Country Dances for 2, 3, 4 or 5 dancers



From the Foreword:



The dances in this book were devised at various times when we did not have a 3C set at the start of class.  They include a variety of dances for 2,3,4 and 5 dancers.', 0, '2006-02-01');
INSERT INTO 'publication' VALUES (1075, '2011-08-26 22:00:00+00', '2017-06-17 17:38:27.429367+00', 'Footnotes', '', 370, 1, 0, 0, 1, 202, '2017-06-17 17:38:27.425598+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1422, '2018-01-19 14:41:06.792633+00', '2018-01-19 14:41:06.792633+00', 'Quiet Achiever [leaflet], The', 'Quiet Achiever', 1214, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (1053, '2011-08-22 22:00:00+00', '2020-04-28 20:27:55.160428+00', '75th Anniversary Dances - Manchester 75th', 'Manchester 75th', 10396, 1, 1, 0, 1, 21468, '2020-04-28 20:27:55.154936+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1079, '2011-08-26 22:00:00+00', '2020-01-25 23:02:23.381683+00', 'New Ruthven Autumn Collection, The', 'Ruthven Autumn', 2419, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2005);
INSERT INTO 'publication' VALUES (1067, '2011-08-25 22:00:00+00', '2020-02-06 21:49:16.866484+00', '25 Years On - New Kilpatrick', 'New Kilpatrick 25', 10442, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (1082, '2011-08-26 22:00:00+00', '2020-09-14 11:03:10.835567+00', '40th Anniversary', '', 320, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2003);
INSERT INTO 'publication' VALUES (1046, '2011-08-04 22:00:00+00', '2021-01-10 18:47:09.456811+00', 'Flying Ghillies Collection Vol 3, The', 'Flying Ghillies 3', 3368, 1, 1, 1, 0, 342, '2011-08-06 12:24:05+00', 0, '

', 0, '2011-07-00');
INSERT INTO 'publication' VALUES (1047, '2011-08-04 22:00:00+00', '2021-01-10 18:50:18.223471+00', 'Flying Ghillies Collection Vol 4, The', 'Flying Ghillies 4', 3368, 1, 0, 1, 0, 342, '2011-08-06 12:24:20+00', 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (1066, '2011-08-25 22:00:00+00', '2017-03-10 16:36:18.117735+00', '2008 Herrington Collection - 10th Anniversary Celebration Dances', 'Herrington', 10434, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2008);
INSERT INTO 'publication' VALUES (1134, '2013-03-16 13:38:23.504692+00', '2017-03-28 22:06:39.262711+00', 'Scottish Country Dances for Perth 800', 'Perth 800', 319, 1, 1, 1, 1, NULL, NULL, 0, '', 1, 2010);
INSERT INTO 'publication' VALUES (1063, '2011-08-25 22:00:00+00', '2017-04-17 12:54:35.343064+00', '12 Scottish Country Dances by Mervyn Short [2009]', '12 SCD - Short [2009]', 347, 1, 1, 1, 1, NULL, NULL, 0, 'Not to be confused with the publication "Twelve Scottish Country Dances  by Mervyn C. Short" [1985]', 0, 0000);
INSERT INTO 'publication' VALUES (1033, '2011-07-02 22:00:00+00', '2017-01-19 22:53:08.492067+00', 'New Dances by John Drewry 2003', 'Drewry 2003', 108, 1, 0, 0, 1, 342, '2011-07-05 00:06:38+00', 0, '', 0, 2003);
INSERT INTO 'publication' VALUES (1092, '2011-12-01 23:00:00+00', '2018-01-16 19:55:18.738679+00', 'Scottish Country Dances in Diagrams, Supplement to the 8th Edition', 'Pillings 8 supplement', 398, 1, 0, 1, 1, 106, '2011-12-02 09:16:57+00', 3, 'This is a Supplement published adding 65 new diagrams not yet included in Edition 8.



In addition, for 12 dances the diagram in the 8th edition was in error; the corrected diagrams are given here in the Supplement.  



The very first edition of ''The Wee Green Book'' was published in 1955.', 0, '2009-07-00');
INSERT INTO 'publication' VALUES (1031, '2011-06-26 22:00:00+00', '2019-09-09 09:15:07.947451+00', 'Nine Weddings (And No Funeral)', '9 Weddings', 228, 1, 1, 1, 1, 1, '2011-06-27 21:01:45+00', 3, '', 0, 2008);
INSERT INTO 'publication' VALUES (1077, '2011-08-26 22:00:00+00', '2017-04-29 12:23:39.897753+00', 'Instructions for Four Demonstration Dances', 'Four Demonstrations', 3479, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1210, '2015-01-18 16:53:51.257805+00', '2018-08-14 08:22:41.563947+00', 'Corberry Collection, The', '', 1582, 1, 1, 1, 1, 202, '2018-05-01 01:25:49+00', 0, 'Available as a printed book and as a PDF. 



The dance "Away Tae Moray" was composed in July 2008 for the chairman of the RSCDS Inverness and District Branch.  It was included in their 2009 "Diamond Jubilee Collection" under the name "The Telford Hornpipe".  The deviser published the dance in her own "The Corberry Collection" using the original name, which she prefers.  ', 0, '2011-08-01');
INSERT INTO 'publication' VALUES (1061, '2011-08-24 22:00:00+00', '2019-06-05 22:22:28.581599+00', 'New Scotland 60th Anniversary Dance Book (1947-2007)', 'New Scotland 60', 1751, 1, 1, 1, 1, 157, '2012-02-13 22:31:38+00', 0, '', 0, 2007);
INSERT INTO 'publication' VALUES (1078, '2011-08-26 22:00:00+00', '2019-07-30 15:40:15.23301+00', 'Craigievar Book 5', 'Craigievar 5', 127, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (675, '2002-12-31 23:00:00+00', '2012-07-16 16:48:22.702837+00', 'Brock Summer Celebration', 'Brock Summer', 380, 1, 1, 1, 1, 106, '2012-05-10 13:30:16+00', 0, 'Twelve SC Dances



Celebrating the 20th Anniversary of TAC Summer School at Brock University in Ontario.



All devisers are RSCDS teachers and TAC members.', 0, '1992-08-00');
INSERT INTO 'publication' VALUES (1069, '2011-08-25 22:00:00+00', '2012-07-16 16:54:52.233861+00', 'Highlander Collection Vol 1', 'Highlander Coll 1', 2753, 1, 0, 1, 1, 106, '2011-10-27 21:54:44+00', 0, 'Full name: The Highlander Collection of Scottish Dances   Volume 1.  

Copyright Highlander Music 2008.  Catalogue number HRMBK003 



In this publication the dance "Crathes Castle" (page 19) carries the name of its official alias, "One for the Millennium".', 0, '2008-00-00');
INSERT INTO 'publication' VALUES (1430, '2018-04-03 08:36:05.353796+00', '2018-04-03 08:46:03.92932+00', 'Compleat Collection of 200 of the most celebrated Country Dances both old and new - Vol 3', 'Compleat Coll Vol 3', 453, 1, 0, 0, 0, NULL, NULL, 0, 'This publication in mentioned as the original source of some dances in the new RSCDS books joining several older books into one.', 0, 1775);
INSERT INTO 'publication' VALUES (1084, '2011-08-27 22:00:00+00', '2013-04-08 19:47:56.132612+00', 'Second Book of Graded Scottish Country Dances, A', 'RSCDS Graded 2', 319, 1, 1, 0, 1, NULL, NULL, 0, '', 1, 2010);
INSERT INTO 'publication' VALUES (1099, '2012-02-06 11:12:44.245433+00', '2013-08-19 11:54:57.132466+00', 'Sidlaw Collection, The', 'Sidlaw Collection', 10600, 0, 1, 1, 1, NULL, NULL, 0, '', 0, 1984);
INSERT INTO 'publication' VALUES (1429, '2018-04-03 08:32:19.982994+00', '2018-04-03 08:45:59.947241+00', 'Compleat Collection of 200 of the most celebrated Country Dances both old and new - Vol 2', 'Compleat Coll Vol 2', 453, 1, 0, 0, 0, NULL, NULL, 0, 'This publication in mentioned as the original source of some dances in the new RSCDS books joining several older books into one.', 0, 1760);
INSERT INTO 'publication' VALUES (1097, '2012-01-03 23:00:00+00', '2013-10-14 23:28:48.681945+00', 'Simply Dancing', '', 289, 1, 0, 1, 1, NULL, NULL, 0, 'A book of dances by young people and their teachers for everyone to enjoy.  The success of ‘Another Newcastle Collection’ prompted John Cass to ask the next generation of Young Dancers and their teachers, from all over the country, to submit dances for consideration with a view to publication.  This book is the result.   Price £3.50', 0, 0000);
INSERT INTO 'publication' VALUES (1187, '2014-07-27 12:24:30.682398+00', '2014-07-27 12:24:30.682398+00', 'Bonnie Brux', 'Bonnie Brux', 10975, 1, 1, 0, 1, NULL, NULL, 0, '»Composed in honour of Dr. The Hon. E. Forbes-Sempill, Leader of the Dancers of Don.«', 0, 1959);
INSERT INTO 'publication' VALUES (1428, '2018-04-03 08:29:28.598739+00', '2018-04-03 08:45:54.433293+00', 'Compleat Collection of 200 of the most celebrated Country Dances both old and new - Vol 1', 'Compleat Coll Vol 1', 453, 1, 0, 0, 0, NULL, NULL, 0, 'This publication in mentioned as the original source of some dances in the new RSCDS books joining several older books into one.', 0, 1755);
INSERT INTO 'publication' VALUES (1110, '2012-07-03 17:39:49.381467+00', '2020-12-02 10:46:45.991728+00', 'Cambridge Scottish Society 75 Years, Twelve Dances 1936 - 2011', 'Cambridge 75 Years', 61, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (919, '2003-09-14 22:00:00+00', '2021-01-10 17:53:47.130563+00', 'Flying Ghillies Collection Vol 1, The', 'Flying Ghillies', 3368, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2003);
INSERT INTO 'publication' VALUES (1135, '2013-03-16 13:47:27.844791+00', '2022-07-13 10:11:15.643326+00', 'Bourtree Collection, The', '', 1415, 1, 0, 0, 1, NULL, '2022-07-13 10:11:15.639577+00', 0, '', 0, 2012);
INSERT INTO 'publication' VALUES (1071, '2011-08-26 22:00:00+00', '2022-10-22 16:32:50.370255+00', 'Vallin Collection 4', 'Vallin 4', 3718, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2007);
INSERT INTO 'publication' VALUES (1130, '2013-02-18 22:53:25.361962+00', '2022-12-18 11:13:48.602306+00', 'Magazine Dances 2005-2009', 'Magazine', 319, 1, 1, 1, 1, NULL, NULL, 0, '', 1, 2012);
INSERT INTO 'publication' VALUES (669, '2002-12-31 23:00:00+00', '2012-02-14 13:36:44.477653+00', 'East Lothian Anniversary Book', 'East Lothian Anniv.', 2903, 1, 1, 1, 1, 106, '2012-02-09 00:10:34+00', 0, 'To mark the occasion of the 75th anniversary of the RSCDS, the East Lothian RSCDS decided to run a competition.  The standard of entries was so high that the Executive Committee considered that they should be made available to a wider audience.  Hence this book of dances. [abbreviated from the Foreword]', 0, 1998);
INSERT INTO 'publication' VALUES (994, '2006-09-03 22:00:00+00', '2012-04-03 20:59:51.847207+00', 'Between the Rivers', 'Between the Rivers', 3691, 1, 1, 1, 1, 106, '2012-04-03 20:59:51.843754+00', 0, '', 0, 2006);
INSERT INTO 'publication' VALUES (1117, '2012-12-18 00:04:26.423762+00', '2012-12-18 10:52:58.556068+00', 'Winchester Branch Diamond Jubilee Dances 1952-2012', 'Winchester Diamond Jub 2012', 10674, 1, 1, 0, 1, 106, '2012-12-18 09:14:26+00', 0, '', 0, 2012);
INSERT INTO 'publication' VALUES (1115, '2012-09-13 16:13:07.518723+00', '2012-09-13 16:16:08.09941+00', 'Mae I Have This Dance', '', 10593, 1, 0, 0, 0, NULL, NULL, 0, 'From website ', 0, 2010);
INSERT INTO 'publication' VALUES (562, '2002-12-31 23:00:00+00', '2012-10-18 21:31:18.934976+00', 'Celebrate Fifty Years of Dancing with the Boston Branch', 'Boston 50', 37, 1, 1, 0, 1, 117, '2009-04-15 14:15:10+00', 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (1118, '2012-12-18 13:00:37.292358+00', '2012-12-18 13:34:19.672506+00', 'Lady Hamilton Collection', 'Lady Hamilton', 1089, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2012);
INSERT INTO 'publication' VALUES (1431, '2018-04-03 08:56:16.837782+00', '2018-04-03 08:56:16.837782+00', 'Second Collection of Scots Reels or Country Dances, A', 'Reels or Country Dances 2', 442, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 1757);
INSERT INTO 'publication' VALUES (1108, '2012-06-12 22:22:01.293345+00', '2015-09-15 15:55:11.450173+00', 'Auld Friends Meet', 'Auld Friends Meet', 340, 1, 1, 1, 1, 1925, '2015-09-15 15:55:11.448291+00', 0, 'Can be ordered from rscdsleeds.uk', 0, 2011);
INSERT INTO 'publication' VALUES (1121, '2013-01-13 22:57:06.900949+00', '2016-05-27 21:13:25.324324+00', '3rd Lustrum Dance Book (Delft)', '', 2916, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1984);
INSERT INTO 'publication' VALUES (703, '2002-12-31 23:00:00+00', '2016-06-20 22:42:57.061058+00', 'Twenty SCD by Alec Hay (Book 1)', 'Hay: 20 SCD', 2357, 1, 0, 0, 1, 342, '2011-08-06 20:06:34+00', 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (1103, '2012-03-06 08:10:05.52591+00', '2016-10-12 12:24:02.25645+00', 'Rose of Glamis', '', 119, 1, 1, 0, 1, 1978, '2016-10-12 12:24:02.254259+00', 0, '', 0, 1990);
INSERT INTO 'publication' VALUES (772, '2006-06-14 22:00:00+00', '2021-01-10 18:39:36.588539+00', 'Flying Ghillies Collection Vol 2, The', 'Flying Ghillies 2', 3368, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 2006);
INSERT INTO 'publication' VALUES (1114, '2012-09-08 22:27:34.804675+00', '2021-06-25 22:25:43.556893+00', 'Corstorphine Fair', '', 277, 1, 1, 0, 0, NULL, NULL, 0, 'The publication date is approximate (but confirmed by <<https://my.strathspey.org/dd/issue/2513/|issue 2513>>).', 0, 1963);
INSERT INTO 'publication' VALUES (893, '2002-12-31 23:00:00+00', '2021-07-03 08:29:43.553675+00', 'Berkhamsted Strathspey and Reel Club Golden Jubilee 1952-2002', 'Berkhamsted Golden', 3331, 1, 1, 0, 1, 35811, '2021-07-03 08:29:43.548186+00', 0, '', 0, 2002);
INSERT INTO 'publication' VALUES (1132, '2013-03-14 09:43:12.819374+00', '2017-06-10 04:11:49.252626+00', 'Oxford Connection', '', 10760, 1, 1, 1, 1, 202, '2017-06-10 04:11:49.249354+00', 0, '9 dances with original music. Devised by and for Oxford dancers. ', 0, 2013);
INSERT INTO 'publication' VALUES (840, '2002-12-31 23:00:00+00', '2018-01-19 10:37:57.412544+00', 'Merse Collection, The', 'Merse', 340, 1, 1, 0, 1, 106, '2012-10-31 22:44:12+00', 0, 'Merse is the part of Berwickshire between the Lammermuir Hills and the river Tweed.', 0, 2002);
INSERT INTO 'publication' VALUES (1433, '2018-04-03 09:17:57.236838+00', '2018-04-03 11:49:43.272571+00', 'Thompson''s Compleat Collection of 200 Favourite Country Dances [18C]', 'Thompson''s Compleat Coll 200 [18C]', 466, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 1755);
INSERT INTO 'publication' VALUES (1448, '2018-04-24 18:01:20.623852+00', '2018-05-03 22:08:26.227081+00', 'Vive La Danse!', '', 44, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (1123, '2013-01-24 15:21:36.84247+00', '2013-01-24 15:39:21.592969+00', 'David Rorie Society Song Dance and Fiddle Music', 'Rorie Book', 10730, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1984);
INSERT INTO 'publication' VALUES (3, '2002-12-31 23:00:00+00', '2018-03-21 23:25:35.056812+00', 'Book 3', 'RSCDS III', 319, 1, 1, 0, 1, 103, '2009-03-13 14:24:42+00', 0, '', 1, 1926);
INSERT INTO 'publication' VALUES (1124, '2013-02-01 09:34:04.754016+00', '2013-02-01 10:59:58.234905+00', 'Exeter Branch 40', 'Exeter 40', 3563, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (1129, '2013-02-18 22:11:48.070069+00', '2013-02-18 22:40:52.904149+00', 'Ceol Na Fidhle vol. 1', '', 10750, 0, 1, 0, 1, NULL, NULL, 0, 'Published by Taigh na Teud music publishers.    

The name means "Highland Tunes for the fiddle".    

There are six volumes in all.    ', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (1112, '2012-07-21 17:22:45.002969+00', '2014-02-04 10:56:41.730821+00', 'Strathspey Anniversary Collection, The', 'Strathspey Ann''y Coll', 228, 1, 1, 1, 0, 1, '2012-07-21 17:22:31+00', 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (1120, '2013-01-05 15:40:43.005312+00', '2013-05-30 22:50:37.948635+00', 'Fun for All Seasons', '', 1394, 1, 0, 1, 1, 106, '2013-01-25 20:24:59+00', 0, '12 dances for 4 dancers or 3 couples.', 0, 2004);
INSERT INTO 'publication' VALUES (448, '2002-12-31 23:00:00+00', '2013-07-11 20:24:37.106538+00', 'Gigha Set, The', 'Gigha', 370, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1991);
INSERT INTO 'publication' VALUES (1116, '2012-10-15 22:30:02.740045+00', '2014-08-06 16:07:04.181923+00', 'Just a Few dances for Just a Few dancers', 'just a few', 10663, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2007);
INSERT INTO 'publication' VALUES (1149, '2013-07-30 17:05:22.985563+00', '2014-04-03 15:49:13.312055+00', 'Here We Go Again', 'Here we go', 10568, 1, 1, 1, 1, 160, '2013-09-28 21:57:47+00', 4, '', 0, 2013);
INSERT INTO 'publication' VALUES (1145, '2013-07-03 18:38:00.32799+00', '2013-07-03 19:21:31.032473+00', 'Glasgow Branch 90th Anniversary', 'Glasgow 90th Anniversary', 144, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2013);
INSERT INTO 'publication' VALUES (715, '2002-12-31 23:00:00+00', '2013-04-24 16:46:21.604092+00', 'Skye Collection Vol 1, The', 'Skye 1', 357, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (1434, '2018-04-03 09:18:55.627902+00', '2018-04-03 09:25:41.7064+00', 'Dale''s Collection of Reels and Dances', 'Dale''s Coll', 11624, 1, 0, 0, 0, NULL, NULL, 0, 'The RSCDS publication states "Dale''s Collection of Reels and Dances c. 1799" as a source of dances.', 0, 1799);
INSERT INTO 'publication' VALUES (1143, '2013-06-20 18:05:03.429111+00', '2013-06-25 21:33:42.443049+00', 'St Ronan''s SCD Club 35 Year Anniversary Book', 'St Ronan''s 35 Anniversary', 10797, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2013);
INSERT INTO 'publication' VALUES (1449, '2018-04-25 23:07:25.979572+00', '2018-05-03 17:26:59.193032+00', 'South East Herts Scottish Country Dance Society Diamond Jubilee Strathspey Collection', 'SEHSCDS Diamond Jubilee Strathspey Collection', 11633, 1, 0, 0, 1, 202, '2018-05-03 17:26:59.190221+00', 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (1113, '2012-08-15 08:14:24.121307+00', '2013-04-08 19:51:30.371411+00', 'QE Diamond Jubilee Dances', 'QE Diamond Jubilee', 319, 1, 1, 0, 1, NULL, NULL, 0, 'The official title is »A Collection of Dances to Celebrate The Diamond Jubilee of Her Majesty Queen Elizabeth II«.



Produced in a limited edition of 1000 copies.



Noted SCD teacher Andrew McConnell produced a sheet of notes on various of the dances in the book which he handed out at the 2012 Summer School in St Andrews. He writes: »I would prefer if my

notes were not formally available on the internet as they may be liable

to misinterpretation or may even cause disagreement!  I''m happy however

for them to be passed on from person to person if anyone asks you for

them.« So if anyone would like a copy, please <<mailto:anselm+djdnotes@strathspey.org|get in touch>>.', 1, '2012-07-00');
INSERT INTO 'publication' VALUES (501, '2002-12-31 23:00:00+00', '2013-04-10 08:14:46.900314+00', 'Cameo Collection Book 1', 'Cameo 1', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (874, '2002-12-31 23:00:00+00', '2017-11-20 15:41:32.864253+00', 'Newcastle Collection, The', 'Newcastle', 289, 0, 1, 1, 1, NULL, NULL, 0, 'Collection of 41 dance tunes by local and Scottish musicians who played for branch functions published by Newcastle RSCDS (mainly collected by Chris Blair). Original cost £2.  Published for the 21st anniversary of this branch.



Reprinted March 1978 (with Notation corrections)

Reprinted 1981', 0, '1971-00-00');
INSERT INTO 'publication' VALUES (913, '2003-07-06 22:00:00+00', '2017-04-17 13:00:17.654706+00', 'Social Dances 2002 (Leeds RSCDS 40th Anniversary Book)', 'SD 2002', 223, 1, 1, 0, 1, 106, '2013-04-13 11:49:19+00', 3, '', 0, 2002);
INSERT INTO 'publication' VALUES (1133, '2013-03-14 15:34:17.239064+00', '2017-07-15 16:54:34.460358+00', 'Burnside Collection, The', '', 1415, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2012);
INSERT INTO 'publication' VALUES (1139, '2013-04-07 19:31:25.321703+00', '2015-07-15 03:19:14.197153+00', 'Magic of Music, The', '', 3183, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2010);
INSERT INTO 'publication' VALUES (1127, '2013-02-04 15:24:56.355723+00', '2017-02-25 18:49:28.965981+00', 'Leaflet Dances with Music, The', 'RSCDS Leaflets', 319, 1, 1, 0, 1, NULL, NULL, 0, 'Contains the tune “Kinrara”, by Wm. Marshall, under the title, “The Countess of Dalkeith” (for <<ddd:Frost and Snow>>).', 1, 2001);
INSERT INTO 'publication' VALUES (1473, '2018-08-28 17:50:23.94034+00', '2018-08-28 20:16:35.568274+00', 'Bath Diamond Jubilee Dances', 'Bath Diamond', 25, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 2008);
INSERT INTO 'publication' VALUES (1146, '2013-07-03 22:32:56.345195+00', '2016-09-08 10:37:29.475408+00', 'Book 47', 'RSCDS XLVII', 319, 1, 1, 0, 1, NULL, '2016-09-08 10:37:29.474476+00', 0, '', 1, 2013);
INSERT INTO 'publication' VALUES (1138, '2013-04-01 10:34:38.872265+00', '2017-01-23 04:39:17.37947+00', 'Another Dookie Bookie', '', 262, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2012);
INSERT INTO 'publication' VALUES (1151, '2013-08-02 19:18:45.304942+00', '2017-04-17 13:01:08.01953+00', 'Leeds Golden Collection, The', 'Leeds 50th Anniversary', 223, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2013);
INSERT INTO 'publication' VALUES (1474, '2018-09-15 17:51:03.681381+00', '2018-09-15 18:31:57.563935+00', 'Holiday Dances, The', '', 11464, 1, 0, 0, 0, NULL, NULL, 0, 'Written to celebrate and remember the Scottish Country Dances Holidays organised by Jean Shaw over the years', 0, 2018);
INSERT INTO 'publication' VALUES (1126, '2013-02-04 14:55:37.155236+00', '2021-03-14 11:16:34.290359+00', 'Scottish Dances collected by Mary Isdal MacNab', 'MacNab', 319, 1, 1, 0, 1, NULL, NULL, 0, 'This is the new one-volume edition of the previous two volumes,

<<ddpub:MacNab Dances Vol 1>> and <<ddpub:MacNab Dances Vol 2>>. 



NB despite the "Isdal" in the title of this publication, it seems clear her middle name was actually "Isdale". See <<https://my.strathspey.org/dd/issue/2305/|issue 2305>>.', 1, '2007-00-00');
INSERT INTO 'publication' VALUES (1122, '2013-01-14 00:51:31.45568+00', '2021-06-21 21:27:53.611929+00', 'Trestle Bridge Collection, The', 'Trestle Bridge', 2680, 1, 0, 0, 1, NULL, NULL, 0, 'The publication gives some suggested recordings but also says that "if you are lucky enough to have live musicians ... just go and have fun!"', 0, 2002);
INSERT INTO 'publication' VALUES (361, '2002-12-31 23:00:00+00', '2021-07-18 13:18:05.247091+00', 'Celebrate 60 Years of West Lothian Branch', 'W. Lothian 60', 408, 1, 1, 1, 1, NULL, '2021-07-18 13:18:05.240551+00', 3, 'To celebrate 60th Anniversary 1936-1996, it was decided to publish a collection of dances which had been composed over the last 10 years by members of the West Lothian Branch of the RSCDS', 0, 1996);
INSERT INTO 'publication' VALUES (103, '2002-12-31 23:00:00+00', '2018-11-13 23:16:03.98554+00', 'Border Dance Book', 'Border', 245, 1, 1, 0, 1, NULL, NULL, 0, 'All the dances and music were collected, mostly by Ion J.B. Jamieson; no authors or composers are named.  Most of the music was arranged by A. Shand.



According to Emmerson, *A Social History of Scottish Dance*, this was first published in Edinburgh in 1932.', 0, '1932-00-00');
INSERT INTO 'publication' VALUES (1119, '2013-01-05 15:38:08.938067+00', '2019-08-12 17:28:12.803216+00', 'Still Enough to Dance', '', 3732, 1, 0, 1, 1, 260, '2019-08-12 17:28:12.793111+00', 0, '20 dances and 7 new formations for fewer than 8 dancers.  Data still to be entered.', 0, 2007);
INSERT INTO 'publication' VALUES (599, '2002-12-31 23:00:00+00', '2019-08-28 11:57:09.057921+00', 'Dancing at the Mill', 'Mill', 228, 1, 1, 1, 1, 1, '2009-03-13 13:51:54+00', 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (266, '2002-12-31 23:00:00+00', '2013-04-10 09:07:52.521053+00', 'Set And Cast Off Volume 1', 'Set & Cast Off 1', 22, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (203, '2002-12-31 23:00:00+00', '2013-04-10 09:08:46.128973+00', 'Summer Collection, Set 1', 'Drewry: Summer 1', 108, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1435, '2018-04-03 09:25:22.978469+00', '2018-04-03 09:25:22.978469+00', 'Preston''s Selection of the most favorite Country Dances, Reels etc', 'Preston''s Selection 1800', 459, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 1800);
INSERT INTO 'publication' VALUES (1154, '2013-08-10 15:10:34.700351+00', '2013-08-10 15:48:10.172164+00', 'Napier SCD Club 60th Anniversary', 'Napier Diamond Anniversary', 10829, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2013);
INSERT INTO 'publication' VALUES (1144, '2013-06-25 21:15:10.753742+00', '2013-08-19 11:54:57.165744+00', 'Tullich Collection, The', '', 2419, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2012);
INSERT INTO 'publication' VALUES (1039, '2011-07-10 22:00:00+00', '2019-05-27 19:10:27.450249+00', 'RSCDS Norwich Branch Golden Jubilee Year 2006 Members'' Dances', 'Norwich 50th anniversary ', 10361, 1, 0, 0, 0, 342, '2011-07-11 22:08:22+00', 0, '', 0, 2006);
INSERT INTO 'publication' VALUES (1190, '2014-07-27 14:38:28.518597+00', '2014-07-27 14:38:28.518597+00', 'Fugues by Hugh Foss', 'Fugues', 344, 1, 0, 0, 1, NULL, NULL, 0, 'A collection of Glendarroch Dance Sheets.', 0, 0000);
INSERT INTO 'publication' VALUES (1156, '2013-08-29 10:36:41.256024+00', '2013-08-29 12:01:50.557711+00', 'Three Scottish Country Dances', '', 200, 1, 1, 0, 1, NULL, NULL, 0, 'Sub-title, below a signed picture of Robert Burns: "In commemoration of the Bi-Centenary of the Bard''s Death".



Taken from an 8-page A5 copy. No publisher, printer or date indicated, but all three dances are by Jackie Johnstone, so I have named him as the editor.

', 0, '1966-01-01');
INSERT INTO 'publication' VALUES (1013, '2006-12-05 23:00:00+00', '2014-02-12 22:05:34.801526+00', 'Reel Friends Book 3', 'Reel Friends 3', 104, 1, 1, 0, 1, 1672, '2013-10-12 07:25:46+00', 0, '', 0, 2006);
INSERT INTO 'publication' VALUES (1158, '2013-08-29 14:09:05.365558+00', '2013-08-29 19:52:38.554955+00', 'Pocket: Books 42,43,44,45', '42, 43, 44, 45', 319, 1, 0, 1, 1, NULL, NULL, 0, '', 1, 2006);
INSERT INTO 'publication' VALUES (1436, '2018-04-03 10:06:35.601827+00', '2018-04-03 10:06:35.601827+00', 'Harbour''s Third Book of New & Favorite Country Dances, Strathspey Reels, Waltz, & Hornpipes', 'Harbour''s New & Favorite 3', 465, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 1800);
INSERT INTO 'publication' VALUES (338, '2002-12-31 23:00:00+00', '2013-10-04 12:03:02.625618+00', 'Stacey - Four Dances', 'Stacey', 370, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1177, '2014-05-09 22:44:12.945861+00', '2014-05-11 13:04:21.76748+00', 'Coast to Coast with Scotch Mist', 'Coast to Coast', 10955, 1, 0, 0, 1, 342, '2014-05-11 13:04:21.765274+00', 0, 'CD Booklet', 0, 2014);
INSERT INTO 'publication' VALUES (208, '2002-12-31 23:00:00+00', '2014-05-16 20:36:00.172067+00', 'Deeside Book Part 1', 'Deeside 1', 108, 1, 0, 0, 1, 160, '2014-05-10 16:22:58+00', 3, '', 0, 1981);
INSERT INTO 'publication' VALUES (1160, '2013-09-18 16:37:34.872045+00', '2013-09-20 18:15:22.017179+00', 'Houston & District 30th Anniversary Collection', '', 10859, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (1161, '2013-09-23 22:02:30.187905+00', '2013-09-23 22:02:30.187905+00', 'Saint Columba''s Strathspey (Leaflet)', 'Leaflet', 435, 1, 0, 0, 1, NULL, NULL, 0, 'Apocryphal leaflet', 0, 1985);
INSERT INTO 'publication' VALUES (1166, '2013-11-16 14:43:36.090529+00', '2013-11-16 15:08:35.414464+00', 'Few for More, A', '', 10657, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2013);
INSERT INTO 'publication' VALUES (1167, '2013-11-16 14:56:21.847737+00', '2013-11-16 15:18:57.384832+00', 'More for a Few', '', 10657, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2013);
INSERT INTO 'publication' VALUES (1168, '2013-12-03 11:08:18.777247+00', '2013-12-03 11:08:18.777247+00', 'Jerry Holland''s Collection of Fiddle Tunes', 'Jerry Holland''s Coll.', 2238, 0, 1, 0, 1, NULL, NULL, 0, '', 0, 2005);
INSERT INTO 'publication' VALUES (925, '2004-01-14 23:00:00+00', '2014-02-08 13:54:53.764955+00', 'Croydon Branch Golden Jubilee', 'Croydon Golden', 92, 1, 0, 1, 1, 106, '2014-02-08 13:54:53.762703+00', 0, 'This is Croydon Branch''s third book of dances, the other two books being published in 1989 and 1994.



This Branch was formed at a special meeting attended by Miss Jean Milligan and approximately 150 local dancers on 9th December 1953. The founder of our Branch was Mrs. Sandison, and the first President Mr. James Henderson-Stewart MP of the Scottish Office.  The branch was originally named East-Surrey - West Kent Branch, changing its name to Croydon and District Branch in 1970.



To mark our anniversary this book of dances has been compiled by its membership.



Elaine Wilde, Chairman', 0, '2003-00-00');
INSERT INTO 'publication' VALUES (1176, '2014-03-20 13:06:48.967927+00', '2014-03-20 18:21:37.581667+00', 'Oaks in Autumn', 'Oaks', 10933, 1, 0, 0, 1, NULL, NULL, 2, '', 0, 2008);
INSERT INTO 'publication' VALUES (1044, '2011-07-20 22:00:00+00', '2015-03-27 16:37:42.204+00', 'Birmingham Book 2004 - Twenty Scottish Country Dances (Compilation of 1973 and 1986)', 'Birmingham 20 SCD 2004', 32, 1, 1, 1, 1, NULL, NULL, 0, 'A Compilation  of the 1973 and 1986 Birmingham Books', 0, 2004);
INSERT INTO 'publication' VALUES (1164, '2013-10-28 23:57:17.041471+00', '2015-03-24 12:25:06.681284+00', 'Sunday Class Dance Book 1, The', 'TSC Book 1', 10648, 1, 1, 1, 1, 342, '2013-10-29 03:00:31+00', 0, 'There is an additional dance description (Barry & Doreen''s Continental Capers by Paula Dyke) in the booklet of The Sunday Class CD 1.', 0, 2013);
INSERT INTO 'publication' VALUES (1185, '2014-07-11 13:32:21.517378+00', '2015-09-05 22:01:52.08856+00', 'Imperial Book of Scottish Country Dances - Volumes 1-3', 'Imp 1-3', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 2014);
INSERT INTO 'publication' VALUES (1150, '2013-07-31 20:22:21.789197+00', '2015-10-20 21:03:52.645973+00', 'Prairie Gold', 'Prairie Gold', 421, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2013);
INSERT INTO 'publication' VALUES (1155, '2013-08-20 12:06:42.188604+00', '2016-02-26 22:09:15.075623+00', 'Golden Ghillies', '', 10835, 1, 1, 1, 1, NULL, '2016-02-26 22:09:15.073368+00', 1, '', 0, 2007);
INSERT INTO 'publication' VALUES (89, '2002-12-31 23:00:00+00', '2016-05-28 10:50:04.788362+00', 'Twelve Scottish Country Dances [Mervyn Short, 1985]', 'Short: 12 SCD [1985]', 347, 1, 0, 1, 1, 106, '2013-09-29 23:50:12+00', 0, 'Not to be confused with the publication "12 Scottish Country Dances devised by Mervyn C. Short" [2009]', 0, 1985);
INSERT INTO 'publication' VALUES (1140, '2013-04-29 13:44:40.803995+00', '2016-09-17 21:39:26.433433+00', '10th Anniversary Collection of SCD and Dance Tunes (Saitama)', '10th Anniversary Book - Saitama', 10779, 1, 1, 1, 1, 202, '2013-10-02 10:05:10+00', 0, '', 0, 2010);
INSERT INTO 'publication' VALUES (1189, '2014-07-27 13:06:09.074772+00', '2018-09-16 09:43:25.580877+00', 'Haliburton SCD Book #4: 15th Anniversary Book', '15th Anniv. (Haliburton)', 2018, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1206, '2015-01-10 18:56:58.589896+00', '2021-03-25 10:14:50.320684+00', 'Who''s Who in Toronto', '', 10835, 1, 0, 1, 1, 202, '2021-03-25 10:14:50.313845+00', 0, '', 0, 2010);
INSERT INTO 'publication' VALUES (1347, '2017-01-20 02:27:41.099352+00', '2017-02-20 09:44:57.091295+00', 'Angela''s and Tony''s Dances Book 1', '', 11441, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 1993);
INSERT INTO 'publication' VALUES (799, '2002-12-31 23:00:00+00', '2022-12-18 11:00:36.297339+00', 'Pocket: Books 1, 2, 3', '1, 2, 3', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 1926);
INSERT INTO 'publication' VALUES (1191, '2014-07-27 14:47:50.493719+00', '2022-12-18 11:33:13.609981+00', 'Ian Powrie''s Farewell to Scotland', 'IPFTS', 277, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1967);
INSERT INTO 'publication' VALUES (1152, '2013-08-06 12:12:43.340266+00', '2019-06-21 22:06:58.925695+00', 'Tweeddale Collection, Volume 4', 'Tweeddale 4', 10854, 1, 1, 0, 1, 2847, '2016-09-13 20:45:10+00', 0, 'Publication date: 2013-06



This book contains many tunes twice: (a) once the tune alone and (b) in an arangement for the dances. Thus, such tunes are listed here twice.', 0, '2013-06-30');
INSERT INTO 'publication' VALUES (1162, '2013-09-28 00:32:31.399916+00', '2019-11-26 09:39:51.98665+00', 'Real MacGregor I, The', 'Real MacGregor', 3101, 1, 0, 1, 1, 160, '2013-09-27 18:02:43+00', 2, '', 0, 2006);
INSERT INTO 'publication' VALUES (1137, '2013-03-26 22:22:30.326192+00', '2019-12-22 22:16:01.666522+00', 'Orkney Connection, The', '', 3165, 1, 0, 0, 1, 106, '2013-06-10 23:02:41+00', 1, '', 0, 1995);
INSERT INTO 'publication' VALUES (1148, '2013-07-21 13:24:04.124885+00', '2017-07-13 01:46:52.272412+00', 'Platinum - 70 Years of Dancing in St Andrews', 'St Andrews Platinum', 367, 1, 0, 0, 1, 106, '2013-07-21 13:56:18+00', 0, 'This booklet, which comes with the CD of the same title, contains the dance descriptions. Dance 13 uses music track 11.



', 0, '2007-01-01');
INSERT INTO 'publication' VALUES (1165, '2013-11-12 18:43:46.936298+00', '2017-10-15 10:09:59.611756+00', 'Dunedin Dances Book 6', 'Dunedin 6', 113, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2013);
INSERT INTO 'publication' VALUES (1163, '2013-09-29 21:37:11.920666+00', '2018-01-19 14:50:45.796538+00', 'City of Nairobi Reel [leaflet], The', '', 781, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1950);
INSERT INTO 'publication' VALUES (1169, '2013-12-07 20:46:58.127514+00', '2013-12-07 21:43:26.106253+00', 'Moments in Time', 'Moments', 1760, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2013);
INSERT INTO 'publication' VALUES (861, '2003-02-24 23:00:00+00', '2014-04-03 01:22:54.202127+00', 'Itch to Dance, An', 'Itch to Dance', 2677, 1, 0, 1, 1, 160, '2014-04-03 01:22:54.19977+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1178, '2014-05-25 09:10:29.930356+00', '2014-05-25 10:52:06.003884+00', 'Ten Modern Scottish Country Dances', '', 2745, 1, 0, 0, 1, 197, '2014-05-25 10:52:06.00171+00', 0, '', 0, 1999);
INSERT INTO 'publication' VALUES (152, '2002-12-31 23:00:00+00', '2014-04-03 18:30:08.481241+00', 'Angus Fitchet Scottish Dance Album', 'Angus Fitchet', 129, 1, 1, 1, 1, 160, '2009-07-15 05:39:38+00', 4, 'Dances devised by Hugh Foss.

Publication is © 1954, James S. Kerr, Music Publishers, Berkeley Street, Glasgow', 0, '1954-00-00');
INSERT INTO 'publication' VALUES (1181, '2014-06-18 14:13:31.68715+00', '2014-06-18 14:17:55.120156+00', 'Letchworth Garden City Centenary', '', 10970, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2003);
INSERT INTO 'publication' VALUES (1188, '2014-07-27 12:41:54.696711+00', '2014-07-27 12:41:54.696711+00', 'Dances for Five Couple Sets', '5c Sets', 344, 1, 0, 0, 1, NULL, NULL, 0, '5-couple dances from the Glendarroch Sheets', 0, 0000);
INSERT INTO 'publication' VALUES (1192, '2014-07-27 14:57:08.950403+00', '2014-07-27 14:57:08.950403+00', 'Lord MacLay''s Reel', 'LMR', 1916, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1957);
INSERT INTO 'publication' VALUES (1193, '2014-08-20 11:11:21.679471+00', '2014-08-20 12:26:06.308756+00', 'Snow Collection, The', 'Snow Coll', 10913, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2014);
INSERT INTO 'publication' VALUES (1094, '2011-12-07 23:00:00+00', '2018-08-09 13:41:44.062253+00', 'Montréal Moments', 'Montreal', 10562, 1, 1, 1, 1, 202, '2018-08-09 13:41:44.058194+00', 0, 'The CD" Music for Scottish Country Dancing" by "Les Joueurs de Bon Accord" with Laura Risk, Nicolas Williams and Eric Breton  is a companion to this publication.', 0, 2008);
INSERT INTO 'publication' VALUES (1170, '2013-12-10 13:50:14.001578+00', '2018-08-13 07:45:09.646374+00', 'Bristol 50 Anniversary', 'Bristol 50', 3164, 1, 0, 1, 1, 202, '2018-08-13 07:45:09.642384+00', 0, 'Includes the tunes for 

Torphins Lassie 

A Jig for Marcus 

by Hugh Ferguson', 0, '2012-00-00');
INSERT INTO 'publication' VALUES (1199, '2014-10-01 21:45:27.816192+00', '2014-10-02 02:01:26.895724+00', '90 - Twelve anniversary dances celebrating ninety years of RSCDS Edinburgh Branch', 'Edinburgh 90', 119, 1, 1, 0, 1, 342, '2014-10-02 01:49:06+00', 0, '', 0, 2014);
INSERT INTO 'publication' VALUES (318, '2002-12-31 23:00:00+00', '2014-11-25 15:42:57.641855+00', 'Twelvesome Reel and 4 more', 'Twelvesome', 313, 1, 0, 1, 1, 160, '2013-10-01 14:16:09+00', 0, '© Barry Priddey; published by TACBooks', 0, 0000);
INSERT INTO 'publication' VALUES (409, '2002-12-31 23:00:00+00', '2014-12-12 21:38:11.12292+00', 'Ian Powrie''s Selection of Scottish Country Dance Tunes', 'Ian Powrie', 1551, 0, 1, 0, 1, 1561, '2013-07-05 08:32:38+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1475, '2018-09-15 19:03:23.390245+00', '2018-09-15 21:19:42.986868+00', 'Ian Shepherd Dance Collection', '', 11464, 1, 0, 0, 0, NULL, NULL, 0, '15 Scottish Country Dances devised by Ian Shepherd

', 0, '2017-01-01');
INSERT INTO 'publication' VALUES (1093, '2011-12-01 23:00:00+00', '2015-01-07 12:15:42.296409+00', 'Green Book Set of Scottish Country Dances, The', 'The Green Book Set', 3694, 1, 0, 0, 0, 106, '2011-12-02 20:46:27+00', 3, 'Source for information on this publication: Tacbooks webpage 

http://store.tac-rscds.org/product_info.php?products_id=1008



Dances Devised by Gillian Jennings  (misspelt as "Gillian Gennigns" on the TACbooks webpage).  On that same page the first dance is called "Mr. John Duckett''s Jig".  That name has been entered as an alias.', 0, '2009-00-00');
INSERT INTO 'publication' VALUES (1202, '2015-01-07 15:31:24.872071+00', '2015-01-07 15:31:24.872071+00', 'Mt. Diablo Collection, The', 'Mt. Diablo Collection', 3549, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2005);
INSERT INTO 'publication' VALUES (1205, '2015-01-10 15:04:15.142669+00', '2015-01-10 15:04:15.142669+00', 'White Rock 55 Anniversary Collection', '', 11042, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (1201, '2015-01-07 12:52:21.47362+00', '2015-01-11 15:23:14.675282+00', 'Last New Ruthven Summer Collection, The', 'Last Ruthven Summer Collection', 2419, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (1196, '2014-08-31 16:46:19.073045+00', '2017-09-29 22:21:52.251015+00', 'Spring Creek Collection', '', 11340, 1, 0, 0, 0, NULL, NULL, 0, 'This publication entry has been collected from original pages and Minicribs.page waiting to be entered in full.  This book is mentioned in Minicrib.', 0, 9999);
INSERT INTO 'publication' VALUES (1179, '2014-06-09 20:04:33.492663+00', '2016-04-22 20:11:50.88658+00', 'Fun''raising Scottish Country Dances', '', 10962, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2007);
INSERT INTO 'publication' VALUES (1204, '2015-01-09 16:40:02.917392+00', '2018-01-19 15:00:13.289194+00', 'Second Catherine de Barnes Collection of Scottish Country Dances, The', 'Second Catherine de Barnes Collection', 3694, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (1180, '2014-06-14 21:22:45.897209+00', '2017-09-11 23:07:11.007278+00', 'Commonwealth Ceilidh Dances', 'CCD', 319, 1, 0, 0, 0, NULL, NULL, 0, 'Not a "physical" publication but an "implicit" publication on the RSCDS Website, see the URL', 1, 2014);
INSERT INTO 'publication' VALUES (1054, '2011-08-22 22:00:00+00', '2016-09-06 21:26:14.132483+00', 'Touch of Gold, A - New Zealand', 'Touch of Gold', 10402, 1, 0, 1, 1, NULL, NULL, 0, 'Published by The New Zealand Branch of the Royal Scottish Country Dance Society in December 2006 to celebrate the 50th nationally-organised New Zealand Summer School.', 0, 2006);
INSERT INTO 'publication' VALUES (1186, '2014-07-14 11:05:56.943942+00', '2017-07-15 16:54:11.455653+00', 'Cathkin Collection, The', 'Cathkin Collection', 1415, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2014);
INSERT INTO 'publication' VALUES (1184, '2014-07-11 13:04:17.836791+00', '2017-05-04 20:30:22.08497+00', 'Third Book of Graded Scottish Country Dances, A', 'RSCDS Graded 3', 319, 1, 1, 0, 1, 202, '2017-05-04 20:30:22.083258+00', 0, '', 1, 2014);
INSERT INTO 'publication' VALUES (281, '2002-12-31 23:00:00+00', '2017-07-15 16:51:57.996562+00', 'Reel Friends', 'Reel Friends 1', 104, 1, 1, 0, 1, 2088, '2014-09-04 13:28:16+00', 0, 'Although the publication itself does not state a date, the tape was published 1993 and appeared at the same time. Thus, the publication date was set 1993.', 0, 1993);
INSERT INTO 'publication' VALUES (1159, '2013-09-12 11:12:34.919924+00', '2017-07-27 08:39:39.212271+00', 'Forty Years On - Pretoria Branch', 'Pretoria 40th Anniversary', 3208, 1, 1, 1, 1, 1686, '2013-10-30 11:50:53+00', 2, '', 0, 2013);
INSERT INTO 'publication' VALUES (1197, '2014-09-28 20:17:24.713432+00', '2017-09-28 22:51:15.318028+00', 'Celebration Dances in the Rodney Rooms Tradition', 'Rodney Celebration ', 3647, 1, 0, 1, 1, 106, '2014-09-28 21:01:46+00', 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (1142, '2013-05-24 13:52:08.588076+00', '2020-04-23 20:28:47.384326+00', 'Heart of San Francisco, The', '', 338, 1, 1, 1, 1, 311, '2014-08-02 18:08:02+00', 0, '', 0, 2012);
INSERT INTO 'publication' VALUES (1203, '2015-01-08 15:53:56.850377+00', '2021-03-15 21:07:11.087973+00', 'International Language, An', '', 1628, 1, 1, 1, 1, 202, '2018-06-04 12:49:19+00', 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (1207, '2015-01-15 14:58:41.749964+00', '2021-01-04 17:34:19.111883+00', 'Haliburton SCD Book #6: Twenty-Ten', 'Twenty-Ten', 2018, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2010);
INSERT INTO 'publication' VALUES (1194, '2014-08-31 14:29:22.29306+00', '2022-01-11 12:02:05.999566+00', 'Stafford Book', '', 10998, 1, 0, 0, 0, NULL, NULL, 0, 'Instructions for several of the dances in this book at on the society''s website <<http://www.staffordscottishdancing.danceorg.uk/dance-cribs/>>', 0, 2001);
INSERT INTO 'publication' VALUES (1174, '2014-03-09 09:07:05.287563+00', '2022-07-27 19:03:07.673023+00', 'Reels and Wheels (CD booklet)', '', 10917, 1, 0, 0, 1, 1904, '2014-03-12 12:29:21+00', 0, 'Booklet included with the CD "Reels and Wheels" see http://my.strathspey.org/dd/album/412/.', 0, 2001);
INSERT INTO 'publication' VALUES (451, '2002-12-31 23:00:00+00', '2022-12-11 23:08:21.434208+00', 'Whetherly Book 1', 'Whetherly 1', 270, 1, 0, 1, 1, NULL, NULL, 0, 'A revised edition by Alison Mitchell (with assistance of Viktor Lehmann and Anika Rost and diagrams by Keith Rose) was re-published online in 2020 as PDF on www.scd-germany.de.', 0, 1967);
INSERT INTO 'publication' VALUES (529, '2002-12-31 23:00:00+00', '2022-12-19 23:04:43.100357+00', 'Tin Woodman and Other Dances, The', 'Tin Woodman', 12228, 1, 1, 1, 1, 1558, '2017-09-24 00:32:21+00', 0, '', 0, 1999);
INSERT INTO 'publication' VALUES (1200, '2014-10-19 08:46:32.327128+00', '2021-04-09 08:48:02.499997+00', 'Sydney Down Under Dance Book', 'Sydney Down Under', 379, 1, 0, 0, 1, 106, '2014-10-19 08:46:14+00', 0, '', 0, 2014);
INSERT INTO 'publication' VALUES (823, '2002-12-31 23:00:00+00', '2021-09-12 09:50:49.411144+00', 'Susie Petrov, Her Book of Musick', 'Susie Petrov', 1054, 0, 1, 0, 1, NULL, '2017-09-14 12:46:22+00', 0, 'Obtainable via <<http://susiepetrov.com/cds-tune-books-dances/>>', 0, 2001);
INSERT INTO 'publication' VALUES (820, '2002-12-31 23:00:00+00', '2021-09-17 21:01:24.006849+00', 'Nutmeg Collection of Scottish Country Dances', 'Nutmeg', 285, 1, 0, 1, 1, NULL, NULL, 3, 'This collection is dedicated to Peter and Sue Day, who founded the New Haven group and were instrumental in the formation of the New Haven Branch.', 0, 2002);
INSERT INTO 'publication' VALUES (1332, '2016-09-08 23:08:57.306046+00', '2021-11-24 08:41:27.179998+00', 'Paris Book of Scottish Country Dances, volume 1, The', 'Paris Book 1', 11342, 1, 0, 1, 1, 2084, '2016-11-07 10:26:46+00', 0, '', 0, 2016);
INSERT INTO 'publication' VALUES (1208, '2015-01-17 18:29:45.868026+00', '2015-01-17 18:29:45.868026+00', 'Step Dance Book 1', '', 401, 1, 0, 1, 1, NULL, NULL, 0, 'Copyright 1991 by Ron Wallace



2nd printing 1993

3rd printing 1994



Special Thank You to



Margaret Zadworny

Barbara Campbell



for their contributions', 0, '1994-12-31');
INSERT INTO 'publication' VALUES (1211, '2015-01-20 13:03:07.500145+00', '2015-01-20 13:03:07.500145+00', 'Knaresborough Collection, A', '', 2625, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2008);
INSERT INTO 'publication' VALUES (1212, '2015-01-20 16:21:49.752013+00', '2015-01-20 16:21:49.752013+00', 'Saint Martin Coll. of New Scottish Country Dances Vol 2, The', 'Saint Martin 2', 3618, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2012);
INSERT INTO 'publication' VALUES (1215, '2015-01-29 14:23:23.874127+00', '2015-01-29 14:23:23.874127+00', 'Signs of the Zodiac Collection', '', 3349, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2010);
INSERT INTO 'publication' VALUES (12, '2002-12-31 23:00:00+00', '2015-01-29 23:42:45.108623+00', 'Book 12', 'RSCDS XII', 319, 1, 1, 0, 1, 103, '2009-03-13 14:25:50+00', 0, '

The early versions of this book (first published in 1938) had “The Border Reel” as 4th dance.  



The SC Dancer of April 2009 , page 7, explains that in 1949 Hugh Thurston, author of “Scotland’s Dances”, complained in a letter that “The Border Reel” differed from the original of Johnson 1748 “Caledonian Dances”, while the SCDS books claimed “the descriptions are those which research indicates to be the original and correct method of performing each dance”.  At a meeting of the Publications Committee in January 1950 this letter was discussed at length, and it was decided to delete “The Border Reel” from the book and substitute another dance”.  We have a letter from Mrs. Stewart in South Africa written in january 1950 agreeing to the substitution of “The Laird of Dumbiedykes’ Favourite” for “The Border reel”.

', 1, '1938-00-00');
INSERT INTO 'publication' VALUES (1028, '2011-06-13 22:00:00+00', '2015-01-30 13:17:09.562713+00', 'Three Hands Across', '', 30, 1, 1, 1, 1, 342, '2011-06-15 00:38:45+00', 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (752, '2002-12-31 23:00:00+00', '2015-01-31 18:07:58.915595+00', 'Woodside Collection', 'Woodside', 2937, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1999);
INSERT INTO 'publication' VALUES (1439, '2018-04-03 10:19:48.951701+00', '2018-04-03 10:21:37.412868+00', 'Twenty Four Country Dances with Figures by Mr Wilson for the year 1816.', '24 for 1816', 11625, 1, 0, 0, 0, NULL, NULL, 0, 'The RSCDS publication "Scottish County Dances Books 18-18" states "Twenty Four Country Dances with Figures by Mr Wilson for the year 1816" to be the source of Wavery (a.k.a. Fergus McIver).', 0, 1816);
INSERT INTO 'publication' VALUES (1219, '2015-02-01 10:42:49.027723+00', '2015-02-01 10:59:40.190429+00', 'Golden Jubilee 1961-2011', '', 233, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (1220, '2015-02-01 14:55:06.445203+00', '2015-02-01 14:55:06.445203+00', 'Eternal Friendship', '', 10835, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (1228, '2015-02-09 18:10:48.706943+00', '2015-02-09 18:10:48.706943+00', 'Carterton Fifth Anniversary Collection', '', 11076, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2005);
INSERT INTO 'publication' VALUES (1432, '2018-04-03 09:11:00.147251+00', '2018-04-03 10:29:19.612263+00', 'Skillern''s Compleat Collection of Two Hundred & four Reels and Country Dances', 'Skillern Compleat Coll 204', 455, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 1789);
INSERT INTO 'publication' VALUES (1234, '2015-02-21 15:02:41.098172+00', '2015-02-21 15:02:41.098172+00', 'And We All Join In', '', 11086, 1, 1, 1, 1, NULL, NULL, 0, 'A Collection of Scottish Country Dances for Children', 0, 2014);
INSERT INTO 'publication' VALUES (1222, '2015-02-03 18:37:19.67708+00', '2015-02-03 18:37:19.67708+00', 'RSCDS in East Lothian 1952-2012', '', 2903, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2012);
INSERT INTO 'publication' VALUES (1450, '2018-05-03 08:15:46.443576+00', '2018-05-07 01:47:18.280869+00', 'Memories Are Made of This - Volume 1', '', 11139, 1, 1, 1, 1, 202, '2018-05-07 01:47:18.277089+00', 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (1239, '2015-02-27 13:16:44.613402+00', '2017-12-17 02:01:43.528709+00', '50th Anniversary 1957-2007 (Roxburgh et al.)', '', 11102, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2007);
INSERT INTO 'publication' VALUES (622, '2002-12-31 23:00:00+00', '2015-02-28 12:13:42.399485+00', 'Glenfeshie Sheets', 'Glenfeshie Sheets', 94, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1452, '2018-05-30 10:30:45.005309+00', '2018-05-30 10:30:45.005309+00', 'Ballochmyle Set, The', 'Ballochmyle', 129, 1, 1, 0, 1, NULL, NULL, 0, 'The three dances in this publication are also included in the Galloway Album.', 0, 0000);
INSERT INTO 'publication' VALUES (1227, '2015-02-09 15:05:28.514015+00', '2019-07-29 09:40:20.792912+00', 'Tokyo Set, The', '', 44, 1, 0, 0, 1, NULL, NULL, 0, 'A collection of Iain Boyd''s dances for teaching in Tokyo and not the primary written source for most of them.', 0, 2010);
INSERT INTO 'publication' VALUES (1231, '2015-02-20 15:38:52.992407+00', '2015-02-20 15:38:52.992407+00', 'Jubilee Dances 2011', '', 380, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (1232, '2015-02-20 18:14:01.704097+00', '2015-02-20 18:14:01.704097+00', 'Blackie Dances 2011', '', 380, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (1233, '2015-02-21 13:14:32.68187+00', '2015-02-21 13:14:32.68187+00', 'Lighthouse Collection Volume1: Mukilteo', 'Mukilteo', 3593, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2014);
INSERT INTO 'publication' VALUES (1235, '2015-02-24 14:30:42.059455+00', '2015-02-24 14:30:42.059455+00', 'Ardbrae Celebrating 50 Years', 'Ardbrae 50 Years', 7, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2014);
INSERT INTO 'publication' VALUES (1236, '2015-02-24 17:29:34.607666+00', '2015-02-24 17:30:12.165697+00', 'Gleneagles Gold Collection', '', 1089, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2013);
INSERT INTO 'publication' VALUES (1237, '2015-02-25 16:11:16.850098+00', '2015-02-25 16:11:16.850098+00', 'BHS Branch 9 Dances for 2015', 'BHS Branch 9 for 2015', 30, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 2015);
INSERT INTO 'publication' VALUES (102, '2002-12-31 23:00:00+00', '2015-02-25 23:06:28.175468+00', 'Scottish Country Dances - RSCDS Stirlingshire Branch 60th Anniversary', 'Stirling SCD', 375, 1, 1, 0, 1, 342, '2014-08-27 01:12:08+00', 0, 'This book was published for the 60th Anniversary of the RSCDS Stirlingshire Branch, now Stirling Branch, in 1987.', 0, 1987);
INSERT INTO 'publication' VALUES (1238, '2015-02-25 23:15:26.506058+00', '2015-02-26 15:03:11.685625+00', 'Bannockburn 700', '', 375, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2014);
INSERT INTO 'publication' VALUES (1241, '2015-02-27 19:11:56.284088+00', '2015-02-27 19:11:56.284088+00', 'Feathered Friends', '', 1309, 1, 0, 1, 1, NULL, NULL, 0, 'Includes two English Country Dances:



- Ducks in a Row (Similar to the Scottish one)

- The Eurasian Collared Dove', 0, '2009-04-01');
INSERT INTO 'publication' VALUES (333, '2002-12-31 23:00:00+00', '2015-02-27 19:54:09.601702+00', 'Sydney Triad', 'Sydney Triad', 325, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1983);
INSERT INTO 'publication' VALUES (1070, '2011-08-26 22:00:00+00', '2017-10-08 18:34:30.625891+00', 'Waratah Collection - Edition 2010', 'Waratah Coll 2010', 74, 1, 0, 1, 1, 1524, '2017-10-08 18:34:30.622329+00', 0, 'The Waratah is the floral emblem of New South Wales and is prominent in the bush in spring near the author’s home. (Cover Photo: Brian Charlton)', 0, 2010);
INSERT INTO 'publication' VALUES (1209, '2015-01-18 10:47:44.433468+00', '2016-06-17 17:09:06.269152+00', 'Step Dance Book 2', '', 401, 1, 0, 1, 1, NULL, NULL, 0, 'Copyright 1994 by Ron Wallace



2nd printing 1995





Special Thank You to



Barbara Campbell

Vicky Goodloe

Phyllis MacCulloch



for their contributions', 0, '1994-00-00');
INSERT INTO 'publication' VALUES (1240, '2015-02-27 16:50:32.306741+00', '2018-01-19 10:29:55.946356+00', 'Here''s to You', '', 10568, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2008);
INSERT INTO 'publication' VALUES (1230, '2015-02-13 14:00:38.078972+00', '2018-01-19 14:59:45.04707+00', 'Third Catherine de Barnes Collection of Scottish Country Dances, The', 'Third Catherine de Barnes', 3694, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (1214, '2015-01-22 16:46:26.610092+00', '2018-01-19 15:00:22.397202+00', 'Catherine de Barnes Collection of Scottish Country Dances, The', '', 3694, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2007);
INSERT INTO 'publication' VALUES (868, '2002-12-31 23:00:00+00', '2015-02-28 13:24:16.277308+00', 'McCaig''s Tower', 'McCaig''s', 11109, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1967);
INSERT INTO 'publication' VALUES (1505, '2019-06-01 15:45:20.171911+00', '2019-06-04 14:50:39.942914+00', 'Second A Reel Goulash, The', '2nd Reel Goulash', 3659, 1, 1, 0, 1, 274, '2019-06-04 09:51:27+00', 0, '', 0, 2019);
INSERT INTO 'publication' VALUES (1438, '2018-04-03 10:12:40.060438+00', '2020-04-23 20:26:23.820168+00', 'Analysis of the London Ballroom', '', 432, 1, 0, 0, 0, NULL, NULL, 0, 'T Wilson: Analysis of the London Ballroom, 1825', 0, 1925);
INSERT INTO 'publication' VALUES (1213, '2015-01-21 15:23:49.932592+00', '2021-06-17 14:08:04.489791+00', 'Whangarei Wanderings', '', 352, 1, 0, 0, 1, 202, '2021-06-17 14:08:04.485569+00', 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (982, '2005-08-21 22:00:00+00', '2021-09-12 09:00:02.67358+00', 'Saint Martin Coll. of New Scottish Country Dances Vol 1, The', 'Saint Martin 1', 3618, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2001);
INSERT INTO 'publication' VALUES (1225, '2015-02-08 18:08:57.758899+00', '2021-10-20 22:29:51.121111+00', 'Gourock Collection, The', '', 703, 1, 0, 1, 1, NULL, NULL, 0, 'The Gourock Collection is part of <<ddpub:The Highland Road Collection#1224>>.', 0, 2012);
INSERT INTO 'publication' VALUES (1224, '2015-02-06 18:10:59.63529+00', '2021-10-20 22:30:27.265827+00', 'Highland Road Collection, The', 'Highland Road', 703, 1, 0, 1, 1, NULL, NULL, 0, 'The last three dances from the Highland Road Collection (pages 33-35) are dances belonging to <<ddpub:The Gourock Collection#1225>> (pages 29-35).', 0, 2013);
INSERT INTO 'publication' VALUES (1221, '2015-02-03 17:24:41.744593+00', '2018-03-04 19:55:48.78157+00', 'Kobby''s New Dances for Cherry Blossom Time', 'Kobby''s New Cherry Blossom Dances', 3783, 1, 0, 0, 1, 202, '2018-03-04 17:20:01+00', 0, 'Available from TAC Books http://store.tac-rscds.org', 0, 2008);
INSERT INTO 'publication' VALUES (1244, '2015-03-20 15:01:13.702504+00', '2015-03-20 15:01:13.702504+00', 'Cockney Jocks', '', 1231, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1976);
INSERT INTO 'publication' VALUES (371, '2002-12-31 23:00:00+00', '2015-03-27 16:31:00.24664+00', 'Frae Thursday Nicht '' til Friday Morn', 'Heston Thurs/Friday', 2021, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (78, '2002-12-31 23:00:00+00', '2015-03-27 16:44:40.769163+00', 'SCD for Children and Teens', 'Douglas - Children', 107, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (449, '2002-12-31 23:00:00+00', '2015-03-27 16:49:14.915843+00', 'Decade of Dance', 'Doncaster - Decade', 106, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (217, '2002-12-31 23:00:00+00', '2015-03-27 16:55:04.921017+00', 'Twelve Scottish Country Dances', 'Tartan Plaidie 12 SCD', 383, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1453, '2018-05-30 10:35:08.76005+00', '2018-05-30 10:35:08.76005+00', 'Greenwich Hill Set, The', 'Greenwich Hill', 129, 1, 1, 0, 1, NULL, NULL, 0, 'The three dances in this publication are also included in the Galloway Album.', 0, 0000);
INSERT INTO 'publication' VALUES (930, '2005-02-01 23:00:00+00', '2017-04-17 14:46:40.990741+00', 'Clapyerhands ''n'' Stampyerfeet', '', 725, 1, 0, 0, 1, 2569, '2015-05-25 03:56:16+00', 0, '', 0, 2003);
INSERT INTO 'publication' VALUES (1253, '2015-05-08 20:19:32.106127+00', '2015-05-09 20:24:11.923847+00', 'Book of Many Thanks, A', 'Many Thanks', 11133, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2010);
INSERT INTO 'publication' VALUES (1256, '2015-05-19 20:39:45.446355+00', '2018-09-16 09:54:42.802738+00', 'Haliburton SCD Book #2: Let''s Dance', 'Let''s Dance', 2018, 1, 0, 1, 1, NULL, NULL, 0, 'Publication date: unknown', 0, 2001);
INSERT INTO 'publication' VALUES (1257, '2015-05-21 15:22:46.524913+00', '2018-09-16 09:55:53.195229+00', 'Haliburton SCD Book #3: Corners', 'Corners', 2018, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1254, '2015-05-10 13:28:55.412605+00', '2015-05-10 13:28:55.412605+00', 'Spotwood Set, The', '', 10433, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (1245, '2015-03-24 12:24:10.643942+00', '2016-10-08 23:31:25.073772+00', 'CD booklet of The Sunday Class Dance Book 1', 'TSC Book 1 CD', 3217, 1, 0, 0, 1, 342, '2016-10-08 23:31:25.072031+00', 0, 'This is the booklet accompanying the CD "The Sunday Class Dance Book 1" by Marian Anderson and her Band.', 0, 2013);
INSERT INTO 'publication' VALUES (1248, '2015-04-21 21:53:56.828687+00', '2015-04-22 14:21:39.561437+00', 'R.S.C.D.S. Edinburgh Branch Ladies'' Club Jubilee Book 1936 - 1996', 'RSCDS Edinburgh Ladies 1936 - 1996', 119, 1, 0, 0, 0, 106, '2015-04-22 14:21:39.55967+00', 0, '', 0, 1996);
INSERT INTO 'publication' VALUES (1258, '2015-05-23 17:41:38.926949+00', '2018-09-16 09:59:34.712042+00', 'Haliburton SCD Book #5: A Haliburton Dozen', 'A Haliburton Dozen', 2018, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (1250, '2015-05-01 16:53:03.557088+00', '2015-05-01 16:53:03.557088+00', 'Dare to Dance', '', 352, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2007);
INSERT INTO 'publication' VALUES (1251, '2015-05-04 15:12:49.136793+00', '2015-05-04 15:12:49.136793+00', 'Gene''s Memory Lane', '', 488, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (1252, '2015-05-07 10:46:12.081648+00', '2015-05-07 10:46:12.081648+00', 'Northampton 20th Anniversary', '', 11132, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2010);
INSERT INTO 'publication' VALUES (1260, '2015-06-02 14:59:50.115142+00', '2015-06-02 15:12:41.881664+00', 'Mainly Fours', '', 165, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2004);
INSERT INTO 'publication' VALUES (1261, '2015-06-06 21:08:58.307324+00', '2015-06-06 21:09:59.795842+00', 'Dance Devisers Days 2009', 'DDD 2009', 3487, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2010);
INSERT INTO 'publication' VALUES (1262, '2015-06-28 09:46:47.001436+00', '2015-08-26 09:45:06.920925+00', 'Clifton Collection, The', '', 234, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2015);
INSERT INTO 'publication' VALUES (1249, '2015-05-01 14:12:09.816326+00', '2019-07-24 15:13:18.565301+00', 'Tom''s Book of Dances', 'Tom''s Book', 84, 1, 1, 1, 1, NULL, NULL, 0, 'Pages 28-31 of the publication contain diagrams for the new figures occurring in these dances:



- Allemande Spray,  

- Crossing Allemandes,  

- The Full Switch,  

- LaCross,  

- The Left hand Switch,  

- The Right hand Switch,  

- The Roundabout,  

- Untie the knot (for 2C and 3C),  



and four other less common formations:  



- Allemande for 1 couple,  

- La Baratte,  

- Poussette for 1 couple,  

- The Targe

', 0, '2015-01-15');
INSERT INTO 'publication' VALUES (1266, '2015-07-20 16:41:24.990505+00', '2017-05-15 14:14:02.382757+00', 'Third Sheaf Collection Diamond Jubilee 1955 - 2015', 'Third Sheaf', 1134, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2015);
INSERT INTO 'publication' VALUES (1267, '2015-07-21 09:39:57.302845+00', '2015-07-21 09:39:57.302845+00', 'Scottish Country Dancing with Beginners', 'SCD with Beginners', 11162, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2015);
INSERT INTO 'publication' VALUES (44, '2002-12-31 23:00:00+00', '2016-02-26 22:08:36.292854+00', 'Five Traditional Scottish Country Dances for 1965', 'RSCDS 5/1965', 319, 1, 1, 0, 1, NULL, '2016-02-26 22:08:36.292131+00', 0, '', 1, 1965);
INSERT INTO 'publication' VALUES (1264, '2015-07-11 14:44:12.18042+00', '2015-08-04 23:44:35.417655+00', 'Book 49', 'RSCDS XLIX', 319, 1, 1, 0, 1, NULL, '2015-08-04 23:44:35.416834+00', 0, '', 1, 2015);
INSERT INTO 'publication' VALUES (1276, '2015-08-27 13:53:04.084526+00', '2015-10-17 12:41:52.58273+00', 'StrathsBabes', 'Babes', 3703, 1, 1, 1, 1, NULL, NULL, 0, 'Ellen Ternes and Pam Stephens published this together', 0, 2015);
INSERT INTO 'publication' VALUES (1270, '2015-08-18 15:18:57.54149+00', '2015-08-18 15:34:27.764231+00', 'Footnotes 6', '', 370, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2008);
INSERT INTO 'publication' VALUES (1271, '2015-08-18 16:05:01.132062+00', '2015-08-18 16:05:01.132062+00', 'Footnotes Goes Golden', '', 11170, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2014);
INSERT INTO 'publication' VALUES (1242, '2015-03-17 13:54:03.575938+00', '2017-04-17 12:58:58.63524+00', 'Sixth Catherine de Barnes Collection of Scottish Country Dances, The', 'Sixth Catherine de Barnes Collection', 3694, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2014);
INSERT INTO 'publication' VALUES (1274, '2015-08-26 13:01:11.949249+00', '2015-08-26 16:01:11.831408+00', 'Queen of the Dance', '', 166, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2014);
INSERT INTO 'publication' VALUES (1275, '2015-08-26 18:43:09.545496+00', '2015-08-26 19:19:43.367873+00', 'Magic of Music, Book 2', '', 3183, 1, 1, 1, 1, NULL, NULL, 0, 'Published in 2015 in aid of Cancer Research UK', 0, 2015);
INSERT INTO 'publication' VALUES (1278, '2015-08-29 13:49:26.106766+00', '2015-08-29 13:49:26.106766+00', 'Amisfield Dances, The', '', 11182, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2015);
INSERT INTO 'publication' VALUES (839, '2002-12-31 23:00:00+00', '2018-03-21 23:35:12.261305+00', 'Book 42, to celebrate the 70th Summer School', 'RSCDS XLII', 319, 1, 1, 0, 1, NULL, '2016-02-26 22:07:20.119453+00', 0, '', 1, 2002);
INSERT INTO 'publication' VALUES (1294, '2016-02-19 15:39:05.284597+00', '2016-06-17 22:14:57.030831+00', 'Scottish Country Dances Books 13 to 18 (Combined A5 edition)', 'Books 13-18', 319, 1, 0, 0, 1, NULL, NULL, 0, '', 1, 2010);
INSERT INTO 'publication' VALUES (1282, '2015-09-16 03:24:07.581261+00', '2015-09-16 03:24:07.581261+00', 'Twenty Two SCD', '22 SCD', 87, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1998);
INSERT INTO 'publication' VALUES (395, '2002-12-31 23:00:00+00', '2015-09-22 07:46:45.128089+00', 'Country Dancer''s Guide to Scottish Linksland, The', 'Linksland', 595, 1, 0, 1, 1, NULL, NULL, 0, 'subtitle: "A Collection of Scottish Country Dances Honoring the Great Golf Courses of Scotland"', 0, 0000);
INSERT INTO 'publication' VALUES (1283, '2015-09-19 17:58:21.096245+00', '2015-09-22 11:37:50.702213+00', 'Whisky Sampler, A', '', 595, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2014);
INSERT INTO 'publication' VALUES (1506, '2019-06-15 21:13:22.191924+00', '2019-06-15 21:16:44.307565+00', 'CD booklet of The Sunday Class Recorded Highlights Volume 1', '', 10648, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2019);
INSERT INTO 'publication' VALUES (1247, '2015-04-15 11:37:27.984525+00', '2020-03-05 18:23:36.250735+00', 'Potters Pairs', '', 10612, 1, 0, 1, 1, NULL, NULL, 0, 'In this publication ''Old Castle Dancers “Potters Pairs”'', the instructions for " This is BirthDay" are in error.  See the indicated link to a correct description.', 0, 2013);
INSERT INTO 'publication' VALUES (1255, '2015-05-11 08:53:04.726844+00', '2020-04-23 20:27:05.959317+00', 'Reeladelphia', '', 10934, 1, 1, 0, 1, NULL, '2019-02-18 15:58:31+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1273, '2015-08-18 23:10:34.48628+00', '2020-04-23 20:27:35.505707+00', 'Footnotes 7', '', 11170, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2008);
INSERT INTO 'publication' VALUES (1272, '2015-08-18 22:44:11.640241+00', '2021-07-30 08:47:02.136937+00', 'Footnotes 5', '', 11170, 1, 0, 0, 1, NULL, NULL, 0, 'The dances in the online version are listed in a different order than currently appears here.', 0, 2006);
INSERT INTO 'publication' VALUES (1284, '2015-09-20 17:02:05.806992+00', '2015-09-30 06:14:47.786178+00', '50 RSCDS Vancouver Golden Anniversary Collection', '50 Vancouver', 399, 1, 0, 0, 1, NULL, NULL, 0, 'An error has been found in the dance "Shopping Mall Scramble" in the Vancouver Golden Anniversary collection. Bars 27-28 should read:



27-28 3rd woman with 1st woman, 3rd man with 2nd woman, and 1st man with 2nd man, giving right hands, cross over.



Rosemary Coupe

', 0, '2015-02-01');
INSERT INTO 'publication' VALUES (77, '2002-12-31 23:00:00+00', '2015-10-03 22:44:25.192934+00', 'Belfast Branch 40th Anniversary', 'Belfast 40th', 569, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1986);
INSERT INTO 'publication' VALUES (670, '2002-12-31 23:00:00+00', '2017-04-15 23:22:08.848923+00', 'Let''s All Dance', 'Let''s All Dnc 1', 170, 1, 0, 1, 1, 202, '2017-04-15 23:22:08.847269+00', 0, 'A collection of beginner and audience participation dances. Compiled by two San Francisco branch teachers.', 0, 1992);
INSERT INTO 'publication' VALUES (1287, '2015-10-06 01:02:33.374732+00', '2017-03-10 21:50:11.85597+00', 'Bardill/Prince Collection of Dances, The', 'Bardill/Prince coll.', 10995, 1, 0, 0, 0, NULL, NULL, 0, 'The dances may not be listed in the correct order', 0, 2014);
INSERT INTO 'publication' VALUES (1280, '2015-09-03 15:54:33.348009+00', '2015-11-03 13:53:54.696379+00', 'Diamond Set Collection, The (Dances for 5 person sets)', 'Diamond Set (5 persons)', 10995, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2007);
INSERT INTO 'publication' VALUES (894, '2002-12-31 23:00:00+00', '2019-08-07 10:31:41.100276+00', 'Scotia Suite of Scottish Country Dances, The', 'RSCDS Scotia', 3330, 1, 1, 0, 1, NULL, '2016-02-26 22:10:54+00', 0, 'This book of dances was produced in collaboration with the Royal Scottish Country Dance Society and the Royal Scottish Geographical Society, as part of the celebrations marking the centenary of the voyage of The Scotia, the research ship of the Scottish National Antarctic Expedition of 1902 - 1904 under the leadership of Dr William Speirs Bruce.



See also <<https://rscdsvancouver.org/resources/the-white-cockade/antarctic-hero/|this article>> on the Vancouver branch website.', 1, '2002-00-00');
INSERT INTO 'publication' VALUES (1289, '2015-10-28 19:40:42.086494+00', '2015-12-30 19:01:49.491916+00', '2nd Tullich Collection', '', 2419, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2015);
INSERT INTO 'publication' VALUES (1296, '2016-02-19 16:39:07.030283+00', '2016-02-23 07:47:20.14327+00', 'Scottish Country Dances Books 25 to 30 (Combined A5 edition)', 'Books 25-30', 319, 1, 0, 1, 1, NULL, NULL, 0, '', 1, 2015);
INSERT INTO 'publication' VALUES (1216, '2015-01-31 17:07:06.612062+00', '2016-01-08 08:28:28.12588+00', 'Here''s To You Too', '', 10568, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (1295, '2016-02-19 16:03:15.916167+00', '2017-09-15 15:31:21.885177+00', 'Scottish Country Dances Books 19 to 24 (Combined A5 edition)', 'Books 19-24', 319, 1, 0, 1, 1, NULL, NULL, 0, '', 1, 2012);
INSERT INTO 'publication' VALUES (1292, '2016-02-19 13:51:32.5364+00', '2016-02-23 07:41:31.402242+00', 'Scottish Country Dances Books 1 to 6 (Combined A5 edition)', 'Books 1-6', 319, 1, 0, 1, 1, NULL, NULL, 0, '', 1, 2008);
INSERT INTO 'publication' VALUES (1293, '2016-02-19 14:37:15.698882+00', '2016-02-23 07:51:12.476894+00', 'Scottish Country Dances Books 7 to 12 (Combined A5 edition)', 'Books 7-12', 319, 1, 0, 1, 1, NULL, NULL, 0, '', 1, 2009);
INSERT INTO 'publication' VALUES (47, '2002-12-31 23:00:00+00', '2016-02-26 22:08:57.570845+00', 'Four Scottish Country Dances 1978', 'RSCDS 4/1978', 319, 1, 1, 0, 1, NULL, '2016-02-26 22:08:57.570088+00', 0, '', 1, 1978);
INSERT INTO 'publication' VALUES (1281, '2015-09-03 20:28:35.942865+00', '2016-05-17 23:47:05.195232+00', '9 for 90 RSCDS Aberdeen Branch 90th Anniversary', '9 for 90', 2850, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2015);
INSERT INTO 'publication' VALUES (1454, '2018-05-30 10:38:29.202551+00', '2018-05-30 10:38:29.202551+00', 'Captain Whiteside Set, The', 'Whiteside', 129, 1, 1, 0, 1, NULL, NULL, 0, 'The three dances in this publication are also included in the Galloway Album.', 0, 0000);
INSERT INTO 'publication' VALUES (1263, '2015-07-06 18:22:21.745628+00', '2019-02-06 07:32:15.592982+00', 'World Wide Weavings', 'World Wide Weavings', 11149, 1, 0, 0, 1, NULL, NULL, 0, 'This first edition does not include music, although several of the dances were submitted with music or suggested tunes. The plan is to publish a second edition with music for all dances.', 0, 2015);
INSERT INTO 'publication' VALUES (465, '2002-12-31 23:00:00+00', '2019-09-13 14:37:33.011501+00', 'Whetherly Book 15', 'Whetherly 15', 270, 1, 0, 1, 1, NULL, NULL, 0, 'In the original book the dances are each printed on one or two pages.  In this SCDDB record, the dances are numbered by page number.', 0, 1986);
INSERT INTO 'publication' VALUES (1306, '2016-06-09 11:01:42.877708+00', '2017-07-15 16:53:41.453115+00', 'Dalnair Collection, The', 'Dalnair Coll', 1415, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2015);
INSERT INTO 'publication' VALUES (1298, '2016-03-16 11:33:43.186859+00', '2016-03-16 11:43:37.31069+00', 'Twelve New Scottish Country Dances (1946-1957)', '', 392, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1957);
INSERT INTO 'publication' VALUES (1389, '2017-10-20 12:40:45.335027+00', '2019-03-07 23:12:34.246632+00', 'Collins Little Books: Scottish Dance', 'Collins Little', 11535, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2017);
INSERT INTO 'publication' VALUES (877, '2002-12-31 23:00:00+00', '2016-04-05 13:10:02.098053+00', 'Melrose Collection 2', 'Melrose 2', 1490, 0, 1, 1, 0, NULL, NULL, 0, 'Published in 1990 by Steblin Music Melrose. Collection of 35 original compositions collected by Jimmy Clinkscale.', 0, 1990);
INSERT INTO 'publication' VALUES (1442, '2018-04-03 11:52:48.311574+00', '2018-04-03 11:52:48.311574+00', '24 Country Dances for 1758', '', 468, 1, 0, 0, 0, NULL, NULL, 0, 'The RSCDS publication "Scottish Country Dances Books 13-18" states this publication as a source of dances.', 0, 1758);
INSERT INTO 'publication' VALUES (1288, '2015-10-12 23:23:25.440477+00', '2020-09-12 10:26:35.13481+00', 'Johnsonville Collection, The', '', 2682, 1, 0, 1, 0, NULL, NULL, 0, 'This collection is still ''under construction''. Thus, it is still growing. 

October 2015 it had 11 dances only,  1 July 2016 it had grown to 14 dances, while February 2018 it has grown to contain 22 dances.



Dances are arranged in increasing order of difficulty, with early ones being teaching dances. Thanks to all who have tried these out, mainly poor Johnsonville club members and the Tuesday group and particularly Charlotte Williams for many corrections. Many of these dances are based around Johnsonville group dancers, and coincides with our 60th anniversary as a club.', 0, '2016-06-01');
INSERT INTO 'publication' VALUES (493, '2002-12-31 23:00:00+00', '2016-05-21 00:26:16.653844+00', 'Corryvrechan Dances No. 1', 'Corryvrechan 1', 304, 1, 0, 1, 1, NULL, NULL, 0, 'Eight social dances derived from Corryvrechan''s repertoire



AI] the dances were written by Andrew Paterson and usually modified after comments from members ofthe Corryvrechan team. Most of the dances are simplified versions of ones that have been used on trips to festivals abroad and for demonstrations nearer home. Some have been circulating in preliminary form - these are the final versions.', 0, '1998-00-00');
INSERT INTO 'publication' VALUES (582, '2002-12-31 23:00:00+00', '2016-05-26 21:36:45.331231+00', 'Some Dances from Orlando Branch', 'Some Dances from Orlando', 298, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1229, '2015-02-11 13:42:55.966094+00', '2018-06-01 14:37:46.544611+00', 'Fourth Catherine de Barnes Collection of Scottish Country Dances, The', '4th Catherine de Barnes Collection', 3694, 1, 0, 0, 1, 202, '2018-06-01 14:37:46.542973+00', 0, '', 0, 2012);
INSERT INTO 'publication' VALUES (1291, '2016-01-18 17:05:57.558518+00', '2016-10-19 22:43:24.44214+00', 'Scottish Country Dancing is all around the world', 'SCD all around the World', 11035, 1, 0, 1, 1, NULL, '2016-10-19 22:43:24.440477+00', 0, '', 0, 2015);
INSERT INTO 'publication' VALUES (1313, '2016-06-22 23:06:16.842781+00', '2016-09-28 08:41:30.889608+00', 'Dance Scottish, A resource for teaching SCD in schools', 'Dance Sc', 319, 1, 0, 1, 1, NULL, NULL, 0, 'This teaching manual has descriptions with diagrams of 18 dances', 1, 2001);
INSERT INTO 'publication' VALUES (1327, '2016-08-21 20:39:58.333198+00', '2016-08-29 21:41:22.111344+00', 'Aurora 20th Anniversary Book of SCD', 'Aurora 20', 3743, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2016);
INSERT INTO 'publication' VALUES (1285, '2015-09-22 20:37:27.118487+00', '2022-09-20 06:54:38.883539+00', 'Lower Hutt SCD Club 60th Anniversary', 'Lower Hutt SCD 60th Anniv', 12207, 1, 1, 1, 1, NULL, NULL, 0, 'Stub entry; needs to be expanded', 0, 2014);
INSERT INTO 'publication' VALUES (1041, '2011-07-11 22:00:00+00', '2022-09-30 16:50:55.91712+00', 'Graded and Social Dances 3 - 16 Dances', 'Goldring Graded 3', 146, 1, 1, 1, 1, 106, '2011-07-12 20:55:38+00', 3, 'Published by Scotscores, 2008



Doreen Goldring: "When Roy died, this book was in the very early planning stages.  After studying his "possible", "Probable" and "??" lists of dances, I hope that my final selection would have met with his approval and will provide enjoyable dancing for many. 



My thanks to Nancy Dickson, Muriel Johnstone and George Meikle for their kind permission to use their tunes and a special thanks to Muriel for all her help and hard work.', 0, '2008-00-00');
INSERT INTO 'publication' VALUES (1246, '2015-04-14 11:48:25.739966+00', '2022-12-17 20:47:21.146691+00', 'Leaflet Dances 1964-1998 and Other Dances', 'Leaflet & Other Dances 2014', 319, 1, 0, 1, 1, 106, '2015-04-14 12:39:07+00', 0, 'The numbers given reflect the page within this publication for the dance.  

The Society’s books have been reprinted and revised several times. The

books revised and combined in this edition were first published in the

following years:



Five Traditional Scottish Country Dances for 1965, revised 1994  

Four Scottish Country Dances 1978, reprinted 1978  

Five Scottish Country Dances 1982  

The Leaflet Dances with Music 2001  

The Scotia Suite of Scottish Country Dances 2002  

Scottish Country Dances for Perth 800 (2010)', 1, '2014-10-00');
INSERT INTO 'publication' VALUES (1040, '2011-07-11 22:00:00+00', '2017-01-23 05:10:44.950299+00', '12 Scottish Country Dances [Ronald, 2009]', '', 2973, 1, 0, 1, 1, 106, '2011-07-12 09:12:33+00', 3, 'Dedicated, with thanks, to Teresa and Louis Perez, for making their home available for dance testing, and to all dancers who participated.



Special thanks to Keith Rose for the diagrams to accompany each dance,

and to Lydia Hedge for proof-reading.



$10 will be donated to the TAC Jubilee Scholarship Fund in support of training SCD teachers for each copy of this book that is sold.



Copies can be obtained from  cjr878@gmail.com  and  http://store.tac-rscds.org/', 0, '2009-00-00');
INSERT INTO 'publication' VALUES (1304, '2016-06-07 18:13:18.486797+00', '2016-06-07 19:16:00.551627+00', 'Road to Stow, The', 'Road to Stow', 2723, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2015);
INSERT INTO 'publication' VALUES (1300, '2016-05-15 19:44:07.20274+00', '2016-06-05 10:23:21.802314+00', 'Hoon Hay S.C.D.C. 10th Anniversary Dance Book 1987-1997', 'Hoon Hay 10th Anniv. Bk. 1997', 11254, 1, 0, 0, 1, NULL, NULL, 0, '10 dances by members of the Hoon Hay S.C.D.C.



The Hoon Hay Club dances in the Presbyterian Church Hall in Downing Street, Hoon Hay, near Christchurch, New Zealand', 0, '1987-12-01');
INSERT INTO 'publication' VALUES (1305, '2016-06-07 19:37:44.878942+00', '2016-06-08 12:10:27.814548+00', 'Tayside Dance Collection Volume III', 'Tayside Dance Coll 3', 10835, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2015);
INSERT INTO 'publication' VALUES (1299, '2016-05-05 23:13:46.338444+00', '2016-09-04 12:37:09.547908+00', 'Celebrating 50 Years (Los Angeles)', '', 236, 1, 1, 1, 1, NULL, NULL, 0, 'Title page: 



Celebrating 50 years 



25 Scottish Country Dances



Devised by members of the Los Angeles Branch of the Royal Scottish Country Dance Society



Including four original tunes



Published by the Los Angeles Branch  2016



For additional copies of this book, please contact Ann McBride at 818-841-8161', 0, '2016-03-01');
INSERT INTO 'publication' VALUES (1303, '2016-06-04 16:21:13.010868+00', '2016-07-03 20:51:40.164201+00', 'Devonian Double Circle', '', 11264, 1, 0, 0, 1, NULL, NULL, 0, 'This is a book of English Country Dances, of which, as far as the author knows, only one, the Polka Dot Polka, is also danced as a Scottish CD.  ', 0, 0000);
INSERT INTO 'publication' VALUES (142, '2002-12-31 23:00:00+00', '2017-01-21 13:00:02.860289+00', 'Carnforth Collection of SC Dances 1', 'Carnforth 1', 175, 1, 0, 0, 1, 106, '2009-03-13 21:57:43+00', 3, 'First published in July 1991 as "The Carnforth Collection of Scottish Country Dances", it was reprinted (at least) in March 2002 and March 2005 as "The First Carnforth Collection of Scottish Country Dances".', 0, 1991);
INSERT INTO 'publication' VALUES (1458, '2018-07-13 09:48:47.670175+00', '2018-07-13 16:30:52.106474+00', 'Flying Scotsman Dance Collection, Vol. 1', 'Flying Scotsman 1', 11658, 1, 0, 0, 1, 2697, '2018-07-13 09:49:34+00', 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (1392, '2017-11-13 16:23:45.541125+00', '2017-11-13 16:26:32.965613+00', 'Selection of the Present Favourite Country Dances for the Year 1796', 'Favourite Dances 1796', 862, 1, 0, 0, 0, NULL, NULL, 0, 'Quite likely B Cooke was the editor of the book, but not the devisor of the dances it contained.', 0, 1796);
INSERT INTO 'publication' VALUES (1302, '2016-05-27 21:24:25.418536+00', '2017-10-27 23:27:48.902104+00', 'Dances for Avril and David Quarrie', '', 11261, 1, 0, 0, 0, 1645, '2017-10-27 22:35:43+00', 0, '', 0, 2015);
INSERT INTO 'publication' VALUES (1386, '2017-09-26 23:05:04.58775+00', '2018-01-20 16:40:47.896918+00', 'Book of Records', '', 11526, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2017);
INSERT INTO 'publication' VALUES (1395, '2017-11-14 10:09:07.717821+00', '2017-11-14 10:09:53.63955+00', 'Twenty Four Country Dances for 1759', '24 Dances 1759', 466, 1, 0, 0, 0, NULL, NULL, 0, 'Mentioned in Combined RSCDS Books 25-30 as original source of dances.', 0, 1759);
INSERT INTO 'publication' VALUES (1383, '2017-09-05 20:38:22.481424+00', '2018-01-20 16:42:18.526451+00', 'Happy Blues (Pretoria 45th Anniversary)', 'Happy Blues', 3208, 1, 1, 1, 1, 202, '2017-10-21 14:27:35+00', 0, '', 0, 2017);
INSERT INTO 'publication' VALUES (1381, '2017-07-16 11:34:01.748137+00', '2019-06-07 12:23:01.464409+00', 'Book 51 – Scottish Country Dances for Young and Less Experienced Dancers', 'RSCDS LI', 319, 1, 1, 0, 1, 202, '2017-07-17 23:57:18+00', 0, '', 1, 2017);
INSERT INTO 'publication' VALUES (1307, '2016-06-19 10:46:06.873337+00', '2018-10-19 19:24:55.221808+00', 'Harwell Caledonian Society 1948-1998', 'HCS 1948-1998', 11269, 1, 0, 1, 0, 1811, '2018-10-16 12:54:04+00', 0, 'To mark the club''s 50th anniversary.', 0, 1998);
INSERT INTO 'publication' VALUES (1324, '2016-07-02 21:34:13.819253+00', '2018-04-29 23:21:07.034841+00', 'Forty and Counting', '', 426, 1, 1, 1, 1, 202, '2018-04-29 23:21:07.032323+00', 0, '"Eleven dances to celebrate the fortieth anniversary of the branch"', 0, 2016);
INSERT INTO 'publication' VALUES (283, '2002-12-31 23:00:00+00', '2016-06-22 13:16:47.022566+00', 'Croydon and District Ruby Anniversary 1994', 'Croydon Ruby', 92, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (1311, '2016-06-22 22:32:06.707049+00', '2018-03-30 20:29:51.347181+00', 'Quaich Dances 2010 (Dundee), The', '', 112, 1, 0, 1, 1, 202, '2018-03-30 20:29:51.343565+00', 0, 'Two parts



1.  Dundee branch Quaich Dances 2010  p. 4-13



2.  Dundee branch Diamond Jubilee Dances, 1985, p. 15-20  (reprinted from the 1985 "Diamond Jubilee Book"', 0, '2010-00-00');
INSERT INTO 'publication' VALUES (1323, '2016-06-30 17:27:05.088448+00', '2016-06-30 21:40:48.679495+00', 'Southsea Celebrates 50 Years of Scottish Country Dancing', 'Southsea 50', 11280, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2006);
INSERT INTO 'publication' VALUES (1443, '2018-04-03 11:59:35.745181+00', '2018-04-03 11:59:35.745181+00', '11th Book of New and Favorite, Country Dances & Strathspey Reels', 'Campbell''s 11th Book', 263, 1, 0, 0, 0, NULL, NULL, 0, 'The RSCDS publication "Scottish Country Dances Books 13-18" states William Campbell''s *11th Book of New and Favorite, Country Dances, & Strathspey Reels* from about 1790 as a source of dances.', 0, 1790);
INSERT INTO 'publication' VALUES (640, '2002-12-31 23:00:00+00', '2016-09-02 19:20:44.367095+00', 'Morison''s Bush Collection, The', 'Morison''s Bush', 407, 1, 1, 0, 1, 1570, '2016-09-01 01:54:53+00', 0, 'The book was Published to mark the twenty-fifth anniversary of the founding of the Wellington/Hawkes Bay Association and of organised Scottish country dancing in New Zealand 1953-1978.', 0, 1978);
INSERT INTO 'publication' VALUES (1318, '2016-06-23 23:08:56.372095+00', '2016-06-23 23:08:56.372095+00', 'Nine Scottish Country Dances (Churnside)', '', 525, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1322, '2016-06-26 16:40:35.908735+00', '2016-06-26 17:16:53.281072+00', 'Friends and Celebrations - 10 additional dances', '', 2887, 1, 0, 0, 1, NULL, NULL, 0, '10 loose dance sheets were found in the back of a copy of "Friends and Celebrations, Book 2".  They appear here in chronological order.', 0, 0000);
INSERT INTO 'publication' VALUES (1456, '2018-06-10 14:02:25.96757+00', '2019-11-26 09:45:43.220881+00', 'Cat Collection Book Two - Ajax''s Book, The', 'Ajax’s Book', 2766, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (1457, '2018-06-11 09:19:02.371194+00', '2019-11-26 09:46:06.710021+00', 'Cat Collection Book Three - Shadow''s Book, The', 'Shadow’s Book', 2766, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (702, '2002-12-31 23:00:00+00', '2016-06-27 23:47:00.34721+00', '75th Anniversary Dances (Saskatchewan)', '75th Anniv. Saskatchewan', 2930, 1, 0, 0, 1, 538, '2016-06-27 18:37:42+00', 0, '', 0, 1998);
INSERT INTO 'publication' VALUES (1315, '2016-06-22 23:21:25.724545+00', '2016-06-26 12:08:22.696562+00', 'Seven Scottish Dances (YSDA, Volume II)', '', 11272, 1, 0, 1, 1, NULL, NULL, 0, 'to accompany cassette YSDA 2', 0, 1994);
INSERT INTO 'publication' VALUES (1319, '2016-06-23 23:16:52.256621+00', '2017-08-03 13:11:46.158526+00', 'Friends and Celebrations, Book 1', '', 2887, 1, 0, 0, 1, NULL, NULL, 0, '10 dances, still to be entered', 0, 2009);
INSERT INTO 'publication' VALUES (1321, '2016-06-26 14:12:52.27099+00', '2016-06-26 14:57:42.223122+00', '40 Jaar The Rowan Tree Dancers', '', 11278, 1, 0, 1, 1, NULL, NULL, 0, 'This is a celebration booklet.  Only the dances are entered here.', 0, 2015);
INSERT INTO 'publication' VALUES (1331, '2016-09-06 23:28:12.861419+00', '2018-01-22 15:03:19.229388+00', 'Slip Knot Collection plus 7 More', 'Slip Knot + 7', 51, 1, 0, 0, 1, NULL, NULL, 0, 'The original Slip Knot Collection  was released in 1995. It was republished in PDF format and expanded 2012 without music. Finally the was corrected version in 2013.', 0, 2012);
INSERT INTO 'publication' VALUES (1330, '2016-09-04 19:16:33.826305+00', '2018-01-22 15:04:01.421653+00', 'Pinewoods Collection Vol 1-3 +3 others', '', 37, 1, 1, 1, 1, NULL, NULL, 0, 'Some pages have two dances





This publication lists all dances from Pinewoods 1, 2 and 3, except



Dee''s Dandy Dance from Pinewoods 2



Jingling Johnny from Pinewoods 3



and adds four new dances





Long Pond Reel



Pinewoods Return



La Turque



Wedding in the Glen', 0, '2005-00-00');
INSERT INTO 'publication' VALUES (689, '2002-12-31 23:00:00+00', '2016-09-06 23:18:41.383472+00', 'Slip Knot Collection, The', 'Slip Knot', 51, 1, 1, 1, 1, NULL, NULL, 0, 'Published by

Melbourne G. Briscoe

1709 Stonebridge Koad

Alexandria  Virginia 22304, U.S.A.

E-mail: Mel@Briscoe.com', 0, '1995-01-01');
INSERT INTO 'publication' VALUES (1328, '2016-09-03 19:45:07.892457+00', '2016-09-03 20:27:01.413986+00', 'Eight Dances for Anne Hueser', '', 9998, 1, 0, 1, 1, NULL, NULL, 0, 'Published after 2010', 0, 0000);
INSERT INTO 'publication' VALUES (1314, '2016-06-22 23:17:08.404014+00', '2023-02-19 11:42:38.82155+00', 'Six Scottish Dances (YSDA 1)', 'YSDA 1', 11272, 1, 0, 1, 1, NULL, NULL, 0, 'to accompany Cassette YSDA 1', 0, 1993);
INSERT INTO 'publication' VALUES (1317, '2016-06-22 23:42:59.362959+00', '2017-01-08 18:10:07.588191+00', 'Five Scottish Dances (YSDA, Volume IV)', '', 11272, 1, 0, 1, 1, NULL, NULL, 0, 'to accompany cassette YSDA 4', 0, 1996);
INSERT INTO 'publication' VALUES (435, '2002-12-31 23:00:00+00', '2017-04-21 20:38:42.454929+00', 'Silver Thistle Collection, Leeds Branch, The', 'Leeds Silver Thistle', 223, 1, 1, 1, 1, NULL, NULL, 0, 'The Silver Thistle Collection was published to celebrate the 35th Anniversary of the Leeds Branch of the Royal Scottish Country Dance Society.', 0, 1998);
INSERT INTO 'publication' VALUES (1329, '2016-09-03 21:05:58.144444+00', '2017-04-29 15:18:24.895621+00', 'From Paper to Pearl', '', 11035, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (1344, '2016-12-27 01:22:12.516845+00', '2019-01-06 00:37:48.795346+00', 'Reeladelphia 2', '', 10934, 1, 0, 0, 1, NULL, NULL, 0, 'Subtitle: 16 Country Dances by Dan Blim.



Dan Blim writes the name as "2eeladelphia".  This should be noted as an alias, if that function were available', 0, '2016-01-01');
INSERT INTO 'publication' VALUES (1320, '2016-06-23 23:17:55.585844+00', '2017-08-03 13:11:08.022344+00', 'Friends and Celebrations, Book 2', '', 2887, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (477, '2002-12-31 23:00:00+00', '2016-09-09 22:39:07.032176+00', 'Thistle and Trillium, The', 'Thistle & Trillium', 121, 1, 1, 0, 1, NULL, NULL, 0, 'This is a collection of Scottish Country Dances composed by George S. 8mmerson for the repertoire of the U.W.O. Scottish Dance Group, london, Ontario, in the decade 1979-89. 



All the dances in this collection are longwise and progressive, adhering to the form traditionally recognized in Scotland. Two figures with a claim to originality are introduced - the "Planet Reel" and the "Clef" - a few others are simple modifications of standard figures but there are no perverse departures from the basic system of the restored Scottish Country Dance. Nevertheless, the dances are intended for devotees of their form as an art.



SCDDB Editor''s note: we have one original copy which has only the first 9 dances, the other 3 are missing.  They may have been published elsewhere.', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (1333, '2016-09-16 19:30:25.28664+00', '2016-09-16 19:55:18.919421+00', 'Four Corners Dance Book', '', 11363, 1, 1, 1, 0, NULL, NULL, 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (488, '2002-12-31 23:00:00+00', '2016-11-02 14:58:45.595679+00', 'Fiddle Music of Scotland, The', 'Fiddle Music', 1488, 0, 1, 1, 1, NULL, NULL, 0, 'The original edition was published by James Hunter in 1979.



In 1988 Alasdair and William Hardy have edited and corrected the 1st edition to to produce fully-bowed versions of all the 365 melodies, to correct mistakes and oversights from the 1st edition and finally to clarify that all-important ingredient in this music - the ornamentation. (rf. the Preface to the New Edition of 1988)



The 1988 version was published by the Hardy Press, and there were reprints at least 1992, 1995 and 2001.



The information of this entry was quite likely taken from the ''New Edition'' from 1988, since this was the publication date originally indicated in the database.

', 0, '1979-00-00');
INSERT INTO 'publication' VALUES (1444, '2018-04-03 12:06:23.112651+00', '2018-04-03 12:06:23.112651+00', '8th Book of New and Favorite, Country Dances & Strathspey Reels', 'Campbell''s 8th Book', 263, 1, 0, 0, 0, NULL, NULL, 0, 'The RSCDS publication "Scottish Country Dances Books 13-18" states William Campbell''s *8th Book of New and Favorite, Country Dances, & Strathspey Reels* from about 1787 as a source of dances.', 0, 1787);
INSERT INTO 'publication' VALUES (1445, '2018-04-03 12:13:11.220585+00', '2018-04-03 12:13:11.220585+00', 'Collection of Favourite Reels & Strathspeys by the Most Eminent Composers [18C], A', 'Coll Eminent Composers [18C]', 457, 1, 0, 0, 0, NULL, NULL, 0, 'The RSCDS publication "Scottish Country Dances Books 13-18" states W Boag''s *A Collection of Favourite Reels & Strathspeys by the Most Eminent Composers* from 1797 a source of dances.', 0, 1797);
INSERT INTO 'publication' VALUES (1350, '2017-02-13 19:10:42.586105+00', '2019-08-18 19:58:38.02038+00', 'Borderland Dances', '', 11164, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2017);
INSERT INTO 'publication' VALUES (74, '2002-12-31 23:00:00+00', '2018-01-16 19:56:52.638452+00', 'Scottish Country Dances in Diagrams. Ed. 7', 'Pillings 7', 398, 1, 0, 1, 1, NULL, NULL, 0, 'The very first edition of ''The Wee Green Book'' was published in 1955.', 0, 1997);
INSERT INTO 'publication' VALUES (1513, '2019-08-11 20:10:32.643474+00', '2019-08-12 09:12:48.452676+00', 'Homemade Dances, volume 3', 'Homemade Dances 3', 11835, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2008);
INSERT INTO 'publication' VALUES (1338, '2016-10-30 11:21:28.867096+00', '2019-11-26 09:41:39.402834+00', 'Carlingwark Book of Scottish Country Dances by Bill Little, The', 'Carlingwark Book', 11403, 1, 1, 1, 1, 202, '2018-09-05 02:16:37+00', 0, 'Available as a printed book and as a PDF. ', 0, 2016);
INSERT INTO 'publication' VALUES (759, '2002-12-31 23:00:00+00', '2020-12-02 10:48:12.34627+00', 'Glasgow Branch A Collection of Dances for the 75th Anniversary 1923-1998', 'Glasgow 75th', 144, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2008);
INSERT INTO 'publication' VALUES (1340, '2016-12-06 09:26:32.314839+00', '2021-09-11 23:13:44.824867+00', 'Saint Martin Coll. of New Scottish Country Dances Vol 3, The', 'Saint Martin 3', 3618, 1, 0, 0, 1, NULL, NULL, 0, 'Information taken from the TAC Books entry (<<http://books.tac-rscds.org/product_info.php?products_id=1166>>).', 0, 2016);
INSERT INTO 'publication' VALUES (1336, '2016-10-08 23:29:55.51962+00', '2016-10-08 23:31:02.872628+00', 'CD booklet of The Sunday Class Dance Book 2', 'TSC Book 2 CD', 10648, 1, 1, 0, 1, 342, '2016-10-08 23:31:02.870867+00', 0, 'This is the booklet accompanying the CD "The Sunday Class Dance Book 2" by Marian Anderson and her Band.', 0, 2016);
INSERT INTO 'publication' VALUES (1335, '2016-10-08 23:08:47.115074+00', '2016-10-09 22:04:25.126906+00', 'Sunday Class Dance Book 2, The', 'TSC Book 2', 10648, 1, 1, 1, 1, 342, '2016-10-08 23:31:06+00', 0, 'There is an additional dance description (Staircase in Styria by Margaret Gray) with its tune by Marian Anderson in the booklet of The Sunday Class CD 2.', 0, 2016);
INSERT INTO 'publication' VALUES (1345, '2017-01-04 17:21:26.801603+00', '2017-01-04 18:05:26.579535+00', 'Dancing in Southsea', '', 11110, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2006);
INSERT INTO 'publication' VALUES (1339, '2016-11-05 13:17:20.551894+00', '2018-01-22 15:00:28.316037+00', 'Platinum Dance Book 1946-2016 (Birmingham)', 'Birmingham Platinum Book 2016', 32, 1, 1, 1, 1, 202, '2017-08-03 07:23:05+00', 0, '', 0, 2016);
INSERT INTO 'publication' VALUES (1343, '2016-12-23 23:48:08.355672+00', '2016-12-27 02:05:47.766523+00', 'Glenshee Collection, The', 'Glenshee-83', 87, 1, 0, 0, 1, NULL, NULL, 0, 'All these dances also appear in "The New Glenshee Collection".', 0, 1983);
INSERT INTO 'publication' VALUES (1346, '2017-01-20 01:45:17.692589+00', '2017-01-20 01:45:17.692589+00', 'Dances of the Budapest Scottish Dance Club Vol. 2', 'Budapest Vol. 2', 3659, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (1348, '2017-01-20 02:40:58.769425+00', '2018-01-21 14:37:23.078608+00', 'Waratah Collection - Edition 2005', 'Waratah Coll 2005', 74, 1, 0, 0, 1, NULL, NULL, 0, 'The Waratah is the floral emblem of New South Wales and is prominent in the bush in spring near the author’s home. (Cover Photo: Brian Charlton)', 0, 2005);
INSERT INTO 'publication' VALUES (434, '2002-12-31 23:00:00+00', '2017-01-21 12:53:22.887969+00', 'Carnforth Collection of SC Dances 4', 'Carnforth 4', 175, 1, 0, 0, 1, 106, '2009-03-13 21:58:17+00', 3, 'On the title page: "First printed in August 1998 by Paul Bond".  Copyright Derek Haynes.



First published in August 1998, it was reprinted in October 2002. In that edition Paul Bond is only mentioned on the back.', 0, '1998-08-01');
INSERT INTO 'publication' VALUES (837, '2002-12-31 23:00:00+00', '2017-01-22 13:39:26.847159+00', 'Ruby Anniversary Collection', 'Brighouse: Ruby', 3175, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (1316, '2016-06-22 23:32:30.183798+00', '2023-02-19 11:59:42.251458+00', 'Six Scottish Dances (YSDA, Volume III)', '', 11272, 1, 0, 1, 1, NULL, NULL, 0, 'to accompany cassette YSDA 3



The dance on p. 7 needs to be checked; in this booklet it is called "A Progressive Circle Waltz", which may be a different dance.  ', 0, '1995-00-00');
INSERT INTO 'publication' VALUES (1334, '2016-10-04 23:37:30.857071+00', '2018-01-22 15:02:28.382352+00', 'Excited States', '', 11388, 1, 1, 1, 1, NULL, NULL, 0, '12 Scottish Country Dances  And 18 tunes 



By Kristi Closser, Bruce Herbold, David Newitt and the members of StringFire! 



', 0, '2016-01-01');
INSERT INTO 'publication' VALUES (1393, '2017-11-13 22:42:25.681899+00', '2018-04-03 09:18:03.70154+00', 'Collection of Scots Reels or Country Dances for the year 1769, A', 'Reels or Country Dances 1769', 442, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 1769);
INSERT INTO 'publication' VALUES (1195, '2014-08-31 16:34:32.916223+00', '2017-02-24 23:54:43.629076+00', 'Angus Scottish Country Dance Book, An', 'Angus Book', 2913, 1, 1, 1, 1, NULL, NULL, 0, 'Date of publication unknown, but after 2006. 



Bunty Wilson has taught Scottish Country Dancing in Montrose for many years. As a tribute, the dance “Tribute to Bunty” was composed in her honour and was first danced by a set trained by Irene Farnell, the other teacher in Montrose. Irene’s efforts to have the dance published by the Royal Scottish Country Dance Society were rejected. This led to the idea that it should be published independently. It was then discovered that there were a number of other dances composed in Angus that had not been published, and this in turn led to the idea of publishing a collection.



Dances contributed to the collection were composed by Muriel Boal, Charles Auld, Mary Gardner and Mark Noble.  Dances include some more suitable for beginners and some for more advanced dancers.



The music for “Tribute to Bunty” was composed especially by Jimmy Boal. Most of the other music is derived from the Caledonian Companion collection of traditional Scottish tunes. 



Many of the dances are linked to places in Angus, to other activities, to looking at the glens, and the history of the area.

', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (467, '2002-12-31 23:00:00+00', '2019-09-13 14:59:14.704042+00', 'Whetherly Book 17', 'Whetherly 17', 270, 1, 0, 0, 1, NULL, NULL, 0, 'In the original book the dances are each printed on one or two pages. In this SCDDB record, the dances are numbered by page number.', 0, 1986);
INSERT INTO 'publication' VALUES (1360, '2017-03-31 09:18:59.553422+00', '2018-04-11 09:19:27.001387+00', 'Decade Dances', '', 11470, 1, 1, 0, 1, 202, '2018-04-11 09:19:26.997939+00', 0, 'Three of the dances have music written for them. ', 0, 2017);
INSERT INTO 'publication' VALUES (362, '2002-12-31 23:00:00+00', '2017-03-07 01:53:56.884066+00', 'Stepping Out Part 2 - Progressive SCDs for Beginners (Original)', 'Stepping Out 2 Original', 872, 1, 0, 1, 1, 202, '2017-03-04 08:59:24+00', 0, 'Somewhere around 2014 Marylin Watson published this revised edition of "Stepping Out 2" of 1997.  That is listed separately as publication 1353.



Some dances have changed, e.g. 



"Over the Heather" has changed from a 2C/4L S 24 into a 2C/4L J 32.



"A Passng Fancy" has changed from a 2C/4L S 32 into a 2C/4L R 32', 0, '1997-00-00');
INSERT INTO 'publication' VALUES (1355, '2017-03-10 17:09:28.6044+00', '2017-03-10 17:09:28.6044+00', 'Dances published by Minicrib', '', 11464, 1, 1, 0, 0, NULL, NULL, 0, 'This is the page of the Minicrib website where anyone can publish dances or dance collections.', 0, 2016);
INSERT INTO 'publication' VALUES (1358, '2017-03-24 18:06:58.982617+00', '2020-07-21 13:23:18.910989+00', 'Emigrant Scot, The', 'Emigrant Scot', 50, 1, 1, 1, 1, 645, '2020-07-21 13:23:18.906389+00', 0, '', 0, 2016);
INSERT INTO 'publication' VALUES (394, '2002-12-31 23:00:00+00', '2020-11-15 19:27:59.921252+00', 'Dances With a Difference, Vol I', 'Brandon: Dances w. Diff. 1', 50, 1, 0, 1, 1, NULL, NULL, 0, 'The first edition of this publication contained just 12 dances. A further five were added in the revised edition, dated 2002. These are the last five listed here (pages 26-30 in the publication).', 0, 1998);
INSERT INTO 'publication' VALUES (1446, '2018-04-03 12:18:55.96636+00', '2021-06-12 17:58:12.325806+00', 'Caledonian Country Dances [1748]', 'Caledonian 1748', 198, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 1748);
INSERT INTO 'publication' VALUES (1354, '2017-03-10 16:08:36.465345+00', '2021-10-09 23:39:22.52523+00', 'Dances published on the Minicrib website', 'Published on Minicrib', 11464, 1, 1, 0, 0, NULL, NULL, 0, 'This is the page of the Minicrib website where anyone can publish SC dances or dance collections.



That web page (<<http://www.minicrib.org.uk/publish.html>>) now contains many more dances than are currently included in this entry.

', 0, '2016-00-00');
INSERT INTO 'publication' VALUES (1342, '2016-12-18 21:47:41.300818+00', '2018-01-21 14:39:19.435024+00', 'Belfast Branch Platinum Anniversary Dances', '', 569, 1, 1, 0, 1, 1483, '2017-01-05 00:24:50+00', 0, 'The Belfast Branch Platinum Anniversary Dances is a Book of 14 dances (with sheet music) with accompanying CD (track 15 is a waltz) by Marian Anderson''s Scottish Dance Band which was launched at a Gala Evening in Belfast on December 3rd 2016.



With regard to SCDDB and MiniCrib, Belfast Branch has expressly requested that no crib, diagram or video of any of the dances be made publicly available in the short term. In the meantime, only the ''bare bones'' of this publication may appear on SCDDB.', 0, '2016-12-01');
INSERT INTO 'publication' VALUES (111, '2002-12-31 23:00:00+00', '2017-04-01 23:08:29.309883+00', 'Flowing Reels and Proud Poussettes', 'Flowing Reels...', 145, 1, 1, 1, 1, 106, '2012-02-14 22:36:21+00', 0, 'The dance "Canadian Corn Rigs" is not listed in the Table of Contents of this book, but presented "on the sly" in the introduction on page 16.  See the dance for more "Extra Info".', 0, 1988);
INSERT INTO 'publication' VALUES (1387, '2017-10-01 22:15:14.314572+00', '2017-10-01 22:15:18.254621+00', 'Stirling at 90', '', 375, 1, 0, 0, 0, NULL, NULL, 0, 'Provisional entry, while waiting for a full original copy of the publication', 0, 2017);
INSERT INTO 'publication' VALUES (1175, '2014-03-17 22:37:35.982618+00', '2017-07-25 09:25:26.118375+00', 'Suncoast Collection, The', 'Suncoast Coll', 10898, 1, 1, 1, 1, NULL, NULL, 0, 'This has been re-edited several times to add corrections, but the various editions are not clearly identified on the front page or in their PDF file name. The version of June 2014 has the filename "Sun-BookNew.pdf".  It replaces "TheSuncoastCollection-v3.pdf" and earlier editions.  The website offers a dec. 2014 edition, but gives no information on any further corrections.', 0, 2014);
INSERT INTO 'publication' VALUES (1378, '2017-06-22 17:56:31.928006+00', '2017-07-30 11:04:21.682657+00', 'Auckland Suite, The', '', 10907, 1, 0, 0, 1, NULL, NULL, 0, 'Reprinted by Queensland Branch in 2017

Includes the recipe for Gin Strawberry', 0, '2013-02-01');
INSERT INTO 'publication' VALUES (1363, '2017-04-29 15:10:07.670309+00', '2017-10-12 15:58:33.103544+00', 'Mrs Hepburn Belches and Miss Murray, Lintrose', '', 277, 1, 1, 0, 1, NULL, NULL, 0, 'The dance descriptions in this leaflet are as in the original publication by John Bowie of Perth (from the mid-18th century). The tunes have been arranged by Ian Macleish.', 0, 1954);
INSERT INTO 'publication' VALUES (1359, '2017-03-31 08:50:24.826125+00', '2018-01-20 16:48:09.391038+00', 'Stepping Out Part 3 - More advanced SCDs for beginners (Revised)', 'Stepping Out 3 Revised', 872, 1, 0, 1, 1, 202, '2017-03-31 08:53:10+00', 0, '', 0, 2014);
INSERT INTO 'publication' VALUES (1394, '2017-11-14 09:49:03.620173+00', '2017-11-14 10:55:00.643393+00', 'Hill Manuscript (Aberdeen)', 'Hill', 9998, 1, 0, 0, 0, NULL, NULL, 0, 'The combined RSCDS Books mention the "Hill Manuscript" (Aberdeen) from 1841 as the source of dances like the <<ddd:Lady of the Lake>>, <<ddd:Miss Dumbreck>> and <<ddd:Burns'' Hornpipe>>.', 0, 1841);
INSERT INTO 'publication' VALUES (469, '2002-12-31 23:00:00+00', '2019-09-13 15:08:05.734677+00', 'Whetherly Book 19', 'Whetherly 19', 270, 1, 0, 0, 1, NULL, NULL, 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages. In this SCDDB record, the dances are numbered in succession, and not by page number.', 0, 1986);
INSERT INTO 'publication' VALUES (471, '2002-12-31 23:00:00+00', '2019-09-13 15:14:26.898089+00', 'Whetherly Book 21', 'Whetherly 21', 270, 1, 0, 1, 1, NULL, NULL, 0, 'In the original book the dances are each printed on one or two pages. In this SCDDB record, the dances are numbered by page number.', 0, 1987);
INSERT INTO 'publication' VALUES (1397, '2017-11-14 10:41:57.382111+00', '2017-11-14 10:41:57.382111+00', 'Collection of Strathspey Reel and Country Dances (Perth, 1789)', 'Dances 1789', 1749, 1, 0, 0, 0, NULL, NULL, 0, 'The combined RSCD SCD Books 25-30 state this the source of which dances have been adapted freely.', 0, 1789);
INSERT INTO 'publication' VALUES (1631, '2022-04-27 22:01:34.932606+00', '2022-06-22 22:32:20.964357+00', 'Argentine Collection 2020, The', '', 2101, 1, 1, 1, 1, 202, '2022-05-04 12:39:18+00', 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (1361, '2017-04-12 13:43:47.174034+00', '2017-04-12 20:42:04.531951+00', 'Flype Collection, The', '', 1167, 1, 0, 1, 1, NULL, NULL, 0, 'Created at T.A.C. Summer School Units 2 and 3 Candidate Classes, July 22 to August 5, 2012



To Alan Twhigg for his calming presence and excellent teaching, and

Ron Krug for his 10 magic fingers and inspiring music



Flype: to turn inside out, as in a sock, is also the little known name of the formation occurring in the final four bars of Miss Hadden’s Reel. The couples are in the order 3rd couple, 1st couple, 2nd couple. 3rd couple casts off to 3rd place. 1st and 2nd couples dance up and cast off into 2nd and 1st places, respectively.



This formation can be done in a variety of ways, with three or four couples. The couples may be in different orders, and they may flype in different directions.  



The earliest known use of the word is in 1530 in John Palsgrave’s Lesclarcissement de la langue francoyse. The modern spelling is flipe.

From the Oxford English Dictionary Online: flipe, v. To turn up or down, to fold back; also, to turn inside out. 



Class Members: Lou Hanson, Gavin Keachie, Kalindi Devi-Dasi, Crystal Goodwin, Sarah MacQueen, Margaret Leversha, Mei-Hwa Neal, Karen Pestana, Tiffany Clede, Heather Clede, Elizabeth Woodbury, Ilse Gilbert, Holly Boyd, Deborah Leary, Peter Price, Kathy Byers', 0, '2012-08-05');
INSERT INTO 'publication' VALUES (1362, '2017-04-29 15:03:49.033049+00', '2017-04-29 15:04:59.22614+00', 'New Scotland Strathspey, The', '', 277, 1, 1, 0, 1, NULL, NULL, 0, 'Single-dance leaflet. The title page says “The New Scotland Strathspey – Dance devised by Capt. E. G. Elder, Black Watch (R. H. R.) – Composed by Calum Bolton – Arranged for Piano and Piano-Accordion by Ian MacLeish – With complete dance instructions”.



It doesn''t give a publication date but Anselm''s copy has a sticker that gives the price as “2/- net”, which puts it before 1970 (if you hold the sticker in front of a strong lamp you can see that the leaflet originally retailed for 1/6).', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (1364, '2017-05-07 00:25:27.923007+00', '2017-05-07 00:25:27.923007+00', 'Fusions of Fancy', 'Fusions', 11481, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2017);
INSERT INTO 'publication' VALUES (1365, '2017-05-09 18:16:27.35961+00', '2017-05-09 18:16:27.35961+00', 'Ashmerg Collection, The', 'Ashmerg', 11482, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 2017);
INSERT INTO 'publication' VALUES (1366, '2017-05-10 22:49:51.507553+00', '2017-05-10 23:08:22.845671+00', 'Higham Hall Anniversary Booklet - Four Scottish Country Dances', 'Higham Hall Anniversary- 4SCD', 9998, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2017);
INSERT INTO 'publication' VALUES (1223, '2015-02-05 13:45:23.857633+00', '2017-05-23 22:09:43.75708+00', 'Munich Anniversary Book', '', 11069, 1, 1, 1, 1, NULL, NULL, 0, 'The Munich Anniversarv Book was published to celebrate 40 years of Scottish country dancing in Munich (1973-2013).

', 0, '2013-07-01');
INSERT INTO 'publication' VALUES (1380, '2017-06-22 17:57:43.720918+00', '2018-05-26 01:47:10.1294+00', 'From the Danube To the Liffey', '', 10907, 1, 0, 0, 1, 202, '2018-05-26 01:47:10.127846+00', 0, 'Reprinted by Queensland Branch in 2017', 0, 2015);
INSERT INTO 'publication' VALUES (1353, '2017-03-07 00:37:14.674658+00', '2018-01-20 16:49:15.822062+00', 'Stepping Out Part 2 - Progressive SCDs for Beginners (Revised)', 'Stepping Out 2 Revised', 872, 1, 0, 1, 1, 202, '2017-03-07 15:44:51+00', 0, 'Most of these dances can be danced as a Reel, Jig or Strathspey



Somewhere around 2014 Marylin Watson published this revised edition of "Stepping Out 2" of 1997.  The original is listed as publication 362.



Some dances have changed, e.g. 



"Over the Heather" has changed from a 2C/4L S 24 into a 2C/4L J 32.



"A Passng Fancy" has changed from a 2C/4L S 32 into a 2C/4L R 32', 0, '2014-00-00');
INSERT INTO 'publication' VALUES (1391, '2017-11-13 01:55:55.440718+00', '2021-01-05 18:04:56.156817+00', 'Ruby Anniversary Book - Scottish Country Dances from Connecticut', 'Connecticut Ruby', 285, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2017);
INSERT INTO 'publication' VALUES (1372, '2017-06-05 23:09:24.137067+00', '2021-03-12 09:42:33.721308+00', 'RSCDS Cheltenham Branch 50th Anniversary Dance Leaflet', 'Cheltenham 50', 11492, 1, 0, 0, 1, NULL, NULL, 0, 'RSCDS Cheltenham was formed in 1958.', 0, 2007);
INSERT INTO 'publication' VALUES (1373, '2017-06-08 10:03:44.210978+00', '2017-06-08 10:03:44.210978+00', 'Schiehallion', '', 129, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1971);
INSERT INTO 'publication' VALUES (1136, '2013-03-23 17:50:24.734294+00', '2017-06-05 00:32:39.555604+00', '20 New Dances by John Drewry 1999-2000', '', 108, 1, 0, 0, 1, NULL, NULL, 0, 'Most of these dances have also been published in other books, like the Greenburn book.   A check my still be needed to see if the descriptions in the different publications are identical.



The dances have been entered below in the order given in the original Table of Contents.



In that table. dance 8 is spelled "The Fruit Cake".', 0, '2000-00-00');
INSERT INTO 'publication' VALUES (1369, '2017-05-11 09:58:35.79077+00', '2018-12-17 18:53:46.710699+00', 'From Near and Far (Longwood 2)', '', 10971, 1, 0, 1, 1, NULL, NULL, 0, 'This is volume 2 of the Longwood Collection', 0, 2017);
INSERT INTO 'publication' VALUES (1411, '2018-01-18 20:59:17.635037+00', '2018-01-20 16:31:01.026126+00', '22 Social Dances by Roy Goldring with Music', '22 Goldring Dances', 340, 1, 1, 0, 1, NULL, NULL, 0, 'This is the compilation of Roy Goldring''s books "10 Social Dances" and "Twelve More Social Dances".', 0, 2010);
INSERT INTO 'publication' VALUES (83, '2002-12-31 23:00:00+00', '2017-06-09 23:06:18.192856+00', 'Silver Collection [Leicester 2002], The', 'Leicester 25', 224, 1, 1, 1, 1, NULL, '2012-01-27 11:42:12+00', 0, 'These 10 dances devised by the Branch members to celebrate the 25th Anniversary have been carefully chosen from those submitted.  



The music is a mixture, some of which has been especially composed for us, and some of course is traditional.



The CD that accompanies this collection has the music and descriptions of these 10 dances.  That CD also has the music and descriptions of five other leaflet dances published over the preceding 10 years by the Leicester Branch; these are Jaunty Jack, The Jovial Gentleman, Daunder in the Glen, The Heather Bank Jig, Bonnie Buchanhaven.   In this database those dances are listed as a separate publication (http://my.strathspey.org/dd/publication/1297/), as they are not actually part of "The Silver Collection".

', 0, '2002-00-00');
INSERT INTO 'publication' VALUES (1375, '2017-06-22 11:11:41.461604+00', '2017-06-22 11:29:52.963764+00', 'Dancing Brolga Collection of Scottish Country Dances - Volume 1, The', 'Dancing Brolga Collection - I', 10907, 1, 0, 0, 1, NULL, NULL, 0, 'Reprinted by Queensland Branch in 2017', 0, 2012);
INSERT INTO 'publication' VALUES (1377, '2017-06-22 17:20:32.92031+00', '2017-06-23 07:57:59.60869+00', 'Dancing Brolga Collection of Scottish Country Dances - Volume 3, The', 'Dancing Brolga Collection - 3', 10907, 1, 0, 0, 1, NULL, NULL, 0, 'Reprinted by Queensland Branch in 2017', 0, 2013);
INSERT INTO 'publication' VALUES (1376, '2017-06-22 17:19:36.356897+00', '2017-06-23 07:57:54.061888+00', 'Dancing Brolga Collection of Scottish Country Dances - Volume 2, The', 'Dancing Brolga Collection - 2', 10907, 1, 0, 0, 1, NULL, NULL, 0, 'Reprinted by Queensland Branch in 2017', 0, 2012);
INSERT INTO 'publication' VALUES (1379, '2017-06-22 17:57:04.448324+00', '2017-07-30 11:03:51.857026+00', 'Clan Mackenzie, The', '', 10907, 1, 0, 0, 1, NULL, NULL, 0, 'Reprinted by Queensland Branch in 2017', 0, 2013);
INSERT INTO 'publication' VALUES (1382, '2017-08-05 13:33:59.271103+00', '2017-08-05 13:33:59.271103+00', 'Great Dances for Small Groups', '', 11514, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2017);
INSERT INTO 'publication' VALUES (1390, '2017-10-22 22:32:20.258664+00', '2017-11-21 14:01:14.715226+00', 'Two National Dances of Scotland', '', 11538, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 1950);
INSERT INTO 'publication' VALUES (1396, '2017-11-14 10:32:33.800236+00', '2017-11-14 10:38:02.059631+00', 'New Lanark Collection', 'New Lanark', 482, 1, 0, 0, 0, NULL, NULL, 0, 'Book 26 credited the dance <<ddd:New Waterloo Reel>> to the *New Lanark Collection* of Robert Owen. New Lanark was a cotton-processing “model village” on the river Clyde south-east of Glasgow which was essentially owned by Owen, who was a social reformer as well as an entrepreneur and believed in keeping his workers entertained in a wholesome fashion, which apparently included dancing. There is no evidence that Owen himself wrote the dance; he probably underwrote the publication of the dance book.



However, the Combined RSCDS Books 25-30 state: The source previously given for this dance is *The Collection of Robert Owen* but we have not been able to verify this.



Furthermore, the collection might refer to the general collection of material at New Lanark and not to a booklet with that name.', 0, '0001-00-00');
INSERT INTO 'publication' VALUES (1385, '2017-09-25 18:33:30.248542+00', '2022-01-09 18:27:57.70561+00', 'Célébrations', '', 10568, 1, 0, 1, 1, 202, '2018-03-17 11:17:43+00', 0, '', 0, 2017);
INSERT INTO 'publication' VALUES (1659, '2022-09-15 13:18:04.900813+00', '2022-09-15 13:20:48.384042+00', 'Scottish Country Dances Books 39 to 44 (Combined A5 edition)', 'Books 39 - 44', 319, 1, 0, 1, 1, NULL, NULL, 0, '', 1, 2021);
INSERT INTO 'publication' VALUES (1447, '2018-04-05 16:03:59.417627+00', '2018-04-05 16:05:20.738901+00', 'Repeat Prescription (PDF)', 'Repeat Prescription ', 21, 1, 0, 1, 0, NULL, NULL, 0, 'Published as a PDF with slightly different contents than the original paper version and includes some of the dances from Dance and Celebration.', 0, 2018);
INSERT INTO 'publication' VALUES (1398, '2017-11-14 10:48:34.330396+00', '2017-11-14 10:49:48.602271+00', 'Twenty Four New Country Dances 1775', '24 Dances 1775', 11564, 1, 0, 0, 0, NULL, NULL, 0, 'Mentioned in the Combined RSCDS *SCD Books 25-30* as the source of dances.', 0, 1775);
INSERT INTO 'publication' VALUES (1400, '2017-11-14 10:53:14.130063+00', '2017-11-14 10:53:14.130063+00', 'Preston''s New Country Dances 1797', 'Preston 1797', 459, 1, 0, 0, 0, NULL, NULL, 0, 'This is stated as the source of dances in the Combined RSCDS *SCD Books 25-30*.', 0, 1797);
INSERT INTO 'publication' VALUES (1403, '2017-11-27 14:18:30.261329+00', '2017-11-27 14:46:55.676232+00', 'Scottish Country Dances Books 31 to 38 (Combined A5 edition)', 'Books 31-38', 319, 1, 0, 1, 1, NULL, NULL, 0, '', 1, 2017);
INSERT INTO 'publication' VALUES (1371, '2017-05-27 20:40:47.264944+00', '2017-12-21 08:19:21.237352+00', 'Anniversary Suite (San Francisco 40th)', '', 338, 1, 0, 0, 0, NULL, NULL, 0, 'Jenifer Kelly writes:    

Notes for teachers on the dances in the Anniversary Suite.   

As I devised these dances I had a particular teaching point in mind for each of them.  



These teaching notes can be found at 

http://rscds-sf.org/resources/dances/Anniversay%20Suite%20Notes.pdf', 0, '2005-04-01');
INSERT INTO 'publication' VALUES (1401, '2017-11-17 08:36:01.000853+00', '2018-01-19 10:30:45.313237+00', 'Dances to Honour Elma McCausland MBE', 'Elma McCausland', 569, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 2017);
INSERT INTO 'publication' VALUES (1402, '2017-11-23 18:36:05.145443+00', '2018-01-19 10:38:55.867116+00', 'Southern Skies', '', 287, 1, 1, 0, 1, NULL, NULL, 0, 'The dances published in this book are the result of a request from the New Zealand Branch.



When the RSCDS was looking for Book 49, all branches throughout the world were asked to submit one dance for consideration. The New Zealand Branch is made up of eleven regions. Each region was asked to submit a dance that had not previously been published. These dances were trialled and one was selected for the Society''s consideration. Unfortunately that dance was not chosen for Book 49.

A decision had previously been made to publish all the regions'' submitted dances in our own New Zealand publication. This is the result.', 0, '2015-12-01');
INSERT INTO 'publication' VALUES (1407, '2018-01-04 10:49:05.809373+00', '2018-01-20 16:32:43.425383+00', 'Scottish Country Dances in Diagrams. Ed. 9', 'Pillings 9', 398, 1, 0, 1, 1, NULL, NULL, 0, 'The very first edition of ''The Wee Green Book'' was published in 1955.', 0, 2017);
INSERT INTO 'publication' VALUES (1406, '2017-12-27 19:39:03.757878+00', '2018-08-19 21:28:09.979663+00', 'May I have the Pleasure?', '', 44, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2017);
INSERT INTO 'publication' VALUES (1374, '2017-06-18 14:07:26.676406+00', '2021-05-11 09:36:20.268449+00', 'Spark O'' Water', 'Spark O'' Water', 11499, 1, 1, 1, 1, 202, '2017-06-18 16:38:26+00', 0, 'Published to celebrate the 35th Anniversary of the RSCDS Nova Scotia Branch. Dances devised by and for NS dancers over the years.', 0, 2017);
INSERT INTO 'publication' VALUES (1027, '2011-03-28 22:00:00+00', '2018-02-12 17:50:47.211176+00', 'Diamond Jubilee Collection (Inverness), The', 'Inverness 60y', 10324, 1, 1, 1, 1, 104, '2011-08-22 21:46:02+00', 0, 'The dance "Away Tae Moray" was composed in July 2008 for the chairman of the RSCDS Inverness and District Branch.  It was included in their 2009 "Diamond Jubilee Collection" under the name "The Telford Hornpipe".  The deviser published the dance in her own "The Corberry Collection" using the original name, which she prefers.  ', 0, 2009);
INSERT INTO 'publication' VALUES (898, '2003-02-28 23:00:00+00', '2018-09-16 10:10:05.253741+00', 'Gaelic College SCD Book #12: Corrie Dances', 'Corrie Dances', 2018, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (377, '2002-12-31 23:00:00+00', '2018-09-16 09:40:28.020891+00', 'Gaelic College SCD Book #6: A Dozen Dances', 'Dozen Dances', 2018, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1482, '2018-09-18 20:13:57.14363+00', '2018-09-18 23:45:53.666549+00', 'Central Iowa 25th Anniversary Book', 'Iowa 25th', 11712, 1, 0, 0, 1, NULL, NULL, 0, '25th Ball Book of Dances



Dances from RSCDS-CI members and nearby friends', 0, '2016-04-20');
INSERT INTO 'publication' VALUES (1404, '2017-11-27 18:47:59.560477+00', '2019-03-10 22:51:25.65792+00', 'Deep Cove Collection of Dances, The', 'Deep Cove Collection', 11571, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2016);
INSERT INTO 'publication' VALUES (1410, '2018-01-17 11:18:17.220698+00', '2018-01-17 11:19:09.890078+00', 'Muriel Hadden''s Strathspey (leaflet)', 'Muriel Hadden''s Strathspey', 108, 1, 1, 0, 1, NULL, NULL, 0, 'Dedicated to Miss Muriel Hadden in reccognition of her many services to the Royal Scottish Country Dance Society.



All proceeds from the sale of this leaflet had been sent to Miss Hadden for her to use in her social work.', 0, '1967-00-00');
INSERT INTO 'publication' VALUES (1408, '2018-01-13 10:21:09.019288+00', '2018-05-08 16:54:31.742405+00', 'From North Cape to the Bluff', 'North Cape', 287, 1, 1, 0, 1, 202, '2018-05-08 16:54:31.738712+00', 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (1412, '2018-01-18 21:20:43.691966+00', '2018-01-18 21:20:43.691966+00', 'Border Lassies + The Dumfries Lad [leaflet]', '', 146, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1985);
INSERT INTO 'publication' VALUES (617, '2002-12-31 23:00:00+00', '2018-01-18 21:32:35.886114+00', 'Crowe''s Nest Set, The', 'Crowe''s Nest', 146, 1, 1, 0, 1, 104, '2009-03-15 10:39:12+00', 0, 'The two tunes are on a loose sheet lying in this leaflet.



But since the envelope states "Musical Arrangements Copyright Muriel Johnstone 1997", the music definitely belongs to the leaflet.', 0, '1997-00-00');
INSERT INTO 'publication' VALUES (1415, '2018-01-18 22:42:17.414391+00', '2018-01-18 22:42:17.414391+00', 'Grimaldi 700 [leaflet]', '', 11591, 1, 0, 0, 1, NULL, NULL, 0, 'The dance was devised by Roy Goldring for the Scottish Dance Group of Monaco to celebrate the 700th anniversary of the arrival of the Grimaldi family in Monaco.



The movements are based on the shape of the family crest (which is depicted on the leaflet).', 0, '1996-00-00');
INSERT INTO 'publication' VALUES (1417, '2018-01-18 22:59:14.688232+00', '2018-01-18 22:59:14.688232+00', 'North Grove', '', 146, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1993);
INSERT INTO 'publication' VALUES (1418, '2018-01-18 23:04:57.571891+00', '2018-01-18 23:04:57.571891+00', 'Scotland''s Gardens', '', 146, 1, 1, 0, 1, NULL, NULL, 0, 'The dance "Scotland''s Gardens" has been devised by Roy Goldring to mark the Diamond Jubilee of Scotland''s Gardens Scheme 1931-1991.', 0, 1991);
INSERT INTO 'publication' VALUES (1419, '2018-01-19 09:36:28.556475+00', '2018-01-19 09:36:28.556475+00', 'Southern Cairn [leaflet], The', '', 146, 1, 1, 0, 1, NULL, NULL, 0, 'The dance was devised by Roy Goldring for the Addlestone and District Scottish Society to celebrate their Diamond Jubilee season, 1993-94.', 0, 1993);
INSERT INTO 'publication' VALUES (626, '2002-12-31 23:00:00+00', '2018-01-19 09:43:43.771372+00', 'Two Celebration Dances', '2 Celebr.', 146, 1, 1, 0, 1, 104, '2009-03-15 10:41:23+00', 0, 'The leaflet mentions under the Celebration Jig that the St. Columba''s class in Leeds celebrated its 30th Anniversary in November 1994. This does of course not necessarily mean that this is also the publication year of the leaflet.



The tune "The Tillytweedle Cat Army" is marked to be from 1989.', 0, '1994-00-00');
INSERT INTO 'publication' VALUES (625, '2002-12-31 23:00:00+00', '2018-01-19 09:56:47.737767+00', 'Welcome to Hamilton', 'Hamilton Welcome', 166, 1, 1, 0, 1, NULL, NULL, 0, 'The two dances have been devised in 1999 by Roy Goldring. 



"Hamilton Welcome" is dedicated to the Hamilton (Ontario) Branch of the RSCDS, while "Hamilton Hospitality" is inscribed for Margaret and John Walton as well as Carol and John Dinsmore, the hosts for the Hamilton (Ontario) Branch Weekend.



Further information from the leaflet: 

Roy Goldring and his wife, Doreen, came to Hamilton, Ontario in October 1999 for the annual Hamilton Branch Weekend. It was the Goldrings'' first visit to Canada and we had the privilege of introducing them to Hamilton and the Niagara Peninsula.



We had a wonderful time with Roy - learning new dances and dancing past favourites. At the conclusion of the weekend, we were honoured when Roy presented the branch with these two fine dances.



Thank you, Roy. We hope with this leaflet to share them with Scottish Country Dancers around the world.



The dance, "Hamilton Hospitality" was featured on the program for our Millennium Ball, April 1, 2000. Bobby Brown introduced the tune "John Middleton''s Reel" on that occasion.



The tune selected for "Hamilton Welcome", "Roy''s Threescore And Ten", was composed by Alastair Hunter and named for Roy Goldring.



The Hamilton Branch thank both Bobby and Alastair for permission to include their music in this leaflet.

', 0, '2000-00-00');
INSERT INTO 'publication' VALUES (1420, '2018-01-19 12:11:00.63124+00', '2018-01-19 12:11:00.63124+00', 'Banks of the Limmat [leaflet], The', '', 671, 1, 0, 0, 1, NULL, NULL, 0, 'Devised by Christopber Harris with music by lain Stuart Robertson.



The dance is dedicated to Prue Brunner, and presented to her on the 24th March 1987 on the occasion or her retirement from the position of president of the Zürich Scottish Country Dancing Club in which position she has loyally served the club for twenty years.', 0, '1987-03-24');
INSERT INTO 'publication' VALUES (1421, '2018-01-19 13:55:57.162373+00', '2018-01-19 13:55:57.162373+00', 'Mein Heidelberg [leaflet]', '', 11593, 1, 0, 0, 1, NULL, NULL, 0, 'The dance was devised for the Heidelberg Jubilee Ball in 2013, celebrating  25 Years of Scottish Country Dancing in Heidelberg.', 0, 2013);
INSERT INTO 'publication' VALUES (1413, '2018-01-18 21:28:09.55056+00', '2019-11-26 09:43:10.289395+00', 'Cairn Strathspey + Miss Ann Dickson [leaflet], The', '', 146, 1, 1, 0, 1, NULL, NULL, 0, 'The dates of the tunes state 1974. Whether the leaflet was published the same year is not entirely certain.', 0, 1974);
INSERT INTO 'publication' VALUES (1416, '2018-01-18 22:55:10.60647+00', '2019-11-26 09:43:47.278748+00', 'Lassie From Stirling + Buchan Gate [leaflet], The', '', 146, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (926, '2004-01-14 23:00:00+00', '2021-01-06 14:20:38.782638+00', 'Haliburton SCD Book #1: Tenth Anniversary Book', 'Tenth Anniversary Book', 2018, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (356, '2002-12-31 23:00:00+00', '2019-11-30 00:29:53.297939+00', 'Gaelic College SCD Book #2: Six and Half a Dozen', 'Six and Half a Dozen', 2018, 1, 0, 1, 1, NULL, NULL, 0, 'http://www.minicrib.org.uk/Publications/Keppie_John/GC02.pdf', 0, 0000);
INSERT INTO 'publication' VALUES (954, '2005-04-12 22:00:00+00', '2018-01-16 19:56:55.743503+00', 'Scottish Country Dances in Diagrams. Ed. 8', 'Pillings 8', 398, 1, 0, 1, 1, NULL, NULL, 0, 'The very first edition of ''The Wee Green Book'' was published in 1955.



The 8th Edition was originally published in 2004 and reprinted in March 2005. A Supplement to the 8th Edition was released in July 2009.



For Twelve dances the diagram in this edition is in error, and has been replaced by a new diagram published in the supplement to the 8th edition.  For these dances, the page number has been increased by 9000, to set them apart.', 0, '2004-00-00');
INSERT INTO 'publication' VALUES (1409, '2018-01-17 11:11:37.229355+00', '2018-01-17 11:11:37.229355+00', 'Glasgow Jubilee (1923-1973)', 'Glasgow Jubilee', 144, 1, 0, 0, 1, NULL, NULL, 0, 'From the leaflet: 

The "GLASGOW JUBILEE" - devised by Mr. John Drewry and gifted to the Glasgow Branch Demonstration Team to commemorate the Jubilee of the Glasgow Branch.', 0, '1973-00-00');
INSERT INTO 'publication' VALUES (1459, '2018-07-16 23:58:02.475832+00', '2018-07-17 21:23:28.255219+00', 'Book 52', 'RSCDS LII', 319, 1, 1, 0, 1, 202, '2018-07-17 21:23:28.253453+00', 0, '', 1, 2018);
INSERT INTO 'publication' VALUES (761, '2002-12-31 23:00:00+00', '2018-03-21 23:34:30.453363+00', 'Book 39', 'RSCDS XXXIX', 319, 1, 1, 0, 1, 72, '2009-03-14 14:23:55+00', 0, 'When the new Book 39 was sold at Summer School in 1996, this sheet with additions and corrections for each of the nine dances was included.  These notes have also been added as "Extra Info" to each of the dances.



R.S.C.D.S. BOOK 39    NOTES ON DANCES    Bob Grant   June 1996



Swiss Lassie

9-16    2nd man & 1st woman need to be beginning to dance out at end of reel

17-20    2nd woman and 1st man should dance to end of reel before following partners



Joie de Vivre

9-12    .... and return to places with men facing up and women facing down



The New Virginia Reel

Fig 1

17-32    Slip in a curve so that start and finish are centred

Fig 3

1-8    Dancing couples need to ‘cheat’ here and meet to start going round the side couples



Cape Town Wedding

9-16    Reel across is between 1st and 2nd positions

21-24    Use first setting step to advance into the circle.  Pull right shoulders back quickly and tightly



The Immigrant Lass

5-8    Right hands across need to be ‘driven’ round

9-16    1/2 rights and lefts have polite turns at end

31-32    1st couple don’t ‘cast’ up into 4th place although it feels more natural and I’m sure will be done



Le Moulin Rouge

1-8    Men must come out of the 4 hands round quickly to get round partners in time

17-24    At the end men are back to back in the middle

53-56    Women keep turning so that they actually face anticlockwise



The Duke and Duchess of Edinburgh

1-8    1st woman ‘hovers’ while 1st man faces the top before casting

9-16    Nearer hands

25-32    Second time through, 1st couple crosses to the bottom giving left hands



The Robertson Rant

17-24    Men finish the reel by curving left about, acknowledging partner, before facing corner (Men speed up, women slow down)



Prince Charles of Edinburgh

Fig 1

17-24    1st and 3rd men face out

Fig 2

15-16    Use setting to turn ‘inwards’ to face corner

1-16 (2nd time)  Couples 2 & 4 - no polite turn at the end of 1/2 rights and lefts

Tulloch Swing:  It is more usual for couples to link arms, hands cupping elbows, ladies holding dresses and men with free arm raised.  Men 2 cuts and women 2 changes of feet to change direction

', 1, '1996-00-00');
INSERT INTO 'publication' VALUES (1425, '2018-02-23 17:38:49.787329+00', '2018-09-19 10:03:29.026501+00', 'Pipe-Major William Ross''s Collection of Highland Bagpipe Music Book 1', 'P/M Ross’s Collection 1', 1635, 0, 1, 0, 1, NULL, NULL, 0, 'For more information see [[http://www.altpibroch.com/bibliography/bibliographies/scots-highland-pipes/348-pipe-major-william-rosss-collection-of-highland-bagpipe-music-by-william-ross/]]



The list of tunes is incomplete due to lack of availability!', 0, '1923-00-00');
INSERT INTO 'publication' VALUES (473, '2002-12-31 23:00:00+00', '2019-09-13 15:28:12.251759+00', 'Whetherly Book 23', 'Whetherly 23', 270, 1, 0, 0, 1, NULL, NULL, 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages. In this SCDDB record, the dances are numbered in succession, and not by page number.', 0, 1990);
INSERT INTO 'publication' VALUES (1423, '2018-02-23 17:35:23.023556+00', '2018-09-19 10:04:00.881328+00', 'Pipe-Major William Ross''s Collection of Highland Bagpipe Music Book 2', 'P/M Ross’s Collection 2', 1635, 0, 1, 0, 1, NULL, NULL, 0, 'For more information see [[http://www.altpibroch.com/bibliography/bibliographies/scots-highland-pipes/348-pipe-major-william-rosss-collection-of-highland-bagpipe-music-by-william-ross/]]



The list of tunes is incomplete due to lack of availability!', 0, '1934-00-00');
INSERT INTO 'publication' VALUES (1483, '2018-10-17 13:30:06.634916+00', '2019-04-28 17:17:26.490107+00', 'Members Only (Herrington SCD Group)', 'Members Only', 10435, 1, 0, 1, 1, 202, '2019-04-28 17:17:26.487743+00', 0, '', 0, 2014);
INSERT INTO 'publication' VALUES (1484, '2018-11-13 22:32:00.087287+00', '2018-11-13 22:40:32.140766+00', 'Furrows End, The', 'Furrows End', 1811, 0, 1, 1, 1, NULL, NULL, 0, 'There appear to be scans of this publication at https://shelialee.files.wordpress.com/2016/03/the-furrows-end-collection-for-accordion-fiddle.pdf



The database entry for this publication does not contain all the tunes in the book, only those already entered in the database as used on recordings.

', 0, '1996-00-00');
INSERT INTO 'publication' VALUES (1485, '2018-11-21 11:11:38.26157+00', '2019-09-12 22:01:30.2869+00', 'Clarkson''s Musical Entertainment', 'Clarksons', 11746, 0, 1, 1, 1, NULL, NULL, 0, 'The title page adds "Being a Selection of Various Tunes and Pieces of Music Adapted for the Piano Forte or Harpsichord".



The website http://hms.scot/fiddle/author/38/ suggests there are two books. The British Library catalogue contains just one 20 page volume with about 45 tunes.



This stub entry was added in response to this issue (http://my.strathspey.org/dd/issue/1394/) submitted by Finlay Forbes. So far only the tune mentioned there has been linked to this publication. ', 0, '1796-00-00');
INSERT INTO 'publication' VALUES (379, '2002-12-31 23:00:00+00', '2019-01-21 23:28:23.824557+00', 'Culver City Collection, The', 'Culver City', 2071, 1, 0, 0, 0, NULL, NULL, 0, 'The old URL for the website hosting this collection is now defunct. It was archived by the "wayback machine" so can still be consulted at http://web.archive.org/web/20070711140946/http://www.tvt.com/dances/culver_city_collection/CCC.html but it does not seem appropriate to set that as an active URL in the database.', 0, 1993);
INSERT INTO 'publication' VALUES (1488, '2019-01-08 15:45:07.541546+00', '2019-01-28 17:10:23.704622+00', 'Musicians'' Wedding, The', 'Musicians'' Wedding', 11035, 1, 1, 1, 1, NULL, NULL, 0, 'Publication and CD are distributed by Gaye Collin (NZ) and The Sunday Class (worldwide)', 0, 2018);
INSERT INTO 'publication' VALUES (535, '2002-12-31 23:00:00+00', '2019-02-03 07:55:37.562417+00', 'Theme and Variations', 'Stein: Variations', 371, 1, 0, 0, 1, 202, '2019-02-03 07:55:37.560193+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1486, '2018-12-03 16:08:38.535972+00', '2021-10-17 14:50:30.130385+00', 'Dunfermline Branch 90th Anniversary Book', 'Dunfermline 90th', 11749, 1, 1, 1, 1, 29717, '2021-10-17 14:50:30.123742+00', 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (1182, '2014-06-27 21:26:14.359855+00', '2018-12-07 22:31:17.893819+00', 'Longwood Collection, The', '', 10971, 1, 0, 1, 1, NULL, '2018-12-07 22:31:17.889972+00', 0, 'Available on paper and as PDF from lulu.com. at





At the moment this is just a "stub" entry, details still need to be filled in.  

27 june 2014.  Eric Ferguson', 0, '2014-06-01');
INSERT INTO 'publication' VALUES (1405, '2017-12-24 08:01:22.614951+00', '2022-12-12 22:05:16.684151+00', 'Tayside Dance Collection Volume II', 'Tayside Dance Coll. Volume II', 11580, 1, 0, 0, 1, 202, '2017-12-24 08:07:18+00', 0, '', 0, 2006);
INSERT INTO 'publication' VALUES (1627, '2022-04-09 23:20:01.305227+00', '2022-04-10 11:13:33.478767+00', 'Dances for Friends Seven', 'Friends 7', 1445, 1, 1, 0, 1, NULL, NULL, 0, 'Rik''s final publication, collecting both recent and earlier unpublished dances', 0, 2021);
INSERT INTO 'publication' VALUES (1171, '2013-12-19 11:07:04.062118+00', '2022-11-10 23:22:15.492836+00', 'Other Kangaroo Paw, The', 'Other Kangaroo Paw', 412, 1, 1, 0, 1, NULL, NULL, 0, 'Booklet accompanying the CD of same name.', 0, 2013);
INSERT INTO 'publication' VALUES (1102, '2012-02-24 21:03:50.860663+00', '2019-02-09 13:04:59.974563+00', 'West Lothian 70th 1936 2006', 'West Lothian 70th', 408, 1, 1, 1, 1, 106, '2013-03-24 17:32:36+00', 0, 'The information on the tunes for these dances comes from Iain Gent.  No tunes are mentioned in the publication. 



With a history of the branch on pp. 3 - 5.', 0, '2006-00-00');
INSERT INTO 'publication' VALUES (1490, '2019-02-20 14:23:59.563852+00', '2019-02-20 14:28:50.72689+00', 'Cornish Hospitality', '', 11782, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (1491, '2019-03-03 18:48:00.92565+00', '2019-03-03 18:48:00.92565+00', 'Quick Scotch Footbook', 'QS Footbook', 11526, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2019);
INSERT INTO 'publication' VALUES (775, '2002-12-31 23:00:00+00', '2019-03-07 23:10:15.330147+00', 'Guide to Scottish Country Dancing (ex-Collins), A', 'Guide (ex-Collins)', 319, 1, 0, 1, 1, NULL, NULL, 0, 'This used to be the »Collins Pocket Reference: Scottish Country Dancing« edited by <<ddp:Knight, Peter>> and published by <<ddp:HarperCollins>>, but has now been taken over and renamed by the <<ddp:RSCDS>>.', 1, 1996);
INSERT INTO 'publication' VALUES (1109, '2012-06-15 04:14:33.920111+00', '2019-03-08 17:33:55.978137+00', 'Reel Goulash, A', 'Reel Goulash', 3659, 1, 0, 1, 1, 274, '2012-10-14 10:01:19+00', 0, '15 dances written by members of the club from 2001-2011, and two dances writtten for club members on special occasions.



This booklet was published in 2011.  Recently (2019) the deviser of "30 isnae Enaw" saw that its original dance description has an error: on bars 13-16 the 1½ turn takes FOUR bars, and there is NO SETTING on [15-16].  



Please download the booklet from http://www.bstk.hu/book/, once this dance has been updated, and delete any old copies.

 ', 0, '2011-00-00');
INSERT INTO 'publication' VALUES (1349, '2017-01-20 03:26:09.42646+00', '2019-04-06 11:52:31.051816+00', 'Music and Dances of Bruce Fordyce, The', 'Bruce Fordyce', 1042, 1, 1, 0, 1, NULL, NULL, 0, 'Most of the dances in this publication are also in <<ddpub:The Bruce Fordyce Memorial Collection#1265>>, which is commercially available.', 0, 2001);
INSERT INTO 'publication' VALUES (31, NULL, '2019-04-29 20:54:50.091366+00', 'Book 31', 'RSCDS XXXI', 319, 1, 1, 0, 0, NULL, NULL, 0, '', 1, 1983);
INSERT INTO 'publication' VALUES (1500, '2019-05-12 09:14:18.854985+00', '2019-05-12 09:14:18.854985+00', 'Orkney Dances', '', 374, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1494, '2019-04-07 14:45:49.893926+00', '2019-04-07 15:22:56.110727+00', 'Firewood Collection, The', 'Firewood', 11534, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (1497, '2019-05-09 13:10:00.868368+00', '2019-05-09 15:57:08.326264+00', 'Guide Dog Book, The', 'Guide Dog Book', 743, 1, 0, 1, 1, NULL, NULL, 0, 'Published in aid of the Guide Dogs for the Blind Association.', 0, 0000);
INSERT INTO 'publication' VALUES (1501, '2019-05-12 10:09:19.233121+00', '2019-05-12 10:09:19.233121+00', 'Crowded Hall, The', '', 44, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2019);
INSERT INTO 'publication' VALUES (1502, '2019-05-12 10:47:30.185468+00', '2019-05-12 10:47:30.185468+00', 'Round ''O'' Book of Scottish Country Dances, The', 'Round ''O'' Book', 11002, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (1498, '2019-05-12 00:17:34.749648+00', '2019-05-12 00:17:34.749648+00', 'Dances Fae Hoy!', '', 374, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1521, '2019-10-24 16:16:04.373732+00', '2019-10-24 17:17:20.513773+00', 'Ox2K', '', 11891, 1, 1, 0, 0, NULL, NULL, 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (1499, '2019-05-12 08:34:56.819855+00', '2019-05-12 08:34:56.819855+00', 'Mair Dances Fae Hoy', '', 374, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2015);
INSERT INTO 'publication' VALUES (592, '2019-05-06 08:42:45.708779+00', '2019-05-13 22:36:41.074024+00', 'When Auld Friends Meet', '', 44, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 1988);
INSERT INTO 'publication' VALUES (903, NULL, '2019-05-14 19:27:32.398686+00', 'Dunsmuir Dances', 'Dunsmuir', 3340, 1, 1, 0, 0, NULL, NULL, 0, '', 0, 2003);
INSERT INTO 'publication' VALUES (1503, '2019-05-16 13:30:13.75368+00', '2019-05-16 13:30:13.75368+00', 'Charities Book 8', 'Charities 8', 27, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1996);
INSERT INTO 'publication' VALUES (1341, NULL, '2019-05-14 20:00:22.35515+00', 'RSCDS Atlanta Branch Celebrating 40 Years of Dancing Memories', 'Atlanta 40yrs', 12, 1, 0, 0, 0, NULL, NULL, 0, 'A collection of 21 Dances Written By or For Members of the Atlanta Branch - 2016. Celebrating 40 Years of Dancing Memories.', 0, 2016);
INSERT INTO 'publication' VALUES (569, '2002-12-31 23:00:00+00', '2019-05-16 13:34:03.691041+00', 'Barnardos Book 1 (later Charities Book 1)', 'Barnardos 1', 27, 1, 0, 0, 1, NULL, NULL, 0, 'The Barnardos Book 1 was later published as the Charities Book 1.', 0, 1989);
INSERT INTO 'publication' VALUES (1466, '2018-08-13 16:09:35.12578+00', '2018-09-19 10:03:18.262565+00', 'Canada''s Irish Rover', '', 380, 1, 0, 1, 1, NULL, NULL, 0, 'Wes Clindinning – Canada’s Irish Rover



As the Teachers’ Association (Canada) celebrates its 60th anniversary year, it is entirely fitting to pay tribute to Wesley Clindinning, one of TAC’s long-time and most enthusiastic supporters, by publishing a collection of dances he devised over many years of dedicated service to the Association and to Scottish Country Dancing in general.



Irish-born Wes received his Teachers’ Certificate in 1975 and, as well as being a popular teacher of Scottish country dancing, he was also a highland dancer with the Toronto Scottish Regiment, a tutor for potential teacher candidates and a guest teacher at workshops throughout North America and overseas.



Wes was Chairman of TAC from 1982 to 1984, during which period he “hosted” the Silver Jubilee Teachers’ AGM Weekend, and established the Silver Jubilee Scholarship Fund. Now known as the Jubilee Scholarship Fund, it continues to assist candidates to attend candidate classes at TAC Summer School. He encouraged many dancers to obtain their teaching certificates and thus continue spreading the joy of Scottish Country Dancing far and wide.



Wes will be remembered for many things, including his sense of humour, and his enjoyment of travel and social gatherings. He always had a twinkle in his eye and a smile on his face and ensured that his classes were fun, even when introducing difficult or more advanced SCD steps and formations. He had an appealing way of demonstrating the finer points of dancing and was adept at correcting and improving its performance without making any dancer feel singled out. His classes were well planned and emphasized the social aspects of SCD, including good handing and eye contact with one’s partner

.

Most of all, though, Wes was passionate about Scottish Country Dancing and really enjoyed imparting his knowledge and love of the dance to his classes. Unbeknownst to most dancers, he often did this in spite of pain caused by severe osteoarthritis. He inspired countless dancers with his friendliness and enthusiasm, right up until the time when health issues made it impossible for him to continue. It is hoped that the dances in this booklet will impart some of his love of the dance to those who never met him or experienced his teaching.



Diana K Hooper

Willowdale, ON', 0, '2018-00-00');
INSERT INTO 'publication' VALUES (399, '2002-12-31 23:00:00+00', '2019-04-15 21:37:07.656419+00', 'Wierdlaw Dance Sheets', 'Wierdlaw', 44, 1, 0, 0, 1, NULL, NULL, 0, 'Notes supplied by <<ddp:Adrian Conrad#1276>>:



Sheet 1 - The Key to the Door - copyright dates were 1967 for the music, 1966 for the dance.



Sheet 2 - The Fiery Cross - copyright date was 1967 for dance (no music included). 



Sheet 3 - The Young Man''s Dream - copyright date was 1969 for both dance and music.



Sheet 4 - Glendarroch - carried no copyright statement and no date, but as it was devised in Hugh Foss''s memory, it must be later than Hugh Foss''s death in 1971 and before 1976 - I suggest 1973. My own copy has pasted-on correction slips which replace earlier text saying that this was originally intended to be published,with the permission of Hugh''s widow Alison Foss, as Glendarroch Sheet No. 50 - continuing Hugh''s set of sheets 1-49. Evidently there was a change of plan and this dance then became Iain Boyd''s own Wierdlaw Sheet No. 4. A different dance (Bill Hamilton''s Fine Fettle) eventually became Glendarroch Sheet 50 when published in 1976 by Bob and Mamie Donald as Hugh Foss (Formby) after their taking over Hugh''s mail-order business from Alison Foss.', 0, '1973-00-00');
INSERT INTO 'publication' VALUES (1388, '2017-10-20 12:09:13.579689+00', '2019-09-12 21:56:40.777349+00', 'Collins Pocket Reference: Scottish Country Dancing', 'Collins SCD', 11535, 1, 0, 1, 1, NULL, NULL, 0, 'This book was edited by <<ddp:Knight, Peter>> in collaboration with the <<ddp:RSCDS>> and published by <<ddp:HarperCollins>>. 

The book was re-issued edition in March 2000, now with a white background cover instead of black as in 1996.



The book has now been taken over by the <<ddp:RSCDS>>, who has re-released it under the new title »A Guide to Scottish Country Dancing«.', 0, '1996-03-01');
INSERT INTO 'publication' VALUES (687, '2002-12-31 23:00:00+00', '2019-05-16 13:36:40.050486+00', 'Barnardos Book 3 (later Charities Book 3)', 'Barnardos 3', 27, 1, 0, 0, 1, NULL, NULL, 0, 'The Barnardos Book 3 was later published as the Charities Book 3.', 0, 1991);
INSERT INTO 'publication' VALUES (322, '2002-12-31 23:00:00+00', '2019-08-17 02:00:14.125094+00', 'Alexander Leaflets', 'Alexander Lflts', 13, 1, 0, 0, 1, NULL, NULL, 0, '"Alexander Leaflets" has been reprinted in 2019 with 44 dances instead of 36. Explanations, read: <<https://dances.e-cribs.org/Alexander_Leaflets_Foreword.pdf|Alexander Leaflets Reprint 2019>>', 0, 0000);
INSERT INTO 'publication' VALUES (198, NULL, '2022-10-01 20:35:39.761862+00', 'Brodie Book, The', 'Brodie Bk', 108, 1, 0, 1, 1, NULL, NULL, 0, 'Dances devised between 1971 and 1987. The booklet is copyright 1994.', 0, 1994);
INSERT INTO 'publication' VALUES (129, '2002-12-31 23:00:00+00', '2019-10-11 20:23:41.31704+00', 'Imperial Book of Scottish Country Dances Vol III', 'Imperial III', 192, 1, 0, 0, 1, NULL, '2019-10-11 20:23:41.314905+00', 0, 'On an original copy of this, the cover page states the dances were published from 1971 - 1977. The subtitle of the volume is "The Jack McConachie Memorial Sword Competition Dances". The foreword states "Each year we hold a competition for members of the Scottish Dance Branch of the Society, for the invention of a Country Dance. For one year the winner holds the Memorial Trophy, a magnificent Dress Sword which is presented in loving memory of one of our founder members, Jack McConachie, to whom this book is dedicated. "', 0, 0000);
INSERT INTO 'publication' VALUES (1519, '2019-09-25 08:12:38.238368+00', '2019-09-26 22:42:37.575216+00', 'We Twa', '', 11886, 1, 0, 0, 0, NULL, NULL, 0, '“We Twa” is a collaboration between Moira Stacey and Sue Petyt. Moira''s dances can be found on https://moirastacey.wordpress.com/about-%e2%80%9cwe-twa%e2%80%9d-the-dances/ . Sue Petyt sent a personal message listing hers.  The numbers refer to the track numbers on the CD.



The dance instructions were included with the CD "We Twa" recorded by Kenny Thomson and the Wardlaw Scottish Dance Band (2006) CD: SPCD002 ', 0, '2006-03-01');
INSERT INTO 'publication' VALUES (1522, '2019-10-28 18:01:08.885417+00', '2019-10-29 11:19:33.993512+00', 'Melbourne Miscellany, A', '', 262, 1, 0, 1, 1, NULL, NULL, 0, 'Dances to celebrate the 50th Anniversary of the Melbourne and District Branch Inc.', 0, 2019);
INSERT INTO 'publication' VALUES (758, '2002-12-31 23:00:00+00', '2019-05-16 13:36:52.905014+00', 'Barnardos Book 4 (later Charities Book 4)', 'Barnardos 4', 27, 1, 0, 0, 1, NULL, NULL, 0, 'The Barnardos Book 4 was later published as the Charities Book 4.', 0, 1992);
INSERT INTO 'publication' VALUES (1128, '2013-02-10 21:10:09.940827+00', '2018-10-20 17:32:32.186818+00', 'RSCDS Herefordshire Branch 40th Anniversary Collection of Dances 1967-2007', 'Herefordshire 40th Anniv. 2007', 10749, 1, 0, 1, 1, 202, '2018-10-20 17:32:32.183154+00', 0, 'Some two and a half years ago, Fran Smith undertook to compile a book of hitherto unpublished dances pertaining to the Herefordshire Branch of the RSCDS and its affiliated clubs.  This proved to be a somewhat time consuming task, but in spite of many trials and tribulations along the way, Fran''s persistence has paid off and we are fortunate to be able to produce this little collection.  There are dances for all grades of Scottish Country dancers from beginners to the more advanced.  



Our thanks and congratulations to Fran for her efforts and her success in compiling this booklet in time to help us celebrate the 40th anniversary of the founding of the Herefordshire Branch of the RSCDS.  



Nigel Carter  

President  



Compiled by Fran Smith  



All of the dances in this book have some connection with RSCDS Herefordshire. Some were devised by members, some for members, or for special occasions. Two of the dances, Jonathan’s Jig and Ross in Bloom appear in a Limited Edition booklet produced by Ross Reel Club but the rest are unpublished even though they may have been around for a while.  

  



First Published April 2008  

This edition Published 2014  

   

   

   

There are a number of other dances with a connection to Herefordshire RSCDS. Those I know of are listed below. The source is given using best information available but I cannot guarantee all the publications can still be purchased.  





The Black Mountain Reel	Derek Haynes    	Carnforth Collection of SC  

The Blue Mess Jacket	        Douglas Henderson  

Connie’s Jig	                Steve Goulden           RSCDS Book 41  

Ewan Telford’s Strathspey  	Alison Telford	        Casnewydd Collection  

The Festival Fancy	        Abergavenny Children’s Class   	Casnewydd Collection  

Flora Inglis’ Strathspey	John Drewry              Greenburn Book 2  

Henderson in Hereford 	John Drewry	        Winter Collection 1988  

The Hereford Rant	        Douglas Henderson  

Hereford Silver Jubilee 	Douglas Henderson	Scottish National Dance Company  

Over the Moon	                John Drewry              Greenburn Book 2  

Rings Around the Moon	John Drewry              Greenburn Book 2  

Wormbridge House	        Derek Haynes        	Scottish Dance Archive  



', 0, '2014-00-00');
INSERT INTO 'publication' VALUES (1504, '2019-06-01 12:14:59.92797+00', '2019-06-01 13:06:43.106655+00', 'DebRA Book, The', 'DebRA', 743, 1, 0, 1, 1, NULL, NULL, 0, 'DebRA is a charity supporting those with Epidermolysis Bullosa.', 0, 0000);
INSERT INTO 'publication' VALUES (1509, '2019-07-17 19:26:10.877219+00', '2019-08-12 08:16:46.519549+00', 'Homemade Dances, volume 2', 'Homemade Dances 2', 11835, 1, 0, 0, 0, NULL, NULL, 0, 'A publication of dances by many different authors, and prepared by the members of the Eagle Rock class led by Lea Maiolo.

', 0, '2007-07-19');
INSERT INTO 'publication' VALUES (1514, '2019-09-11 10:38:40.349128+00', '2019-09-11 11:05:54.948825+00', 'John A Johnston Dances', '', 640, 1, 0, 0, 0, NULL, NULL, 0, 'Can be downloaded from the Minicrib website', 0, 2019);
INSERT INTO 'publication' VALUES (1414, '2018-01-18 22:16:21.645855+00', '2019-09-11 20:39:37.055911+00', 'Entente Cordiale + Berwickshire Round Reel', '', 146, 1, 1, 0, 0, NULL, NULL, 0, 'The only date mentioned on the leaflet is 1978 for the dance "Entente Cordiale", but this was not necessarily the publication date of the leaflet.', 0, 1978);
INSERT INTO 'publication' VALUES (1511, '2019-07-22 21:15:12.133793+00', '2020-12-02 10:47:46.685568+00', 'Scandinavian Scottish Dance Book Vol 1.', 'Scandinavian vol 1 (2018)', 11836, 1, 1, 1, 0, NULL, NULL, 0, 'Free Download at http://dancetide.dk/wp-content/uploads/2018/05/Scandinavian-Scottish-Dancebook-vol-I-21-04-2018-Dancebook-.pdf



The publishers decided to fulfil a dream that they both had, to collect and publish dances devised by Scandinavians or people who live or had lived in Scandinavia.  The dances date back to the 1980s. (SC Dancer, no 28, April 2019)



There are 32 dances in all.  ', 0, '2018-04-21');
INSERT INTO 'publication' VALUES (1520, '2019-09-26 09:29:31.552373+00', '2020-04-01 23:44:30.331792+00', 'Imperial Book of Scottish Country Dances - Volumes 4, 5 and More', 'Imp 4-5+', 319, 1, 0, 0, 0, NULL, NULL, 0, 'From the April 2020 Magazine:   Errata   

Revisions for the Imperial Book 4, 5 and More can be viewed on the website: rscds.org/learn/resources-dancers/publication-updates  ', 1, '2019-06-01');
INSERT INTO 'publication' VALUES (456, '2002-12-31 23:00:00+00', '2021-06-25 09:36:38.210503+00', 'Whetherly Book 6', 'Whetherly 6', 270, 1, 0, 0, 1, NULL, NULL, 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages.  In this SCDDB record, the dances are numbered in succession, and not by page number.



A revised edition by Alison Mitchell (with assistance of Viktor Lehmann and Eva-Maria Beckmann) was re-published online in 2020 as PDF on www.scd-germany.de.', 0, '1980-00-00');
INSERT INTO 'publication' VALUES (455, '2002-12-31 23:00:00+00', '2021-06-25 09:35:23.118191+00', 'Whetherly Book 5', 'Whetherly 5', 270, 1, 0, 0, 1, NULL, '2009-12-12 22:36:45+00', 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages.  In this SCDDB record, the dances are numbered in succession, and not by page number.



A revised edition by Alison Mitchell (with assistance of Viktor Lehmann) was re-published online in 2020 as PDF on www.scd-germany.de.', 0, '1980-00-00');
INSERT INTO 'publication' VALUES (1517, '2019-09-23 10:46:25.998477+00', '2021-06-06 21:12:41.79995+00', 'Scottish Country Dances in Diagrams. Ed. 5', 'Pillings 5', 398, 1, 0, 0, 1, NULL, NULL, 0, 'The very first edition of ''The Wee Green Book'' was published in 1955.', 0, 1980);
INSERT INTO 'publication' VALUES (1516, '2019-09-23 10:45:33.762942+00', '2021-06-06 21:12:59.322205+00', 'Scottish Country Dances in Diagrams. Ed. 4', 'Pillings 4', 398, 1, 0, 0, 1, NULL, NULL, 0, 'Reprinted 1977 and 1978 (according to <<https://my.strathspey.org/dd/issue/2467/|issue 2467>>).



The very first edition of ''The Wee Green Book'' was published in 1955.', 0, '1974-00-00');
INSERT INTO 'publication' VALUES (1512, '2019-08-11 20:08:41.110707+00', '2019-08-11 21:37:17.946366+00', 'Homemade Dances, volume 1', 'Homemade Dances 1', 11835, 1, 0, 0, 0, NULL, NULL, 0, 'Dances devised by class members and friends.', 0, 2006);
INSERT INTO 'publication' VALUES (1268, '2015-07-21 14:46:56.29064+00', '2019-08-17 00:53:55.932148+00', 'Riverside Dances', 'Riverside', 11164, 1, 0, 1, 1, 202, '2018-05-24 01:24:04+00', 0, '', 0, 2015);
INSERT INTO 'publication' VALUES (1508, '2019-07-03 17:23:05.938442+00', '2019-07-03 18:15:46.813013+00', 'RSCDS Winchester Branch Golden Anniversary Book', 'Winchester Golden', 10674, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2002);
INSERT INTO 'publication' VALUES (1515, '2019-09-16 00:07:46.697645+00', '2022-12-21 14:51:34.184606+00', 'New World Scottish Dancers Collection, Vol 2', 'New World Vol 2', 10429, 1, 1, 1, 1, 202, '2019-09-16 01:18:22+00', 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (461, '2002-12-31 23:00:00+00', '2023-01-26 18:57:38.294838+00', 'Whetherly Book 11', 'Whetherly 11', 270, 1, 0, 0, 1, NULL, NULL, 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages.  In this SCDDB record, the dances are numbered in succession, and not by page number. In the re-published version (2019 and later), each dance starts on a new page.', 0, 1982);
INSERT INTO 'publication' VALUES (464, '2002-12-31 23:00:00+00', '2019-09-13 14:29:00.824621+00', 'Whetherly Book 14', 'Whetherly 14', 270, 1, 0, 0, 1, NULL, NULL, 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages.  In this SCDDB record, the dances are numbered in succession, and not by page number.', 0, 1984);
INSERT INTO 'publication' VALUES (1487, '2018-12-13 16:11:11.064159+00', '2018-12-28 10:47:08.580764+00', 'Scottish Country Dances by James McMillan', '', 3699, 1, 1, 1, 1, 202, '2018-12-27 13:03:03+00', 0, 'Originally only a few paper copies were printed for private circulation.  A new edition was made in 2018 by Maureen Daniel, who collected these dances in a single pdf, and included her diagrams.



Erratum:  In the Table of Contents, the "Sheilandwill Jig" is erroneously listed as "Sheilandwill".  The name on the dance page is correct.



The first item in this publication is "Triple Tournée".  That is not a dance but the following description of the figure "Triple Tournée" that appears in three of the dances. 



+++++++++++++++++++++++++++++++++++++++

This is a tournée for 3 couples in strathspey time. Top and bottom couples change places with 8 travelling steps.



Bars

1 Top lady dances in above partner, top man dances in below his partner pulling back left shoulder to face his own side; middle couple dance in and pull back right shoulder to face their own side of the dance, man above his partner; bottom lady dances in pulling back left shoulder to face own side of the dance and bottom man dances in below partner. All three couples are now in a straight line up and down the middle of the set, the top 3 people are facing the men’s side and the bottom 3 facing the women’s side, with nearer hands joined.



2 - 4 All three couples dance round half-way, anti-clockwise, on the fourth step the couples at top and bottom of the line change to right hands so the women face towards the men''s side and the men face towards the women''s side of the dance, middle couple retain left hands



5 - 8 Top and bottom couple turn with the right hand one-and-a-half times, middle couple turn with the left hand one-and-a-half times, then dance out to finish on own sides.

+++++++++++++++++++++++++++++++++++++', 0, '2018-01-01');
INSERT INTO 'publication' VALUES (1524, '2019-11-20 19:45:45.355555+00', '2019-11-20 19:45:45.355555+00', 'Dancing Forth Too - CD booklet', 'Dancing Forth Too', 119, 1, 0, 0, 1, NULL, NULL, 0, 'This is the booklet included in the jewel case of the CD "Dancing Forth Too"', 0, 2004);
INSERT INTO 'publication' VALUES (1037, '2011-07-09 22:00:00+00', '2019-11-26 07:44:00.468549+00', 'Carnforth Collection of SC Dances 6', 'Carnforth 6', 175, 1, 0, 1, 1, 106, '2011-07-10 14:38:26+00', 3, '', 0, 2008);
INSERT INTO 'publication' VALUES (1259, '2015-05-30 19:19:59.166984+00', '2019-11-26 07:51:37.391568+00', 'Haliburton SCD Book #7: Haliburton School of Arts', 'Haliburton Book 7', 2018, 1, 0, 1, 1, NULL, NULL, 0, 'Errors have been found in the description of the dance "Valentine Special".  The other dances may need to be checked too.', 0, 2011);
INSERT INTO 'publication' VALUES (739, '2002-12-31 23:00:00+00', '2019-11-26 09:38:08.943757+00', 'Summer Collection, Set 4 (Scottish Country Dances, Volume 4)', 'Drewry: Summer 4', 108, 1, 0, 0, 1, NULL, '2012-02-10 12:45:02+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1286, '2015-09-22 21:12:36.013783+00', '2019-11-26 09:38:47.839754+00', 'Laurieston Collection 3, The', '', 2673, 1, 0, 1, 1, NULL, NULL, 0, 'Stub entry, needs expanding.  Date is a stub', 0, 2014);
INSERT INTO 'publication' VALUES (1308, '2016-06-22 21:34:15.080544+00', '2019-11-26 09:41:06.152043+00', 'Whangarei Book of Scottish Country Dances, The', 'Whangarei Book', 411, 1, 0, 1, 0, NULL, NULL, 0, 'CD included', 0, 2008);
INSERT INTO 'publication' VALUES (1507, '2019-06-23 23:18:24.916013+00', '2019-11-26 09:47:07.507061+00', 'Collection of Scottish Country Dances: Jig Time Vol 1, A', 'Jig Time 1', 640, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 2019);
INSERT INTO 'publication' VALUES (1045, '2011-07-24 22:00:00+00', '2020-06-14 23:24:40.775024+00', 'Tuatara Collection, The', 'Tuatara Collection', 2682, 1, 0, 1, 0, 106, '2011-07-25 11:12:09+00', 0, 'Collection in progress; Rod is adding his new dances as they come.', 0, 2013);
INSERT INTO 'publication' VALUES (459, '2002-12-31 23:00:00+00', '2021-06-25 09:44:18.454776+00', 'Whetherly Book 9', 'Whetherly 9', 270, 1, 0, 0, 1, NULL, NULL, 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages.  In this SCDDB record, the dances are numbered in succession, and not by page number.



A revised edition by Alison Mitchell (with assistance of Viktor Lehmann) was re-published online in 2021 as PDF on www.scd-germany.de.', 0, '1981-00-00');
INSERT INTO 'publication' VALUES (1538, '2020-03-29 11:44:58.65141+00', '2021-04-01 20:44:51.064062+00', 'Salute to San Diego', 'Salute to San Diego', 337, 1, 1, 0, 1, 202, '2020-04-08 00:15:55+00', 0, 'Scottish Country Dances Celebrating the Sapphire (45th) Anniversary of the San Diego Branch', 0, 2020);
INSERT INTO 'publication' VALUES (735, '2002-12-31 23:00:00+00', '2021-06-15 10:45:06.960514+00', 'Mile Stones', 'Mile Stones', 352, 1, 0, 0, 1, 202, '2021-06-15 10:45:06.95339+00', 0, '', 0, 1995);
INSERT INTO 'publication' VALUES (457, '2002-12-31 23:00:00+00', '2021-06-25 09:42:02.812155+00', 'Whetherly Book 7', 'Whetherly 7', 270, 1, 0, 0, 1, NULL, NULL, 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages.  In this SCDDB record, the dances are numbered in succession, and not by page number.



A revised edition by Alison Mitchell (with assistance of Viktor Lehmann and Martina Müller-Franz) was re-published online in 2021 as PDF on www.scd-germany.de.', 0, '1980-00-00');
INSERT INTO 'publication' VALUES (1437, '2018-04-03 10:08:29.606289+00', '2019-11-26 09:44:40.60267+00', 'Sylphe. An elegant Collection of Twenty four Country dances, the Figures by Mr Wilson for the year 1813, Le', 'Le Sylphe - Dances for 1813', 443, 1, 0, 0, 0, NULL, NULL, 0, 'The RSCDS publication "Scottish Country Dances Books 13-18" states *Button & Whitaker: Le Sylphe. An elegant Collection of Twenty four Country dances, the Figures by Mr Wilson for the year 1813* as the source of dances.



Sometimes this publication was referred to as just "Dances for 1813".', 0, '1813-01-01');
INSERT INTO 'publication' VALUES (1455, '2018-06-10 13:51:20.467955+00', '2019-11-26 09:45:16.772835+00', 'Cat Collection Book One - Misty''s Book, The', 'Misty’s Book', 2766, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (1471, '2018-08-21 10:11:38.248179+00', '2019-11-26 09:46:34.498663+00', 'Walnut Book, The', 'Walnut Book', 11677, 1, 0, 1, 1, 202, '2018-09-06 00:11:44+00', 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (1351, '2017-02-15 18:18:27.565048+00', '2020-11-11 21:04:41.779362+00', 'Corberry Collection II (with the music), The', 'Corberry Collection II', 1582, 1, 1, 1, 1, NULL, NULL, 0, 'Available as a printed book and as a PDF. 



In addition to the dances listed there are seven Ceilidh dances in the book  



Adelaide Two-step	32 bar two step



An Allemande Fancy	32 bar two step



Awa Tae Box & Fiddle	32 bar two step



Change and Go	32 bar march



DG Dancers’ Celebration	32 bar jig



Guid Tae Ken Ye	32 bar march



Hamburg 2012	32 bar reel', 0, '2017-02-10');
INSERT INTO 'publication' VALUES (1370, '2017-05-27 15:37:21.924195+00', '2019-12-13 16:12:50.925601+00', 'Dances Online [San Francisco]', '', 338, 1, 1, 0, 0, NULL, NULL, 0, 'This is a page on the SF branch website where dances are published that have been locally devised. At the moment of writing they are arranged in order of submission to the page; on the web page they are not numbered.  Some have been published elsewhere, some not.



The Branch will be adding more dances.  I propose that we editors use the "publication date" above to indicate the last day of updating this entry. 



Links to the dances can be found from the main web page; there are also links directly to each individual dance. 



The "Anniversary Suite" has three dances, the fourth entry is a set of teaching notes for these three.  Jennifer Kelly writes:    

"Notes for teachers on the dances in the Anniversary Suite.   As I devised these dances I had a particular teaching point in mind for each of them.".



These teaching notes can be found at 

http://rscds-sf.org/resources/dances/Anniversay%20Suite%20Notes.pdf



Eric', 0, '2019-12-13');
INSERT INTO 'publication' VALUES (1566, '2021-01-02 12:13:01.948028+00', '2021-01-03 12:11:42.22239+00', 'Jink & Diddle Book o'' Tunes 2010', 'Jink & Diddle 2010', 12009, 0, 1, 1, 0, NULL, NULL, 0, 'This is a stub entry and only links tunes used in dances.

', 0, '2010-00-00');
INSERT INTO 'publication' VALUES (1525, '2019-12-20 10:54:01.81428+00', '2019-12-20 11:01:27.012636+00', 'Simple Highland Dances for Scottish Country Dancers', 'Simple Highland', 175, 1, 0, 0, 1, NULL, NULL, 0, 'The entry is a place holder for adding those dances in the book when required, eg if they appear on dance lists or have videos. Few of the dances have yet been added to the database.', 0, 0000);
INSERT INTO 'publication' VALUES (1526, '2019-12-23 20:47:31.218256+00', '2019-12-23 20:52:06.906357+00', 'Scottish Dance Masters Volume 5', '', 3461, 1, 0, 0, 1, NULL, NULL, 0, 'Musicassette (MC) insert sheet', 0, 1991);
INSERT INTO 'publication' VALUES (1527, '2020-01-17 13:40:29.754119+00', '2020-01-17 14:04:40.202699+00', 'From North to South', '', 11155, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2019);
INSERT INTO 'publication' VALUES (87, '2002-12-31 23:00:00+00', '2020-01-18 21:26:04.685455+00', 'Cairngorm Dancers 1980-1990', 'Cairngorm 1', 138, 1, 0, 0, 1, 11583, '2020-01-18 21:26:04.678554+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1088, '2011-08-29 22:00:00+00', '2020-01-24 12:07:03.302387+00', 'Katannuta, a Collection of Salt Spring Island Scottish Country Dances', 'Katannuta', 10731, 1, 0, 0, 1, NULL, '2012-10-23 18:53:13+00', 0, '', 0, 2009);
INSERT INTO 'publication' VALUES (1104, '2012-04-29 13:43:08.441878+00', '2020-01-24 12:07:28.837311+00', 'Land of Milk and Plenty 1', '', 10402, 1, 0, 1, 1, NULL, NULL, 0, 'This entry is very incomplete.  There are three books of this name, numbered 1,2,3.



The Publisher has been guessed.  Needs checking when the full book is entered into DD.', 0, '2003-00-00');
INSERT INTO 'publication' VALUES (1173, '2014-02-20 13:41:28.869155+00', '2020-01-24 12:07:57.356104+00', 'Fifth Catherine de Barnes Collection of Scottish Country Dances, The', 'Fifth Catherine de Barnes Collection', 3694, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2013);
INSERT INTO 'publication' VALUES (1198, '2014-09-29 00:44:12.116411+00', '2020-02-12 09:25:41.954914+00', 'Dances devised locally to Bridport', '', 11005, 1, 0, 0, 0, 106, '2014-09-29 00:44:18+00', 0, 'This publication is acccessible online.  As far as the editors know it has not been published on paper.', 0, 2014);
INSERT INTO 'publication' VALUES (1529, '2020-02-12 09:45:26.47913+00', '2020-02-12 14:43:40.674888+00', 'Braiding from Bridport', '', 11005, 1, 0, 1, 1, 202, '2020-02-12 14:43:40.669812+00', 0, '', 0, 2005);
INSERT INTO 'publication' VALUES (125, '2002-12-31 23:00:00+00', '2020-02-13 15:44:49.315505+00', 'Scottish Country Dances of The 18th Century', '18th Cent.', 251, 1, 0, 0, 1, NULL, '2020-02-13 15:44:49.311147+00', 0, 'The inscription in the second (revised) edition, 1963 states:



Derived from a manuscript dated 1740 in the Bodleian Library, Oxford. "A Collection of the newest Country Dances Performed in Scotland" written at Edinburgh by D.A. Young W.M. 1740



Edited & adapted to conform with modern presentation by Jack McConachie, Fellow of The Imperial Society of Teachers of Dancing Incorporated (Scottish Country Dance Branch). Published by order of the Council The Imperial Society of Teachers of Dancing Incorporated.

', 0, '1960-00-00');
INSERT INTO 'publication' VALUES (901, '2003-04-21 22:00:00+00', '2020-02-28 11:36:44.918371+00', 'Gone Dancing Bk 1', '', 3334, 1, 0, 1, 1, 202, '2018-10-29 02:10:07+00', 0, 'Anniversary Book of the Lyons RSCDS Branch "La Chanterelle".', 0, 2011);
INSERT INTO 'publication' VALUES (1533, '2020-03-09 07:49:10.163353+00', '2020-03-11 11:33:06.967107+00', 'Oh, How We''ve Danced!', 'Oh, How We''ve Danced!', 10568, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (1535, '2020-03-24 19:53:06.546722+00', '2020-03-25 08:29:01.260316+00', 'Chicago 40th Anniversary Collection', '', 76, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (1532, '2020-02-28 11:37:36.417404+00', '2020-05-05 15:18:26.27624+00', 'Gone Dancing Bk 2', '', 3334, 1, 0, 1, 1, 202, '2020-02-28 11:45:05+00', 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (1528, '2020-02-05 21:42:33.670071+00', '2021-01-02 12:40:28.758067+00', 'World''s End Book of 13 SCDs - Vol 1, A', 'World''s End Book, V 1', 3583, 1, 1, 1, 0, 1586, '2020-03-03 22:19:18+00', 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (358, '2002-12-31 23:00:00+00', '2020-05-04 23:46:13.619406+00', 'Gala Scottish Reels, The', 'Gala Reels', 121, 1, 0, 0, 1, NULL, NULL, 0, 'From Strathspey message 71121:  The book is a collection of ''display reels'', which were performed by the U of Western Ontario SCD group at annual "Gala Days" conducted alternately by the Ontario and Hamilton dance groups. 

', 0, '1993-01-01');
INSERT INTO 'publication' VALUES (1539, '2020-04-27 22:38:01.499056+00', '2021-04-20 12:02:49.600783+00', 'Stay at Home Book, The', '', 11509, 1, 0, 1, 0, 202, '2021-04-20 12:02:49.595527+00', 0, 'This book was published during the Coronavirus pandemic of 2020 to provide ideas to continue Scottish dancing during the period of lockdown for those who are lucky enough to live with 2 or 3 other dancers.', 0, 2020);
INSERT INTO 'publication' VALUES (1269, '2015-07-26 10:02:54.832769+00', '2020-03-31 12:07:40.445775+00', 'My Inspirations', 'My Inspirations', 3355, 1, 1, 1, 1, NULL, NULL, 0, 'Available from:  

Minnie Bänninger  

Gernstrasse 8  

8311 Brüten  

Switzerland', 0, '2015-07-01');
INSERT INTO 'publication' VALUES (166, '2002-12-31 23:00:00+00', '2020-05-03 10:55:36.802962+00', 'Peggy McGhie''s Reel & Other Scottish Country Dances', 'Peggy McGhie''s Reel', 99, 1, 0, 0, 1, 35761, '2020-04-22 15:30:58+00', 0, 'This was the third publication by Lewis N Derrick in his McGhie series and he now refers to it with the abbreviated colophon ''Mc3''.', 0, 1988);
INSERT INTO 'publication' VALUES (1523, '2019-11-03 13:35:41.708366+00', '2020-04-01 21:38:04.744308+00', 'Thirty Popular Dances, Volume Two', 'RSCDS 30 popular, Vol 2', 319, 1, 1, 1, 1, NULL, NULL, 0, 'From the April 2020 magazine:  It  was  noticed  by  many  of  you  that  the  Thirty  Popular  Dances  Volume 2, Part 2, tracks 10 and 11 are in the opposite order from that in which they appear in the list on the cover. We apologise for any confusion.', 1, 2019);
INSERT INTO 'publication' VALUES (41, '2002-12-31 23:00:00+00', '2021-07-03 20:41:28.814609+00', '101 Scottish Country Dances', 'RSCDS 101', 319, 1, 0, 0, 1, 73, '2012-01-15 22:17:45+00', 0, 'First published 1956, reprinted January 1957, corrected  October 1957, another reprint in January 1960 and again in November 1961. Details from <<https://my.strathspey.org/dd/issue/2465/|issue 2465>>.', 1, 1956);
INSERT INTO 'publication' VALUES (865, '2002-12-31 23:00:00+00', '2020-04-21 15:42:30.189227+00', '10th Anniversary Book of Dances (Builth Wells)', 'Builth Wells 10', 3285, 1, 0, 1, 1, NULL, NULL, 0, '', 0, 2001);
INSERT INTO 'publication' VALUES (329, '2002-12-31 23:00:00+00', '2020-04-21 16:13:24.496909+00', 'Angus Reel, The', 'Angus Reel', 321, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1949);
INSERT INTO 'publication' VALUES (905, '2003-05-09 22:00:00+00', '2020-04-21 20:51:42.648563+00', 'Welsh Set, The', 'Welsh Set', 108, 1, 0, 0, 1, NULL, NULL, 0, 'The book says:  "This booklet of dances contains dances which John taught at the John Drewry Day School held by the South Wales Branch of the Royal Scottish Country Dance Society on the 23rd of October 1999".', 0, 0000);
INSERT INTO 'publication' VALUES (1312, '2016-06-22 22:53:16.901857+00', '2020-04-22 08:51:37.080303+00', 'Introduction to Scottish Country Dancing, An', '', 319, 1, 0, 1, 1, NULL, NULL, 0, 'Foreword by Duncan MacLeod



An introductory manual, explaining many figures.  From p. 28 a number of popular SC dances are described', 1, '1987-00-00');
INSERT INTO 'publication' VALUES (1541, '2020-05-03 11:18:47.180068+00', '2020-05-08 07:41:16.210491+00', 'Triangular Suite of Scottish Country Dances, The', 'Triangular Suite', 99, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (165, '2002-12-31 23:00:00+00', '2020-04-22 20:57:26.728932+00', 'Saint Andrews Suite of Scottish Country Dances, The', 'St Andrews Suite', 99, 1, 0, 0, 1, 35761, '2020-04-22 15:42:43+00', 0, 'The leaflet contains three separate dances, jig, strathspey, reel, with a note about how they may be run together as a medley for demonstration purposes', 0, 1988);
INSERT INTO 'publication' VALUES (949, '2005-02-23 23:00:00+00', '2020-05-08 08:07:15.71364+00', 'Chicago 25th Anniversary Collection', '', 76, 1, 1, 1, 1, 202, '2020-05-08 08:07:15.706057+00', 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1547, '2020-06-04 20:47:20.10943+00', '2021-07-16 13:36:05.142605+00', 'Second Canberra Book of Scottish Country Dances, The', '2nd Canberra Book', 10393, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2018);
INSERT INTO 'publication' VALUES (1565, '2021-01-02 12:10:46.414948+00', '2021-01-03 12:11:49.022954+00', 'Jink & Diddle Book o'' Tunes 2009', 'Jink & Diddle 2009', 12009, 0, 1, 1, 0, NULL, NULL, 0, 'This is a stub entry and only links tunes used in dances.', 0, 2009);
INSERT INTO 'publication' VALUES (122, '2002-12-31 23:00:00+00', '2022-09-30 16:50:16.891324+00', 'Graded and Social Dances 1 - 24 Dances', 'Goldring Graded 1', 146, 1, 0, 0, 1, 108, '2009-03-18 02:12:57+00', 0, 'This book has been published in a new edition by Scotscores in 2009.', 0, 0000);
INSERT INTO 'publication' VALUES (1153, '2013-08-07 09:25:22.616986+00', '2020-04-28 20:04:23.352015+00', 'Real McGhie & Other Scottish Country Dances, The', 'Real McGhie, The', 99, 1, 0, 0, 1, 35761, '2020-04-22 15:36:42+00', 0, '*Extra information from the deviser (issue 2069):*

The Volume title is: The McGhie Scottish Country Dance Books Volume 5 [the first four books didn''t have this volume indicator], abbreviated on cover colophon as ''Mc5''.', 0, '1992-01-01');
INSERT INTO 'publication' VALUES (162, '2002-12-31 23:00:00+00', '2020-05-03 10:54:47.268068+00', 'McGhie the Moudie-Catcher & Other Scottish Country Dances', 'McGhie the Moudie-Catcher', 99, 1, 0, 0, 1, 35761, '2020-04-22 15:28:29+00', 0, 'McGhie the Moudie-Catcher & Other Scottish Country Dance

This was the second publication by Lewis N Derrick in his McGhie series and he now refers to it with the abbreviated colophon ''Mc2''.', 0, '1987-00-00');
INSERT INTO 'publication' VALUES (1544, '2020-05-09 17:41:27.115334+00', '2020-05-09 17:49:15.720576+00', 'Cardenden Connection Volume 3', 'Cardenden3', 10603, 0, 1, 0, 0, NULL, NULL, 0, 'Published by Deeay Music and the composer Michael Philip.



This is a partial entry: only tunes already known to SCDDB have been added here.', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (578, '2002-12-31 23:00:00+00', '2020-05-14 11:10:26.188183+00', 'Cameo Collection Book 15', 'Cameo 15', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1994);
INSERT INTO 'publication' VALUES (1542, '2020-05-09 10:30:59.468485+00', '2020-05-09 17:44:44.519514+00', 'Cardenden Collection Volume 1', 'Cardenden1', 10603, 0, 1, 0, 0, NULL, NULL, 0, 'This is a partial entry: only tunes already known to SCDDB have been added here.

', 0, '2005-02-01');
INSERT INTO 'publication' VALUES (1545, '2020-05-21 10:34:40.312308+00', '2020-05-21 10:34:40.312308+00', 'Grove Collection of SCDs Volume 1 (CD Booklet)', 'Grove Collection 1', 11858, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (1543, '2020-05-09 17:39:57.578166+00', '2020-05-09 17:48:02.848966+00', 'Cardenden Collection Volume 2', 'Cardenden2', 10603, 0, 1, 0, 0, NULL, NULL, 0, 'This is a partial entry: only tunes already known to SCDDB have been added here.', 0, 2007);
INSERT INTO 'publication' VALUES (1277, '2015-08-27 16:31:02.944978+00', '2020-05-17 01:36:10.027281+00', 'Shortcut to Happiness, A', 'Shortcut to Happiness', 10568, 1, 0, 1, 1, NULL, NULL, 0, 'Montreal/Entrelac Tees is the correct spelling; the spelling Montreal Entrelac Tees in the Table of Contents is a mistake.



MISPRINT: The author states that the book has a misprint in bars 9–16 of Muddy Dog Run.  Go to the Extra Info for that dance for the correct text.. 



The author prefers the 5c version of Fairlee Frolic.  A DOCX file of that variant is available.', 0, '2015-01-01');
INSERT INTO 'publication' VALUES (647, '2002-12-31 23:00:00+00', '2020-05-26 21:24:06.337873+00', '14 Social Dances for 2000', 'Goldring 2000', 146, 1, 1, 0, 1, 104, '2009-03-15 10:37:50+00', 0, '', 0, 2000);
INSERT INTO 'publication' VALUES (1546, '2020-05-26 20:05:55.285097+00', '2020-05-26 20:11:34.414638+00', 'Lorne Collection, The', '', 11952, 0, 1, 1, 1, NULL, NULL, 0, '33 tunes composed by Alastair Hunter and his father Charlie Hunter, published by Deeay Music, Forfar.



This is a stub entry and only contains tunes known to be part of this collection.', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (13, '2002-12-31 23:00:00+00', '2020-05-27 08:13:01.075998+00', 'Book 13 - Victory Book', 'RSCDS XIII', 319, 1, 1, 0, 1, 1893, '2020-05-22 05:07:36+00', 4, 'There are two tunes per dance which are listed here in order. So tunes 1 and 2 are the original and alternate tunes for dance #1 etc.', 1, 1945);
INSERT INTO 'publication' VALUES (1549, '2020-06-09 21:16:45.284716+00', '2020-06-09 21:16:45.284716+00', 'Marie Curie Suite of Scottish Country Dances, The', 'Marie Curie Suite', 99, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (1548, '2020-06-04 21:32:58.827065+00', '2020-06-04 21:48:29.004482+00', '8 Dances devised by Holly V Sherman', 'Sherman 8 Dances', 3723, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (1550, '2020-06-09 22:18:15.846621+00', '2020-06-09 22:18:15.846621+00', 'Quinary Suite of Scottish Country Dances, The', 'Quinary Suite', 99, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (163, '2002-12-31 23:00:00+00', '2020-08-04 10:24:43.046636+00', 'McGhie''s Fancy & Other Scottish Country Dances, The', 'McGhie''s Fancy', 99, 1, 0, 1, 1, 35761, '2020-04-22 15:16:59+00', 0, 'This was the first publication by Lewis N Derrick in his McGhie series and he now refers to it with the abbreviated colophon ''Mc1''.

Electronic version published 2020', 0, '1987-00-00');
INSERT INTO 'publication' VALUES (452, '2002-12-31 23:00:00+00', '2021-06-25 09:27:05.626552+00', 'Whetherly Book 2', 'Whetherly 2', 270, 1, 0, 0, 1, NULL, NULL, 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages.  In this SCDDB record, the dances are numbered in succession, and not by page number.



A revised edition by Alison Mitchell (with assistance of Viktor Lehmann and Katrin Edelmann and diagrams by Keith Rose) was re-published online in 2020 as PDF on www.scd-germany.de.', 0, '1975-00-00');
INSERT INTO 'publication' VALUES (1558, '2020-10-02 17:35:10.478396+00', '2020-10-04 15:37:32.917886+00', 'Jennifer''s Dances', '', 749, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2019);
INSERT INTO 'publication' VALUES (1554, '2020-07-04 10:01:39.774055+00', '2020-07-04 10:04:30.605233+00', 'Bon Accord Collection', 'Bon Accord', 1505, 0, 1, 0, 0, NULL, NULL, 0, 'This entry is a stub. The tunes are not yet added. There is a table of contents of the e-book available at <<https://www.scotlandsmusic.com/Product/SM-P41OQV/bert-murrays-bon-accord-collection>>.', 0, 1999);
INSERT INTO 'publication' VALUES (368, '2002-12-31 23:00:00+00', '2020-07-07 09:24:17.033318+00', 'Ness House Collection, The - Book 1', 'Ness House 1', 344, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1997);
INSERT INTO 'publication' VALUES (268, '2002-12-31 23:00:00+00', '2020-07-08 17:26:39.731541+00', 'Set and Cast Off Volume 3', 'Set & Cast Off 3', 22, 1, 0, 0, 1, NULL, NULL, 0, 'The entry for this publication was originally missing Wileycat Wood. It is not known if this was added to a later edition of this book.', 0, 0000);
INSERT INTO 'publication' VALUES (1552, '2020-06-17 14:24:02.455935+00', '2020-06-17 14:37:44.215489+00', 'Call of Home, The', 'Call of Home', 1631, 0, 1, 0, 0, NULL, NULL, 0, 'First book of tunes composed by Ian Robertson.



This entry is incomplete and currently only lists the tunes already used in recordings known to the database (about half of those in the book).', 0, '2014-00-00');
INSERT INTO 'publication' VALUES (216, '2002-12-31 23:00:00+00', '2020-07-14 08:34:23.300643+00', 'From the Land of the Shining River to the City of Light', 'Shining River', 220, 1, 0, 0, 1, 202, '2018-08-03 22:41:55+00', 0, '', 0, 1985);
INSERT INTO 'publication' VALUES (1555, '2020-08-03 08:56:15.004053+00', '2020-08-03 09:03:51.393653+00', 'Postie''s Jig, The', 'Postie''s Jig', 412, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (453, '2002-12-31 23:00:00+00', '2021-06-25 09:28:01.049467+00', 'Whetherly Book 3', 'Whetherly 3', 270, 1, 0, 0, 1, NULL, '2019-08-26 06:47:17+00', 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages.  In this SCDDB record, the dances are numbered in succession, and not by page number.



A revised edition by Alison Mitchell (with assistance of Viktor Lehmann and diagrams by Keith Rose) was re-published online in 2020 as PDF on www.scd-germany.de.', 0, '1977-00-00');
INSERT INTO 'publication' VALUES (1553, '2020-06-17 14:56:43.498042+00', '2020-06-17 15:27:07.597883+00', 'Heart of Me, The', 'Heart of Me', 1631, 0, 1, 1, 0, NULL, NULL, 0, 'Second book of tunes composed by Ian Robertson.



This entry is incomplete and currently only lists the tunes already used in recordings known to the database (about half of those in the book).

', 0, '2020-00-00');
INSERT INTO 'publication' VALUES (1556, '2020-08-25 09:13:35.245175+00', '2020-08-25 10:10:45.697089+00', 'Tanzen & Tafeln im Kuckucksnest', 'Tanzen & Tafeln', 10451, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (1096, '2011-12-10 23:00:00+00', '2021-08-15 08:15:03.000836+00', 'Eight by Thirty-Two', '8 x 32', 2408, 1, 0, 0, 0, 106, '2011-12-11 22:54:05+00', 0, 'This blog allows anyone to post SC dances; it keeps on growing.



Updated 19 december 2011:  All 78 dances have been entered.



Updated 25 july 2013.  All 87 dances now entered



Updated 8 november 2017. All 99 now entered', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (205, '2002-12-31 23:00:00+00', '2020-09-14 09:18:51.069255+00', 'Autumn Collection 1983', 'Drewry: Autumn 83', 108, 1, 0, 0, 1, NULL, NULL, 0, 'The original SCDDB entry for this publication had 20 dances. Thanks to Bruce Herbold reporting <<https://my.strathspey.org/dd/issue/2171/|issue 2171>>, three other dances included in his copy of the publication were added: <<ddd:#4354>>, <<ddd:#1384>> and <<ddd:#3454>>.

', 0, '1983-00-00');
INSERT INTO 'publication' VALUES (1032, '2011-06-28 22:00:00+00', '2020-09-19 23:37:03.11193+00', 'Mountain Spring Dances', '', 10344, 1, 0, 0, 1, 106, '2011-06-29 21:12:36+00', 3, 'This year Wil van den Berg will be leading the Social Dance of the Geldermalsen Scottish Country Dance Group for the 20th time.  For this occasion we have compiled this little booklet of dances written by our members.



The booklet''s name refers to Wil; "Berg" means "Mountain".



Spring 2007', 0, '2007-00-00');
INSERT INTO 'publication' VALUES (963, '2005-04-17 22:00:00+00', '2020-10-05 16:36:44.675203+00', 'Threave Collection and five other step dances, The', 'Threave Collection', 340, 1, 0, 1, 0, 24432, '2020-10-03 18:26:48+00', 0, 'Dances composed by Hope Little (copyright 1997) with music arranged by Margaret Rae & Muriel Johnstone (copyright Scotscores 1997).

', 0, '1997-00-00');
INSERT INTO 'publication' VALUES (454, '2002-12-31 23:00:00+00', '2021-06-25 09:39:33.557204+00', 'Whetherly Book 4', 'Whetherly 4', 270, 1, 0, 1, 1, NULL, NULL, 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages.  In this SCDDB record, the dances are numbered in succession, and not by page number



A revised edition by Alison Mitchell (with assistance of Viktor Lehmann and diagrams by Keith Rose) was re-published online in 2020 as PDF on www.scd-germany.de.', 0, '1979-00-00');
INSERT INTO 'publication' VALUES (201, '2002-12-31 23:00:00+00', '2020-10-04 10:43:46.810285+00', 'Bon Accord Book of Scottish Country Dances', 'Bon Accord', 108, 1, 0, 0, 1, 108, '2009-04-07 22:34:08+00', 0, 'John Drewry originally published two duplicated versions of the Bon Accord book (see his notes at end of this book).

He then had the book printed properly, containing 20 dances.  The copyright date is 1968.



The SNDC republished this version, appending three dances, Jennifer''s Jig, The Quaich and Flying Spur but keeping the copyright date of 1968 (the SNDC was not founded until 1970).



In 2003, TACBooks republished the book, putting the 23 dances into alphabetical order.', 0, '1968-00-00');
INSERT INTO 'publication' VALUES (1489, '2019-01-16 22:51:48.441985+00', '2021-03-30 19:55:59.617647+00', 'Collection of SCDs, Nova Scotia 2017, A', 'Collection Nova Scotia 2017', 11499, 1, 0, 1, 1, NULL, NULL, 0, 'Full Title:



A Collection of Scottish Country Dances  



Written by or in honour of Nova Scotian dancers  



Collected on the occasion of the 35th anniversary of the RSCDS Nova Scotia Branch in 2017  



Diagrams by Keith Rose



++++++++++++++++++++++++++++++++++++++++++++



These dances were compiled by the Royal Scottish Country Dance Society Nova Scotia Branch.  Twenty-one of the dances were published in Spark O'' Water, Dances of Nova Scotia in 2017 to celebrate the Branch''s 35th Anniversary. The rest of the dances were submitted for consideration for publication, but, due to technical restrictions, could not be included in the booklet. It seemed a shame that all the dances could not be shared, so the decision was made to create this document with all of the submitted dances.



The original booklet has an accompanying CD featuring the wonderful fiddle and piano music of Keith Smith and Muriel Johnstone. The CD is called Spark O'' Water, Music for Scottish Country Dancing.



The original booklet and CD are available for purchase from the RSCDS Nova Scotia Branch. (http://www.rscdsnovascotia.ca).', 0, '2017-12-31');
INSERT INTO 'publication' VALUES (1563, '2020-12-03 21:31:15.960466+00', '2020-12-03 21:34:37.582987+00', 'Collection of Strathspeys, Reels, Jiggs, A', 'Duff''s Collection', 1928, 0, 1, 0, 1, NULL, NULL, 0, 'Published circa 1792.



This is a stub entry and so far only contains tunes already included in the database and known to be in this book.', 0, '1792-00-00');
INSERT INTO 'publication' VALUES (1561, '2020-11-10 08:40:24.391982+00', '2020-11-10 14:22:35.635688+00', 'Borders Connection, The', 'Borders Connection', 11999, 0, 1, 0, 0, NULL, NULL, 0, 'Introduction from the publication:



Since we published our first book of tunes, “Winds of Change” in 2018 Seonaid and I have continued to add to our collection.



The tunes in “Border Connection”, with some exceptions, were written with dancing in mind and a number of the titles refer to the area of the Scottish Borders where we live.



2020 has been an exceptional year and we would like to share these tunes freely. Please use the music as you wish. Our only request is that our copyright is acknowledged and they are not used for personal gain.



We hope you find something you like in the collection.  

Roddy Johnston and Seonaid Lynn





For printed copies of the book of tunes please contact Roddy Johnston.', 0, '2020-09-30');
INSERT INTO 'publication' VALUES (1559, '2020-10-06 13:34:04.862366+00', '2020-10-16 05:14:11.660241+00', 'Eglinton Collection, The', '', 1415, 1, 0, 1, 1, 202, '2020-10-16 05:14:11.654957+00', 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (1564, '2020-12-08 00:47:00.346712+00', '2020-12-08 01:40:51.005987+00', 'Trillium Collection, The', '', 10971, 1, 0, 1, 0, 202, '2020-12-08 01:38:21+00', 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (1557, '2020-09-30 15:13:05.251726+00', '2020-10-23 15:04:33.709992+00', 'Freiburg Corona Collection, The', 'Freiburg Corona', 11983, 1, 0, 1, 0, 202, '2020-10-05 16:48:04+00', 0, 'This collection of dances was devised for the Freiburg Scottish Country Dancers. It developed during the first weeks after the lockdown in Germany was over, when dancing classes were possible again. All dances share the same feature – no giving of hands is needed, so they comply with the basic hygiene and keep-your-distance rules issued by the government. Some of the dances contain formations, however, that actually require the giving of hands. So whenever the pandemic is over, they can be danced ‘properly’ as well.', 0, 2020);
INSERT INTO 'publication' VALUES (1560, '2020-10-31 11:05:05.900925+00', '2020-10-31 11:05:05.900925+00', 'Logan''s Collection of Highland Bagpipe Music', 'Logan''s Collection', 11994, 0, 1, 0, 1, NULL, NULL, 0, 'A large collection of pipe tunes in eight books, the first published in 1899 by Logan & co.



This is a stub entry only linking tunes in the database known to be in this publication. There is a complete table of contents at <<https://ceolsean.net/content/Logan/Logan_TOC.html>>.', 0, '1899-00-00');
INSERT INTO 'publication' VALUES (1562, '2020-11-10 14:20:36.522782+00', '2020-11-11 00:41:04.7065+00', 'Wind of Change', '', 11999, 0, 1, 0, 0, NULL, NULL, 0, 'If you have interest in copies of this book of 68 tunes please contact Roddy Johnston.', 0, 2018);
INSERT INTO 'publication' VALUES (1141, '2013-05-17 21:56:10.127786+00', '2020-11-12 12:56:16.490889+00', '140 Scottish Country Dances', '140SCDs', 17, 1, 0, 0, 0, 209, '2017-09-15 12:28:31+00', 0, 'The document also lists the dances "Genevieve''s Jig" (1983, rf. RSCDS Bk 32), "Jaunt in July", "Lazy August", "Rain in Spring" (1989), "Rashleigh''s Reel" (1988), "Rose and Thistle" (2000), "Ruby Square", "Thistle Square" (1995), and "Thurso Square" (1991), but without description.', 0, 2010);
INSERT INTO 'publication' VALUES (1534, '2020-03-23 17:29:29.532058+00', '2021-08-23 16:16:20.639955+00', 'Pandemic Set of Dances, The', '', 11925, 1, 1, 0, 0, NULL, '2021-08-23 16:16:20.635576+00', 0, 'The dances are from the <<https://www.facebook.com/groups/5808618015/|Facebook SCD Teachers page>>.



Individuals contributed dances and Bob Messner gathered them together in March 2020 into this single document, originally with 8 dances.  He updates this as new dances & corrections come in.  ', 0, '2020-03-20');
INSERT INTO 'publication' VALUES (1297, '2016-03-16 09:42:10.193503+00', '2020-12-02 10:47:14.120116+00', 'CD booklet of Leicester Branch 1977-2002 The Silver Collection', 'Leicester Silver CD', 3006, 1, 1, 1, 1, NULL, NULL, 0, 'The CD that accompanies "The Silver Collection" by the Leicester Branch 1977-2002 (TRCD0302) contains the descriptions and music of the ten dances of that collection.  That collection is listed as publication http://my.strathspey.org/dd/admin/acedd/publication/83/



That CD also has the music and descriptions of five other leaflet dances published over the preceding 10 years by the Leicester Branch; but they are not actually part of "The Silver Collection".  This publication (publication/1297/) lists those dances. ', 0, '2003-01-01');
INSERT INTO 'publication' VALUES (1570, '2021-01-02 12:27:58.394936+00', '2021-01-03 12:10:49.434876+00', 'Fiddletree Manuscript 2', 'Fiddletree 2', 12009, 0, 1, 1, 0, NULL, NULL, 0, 'This is a stub entry and only links tunes used in dances.', 0, 0000);
INSERT INTO 'publication' VALUES (1571, '2021-01-03 12:09:46.945268+00', '2021-01-03 12:09:46.945268+00', 'Melodies Yn THe Scottish style', 'MYTHS', 12009, 0, 1, 1, 0, NULL, NULL, 0, 'The capitalisation in the title is supposed to spell MYTHS.', 0, 0000);
INSERT INTO 'publication' VALUES (1569, '2021-01-02 12:26:49.088386+00', '2021-01-03 12:10:05.795242+00', 'Jink & Diddle Book o'' Tunes 2019', 'Jink & Diddle 2019', 12009, 0, 1, 1, 0, NULL, NULL, 0, 'This is a stub entry and only links tunes used in dances.', 0, 2019);
INSERT INTO 'publication' VALUES (1568, '2021-01-02 12:20:18.770627+00', '2021-01-03 12:11:15.218457+00', 'Jink & Diddle Book o'' Tunes 2017', 'Jink & Diddle 2017', 12009, 0, 1, 1, 0, NULL, NULL, 0, 'This is a stub entry and only links tunes used in dances.', 0, 2017);
INSERT INTO 'publication' VALUES (1567, '2021-01-02 12:17:49.342657+00', '2021-01-03 12:11:35.046062+00', 'Jink & Diddle Book o'' Tunes 2011', 'Jink & Diddle 2011', 12009, 0, 1, 1, 0, NULL, NULL, 0, 'This is a stub entry and only links tunes used in dances.

', 0, '2011-00-00');
INSERT INTO 'publication' VALUES (436, '2002-12-31 23:00:00+00', '2023-01-04 17:13:14.816915+00', 'Scottish Dance Archives', 'SDA', 1343, 1, 0, 0, 1, NULL, NULL, 0, 'This entry primarily concerns the publication scheme known as “Scottish Dance Archives” under which 190 newly devised Scottish Country dances from numerous devisers were published in the years 1972-81. All these dances have separate entries in this database, and are linked with this publication entry.



However, it is easy to confuse this scheme with the much more recent “Dance Archives” initiative, especially since both activities heavily involved one person, <<ddp:Donald, Bob#105>>. An explanation of the separate Dance Archives will therefore be found at the end of this article.



_1.	Scottish Dance Archives_



<<ddp:Clowes, Roy#82>> and <<ddp:Donald, Bob#105>>, both active dancers, dancing teachers and dance devisers in the Merseyside area, launched the scheme in 1972, to help aspiring devisers of new SCD to get their dances publicised and distributed.



This initiative came at a time when just a few major devisers of new Scottish Country dances had become well known, notably <<ddp:#129|Hugh Foss>> (who had just died) and <<ddp:#108|John Drewry>> in the UK, and also some other devisers elsewhere such as <<ddp:#62|Robert Campbell>> and <<ddp:#35|Marie Boehmer>> in Canada. Numerous other devisers had new dances to introduce, but lacked an easy way to issue them, since producing printed booklets was time-consuming and expensive.



At the same time, the RSCDS itself, despite having experimented with the publication of new dances in the 1960s, in Books 22 and 23, seemed to have turned its back completely on new dances, and in its more recently issued books had reverted to publishing dances taken exclusively from historical sources. (That policy was eventually reversed starting with Book 31 in 1983.)



Under the Scottish Dance Archives scheme, Roy and Bob accepted submissions of new dances, and helped the devisers by practical testing of the dances and their instructions. The finished dances, selected for widest appeal by Roy and Bob, were then distributed to interested subscribers in groups of ten loose foolscap sheets twice yearly, starting in September 1972.



Production costs were minimised by the sheets being typed on stencils and duplicated, with strathspeys, reels, jigs and medleys printed on orange, pink, blue and white paper respectively. Occasionally other (yellow) sheets were also distributed, covering teaching and discussion topics, and also a few demonstration “set dances” and Highland dances.



Roy and Bob had hoped that after “releasing the dam”, the early flood of newly devised dances would slow to a trickle, but the flow of new submissions never eased, this being an early phase of what we now call “the dance explosion”.  Consequently they decided to close the scheme in 1982, after ten years in which they had published 190 new Scottish Country dances.



A little before that, the SDA team had used a growing surplus of cash from subscriptions to finance a weekend dance school in Liverpool in 1978, with several eminent teachers and musicians contributing. Some of the material from those sessions was then subsequently circulated to SDA subscribers as the very informative booklet ”Notes on teaching Scottish Country Dancing”.



By its close, nearly ninety different dance devisers had contributed to Scottish Dance Archives, mostly with just one submission each, but a few had contributed several times, including <<ddp:Haynes, Derek#175>>, <<ddp:Priddey, Barry#313>>, <<ddp:#850|Douglas & Lisbeth Henderson>>, <<ddp:Firth, Sam#696>>, <<ddp:#57|Tony Bulteel>> and <<ddp:#567|Anne Large>>. A scan of the dance list will also reveal several other well-known dance devisers, including some from Canada, New Zealand and the USA, and both the founders <<ddp:Clowes, Roy#82>> and <<ddp:Donald, Bob#105>>. Several of the dances were later re-published by their devisers in their own collections, but for some dances, the SD Archives manuscripts remain the original source, for example <<ddd:The Pines of Pitlochry#5260>> and <<ddd:Mr. George Gray’s Reel#4709>>. 



_2.	The “Dance Archives” website_



As the separate entry for <<ddp:Donald, Bob#105>> explains, during the 1970s, as well as helping to run Scottish Dance Archives, Bob was involved in other activities. In particular for a few years, under the name “<<ddp:Hugh Foss (Formby)#12219>>”, Bob and his wife Mamie ran a mail-order business, originally started by <<ddp:#129|Hugh Foss>> himself, for the distribution of sheets and books for dances not connected with the RSCDS.



Bob and Mamie ceased running this service around 1980, that role then being taken up by others, but partly as a result of running “Hugh Foss (Formby)”, Bob and Mamie ended up with an impressive collection of hardcopy SCD instructions, including some material that had become hard to find, such as the <<ddpub:#155|Glendarroch sheets>>, originally published by <<ddp:#129|Hugh Foss>> in the late 1960s and featuring dances by him, <<ddp:Haynes, Derek#175>>, and others.



When web-based online information sources started up, around the year 2000, Bob and Mamie seized this opportunity in two ways. First, they set up the website www.dancearchives.co.uk which provided two things: an online index to their hardcopy dance collection, and online transcripts for the instructions of about 250 selected dances. Those online transcripts were prepared individually by Bob, not without effort, and in some cases, such as those for the <<ddpub:#155|Glendarroch sheets>> just mentioned, the transcripts were far more readable than the typed originals.



Also, having by now moved from Lancashire to Edinburgh, Bob and Mamie then donated their hardcopy dance material to the music department of Edinburgh Central Library, for use as reference material, and it is now known there as the Donald Collection.



In 2020, RSCDS London Branch agreed to take over the Donalds’ online website. The full contents are now accessible on the new link

      <<https://www.rscdslondon.org.uk/scottish-dance-archives/>>.

However, despite the similarity of name, in most cases the 190 dances published via the Scottish Dance Archives scheme in the 1970s are NOT among the dances with instructions available online through the new website. More details of those online instructions can be found there. The duplicate of the list can be found in our database too, visit: <<https://my.strathspey.org/dd/publication/1668/>>

', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (1583, '2021-03-15 21:09:03.626907+00', '2021-05-01 21:41:01.416187+00', 'Three Traditional Scottish Dances - 7th Set', 'MacNab 7th Set', 319, 1, 1, 0, 1, NULL, NULL, 0, 'This is the 7th set of dances collected by <<ddp:MacNab#242>>. They were taught at the 1962 summer school and published around that time as a <<https://archive.rscds.org/index.php/three-traditional-scottish-dances-7th-set|leaflet>> by the RSCDS prior to the subsequent combined editions.', 1, 1962);
INSERT INTO 'publication' VALUES (544, '2002-12-31 23:00:00+00', '2021-01-21 11:55:32.702463+00', 'Collection for the Washington State Centennial, A', 'Washington State Centennial', 208, 1, 1, 1, 0, NULL, NULL, 0, 'Not available on paper.



Washington State celebrates 100 years of statehood from November 11, 1988 to November 11, 1989. As part of the celebration, the Kelso 

Scottish Country Dancers (affiliated with the Vancouver USA Scottish Country Dancers) conducted a contest to create an official Washington State Centennial Scottish Country Dance. The dances were required to relate to at least one part of the three-part Washington State Centennial celebration theme: 



 -- Celebrate the heritage of the past 



 -- Enjoy the energy of the present 



 -- Share the promise of the future. 



We are pleased to present the contest winner as well as nine additional entries in this booklet. 

', 0, '1988-11-00');
INSERT INTO 'publication' VALUES (796, '2002-12-31 23:00:00+00', '2021-02-25 01:11:46.006448+00', 'Saint Andrews of Brampton Book 2', 'Brampton 2', 440, 1, 0, 0, 1, 202, '2021-02-24 00:44:51+00', 0, '', 0, 1996);
INSERT INTO 'publication' VALUES (406, '2002-12-31 23:00:00+00', '2021-03-02 21:02:42.908777+00', 'Roll Back the Carpet - We Agree to Differ', '', 129, 1, 0, 1, 1, 106, '2011-07-30 22:03:43+00', 2, 'The publication carries no date, but it must be after 1954 as there is a reference to that year.  Much of the text was originally published in "The Reel" of the London Branch.



This delightful and interesting book describes and analyses a large variety of possible SCD figures.  Only one dance is described, "Fugal Fergus", in the section on Counterpoint.  The final discussions between "Light" and "Dark" in "We agree to differ", especially the famous "The Reel of three Perplexes Me", should be read by every dancer interested in the deeper structures of SCD.





London Branch has recently made scans of old issues of The Reel available on the web via <<https://www.rscdslondon.org.uk/the-reel-archives/>>



Those without access to the subsequent collection in book form can use the following links to the complete issues containing the original articles.

One bonus issue (77) contains two articles.



_We Agree to Differ (1952)_



  1. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/04/Reel-004-January-February-1952.pdf#page=2|Reel#004>> *The Reel of Three Perplexes Me*

  2. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/08/Reel-005-March-1952.pdf#page=2|Reel#005>> *Should We?*

  3. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/02/Reel-006-April-May-1952.pdf#page=2|Reel#006>> *The Women''s Reel*

  4. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/02/Reel-007-June-August-1952.pdf#page=2|Reel#007>> *New Dances*

  5. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/02/Reel-008-September-October-1952.pdf#page=2|Reel#008>> *Beginners*



_Roll Back the Carpet (1963-5)_



  1. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-071-February-March-1963.pdf#page=5|Reel#071>> *Madrigals*

  2. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-072-April-May-1963.pdf#page=4|Reel#072>> *New figures from old*

  3. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-073-June-July-1963.pdf#page=2|Reel#073>> *More new reels*

  4. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-074-August-September-1963.pdf#page=4|Reel#074>> *Grafting*

  5. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-075-October-November-1963.pdf#page=4|Reel#075>> *Counterpoint*

  6. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-077-February-March-1964.pdf#page=4|Reel#077>> *Joints, plain and fitted*

  7. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-077-February-March-1964.pdf#page=5|Reel#077>> *Joints, flows and pauses*

  8. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-078-April-May-1964.pdf#page=2|Reel#078>> *The dance and its tune*

  9. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-079-June-July-1964.pdf#page=2|Reel#079>> *The tune: Structure*

  10. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-080-August-September-1964.pdf#page=5|Reel#080>> *The tune: content*

  11. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-081-October-November-1964.pdf#page=3|Reel#081>> *Petronella*

  12. <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/03/Reel-082-December-1964-January-1965.pdf#page=3|Reel#082>> *The Montgomeries'' Rant*

', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (1574, '2021-02-19 08:00:28.832666+00', '2021-02-19 17:20:26.50431+00', 'Devil''s Quandary Book 1, The', 'Devil''s Quandary 1', 2961, 1, 1, 1, 1, NULL, NULL, 0, 'Please note: There are two versions of Book 1, an electronic PDF version and the older printed version.



The latter version seems not to contain the dance "Down Unda".', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (337, '2002-12-31 23:00:00+00', '2021-03-02 21:07:50.90993+00', 'Ian Powrie''s Farewell to Auchterarder', 'Ian Powrie''s Farewell', 3518, 1, 1, 0, 1, NULL, NULL, 0, 'Publication date around 1967-8 (see <<https://my.strathspey.org/dd/issue/2331/|issue 2331>>).', 0, 1967);
INSERT INTO 'publication' VALUES (1577, '2021-03-12 23:33:25.148914+00', '2021-03-12 23:52:37.670703+00', '24 Favourite Scottish Country Dances', 'RSCDS 24 Fav', 319, 1, 1, 0, 1, NULL, NULL, 0, 'Some photos of the front cover show 1954, others have no date.



The publication also contains music but these are not yet listed here.



The index misspells "Circassian Circle" as "Cicassian Circle". The dance "The Ninety-second" is here referred to by its alternative title "Marquis of Huntly''s Highlanders" and "Teviot Bridge" is here spelled "Teviot Brig".', 1, '1954-00-00');
INSERT INTO 'publication' VALUES (1573, '2021-02-19 07:32:25.975794+00', '2021-02-19 17:26:38.554295+00', 'Devil''s Quandary Book 2, The', 'Devil''s Quandary 2', 2961, 1, 1, 0, 1, NULL, NULL, 0, 'Tunes still missing', 0, 0000);
INSERT INTO 'publication' VALUES (833, '2002-12-31 23:00:00+00', '2021-02-19 17:28:02.160539+00', 'Devil''s Quandary, The', 'Devil''s Quandary', 2961, 1, 1, 1, 1, NULL, NULL, 0, 'This is the joint publication of the content of Devil''s Quandary Books 1 and 2.



The Devil''s Quandary Books contain dances for different levels of dancing.

Dances 1-30 (pp 1-17) are beginner dances, 31-60 (pp 21-44) are intermediate/advanced dances.



Date has been added after consulting Bob McMurtry.', 0, '2002-00-00');
INSERT INTO 'publication' VALUES (1576, '2021-03-12 16:50:37.075665+00', '2021-03-12 17:34:36.404035+00', 'Russian Collection, The', '', 635, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (1575, '2021-03-04 10:37:07.316872+00', '2021-03-04 12:21:31.255643+00', 'Peat Road and Other Dances, The', 'Peat Road Book, The', 10959, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (719, '2002-12-31 23:00:00+00', '2021-03-10 12:10:04.392718+00', 'Cambridge Scottish Society Diamond Jubilee, Twelve Dances 1936 - 1996', 'Cambridge Diamond', 61, 1, 0, 0, 1, NULL, NULL, 0, 'The dances in this book are selected from entries in a dance competition held by Cambridge Scottish Society Dance Circle to celebrate the Society’s Diamond Jubilee. Donald Wilson, chairman 1994-95 adds, "arriving at the dances after devising, testing and revising was great fun".', 0, 1996);
INSERT INTO 'publication' VALUES (480, '2002-12-31 23:00:00+00', '2021-05-07 22:28:30.856226+00', 'Thistle - A Magazine of Scottish Country Dancing and Allied Subjects, The', 'Thistle', 392, 1, 0, 0, 1, NULL, NULL, 0, 'PDF scans of all 55 issues of The Thistle, published betwen 1961 and 1973, are available via <<https://www.rscdslondon.org.uk/the-thistle-magazine-john-mitchell-bequest/|London Branch Archives>>.



Assignment of dance numbers in a magazine is not entirely clear. Most are now listed by the issue number, but a few, perhaps only mentioned in passing, still have number 0. As these are generally republications, the dance "priority" is set to 40 so they appear after an original publication. However the descriptions here frequently have some interesting background information.', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (1572, '2021-02-18 04:44:11.411842+00', '2021-02-18 05:35:49.183136+00', 'Hornpipes, Jigs, Strathspeys and Reels Composed by Fred Moyes', 'Hornpipes, Jigs, Strathspeys and Reels', 1836, 0, 1, 0, 1, NULL, NULL, 0, 'Printed by Thistle-Maple Music Publications', 0, 0000);
INSERT INTO 'publication' VALUES (1580, '2021-03-14 19:39:15.298075+00', '2021-05-01 21:16:26.00029+00', 'Three Traditional Scottish Dances - 4th Set', 'MacNab 4th Set', 319, 1, 1, 0, 1, NULL, NULL, 0, 'This is the 4th set of dances collected by <<ddp:MacNab#242>>. They were taught at the 1956 summer school and published as a <<https://archive.rscds.org/index.php/three-traditional-scottish-dances-4th-set|leaflet>> by the RSCDS prior to the subsequent combined editions.', 1, 1956);
INSERT INTO 'publication' VALUES (1595, '2021-07-04 12:19:20.932815+00', '2022-12-18 11:11:15.576183+00', 'St Andrews Collection of Step Dances, Volume 1, The', 'St Andrews Step 1', 319, 1, 0, 0, 1, NULL, NULL, 0, 'This is a stub entry. Only one dance is initially added (from <<https://my.strathspey.org/dd/issue/2443/|issue 2443>>).', 1, 2010);
INSERT INTO 'publication' VALUES (1578, '2021-03-14 12:16:39.137088+00', '2021-05-01 19:52:12.22646+00', 'Four Traditional Scottish Dances - 2nd Set', 'MacNab 2nd Set', 319, 1, 0, 0, 1, NULL, NULL, 0, 'This is the 2nd set of dances collected by <<ddp:MacNab#242>>. They were taught at the 1950 summer school and published around that time as a <<https://archive.rscds.org/index.php/four-traditional-scottish-dances-2nd-set|leaflet>> by the RSCDS prior to the subsequent combined editions.

', 1, '1950-00-00');
INSERT INTO 'publication' VALUES (474, '2002-12-31 23:00:00+00', '2021-04-01 09:23:04.54873+00', 'Whetherly Book 24 (Dances 17th, 18th, 19th Century)', 'Whetherly 24', 270, 1, 0, 0, 1, 30976, '2019-11-30 09:13:26+00', 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages. In this SCDDB record, the dances are numbered in succession, and not by page number.



The dance Mrs Booth''s Minuet appears twice in this publication, once as ''Drapers Maggot'' (page 6) and once as ''Mrs Booth''s Minuet'' (page 54).



The title of the SCDDB entry reflects the contents of the book, but as reported in <<http://my.strathspey.org/dd/issue/1930/|issue 1930>> the title on paper just reads "The Whetherly Book of Scottish Country Dances Number 24".



An updated version of this book is in preparation (2020). This will have a number of corrections as listed in <<http://my.strathspey.org/dd/issue/2184/|issue 2184>>.

', 0, '1991-00-00');
INSERT INTO 'publication' VALUES (1581, '2021-03-14 19:48:21.340228+00', '2021-05-01 20:22:44.286589+00', 'Four Traditional Scottish Dances - 5th Set', 'MacNab 5th Set', 319, 1, 1, 0, 1, NULL, NULL, 0, 'This is the 5th set of dances collected by <<ddp:MacNab#242>>. They were taught at the 1958 summer school and published as a <<https://archive.rscds.org/index.php/four-traditional-scottish-dances-5th-set|leaflet>> by the RSCDS prior to the subsequent combined editions.

', 1, '1958-00-00');
INSERT INTO 'publication' VALUES (314, '2002-12-31 23:00:00+00', '2021-06-22 12:57:07.026933+00', 'Hamilton Silver Anniversary', 'Hamilton Silver', 166, 1, 0, 0, 1, NULL, NULL, 0, 'The book was publish to celebrate the silver anniversary of the Hamilton Branch (Ontario, Canada) from 1954 to 1979.', 0, 1979);
INSERT INTO 'publication' VALUES (1585, '2021-03-15 21:17:28.401387+00', '2021-05-01 22:07:47.980883+00', 'Two Traditional Scottish Dances - 9th Set', 'MacNab 9th Set', 319, 1, 1, 0, 1, NULL, NULL, 0, 'This is the 9th and last set of dances collected by <<ddp:MacNab#242>>. They were  published in 1966 as a <<https://archive.rscds.org/index.php/two-traditional-scottish-dances-9th-set|leaflet>> by the RSCDS prior to the subsequent combined editions.



In addition to the two "MacNab" dances this also contains The Silver Tassie.', 1, '1966-00-00');
INSERT INTO 'publication' VALUES (1586, '2021-04-05 09:01:25.420266+00', '2021-04-05 09:16:30.14607+00', 'Counting Sheep', '', 11029, 1, 0, 1, 0, 202, '2021-04-05 09:16:30.137195+00', 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (230, '2002-12-31 23:00:00+00', '2021-06-22 16:09:40.376716+00', 'Braeside Dances', 'Braeside', 141, 1, 0, 0, 1, NULL, NULL, 0, 'Six new SCD in traditional form by Margaret D. Gibbs. Formally published by the Banbury SCD group.



The order of the dances is as given in <<https://my.strathspey.org/dd/issue/2487/|issue 2487>> (which is not the alphabetical order they were originally entered in SCDDB).', 0, '1967-00-00');
INSERT INTO 'publication' VALUES (357, '2002-12-31 23:00:00+00', '2021-06-22 18:33:29.258108+00', 'Just Enough to Dance', 'Just Enough', 1391, 1, 0, 0, 1, NULL, '2013-01-25 20:23:52+00', 0, 'A note in the book says that "most of the dances in this book can be danced to strathspey time or to jig and reel time."', 0, 1996);
INSERT INTO 'publication' VALUES (1591, '2021-06-06 21:04:11.527257+00', '2021-06-06 21:04:11.527257+00', 'Scottish Country Dances in Diagrams. Ed. 1', 'Pillings 1', 398, 1, 0, 0, 1, NULL, NULL, 0, 'A stub entry, so far just with publication date (from <<https://my.strathspey.org/dd/issue/2467/|issue 2467>>).', 0, 1955);
INSERT INTO 'publication' VALUES (1587, '2021-04-06 16:04:03.703988+00', '2021-04-06 16:22:24.127579+00', 'George Bell Collection, The', 'Bell Collection', 1579, 0, 1, 0, 0, NULL, NULL, 0, 'Incomplete entry. Information taken from https://musicscotland.com/products/george-bell-george-bell-collection-book (which has some variant spellings) but only dances already known to SCDDB are linked so far.', 0, 0000);
INSERT INTO 'publication' VALUES (1593, '2021-06-06 21:08:06.189075+00', '2021-06-06 21:13:15.517563+00', 'Scottish Country Dances in Diagrams. Ed. 3', 'Pillings 3', 398, 1, 0, 0, 1, NULL, NULL, 0, 'A stub entry, so far just with publication date (from <<https://my.strathspey.org/dd/issue/2467/|issue 2467>>).



Revised 1970.



The very first edition of ''The Wee Green Book'' was published in 1955.', 0, '1969-00-00');
INSERT INTO 'publication' VALUES (1592, '2021-06-06 21:07:00.834393+00', '2021-06-06 21:13:27.412363+00', 'Scottish Country Dances in Diagrams. Ed. 2', 'Pillings 2', 398, 0, 0, 0, 0, NULL, NULL, 0, 'A stub entry, so far just with publication date (from <<https://my.strathspey.org/dd/issue/2467/|issue 2467>>).



The very first edition of ''The Wee Green Book'' was published in 1955.', 0, '1958-00-00');
INSERT INTO 'publication' VALUES (1441, '2018-04-03 11:35:32.671583+00', '2021-06-12 17:57:50.879181+00', 'Caledonian Country Dances [1754]', 'Caledonian 1754', 9998, 1, 0, 0, 0, NULL, NULL, 0, 'The RSCDS publication "Scottish Country Dances Books 13-18" states *Caledonian Country Dances* (1754) as the source of dances.', 0, 1754);
INSERT INTO 'publication' VALUES (1594, '2021-06-20 20:08:58.489195+00', '2021-06-20 20:08:58.489195+00', 'Two Dances for Prince William at St Andrews', 'Two for William', 367, 1, 1, 0, 1, NULL, NULL, 0, 'According to <<https://my.strathspey.org/dd/issue/2473/|issue 2473>> the front page reads "Two dances devised to mark Prince William''s years at St Andrews University". The title in this database entry is slightly abbreviated.', 0, 2004);
INSERT INTO 'publication' VALUES (1589, '2021-04-19 10:43:06.789459+00', '2021-04-24 08:12:10.312544+00', 'Méaudre Reel Book 1', '', 12048, 1, 0, 0, 0, 202, '2021-04-19 11:39:20+00', 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (1582, '2021-03-15 21:06:35.468966+00', '2021-05-01 19:40:11.311251+00', 'Three Traditional Scottish Dances - 6th Set', 'MacNab 6th Set', 319, 1, 1, 0, 1, NULL, NULL, 0, 'This is the 6th set of dances collected by <<ddp:MacNab#242>>. They were taught at the 1960 summer school and published around that time as a <<https://archive.rscds.org/index.php/three-traditional-scottish-dances-6th-set|leaflet>> by the RSCDS prior to the subsequent combined editions.', 1, 1960);
INSERT INTO 'publication' VALUES (1590, '2021-05-26 23:14:09.318818+00', '2021-07-30 13:46:56.316514+00', 'Toronto Connections', '', 440, 1, 0, 0, 0, 202, '2021-05-26 23:27:14+00', 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (1055, '2011-08-22 22:00:00+00', '2021-06-22 12:00:02.093156+00', 'Geordie Diamond, The', 'Geordie Diamond', 289, 1, 1, 1, 1, NULL, NULL, 0, 'Published in May 2010. Celebrating the diamond jubilee of the Royal Scottish Country Dance Society Newcastle upon Tyne and District Branch 1950-2010. Dances devised by Dr. Peter Avery.', 0, 2010);
INSERT INTO 'publication' VALUES (278, '2002-12-31 23:00:00+00', '2021-06-23 06:50:23.064448+00', 'Sutton Coldfield Book of SCD, The', 'Sutton Coldfield', 313, 1, 0, 1, 1, NULL, NULL, 0, 'The book is celebrating twenty-one happy years of Scottish Country Dancing in Sutton Coldfield, after the founding of the group in the year June 1959.



Barry Priddey who has devised all the dances in the book started as class teacher of of the Sutton Coldfield group in January the same year the book was published (1980).', 0, '1980-00-00');
INSERT INTO 'publication' VALUES (1052, '2011-08-22 22:00:00+00', '2021-06-23 07:16:05.432794+00', 'Scottish Country dances - London 75th', 'London 75th', 235, 1, 1, 0, 1, 104, '2011-08-23 08:30:12+00', 1, '', 0, 2005);
INSERT INTO 'publication' VALUES (1310, '2016-06-22 22:26:11.636262+00', '2021-08-10 17:12:58.497995+00', 'Geneva Park Dances Part 1 (Campbell), The', 'Geneva Park 1', 62, 1, 1, 1, 1, NULL, NULL, 0, 'Geneva Park on Lake Couchiching is where the annual Toronto Branch weekend is regularly held.



Includes the description, with diagrams, of a new figure, the Philabeg, p. 15, and notes on the dances on p. 16



NOTE:  The tune for "Geneva Park" (printed on page 2) is called "The Devil in Dublin" (Kerr''s fourth collection for the violin; Arranged by Nan Main).  As it may differ from the tune of the same name composed by William Marshall, this tune has not been entered yet on this page.  Eric F.  june 2016.', 0, '1970-00-00');
INSERT INTO 'publication' VALUES (1588, '2021-04-14 11:10:02.022591+00', '2021-11-24 08:41:44.328782+00', 'Paris Book of Scottish Country Dances, volume 2, The', 'Paris Book 2', 11342, 1, 0, 1, 1, 12064, '2021-11-20 15:53:26+00', 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (1068, '2011-08-25 22:00:00+00', '2021-07-04 09:03:51.647323+00', 'Waverley Suite, The', 'Waverley Suite', 10448, 1, 0, 1, 1, 202, '2018-09-01 23:34:25+00', 0, 'The Waverley Scottish Society celebrated its 40th anniversary in 2008. To celebrate the occasion, Frances Wallace devised a series of dances which were published by the Society as The Waverley Suite.', 0, 2008);
INSERT INTO 'publication' VALUES (1600, '2021-09-15 20:19:12.197327+00', '2021-09-16 20:08:44.205136+00', 'Further Ado', '', 12066, 1, 1, 1, 0, 202, '2021-09-16 10:55:42+00', 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (51, '2002-12-31 23:00:00+00', '2021-07-03 21:15:36.154815+00', 'Miss Milligan''s Miscellany Volume II', 'MMM II', 319, 1, 0, 0, 1, 103, '2009-03-13 14:26:27+00', 0, 'Publication date provided in <<https://my.strathspey.org/dd/issue/2499/|issue 2499>>.', 1, 1977);
INSERT INTO 'publication' VALUES (1125, '2013-02-04 11:47:01.477109+00', '2021-07-03 21:20:04.934253+00', 'Miss Milligan''s Miscellany of Scottish Country Dances', 'MMM', 319, 1, 0, 0, 1, 1034, '2017-11-05 07:40:03+00', 0, 'This is the new revised one-volume edition.



<<https://my.strathspey.org/dd/issue/2502/|Issue 2502>> reports that the original two volume edition was published in 1977.', 1, '2007-00-00');
INSERT INTO 'publication' VALUES (1172, '2013-12-22 23:02:58.595076+00', '2021-07-04 08:55:11.120691+00', 'Princess Bride Collection of Scottish Country Dances, The', 'The Princess Bride Collection', 312, 1, 0, 1, 0, NULL, '2015-01-04 10:05:26+00', 0, 'The book was actually published jointly by the Southwest Washington State Branch AND the Portland Oregon Branch. The database editors would have liked to include both as official publishers, but the database only allows a single publisher, so this note is used instead.  Apologies to  the Southwest Washington State Branch for being the one left out; the choice was arbitrary.', 0, 2013);
INSERT INTO 'publication' VALUES (229, '2002-12-31 23:00:00+00', '2021-07-06 20:46:30.561985+00', 'Tartan Track, The', 'Tartan Track', 181, 1, 0, 0, 1, NULL, NULL, 0, 'Dances devised by <<ddp:Holden, Anna Campbell#181>> to commemorate the Commonwealth Games in Scotland 1970. Music composed by <<ddp:Johnston, Beryl#1701>>. The dance instruction pages just have titles like "Dance No. 1 Reel" rather than "The Tartan Track Reel" as currently entered in SCDDB (perhaps to be more distinctive). The dances incorporate the ideas of the Tartan Track, the Cross of St. Andrews and the Right Hand of Fellowship (info from <<https://my.strathspey.org/dd/issue/2519/|issue 2519>>).', 0, 1970);
INSERT INTO 'publication' VALUES (374, '2002-12-31 23:00:00+00', '2021-07-06 22:07:11.02159+00', 'San Francisco Collection Volume 2', 'San Francisco 2', 338, 1, 1, 0, 1, NULL, NULL, 0, 'The foreword begins with: ''This book is a long overdue sequel to "San Francisco Collection", first published in 1979.''', 0, 1997);
INSERT INTO 'publication' VALUES (309, '2002-12-31 23:00:00+00', '2021-07-08 09:37:56.705096+00', 'Delft Book of Scottish Country Dances', 'Delft', 2916, 1, 1, 0, 1, NULL, NULL, 0, 'Published in May 2001. Most of the dances can be found via the Delft branch website at <<https://rscds-delft.nl/>> under the tab "Dansen" which has entries for each dance deviser.', 0, 2001);
INSERT INTO 'publication' VALUES (1597, '2021-07-25 16:46:13.240246+00', '2021-07-25 16:56:39.796459+00', 'Odd Half-Dozen, The', 'Odd Half-Dozen', 1276, 1, 0, 0, 0, NULL, NULL, 0, 'Six Scottish Country Dances devised by Adrian Conrad.', 0, 2021);
INSERT INTO 'publication' VALUES (1157, '2013-08-29 13:20:35.477391+00', '2021-07-21 11:49:48.957199+00', 'Reel of the Gordon Highlanders, The', '', 1500, 1, 1, 0, 1, NULL, NULL, 0, 'Leaflet for just his one dance.



The dance was devised for the Regiment of the Gordon Highlanders on the occasion of its 200th Anniversary in 1994. 



The inside of the cover of this one dance leaflet also mentions: "The present Regiment stems directly from the amalgamation, in 1881, of the 75th Stirlingshire Regiment and the 92th (Highland) Regiment of Foot. The 92nd, was raised in 1794 as the 100th (Highland) Regiment of Foot - known as the Gordon Highlanders - by Jean, Duchess of Gordon, at a time when Britain faced a war with Revolutionary France. It was renumbered 92nd in 1798. The 75th was raised in 1787 as the 75th Highland Regiment - known as Abercromby''s - in the county of Stirling to assist the East Indian Company. On amalgamation in 1881 the new Regiment was named ''The Gordon Highlanders''. In September 1994 the Gordon Highlanders were amalgamated with the Queen''s Own Highlanders to form a new regiment ''The Highlanders''."', 0, '1994-01-01');
INSERT INTO 'publication' VALUES (931, '2004-06-12 22:00:00+00', '2021-07-21 12:17:29.421098+00', 'Reel of the Transvaal Scottish, The', 'Reel of Transv Scots', 1500, 1, 1, 0, 0, NULL, NULL, 0, 'This dance was devised for the Tranvaal Scottish Regiment on the occasion of its Centenary 2002.



The inside of the cover of this one dance leaflet also mentions about the The Tranvaal Scottish:



On 9 June 1902, shortly after the Anglo-Boer War had ended, the Marquis of Tullibardine raised the Tranvaal Scottish Volunteers, as an infantry unit to be part of the embryonic Defence Fore of the Transvaal Colony. In 1910 the name was changed into The Transvaal Scottish. In October 1927, the Transvaal Scottish was affiliated to The Black Watch (Royal Highland Regiment).



Sidenote: According to Aad Boode (the deviser of the dance), the tune was also composed by Bill Clement also in 2002 (same year as the dance itself). 



Bill Clement (the composer of the dance''s tune) served in The Black Watch (Royal Highland Regiment) from May 1942 to April 1947; he joined the 10th Battalion Pipe Band in January 1943 and was acting Pipe-Major from January 1946. He joined the Atholl Highlanders in October 1947.', 0, '2002-00-00');
INSERT INTO 'publication' VALUES (1356, '2017-03-10 22:36:28.095059+00', '2021-07-30 09:16:48.558005+00', 'Footnotes 3', '', 11170, 1, 0, 0, 0, NULL, NULL, 0, 'The entry for this publication and those for many of the dances in it are stub entries. The only information about them comes from <<http://moirastacey.com/?page_id=2|the deviser''s website>>.', 0, 0000);
INSERT INTO 'publication' VALUES (979, '2005-06-29 22:00:00+00', '2021-08-09 17:58:53.525277+00', 'Originally Ours', 'Originally Ours', 319, 0, 1, 1, 1, NULL, NULL, 0, 'Contains the tune, “Kinrara”, by Wm. Marshall, under the title “The Countess of Dalkeith”.



According to <<https://my.strathspey.org/dd/issue/2593/|issue 2593>> this book contains all of the nearly 700 original tunes for the RSCDS dances to date, up and including book 45.', 1, '2005-00-00');
INSERT INTO 'publication' VALUES (1357, '2017-03-10 22:46:13.877859+00', '2021-07-30 21:38:34.786338+00', 'Footnotes 4', '', 11170, 1, 0, 0, 0, NULL, NULL, 0, 'The entry for this publication and those for many of the dances in it are stub entries. The only information about them comes from <<http://moirastacey.com/?page_id=2|the deviser''s website>>.', 0, 0000);
INSERT INTO 'publication' VALUES (497, '2002-12-31 23:00:00+00', '2021-08-10 17:19:34.111913+00', 'Centennial Collection, A', 'Deep River Cent.', 97, 1, 0, 0, 1, NULL, NULL, 0, 'Rod Downey writes:  I was given a photocopy of an original of this and it is dated 1967.



The front says: These dances were submitted for a collection of SCD''s to commemorate Canada''s Centennial in 1967.  It then goes on to say "The Saint John River" won.



A digital recontruction was made in 2020 and is available via the Toronto website <<http://www.dancescottish.ca/books.html>>.', 0, '1967-00-00');
INSERT INTO 'publication' VALUES (1493, '2019-04-03 14:03:18.94099+00', '2021-08-16 21:14:59.192851+00', 'Leaflet for Carol Anderson''s 80th Birthday', 'Carol''s Celebration Leaflet', 3694, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2016);
INSERT INTO 'publication' VALUES (1604, '2021-11-05 17:18:43.290992+00', '2021-11-05 20:43:07.342238+00', 'Covid-19 Collection', '', 407, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (1598, '2021-08-19 12:18:41.929035+00', '2021-08-20 13:55:30.419783+00', 'Friday Fun Night at the Stagger Inn', 'Stagger Inn', 11858, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (1599, '2021-08-21 00:18:50.387228+00', '2021-09-10 04:07:20.695927+00', 'Brampton Connections', '', 440, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (1606, '2021-11-23 07:03:37.826431+00', '2021-11-24 14:05:04.17178+00', 'Paris Book of Scottish Country Dances, Companion Book of Tunes, volume 2, The', 'Paris Book Tunes 2', 11342, 0, 1, 1, 1, 12064, '2021-11-23 13:19:42+00', 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (1326, '2016-07-12 23:25:18.413356+00', '2021-09-20 22:18:52.900949+00', 'Buckie Lad, The', '', 12053, 1, 0, 0, 0, NULL, NULL, 0, 'This booklet created by Peter Loveland was a gift to guests at Bill Forbes’ 90th Birthday Party held on 2 July 2011 at Carnation Hall jointly given by Maidenhead SCD Club & St John’s SCD Club. During the evening of dancing 7 dances on the programme were by Bill. Music was played appropriately by The Craigievar Band and the three dances in the booklet The Buckie Lad were demonstrated as a medley J/S/R to music specially composed by Alistair Forbes. The three pieces of music and therefore the recommended tunes for each dance were The 1921 Jig/ Bill Forbes’s Strathspey/ The Braes of Enzie.  

Bill wrote 5 books of Scottish dances and Sheena his daughter plans to publish a sixth of Bill’s completed but so far unpublished dances - watch this space.  

As a postscript Bill’s 100th Birthday was also celebrated, but posthumously at Hernes Farm Estate, Henley on 14 August 2021 where the Friday Nighters meet in The “Shooting Lodge” which not by coincidence is the name of one of Bill’s dances.', 0, '2011-00-00');
INSERT INTO 'publication' VALUES (1601, '2021-10-08 09:31:10.263792+00', '2021-10-09 13:19:49.330274+00', 'Down Under', '', 352, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 2008);
INSERT INTO 'publication' VALUES (1605, '2021-11-23 06:28:20.117975+00', '2021-11-24 15:04:34.724204+00', 'Paris Book of Scottish Country Dances, Companion Book of Tunes, volume 1, The', 'Paris Book Tunes 1', 11342, 0, 1, 1, 1, 12064, '2021-11-23 13:19:42+00', 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (1607, '2021-12-03 17:19:52.135888+00', '2021-12-04 11:23:20.780991+00', 'Sir Walter Scott, The Heart of Midlothian', '', 319, 1, 1, 1, 1, NULL, NULL, 0, 'A Celebration through Scottish Dance and Music.  To commemorate the 250th anniversary of Sir Walter Scott''s birth.', 1, 2021);
INSERT INTO 'publication' VALUES (1602, '2021-10-11 22:00:58.004656+00', '2021-10-12 17:17:48.375804+00', 'After the Rain', '', 569, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (612, '2002-12-31 23:00:00+00', '2021-10-15 08:50:35.601263+00', 'Australia-Caledonia Set', 'Australia-Caled.', 250, 1, 0, 0, 1, NULL, NULL, 0, 'According to <<https://my.strathspey.org/dd/issue/2634/|issue 2634>> the date of this publication is between 1954 and 1965.', 0, 1965);
INSERT INTO 'publication' VALUES (1603, '2021-10-21 18:35:33.568342+00', '2021-10-21 18:39:49.680991+00', 'Walnut Book Vol 2, The', '', 11677, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (194, '2002-12-31 23:00:00+00', '2021-10-31 15:34:35.660836+00', 'Ayr Country Town Book', 'Ayr Country Town', 16, 1, 0, 0, 1, NULL, NULL, 0, 'To commemorate the Golden Jubilee of the Ayr Branch of the Royal Scottish Country Dance Society 1933 - 1983.



According to <<https://my.strathspey.org/dd/issue/2642/|issue 2642>> this publication is hand written, cost 40p and the proceeds went to Ayr Branch RSCDS 1983 Jubilee fund. ', 0, '1983-00-00');
INSERT INTO 'publication' VALUES (1608, '2021-12-04 17:13:35.295986+00', '2021-12-04 17:22:53.449914+00', 'Fifty Scottish Dances', '50 SD', 12087, 1, 0, 0, 1, NULL, NULL, 0, 'Undated pamphlet published by "Lang Syne Publications" with an introduction by Duncan MacLeod, then chairman of the RSCDS.', 0, 0000);
INSERT INTO 'publication' VALUES (1451, '2018-05-21 09:31:47.326294+00', '2021-12-21 15:58:48.442941+00', 'Golden Bear Collection, The', '', 2682, 1, 0, 1, 0, NULL, NULL, 0, 'This publication was a work in progress for a while, but was declared final in December 2021.', 0, 2019);
INSERT INTO 'publication' VALUES (316, '2002-12-31 23:00:00+00', '2022-01-04 21:03:34.249176+00', 'Inverclyde Foursome', 'Inverclyde', 2020, 1, 1, 0, 1, 35907, '2022-01-03 05:14:24+00', 0, 'This was the West Renfrewshire Branch Diamond Jubilee book.', 0, 1985);
INSERT INTO 'publication' VALUES (1611, '2022-01-07 14:41:39.008348+00', '2022-01-07 18:28:02.135857+00', 'Great Dances for the Success', 'Success', 11514, 1, 0, 1, 1, NULL, NULL, 0, 'Let the dancers succeed: four couple dances in a 4 couple set.', 0, 0000);
INSERT INTO 'publication' VALUES (1610, '2022-01-05 17:45:14.776189+00', '2022-01-05 18:05:14.739448+00', 'Around the World in 13 Scottish Country Dances', 'Around the World', 12090, 1, 0, 0, 0, NULL, NULL, 0, 'A collection of Scottish Country Dances for Children. Stories, Crafts and Games.



It is divided into 13 chapters and a “Crafts and Games” Section. Each chapter begins with either a story or a fact file about an animal that is part of the country’s fauna or culture. These characters have their own dance and a “Find out” stepping stone that invites children to learn more about the fauna or culture of the country in question.



This publication aims at helping primary school dancers and their teachers to improve technique, learn new formations and above all enjoy dancing. The tunes chosen are traditional ones or tunes for kids of each country mentioned. ', 0, '2021-00-00');
INSERT INTO 'publication' VALUES (1147, '2013-07-20 12:41:43.305463+00', '2022-01-11 11:19:31.586931+00', '75 Years of Dancing in St Andrews', 'St Andrews 75th', 367, 1, 1, 0, 1, NULL, NULL, 0, '"In celebration of our 75th anniversary, which coincides with the University''s 600th, we have produced a book of 12 dances."', 0, 2013);
INSERT INTO 'publication' VALUES (664, '2002-12-31 23:00:00+00', '2022-01-14 10:42:06.993311+00', 'Tighes Hill Dances', 'Tighes Hill', 109, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1991);
INSERT INTO 'publication' VALUES (1613, '2022-01-10 17:07:39.907247+00', '2022-01-11 14:40:54.097381+00', 'Bovey Collection of SCD, The', '', 854, 1, 0, 0, 1, 202, '2022-01-10 17:18:50+00', 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (1612, '2022-01-09 19:00:51.300062+00', '2022-01-09 19:47:02.178418+00', 'West Wynd and other Dances, The', 'West Wynd', 1190, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (63, '2002-12-31 23:00:00+00', '2022-01-11 18:35:26.240981+00', 'Alexander Dances Book 1', 'Alexander 1', 13, 1, 0, 1, 1, NULL, NULL, 0, 'In the reprint of this book all the page numbers are reduced by 1 compared to the original.', 0, 0000);
INSERT INTO 'publication' VALUES (1616, '2022-01-11 11:39:11.514525+00', '2022-01-27 19:42:47.898339+00', 'To Dance To, Volume 3', 'To Dance To 3', 340, 0, 1, 0, 1, NULL, NULL, 0, 'The numbering might not be correct as it was take from the Scotscores webpage and not from the book itself.', 0, 0000);
INSERT INTO 'publication' VALUES (86, '2002-12-31 23:00:00+00', '2022-02-02 23:47:20.801662+00', 'Nottingham 10.30', 'Nottingham 10:30', 294, 1, 1, 0, 1, NULL, NULL, 0, '10 dances to celebrate 30 years 1959-1989', 0, 1989);
INSERT INTO 'publication' VALUES (422, '2002-12-31 23:00:00+00', '2022-01-27 19:39:19.505881+00', 'To Dance To, Volume 1', 'To Dance To 1', 340, 0, 1, 1, 1, NULL, NULL, 0, 'In the past this publication was also labelled "Wasatch Mountain" in SCDDB. However, we cannot verify this label, because it is not printed on the book itself.', 0, 0000);
INSERT INTO 'publication' VALUES (610, '2002-12-31 23:00:00+00', '2022-01-14 10:35:11.348713+00', 'Melbourne Dance Book', 'Melbourne 1', 262, 1, 1, 0, 1, NULL, NULL, 0, '', 0, 1985);
INSERT INTO 'publication' VALUES (262, '2002-12-31 23:00:00+00', '2022-01-14 10:37:04.883596+00', 'Muckle Book, The', 'Muckle Book', 212, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1979);
INSERT INTO 'publication' VALUES (1617, '2022-01-11 11:39:47.224405+00', '2022-01-27 19:41:46.01972+00', 'To Dance To, Volume 4', 'To Dance To 4', 340, 0, 1, 0, 1, NULL, NULL, 0, 'The numbering might not be correct as it was take from the Scotscores webpage and not from the book itself.', 0, 0000);
INSERT INTO 'publication' VALUES (137, '2002-12-31 23:00:00+00', '2022-01-14 10:40:02.237044+00', 'Oxford Book of Dances, Silver Jubilee', 'Oxford', 302, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 1993);
INSERT INTO 'publication' VALUES (239, '2002-12-31 23:00:00+00', '2022-01-14 10:46:04.632655+00', 'Whisky Collection, The', 'Whisky', 162, 1, 0, 0, 1, NULL, NULL, 0, 'This book was revised in March 1977 so presumably first published somewhat earlier.', 0, 1977);
INSERT INTO 'publication' VALUES (1596, '2021-07-13 14:36:47.992174+00', '2022-01-14 11:03:23.686101+00', '20 Scottish Country Dances', '20 SCD', 631, 1, 0, 0, 0, NULL, NULL, 0, 'Devised for The Scottish Bluebells', 0, 1988);
INSERT INTO 'publication' VALUES (690, '2002-12-31 23:00:00+00', '2022-01-14 11:09:47.362558+00', 'Rowan Tree Set, The', 'Rowan Tree', 422, 1, 1, 0, 1, 149, '2011-02-09 14:51:51+00', 0, 'Published in 1993 but copyright 1992 (New Haven Branch for Anne Wolf) - see <<https://my.strathspey.org/dd/issue/2689/|issue 2689>>.', 0, 1993);
INSERT INTO 'publication' VALUES (1614, '2022-01-11 09:38:26.185343+00', '2022-01-27 19:38:38.193532+00', 'To Dance To, Volume 5', 'To Dance To 5', 340, 0, 1, 0, 1, NULL, NULL, 0, 'The numbering might not be correct as it was taken from the Scotscores webpage and not from the book itself.', 0, 0000);
INSERT INTO 'publication' VALUES (1615, '2022-01-11 11:18:24.435577+00', '2022-01-27 19:39:40.807795+00', 'To Dance To, Volume 2', 'To Dance To 2', 340, 0, 1, 0, 1, NULL, NULL, 0, 'The numbering might not be correct as it was take from the Scotscores webpage and not from the book itself.', 0, 0000);
INSERT INTO 'publication' VALUES (1609, '2021-12-21 15:51:17.399556+00', '2022-06-23 19:09:19.252219+00', 'Piwakawaka Collection, The', 'Piwakawaka', 2682, 1, 1, 1, 0, NULL, NULL, 0, 'The publication is a work in progress. New dances are still being added, and new editions appear when needed. So the order and page numbers of the dances changes and online source URLs may therefore be out of date.', 0, 2021);
INSERT INTO 'publication' VALUES (522, '2002-12-31 23:00:00+00', '2022-01-15 09:38:15.728449+00', 'Bicentennial Book', 'Ways: Bicentennial', 406, 1, 0, 0, 1, NULL, NULL, 0, 'An <<https://my.strathspey.org/dd/publication/554/|augmented 2nd edition>> was published in 1993 and included extra dances (information from <<https://my.strathspey.org/dd/issue/2562/|issue 2562>>).



Original edition published in 1975 (according to <<https://my.strathspey.org/dd/issue/2696/|issue 2696>>).', 0, '1975-00-00');
INSERT INTO 'publication' VALUES (554, '2002-12-31 23:00:00+00', '2022-01-15 09:42:47.114238+00', 'Bicentennial Book plus Seven SCD', 'Ways: Bicentennial+7', 406, 1, 0, 0, 1, NULL, NULL, 0, 'This is an augmented edition of the original <<ddpub:#522>>.', 0, 1993);
INSERT INTO 'publication' VALUES (234, '2002-12-31 23:00:00+00', '2022-01-17 23:37:53.667789+00', 'Oaks of Sherwood Book', 'Oaks of Sherwood', 48, 1, 0, 0, 1, NULL, NULL, 0, 'A second book of Nottingham Dances devised by Jenny Bradley between 1980 / 1986', 0, 0000);
INSERT INTO 'publication' VALUES (1217, '2015-02-01 00:58:02.072507+00', '2022-02-14 16:32:59.620978+00', 'Six original Scottish country dances', '6 Original SCD', 10623, 1, 0, 0, 1, 106, '2015-02-01 22:20:49+00', 3, '', 0, 2015);
INSERT INTO 'publication' VALUES (1622, '2022-03-07 18:32:28.163551+00', '2022-05-03 23:02:05.635524+00', '4 Dances devised by Peter Marshall', 'Marshall4', 11464, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 2022);
INSERT INTO 'publication' VALUES (1057, '2011-08-22 22:00:00+00', '2022-01-20 22:26:22.831912+00', 'Book of Perth Dances, A', 'Perth Book', 306, 1, 1, 0, 1, 104, '2011-08-23 14:56:32+00', 0, '', 0, 2008);
INSERT INTO 'publication' VALUES (1492, '2019-03-08 20:47:42.090404+00', '2022-01-20 22:56:26.890682+00', 'Iberian Commemorative Book', '', 11797, 1, 1, 1, 0, NULL, NULL, 0, 'To celebrate the twentieth anniversary of the annual Iberian Peninsula Scottish Country Dance Weekends.  Dedicated to the memory of Betty MacKenzie and Jeronimo Maeso', 0, 2019);
INSERT INTO 'publication' VALUES (120, '2002-12-31 23:00:00+00', '2022-01-21 23:15:05.409456+00', 'Tower Collection', 'Tower', 159, 1, 1, 0, 1, NULL, NULL, 0, 'The Tower depicted in our emblem stands on the top of Darwen Moors of Lancashire.



Built to commemorate the Diamond Jubilee in 1897 of Queen Victoria, its correct title is "Victoria Tower", but it is locally known as "Darwen tower" or "The Tower", hence the name of the first dance in this book.', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (573, '2002-12-31 23:00:00+00', '2022-01-22 20:08:57.881752+00', 'Reeves Wedding Ball and Other Dances', 'Reeves', 322, 1, 0, 0, 1, NULL, NULL, 0, 'As reported in <<https://my.strathspey.org/dd/issue/2713/|issue 2713>> at least some copies of this publication just have three dances. The database also assigns <<ddd:Wee Hours, The#7000>> to this publication - possibly in a later edition or just by mistake?', 0, 0000);
INSERT INTO 'publication' VALUES (324, '2002-12-31 23:00:00+00', '2022-01-22 20:26:16.027493+00', 'San Diego Bicentennial', 'San Diego 200', 337, 1, 0, 0, 1, NULL, NULL, 0, 'First published in July 1976. Second edition October 1977.



The order of dances might have been changed between editions. A different order is given in <<https://my.strathspey.org/dd/issue/2714/|issue 2714>> which also corresponds to that in scans of dance pages available to the e-cribs team. Those have page numbers as follows:  

2: Oh My America!  

4: The Craigdarroch Jig  

6: Hands Across the Ocean  

8: McCormick''s Reaper  

10: The Prairie Schooner  

12: The Ballachulish Ferry  

14: John Paul Jones'' Apologies to Lady Selkirk  

17: No The Noo, Johnny  

18: The High Road  

22: Battle Road  

24: My Piper''s Dream  

28: Washington Crossing  

31: The Covered Wagon  

', 0, '1976-00-00');
INSERT INTO 'publication' VALUES (317, '2002-12-31 23:00:00+00', '2022-01-22 21:31:09.212922+00', 'Hamish Dances', 'Hamish', 9998, 1, 0, 0, 1, NULL, NULL, 0, 'The cover shows:



Hamish Dances 1964-1989 Hamish Iain McMouse Pinewoods



The inside cover says:



HAMISH IAIN McMOUSE: An unpretentious mouse of humble origin, who lived his whole life at Pinewoods, where he died in 1964. Following his death he was given, under peculiar circumstances, to Maurice Whitby, who not only kept him, but was responsible for his peripatetic wanderings. These have taken him overseas in addition to extensive travel in the U.S.A. and Canada. Hamish''s travels, when not directly instigated by Maurice, have generally returned him "home" by willing cohorts. Now, 25 years later, Hamish returns to Pinewoods, the scene of his life.



This small book of dances is lovingly dedicated to our small friend upon his retirement in thanksgiving for the fun and friendship he has engendered over the years.



The profits from the sale of this book will go to Pinewoods.



*Information from <<https://my.strathspey.org/dd/issue/2710/|issue 2710>>.*', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (1618, '2022-01-23 19:38:10.549111+00', '2022-01-23 19:38:10.549111+00', 'Roses and Heather and The Bonnie Broom', '', 289, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1107, '2012-06-12 13:25:19.86132+00', '2022-02-14 16:35:32.205315+00', 'Berkhamsted Diamond Collection, The', 'Berkhamsted Diamond', 3331, 1, 1, 1, 1, 104, '2012-06-12 22:01:30+00', 0, '', 0, 2011);
INSERT INTO 'publication' VALUES (155, '2002-12-31 23:00:00+00', '2022-02-18 20:42:23.010831+00', 'Glendarroch Scottish Dance Sheets', 'Glendarroch', 129, 1, 1, 0, 1, NULL, NULL, 0, 'The Glendarroch Sheets have been published in the period 1966 - 1976.



The Glendarroch Sheets (and other dances) are available online via the London Branch copy of the former <<ddpub:Scottish Dance Archives>> website. This is available at <<https://www.rscdslondon.org.uk/sda-dance-instructions/>> and the direct URLs are linked as the Online Source on the page for for each dance.', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (1619, '2022-01-27 18:55:54.266918+00', '2022-01-27 20:42:47.086241+00', 'Perth & Perthshire Branch 95th Anniversary Dances', 'Perth 95th', 306, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (1337, '2016-10-16 16:51:04.7089+00', '2022-01-30 21:19:59.037012+00', 'Leeds Scottish Country Dance Club 65th Anniversary', 'Leeds SCDC 65th', 12109, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2016);
INSERT INTO 'publication' VALUES (1621, '2022-03-03 17:46:14.516777+00', '2022-08-31 08:35:03.88267+00', 'Twin Peaks', '', 11526, 1, 0, 0, 0, NULL, NULL, 0, 'This publication is really two books. The Red book includes the first 18 dances from The Queensland Breeze to The Final Fling. These require more advanced skills. Whereas those in the Blue book, from Queens Prefer Violet to Russian Mushrooms, are more calm and familiar.', 0, 2022);
INSERT INTO 'publication' VALUES (1440, '2018-04-03 10:34:01.993515+00', '2022-09-03 21:55:15.638799+00', 'Companion to the Ballroom, A', 'Ballroom Companion 1816', 432, 1, 1, 0, 0, NULL, NULL, 0, 'The RSCDS publication "Scottish Country Dances Books 13-18" states *Thomas Wilson: A Companion to the Ballroom, London, 1816* as the source of dances.', 0, 1816);
INSERT INTO 'publication' VALUES (1623, '2022-03-07 18:34:52.489527+00', '2022-03-07 19:03:30.231153+00', 'Alderley & District Caledonian Society 50th Anniversary', 'Alderley 50th', 11464, 1, 0, 1, 0, NULL, NULL, 0, '', 0, 2022);
INSERT INTO 'publication' VALUES (1624, '2022-03-09 09:37:55.928632+00', '2022-03-09 09:52:44.953037+00', 'Own Dances', '', 11162, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (1625, '2022-03-26 19:55:58.579412+00', '2022-03-27 10:23:49.347797+00', 'Wellington 60th Anniversary Collection, The', 'Wellington 60th Anniversary', 407, 1, 1, 1, 1, NULL, NULL, 0, 'Published September 2021', 0, 2021);
INSERT INTO 'publication' VALUES (1626, '2022-04-02 19:23:22.967954+00', '2022-04-02 19:30:24.561615+00', 'Floating Song, The', '', 3683, 1, 1, 0, 1, NULL, NULL, 0, 'Six Scottish Country Dances and Tunes Inspired by the Poetry of Edwin Morgan', 0, 2021);
INSERT INTO 'publication' VALUES (1620, '2022-02-24 19:01:57.684041+00', '2022-04-07 04:43:24.704212+00', 'Remission Book, The', '', 11509, 1, 0, 0, 0, 202, '2022-04-07 04:43:24.700422+00', 0, '', 0, 2022);
INSERT INTO 'publication' VALUES (867, '2002-12-31 23:00:00+00', '2022-04-07 21:57:12.901705+00', 'Skye Collection', 'Skye', 1662, 0, 1, 1, 0, NULL, NULL, 0, 'Modern editions are available.', 0, 1887);
INSERT INTO 'publication' VALUES (1089, '2011-10-15 22:00:00+00', '2022-04-10 10:11:50.327529+00', 'Dances for Friends Six', 'Friends 6', 1445, 1, 1, 0, 1, 106, '2011-10-16 22:09:03+00', 0, 'Aalst, August 2011', 0, 2011);
INSERT INTO 'publication' VALUES (515, '2002-12-31 23:00:00+00', '2023-01-09 22:57:33.291763+00', 'Pinewoods Collection Vol 3', 'Pinewoods 3', 148, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1630, '2022-04-22 20:16:22.628515+00', '2022-04-22 20:21:35.429941+00', 'Creative in Lockdown', '', 11035, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2022);
INSERT INTO 'publication' VALUES (33, '2002-12-31 23:00:00+00', '2022-05-03 18:31:22.34545+00', 'Book 33 Eight Modern Scottish Country Dances', 'RSCDS XXXIII', 319, 1, 1, 0, 1, NULL, '2022-05-03 18:31:22.340094+00', 0, '', 1, 1985);
INSERT INTO 'publication' VALUES (1551, '2020-06-16 18:35:38.817068+00', '2022-07-10 08:33:26.6971+00', 'Class of ''13', 'Class 13', 11415, 1, 0, 0, 0, 202, '2022-07-10 08:33:26.69037+00', 0, 'A collection of dances devised for the Unit 5 Class at Summer School, July 2013.

', 0, '2014-07-01');
INSERT INTO 'publication' VALUES (1632, '2022-05-03 20:00:16.236812+00', '2022-05-03 22:19:56.379134+00', 'Ship Ahoy! - A Booklet of 5 Seafaring Country Dances', 'Ship Ahoy!', 11858, 1, 1, 0, 1, NULL, NULL, 0, 'Produced by Ewan Galloway to raise funds for the Edinburgh Trinity Sea Cadets.', 0, 2020);
INSERT INTO 'publication' VALUES (1655, '2022-07-30 12:40:33.383767+00', '2022-07-30 12:40:33.383767+00', 'Cat Collection', '', 1349, 1, 0, 0, 0, NULL, NULL, 0, 'This is a stub entry for the dance found on <<https://my.strathspey.org/dd/list/34989/>> which is attributed to the "Cat Collection".', 0, 0000);
INSERT INTO 'publication' VALUES (91, '2002-12-31 23:00:00+00', '2022-07-15 14:02:37.440967+00', 'Tam O'' Shanter Book of Scottish Country Dances, The', 'Tam O'' Shanter', 313, 1, 0, 1, 1, 160, '2013-09-29 00:50:16+00', 0, 'This book was reprinted in A4 format in 2019. The page numbers in the list of dances refer to the original publication.', 0, 0000);
INSERT INTO 'publication' VALUES (1642, '2022-07-15 14:37:15.416811+00', '2022-07-15 14:37:15.416811+00', 'Sampler of New Country Dances, A', 'Sampler', 17, 1, 0, 0, 0, NULL, NULL, 0, 'This booklet includes a selection of dances from other publications by <<ddp:Sheffield, Martin>>.', 0, 1998);
INSERT INTO 'publication' VALUES (1530, '2020-02-28 10:27:35.60285+00', '2022-07-15 14:47:58.814645+00', 'Celebrating 90 Years of the Banffshire Branch', 'Banffshire 90th', 3648, 1, 0, 0, 1, 202, '2021-08-21 00:00:01+00', 0, 'Locally inspired dances to celebrate 90 years of the Banffshire Branch. All devised by members of the Branch.', 0, 2019);
INSERT INTO 'publication' VALUES (991, '2005-12-21 23:00:00+00', '2022-07-15 14:49:59.135113+00', 'Pam''s Dance Book', 'Pam''s Dances', 3412, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2003);
INSERT INTO 'publication' VALUES (1638, '2022-06-07 20:31:38.629498+00', '2022-06-08 10:16:57.310659+00', 'Clara 20th & Saltire 10th Anniversary', 'Clara 20th & Saltire 10th', 12140, 1, 0, 0, 1, 645, '2022-06-08 10:16:57.302164+00', 0, '', 0, 2021);
INSERT INTO 'publication' VALUES (1639, '2022-06-07 20:35:09.403094+00', '2022-06-08 11:11:12.6518+00', 'RSCDS Tokai 25th Anniversary Book', 'Tokai 25th Anniversary', 12142, 1, 1, 1, 0, 645, '2022-06-08 10:16:39+00', 0, 'The RSCDS Tokai Branch was established in 1997 as the second branch in Japan. This book celebrates its 25th anniversary.', 0, 2022);
INSERT INTO 'publication' VALUES (1640, '2022-06-25 16:59:25.731177+00', '2022-06-26 21:54:08.669275+00', 'Newcastle 70th Anniversary', '', 289, 1, 1, 0, 1, NULL, NULL, 0, 'Newcastle Upon Tyne & District RSCDS 70th Anniversary (1950-2020)', 0, 2022);
INSERT INTO 'publication' VALUES (1644, '2022-07-15 17:02:17.2081+00', '2022-07-15 17:02:17.2081+00', 'Cubbie Roo and Three More Scottish Country Dances', 'Cubbie Roo', 13, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1643, '2022-07-15 17:00:20.071048+00', '2022-07-15 17:03:19.322134+00', 'Braes o'' Lochaber and Three More Scottish Country Dances', 'Braes o'' Lochaber', 13, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1645, '2022-07-15 17:05:04.099608+00', '2022-07-15 17:05:12.933143+00', 'Inveran Bridge and Three More Scottish Country Dances', 'Inveran Bridge', 13, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1646, '2022-07-15 17:06:43.804545+00', '2022-07-15 17:06:43.804545+00', 'Reekie Linn and Three More Scottish Country Dances', 'Reekie Linn', 13, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (788, '2002-12-31 23:00:00+00', '2022-07-15 18:27:51.283441+00', 'Cameo Collection Book 18', 'Cameo 18', 35, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1647, '2022-07-15 18:51:38.637073+00', '2022-07-15 18:51:38.637073+00', 'Hogmanay Jig and Drumelzier', 'Hogmanay/Drumelzier', 289, 1, 1, 0, 0, NULL, NULL, 0, '', 0, 1967);
INSERT INTO 'publication' VALUES (1290, '2016-01-14 17:58:07.772532+00', '2023-01-17 12:27:55.995406+00', 'Set and Link', '', 10835, 1, 0, 0, 1, NULL, NULL, 0, '"Set and Link" is the Toronto Branch Newsletter, started in 2005, and still being published in 2020.  The Dances were published singly in different issues, from 2011 to 2020, and never together in a single volume.



The web page <<https://www.dancescottish.ca/leaflets.html>> contains a list of all dances published in Set and Link with URLs for dances and videos where available.

', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (1634, '2022-05-14 16:56:31.981574+00', '2022-05-17 18:43:12.071088+00', 'McGhie SCD Sheets Collection #1', 'McGhie Sheets 1', 99, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (1633, '2022-05-09 11:50:48.579229+00', '2022-05-17 18:43:38.817196+00', 'McGhie SCD Sheets Collection #5', 'McGhie Sheets 5', 99, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2022);
INSERT INTO 'publication' VALUES (1635, '2022-05-14 16:56:58.985956+00', '2022-05-17 18:43:57.252027+00', 'McGhie SCD Sheets Collection #2', 'McGhie Sheets 2', 99, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (1636, '2022-05-14 16:57:29.171291+00', '2022-05-17 18:44:17.948671+00', 'McGhie SCD Sheets Collection #3', 'McGhie Sheets 3', 99, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (1637, '2022-05-14 16:57:53.094642+00', '2022-05-17 18:44:40.325231+00', 'McGhie SCD Sheets Collection #4', 'McGhie Sheets 4', 99, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2020);
INSERT INTO 'publication' VALUES (547, '2002-12-31 23:00:00+00', '2022-06-05 12:27:46.989066+00', 'San Francisco Collection 1', 'San Francisco 1', 338, 1, 0, 1, 1, NULL, NULL, 0, 'Fourteen Scottish Country Dances Devised by Members of the San Francisco Branch

Now Available to All as a Free Download!', 0, '1979-00-00');
INSERT INTO 'publication' VALUES (1657, '2022-08-07 19:36:29.80653+00', '2022-08-10 13:05:44.192788+00', 'Dances in Kintail', '', 11449, 1, 0, 0, 0, NULL, '2022-08-10 13:05:44.18664+00', 0, '', 0, 2022);
INSERT INTO 'publication' VALUES (1579, '2021-03-14 19:35:22.739007+00', '2022-09-03 21:57:07.381958+00', 'Three Traditional Scottish Dances - 3rd Set', 'MacNab 3rd Set', 319, 1, 1, 0, 1, NULL, NULL, 0, 'This is the 3rd set of dances collected by <<ddp:MacNab#242>>. They were taught at the 1954 summer school and published around that time as a <<https://archive.rscds.org/index.php/three-traditional-scottish-dances-3rd-set|leaflet>> by the RSCDS prior to the subsequent combined editions.

', 1, '1954-00-00');
INSERT INTO 'publication' VALUES (643, '2002-12-31 23:00:00+00', '2022-08-30 19:26:20.533086+00', 'Island Bay Collection', 'Island Bay 1', 194, 1, 0, 1, 1, NULL, NULL, 0, 'An expanded edition including more dances was published in 1996. See <<ddpub:Island Bay Collection (2nd edition)#344>>.', 0, 1984);
INSERT INTO 'publication' VALUES (1656, '2022-08-07 19:35:12.857405+00', '2022-08-12 15:54:48.196897+00', 'Dedicated Dancing', '', 11449, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2022);
INSERT INTO 'publication' VALUES (1648, '2022-07-15 22:00:13.263805+00', '2022-07-16 01:34:12.357823+00', 'Ça Va Bien Aller', '', 10568, 1, 1, 0, 1, 202, '2022-07-16 01:34:12.349985+00', 0, '', 0, 2022);
INSERT INTO 'publication' VALUES (1265, '2015-07-20 13:24:02.634619+00', '2022-07-17 13:03:38.421975+00', 'Bruce Fordyce Memorial Collection, The', 'Bruce Fordyce Mem. Coll.', 725, 1, 1, 1, 1, NULL, NULL, 0, 'Compiled by Ruary Laidlaw', 0, 2012);
INSERT INTO 'publication' VALUES (1649, '2022-07-17 22:12:31.728498+00', '2022-07-17 22:12:31.728498+00', 'Drumlins of Down / Glens of Antrim', '', 569, 1, 0, 0, 0, NULL, NULL, 0, 'Two dances from the <<ddpub:Belfast Branch 40th Anniversary>> book.', 0, 0000);
INSERT INTO 'publication' VALUES (1650, '2022-07-22 23:03:24.553003+00', '2022-07-22 23:03:24.553003+00', 'Old Wick Castle and Three More SCD', 'Old Wick Castle', 13, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1651, '2022-07-22 23:05:32.578729+00', '2022-07-22 23:05:32.578729+00', 'Braid Bonnet and Three More SCD, The', 'Braid Bonnet', 13, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1652, '2022-07-22 23:07:29.143357+00', '2022-07-22 23:07:29.143357+00', 'Caithness Heart and Three More SCD, The', 'Caithness Heart', 13, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1653, '2022-07-22 23:09:13.607943+00', '2022-07-22 23:09:13.607943+00', 'Gold of Fairnilee and Three More SCD, The', 'Gold of Fairnilee', 13, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1654, '2022-07-22 23:11:10.248588+00', '2022-07-22 23:11:10.248588+00', 'Rossie Moor Reel and Three More SCD, The', 'Rossie Moor Reel', 13, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 0000);
INSERT INTO 'publication' VALUES (1658, '2022-09-13 10:15:14.852557+00', '2022-09-13 10:15:14.852557+00', 'Her Majesty Queen Elizabeth II - A Celebration through Scottish Music and Dance - The Platinum Jubilee', 'Platinum Jubilee', 319, 1, 1, 1, 1, NULL, NULL, 0, '', 1, 2022);
INSERT INTO 'publication' VALUES (1641, '2022-07-05 22:36:11.372418+00', '2022-12-01 15:44:43.474727+00', 'Couple One Ready', 'Couple1 Ready', 12161, 1, 0, 1, 0, 35737, '2022-12-01 15:44:43.466057+00', 0, 'This is a stub entry: dances are still being added.', 0, 2022);
INSERT INTO 'publication' VALUES (460, '2002-12-31 23:00:00+00', '2023-01-26 18:58:06.260868+00', 'Whetherly Book 10', 'Whetherly 10', 270, 1, 0, 0, 1, NULL, NULL, 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages.  In this SCDDB record, the dances are numbered in succession, and not by page number. In the re-published version (2019 and later), each dance starts on a new page.', 0, 1981);
INSERT INTO 'publication' VALUES (1518, '2019-09-24 11:25:58.459875+00', '2022-09-16 10:17:17.237395+00', 'Scottish Country Dance Book of Four Set Dances', 'Four Set Dances', 319, 1, 1, 0, 1, NULL, NULL, 0, 'As collected by <<ddp:Mrs Mary Isdale MacNab#242>> of Vancouver and given to the Society at their 17th Summer School at St. Andrews.



This is the 1st set of nine such sets of dances which she taught every two years at successive Summer Schools.  First published in 1948, the sets were later republished in combined editions.', 1, '1948-00-00');
INSERT INTO 'publication' VALUES (1062, '2011-08-25 22:00:00+00', '2022-09-17 19:13:38.744964+00', 'San Andreas Collection, The', 'San Andreas', 390, 1, 1, 1, 1, 111, '2022-09-17 19:13:38.735899+00', 0, 'Reprinted: 2009

Available as a printed book and as a PDF. ', 0, '2008-00-00');
INSERT INTO 'publication' VALUES (339, '2002-12-31 23:00:00+00', '2022-12-16 14:37:27.206971+00', 'Kerr''s Collection', 'Kerr', 1916, 1, 1, 0, 1, NULL, NULL, 0, 'This is a stub entry linkng only tunes used in dances and where Kerr''s collection is given as the source.', 0, 0000);
INSERT INTO 'publication' VALUES (810, '2002-12-31 23:00:00+00', '2022-12-18 11:01:07.338649+00', 'Pocket: Books 22, Graded', '22, Graded', 319, 1, 0, 0, 1, NULL, NULL, 0, 'The dances in Book 22 are numbered 1 to 12.

The dances in the Graded Book are numbered 1 to 24.  

That mixes up the dance listing.  

As the numbering system of this database does not allow adding a code prefix like "G", all numbers in the "Graded Book" have been increased by 100.

', 1, '1966-00-00');
INSERT INTO 'publication' VALUES (1665, '2022-12-17 23:23:03.05316+00', '2022-12-18 11:19:10.498848+00', '"Stuart''s Fancy" Set of Three 4-couple Dances by Martin Sprague, The', '"Stuart''s Fancy" Set', 333, 1, 1, 1, 1, NULL, NULL, 0, '8 page leaflet, the cover states: "Music arranged by Elizabeth Higgins. (..) All profits will be given to the Cheshire Home for Mentally Handicapped Children, Hawthorn Lodge, Dorchester."', 0, 1968);
INSERT INTO 'publication' VALUES (1660, '2022-09-19 07:51:35.820845+00', '2022-09-19 21:17:01.251519+00', 'Doonhamers'' Book, The', '', 12206, 1, 0, 0, 0, 12064, '2022-09-19 15:49:06+00', 0, '', 0, 2022);
INSERT INTO 'publication' VALUES (1427, '2018-03-11 09:14:08.553338+00', '2022-09-27 23:07:45.612524+00', 'High Time', '', 11602, 1, 1, 0, 1, 202, '2018-03-17 19:24:14+00', 0, 'Dances devised for the wedding of Ramona Zohm and Matthias Rank.', 0, 2018);
INSERT INTO 'publication' VALUES (1666, '2022-12-18 21:24:06.714607+00', '2022-12-19 14:10:50.103122+00', 'Dances Devised by Members and Friends', 'MSCD Dances', 12225, 1, 0, 1, 0, NULL, NULL, 0, 'This publication might rather be a list than a real publication. ', 0, 2002);
INSERT INTO 'publication' VALUES (1226, '2015-02-09 13:42:53.454802+00', '2022-12-19 23:15:09.192416+00', 'Mohonk Dances, The', '', 12228, 1, 0, 1, 1, 1558, '2017-09-24 00:33:26+00', 0, 'This book of dances is dedicated to the many enthusiastic participants at the Mohonk Mountain House Scottish Weekend, many of whom were first time dancers, and to the Loch Leven dancers, who, with a generous spirit, share their love of Scottish dancing with all beginners.

', 0, '2001-01-01');
INSERT INTO 'publication' VALUES (1352, '2017-02-22 17:06:31.253104+00', '2022-12-21 21:12:13.623849+00', 'MacNab Dances in diagrams, The', 'MacNab diagrams', 2865, 1, 0, 0, 1, NULL, NULL, 0, 'Detailed diagramatic representations of the 27 dances collected by Mary Isdale MacNab and published by the RSCDS in "Scottish Dances" volumes I and II, plus two other dances published earlier in the RSCDS leaflet sets "Traditional Scottish Dances".  ', 0, 2006);
INSERT INTO 'publication' VALUES (707, '2002-12-31 23:00:00+00', '2022-12-21 21:22:10.513307+00', 'Ladies of Dunse, The', 'Ladies of Dunse', 115, 1, 1, 1, 1, NULL, NULL, 0, 'The Ladies of Dunse would be Miss Margaret Rae, founder of the Branch, and her protege Wilma Miller who retired from teaching as the book was published.', 0, 1995);
INSERT INTO 'publication' VALUES (261, '2002-12-31 23:00:00+00', '2022-12-24 11:24:30.297294+00', 'Anniversary Book (Killeen), The', 'Killeen: Anniv.', 12244, 1, 1, 0, 1, NULL, NULL, 0, 'From the "Strathspey Mailing List" on Tue, 3 Jan 2012 (message 62176):



I have "The Anniversary Book" in front of me and, sadly, can

find no clue to the nature of the anniversary.  Not even a

date!



As you know the dances are by Joseph Killeen, who I know was

active in Carlisle in the early 70s.  Music is by Nancy

Dickson and Donald C Ridley and the publisher was Carlisle

RSCDS whose secretary was Mrs C Ridley.

', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (1661, '2022-10-01 07:41:07.364893+00', '2023-02-03 20:20:16.880225+00', 'Fields of Gold 2022', '', 3208, 1, 1, 1, 1, 202, '2022-10-01 09:09:30+00', 0, 'RSCDS Pretoria 50th Anniversary.



Erratum: In the printed version of the book the diagram for <<ddd:5000#21115>> has the wrong progression (54123). It should be 45123 as shown in the updated version in the database. The printed text for the dance is correct.', 0, '2022-10-01');
INSERT INTO 'publication' VALUES (999, '2006-10-25 22:00:00+00', '2022-10-22 16:34:13.363693+00', 'Vallin Collection 3', 'Vallin 3', 3718, 1, 0, 0, 1, NULL, NULL, 0, 'A second edition was published in 2008.', 0, 2006);
INSERT INTO 'publication' VALUES (279, '2002-12-31 23:00:00+00', '2022-11-04 21:09:29.385952+00', 'Silver Rose Book of Scottish Country Dances, The', 'Silver Rose', 313, 1, 0, 0, 1, 160, '2013-09-29 00:45:35+00', 0, 'Published by the Sutton Coldfield Branch of the Royal Scottish Country Dance Society to mark the twenty-fifth anniversary of organized Scottish Country Dancing in Sutton Coldfield.', 0, 1984);
INSERT INTO 'publication' VALUES (1014, '2006-12-06 23:00:00+00', '2022-11-13 17:09:05.711203+00', 'Saskatchewan''s Centennial Collection 2005', 'Saskatchewan Cent. 2005', 2930, 1, 0, 1, 1, 538, '2016-06-27 18:37:52+00', 0, 'The book is out of print but the dances are posted on the "Publications" page of the Branch web site [rscdssask.org]. Permission has been obtained from all the devisers to publish their dances on line.', 0, 2005);
INSERT INTO 'publication' VALUES (1663, '2022-11-27 11:24:43.969346+00', '2022-11-27 11:56:08.369187+00', 'Dunfermline Collection, A', 'Dunfermline Collection', 11753, 1, 0, 0, 1, NULL, NULL, 0, '', 0, 2022);
INSERT INTO 'publication' VALUES (1662, '2022-11-18 12:05:45.310352+00', '2022-12-04 10:38:59.316026+00', '60th Anniversary of Atholl SCD Club', 'Atholl 60th', 12209, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2022);
INSERT INTO 'publication' VALUES (1325, '2016-07-10 06:56:59.33102+00', '2022-12-08 18:09:02.378943+00', 'Book 50', 'RSCDS L', 319, 1, 1, 0, 1, NULL, NULL, 0, 'Available on paper and as e-book', 1, 2016);
INSERT INTO 'publication' VALUES (1384, '2017-09-15 16:25:04.189047+00', '2022-12-08 22:30:44.796024+00', 'Modern Country Dances in the Scottish Tradition, devised since 1970 by Martin Sheffield', 'Modern SCDs by M Sheffield', 17, 1, 0, 0, 0, NULL, NULL, 0, 'THIS BOOK IS CURRENTLY ADDED - THUS, STILL INCOMPLETE.

2022-12-08: the previous online source is not available anymore. ', 0, '2017-01-01');
INSERT INTO 'publication' VALUES (1664, '2022-12-09 21:37:01.250414+00', '2022-12-09 21:38:01.590802+00', 'Angus MacLeod', 'Angus MacLeod', 129, 1, 1, 0, 1, NULL, NULL, 0, 'Original publication. The Scottish National Dance Company publication followed later.', 0, 1969);
INSERT INTO 'publication' VALUES (421, '2002-12-31 23:00:00+00', '2022-12-10 20:05:46.225835+00', 'Athole Collection, The', 'Athole', 10707, 0, 1, 1, 1, NULL, NULL, 0, 'This a collection of dance music comprising 870 tunes collected by James Stewart Robertson. Originally published in 1884. Reissued by Highland Music Trust.



This partial entry contains only a subset of the collection, probably just those tunes referenced by dances in the database.', 0, '1884-00-00');
INSERT INTO 'publication' VALUES (574, '2002-12-31 23:00:00+00', '2022-12-25 19:14:52.908009+00', 'Thistle Club Jubilee Book 1977-2002', 'ThistleJubilee2002', 3198, 1, 1, 0, 1, 106, '2011-07-16 21:19:27+00', 3, 'Correction note  

The tune "The White Bridge" is incorrectly assigned to be "traditional" (handwritten content by Ian Slater). It is Nancy Dickson''s tune.



25 years Thistle Club   12-10-2002  

In 25 years of dancing, the Thistle Club was shaped by its members, teachers and dancers like as well as by many that attended dayschools and the sometimes spectacular balls that were held in Eindhoven.  The musicians that played for us also took their part, be it as members of a band or as individual musicians to play for a dayschool.  

To all of those this Jubilee Book is dedicated, and therefore it contains not only dances and music from Thistle Club members, but also from "outsiders", so that it reflects in a way the multicoloured pattern of the Thistle Club over the past quarter century.  

We do hope that you will enjoy the book, and our special thanks go to the dance makers and composers who all contributed enthusiastically to this book.  

  

Bas Broekhuizen  

Lily Bruns  

Monica Ferguson  

Bernie Hewitt  

Alistar Hunter  

Anselm Lingnau  

George McLennan  

Marjolij Rijnenberg-Nabbe  

Ian Slater  

Sheena Sturrock  

Marijcke Visscher  ', 0, '2002-10-00');
INSERT INTO 'publication' VALUES (60, '2002-12-31 23:00:00+00', '2022-12-26 12:35:32.127054+00', 'MacNab Dances Vol 1', 'MacNab 1', 319, 1, 1, 0, 1, 117, '2010-02-04 19:32:20+00', 0, 'The tune to "Ms Nichol..." in one of the MacNab publications is headed with the dance name. The tune given yet is "Mrs Compton of Carham-Hall", as used by Muriel Johnstone on her recordings for that dance.', 1, 1987);
INSERT INTO 'publication' VALUES (1584, '2021-03-15 21:13:00.889943+00', '2022-12-26 12:36:57.725606+00', 'Two Traditional Scottish Dances - 8th Set', 'MacNab 8th Set', 319, 1, 1, 0, 1, NULL, NULL, 0, 'This is the 8th set of dances collected by <<ddp:MacNab#242>>. They were taught at the 1964 summer school and published around that time as a <<https://archive.rscds.org/index.php/two-traditional-scottish-dances-8th-set|leaflet>> by the RSCDS prior to the subsequent combined editions.



The first two dances were the ones actually taught by Mary MacNab (hence the title). The last two dances were apparently just added to this as a convenient publication.



The tune to "Ms Nichol..." in this publication is headed with the dance name. The tune (unnamed) shown yet is "Mrs Compton of Carham-Hall", as used by Muriel Johnstone on her recordings for that dance.', 1, '1964-00-00');
INSERT INTO 'publication' VALUES (1667, '2023-01-04 11:57:24.416624+00', '2023-01-04 11:59:25.366072+00', 'Mr. John Rice''s Gift', 'RiceGift', 12249, 1, 1, 0, 1, NULL, NULL, 0, 'The "publication date" entry is an estimation. The deviser notes she could dance again from January 2015 on after her surgery, and the tune to the dance was composed in early 2016.

Mr. Rice, a consultant orthopaedic surgeon, restored the deviser''s left knee.', 0, '2015-01-01');
INSERT INTO 'publication' VALUES (1668, '2023-01-04 15:23:33.385596+00', '2023-01-06 15:57:20.249124+00', 'Scottish Dance Archives - The Donald Collection (Online List)', 'SDA/DC', 12251, 1, 1, 0, 0, NULL, NULL, 0, 'This is not a real publication, but an online list, one of two (of almost the same name) with which Bob Donald was heavily involved.  

Out of the total of 1800 dances, 250 have online instructions available through the <<https://www.rscdslondon.org.uk/sda-dance-instructions/|RSCDS London Branch website>>. This is the list duplicated here.

A few of the dances include tunes. In this list they are numbered as their corresponding dances.

Read more about the complete set of SDA dances here: <<https://my.strathspey.org/dd/publication/436/>>  ', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (1669, '2023-01-04 22:26:43.209834+00', '2023-01-05 12:45:58.952934+00', 'Delightful Diversion, A', 'Delightful Diversion', 11981, 1, 0, 0, 0, NULL, NULL, 0, '', 0, 2023);
INSERT INTO 'publication' VALUES (59, '2002-12-31 23:00:00+00', '2023-01-12 17:27:06.208709+00', 'Dance(s) Collected by Mary Isdale MacNab', 'Mary Isdale MacNab', 242, 1, 0, 0, 1, 35811, '2021-02-27 19:07:17+00', 0, 'This "publication" is a virtual entry to link in one place all the dances known or thought to have been collected (or just taught) by <<ddp:MacNab, Mary Isdale>> and which have been catalogued on the London Branch archives at <<https://www.rscdslondon.org.uk/mary-isdale-macnab-dances/>>.



The London Branch list assigns a catalogue number to each dance in a few groups according to where they were published (or not) and the state of information about them.  

_S01-S29_: The nine sets of dances published by the RSCDS. Here numbered 1-29  

_L01-L11_: Eleven other dances published privately or by the RSCDS (here 31-41)  

_F01-F12_: Taught by Mrs MacNab at festivals but not collected by her (51-62)  

_T01-T16_: Typed descriptions from Hugh Thurston/Tom Flett/Elizabeth Sutorius and others (71-86)



Note that not all the dances in the F series yet have entries in the database. The London Branch catalogue continues with other progressively more speculative sets with even fewer database entries.', 0, '0000-00-00');
INSERT INTO 'publication' VALUES (564, '2002-12-31 23:00:00+00', '2023-01-19 21:07:12.838406+00', 'Dances listed in TAC', 'in TAC', 380, 1, 0, 0, 1, NULL, NULL, 0, 'This collection of dance names is NOT a real publication. It is a list of dances that Keith Napier indexed as associated with TAC dances (number 799 in his index). It is unknown as to what this "association" is - a first presumption that these dances appeared in *TACTalk* over the years is rather wrong, as *TACtalk* at some point specifically stated that it didn''t want to publish dances and only made the odd exception, as far as the editors know.', 0, 0000);
INSERT INTO 'publication' VALUES (1670, '2023-01-25 12:20:18.408204+00', '2023-01-25 15:22:32.092651+00', 'Glasgow Branch 100th Anniversary Dances', 'Glasgow 100', 144, 1, 1, 1, 1, NULL, NULL, 0, '', 0, 2023);
INSERT INTO 'publication' VALUES (462, '2002-12-31 23:00:00+00', '2023-01-26 18:56:58.67625+00', 'Whetherly Book 12', 'Whetherly 12', 270, 1, 0, 0, 1, NULL, NULL, 0, 'In the original book the dances are printed in close spacing; more than one dance can start on a page, and dances can be broken across pages.  In this SCDDB record, the dances are numbered in succession, and not by page number. In the re-published version (2019 and later), each dance starts on a new page.', 0, 1983);
INSERT INTO 'publication' VALUES (1671, '2023-02-17 11:06:25.818861+00', '2023-02-17 11:06:25.818861+00', 'Dance Through The Decades', 'Decades', 319, 1, 0, 0, 1, NULL, NULL, 0, 'CD booklet included with Dance Through The Decades CD published for the RSCDS Centenary in 2023.', 1, 2023);


--
INSERT INTO 'publicationurl' VALUES (119, 'http://www.strathspey.org/libDances/sspbook.pdf', 10, 1112);
INSERT INTO 'publicationurl' VALUES (120, 'http://danciemaetion.imaginationprocessing.com/MIHTD.htm', 10, 1115);
INSERT INTO 'publicationurl' VALUES (118, 'http://www.bstk.hu/book/', 10, 1109);
INSERT INTO 'publicationurl' VALUES (106, 'http://www.music.davidknight.us/catalog-fleeting.htm', 10, 918);
INSERT INTO 'publicationurl' VALUES (241, 'http://rscdsleeds.uk/index.php?id_product=1034&controller=product', 100, 1447);
INSERT INTO 'publicationurl' VALUES (102, 'http://www.scottishdance.net/dances/', 10, 671);
INSERT INTO 'publicationurl' VALUES (109, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/unnamed.pdf', 10, 985);
INSERT INTO 'publicationurl' VALUES (110, 'http://the-nine-koi.co.uk/12_dances_b.pdf', 10, 990);
INSERT INTO 'publicationurl' VALUES (124, 'http://www.craigellachie-band.co.uk/oxford_connections.html', 10, 1132);
INSERT INTO 'publicationurl' VALUES (126, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=c3Ryb25hbnMub3JnfHN0LXJvbmFucy1zY290dGlzaC1jb3VudHJ5LWRhbmNpbmctY2x1YnxneDo3YWM5YTNkMGI2ZDQxNDk', 10, 1143);
INSERT INTO 'publicationurl' VALUES (131, 'http://www.minicrib.org.uk/publish.html', 10, 1066);
INSERT INTO 'publicationurl' VALUES (132, 'https://www.rscds.org/article/commonwealth-ceilidh', 10, 1180);
INSERT INTO 'publicationurl' VALUES (133, 'http://www.lulu.com/shop/search.ep?type=&keyWords=longwood+collection&x=3&y=7&sitesearch=lulu.com&q=', 10, 1182);
INSERT INTO 'publicationurl' VALUES (134, 'http://www.minicrib.org.uk/Publications/Snow%20Collection.pdf', 10, 1193);
INSERT INTO 'publicationurl' VALUES (135, 'http://www.bracknellreelclub.org.uk/douglas/Rodney%20Celebration.pdf', 10, 1197);
INSERT INTO 'publicationurl' VALUES (137, 'http://bridportscottishdancers.org.uk/', 10, 1198);
INSERT INTO 'publicationurl' VALUES (108, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/cane_toad.pdf', 10, 924);
INSERT INTO 'publicationurl' VALUES (146, 'http://www.minicrib.org.uk/Publications/BHS%209%20for%202015.pdf', 10, 1237);
INSERT INTO 'publicationurl' VALUES (151, 'http://www.bracknellreelclub.org.uk/douglas/rodney2.html', 10, 988);
INSERT INTO 'publicationurl' VALUES (152, 'http://www.bracknellreelclub.org.uk/douglas/rodney1.html', 10, 987);
INSERT INTO 'publicationurl' VALUES (153, 'http://www.minicrib.org.uk/Publications/Keppie_John/H02.pdf', 10, 1256);
INSERT INTO 'publicationurl' VALUES (154, 'http://www.minicrib.org.uk/Publications/Keppie_John/H03.pdf', 10, 1257);
INSERT INTO 'publicationurl' VALUES (155, 'http://www.minicrib.org.uk/Publications/Keppie_John/H5.pdf', 10, 1258);
INSERT INTO 'publicationurl' VALUES (156, 'http://www.minicrib.org.uk/Publications/Keppie_John/H7.pdf', 10, 1259);
INSERT INTO 'publicationurl' VALUES (111, 'http://www.rscdsvienna.org/book/', 10, 1025);
INSERT INTO 'publicationurl' VALUES (159, 'https://footnotes5.wordpress.com/', 10, 1272);
INSERT INTO 'publicationurl' VALUES (160, 'http://www.minicrib.org.uk/bardill-prince%20-%20diamond%20set.html', 10, 1280);
INSERT INTO 'publicationurl' VALUES (162, 'https://www.dropbox.com/s/l761uh2g6mguypy/Oldenburg%20dance%20book.pdf', 10, 1247);
INSERT INTO 'publicationurl' VALUES (161, 'http://homepages.ecs.vuw.ac.nz/~downey/dances/book4.pdf', 10, 1288);
INSERT INTO 'publicationurl' VALUES (178, 'http://rscdsleeds.uk/index.php?id_product=938&controller=product', 100, 81);
INSERT INTO 'publicationurl' VALUES (167, 'http://www.bstk.hu/dances-bstk-2.pdf', 10, 1346);
INSERT INTO 'publicationurl' VALUES (168, 'http://www.bstk.hu/dances-bstk-1.pdf', 10, 380);
INSERT INTO 'publicationurl' VALUES (171, 'http://www.rscdswa.com/publications', 10, 1009);
INSERT INTO 'publicationurl' VALUES (100, 'https://suedan.com/dances/index.php', 10, 644);
INSERT INTO 'publicationurl' VALUES (174, 'http://www.minicrib.org.uk/publish.html', 10, 1355);
INSERT INTO 'publicationurl' VALUES (177, 'http://rscdsleeds.uk/index.php?id_product=947&controller=product', 100, 1360);
INSERT INTO 'publicationurl' VALUES (180, 'http://rscdsleeds.uk/index.php?id_product=930&controller=product', 100, 1063);
INSERT INTO 'publicationurl' VALUES (181, 'http://rscdsleeds.uk/index.php?id_product=929&controller=product', 100, 1062);
INSERT INTO 'publicationurl' VALUES (143, 'http://rscdsleeds.uk/index.php?id_product=916&controller=product', 100, 1214);
INSERT INTO 'publicationurl' VALUES (144, 'http://rscdsleeds.uk/index.php?id_product=917&controller=product', 100, 1204);
INSERT INTO 'publicationurl' VALUES (145, 'http://rscdsleeds.uk/index.php?id_product=918&controller=product', 100, 1230);
INSERT INTO 'publicationurl' VALUES (183, 'http://rscdsleeds.uk/index.php?id_product=927&controller=product', 100, 1173);
INSERT INTO 'publicationurl' VALUES (182, 'http://rscdsleeds.uk/index.php?id_product=926&controller=product', 100, 1229);
INSERT INTO 'publicationurl' VALUES (184, 'http://rscdsleeds.uk/index.php?id_product=928&controller=product', 100, 1242);
INSERT INTO 'publicationurl' VALUES (121, 'http://rscdsleeds.uk/index.php?id_product=924&controller=product', 100, 913);
INSERT INTO 'publicationurl' VALUES (142, 'http://rscdsleeds.uk/index.php?id_product=923&controller=product', 100, 1053);
INSERT INTO 'publicationurl' VALUES (169, 'http://rscdsleeds.uk/index.php?id_product=919&controller=product', 100, 1351);
INSERT INTO 'publicationurl' VALUES (139, 'http://www.lulu.com/shop/livia-kohn-and-ellen-mcranor-and-bob-davidson/the-suncoast-collection/ebook/product-21928140.html', 10, 1175);
INSERT INTO 'publicationurl' VALUES (136, 'http://www.bracknellreelclub.org.uk/douglas/rodneycelebration.html', 10, 1197);
INSERT INTO 'publicationurl' VALUES (163, 'https://harwellscdc.mno.org.uk/wp-content/uploads/2018/08/HCS-1948-1998.pdf', 10, 1307);
INSERT INTO 'publicationurl' VALUES (147, 'http://www.rscds-swws.org/JustDesserts.pdf', 10, 1095);
INSERT INTO 'publicationurl' VALUES (129, 'http://www.rscds-swws.org/PBC%20of%20SCDv3.pdf', 10, 1172);
INSERT INTO 'publicationurl' VALUES (128, 'http://lmd.imaginationprocessing.com/subpages/PBC%20of%20SCDv3.pdf', 10, 1172);
INSERT INTO 'publicationurl' VALUES (157, 'http://www.lulu.com/shop/rscds-international-branch/world-wide-weavings/ebook/product-22219057.html', 20, 1263);
INSERT INTO 'publicationurl' VALUES (158, 'http://www.lulu.com/shop/rscds-international-branch/world-wide-weavings/paperback/product-22213626.html', 20, 1263);
INSERT INTO 'publicationurl' VALUES (113, 'http://www.rscds-norwich.org.uk/rscds50annivdances.html', 10, 1039);
INSERT INTO 'publicationurl' VALUES (286, 'http://bstk.hu/book2/', 10, 1505);
INSERT INTO 'publicationurl' VALUES (99, 'https://www.anselms.net/pdf/scd-books/pmbook.pdf', 10, 599);
INSERT INTO 'publicationurl' VALUES (176, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=8f14e45fceea167a5a36dedd4bea2543', 100, 1350);
INSERT INTO 'publicationurl' VALUES (112, 'https://www.anselms.net/pdf/scd-books/wbook.pdf', 10, 1031);
INSERT INTO 'publicationurl' VALUES (141, 'http://rscdsleeds.uk/index.php?id_product=922&controller=product', 100, 1151);
INSERT INTO 'publicationurl' VALUES (185, 'http://rscdsleeds.uk/index.php?id_product=915&controller=product', 100, 1210);
INSERT INTO 'publicationurl' VALUES (274, 'http://www.minicrib.org.uk/Publications/Keppie_John/GC12.pdf', 10, 898);
INSERT INTO 'publicationurl' VALUES (149, 'http://www.rscds-swws.org/WaCentennialCollection.pdf', 10, 544);
INSERT INTO 'publicationurl' VALUES (107, 'https://dances.e-cribs.org/FlyingGhilliesCollection_Vol1.pdf', 10, 919);
INSERT INTO 'publicationurl' VALUES (103, 'https://dances.e-cribs.org/FlyingGhilliesCollection_Vol2.pdf', 10, 772);
INSERT INTO 'publicationurl' VALUES (115, 'https://dances.e-cribs.org/FlyingGhilliesCollection_Vol3.pdf', 10, 1046);
INSERT INTO 'publicationurl' VALUES (116, 'https://dances.e-cribs.org/FlyingGhilliesCollection_Vol4.pdf', 10, 1047);
INSERT INTO 'publicationurl' VALUES (148, 'http://www.rscds-swws.org/FeastOfDances.pdf', 10, 352);
INSERT INTO 'publicationurl' VALUES (150, 'http://www.rscds-swws.org/InternationalLanguage.pdf', 10, 1203);
INSERT INTO 'publicationurl' VALUES (165, 'http://portlandscottishdancers.org/files/princess_bride_collection.pdf', 20, 1172);
INSERT INTO 'publicationurl' VALUES (117, 'https://www.8x32.org/', 10, 1096);
INSERT INTO 'publicationurl' VALUES (173, 'http://www.minicrib.org.uk/publish.html', 10, 1354);
INSERT INTO 'publicationurl' VALUES (187, 'http://www.minicrib.org.uk/Publications/ASHMERG%20Collection.pdf', 30, 1365);
INSERT INTO 'publicationurl' VALUES (188, 'http://rscdsleeds.uk/index.php?id_product=954&controller=product', 100, 1324);
INSERT INTO 'publicationurl' VALUES (189, 'http://rscds-sf.org/resources/popup/sfcoll1.htm', 10, 547);
INSERT INTO 'publicationurl' VALUES (164, 'https://rscdssask.org/wp-content/uploads/2022/11/centennial_collection.pdf', 10, 1014);
INSERT INTO 'publicationurl' VALUES (98, 'http://www.scotia-dance.org/', 10, 529);
INSERT INTO 'publicationurl' VALUES (190, 'http://rscds-sf.org/resources/popup/SFCollection1/SF%20Collection%201.pdf', 10, 547);
INSERT INTO 'publicationurl' VALUES (191, 'http://rscds-sf.org/resources/', 10, 1370);
INSERT INTO 'publicationurl' VALUES (192, 'http://rscds-sf.org/resources/', 10, 1371);
INSERT INTO 'publicationurl' VALUES (193, 'http://rscdsleeds.uk/index.php?id_product=959&controller=product', 100, 147);
INSERT INTO 'publicationurl' VALUES (194, 'http://rscdsleeds.uk/index.php?id_product=969&controller=product', 100, 281);
INSERT INTO 'publicationurl' VALUES (195, 'http://rscdsleeds.uk/index.php?id_product=977&controller=product', 100, 1306);
INSERT INTO 'publicationurl' VALUES (196, 'http://rscdsleeds.uk/index.php?id_product=976&controller=product', 100, 1186);
INSERT INTO 'publicationurl' VALUES (197, 'http://rscdsleeds.uk/index.php?id_product=975&controller=product', 100, 1133);
INSERT INTO 'publicationurl' VALUES (198, 'http://rscdsleeds.uk/index.php?id_product=974&controller=product', 100, 1135);
INSERT INTO 'publicationurl' VALUES (200, 'http://rscdsleeds.uk/index.php?id_product=968&controller=product', 100, 1380);
INSERT INTO 'publicationurl' VALUES (201, 'http://rscdsleeds.uk/index.php?id_product=967&controller=product', 10, 1379);
INSERT INTO 'publicationurl' VALUES (202, 'http://rscdsleeds.uk/index.php?id_product=966&controller=product', 10, 1378);
INSERT INTO 'publicationurl' VALUES (203, 'http://rscdsleeds.uk/index.php?id_product=979&controller=product', 100, 1320);
INSERT INTO 'publicationurl' VALUES (204, 'http://rscdsleeds.uk/index.php?id_product=978&controller=product', 100, 1319);
INSERT INTO 'publicationurl' VALUES (205, 'https://www.rscdslondon.org.uk/thereel/', 10, 73);
INSERT INTO 'publicationurl' VALUES (206, 'http://www.lulu.com/', 10, 1369);
INSERT INTO 'publicationurl' VALUES (253, 'http://www.minicrib.org.uk/Publications/The%20Holiday%20Dances-%20Jean%20Shaw.pdf', 10, 1474);
INSERT INTO 'publicationurl' VALUES (208, 'http://rscdsleeds.uk/index.php?id_product=1004&controller=product', 100, 1240);
INSERT INTO 'publicationurl' VALUES (209, 'http://rscdsleeds.uk/index.php?id_product=1003&controller=product', 100, 1401);
INSERT INTO 'publicationurl' VALUES (210, 'http://rscdsleeds.uk/index.php?id_product=1002&controller=product', 100, 885);
INSERT INTO 'publicationurl' VALUES (211, 'http://rscdsleeds.uk/index.php?id_product=1001&controller=product', 100, 883);
INSERT INTO 'publicationurl' VALUES (212, 'http://rscdsleeds.uk/index.php?id_product=997&controller=product', 100, 884);
INSERT INTO 'publicationurl' VALUES (213, 'http://rscdsleeds.uk/index.php?id_product=1000&controller=product', 100, 980);
INSERT INTO 'publicationurl' VALUES (214, 'http://rscdsleeds.uk/index.php?id_product=981&controller=product', 100, 115);
INSERT INTO 'publicationurl' VALUES (215, 'http://rscdsleeds.uk/index.php?id_product=999&controller=product', 100, 993);
INSERT INTO 'publicationurl' VALUES (216, 'http://rscdsleeds.uk/index.php?id_product=996&controller=product', 100, 136);
INSERT INTO 'publicationurl' VALUES (217, 'http://rscdsleeds.uk/index.php?id_product=998&controller=product', 100, 840);
INSERT INTO 'publicationurl' VALUES (218, 'http://rscdsleeds.uk/index.php?id_product=992&controller=product', 100, 1402);
INSERT INTO 'publicationurl' VALUES (219, 'http://rscdsleeds.uk/index.php?id_product=521&controller=product', 100, 1411);
INSERT INTO 'publicationurl' VALUES (220, 'http://rscdsleeds.uk/index.php?id_product=169', 100, 1407);
INSERT INTO 'publicationurl' VALUES (221, 'http://rscdsleeds.uk/index.php?id_product=1013&controller=product', 100, 1406);
INSERT INTO 'publicationurl' VALUES (223, 'http://rscdsleeds.uk/index.php?id_product=995&controller=product', 100, 1389);
INSERT INTO 'publicationurl' VALUES (224, 'http://rscdsleeds.uk/index.php?id_product=640&controller=product', 100, 1386);
INSERT INTO 'publicationurl' VALUES (225, 'http://rscdsleeds.uk/index.php?id_product=988&controller=product', 100, 1385);
INSERT INTO 'publicationurl' VALUES (226, 'http://rscdsleeds.uk/index.php?id_product=984&controller=product', 100, 1383);
INSERT INTO 'publicationurl' VALUES (227, 'http://rscdsleeds.uk/index.php?id_product=956&controller=product', 100, 1374);
INSERT INTO 'publicationurl' VALUES (228, 'http://rscdsleeds.uk/index.php?id_product=828&controller=product', 100, 1359);
INSERT INTO 'publicationurl' VALUES (229, 'http://rscdsleeds.uk/index.php?id_product=827&controller=product', 100, 1353);
INSERT INTO 'publicationurl' VALUES (231, 'http://rscdsleeds.uk/index.php?id_product=937&controller=product', 100, 1348);
INSERT INTO 'publicationurl' VALUES (233, 'http://rscdsleeds.uk/index.php?id_product=899&controller=product', 100, 1342);
INSERT INTO 'publicationurl' VALUES (235, 'http://rscdsleeds.uk/index.php?id_product=896&controller=product', 100, 1339);
INSERT INTO 'publicationurl' VALUES (236, 'http://rscdsleeds.uk/index.php?id_product=887&controller=product', 100, 1337);
INSERT INTO 'publicationurl' VALUES (237, 'http://rscdsleeds.uk/index.php?id_product=891&controller=product', 100, 1334);
INSERT INTO 'publicationurl' VALUES (238, 'http://rscdsleeds.uk/index.php?id_product=875&controller=product', 100, 1331);
INSERT INTO 'publicationurl' VALUES (239, 'http://rscdsleeds.uk/index.php?id_product=636&controller=product', 100, 1330);
INSERT INTO 'publicationurl' VALUES (240, 'http://www.rscds-newcastle.org/Life_Begins_at_Forty.pdf', 20, 113);
INSERT INTO 'publicationurl' VALUES (179, 'http://rscdsleeds.uk/index.php?id_product=933&controller=product', 100, 1332);
INSERT INTO 'publicationurl' VALUES (243, 'http://rscdsleeds.uk/index.php?id_product=1054&controller=product', 100, 1457);
INSERT INTO 'publicationurl' VALUES (244, 'http://rscdsleeds.uk/index.php?id_product=1053&controller=product', 10, 1456);
INSERT INTO 'publicationurl' VALUES (245, 'http://rscdsleeds.uk/index.php?id_product=1052&controller=product', 10, 1455);
INSERT INTO 'publicationurl' VALUES (232, 'http://rscdsleeds.uk/index.php?id_product=982&controller=product', 100, 1344);
INSERT INTO 'publicationurl' VALUES (246, 'http://www.minicrib.org.uk/Publications/JeanShawCollection.pdf', 10, 1464);
INSERT INTO 'publicationurl' VALUES (247, 'https://sites.google.com/site/thefollyofrogues/cusrc-reelwiki', 10, 1131);
INSERT INTO 'publicationurl' VALUES (207, 'http://rscdsleeds.uk/index.php?id_product=1066&controller=product', 100, 1338);
INSERT INTO 'publicationurl' VALUES (249, 'http://hms.scot/fiddle/source/17/', 10, 1467);
INSERT INTO 'publicationurl' VALUES (250, 'http://hms.scot/fiddle/source/18/', 10, 1468);
INSERT INTO 'publicationurl' VALUES (251, 'http://hms.scot/fiddle/source/151/', 10, 1469);
INSERT INTO 'publicationurl' VALUES (252, 'http://hms.scot/fiddle/source/152/', 10, 1470);
INSERT INTO 'publicationurl' VALUES (254, 'http://www.minicrib.org.uk/Publications/Ian%20Shepherd%20Dance%20Collection.pdf', 10, 1475);
INSERT INTO 'publicationurl' VALUES (255, 'http://www.minicrib.org.uk/Publications/Keppie_John/Dances%20BURNS.pdf', 10, 682);
INSERT INTO 'publicationurl' VALUES (264, 'http://www.minicrib.org.uk/Publications/Keppie_John/GC05.pdf', 10, 376);
INSERT INTO 'publicationurl' VALUES (199, 'https://www.rscds.org/shop/product/books/book-51/', 10, 1381);
INSERT INTO 'publicationurl' VALUES (263, 'http://www.minicrib.org.uk/Publications/Keppie_John/GC04.pdf', 10, 354);
INSERT INTO 'publicationurl' VALUES (261, 'http://www.minicrib.org.uk/Publications/Keppie_John/GC01.pdf', 10, 353);
INSERT INTO 'publicationurl' VALUES (262, 'http://www.minicrib.org.uk/Publications/Keppie_John/GC03.pdf', 10, 355);
INSERT INTO 'publicationurl' VALUES (265, 'http://www.minicrib.org.uk/Publications/Keppie_John/GC06.pdf', 10, 377);
INSERT INTO 'publicationurl' VALUES (266, 'http://www.minicrib.org.uk/Publications/Keppie_John/H4.pdf', 10, 1189);
INSERT INTO 'publicationurl' VALUES (267, 'http://www.minicrib.org.uk/Publications/Keppie_John/GC07.pdf', 10, 378);
INSERT INTO 'publicationurl' VALUES (268, 'http://www.minicrib.org.uk/Publications/Keppie_John/GC08.pdf', 10, 411);
INSERT INTO 'publicationurl' VALUES (269, 'http://www.minicrib.org.uk/Publications/Keppie_John/H01.pdf', 10, 926);
INSERT INTO 'publicationurl' VALUES (270, 'http://www.minicrib.org.uk/Publications/Keppie_John/HSCD6.pdf', 10, 1207);
INSERT INTO 'publicationurl' VALUES (271, 'http://www.minicrib.org.uk/Publications/Keppie_John/GC09.pdf', 10, 410);
INSERT INTO 'publicationurl' VALUES (272, 'http://www.minicrib.org.uk/Publications/Keppie_John/GC10.pdf', 10, 412);
INSERT INTO 'publicationurl' VALUES (273, 'http://www.minicrib.org.uk/Publications/Keppie_John/GC11.pdf', 10, 767);
INSERT INTO 'publicationurl' VALUES (275, 'http://www.minicrib.org.uk/Publications/Keppie_John/GC02.pdf', 10, 356);
INSERT INTO 'publicationurl' VALUES (276, 'https://harwellscdc.mno.org.uk/club-dances/', 10, 1307);
INSERT INTO 'publicationurl' VALUES (278, 'https://dances.e-cribs.org/Scottish_Country_Dances_by_James_McMillan.pdf', 10, 1487);
INSERT INTO 'publicationurl' VALUES (279, 'https://tinyurl.com/JamesMcMillan', 10, 1487);
INSERT INTO 'publicationurl' VALUES (280, 'http://rscdswestlothian.org.uk/west-lothian-dance-books/westlothiana/', 10, 332);
INSERT INTO 'publicationurl' VALUES (281, 'http://rscdswestlothian.org.uk/west-lothian-dance-books/wl-60-dances/', 10, 361);
INSERT INTO 'publicationurl' VALUES (282, 'http://rscdswestlothian.org.uk/west-lothian-dance-books/wl-50-dances/', 10, 95);
INSERT INTO 'publicationurl' VALUES (283, 'http://rscdswestlothian.org.uk/west-lothian-dance-books/wl-70/', 10, 1102);
INSERT INTO 'publicationurl' VALUES (285, 'http://rscdsleeds.uk/index.php?id_product=807&controller=product', 10, 1265);
INSERT INTO 'publicationurl' VALUES (288, 'http://dancetide.dk/wp-content/uploads/2018/05/Scandinavian-Scottish-Dancebook-vol-I-21-04-2018-Dancebook-.pdf', 10, 1511);
INSERT INTO 'publicationurl' VALUES (289, 'http://www.oscdg.no/Scandinavian%20Dancebook.pdf', 10, 1511);
INSERT INTO 'publicationurl' VALUES (290, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=c4ca4238a0b923820dcc509a6f75849b#tab31&.pdf', 10, 1268);
INSERT INTO 'publicationurl' VALUES (292, 'http://minicrib.org.uk/JohnAJohnstonDances.html', 10, 1514);
INSERT INTO 'publicationurl' VALUES (293, 'http://bridportscottishdancers.org.uk/pages/localdances.htm?LMCL=AtJDjm', 10, 1198);
INSERT INTO 'publicationurl' VALUES (322, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/01-Scottish-Country-Dance-Book-of-Four-Set-Dances-1st-Set.pdf', 10, 1518);
INSERT INTO 'publicationurl' VALUES (295, 'https://dances.e-cribs.org/A_World''s_End_Book_of_13_SCD_-_Vol1.pdf', 10, 1528);
INSERT INTO 'publicationurl' VALUES (296, 'http://www.minicrib.org.uk/Publications/The%20Second%20Canberra%20Book%20of%20SCDs.pdf', 10, 1547);
INSERT INTO 'publicationurl' VALUES (297, 'http://www.minicrib.org.uk/Publications/8%20Dances%20-%20Holly%20V%20Sherman.pdf', 10, 1548);
INSERT INTO 'publicationurl' VALUES (114, 'https://homepages.ecs.vuw.ac.nz/~downey/dances/book3.pdf', 10, 1045);
INSERT INTO 'publicationurl' VALUES (300, 'https://www.rscdslondon.org.uk/scottish-dance-archives/', 10, 436);
INSERT INTO 'publicationurl' VALUES (323, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/04-Three-Traditional-Scottish-Dances-4th-Set.pdf', 10, 1580);
INSERT INTO 'publicationurl' VALUES (324, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/07-Three-Traditional-Scottish-Dances-7th-Set.pdf', 10, 1583);
INSERT INTO 'publicationurl' VALUES (325, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/08-Two-Traditional-Scottish-Dances-8th-Set-1.pdf', 10, 1584);
INSERT INTO 'publicationurl' VALUES (326, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/09-Two-Traditional-Scottish-Dances-9th-Set-1.pdf', 10, 1585);
INSERT INTO 'publicationurl' VALUES (301, 'https://links.e-cribs.org/WhetherlyBook4', 10, 454);
INSERT INTO 'publicationurl' VALUES (294, 'https://links.e-cribs.org/WhetherlyBook1', 10, 451);
INSERT INTO 'publicationurl' VALUES (298, 'https://links.e-cribs.org/WhetherlyBook2', 10, 452);
INSERT INTO 'publicationurl' VALUES (299, 'https://links.e-cribs.org/WhetherlyBook3', 10, 453);
INSERT INTO 'publicationurl' VALUES (302, 'http://www.rscdsnovascotia.ca/A%20Collection%20of%20SCDs%20from%20NS.pdf', 10, 1489);
INSERT INTO 'publicationurl' VALUES (242, 'https://homepages.ecs.vuw.ac.nz/~downey/dances/book5.pdf', 10, 1451);
INSERT INTO 'publicationurl' VALUES (303, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=e369853df766fa44e1ed0ff613f563bd#tab31', 10, 455);
INSERT INTO 'publicationurl' VALUES (304, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=4e732ced3463d06de0ca9a15b6153677#tab31', 10, 451);
INSERT INTO 'publicationurl' VALUES (305, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=02e74f10e0327ad868d138f2b4fdd6f0#tab31', 10, 452);
INSERT INTO 'publicationurl' VALUES (306, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=33e75ff09dd601bbe69f351039152189#tab31', 10, 453);
INSERT INTO 'publicationurl' VALUES (307, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=182be0c5cdcd5072bb1864cdee4d3d6e#tab31', 10, 454);
INSERT INTO 'publicationurl' VALUES (308, 'https://dances.e-cribs.org/The_Freiburg_Corona_Collection.pdf', 10, 1557);
INSERT INTO 'publicationurl' VALUES (310, 'http://www.dancescottish.ca/books_files/Tayside%20Collection%2020th%20Anniv.pdf', 10, 956);
INSERT INTO 'publicationurl' VALUES (311, 'https://www.rscdslondon.org.uk/the-thistle-magazine-john-mitchell-bequest/', 10, 480);
INSERT INTO 'publicationurl' VALUES (312, 'https://www.rscdslondon.org.uk/the-reel-archives/', 10, 73);
INSERT INTO 'publicationurl' VALUES (313, 'http://www.rscdsnovascotia.ca/2017-Booklet-CD.htm', 10, 1374);
INSERT INTO 'publicationurl' VALUES (332, 'https://www.matsmelin.com/wp-content/uploads/2011/05/Cormorant-Book-1.pdf', 10, 143);
INSERT INTO 'publicationurl' VALUES (315, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=1c383cd30b7c298ab50293adfecb7b18#tab31', 10, 456);
INSERT INTO 'publicationurl' VALUES (316, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=a5bfc9e07964f8dddeb95fc584cd965d#tab31', 10, 457);
INSERT INTO 'publicationurl' VALUES (317, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=19ca14e7ea6328a42e0eb13d585e4c22#tab31', 10, 474);
INSERT INTO 'publicationurl' VALUES (186, 'https://www.rscds.org.au/uploads/1/3/3/9/133950348/sydney_down_under_dance_book_2014_1amended30oct2014.pdf', 10, 1200);
INSERT INTO 'publicationurl' VALUES (318, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/06-Three-Traditional-Scottish-Dances-6th-Set.pdf', 10, 1582);
INSERT INTO 'publicationurl' VALUES (319, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/02-Four-Traditional-Scottish-Dances-2nd-Set.pdf', 10, 1578);
INSERT INTO 'publicationurl' VALUES (320, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/03/05-Four-Traditional-Scottish-Dances-5th-Set.pdf', 10, 1581);
INSERT INTO 'publicationurl' VALUES (321, 'https://www.rscdslondon.org.uk/wp-content/uploads/2021/04/03-Three-Traditional-Scottish-Dances-3rd-Set.pdf', 10, 1579);
INSERT INTO 'publicationurl' VALUES (328, 'https://www.scd-germany.de/de/schottentanzen-in-deutschland/publikationen/publikationen.html?download=31&token=d67d8ab4f4c10bf22aa353e27879133c#tab31', 10, 458);
INSERT INTO 'publicationurl' VALUES (329, 'https://www.scd-germany.de/de/schottentanzen-in-deutschland/publikationen/publikationen.html?download=31&token=d645920e395fedad7bbbed0eca3fe2e0#tab31', 10, 459);
INSERT INTO 'publicationurl' VALUES (330, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxzY2RjYW5iZXJyYXxneDozZDE3YWFjN2IyNWRkOTc3', 10, 1547);
INSERT INTO 'publicationurl' VALUES (331, 'http://www.minicrib.org.uk/Publications/AConrad.The.Odd.Half-dozen.pdf', 10, 1597);
INSERT INTO 'publicationurl' VALUES (333, 'http://www.dancescottish.ca/books_files/The%20Geneva%20Park%20Dances%20book%201970.pdf', 10, 1310);
INSERT INTO 'publicationurl' VALUES (334, 'http://www.dancescottish.ca/books_files/Centennial%20Collection.pdf', 10, 497);
INSERT INTO 'publicationurl' VALUES (335, 'http://www.wellingtonscd.org.nz/wp-content/uploads/2021/10/Wellington-Region-Covid-19-Collection.pdf', 10, 1604);
INSERT INTO 'publicationurl' VALUES (336, 'https://music.rscdsparis.fr/files/paris-book-2-pdf.zip', 10, 1606);
INSERT INTO 'publicationurl' VALUES (337, 'https://music.rscdsparis.fr/files/paris-book-pdf.zip', 10, 1605);
INSERT INTO 'publicationurl' VALUES (338, 'http://www.minicrib.org.uk/Publications/The%20West%20Wynd%20and%20other%20Dances%20by%20Nan%20Lawson.pdf', 10, 1612);
INSERT INTO 'publicationurl' VALUES (284, 'https://sites.google.com/site/ipscdg/commemorative-book-of-dances', 10, 1492);
INSERT INTO 'publicationurl' VALUES (339, 'https://scotscores.com/product/to-dance-to-5/', 10, 1614);
INSERT INTO 'publicationurl' VALUES (340, 'https://scotscores.com/product/to-dance-to-1/', 10, 422);
INSERT INTO 'publicationurl' VALUES (341, 'https://scotscores.com/product/to-dance-to-2/', 10, 1615);
INSERT INTO 'publicationurl' VALUES (342, 'https://scotscores.com/product/to-dance-to-4/', 10, 1617);
INSERT INTO 'publicationurl' VALUES (343, 'https://scotscores.com/product/to-dance-to-3-2/', 10, 1616);
INSERT INTO 'publicationurl' VALUES (327, 'http://www.dancescottish.ca/leaflet-dances.html', 15, 1290);
INSERT INTO 'publicationurl' VALUES (345, 'http://www.minicrib.org.uk/Publications/Alderley%20and%20District%2050th%20Anniversary.pdf', 10, 1623);
INSERT INTO 'publicationurl' VALUES (346, 'https://www.turnverein-maxglan.at/reginas-dances/', 10, 1624);
INSERT INTO 'publicationurl' VALUES (344, 'http://www.minicrib.org.uk/Publications/4%20Dances%20by%20Peter%20Marshall.pdf', 10, 1622);
INSERT INTO 'publicationurl' VALUES (347, 'https://www.scottish-country-dancing-dictionary.com/images/mcghie-scd-sheets-collection-1.pdf', 10, 1634);
INSERT INTO 'publicationurl' VALUES (348, 'https://www.scottish-country-dancing-dictionary.com/images/mcghie-scd-sheets-collection-5.pdf', 10, 1633);
INSERT INTO 'publicationurl' VALUES (349, 'https://www.scottish-country-dancing-dictionary.com/images/mcghie-scd-sheets-collection-2.pdf', 10, 1635);
INSERT INTO 'publicationurl' VALUES (350, 'https://www.scottish-country-dancing-dictionary.com/images/mcghie-scd-sheets-collection-3.pdf', 10, 1636);
INSERT INTO 'publicationurl' VALUES (351, 'https://www.scottish-country-dancing-dictionary.com/images/mcghie-scd-sheets-collection-4.pdf', 10, 1637);
INSERT INTO 'publicationurl' VALUES (352, 'https://homepages.ecs.vuw.ac.nz/~downey/dances/book6.pdf', 10, 1609);
INSERT INTO 'publicationurl' VALUES (354, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=a1d0c6e83f027327d8461063f4ac58a6#tab31', 10, 460);
INSERT INTO 'publicationurl' VALUES (355, 'https://drive.google.com/drive/folders/1ztkBbZLNzbBhPZI4n9L8ouhCW-QK3SYl', 10, 844);
INSERT INTO 'publicationurl' VALUES (356, 'https://drive.google.com/drive/u/0/folders/1OfqpOIK83eX-bKOsEEENdOnq12UApvVr', 10, 846);
INSERT INTO 'publicationurl' VALUES (357, 'https://drive.google.com/drive/u/0/folders/1yAPMIn9x-qpM88MhmjD_ElVZevS1Sdv1', 10, 847);
INSERT INTO 'publicationurl' VALUES (358, 'https://drive.google.com/drive/u/0/folders/1O05_-9ulJQOmsCsIMfBI7eoYG2X2y8fn', 10, 848);
INSERT INTO 'publicationurl' VALUES (359, 'https://drive.google.com/drive/u/0/folders/1VACZHfZRTa3Ly0J3X7c3U_LIL9O8ls_R', 10, 770);
INSERT INTO 'publicationurl' VALUES (360, 'https://drive.google.com/drive/u/0/folders/1F5Qo-Uv9i6YpXM8mNxsySMvPGP1isA5J', 10, 1265);
INSERT INTO 'publicationurl' VALUES (170, 'https://www.rscdswa.com/about-us/wa-dances-and-publications', 10, 1171);
INSERT INTO 'publicationurl' VALUES (361, 'https://www.dancescottish.ca/books_files/Tayside-Collection,-Volume-II,-2006.pdf', 10, 1405);
INSERT INTO 'publicationurl' VALUES (362, 'https://dances.e-cribs.org/2002_Ball_Book.pdf', 10, 1666);
INSERT INTO 'publicationurl' VALUES (363, 'https://sprott.physics.wisc.edu/mecds/ScotBook/Contents.html', 10, 1666);
INSERT INTO 'publicationurl' VALUES (364, 'https://archive.rscds.org/uploads/r/royal-scottish-country-dance-society-archive/f/e/8/fe80dd07aec191b2b01ae284dd85dd8c5ab42431bbdd92de1faeee0cc340f874/877-001opt.pdf', 10, 1667);
INSERT INTO 'publicationurl' VALUES (365, 'https://www.rscdslondon.org.uk/scottish-dance-archives/', 10, 1668);
INSERT INTO 'publicationurl' VALUES (366, 'http://www.dancescottish.ca/leaflets.html', 10, 1290);
INSERT INTO 'publicationurl' VALUES (367, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=642e92efb79421734881b53e1e1b18b6#tab31', 10, 462);
INSERT INTO 'publicationurl' VALUES (368, 'https://www.scd-germany.de/en/scottish-dancing-in-germany/publications/publications.html?download=31&token=67c6a1e7ce56d3d6fa748ab6d9af3fd7#tab31', 10, 461);


--
INSERT INTO 'recording' VALUES (1, NULL, '2012-01-20 12:55:01.46924+00', '1314', 3007, 4, 0, 128, 2, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (2, NULL, '2012-01-20 12:55:01.476+00', '2/4 Marches', 3010, 11, 0, 0, 9999, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (4, NULL, '2012-01-20 12:55:01.488669+00', 'Airdrie Lassies', 3006, 2, 4, 48, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (5, NULL, '2012-01-20 12:55:01.494962+00', 'Alison Rose', 3006, 3, 4, 32, 9999, NULL, 243, 0, '');
INSERT INTO 'recording' VALUES (7, NULL, '2012-01-20 12:55:01.507804+00', 'Alyth Burn', 3006, 2, 8, 48, 9999, NULL, 397, 0, '');
INSERT INTO 'recording' VALUES (9, NULL, '2012-01-20 12:55:01.522422+00', 'Autumn in Appin', 3026, 3, 4, 32, 9999, 5, 290, 1, '');
INSERT INTO 'recording' VALUES (10, NULL, '2012-01-20 12:55:01.527583+00', 'Axum Reel, The', 3023, 3, 0, 32, 9999, NULL, 68, 0, '');
INSERT INTO 'recording' VALUES (4272, NULL, '2018-03-02 23:08:22.620944+00', 'Eskdalemuir', 2566, 3, 3, 32, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (12, NULL, '2012-01-20 12:55:01.538225+00', 'Fair Jenny''s Jig', 3048, 2, 8, 32, 9999, 1, 283, 0, '');
INSERT INTO 'recording' VALUES (13, NULL, '2012-01-20 12:55:01.543035+00', 'Baldovan Jig, The', 3012, 2, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (14, NULL, '2012-01-20 12:55:01.548527+00', 'Banks Of Clyde, The', 3002, 3, 8, 32, 9999, 5, 505, 0, '');
INSERT INTO 'recording' VALUES (15, NULL, '2012-01-20 12:55:01.553366+00', 'Because He Was A Bonnie Lad', 3015, 4, 0, 112, 19, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (16, NULL, '2012-01-20 12:55:01.55816+00', 'Bees of Maggieknockater, The', 3006, 2, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (17, NULL, '2012-01-20 12:55:01.563662+00', 'Birks of Invermay, The', 3017, 3, 8, 32, 9999, 5, 497, 0, '');
INSERT INTO 'recording' VALUES (18, NULL, '2012-01-20 12:55:01.56916+00', 'Birks of Invermay, The', 3018, 3, 8, 32, 9999, 5, 510, 0, '');
INSERT INTO 'recording' VALUES (19, NULL, '2012-01-20 12:55:01.574668+00', 'Black Dance, The', 3010, 1, 8, 32, 9999, 1, 258, 0, '');
INSERT INTO 'recording' VALUES (20, NULL, '2012-01-20 12:55:01.579483+00', 'Black Mountain Reel, The', 3011, 1, 5, 32, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (22, NULL, '2012-01-20 12:55:01.589819+00', 'Blooms of Bon Accord, The', 3012, 1, 4, 32, 9999, NULL, 137, 1, '');
INSERT INTO 'recording' VALUES (23, NULL, '2012-01-20 12:55:01.5946+00', 'Bluebell Polka', 3010, 13, 0, 0, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (24, NULL, '2012-01-20 12:55:01.600035+00', 'Tam O'' Shanter', 2029, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (25, NULL, '2012-01-20 12:55:01.604884+00', 'Bonnie Anne', 3011, 2, 0, 96, 9999, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (26, NULL, '2012-01-20 12:55:01.60968+00', 'Bonnie Anne', 3015, 2, 0, 96, 9999, NULL, 116, 0, '');
INSERT INTO 'recording' VALUES (27, NULL, '2012-01-20 12:55:01.614464+00', 'Bonnie Lass O'' Bon Accord, The', 3037, 3, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (28, NULL, '2012-01-20 12:55:01.619903+00', 'Bonniest Lass In All The World, The', 3023, 3, 8, 40, 9999, 6, 624, 0, '');
INSERT INTO 'recording' VALUES (29, NULL, '2012-01-20 12:55:01.624707+00', 'Boston Two Step', 3056, 50, 0, 0, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (30, NULL, '2012-01-20 12:55:01.629516+00', 'Braes of Balquhidder, The', 3015, 3, 0, 128, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (31, NULL, '2012-01-20 12:55:01.634965+00', 'Braes O'' Breadalbane, The', 3001, 3, 8, 32, 9999, 5, 470, 0, '');
INSERT INTO 'recording' VALUES (32, NULL, '2012-01-20 12:55:01.640421+00', 'Bratach Bana', 3013, 1, 8, 32, 9999, 1, 285, 0, '');
INSERT INTO 'recording' VALUES (33, NULL, '2012-01-20 12:55:01.645209+00', 'Bratach Bana', 3008, 1, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (34, NULL, '2012-01-20 12:55:01.650662+00', 'Brechin Lassies', 3002, 1, 8, 32, 9999, 1, 287, 0, '');
INSERT INTO 'recording' VALUES (35, NULL, '2012-01-20 12:55:01.655461+00', 'Brig O'' Doon', 3015, 3, 0, 96, 9999, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (36, NULL, '2012-01-20 12:55:01.66039+00', 'Buchan Eightsome Reel, The', 3011, 1, 10, 40, 9999, NULL, 419, 0, '');
INSERT INTO 'recording' VALUES (37, NULL, '2012-01-20 12:55:01.665923+00', 'Burnieboozle', 3009, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (38, NULL, '2012-01-20 12:55:01.671468+00', 'Butterscotch And Honey', 3013, 3, 4, 32, 9999, 5, 247, 0, '');
INSERT INTO 'recording' VALUES (39, NULL, '2012-01-20 12:55:01.676931+00', 'Ca'' The Ewes Tae The Knowes', 3018, 3, 8, 32, 9999, 5, 503, 0, '');
INSERT INTO 'recording' VALUES (3380, NULL, '2012-01-20 12:55:20.317528+00', 'Tartan Track Strathspey, The', 1701, 3, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3381, NULL, '2012-01-20 12:55:20.323844+00', 'Waltz Country Dance', 1701, 5, 2, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3382, NULL, '2012-01-20 12:55:20.330107+00', 'Baldovan Reel, The', 2039, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3383, NULL, '2012-01-20 12:55:20.336343+00', 'From Scotia''s Shores We''re Noo Awa''', 2039, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3384, NULL, '2012-01-20 12:55:20.342724+00', 'Peggy''s Wedding', 2039, 2, 3, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3385, NULL, '2012-01-20 12:55:20.348946+00', 'Minard Castle', 2039, 1, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3386, NULL, '2012-01-20 12:55:20.355221+00', 'River Cree, The', 2039, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3387, NULL, '2012-01-20 12:55:20.361443+00', 'Scottish Waltz', 2039, 5, 6, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3388, NULL, '2012-01-20 12:55:20.367669+00', 'Gay Gordons', 2039, 11, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3389, NULL, '2012-01-20 12:55:20.37391+00', 'Captain MacBean''s Reel', 2039, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3390, NULL, '2012-01-20 12:55:20.380152+00', 'Hornpipes', 2093, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4838, NULL, '2012-01-20 12:55:29.179149+00', 'Scottish Waltzes', 3064, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4847, NULL, '2012-01-20 12:55:29.222905+00', 'Dunoon Barn Dance', 3063, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4848, NULL, '2012-01-20 12:55:29.2277+00', 'Jig', 3063, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4849, NULL, '2012-01-20 12:55:29.232686+00', 'Northumbrian Reel', 3063, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4850, NULL, '2012-01-20 12:55:29.237489+00', 'Scottish Waltz', 3063, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4851, NULL, '2012-01-20 12:55:29.242283+00', 'Lancashire Clog Dance', 3063, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4852, NULL, '2012-01-20 12:55:29.247058+00', 'Latheronwheel Polka', 3063, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (8847, '2012-02-28 14:20:54.109475+00', '2012-02-28 14:20:54.109485+00', 'Flowers of Edinburgh', 903, 1, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (8852, '2012-04-29 12:27:40.447725+00', '2012-04-29 12:27:40.447735+00', 'Reels (simple)', 1502, 1, 6, 32, 9999, NULL, 228, 0, '');
INSERT INTO 'recording' VALUES (8856, '2012-04-29 13:00:07.610875+00', '2012-04-29 13:03:52.863864+00', 'Jigs (Pipe Tunes)', 1502, 2, 6, 32, 9999, NULL, 229, 0, '');
INSERT INTO 'recording' VALUES (8884, '2012-05-31 06:59:39.001949+00', '2012-05-31 06:59:39.001959+00', 'Sleepy Maggie', 10034, 1, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (8871, '2012-05-09 15:21:34.065514+00', '2012-06-04 23:59:00.861408+00', 'Ayrshire Craig', 1502, 1, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (8918, '2012-06-17 14:24:24.273817+00', '2012-06-17 14:25:49.958525+00', 'Ladies'' Fancy', 10000, 2, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (8932, '2012-10-18 13:02:18.662778+00', '2012-10-18 13:02:18.662788+00', 'Strathspey', 3678, 3, 3, 40, 9999, NULL, 238, 0, '');
INSERT INTO 'recording' VALUES (8933, '2012-12-25 22:26:15.102299+00', '2012-12-25 22:26:15.102309+00', 'Trip to the Drakensberg', 3658, 2, 2, 40, 9999, NULL, 91, 0, '');
INSERT INTO 'recording' VALUES (8942, '2012-12-27 11:05:32.996079+00', '2012-12-27 11:05:32.996089+00', 'March and Waltz', 903, 50, 0, 0, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (8943, '2012-12-27 11:14:10.201404+00', '2012-12-27 11:14:10.201414+00', 'Scotch Circle', 903, 1, 6, 32, 9999, NULL, 224, 0, '');
INSERT INTO 'recording' VALUES (8945, '2012-12-27 11:59:27.785213+00', '2012-12-27 11:59:27.785222+00', 'Cadgers in the Canongate', 903, 1, 8, 48, 9999, NULL, 411, 0, '');
INSERT INTO 'recording' VALUES (41, NULL, '2012-01-20 12:55:01.687219+00', 'Cadgers in the Canongate', 3018, 1, 8, 48, 9999, 4, 429, 0, '');
INSERT INTO 'recording' VALUES (42, NULL, '2012-01-20 12:55:01.692394+00', 'Caledonian Rant, The', 3001, 3, 8, 32, 9999, NULL, 459, 0, '');
INSERT INTO 'recording' VALUES (43, NULL, '2018-01-18 13:06:08.228154+00', 'Campbeltown Loch', 3007, 2, 4, 48, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (40, NULL, '2019-01-22 23:18:23.592318+00', 'Caddam Wood', 3007, 1, 5, 32, 9999, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (6, NULL, '2019-01-23 23:45:05.685009+00', 'Alltshellach', 3011, 3, 8, 32, 9999, NULL, 520, 0, '');
INSERT INTO 'recording' VALUES (3, NULL, '2019-06-18 08:33:59.827159+00', 'Train, Le', 3003, 98, 0, 0, 9999, NULL, 115, 0, '');
INSERT INTO 'recording' VALUES (44, NULL, '2012-01-20 12:55:01.7023+00', 'Canadian Barn Dance', 3037, 11, 0, 16, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (46, NULL, '2012-01-20 12:55:01.713225+00', 'Carl Cam O''er the Croft, The', 3002, 1, 8, 32, 9999, 5, 285, 0, '');
INSERT INTO 'recording' VALUES (47, NULL, '2012-01-20 12:55:01.718335+00', 'Castles in the Air', 3037, 5, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4837, NULL, '2022-08-20 23:09:30.79219+00', 'Jig', 3064, 2, 6, 32, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (4839, NULL, '2022-08-20 23:10:09.646935+00', 'Polka', 3064, 13, 0, 0, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (4841, NULL, '2022-08-20 23:11:48.637168+00', 'Reel', 3064, 1, 6, 32, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (4842, NULL, '2022-08-20 23:13:02.637311+00', 'Strathspey', 3064, 3, 2, 32, 9999, NULL, 121, 0, '');
INSERT INTO 'recording' VALUES (4843, NULL, '2022-08-20 23:13:38.085302+00', 'Jig', 3064, 2, 6, 32, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (4844, NULL, '2022-08-20 23:14:42.080518+00', 'Waltzes', 3064, 5, 0, 0, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (4845, NULL, '2022-08-20 23:15:39.888576+00', 'Barn Dance', 3064, 50, 0, 0, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (4846, NULL, '2022-08-20 23:17:39.32546+00', 'Set of Reels (Hamilton Rant)', 3064, 1, 6, 32, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (48, NULL, '2012-01-20 12:55:01.723135+00', 'Cauld Kail', 3012, 4, 8, 32, 1, NULL, 370, 0, '');
INSERT INTO 'recording' VALUES (49, NULL, '2012-01-20 12:55:01.728602+00', 'Cherrybank Gardens', 3013, 3, 3, 32, 9999, 5, 187, 0, '');
INSERT INTO 'recording' VALUES (50, NULL, '2012-01-20 12:55:01.734449+00', 'Circassian Circle', 3018, 1, 8, 32, 9999, 1, 273, 0, '');
INSERT INTO 'recording' VALUES (51, NULL, '2012-01-20 12:55:01.739299+00', 'Circle Waltz', 3062, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (52, NULL, '2012-01-20 12:55:01.74476+00', 'Clansman, The', 3022, 1, 8, 32, 9999, 1, 285, 0, '');
INSERT INTO 'recording' VALUES (53, NULL, '2012-01-20 12:55:01.750294+00', 'Clutha', 3026, 1, 4, 48, 9999, 4, 214, 0, '');
INSERT INTO 'recording' VALUES (54, NULL, '2012-01-20 12:55:01.755136+00', 'College Hornpipe, The', 3012, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (55, NULL, '2012-01-20 12:55:01.759929+00', 'Corstorphine Fair', 3007, 2, 4, 40, 9999, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (56, NULL, '2012-01-20 12:55:01.765395+00', 'Crown Court', 3009, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (58, NULL, '2012-01-20 12:55:01.775731+00', 'Dalkeith''s Strathspey', 3011, 3, 8, 32, 9999, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (59, NULL, '2012-01-20 12:55:01.781196+00', 'Dashing White Sergeant, The', 3018, 1, 6, 32, 9999, 1, 208, 0, '');
INSERT INTO 'recording' VALUES (60, NULL, '2012-01-20 12:55:01.786032+00', 'Dashing White Sergeant, The', 3008, 1, 5, 32, 9999, NULL, 159, 0, '');
INSERT INTO 'recording' VALUES (61, NULL, '2012-01-20 12:55:01.791552+00', 'Deil amang The Tailors, The', 3023, 1, 8, 32, 9999, 1, 291, 0, '');
INSERT INTO 'recording' VALUES (7779, NULL, '2018-03-23 01:32:20.775426+00', 'Come Ashore, Jolly Tar', 3006, 1, 8, 32, NULL, NULL, 284, 1, '');
INSERT INTO 'recording' VALUES (63, NULL, '2012-01-20 12:55:01.801197+00', 'Deuks Dang Ower my Daddie, The', 3012, 2, 8, 40, 9999, NULL, 340, 0, '');
INSERT INTO 'recording' VALUES (64, NULL, '2012-01-20 12:55:01.806672+00', 'Diamond Jubilee, The', 3026, 2, 4, 32, 9999, 1, 136, 0, '');
INSERT INTO 'recording' VALUES (65, NULL, '2012-01-20 12:55:01.81148+00', 'Donald Bane', 3064, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (66, NULL, '2012-01-20 12:55:01.81644+00', 'Donald Bane', 3001, 3, 8, 32, 9999, NULL, 468, 0, '');
INSERT INTO 'recording' VALUES (67, NULL, '2012-01-20 12:55:01.821273+00', 'Drumelzier', 3029, 3, 4, 32, 9999, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (68, NULL, '2012-01-20 12:55:01.826066+00', 'Drumelzier', 3014, 3, 4, 32, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (69, NULL, '2012-01-20 12:55:01.830905+00', 'Duchess Tree, The', 3011, 3, 8, 32, 9999, NULL, 561, 0, '');
INSERT INTO 'recording' VALUES (70, NULL, '2012-01-20 12:55:01.836396+00', 'Duke Of Atholl''s Reel, The', 3018, 2, 8, 32, 9999, 1, 275, 0, '');
INSERT INTO 'recording' VALUES (71, NULL, '2012-01-20 12:55:01.841911+00', 'Delvine Side', 3048, 3, 8, 32, 9999, 5, 506, 0, '');
INSERT INTO 'recording' VALUES (72, NULL, '2012-01-20 12:55:01.84673+00', 'Duke of Perth', 3018, 1, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (73, NULL, '2012-01-20 12:55:01.851516+00', 'Dunoon Barn Dance', 3001, 50, 16, 8, 9999, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (74, NULL, '2012-01-20 12:55:01.85631+00', 'Neidpath Castle', 2133, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (76, NULL, '2012-01-20 12:55:01.865912+00', 'Earl of Errol''s Reel, The', 3015, 2, 0, 200, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (77, NULL, '2012-01-20 12:55:01.871855+00', 'Earl of Mansfield, The', 3042, 1, 4, 48, 9999, 30, 205, 0, '');
INSERT INTO 'recording' VALUES (78, NULL, '2012-01-20 12:55:01.876761+00', 'Earl of Mansfield, The', 3006, 1, 4, 48, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (79, NULL, '2012-01-20 12:55:01.88236+00', 'Earlstoun Loch', 3009, 1, 5, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (80, NULL, '2012-01-20 12:55:01.887196+00', 'Eightsome Reel, The', 3051, 1, 0, 464, 9999, NULL, 489, 0, '');
INSERT INTO 'recording' VALUES (81, NULL, '2012-01-20 12:55:01.891976+00', 'Eightsome Reel/Sixteensome Reel', 3011, 1, 0, 464, 9999, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (3391, NULL, '2012-01-20 12:55:20.387152+00', 'Military Two Step', 2093, 11, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3392, NULL, '2012-01-20 12:55:20.393473+00', 'Tomtain Brae', 3046, 2, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (3393, NULL, '2012-01-20 12:55:20.399728+00', 'West''s Hornpipe', 3046, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (3394, NULL, '2012-01-20 12:55:20.405985+00', 'Cashmere Shawl, The', 3046, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (3395, NULL, '2012-01-20 12:55:20.412225+00', 'Jennifer''s Jig', 3046, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (3396, NULL, '2012-01-20 12:55:20.418457+00', 'Polharrow Burn', 3046, 1, 5, 32, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (3397, NULL, '2012-01-20 12:55:20.424683+00', 'Hermitage Castle', 3046, 2, 4, 48, 9999, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (3398, NULL, '2012-01-20 12:55:20.430956+00', 'Blooms Of Bon Accord', 3046, 1, 4, 32, 9999, NULL, 150, 1, '');
INSERT INTO 'recording' VALUES (3399, NULL, '2012-01-20 12:55:20.437242+00', 'New Scotland Strathspey, The', 3046, 3, 4, 40, 9999, NULL, 313, 0, '');
INSERT INTO 'recording' VALUES (3400, NULL, '2012-01-20 12:55:20.443512+00', 'MacDonald Of Sleat', 3046, 2, 0, 120, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (3401, NULL, '2012-01-20 12:55:20.449977+00', 'Fisherman''s Reel', 3046, 1, 5, 32, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (3402, NULL, '2012-01-20 12:55:20.456262+00', 'Luckenbooth Brooch, The', 3046, 2, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (3403, NULL, '2012-01-20 12:55:20.462558+00', 'Mairi''s Wedding', 3046, 1, 8, 40, 9999, NULL, 363, 0, '');
INSERT INTO 'recording' VALUES (3404, NULL, '2012-01-20 12:55:20.467924+00', 'Foursome Reel', 3068, 4, 0, 132, NULL, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (3405, NULL, '2012-01-20 12:55:20.475007+00', 'Eightsome Reel, The', 2233, 1, 1, 464, 9999, NULL, 433, 0, '');
INSERT INTO 'recording' VALUES (3406, NULL, '2012-01-20 12:55:20.481251+00', 'Reel of the 51st Division, The', 2233, 1, 10, 32, 9999, NULL, 314, 0, '');
INSERT INTO 'recording' VALUES (3407, NULL, '2012-01-20 12:55:20.487524+00', 'Duke of Perth', 2233, 1, 10, 32, 9999, NULL, 315, 0, '');
INSERT INTO 'recording' VALUES (3408, NULL, '2012-01-20 12:55:20.493768+00', 'Hamilton House', 2233, 2, 10, 32, 9999, NULL, 313, 0, '');
INSERT INTO 'recording' VALUES (3409, NULL, '2012-01-20 12:55:20.500009+00', 'Waltz Country Dance', 2233, 5, 0, 40, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (8848, '2012-02-28 14:33:52.012868+00', '2012-02-28 14:33:52.012878+00', 'Miss Milligan''s Strathspey', 903, 3, 8, 32, 9999, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (8853, '2012-04-29 12:31:47.54598+00', '2012-04-29 12:31:47.54599+00', 'Jigs', 1502, 2, 6, 32, 9999, NULL, 231, 0, '');
INSERT INTO 'recording' VALUES (8934, '2012-12-25 22:30:20.884863+00', '2012-12-25 22:30:20.884874+00', 'General Stuart''s Reel', 3658, 1, 2, 32, 9999, NULL, 79, 0, '');
INSERT INTO 'recording' VALUES (8885, '2012-05-31 07:05:23.188827+00', '2012-05-31 07:05:23.188837+00', 'Wild Geese, The', 10034, 2, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (8872, '2012-05-09 15:29:05.462838+00', '2012-06-04 23:51:17.308838+00', 'Mrs Jappy''s Measure', 1502, 3, 8, 32, 9999, NULL, 532, 0, '');
INSERT INTO 'recording' VALUES (8857, '2012-04-29 13:10:25.731773+00', '2012-06-05 00:36:11.790506+00', 'Strathspeys (Airs)', 1502, 3, 6, 32, 9999, NULL, 407, 0, '');
INSERT INTO 'recording' VALUES (8919, '2012-06-17 14:28:55.591418+00', '2012-06-17 14:29:40.246975+00', 'Swiss Lassie', 10000, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (8944, '2012-12-27 11:17:00.410725+00', '2012-12-27 11:17:00.410734+00', 'Hooper''s Jig', 903, 2, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (8946, '2012-12-27 12:03:39.822232+00', '2012-12-27 12:03:39.822241+00', 'Jubilee Jig', 903, 2, 8, 32, 9999, NULL, 302, 0, '');
INSERT INTO 'recording' VALUES (8948, '2012-12-27 12:17:12.632094+00', '2012-12-27 12:17:12.632104+00', 'Lady Susan Stewart''s Reel', 903, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (82, NULL, '2012-01-20 12:55:01.897419+00', 'Ellie''s Jig', 3017, 2, 8, 32, 9999, 1, 284, 0, '');
INSERT INTO 'recording' VALUES (84, NULL, '2012-01-20 12:55:01.908493+00', 'Espie McNabb', 3002, 2, 8, 32, 9999, 1, 284, 0, '');
INSERT INTO 'recording' VALUES (86, NULL, '2012-01-20 12:55:01.918785+00', 'Lament for Janet', 3003, 98, 0, 0, 9999, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (88, NULL, '2012-01-20 12:55:01.92901+00', 'Flowers of Edinburgh, The', 3018, 1, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (90, NULL, '2012-01-20 12:55:01.939585+00', 'Foursome and Half Reel of Tulloch', 3018, 4, 0, 128, 9999, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (91, NULL, '2012-01-20 12:55:01.945111+00', 'Frog In The Middle', 3002, 2, 8, 32, 9999, 5, 276, 0, '');
INSERT INTO 'recording' VALUES (93, NULL, '2012-01-20 12:55:01.955443+00', 'Galloway House', 3010, 1, 8, 32, 9999, 1, 267, 0, '');
INSERT INTO 'recording' VALUES (94, NULL, '2012-01-20 12:55:01.960258+00', 'Galloway House', 3001, 1, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (87, NULL, '2014-07-25 15:16:01.434342+00', 'Fight About the Fireside', 3029, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (85, NULL, '2014-08-21 06:39:58.465066+00', 'Fair Donald', 3018, 3, 8, 32, 9999, 5, 492, 0, '');
INSERT INTO 'recording' VALUES (83, NULL, '2019-01-13 11:55:10.795933+00', 'Espie McNabb', 3017, 2, 8, 32, 9999, 1, 287, 0, '');
INSERT INTO 'recording' VALUES (45, NULL, '2019-01-23 18:02:20.606938+00', 'Captain Mackintosh', 3002, 1, 8, 40, 9999, 17, 351, 0, '');
INSERT INTO 'recording' VALUES (57, NULL, '2019-10-03 18:35:28.541803+00', 'Cumbrae Reel, The', 3025, 1, 8, 32, 9999, 5, 278, 0, '');
INSERT INTO 'recording' VALUES (96, NULL, '2012-01-20 12:55:01.969882+00', 'Garry Strathspey, The', 3012, 3, 4, 32, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (98, NULL, '2012-01-20 12:55:01.98027+00', 'Gay Gordons', 3010, 11, 0, 16, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (99, NULL, '2012-01-20 12:55:01.985087+00', 'Gay Gordons', 3014, 11, 0, 16, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (100, NULL, '2012-01-20 12:55:01.990565+00', 'Gay Gordons', 3001, 11, 8, 16, 9999, 1, 161, 0, '');
INSERT INTO 'recording' VALUES (101, NULL, '2012-01-20 12:55:01.995378+00', 'Gay Gordons', 3059, 11, 0, 16, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (102, NULL, '2012-01-20 12:55:02.000164+00', 'Gay Gordons', 3061, 11, 10, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (103, NULL, '2012-01-20 12:55:02.005625+00', 'General Stuart''s Reel', 3018, 1, 8, 32, 9999, 5, 280, 0, '');
INSERT INTO 'recording' VALUES (104, NULL, '2012-01-20 12:55:02.011135+00', 'Gentle Shepherd, The', 3022, 2, 4, 32, 9999, 5, 172, 0, '');
INSERT INTO 'recording' VALUES (105, NULL, '2012-01-20 12:55:02.016636+00', 'Gentleman, The', 3009, 3, 8, 32, 9999, 5, 512, 0, '');
INSERT INTO 'recording' VALUES (106, NULL, '2012-01-20 12:55:02.022158+00', 'Glasgow Highlanders, The', 3018, 3, 8, 32, 9999, 5, 470, 1, '');
INSERT INTO 'recording' VALUES (107, NULL, '2012-01-20 12:55:02.027661+00', 'Galloway Tale, A', 2029, 1, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (108, NULL, '2012-01-20 12:55:02.032475+00', 'Glayva', 3008, 2, 8, 32, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (109, NULL, '2012-01-20 12:55:02.037262+00', 'Golden Pheasant, The', 3007, 2, 8, 40, 9999, NULL, 340, 0, '');
INSERT INTO 'recording' VALUES (111, NULL, '2012-01-20 12:55:02.047623+00', 'Grand March', 3055, 11, 0, 0, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (112, NULL, '2012-01-20 12:55:02.053086+00', 'Guidman Of Balangigh, The', 3018, 2, 8, 32, 9999, 1, 265, 0, '');
INSERT INTO 'recording' VALUES (115, NULL, '2012-01-20 12:55:02.06897+00', 'Happy Meeting, The', 3029, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (117, NULL, '2012-01-20 12:55:02.079919+00', 'Haughs O'' Cromdale', 3011, 3, 8, 16, 9999, 23, 247, 0, '');
INSERT INTO 'recording' VALUES (118, NULL, '2012-01-20 12:55:02.084726+00', 'Hebridean Waltz', 3054, 5, 0, 0, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (119, NULL, '2012-01-20 12:55:02.089511+00', 'Hebridean Weaving Lilt', 3015, 3, 0, 88, 9999, NULL, 225, 0, '');
INSERT INTO 'recording' VALUES (121, NULL, '2012-01-20 12:55:02.099484+00', 'Highland Schottische', 3010, 3, 0, 16, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (122, NULL, '2012-01-20 12:55:02.104281+00', 'Highland Schottische', 3001, 3, 0, 8, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (3410, NULL, '2012-01-20 12:55:20.50626+00', 'Mairi''s Wedding', 1557, 1, 10, 40, 9999, NULL, 410, 0, '');
INSERT INTO 'recording' VALUES (3411, NULL, '2012-01-20 12:55:20.512534+00', 'Postie''s Jig', 1557, 2, 4, 32, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (3412, NULL, '2012-01-20 12:55:20.519112+00', 'Postie''s Jig', 1557, 2, 4, 32, 9999, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (3413, NULL, '2012-01-20 12:55:20.525381+00', 'Machine Without Horses', 1557, 2, 10, 32, 9999, NULL, 334, 0, '');
INSERT INTO 'recording' VALUES (3414, NULL, '2012-01-20 12:55:20.531623+00', 'Petronella', 1557, 1, 10, 32, 9999, NULL, 329, 0, '');
INSERT INTO 'recording' VALUES (3415, NULL, '2012-01-20 12:55:20.537845+00', 'Gay Gordons', 1557, 11, 0, 16, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (3416, NULL, '2012-01-20 12:55:20.544123+00', 'Gay Gordons', 1557, 11, 0, 16, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (3417, NULL, '2012-01-20 12:55:20.550366+00', 'Strip the Willow', 1557, 2, 8, 32, 9999, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (3418, NULL, '2012-01-20 12:55:20.556599+00', 'Strip the Willow', 1557, 2, 10, 32, 9999, NULL, 304, 0, '');
INSERT INTO 'recording' VALUES (3419, NULL, '2012-01-20 12:55:20.562877+00', 'Duke and Duchess of Edinburgh, The', 1557, 1, 10, 40, 9999, NULL, 397, 0, '');
INSERT INTO 'recording' VALUES (3420, NULL, '2012-01-20 12:55:20.569216+00', 'John Peel', 1557, 99, 0, 0, 9999, NULL, 70, 0, '');
INSERT INTO 'recording' VALUES (3421, NULL, '2012-01-20 12:55:20.576137+00', 'National Anthem, The', 1557, 98, 0, 0, 9999, NULL, 39, 0, '');
INSERT INTO 'recording' VALUES (3422, NULL, '2012-01-20 12:55:20.582465+00', 'Dunfermline Glen', 3002, 3, 6, 32, 9999, NULL, 392, 0, '');
INSERT INTO 'recording' VALUES (3423, NULL, '2012-01-20 12:55:20.588943+00', 'Dancing Man, The', 3002, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (3424, NULL, '2012-01-20 12:55:20.595769+00', 'Rover''s Rant, The', 3002, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (3425, NULL, '2012-01-20 12:55:20.602023+00', 'Unicef Circle, The', 3002, 1, 0, 88, 9999, NULL, 100, 0, '');
INSERT INTO 'recording' VALUES (3426, NULL, '2012-01-20 12:55:20.608279+00', 'Hope Little''s Strathspey', 3002, 3, 3, 32, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (3428, NULL, '2012-01-20 12:55:20.62089+00', 'Well''s House', 3002, 3, 8, 32, 9999, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (3429, NULL, '2012-01-20 12:55:20.627264+00', 'Society Piper', 3002, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (8854, '2012-04-29 12:37:36.93548+00', '2012-04-29 12:41:14.669517+00', 'Strathspeys (Trad)', 1502, 3, 6, 32, 9999, NULL, 418, 0, '');
INSERT INTO 'recording' VALUES (8858, '2012-04-29 13:15:29.216252+00', '2012-04-29 13:17:19.810714+00', 'Reels (Hornpipes)', 1502, 1, 6, 32, 9999, NULL, 225, 0, '');
INSERT INTO 'recording' VALUES (8873, '2012-05-09 15:31:58.544154+00', '2012-05-09 15:31:58.544164+00', 'Denise''s Delight', 1502, 2, 4, 32, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (8886, '2012-05-31 07:12:11.614613+00', '2012-05-31 07:12:11.614623+00', '12 Coates Crescent', 10034, 3, 4, 32, 9999, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (8920, '2012-06-17 14:37:54.485042+00', '2012-06-17 14:37:54.485051+00', 'Glasgow Highlanders, The', 10000, 3, 5, 32, NULL, 5, 319, 1, '');
INSERT INTO 'recording' VALUES (8935, '2012-12-25 22:33:05.276516+00', '2012-12-25 22:33:05.276526+00', '12 Coates Crescent', 3658, 3, 1, 32, 9999, NULL, 70, 0, '');
INSERT INTO 'recording' VALUES (8949, '2012-12-27 12:20:10.607346+00', '2012-12-27 12:20:10.607356+00', 'Waltz', 903, 5, 0, 0, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (8953, '2012-12-27 13:12:56.004052+00', '2012-12-27 13:12:56.004062+00', 'Peat Fire Flame', 903, 1, 8, 40, 9999, NULL, 353, 0, '');
INSERT INTO 'recording' VALUES (8955, '2012-12-27 20:13:19.483312+00', '2012-12-27 20:13:19.483321+00', 'Fair Jenny''s Jig', 903, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (8961, '2012-12-27 21:00:18.467353+00', '2012-12-27 21:00:18.467362+00', 'Machine Without Horses, The', 903, 2, 8, 32, 9999, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (8974, '2012-12-28 13:35:18.126414+00', '2012-12-28 13:35:18.126425+00', 'Two Step', 10679, 11, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (8980, '2012-12-28 14:16:27.113392+00', '2012-12-28 14:16:27.113403+00', '2/4 Marches', 10679, 11, 4, 32, 9999, NULL, 224, 0, '');
INSERT INTO 'recording' VALUES (123, NULL, '2012-01-20 12:55:02.109759+00', 'Alloway Kirk Rant', 2029, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (124, NULL, '2012-01-20 12:55:02.114668+00', 'Hollin Buss, The', 3001, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (125, NULL, '2012-01-20 12:55:02.119465+00', 'Hoop Her And Gird Her', 3057, 1, 6, 32, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (126, NULL, '2012-01-20 12:55:02.124255+00', 'Hooper''s Jig', 3010, 2, 8, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (127, NULL, '2012-01-20 12:55:02.129049+00', 'Ian Powrie''s Farewell to Auchterarder', 3012, 2, 0, 128, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (128, NULL, '2012-01-20 12:55:02.134777+00', 'Inverary', 3002, 3, 8, 32, 9999, 5, 510, 0, '');
INSERT INTO 'recording' VALUES (129, NULL, '2012-01-20 12:55:02.139592+00', 'Inverness Country Dance', 3001, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (130, NULL, '2012-01-20 12:55:02.144803+00', 'Irish Rover, The', 3008, 1, 8, 32, 9999, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (131, NULL, '2012-01-20 12:55:02.149677+00', 'Irish Two Step', 3010, 50, 0, 0, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (134, NULL, '2012-01-20 12:55:02.164045+00', 'Jessie''s Hornpipe', 3001, 1, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (135, NULL, '2012-01-20 12:55:02.16885+00', 'Findhorn Medley', 3040, 4, 0, 96, 21, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (136, NULL, '2012-01-20 12:55:02.175404+00', 'Jimmy''s Fancy', 3021, 3, 8, 32, 9999, 5, 496, 0, '');
INSERT INTO 'recording' VALUES (137, NULL, '2012-01-20 12:55:02.180846+00', 'John McAlpin', 3007, 3, 8, 32, 9999, NULL, 461, 0, '');
INSERT INTO 'recording' VALUES (138, NULL, '2012-01-20 12:55:02.186233+00', 'John McAlpin', 3014, 3, 8, 32, 9999, NULL, 518, 0, '');
INSERT INTO 'recording' VALUES (133, NULL, '2019-01-23 18:07:31.505447+00', 'Jeannie o'' the Witchin'' E''e', 3015, 2, 8, 40, 9999, NULL, 375, 0, '');
INSERT INTO 'recording' VALUES (113, NULL, '2014-06-28 07:18:24.228221+00', 'Hamilton House', 3020, 2, 8, 32, 9999, 5, 272, 0, '');
INSERT INTO 'recording' VALUES (114, NULL, '2014-08-21 06:41:56.864575+00', 'Happy Meeting, The', 3018, 2, 8, 32, 9999, 1, 268, 0, '');
INSERT INTO 'recording' VALUES (120, NULL, '2014-09-16 11:31:41.408259+00', 'Thistle Welcome', 2188, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (139, NULL, '2012-01-20 12:55:02.192287+00', 'John of Bon Accord', 3019, 1, 8, 32, 9999, 1, 275, 0, '');
INSERT INTO 'recording' VALUES (140, NULL, '2012-01-20 12:55:02.197798+00', 'Johnnie Walker', 3013, 4, 0, 128, 13, 1, 193, 0, '');
INSERT INTO 'recording' VALUES (141, NULL, '2012-01-20 12:55:02.202618+00', 'Johnnie Walker', 3008, 4, 0, 128, 13, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (143, NULL, '2012-01-20 12:55:02.212282+00', 'Jubilee Jig, The', 3029, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (144, NULL, '2012-01-20 12:55:02.217096+00', 'Kelvingrove', 3015, 3, 0, 152, 9999, NULL, 311, 0, '');
INSERT INTO 'recording' VALUES (145, NULL, '2012-01-20 12:55:02.22212+00', 'Killarney Waltz', 3010, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (147, NULL, '2012-01-20 12:55:02.23305+00', 'Kiss under the Stairs', 3002, 2, 8, 32, 9999, 1, 284, 0, '');
INSERT INTO 'recording' VALUES (148, NULL, '2012-01-20 12:55:02.238571+00', 'Flora, La', 3024, 2, 8, 32, 9999, 1, 265, 0, '');
INSERT INTO 'recording' VALUES (149, NULL, '2012-01-20 12:55:02.244055+00', 'Tempête, La', 3018, 1, 4, 48, 9999, 22, 202, 0, '');
INSERT INTO 'recording' VALUES (150, NULL, '2012-01-20 12:55:02.249556+00', 'Ladies Of Dingwall, The', 3002, 1, 8, 48, 9999, 4, 422, 0, '');
INSERT INTO 'recording' VALUES (152, NULL, '2012-01-20 12:55:02.259912+00', 'Ladies'' Fancy', 3018, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (153, NULL, '2012-01-20 12:55:02.265402+00', 'Ladies'' Fancy', 3001, 2, 8, 32, 9999, 1, 280, 0, '');
INSERT INTO 'recording' VALUES (154, NULL, '2012-01-20 12:55:02.27095+00', 'Lads Of Saltcoats, The', 3002, 1, 8, 32, 9999, 5, 286, 0, '');
INSERT INTO 'recording' VALUES (8954, '2012-12-27 13:26:36.049464+00', '2022-12-14 13:27:11.01797+00', 'Birks of Invermay, The', 903, 3, 8, 32, 9999, NULL, 532, 0, '');
INSERT INTO 'recording' VALUES (8962, '2012-12-28 10:23:52.75835+00', '2023-01-12 22:30:45.352333+00', 'Sugar Candie', 903, 3, 8, 32, 9999, NULL, 518, 0, '');
INSERT INTO 'recording' VALUES (3427, NULL, '2023-02-26 18:37:51.579467+00', 'Dalesman, The', 3002, 1, 8, 40, 9999, NULL, 351, 0, '');
INSERT INTO 'recording' VALUES (156, NULL, '2012-01-20 12:55:02.281318+00', 'Lady Sophia Anne Of Bute', 3029, 1, 4, 48, 9999, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (157, NULL, '2012-01-20 12:55:02.286812+00', 'Lady Susan Stewart''s Reel', 3019, 1, 8, 32, 9999, 5, 278, 0, '');
INSERT INTO 'recording' VALUES (158, NULL, '2012-01-20 12:55:02.291692+00', 'Laird o'' Dochart''s Reel', 3015, 2, 0, 80, 9999, NULL, 99, 0, '');
INSERT INTO 'recording' VALUES (159, NULL, '2012-01-20 12:55:02.296512+00', 'Lamb Skinnet', 3010, 2, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (160, NULL, '2012-01-20 12:55:02.301304+00', 'Lamont of Inveryne', 3015, 1, 0, 208, 9999, NULL, 237, 0, '');
INSERT INTO 'recording' VALUES (161, NULL, '2012-01-20 12:55:02.306835+00', 'Largo Law', 3002, 3, 8, 32, 9999, 5, 504, 0, '');
INSERT INTO 'recording' VALUES (162, NULL, '2012-01-20 12:55:02.312396+00', 'Lassies O'' Melrose, The', 3001, 2, 8, 32, 9999, 1, 268, 0, '');
INSERT INTO 'recording' VALUES (163, NULL, '2012-01-20 12:55:02.317216+00', 'Last Of The Lairds, The', 3001, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (3430, NULL, '2012-01-20 12:55:20.633573+00', 'Tae Fife and Back', 3002, 2, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (3431, NULL, '2012-01-20 12:55:20.639847+00', 'West End', 3002, 3, 6, 32, 9999, NULL, 390, 0, '');
INSERT INTO 'recording' VALUES (3433, NULL, '2012-01-20 12:55:20.65234+00', 'Tom''s Friends', 3002, 3, 3, 32, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (3434, NULL, '2012-01-20 12:55:20.658604+00', 'Happy Dancers, The', 3002, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (3435, NULL, '2012-01-20 12:55:20.664814+00', 'Haste Ye Back', 3002, 1, 0, 88, 9999, NULL, 101, 0, '');
INSERT INTO 'recording' VALUES (3436, NULL, '2012-01-20 12:55:20.671052+00', 'Maxwell''s Rant', 2236, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (3438, NULL, '2012-01-20 12:55:20.683596+00', 'Miss Milligan''s Strathspey', 2236, 3, 8, 32, 9999, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (3439, NULL, '2012-01-20 12:55:20.689834+00', 'General Stuart''s Reel', 2236, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (3440, NULL, '2012-01-20 12:55:20.696264+00', 'Follow Me Home', 2236, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (142, NULL, '2018-03-02 23:06:36.949466+00', 'Joe''s Reel', 2566, 1, 5, 32, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (3442, NULL, '2012-01-20 12:55:20.709076+00', 'Triumph, The', 2236, 1, 4, 24, 9999, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (3443, NULL, '2012-01-20 12:55:20.715353+00', 'Eightsome Reel, The', 2236, 1, 0, 464, 9999, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (3444, NULL, '2012-01-20 12:55:20.72159+00', 'Round Reel of Eight', 2236, 1, 0, 88, 9999, NULL, 103, 0, '');
INSERT INTO 'recording' VALUES (3446, NULL, '2012-01-20 12:55:20.734109+00', 'Monymusk', 2236, 3, 8, 32, 9999, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (3447, NULL, '2012-01-20 12:55:20.740325+00', 'Mrs Stewart of Fasnacloich', 2236, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (3449, NULL, '2012-01-20 12:55:20.752908+00', 'Balmoral Strathspey', 2236, 3, 4, 32, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (8850, '2012-02-28 14:44:52.828643+00', '2012-02-28 14:44:52.828653+00', 'MacDonald of the Isles', 903, 3, 3, 32, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (8855, '2012-04-29 12:45:26.515878+00', '2012-04-29 12:51:02.108242+00', 'Reels', 1502, 1, 6, 32, 9999, NULL, 227, 0, '');
INSERT INTO 'recording' VALUES (8859, '2012-04-29 13:22:04.90937+00', '2012-04-29 13:22:04.90938+00', 'Jigs', 1502, 2, 6, 32, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (8950, '2012-12-27 12:36:03.150245+00', '2012-12-27 12:36:03.150255+00', 'Ye''re Welcome, Charly Stuart', 903, 1, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (8874, '2012-05-09 15:34:47.968183+00', '2012-05-09 15:37:02.163306+00', 'Paris Celebration Medley, The', 1502, 4, 5, 64, 5, NULL, 528, 0, '');
INSERT INTO 'recording' VALUES (8887, '2012-05-31 07:18:14.947317+00', '2012-05-31 07:18:14.947326+00', 'Cati Ramsay', 10034, 1, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (8921, '2012-06-17 14:40:18.402419+00', '2012-06-17 14:40:18.402429+00', 'Scott Meikle', 10000, 1, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (8936, '2012-12-25 22:36:04.825914+00', '2012-12-25 22:36:04.825924+00', 'Miss Hadden''s Reel', 3658, 2, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (8956, '2012-12-27 20:16:53.336322+00', '2012-12-27 20:16:53.336332+00', 'Robertson Rant, The', 903, 3, 1, 80, 9999, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (8963, '2012-12-28 10:28:34.319568+00', '2012-12-28 10:28:34.319578+00', 'McLaughlin''s Reel', 903, 1, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (8975, '2012-12-28 13:44:50.205072+00', '2012-12-28 13:44:50.205082+00', '4/4 March', 10679, 11, 5, 32, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (8981, '2012-12-28 14:21:21.605134+00', '2012-12-28 14:21:21.605144+00', 'Waltzes', 10679, 5, 0, 0, 9999, NULL, 310, 0, '');
INSERT INTO 'recording' VALUES (8991, '2012-12-28 15:24:51.891611+00', '2012-12-28 15:24:51.891622+00', 'Millennium March', 2583, 11, 4, 32, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (164, NULL, '2012-01-20 12:55:02.322737+00', 'Leith Country Dance', 3001, 2, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (166, NULL, '2012-01-20 12:55:02.33337+00', 'Light and Airy', 3017, 2, 8, 32, 9999, 5, 285, 0, '');
INSERT INTO 'recording' VALUES (167, NULL, '2012-01-20 12:55:02.338956+00', 'Light and Airy', 3011, 2, 8, 32, 9999, 5, 280, 0, '');
INSERT INTO 'recording' VALUES (168, NULL, '2012-01-20 12:55:02.344463+00', 'Linton Ploughman, The', 3010, 2, 8, 32, 9999, 1, 256, 0, '');
INSERT INTO 'recording' VALUES (169, NULL, '2012-01-20 12:55:02.349955+00', 'Linton Ploughman, The', 3019, 2, 8, 32, 9999, 1, 271, 0, '');
INSERT INTO 'recording' VALUES (170, NULL, '2012-01-20 12:55:02.355459+00', 'Weel Danced, Lucky Hare', 2029, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (171, NULL, '2012-01-20 12:55:02.360284+00', 'Lochanside', 3015, 5, 0, 72, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (173, NULL, '2012-01-20 12:55:02.37056+00', 'Longwise Eightsome Reel', 3051, 4, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (174, NULL, '2012-01-20 12:55:02.376049+00', 'Lothian Lads', 3040, 1, 8, 32, 9999, 1, 271, 0, '');
INSERT INTO 'recording' VALUES (175, NULL, '2012-01-20 12:55:02.380862+00', 'Luckenbooth Brooch, The', 3008, 2, 8, 32, 9999, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (176, NULL, '2012-01-20 12:55:02.385732+00', 'Luckenbooth Brooch, The', 3014, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (177, NULL, '2012-01-20 12:55:02.391212+00', 'Lucy Campbell', 3022, 1, 8, 32, 9999, 5, 287, 0, '');
INSERT INTO 'recording' VALUES (178, NULL, '2012-01-20 12:55:02.396075+00', 'MacDonald Of Sleat', 3006, 2, 0, 120, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (179, NULL, '2012-01-20 12:55:02.400876+00', 'MacDonald of Sleat', 3015, 2, 0, 120, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (180, NULL, '2012-01-20 12:55:02.406554+00', 'Macdonald of the Isles', 3009, 3, 3, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (181, NULL, '2012-01-20 12:55:02.412063+00', 'Machine Without Horses, The', 3023, 2, 8, 32, 9999, 1, 284, 0, '');
INSERT INTO 'recording' VALUES (183, NULL, '2012-01-20 12:55:02.421737+00', 'Macleod of Harris', 3015, 1, 0, 144, 9999, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (184, NULL, '2012-01-20 12:55:02.42722+00', 'MacLeod''s Fancy', 3019, 2, 4, 32, 9999, 1, 143, 0, '');
INSERT INTO 'recording' VALUES (185, NULL, '2012-01-20 12:55:02.432052+00', 'MacLeod''s Fancy', 3014, 2, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (3445, NULL, '2014-08-30 23:14:35.046317+00', 'MacLeod''s Fancy', 2236, 2, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (146, NULL, '2014-09-16 11:32:22.790439+00', 'Lucy Helen''s Strathspey', 2188, 3, 3, 32, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (155, NULL, '2014-10-30 07:20:36.137626+00', 'Lady Home''s Jig', 3002, 2, 8, 32, 9999, 1, 276, 0, '');
INSERT INTO 'recording' VALUES (186, NULL, '2012-01-20 12:55:02.437572+00', 'Madge Wildfire''s Strathspey', 3018, 3, 8, 32, 9999, 5, 504, 0, '');
INSERT INTO 'recording' VALUES (188, NULL, '2012-01-20 12:55:02.447863+00', 'Major Ian Stewart', 3009, 2, 8, 32, 9999, 1, 287, 0, '');
INSERT INTO 'recording' VALUES (189, NULL, '2012-01-20 12:55:02.452672+00', 'Major Ian Stewart', 3014, 2, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (190, NULL, '2012-01-20 12:55:02.45752+00', 'March Selection', 3051, 11, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3437, NULL, '2017-03-10 21:46:52.039051+00', 'Mrs Stewart''s Jig', 2236, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (165, NULL, '2019-01-23 16:59:10.293499+00', 'Lerwick Reel, The', 3015, 3, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3448, NULL, '2019-09-23 20:26:32.050031+00', 'Tribute to the Borders', 2236, 2, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (191, NULL, '2012-01-20 12:55:02.462313+00', 'Marches', 3063, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (192, NULL, '2012-01-20 12:55:02.467103+00', 'Marching with Jimmy Shand', 3010, 11, 0, 0, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (193, NULL, '2012-01-20 12:55:02.472587+00', 'Margaret Parker''s Strathspey', 3026, 3, 8, 32, 9999, 5, 484, 0, '');
INSERT INTO 'recording' VALUES (194, NULL, '2012-01-20 12:55:02.477417+00', 'Maxwell''s Rant', 3023, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (195, NULL, '2012-01-20 12:55:02.48221+00', 'McLaine of Lochbuie', 3015, 1, 0, 176, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (196, NULL, '2012-01-20 12:55:02.487004+00', 'McNeill of Barra', 3015, 4, 0, 144, 18, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (3432, NULL, '2020-06-05 17:16:15.339572+00', 'Clatterin'' Brig', 3002, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (151, NULL, '2021-06-13 09:54:20.905675+00', 'Ladies of Dunse, The', 3009, 1, 8, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (198, NULL, '2012-01-20 12:55:02.496615+00', 'Medley', 3003, 4, 0, 128, 2, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (199, NULL, '2012-01-20 12:55:02.501411+00', 'Meg Merrilees', 3007, 1, 8, 24, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (201, NULL, '2012-01-20 12:55:02.511704+00', 'Middleton Medley, The', 3062, 4, 8, 32, 8, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (202, NULL, '2012-01-20 12:55:02.517205+00', 'Middling, Thank You', 3021, 2, 8, 40, 9999, 9, 340, 0, '');
INSERT INTO 'recording' VALUES (200, NULL, '2022-09-30 20:12:14.290288+00', 'Merry Dancers, The', 3011, 2, 8, 32, 9999, 1, 277, 0, '');
INSERT INTO 'recording' VALUES (197, NULL, '2022-12-26 12:40:06.203119+00', 'McNichol of the Black Isle', 3015, 1, 0, 104, 9999, NULL, 121, 0, '');
INSERT INTO 'recording' VALUES (203, NULL, '2012-01-20 12:55:02.522071+00', 'Midnight Oil', 3008, 2, 5, 48, 9999, NULL, 238, 0, '');
INSERT INTO 'recording' VALUES (3450, NULL, '2012-01-20 12:55:20.759165+00', 'Montgomeries'' Rant, The', 2236, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (3451, NULL, '2012-01-20 12:55:20.765442+00', 'Auld Alliance, The', 3050, 1, 4, 32, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (3452, NULL, '2012-01-20 12:55:20.77169+00', 'Alltshellach', 3050, 3, 8, 32, 9999, NULL, 525, 0, '');
INSERT INTO 'recording' VALUES (3453, NULL, '2012-01-20 12:55:20.777943+00', 'Glens of Angus, The', 3050, 1, 4, 32, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (3454, NULL, '2012-01-20 12:55:20.784181+00', 'Dean Bridge of Edinburgh, The', 3050, 3, 8, 32, 9999, NULL, 513, 0, '');
INSERT INTO 'recording' VALUES (3455, NULL, '2012-01-20 12:55:20.790555+00', 'Miss Hadden''s Reel', 3050, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (3456, NULL, '2012-01-20 12:55:20.796853+00', 'Glasgow Country Dance', 3050, 4, 8, 32, 1, NULL, 387, 0, '');
INSERT INTO 'recording' VALUES (3457, NULL, '2012-01-20 12:55:20.803133+00', 'Reivers, The', 3050, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (3458, NULL, '2012-01-20 12:55:20.809365+00', 'Swilcan, The', 3050, 2, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (3459, NULL, '2012-01-20 12:55:20.815609+00', 'Mrs Hamilton of Wishaw', 3050, 3, 8, 32, 9999, NULL, 501, 0, '');
INSERT INTO 'recording' VALUES (3460, NULL, '2012-01-20 12:55:20.821859+00', 'Rudha Dubh', 3050, 1, 8, 48, 9999, NULL, 428, 0, '');
INSERT INTO 'recording' VALUES (3461, NULL, '2012-01-20 12:55:20.828105+00', 'Starry Eyed Lassie, The', 3050, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (3463, NULL, '2012-01-20 12:55:20.840589+00', 'Scotch Circle, The', 3002, 1, 5, 32, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (3464, NULL, '2012-01-20 12:55:20.846931+00', 'Balquidder Strathspey', 3002, 3, 8, 32, 9999, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (3465, NULL, '2012-01-20 12:55:20.853154+00', 'Wild Geese, The', 3002, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (3466, NULL, '2012-01-20 12:55:20.859413+00', 'Sailor, The', 3002, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (3468, NULL, '2012-01-20 12:55:20.872357+00', 'Oh, Whistle and I''ll Come tae Ye, My Lad', 3002, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (3469, NULL, '2012-01-20 12:55:20.878629+00', 'I Canna Buckle To', 3002, 3, 8, 32, 9999, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (8851, '2012-02-28 14:50:42.827527+00', '2012-02-28 14:50:42.827536+00', 'Sleepy Maggie', 903, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (8860, '2012-04-29 13:27:23.582842+00', '2012-04-29 13:27:23.582852+00', 'Strathspeys (Trad)', 1502, 3, 6, 32, 9999, NULL, 410, 0, '');
INSERT INTO 'recording' VALUES (8922, '2012-06-17 14:42:07.872091+00', '2012-06-17 14:42:07.872101+00', 'Waltz for Atsuko and Bill', 10000, 5, 0, 0, NULL, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (8937, '2012-12-25 22:40:13.594186+00', '2012-12-25 22:40:13.594196+00', 'Lady Susan Stewart''s Reel', 3658, 1, 2, 32, 9999, NULL, 78, 0, '');
INSERT INTO 'recording' VALUES (8951, '2012-12-27 12:40:59.402598+00', '2012-12-27 12:40:59.402608+00', 'Balquidder Strathspey', 903, 3, 8, 32, 9999, NULL, 529, 0, '');
INSERT INTO 'recording' VALUES (8957, '2012-12-27 20:20:01.4697+00', '2012-12-27 20:20:01.46971+00', 'Wicked Willy', 903, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (8964, '2012-12-28 10:31:53.046839+00', '2012-12-28 10:31:53.046849+00', 'Luckenbooth Brooch, The', 903, 2, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (8976, '2012-12-28 13:47:37.145485+00', '2012-12-28 13:47:37.145496+00', 'Waltz', 10679, 5, 0, 0, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (8982, '2012-12-28 14:24:50.652845+00', '2012-12-28 14:24:50.652856+00', '6/8 Maches', 10679, 11, 4, 32, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (8992, '2012-12-28 15:30:31.098854+00', '2012-12-28 15:30:31.098865+00', 'Postie''s Jig', 2583, 2, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (9011, '2012-12-28 18:18:35.731521+00', '2012-12-28 18:18:35.731531+00', 'Highland Fling 4 SOBHD', 10687, 7, 4, 8, 9999, NULL, 84, 0, '');
INSERT INTO 'recording' VALUES (9010, '2012-12-28 18:08:12.954264+00', '2012-12-28 18:22:08.302018+00', 'Highland Fling 4 Junior', 10687, 7, 4, 8, 9999, NULL, 80, 0, '');
INSERT INTO 'recording' VALUES (9012, '2012-12-28 18:29:40.969107+00', '2012-12-28 18:29:40.969117+00', 'Highland Fling 6 SOBHD', 10687, 7, 6, 8, 9999, NULL, 117, 0, '');
INSERT INTO 'recording' VALUES (9020, '2012-12-31 15:11:37.422692+00', '2012-12-31 15:11:37.422702+00', 'Royal Patron, The', 2944, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (9021, '2012-12-31 15:18:27.986925+00', '2012-12-31 15:18:27.986935+00', 'Castle of Mey, The', 2944, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (204, NULL, '2012-01-20 12:55:02.526875+00', 'Military Two Step', 3009, 11, 10, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (205, NULL, '2012-01-20 12:55:02.531994+00', 'Irish Military Two-Step', 3052, 50, 0, 16, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (208, NULL, '2012-01-20 12:55:02.547875+00', 'Miss Allie Anderson', 3011, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (209, NULL, '2012-01-20 12:55:02.552679+00', 'Reverend Mr Frog', 2468, 4, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (210, NULL, '2012-01-20 12:55:02.557463+00', 'Miss Fiona Macrae of Conchra', 3015, 3, 0, 64, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (211, NULL, '2012-01-20 12:55:02.562953+00', 'Miss Gibson''s Strathspey', 3042, 3, 8, 32, 9999, 5, 505, 0, '');
INSERT INTO 'recording' VALUES (212, NULL, '2012-01-20 12:55:02.567777+00', 'Miss Gibson''s Strathspey', 3006, 3, 8, 32, 9999, NULL, 481, 0, '');
INSERT INTO 'recording' VALUES (213, NULL, '2012-01-20 12:55:02.57327+00', 'Miss Hadden''s Reel', 3018, 2, 8, 32, 9999, 1, 265, 0, '');
INSERT INTO 'recording' VALUES (214, NULL, '2012-01-20 12:55:02.578769+00', 'Miss Margaret Hill', 3002, 2, 8, 32, 9999, 1, 288, 0, '');
INSERT INTO 'recording' VALUES (215, NULL, '2012-01-20 12:55:02.584279+00', 'Miss Mary Douglas', 3020, 2, 8, 48, 9999, 25, 412, 0, '');
INSERT INTO 'recording' VALUES (216, NULL, '2012-01-20 12:55:02.589842+00', 'Miss Milligan''s Strathspey', 3018, 3, 8, 32, 9999, 5, 483, 0, '');
INSERT INTO 'recording' VALUES (217, NULL, '2012-01-20 12:55:02.595356+00', 'Moffat Weavers, The', 3013, 2, 4, 32, 9999, 1, 143, 0, '');
INSERT INTO 'recording' VALUES (218, NULL, '2012-01-20 12:55:02.600863+00', 'Montgomeries'' Rant, The', 3020, 1, 8, 32, 9999, 5, 277, 0, '');
INSERT INTO 'recording' VALUES (219, NULL, '2012-01-20 12:55:02.606368+00', 'Montgomery''s Rant', 3001, 1, 8, 32, 9999, 5, 273, 0, '');
INSERT INTO 'recording' VALUES (221, NULL, '2012-01-20 12:55:02.616685+00', 'Monymusk', 3008, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (222, NULL, '2012-01-20 12:55:02.6215+00', 'Moray House Of Edinburgh, The', 3011, 2, 4, 48, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (223, NULL, '2012-01-20 12:55:02.626298+00', 'Moulin Dhu', 3015, 3, 0, 120, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (224, NULL, '2012-01-20 12:55:02.631748+00', 'Mr Wilson''s Hornpipe', 3018, 1, 8, 32, 9999, 1, 282, 0, '');
INSERT INTO 'recording' VALUES (225, NULL, '2012-01-20 12:55:02.636578+00', 'Mrs Cholmondeley''s Reel', 3010, 1, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (227, NULL, '2012-01-20 12:55:02.646856+00', 'Mrs Stewart of Fasnacloich', 3018, 1, 8, 32, 9999, 5, 282, 0, '');
INSERT INTO 'recording' VALUES (228, NULL, '2012-01-20 12:55:02.652342+00', 'Mrs Stewart''s Jig', 3009, 2, 8, 32, 9999, 1, 280, 0, '');
INSERT INTO 'recording' VALUES (229, NULL, '2012-01-20 12:55:02.657155+00', 'Muirland Willie', 3007, 2, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (231, NULL, '2012-01-20 12:55:02.667454+00', 'Neidpath Castle', 3010, 3, 3, 32, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (232, NULL, '2012-01-20 12:55:02.672256+00', 'Neidpath Castle', 3012, 3, 3, 32, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (3467, NULL, '2015-06-27 06:34:47.179325+00', 'Saint Andrew''s Day', 3002, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (8875, '2012-05-09 15:39:14.995746+00', '2017-08-18 22:33:13.556784+00', 'Paris Celebration Medley, The', 1502, 4, 3, 64, 5, NULL, 325, 0, '');
INSERT INTO 'recording' VALUES (10230, '2018-09-15 09:56:40.139168+00', '2018-11-06 21:54:11.239531+00', 'Stretching Slow Waltz', 10659, 5, 4, 16, NULL, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (226, NULL, '2019-01-23 18:34:08.678936+00', 'Mrs Hepburn Belches of Invermay', 3006, 1, 8, 48, 9999, NULL, 405, 0, '');
INSERT INTO 'recording' VALUES (233, NULL, '2012-01-20 12:55:02.677048+00', 'New Park', 3028, 3, 8, 32, 9999, NULL, 500, 0, '');
INSERT INTO 'recording' VALUES (234, NULL, '2012-01-20 12:55:02.682566+00', 'New Petronella, The', 3025, 1, 2, 48, 9999, 4, 108, 0, '');
INSERT INTO 'recording' VALUES (235, NULL, '2012-01-20 12:55:02.688054+00', 'Witches'' Score, The', 2029, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (236, NULL, '2012-01-20 12:55:02.692853+00', 'None So Pretty', 3028, 1, 8, 40, 9999, NULL, 345, 0, '');
INSERT INTO 'recording' VALUES (237, NULL, '2012-01-20 12:55:02.697643+00', 'None So Pretty', 3011, 1, 8, 40, 9999, NULL, 343, 0, '');
INSERT INTO 'recording' VALUES (238, NULL, '2012-01-20 12:55:02.702458+00', 'Nor'' Loch, The', 3006, 4, 0, 96, 11, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (239, NULL, '2012-01-20 12:55:02.707265+00', 'Northern Lights of Aberdeen', 3010, 5, 0, 0, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (240, NULL, '2012-01-20 12:55:02.712739+00', 'Cumberland Square', 2029, 1, 2, 64, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (3494, NULL, '2012-01-20 12:55:21.036207+00', 'Highland Cathedral', 3003, 98, 0, 0, 9999, NULL, 233, 0, '');
INSERT INTO 'recording' VALUES (220, NULL, '2020-02-24 22:14:04.249964+00', 'Circassian Circle', 3026, 1, 5, 32, 9999, 1, 178, 0, '');
INSERT INTO 'recording' VALUES (241, NULL, '2012-01-20 12:55:02.718221+00', 'Nottingham Lace', 3011, 1, 0, 96, 9999, 4, 106, 0, 'Phrasing unsutiable for dance (which requires 4 ABB sequences).');
INSERT INTO 'recording' VALUES (243, NULL, '2018-03-02 23:07:22.035855+00', 'Annan Gold', 2566, 3, 3, 32, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (3470, NULL, '2012-01-20 12:55:20.885311+00', 'Hollin Buss, The', 3002, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (3472, NULL, '2012-01-20 12:55:20.898181+00', 'Campbells Are Coming, The', 3002, 2, 5, 32, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (3473, NULL, '2012-01-20 12:55:20.904421+00', 'Adieu Mon Ami', 3002, 3, 8, 32, 9999, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (3474, NULL, '2012-01-20 12:55:20.910668+00', 'Mairrit Man''s Favourite, The', 3002, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (207, NULL, '2023-01-27 19:13:46.231066+00', 'Milton''s Welcome', 3019, 1, 8, 32, 9999, 1, 282, 0, '');
INSERT INTO 'recording' VALUES (3475, NULL, '2012-01-20 12:55:20.91735+00', 'New Biggin', 3071, 2, 8, 48, 9999, NULL, 413, 0, '');
INSERT INTO 'recording' VALUES (3476, NULL, '2012-01-20 12:55:20.92361+00', 'Old Way of Killiecrankie, The', 3071, 1, 3, 48, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (3477, NULL, '2012-01-20 12:55:20.929859+00', 'Lady Susan Montgomery', 3071, 3, 8, 40, 9999, NULL, 611, 0, '');
INSERT INTO 'recording' VALUES (3478, NULL, '2012-01-20 12:55:20.936144+00', 'Periwig, The', 3071, 1, 4, 48, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (3479, NULL, '2012-01-20 12:55:20.942394+00', 'Colonel, The', 3071, 2, 8, 40, 9999, NULL, 344, 0, '');
INSERT INTO 'recording' VALUES (3480, NULL, '2012-01-20 12:55:20.948627+00', 'Kelloholm Jig, The', 3071, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (3481, NULL, '2012-01-20 12:55:20.954861+00', 'Mrs Milne of Kinneff', 3071, 3, 4, 32, 9999, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (3482, NULL, '2012-01-20 12:55:20.961084+00', 'Broadford Bay', 3071, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (3485, NULL, '2012-01-20 12:55:20.979811+00', 'Mrs Garthland''s Strathspey', 3071, 3, 8, 32, 9999, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (3486, NULL, '2012-01-20 12:55:20.986068+00', 'West''s Hornpipe', 3071, 1, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (3487, NULL, '2012-01-20 12:55:20.992403+00', 'Fyket, The', 3071, 2, 8, 40, 9999, NULL, 340, 0, '');
INSERT INTO 'recording' VALUES (3488, NULL, '2012-01-20 12:55:20.99865+00', 'Sow''s Tail, The', 3071, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (3489, NULL, '2012-01-20 12:55:21.004875+00', 'Jig to Start, A', 3003, 2, 8, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (8861, '2012-04-29 13:41:33.158051+00', '2012-04-29 14:35:38.854656+00', 'Jigs (Simple)', 1502, 2, 6, 24, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (8876, '2012-05-09 15:42:48.063416+00', '2012-05-09 15:42:48.063426+00', 'Fran''s Fancy', 1502, 3, 4, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (8889, '2012-05-31 07:30:59.981922+00', '2012-05-31 07:30:59.981932+00', 'Miss Milligan''s Strathspey', 10034, 3, 8, 32, 9999, NULL, 507, 0, '');
INSERT INTO 'recording' VALUES (8923, '2012-06-17 14:44:35.925947+00', '2012-06-17 14:49:52.829293+00', 'Machine Without Horses, The', 10000, 2, 8, 32, NULL, 1, 286, 0, '');
INSERT INTO 'recording' VALUES (8938, '2012-12-25 22:43:23.373048+00', '2012-12-25 22:43:23.373058+00', 'Miss Gibson''s Strathspey', 3658, 3, 2, 32, 9999, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (8952, '2012-12-27 12:50:50.61039+00', '2012-12-27 12:50:50.6104+00', 'Nurseryman, The', 903, 2, 8, 32, 9999, NULL, 301, 0, '');
INSERT INTO 'recording' VALUES (8958, '2012-12-27 20:24:36.297324+00', '2012-12-27 20:24:36.297335+00', 'Duke of Atholl''s Reel, The', 903, 2, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (8965, '2012-12-28 10:38:31.163309+00', '2012-12-28 10:38:31.163319+00', 'Monymusk', 903, 3, 8, 32, 9999, NULL, 517, 0, '');
INSERT INTO 'recording' VALUES (8977, '2012-12-28 14:00:01.929345+00', '2012-12-28 14:00:01.929355+00', 'Jigs', 10679, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (8983, '2012-12-28 14:31:12.042839+00', '2012-12-28 14:31:12.042849+00', 'Shetland Reels', 10679, 1, 6, 32, 9999, NULL, 226, 0, '');
INSERT INTO 'recording' VALUES (8993, '2012-12-28 15:35:59.582954+00', '2012-12-28 15:35:59.582965+00', 'New Killarney Waltz', 2583, 5, 0, 0, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (9013, '2012-12-28 18:31:22.620203+00', '2012-12-28 18:31:22.620213+00', 'Highland Fling 6 Adult', 10687, 7, 6, 8, 9999, NULL, 122, 0, '');
INSERT INTO 'recording' VALUES (9026, '2012-12-31 16:00:46.871359+00', '2012-12-31 16:00:46.871369+00', 'Perth 800', 2944, 1, 4, 32, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (244, NULL, '2012-01-20 12:55:02.733548+00', 'Over the Dee and Over the Don', 3015, 2, 0, 152, 9999, NULL, 234, 0, '');
INSERT INTO 'recording' VALUES (245, NULL, '2012-01-20 12:55:02.738441+00', 'Palais Glide, The', 3037, 50, 0, 0, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (246, NULL, '2012-01-20 12:55:02.743256+00', 'Para Handy', 3064, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (247, NULL, '2012-01-20 12:55:02.748191+00', 'Peat Fire Flame, The', 3012, 1, 8, 40, 9999, NULL, 347, 0, '');
INSERT INTO 'recording' VALUES (248, NULL, '2012-01-20 12:55:02.753002+00', 'Peerie, The', 3012, 2, 4, 32, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (249, NULL, '2012-01-20 12:55:02.758467+00', 'Waverley', 3048, 2, 8, 48, 9999, 11, 416, 0, '');
INSERT INTO 'recording' VALUES (250, NULL, '2012-01-20 12:55:02.764001+00', 'Peggy''s Love', 3009, 3, 8, 32, 9999, 5, 465, 0, '');
INSERT INTO 'recording' VALUES (251, NULL, '2012-01-20 12:55:02.769497+00', 'Peggy''s Wedding', 3009, 2, 4, 64, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (252, NULL, '2012-01-20 12:55:02.774298+00', 'Carolynn''s Waltz', 3048, 5, 0, 0, 9999, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (253, NULL, '2012-01-20 12:55:02.779086+00', 'Petronella', 3006, 1, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (255, NULL, '2012-01-20 12:55:02.789031+00', 'Plantation Reel, The', 3006, 1, 5, 32, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (256, NULL, '2012-01-20 12:55:02.793834+00', 'Polharrow Burn', 3008, 1, 5, 32, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (257, NULL, '2012-01-20 12:55:02.799303+00', 'Polka Country Dance', 3026, 13, 8, 32, 9999, 1, 287, 1, '');
INSERT INTO 'recording' VALUES (258, NULL, '2012-01-20 12:55:02.804803+00', 'Porchester Hall', 3009, 3, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (260, NULL, '2012-01-20 12:55:02.814427+00', 'Postie''s Jig', 3011, 2, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (261, NULL, '2012-01-20 12:55:02.819256+00', 'Pretty Ladies', 3006, 3, 0, 80, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (262, NULL, '2012-01-20 12:55:02.824104+00', 'Pride of Erin Waltz', 2328, 5, 0, 16, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (264, NULL, '2012-01-20 12:55:02.833786+00', 'Quarries'' Jig', 3014, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (265, NULL, '2012-01-20 12:55:02.838618+00', 'Queen Victoria''s Visit Quadrilles', 3028, 10, 5, 40, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (267, NULL, '2012-01-20 12:55:02.848915+00', 'Reel of the 51st Division, The', 3018, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (268, NULL, '2012-01-20 12:55:02.854374+00', 'Reel of the Royal Scots, The', 3017, 1, 8, 32, 9999, 5, 291, 0, '');
INSERT INTO 'recording' VALUES (269, NULL, '2012-01-20 12:55:02.859183+00', 'Reel of the Royal Scots, The', 3014, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (270, NULL, '2012-01-20 12:55:02.86397+00', 'Reel of the Royal Scots, The', 3012, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (271, NULL, '2012-01-20 12:55:02.868771+00', 'Rest And Be Thankful', 3007, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (272, NULL, '2012-01-20 12:55:02.874054+00', 'Reverend John Macfarlane, The', 3014, 1, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (273, NULL, '2012-01-20 12:55:02.878869+00', 'Robertson Rant, The', 3009, 3, 0, 80, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (274, NULL, '2012-01-20 12:55:02.88434+00', 'J.B. Milne', 3048, 1, 8, 32, 9999, 10, 277, 0, '');
INSERT INTO 'recording' VALUES (275, NULL, '2012-01-20 12:55:02.889163+00', 'Rothesay at the Fair', 3015, 1, 0, 240, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (276, NULL, '2012-01-20 12:55:02.893965+00', 'Rothesay Rant, The', 3029, 2, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (277, NULL, '2012-01-20 12:55:02.898745+00', 'Rouken Glen', 3015, 3, 0, 72, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (278, NULL, '2012-01-20 12:55:02.903536+00', 'Round Reel Of Eight', 3024, 1, 0, 88, 9999, NULL, 100, 0, '');
INSERT INTO 'recording' VALUES (266, NULL, '2017-03-24 16:06:00.288191+00', 'Red House', 3020, 1, 8, 40, 9999, 31, 338, 0, '');
INSERT INTO 'recording' VALUES (9022, '2012-12-31 15:24:55.380952+00', '2017-03-28 21:58:14.419623+00', 'Mist O''er the Loch', 2944, 3, 8, 32, 9999, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (3483, NULL, '2019-09-28 23:30:56.901161+00', 'Georgie''s Jig', 3071, 2, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (279, NULL, '2012-01-20 12:55:02.90834+00', 'Royal Salute, The', 3015, 1, 0, 112, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (280, NULL, '2012-01-20 12:55:02.913134+00', 'Royal Scots Polka', 3010, 13, 0, 0, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (281, NULL, '2012-01-20 12:55:02.919164+00', 'Sailor, The', 3009, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (283, NULL, '2012-01-20 12:55:02.928807+00', 'Saint Andrew''s Fair', 3006, 2, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (284, NULL, '2012-01-20 12:55:02.933937+00', 'Saint Andrew''s Nicht', 3015, 2, 4, 48, 9999, NULL, 222, 0, '');
INSERT INTO 'recording' VALUES (3490, NULL, '2012-01-20 12:55:21.011121+00', 'Rickety', 3003, 1, 4, 48, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (3491, NULL, '2012-01-20 12:55:21.017389+00', 'Strathspey', 3003, 3, 4, 32, 9999, NULL, 234, 0, '');
INSERT INTO 'recording' VALUES (3493, NULL, '2012-01-20 12:55:21.029971+00', 'Continental Capers', 3003, 1, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (3471, NULL, '2021-07-05 07:37:06.049661+00', 'Duke He was a Bonnie Beau, The', 3002, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (8905, '2012-06-12 14:44:46.820804+00', '2020-01-25 23:38:33.510778+00', 'Ladies of Berkeau, The', 3012, 3, 8, 32, NULL, NULL, 447, 0, '');
INSERT INTO 'recording' VALUES (3484, NULL, '2021-08-22 10:28:52.572884+00', 'Haymaking', 3071, 1, 8, 40, 9999, NULL, 340, 0, '');
INSERT INTO 'recording' VALUES (3496, NULL, '2012-01-20 12:55:21.048715+00', 'Over the Pond 1', 3003, 1, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (3497, NULL, '2012-01-20 12:55:21.054948+00', 'Strathspey', 3003, 3, 3, 32, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (3498, NULL, '2012-01-20 12:55:21.06118+00', 'Scottish Jigs', 3003, 2, 4, 40, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (3500, NULL, '2012-01-20 12:55:21.073652+00', 'Irish Air', 3003, 50, 0, 0, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (3502, NULL, '2012-01-20 12:55:21.156812+00', 'Dinkie''s', 3003, 1, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (3503, NULL, '2012-01-20 12:55:21.161877+00', 'Medley', 3003, 4, 0, 128, 13, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (3505, NULL, '2012-01-20 12:55:21.171562+00', 'Bluebell Polka', 3046, 13, 0, 16, 9999, NULL, 115, 0, '');
INSERT INTO 'recording' VALUES (3506, NULL, '2012-01-20 12:55:21.176348+00', 'Boston Two Step', 3046, 50, 0, 16, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (259, NULL, '2022-07-24 17:49:50.202919+00', 'Britannia Two-Step', 3049, 11, 8, 16, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (3507, NULL, '2012-01-20 12:55:21.181271+00', 'Britannia Two Step', 3046, 50, 0, 16, 9999, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (3508, NULL, '2012-01-20 12:55:21.186333+00', 'Canadian Barn Dance', 3046, 11, 0, 16, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (3509, NULL, '2012-01-20 12:55:21.191344+00', 'Circle Waltz', 3046, 5, 0, 32, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (3510, NULL, '2012-01-20 12:55:21.196966+00', 'Elephant Walk', 3046, 50, 0, 8, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (3511, NULL, '2012-01-20 12:55:21.201988+00', 'Eva Three Step', 3046, 11, 0, 16, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (3512, NULL, '2012-01-20 12:55:21.206794+00', 'Friendly Waltz', 3046, 5, 0, 16, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (3513, NULL, '2012-01-20 12:55:21.211578+00', 'Gay Gordons', 3046, 11, 0, 16, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (3514, NULL, '2012-01-20 12:55:21.216375+00', 'Hesitation Waltz', 3046, 5, 0, 16, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (3515, NULL, '2012-01-20 12:55:21.221446+00', 'Highland Schottische', 3046, 3, 0, 8, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (8862, '2012-04-29 13:45:54.668675+00', '2012-04-29 14:33:16.3296+00', 'Reels (Simple)', 1502, 1, 3, 24, 9999, NULL, 94, 0, '');
INSERT INTO 'recording' VALUES (8877, '2012-05-09 15:45:36.445437+00', '2012-05-09 15:46:05.084197+00', 'Twelfth Night Revels', 1502, 2, 8, 40, 9999, NULL, 353, 0, '');
INSERT INTO 'recording' VALUES (8890, '2012-05-31 07:35:14.391589+00', '2012-05-31 07:35:14.391599+00', 'Kandahar Reel, The', 10034, 1, 5, 32, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (8924, '2012-06-17 14:49:02.837086+00', '2012-06-17 14:49:02.837095+00', 'Montgomeries'' Rant, The', 10000, 1, 8, 32, NULL, 5, 285, 0, '');
INSERT INTO 'recording' VALUES (8939, '2012-12-25 22:46:05.025996+00', '2012-12-25 22:46:05.026008+00', 'Joie de Vivre', 3658, 2, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (8966, '2012-12-28 10:44:08.692272+00', '2012-12-28 10:44:08.692281+00', 'Bonnie Anne', 903, 2, 1, 96, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (8978, '2012-12-28 14:02:53.899299+00', '2012-12-28 14:02:53.89931+00', 'Reels', 10679, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (8984, '2012-12-28 14:34:50.198968+00', '2012-12-28 14:34:50.198979+00', 'Polka', 10679, 13, 4, 32, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (8994, '2012-12-28 16:06:58.884034+00', '2012-12-28 16:06:58.884044+00', 'Highland Schottische', 2583, 3, 10, 8, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (9014, '2012-12-28 18:34:37.066079+00', '2012-12-28 18:34:37.066089+00', 'Highland Fling Marathon 16 SOBHD', 10687, 7, 16, 8, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9023, '2012-12-31 15:31:51.642903+00', '2012-12-31 15:31:51.642913+00', 'Rodney''s Rant', 2944, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (285, NULL, '2012-01-20 12:55:02.939413+00', 'Saltire Society Reel, The', 3018, 1, 8, 32, 9999, 1, 286, 0, '');
INSERT INTO 'recording' VALUES (286, NULL, '2012-01-20 12:55:02.944963+00', 'Sandy O''er The Lea', 3002, 3, 6, 32, 9999, 5, 383, 0, '');
INSERT INTO 'recording' VALUES (287, NULL, '2012-01-20 12:55:02.949832+00', 'Schiehallion', 3011, 4, 0, 128, 2, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (288, NULL, '2012-01-20 12:55:02.95466+00', 'Schiehallion', 3014, 4, 0, 128, 2, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (289, NULL, '2012-01-20 12:55:02.960106+00', 'Scotland''s Gardens', 3013, 1, 8, 32, 9999, 1, 283, 0, '');
INSERT INTO 'recording' VALUES (290, NULL, '2012-01-20 12:55:02.965611+00', 'Scottish Reform', 3018, 2, 8, 32, 9999, 1, 273, 0, '');
INSERT INTO 'recording' VALUES (291, NULL, '2012-01-20 12:55:02.970488+00', 'Scottish Waltz', 3009, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (292, NULL, '2012-01-20 12:55:02.975322+00', 'Scottish Waltz', 3001, 5, 0, 0, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (293, NULL, '2012-01-20 12:55:02.980775+00', 'Seann Triubhas Willichan', 3017, 3, 8, 32, 9999, 5, 495, 0, '');
INSERT INTO 'recording' VALUES (294, NULL, '2012-01-20 12:55:02.986398+00', 'Seann Triubhas Willichan', 3024, 3, 4, 32, 9999, 5, 270, 0, '');
INSERT INTO 'recording' VALUES (295, NULL, '2012-01-20 12:55:02.991264+00', 'Irish Singalong Jigs', 3003, 2, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (296, NULL, '2012-01-20 12:55:02.996062+00', 'Set of Jigs - Irish', 3052, 2, 4, 32, 9999, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (297, NULL, '2012-01-20 12:55:03.000855+00', 'Pipe Jigs', 3003, 2, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (300, NULL, '2012-01-20 12:55:03.015944+00', 'Scottish Jigs', 3003, 2, 8, 48, 9999, NULL, 398, 0, '');
INSERT INTO 'recording' VALUES (301, NULL, '2012-01-20 12:55:03.020722+00', 'In Reel Time', 3009, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (302, NULL, '2012-01-20 12:55:03.025557+00', 'Set of Reels', 3014, 1, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (303, NULL, '2012-01-20 12:55:03.030682+00', 'Scottish Reels', 3003, 1, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (304, NULL, '2012-01-20 12:55:03.035535+00', 'Scottish Reels', 3003, 1, 4, 40, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (305, NULL, '2012-01-20 12:55:03.040381+00', 'Set of Reels', 3001, 1, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (306, NULL, '2012-01-20 12:55:03.045187+00', 'Set of Reels', 3014, 1, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (308, NULL, '2012-01-20 12:55:03.054787+00', 'Set of Reels - North American', 3003, 1, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (309, NULL, '2012-01-20 12:55:03.059578+00', 'Set of Strathspeys', 3014, 3, 3, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (310, NULL, '2012-01-20 12:55:03.064357+00', 'Slow Air Strathspeys', 3003, 3, 4, 32, 9999, NULL, 239, 0, '');
INSERT INTO 'recording' VALUES (312, NULL, '2012-01-20 12:55:03.075401+00', 'Seton''s Ceilidh Band', 3013, 2, 4, 64, 9999, 10, 272, 0, '');
INSERT INTO 'recording' VALUES (313, NULL, '2012-01-20 12:55:03.080258+00', 'Seton''s Ceilidh Band', 3029, 2, 4, 64, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (314, NULL, '2012-01-20 12:55:03.085339+00', 'Shepherd''s Crook, The', 3015, 3, 0, 72, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (315, NULL, '2012-01-20 12:55:03.09083+00', 'Shiftin'' Bobbins', 3013, 1, 8, 32, 9999, 1, 282, 0, '');
INSERT INTO 'recording' VALUES (316, NULL, '2012-01-20 12:55:03.095653+00', 'Shiftin'' Bobbins', 3006, 1, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (3501, NULL, '2014-10-28 07:56:26.127892+00', 'Over the Pond 2', 3003, 2, 8, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (318, NULL, '2012-01-20 12:55:03.105902+00', 'Shuttle Bus, The', 3017, 2, 8, 32, 9999, 1, 282, 0, '');
INSERT INTO 'recording' VALUES (319, NULL, '2012-01-20 12:55:03.111382+00', 'Silver Tassie, The', 3018, 3, 8, 32, 9999, 5, 486, 0, '');
INSERT INTO 'recording' VALUES (320, NULL, '2012-01-20 12:55:03.11666+00', 'Silver Tassie, The', 3008, 3, 8, 32, 9999, NULL, 507, 0, '');
INSERT INTO 'recording' VALUES (321, NULL, '2012-01-20 12:55:03.122163+00', 'Brisk Young Lad, The', 3026, 2, 5, 48, 9999, 4, 255, 0, '');
INSERT INTO 'recording' VALUES (8906, '2012-06-12 14:55:44.827519+00', '2019-01-05 12:26:30.019103+00', 'Ocean Voyage', 3012, 1, 5, 32, NULL, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (317, NULL, '2019-01-23 00:14:33.412447+00', 'Ship O'' Grace', 3007, 3, 4, 40, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (3504, NULL, '2019-07-24 21:49:53.819944+00', 'Final Fling', 3003, 1, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (3495, NULL, '2019-08-07 10:08:33.922799+00', 'O''Neill''s 48''s', 3003, 2, 4, 48, 9999, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (324, NULL, '2012-01-20 12:55:03.138226+00', 'Sound Of Harris, The', 3007, 1, 8, 48, 9999, NULL, 417, 0, '');
INSERT INTO 'recording' VALUES (325, NULL, '2012-01-20 12:55:03.143223+00', 'St Bernard''s Waltz', 3037, 5, 0, 0, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (3516, NULL, '2012-01-20 12:55:21.226257+00', 'Kelvingrove Two Step', 3046, 50, 0, 16, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (3517, NULL, '2012-01-20 12:55:21.231192+00', 'Lambeth Walk', 3046, 50, 0, 16, 9999, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (3518, NULL, '2012-01-20 12:55:21.236004+00', 'Lomond Waltz', 3046, 5, 0, 32, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (3519, NULL, '2012-01-20 12:55:21.240888+00', 'Military Two-Step', 3046, 11, 0, 16, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (3520, NULL, '2012-01-20 12:55:21.245691+00', 'Mississippi Dip', 3046, 50, 0, 16, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (3521, NULL, '2012-01-20 12:55:21.250486+00', 'Palais Glide', 3046, 50, 0, 0, 9999, NULL, 83, 0, '');
INSERT INTO 'recording' VALUES (3522, NULL, '2012-01-20 12:55:21.256416+00', 'Pride of Erin Waltz', 3046, 5, 0, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (3523, NULL, '2012-01-20 12:55:21.262699+00', 'Saint Bernard''s Waltz', 3046, 5, 0, 16, 9999, NULL, 226, 0, '');
INSERT INTO 'recording' VALUES (3524, NULL, '2012-01-20 12:55:21.268937+00', 'Sheena''s Saunter', 3046, 11, 0, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (3492, NULL, '2020-03-12 00:06:14.005607+00', 'Songs Without Words', 3003, 2, 4, 32, 9999, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (3499, NULL, '2021-07-03 09:16:26.134405+00', 'Take Five', 3003, 1, 5, 32, 9999, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (299, NULL, '2021-08-16 10:26:23.990629+00', 'North American Jigs', 3003, 2, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (3525, NULL, '2012-01-20 12:55:21.275082+00', 'Stern Polka', 3046, 13, 0, 48, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (3526, NULL, '2012-01-20 12:55:21.280085+00', 'Suzuki Circle, The', 3046, 1, 0, 40, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (3527, NULL, '2012-01-20 12:55:21.284893+00', 'Swedish Masquerade', 3046, 4, 0, 48, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (3528, NULL, '2012-01-20 12:55:21.289697+00', 'Va, La', 3046, 99, 0, 0, 9999, NULL, 116, 0, '');
INSERT INTO 'recording' VALUES (3529, NULL, '2012-01-20 12:55:21.294508+00', 'Virginia Reel', 3046, 50, 4, 40, 9999, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (3530, NULL, '2012-01-20 12:55:21.299289+00', 'Dunnet Head', 3046, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (3531, NULL, '2012-01-20 12:55:21.304071+00', 'Auld Lang Syne', 3046, 98, 0, 0, 9999, NULL, 87, 0, '');
INSERT INTO 'recording' VALUES (3532, NULL, '2012-01-20 12:55:21.308904+00', 'Dashing White Sergeant, The', 3046, 1, 6, 32, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (3533, NULL, '2012-01-20 12:55:21.313701+00', 'Eightsome Reel, The', 3046, 1, 0, 464, 9999, NULL, 510, 0, '');
INSERT INTO 'recording' VALUES (8959, '2012-12-27 20:27:48.827599+00', '2023-01-12 22:31:22.498843+00', 'Dalkeith''s Strathspey', 903, 3, 8, 32, 9999, NULL, 514, 0, '');
INSERT INTO 'recording' VALUES (323, NULL, '2023-01-20 22:13:49.553696+00', 'Solway Reel, The', 3013, 1, 4, 48, 9999, 11, 214, 0, '');
INSERT INTO 'recording' VALUES (3534, NULL, '2012-01-20 12:55:21.317827+00', 'Foursome Reel, The', 3046, 4, 0, 128, NULL, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (3535, NULL, '2012-01-20 12:55:21.322595+00', 'Hamilton House', 3046, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (8863, '2012-04-29 13:50:12.416567+00', '2012-04-29 13:50:12.416576+00', 'Strathspeys (Song Style Tunes)', 1502, 3, 3, 32, 9999, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (8878, '2012-05-09 15:48:29.626109+00', '2012-05-09 15:49:13.253032+00', 'Buckie Loon, The', 1502, 1, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (8891, '2012-05-31 07:40:54.950543+00', '2012-05-31 07:40:54.950553+00', 'Joie de Vivre', 10034, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (8925, '2012-06-17 14:52:46.955937+00', '2012-06-17 14:52:46.955946+00', 'Abbot of Unreason, The', 10000, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (8960, '2012-12-27 20:32:45.328887+00', '2012-12-27 20:32:45.328897+00', 'Niel Gow''s Lament for the Death of his Second Wife', 903, 98, 0, 0, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (8967, '2012-12-28 10:49:20.942223+00', '2012-12-28 10:49:20.942236+00', 'Braes of Breadalbane, The', 903, 3, 8, 32, 9999, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (8979, '2012-12-28 14:10:52.016458+00', '2012-12-28 14:10:52.016468+00', 'Fiddle Selection', 10679, 98, 1, 0, 9999, NULL, 247, 0, '');
INSERT INTO 'recording' VALUES (8985, '2012-12-28 14:40:29.986571+00', '2012-12-28 14:40:29.986581+00', 'Foxtrot', 10679, 50, 0, 0, 9999, NULL, 358, 0, '');
INSERT INTO 'recording' VALUES (8995, '2012-12-28 16:11:49.926192+00', '2012-12-28 16:11:49.926202+00', 'Flowers of Edinburgh', 2583, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (9015, '2012-12-28 18:36:12.695591+00', '2012-12-28 18:36:12.695602+00', 'Highland Fling Marathon 16 Adult', 10687, 7, 16, 8, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (326, NULL, '2012-01-20 12:55:03.148909+00', 'St. Columba''s Strathspey', 3013, 3, 5, 32, 9999, 5, 314, 0, '');
INSERT INTO 'recording' VALUES (329, NULL, '2012-01-20 12:55:03.163423+00', 'Strip the Willow (6/8)', 3061, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (330, NULL, '2012-01-20 12:55:03.168228+00', 'Strip the Willow', 3037, 2, 4, 40, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (331, NULL, '2012-01-20 12:55:03.173701+00', 'Sugar Candie', 3018, 3, 8, 32, 9999, 5, 480, 0, '');
INSERT INTO 'recording' VALUES (332, NULL, '2012-01-20 12:55:03.178571+00', 'Sugar Candie', 3012, 3, 8, 32, 9999, NULL, 469, 0, '');
INSERT INTO 'recording' VALUES (333, NULL, '2012-01-20 12:55:03.184227+00', 'Summer Assembly, The', 3009, 1, 0, 88, 9999, NULL, 107, 0, '');
INSERT INTO 'recording' VALUES (334, NULL, '2012-01-20 12:55:03.189898+00', 'Swilcan, The', 3010, 2, 4, 32, 9999, 1, 141, 0, '');
INSERT INTO 'recording' VALUES (335, NULL, '2012-01-20 12:55:03.195502+00', 'Swilcan, The', 3009, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (339, NULL, '2012-01-20 12:55:03.217174+00', 'There''s Nae Luck Aboot The Hoose', 3020, 3, 8, 32, 9999, 5, 490, 0, '');
INSERT INTO 'recording' VALUES (340, NULL, '2012-01-20 12:55:03.222249+00', 'Threave Castle Polka', 3010, 13, 0, 0, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (341, NULL, '2012-01-20 12:55:03.227268+00', 'Tobermory Two-Step', 3014, 50, 0, 16, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (342, NULL, '2012-01-20 12:55:03.232321+00', 'Traquair House', 3012, 1, 4, 48, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (343, NULL, '2012-01-20 12:55:03.237147+00', 'Trip to Aberdeen, A', 3001, 2, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (344, NULL, '2012-01-20 12:55:03.241962+00', 'Trip to Bavaria, A', 3007, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (345, NULL, '2012-01-20 12:55:03.247439+00', 'Triumph, The', 3018, 1, 8, 24, 9999, 19, 210, 0, '');
INSERT INTO 'recording' VALUES (346, NULL, '2012-01-20 12:55:03.252285+00', 'Tweedside', 3028, 50, 4, 36, 9999, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (348, NULL, '2012-01-20 12:55:03.26192+00', 'Two-Step', 3003, 11, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (349, NULL, '2012-01-20 12:55:03.266725+00', 'Tyneside Waltz', 3010, 5, 0, 0, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (350, NULL, '2012-01-20 12:55:03.271523+00', 'Waltz Country Dance', 3011, 5, 4, 40, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (351, NULL, '2012-01-20 12:55:03.27633+00', 'Waltz Country Dance', 3053, 5, 4, 40, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (353, NULL, '2012-01-20 12:55:03.287295+00', 'Waverley', 3021, 2, 8, 48, 9999, 4, 418, 0, '');
INSERT INTO 'recording' VALUES (354, NULL, '2012-01-20 12:55:03.292155+00', 'Weathercock, The', 3008, 2, 4, 32, 9999, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (356, NULL, '2012-01-20 12:55:03.302462+00', 'West Highland Waltz', 3052, 5, 0, 0, 9999, NULL, 223, 0, '');
INSERT INTO 'recording' VALUES (357, NULL, '2012-01-20 12:55:03.307255+00', 'West''s Awake Hornpipe', 3037, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (358, NULL, '2012-01-20 12:55:03.31274+00', 'West''s Hornpipe', 3018, 1, 4, 32, 9999, 1, 141, 0, '');
INSERT INTO 'recording' VALUES (361, NULL, '2012-01-20 12:55:03.328567+00', 'Westminster Reel, The', 3009, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (362, NULL, '2012-01-20 12:55:03.334408+00', 'What You Please', 3002, 2, 8, 40, 9999, 9, 343, 0, '');
INSERT INTO 'recording' VALUES (364, NULL, '2012-01-20 12:55:03.344097+00', 'Wild Geese, The', 3012, 2, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (365, NULL, '2012-01-20 12:55:03.348905+00', 'Wild Geese, The', 3001, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (366, NULL, '2012-01-20 12:55:03.354367+00', 'Willie''s Rare and Willie''s Fair', 3002, 2, 8, 48, 9999, 13, 428, 0, '');
INSERT INTO 'recording' VALUES (3536, NULL, '2012-01-20 12:55:21.327386+00', 'Inverness Country Dance', 3046, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (3537, NULL, '2012-01-20 12:55:21.332197+00', 'Duke and Duchess of Edinburgh, The', 3046, 1, 8, 40, 9999, NULL, 354, 0, '');
INSERT INTO 'recording' VALUES (3538, NULL, '2012-01-20 12:55:21.336981+00', 'Machine Without Horses, The', 3046, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (3539, NULL, '2012-01-20 12:55:21.341797+00', 'Reel of the 51st Division, The', 3046, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (3540, NULL, '2012-01-20 12:55:21.34659+00', 'Duke of Perth', 3046, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (3541, NULL, '2012-01-20 12:55:21.351392+00', 'Scottish Reform', 3046, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (327, NULL, '2019-01-23 17:05:35.932691+00', 'St. Columba''s Strathspey', 3008, 3, 5, 32, 9999, NULL, 319, 0, '');
INSERT INTO 'recording' VALUES (363, NULL, '2019-01-23 18:17:42.754891+00', 'Wicked Willy', 3008, 1, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (359, NULL, '2019-01-23 23:35:48.770901+00', 'West''s Hornpipe', 3011, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (3542, NULL, '2012-01-20 12:55:21.356194+00', 'Waltz Country Dance', 3046, 5, 4, 40, 9999, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (3543, NULL, '2012-01-20 12:55:21.361005+00', 'Mairi''s Wedding', 3046, 1, 8, 40, 9999, NULL, 351, 0, '');
INSERT INTO 'recording' VALUES (3545, NULL, '2012-01-20 12:55:21.370596+00', 'Petronella', 3046, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (9016, '2012-12-28 18:41:09.710292+00', '2012-12-28 18:41:09.710302+00', 'Sword Dance 2+1 Junior', 10687, 7, 3, 32, 9999, NULL, 119, 0, '');
INSERT INTO 'recording' VALUES (3547, NULL, '2012-01-20 12:55:21.380177+00', 'Strip the Willow', 3046, 2, 4, 64, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (3548, NULL, '2012-01-20 12:55:21.384958+00', 'Hooper''s Jig', 3032, 2, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (3549, NULL, '2012-01-20 12:55:21.389795+00', 'Deveron Reel, The', 3032, 1, 4, 40, 9999, NULL, 184, 1, '');
INSERT INTO 'recording' VALUES (3550, NULL, '2012-01-20 12:55:21.394613+00', 'Wisp of Thistle', 3032, 3, 8, 32, 9999, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (3552, NULL, '2012-01-20 12:55:21.404175+00', 'Swiss Lassie', 3032, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (3553, NULL, '2012-01-20 12:55:21.408952+00', 'Autumn in Appin', 3032, 3, 4, 32, 9999, NULL, 257, 1, '');
INSERT INTO 'recording' VALUES (3554, NULL, '2012-01-20 12:55:21.413752+00', 'Sound of Harris, The', 3032, 1, 3, 48, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (352, NULL, '2020-05-15 11:04:49.82931+00', 'Miss Ogilvie''s Fancy', 3048, 3, 8, 32, 9999, 5, 512, 0, '');
INSERT INTO 'recording' VALUES (3551, NULL, '2020-01-15 10:53:36.323679+00', 'MacLeod of Tobermory', 3032, 2, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (8907, '2012-06-12 15:09:28.243472+00', '2020-01-25 22:33:41.571145+00', 'Trip to Perth', 3012, 2, 6, 32, NULL, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (9024, '2012-12-31 15:39:40.482873+00', '2021-04-21 06:54:07.340826+00', 'Orwell Lodge Strathspey', 2944, 3, 3, 32, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (347, NULL, '2021-06-06 19:38:27.00187+00', 'Two and Two', 3028, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (3555, NULL, '2012-01-20 12:55:21.418543+00', 'Let the Hackles Rise', 3032, 2, 4, 48, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (3546, NULL, '2012-01-26 13:43:43.561538+00', 'Dunedin Festival Dance, The', 3046, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (8864, '2012-04-29 14:02:31.895505+00', '2012-04-29 14:02:31.895515+00', 'Reels (Simple)', 1502, 1, 3, 32, 9999, NULL, 125, 0, '');
INSERT INTO 'recording' VALUES (8892, '2012-05-31 07:44:21.980621+00', '2012-05-31 07:44:21.980631+00', 'Silver Grey, The', 10034, 3, 3, 32, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (8926, '2012-06-17 14:55:49.540432+00', '2012-06-17 14:55:49.540441+00', 'Lady Susan Stewart''s Reel', 10000, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (8941, '2012-12-25 22:51:40.998314+00', '2012-12-25 22:51:40.998323+00', 'Cape Town Wedding', 3658, 3, 2, 32, 9999, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (8968, '2012-12-28 10:52:55.811386+00', '2012-12-28 10:52:55.811397+00', 'J. B. Milne', 903, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (8986, '2012-12-28 14:45:55.532452+00', '2012-12-28 14:45:55.532463+00', 'March, Strathspey & Reel', 10679, 4, 1, 128, 10016, NULL, 221, 0, '');
INSERT INTO 'recording' VALUES (8996, '2012-12-28 16:18:25.194303+00', '2012-12-28 16:18:25.194314+00', 'Canadian Barn Dance', 2583, 11, 16, 16, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (338, NULL, '2022-12-09 20:00:15.3287+00', 'Teviot Brig', 3037, 2, 8, 24, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (9027, '2012-12-31 16:09:11.636704+00', '2022-12-19 16:24:02.843628+00', 'Buttercup, The', 2944, 2, 8, 40, 9999, NULL, 358, 0, '');
INSERT INTO 'recording' VALUES (336, NULL, '2022-12-19 16:24:24.745194+00', 'Tattie Bogle, The', 3013, 2, 8, 32, 9999, 1, 278, 0, '');
INSERT INTO 'recording' VALUES (9025, '2012-12-31 15:45:37.678549+00', '2012-12-31 15:45:37.678559+00', 'Burnaby at Forty', 2944, 3, 4, 40, 9999, NULL, 328, 0, '');
INSERT INTO 'recording' VALUES (9029, '2012-12-31 16:33:22.169255+00', '2012-12-31 16:33:22.169265+00', 'Perth Meets Perth', 2944, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (9030, '2012-12-31 16:43:48.190447+00', '2012-12-31 16:43:48.190457+00', 'Kandahar Reel, The', 2944, 1, 10, 32, 9999, NULL, 357, 0, '');
INSERT INTO 'recording' VALUES (9031, '2013-01-01 17:58:38.690775+00', '2013-01-01 17:58:38.690786+00', 'Sword Dance 2+2 SOBHD', 10687, 7, 4, 32, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (9035, '2013-01-01 18:16:26.147589+00', '2013-01-02 11:59:19.357642+00', 'Seann Triubhas 3+1 Junior', 10687, 7, 4, 16, 9999, NULL, 93, 0, '');
INSERT INTO 'recording' VALUES (9055, '2013-01-02 14:34:05.296563+00', '2013-01-02 14:34:05.296573+00', 'Follow Me Home', 3678, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (367, NULL, '2012-01-20 12:55:03.35986+00', 'Miss Grace Hay''s Delight', 3048, 2, 8, 32, 9999, 12, 284, 0, '');
INSERT INTO 'recording' VALUES (368, NULL, '2012-01-20 12:55:03.364841+00', 'Woo''d and Married and A''', 3007, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (369, NULL, '2012-01-20 12:55:03.369655+00', 'Waltz for Mary Kay', 3017, 5, 0, 0, 9999, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (370, NULL, '2012-01-20 12:55:03.374451+00', 'Rosewood Waltz', 3017, 5, 0, 0, 9999, NULL, 254, 0, '');
INSERT INTO 'recording' VALUES (371, NULL, '2012-01-20 12:55:03.37924+00', 'Scottish Reels', 3003, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (372, NULL, '2012-01-20 12:55:03.384711+00', 'Monymusk', 3048, 3, 8, 32, 9999, 8, 527, 0, '');
INSERT INTO 'recording' VALUES (373, NULL, '2012-01-20 12:55:03.389534+00', 'Set of Reels', 3009, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (374, NULL, '2012-01-20 12:55:03.39435+00', 'Military Two Step', 3037, 11, 8, 16, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (375, NULL, '2012-01-20 12:55:03.399877+00', 'Byron Strathspey, The', 3026, 3, 3, 32, 9999, 5, 188, 0, '');
INSERT INTO 'recording' VALUES (376, NULL, '2012-01-20 12:55:03.405433+00', 'Saltire Society Reel, The', 3026, 1, 8, 32, 9999, 1, 278, 0, '');
INSERT INTO 'recording' VALUES (377, NULL, '2012-01-20 12:55:03.410261+00', 'Hebridean Weaving Lilt', 3026, 3, 0, 88, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (378, NULL, '2012-01-20 12:55:03.415055+00', 'Laird o'' Dochart''s Reel', 3015, 2, 2, 80, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (379, NULL, '2012-01-20 12:55:03.419845+00', 'Schottische', 3056, 3, 0, 0, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (380, NULL, '2012-01-20 12:55:03.424645+00', 'Quincentenary Reel, The', 3038, 1, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (381, NULL, '2012-01-20 12:55:03.430129+00', 'Music Makars', 3030, 1, 8, 32, 9999, 5, 269, 0, '');
INSERT INTO 'recording' VALUES (382, NULL, '2012-01-20 12:55:03.435778+00', 'Strathspey King, The', 3030, 3, 4, 32, 9999, 5, 262, 0, '');
INSERT INTO 'recording' VALUES (384, NULL, '2012-01-20 12:55:03.446753+00', 'Sarona', 3030, 3, 4, 32, 9999, 1, 270, 1, '');
INSERT INTO 'recording' VALUES (385, NULL, '2012-01-20 12:55:03.452233+00', 'Shetland Reel Set', 3030, 1, 8, 32, 9999, 1, 276, 0, '');
INSERT INTO 'recording' VALUES (402, NULL, '2018-04-13 20:28:44.240122+00', 'Ray Milbourne', 1396, 1, 4, 32, 9999, 1, 149, 1, '');
INSERT INTO 'recording' VALUES (388, NULL, '2012-01-20 12:55:03.468708+00', 'Argyll Strathspey', 3030, 3, 8, 32, 9999, 5, 508, 0, '');
INSERT INTO 'recording' VALUES (389, NULL, '2012-01-20 12:55:03.474182+00', 'Follow Me Home', 3030, 2, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (390, NULL, '2012-01-20 12:55:03.479+00', 'Waltz', 3030, 5, 0, 0, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (391, NULL, '2012-01-20 12:55:03.48379+00', 'Dancer''s Auld Lang Syne and Polka', 3030, 13, 0, 0, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (392, NULL, '2012-01-20 12:55:03.489248+00', 'Diamond Jubilee', 1396, 2, 4, 32, 9999, 1, 145, 0, '');
INSERT INTO 'recording' VALUES (393, NULL, '2012-01-20 12:55:03.49521+00', 'Blooms of Bon Accord, The', 1396, 1, 4, 32, 9999, 1, 149, 1, '');
INSERT INTO 'recording' VALUES (394, NULL, '2012-01-20 12:55:03.5007+00', 'Set of Jigs', 1396, 2, 8, 32, 9999, 1, 286, 0, '');
INSERT INTO 'recording' VALUES (395, NULL, '2012-01-20 12:55:03.506191+00', 'Medley', 1396, 4, 0, 0, 9999, 1, 207, 0, '');
INSERT INTO 'recording' VALUES (397, NULL, '2012-01-20 12:55:03.517153+00', 'Set of Strathspeys', 1396, 3, 8, 32, 9999, 5, 510, 0, '');
INSERT INTO 'recording' VALUES (398, NULL, '2012-01-20 12:55:03.521985+00', 'Slow Air', 1396, 98, 0, 0, 9999, NULL, 101, 0, '');
INSERT INTO 'recording' VALUES (400, NULL, '2012-01-20 12:55:03.537323+00', 'Miss Allie Anderson', 1396, 2, 8, 32, 9999, 1, 288, 0, '');
INSERT INTO 'recording' VALUES (401, NULL, '2012-01-20 12:55:03.542154+00', 'Pipe Medley', 1396, 50, 0, 0, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (403, NULL, '2012-01-20 12:55:03.554098+00', 'Britannia Two-step', 1396, 11, 0, 16, 9999, 1, 154, 0, '');
INSERT INTO 'recording' VALUES (404, NULL, '2012-01-20 12:55:03.558944+00', 'Fiddle Medley', 1396, 50, 0, 0, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (8969, '2012-12-28 10:55:28.959194+00', '2012-12-28 10:55:28.959204+00', 'Last of the Lairds, The', 903, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (407, NULL, '2012-01-20 12:55:03.575476+00', 'Canadian Barn Dance', 1396, 11, 8, 16, 9999, 1, 236, 0, '');
INSERT INTO 'recording' VALUES (3556, NULL, '2012-01-20 12:55:21.423329+00', 'Saint Margaret''s Inch', 3032, 3, 5, 32, 9999, NULL, 305, 0, '');
INSERT INTO 'recording' VALUES (399, NULL, '2013-05-28 09:42:22.506146+00', 'Set of Reels', 1396, 1, 8, 32, 9999, 1, 290, 0, '');
INSERT INTO 'recording' VALUES (3544, NULL, '2014-08-19 08:56:34.880856+00', 'Postie''s Jig', 3046, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (3557, NULL, '2012-01-20 12:55:21.428127+00', 'Anniversary Reel', 3032, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (3558, NULL, '2012-01-20 12:55:21.43291+00', 'Wee Cooper o'' Fife, The', 3032, 2, 8, 40, 9999, NULL, 340, 0, '');
INSERT INTO 'recording' VALUES (3559, NULL, '2012-01-20 12:55:21.437718+00', 'Oregon Rant, The', 3032, 4, 0, 128, 13, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (3560, NULL, '2012-01-20 12:55:21.442931+00', 'Winding Nith, The', 3032, 3, 4, 40, 9999, NULL, 303, 0, '');
INSERT INTO 'recording' VALUES (3561, NULL, '2012-01-20 12:55:21.447767+00', 'Australian Ladies', 3032, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (3562, NULL, '2012-01-20 12:55:21.452606+00', 'Caller Herrin''', 2184, 1, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3563, NULL, '2012-01-20 12:55:21.457426+00', 'Mr William Brown''s Reel', 2184, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3564, NULL, '2012-01-20 12:55:21.462247+00', 'John McAlpin', 2184, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3565, NULL, '2012-01-20 12:55:21.467034+00', 'Fireside Reel, The', 2184, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (386, NULL, '2017-03-05 18:56:48.532168+00', 'Interlude Medley of Bagpipe Tunes', 3030, 98, 1, 0, 9999, 1, 283, 0, '');
INSERT INTO 'recording' VALUES (383, NULL, '2019-02-06 23:34:46.057342+00', 'Susan''s Jig Set', 3030, 2, 4, 32, 9999, 1, 140, 0, '');
INSERT INTO 'recording' VALUES (396, NULL, '2019-06-28 08:59:18.299856+00', 'Dancers of Don', 1396, 4, 0, 112, 29, 5, 155, 0, '');
INSERT INTO 'recording' VALUES (405, NULL, '2019-06-28 15:28:06.934398+00', 'Set of Reels', 1396, 1, 4, 32, 9999, 1, 145, 0, '');
INSERT INTO 'recording' VALUES (3566, NULL, '2012-01-20 12:55:21.47181+00', 'Duchess Tree, The', 2184, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3567, NULL, '2012-01-20 12:55:21.476623+00', 'Cold and Raw', 2184, 2, 8, 24, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3568, NULL, '2012-01-20 12:55:21.481424+00', 'Bob of Fettercairn, The', 2184, 1, 8, 24, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3569, NULL, '2012-01-20 12:55:21.486244+00', 'General Stuart''s Reel', 2184, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3570, NULL, '2012-01-20 12:55:21.491034+00', 'Waverley', 2184, 2, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3571, NULL, '2012-01-20 12:55:21.495827+00', 'Golden Pheasant, The', 2184, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3572, NULL, '2012-01-20 12:55:21.500615+00', 'Maid of the Mill, The', 2184, 2, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3573, NULL, '2012-01-20 12:55:21.505404+00', 'Triumph, The', 2184, 1, 4, 24, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3574, NULL, '2012-01-20 12:55:21.510183+00', 'Meg Merrilees', 2184, 1, 8, 24, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3575, NULL, '2012-01-20 12:55:21.514975+00', 'Prince of Orange', 2184, 2, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (8987, '2012-12-28 14:55:30.518598+00', '2012-12-28 14:55:30.518608+00', 'Jigs', 10679, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (8880, '2012-05-09 15:55:36.198611+00', '2012-05-09 15:55:36.198621+00', 'October in Rechberg', 1502, 3, 3, 32, 9999, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (8893, '2012-05-31 07:52:43.39396+00', '2012-05-31 07:52:43.39397+00', 'Sailor, The', 10034, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (8865, '2012-04-29 14:06:16.843151+00', '2012-06-05 00:32:06.499444+00', 'Jigs (Simple) (with pauses between turns)', 1502, 2, 3, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (8997, '2012-12-28 16:22:40.162941+00', '2012-12-28 16:22:40.162952+00', 'Seton''s Ceilidh Band', 2583, 2, 4, 64, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (8927, '2012-06-17 14:59:10.426242+00', '2012-06-17 14:59:10.426251+00', 'Braes of Breadalbane, The', 10000, 3, 8, 32, NULL, 5, 503, 0, '');
INSERT INTO 'recording' VALUES (9017, '2012-12-28 18:43:55.578445+00', '2012-12-28 18:43:55.578456+00', 'Sword Dance 2+2 SOBHD', 10687, 7, 4, 32, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (9032, '2013-01-01 18:00:26.623748+00', '2013-01-01 18:00:26.623758+00', 'Sword Dance 3+1 SOBHD', 10687, 7, 4, 32, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (9036, '2013-01-01 18:19:05.140706+00', '2013-01-02 12:00:31.554649+00', 'Seann Triubhas 3+1 SOBHD', 10687, 7, 4, 16, 9999, NULL, 96, 0, '');
INSERT INTO 'recording' VALUES (9061, '2013-01-02 15:26:20.165181+00', '2013-01-02 15:26:20.165191+00', 'My Heather Hills', 3678, 2, 3, 48, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (409, NULL, '2012-01-20 12:55:03.587302+00', 'Johnnie Walker', 3026, 4, 0, 128, 13, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (410, NULL, '2012-01-20 12:55:03.59467+00', 'Crammond Bridge', 3026, 1, 8, 32, 9999, 1, 281, 0, '');
INSERT INTO 'recording' VALUES (412, NULL, '2012-01-20 12:55:03.605726+00', 'Cumberland Reel', 3026, 2, 4, 32, 9999, 1, 135, 0, '');
INSERT INTO 'recording' VALUES (3678, NULL, '2012-01-20 12:55:22.092817+00', 'Jig', 2291, 2, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (413, NULL, '2012-01-20 12:55:03.61122+00', 'New Scotia Quadrille', 3026, 1, 2, 48, 9999, 11, 112, 0, '');
INSERT INTO 'recording' VALUES (414, NULL, '2012-01-20 12:55:03.616706+00', 'Dundee Whaler, The', 3026, 3, 4, 32, 9999, 5, 245, 0, '');
INSERT INTO 'recording' VALUES (415, NULL, '2012-01-20 12:55:03.622188+00', 'Bannetstane, The', 3026, 2, 4, 32, 9999, 10, 138, 0, '');
INSERT INTO 'recording' VALUES (416, NULL, '2012-01-20 12:55:03.627086+00', 'Lomond Waltz', 3026, 5, 0, 32, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (417, NULL, '2012-01-20 12:55:03.63259+00', 'Angus Reel, The', 3026, 1, 0, 128, 9999, 5, 152, 1, '');
INSERT INTO 'recording' VALUES (419, NULL, '2012-01-20 12:55:03.642884+00', 'Belle Of Bon Accord, The', 3026, 3, 4, 32, 9999, 10, 253, 0, '');
INSERT INTO 'recording' VALUES (420, NULL, '2012-01-20 12:55:03.648368+00', 'Rab the Ranter', 3026, 1, 4, 32, 9999, 1, 146, 0, '');
INSERT INTO 'recording' VALUES (421, NULL, '2012-01-20 12:55:03.65387+00', 'C''est l''Amour', 3026, 2, 8, 32, 9999, 1, 271, 0, '');
INSERT INTO 'recording' VALUES (422, NULL, '2012-01-20 12:55:03.660498+00', 'Wind On Loch Fyne, The', 3026, 3, 3, 32, 9999, 3, 190, 0, '');
INSERT INTO 'recording' VALUES (423, NULL, '2012-01-20 12:55:03.669643+00', 'Seton''s Ceilidh Band', 3026, 2, 4, 64, 9999, 10, 273, 0, '');
INSERT INTO 'recording' VALUES (424, NULL, '2012-01-20 12:55:03.676741+00', 'New Petronella, The', 3026, 1, 2, 48, 9999, 4, 110, 0, '');
INSERT INTO 'recording' VALUES (425, NULL, '2012-01-20 12:55:03.68303+00', 'Bonnie Lass of Bon Accord, The', 3026, 3, 0, 64, 9999, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (428, NULL, '2012-01-20 12:55:03.704886+00', 'Broon''s Reel', 3026, 1, 8, 32, 9999, 1, 268, 0, '');
INSERT INTO 'recording' VALUES (429, NULL, '2012-01-20 12:55:03.711989+00', 'Rothesay Rant, The', 3026, 2, 4, 32, 9999, 1, 145, 0, '');
INSERT INTO 'recording' VALUES (430, NULL, '2012-01-20 12:55:03.718267+00', 'Phantom Piper, The', 3032, 2, 4, 32, 9999, NULL, 148, 1, '');
INSERT INTO 'recording' VALUES (431, NULL, '2012-01-20 12:55:03.724505+00', 'Niel Gow''s Farewell to Whisky', 3032, 1, 4, 48, 9999, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (432, NULL, '2012-01-20 12:55:03.731004+00', 'Dundee Whaler, The', 3032, 3, 4, 32, 9999, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (433, NULL, '2012-01-20 12:55:03.737264+00', 'Brisk Young Lad, The', 3032, 2, 5, 48, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (434, NULL, '2012-01-20 12:55:03.743522+00', 'Salmonfield Poacher, The', 3032, 1, 8, 40, 9999, NULL, 355, 0, '');
INSERT INTO 'recording' VALUES (435, NULL, '2012-01-20 12:55:03.749853+00', '1314', 3032, 4, 0, 128, 2, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (436, NULL, '2012-01-20 12:55:03.756085+00', 'Swilcan, The', 3032, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (438, NULL, '2012-01-20 12:55:03.768575+00', 'Lady Sophia Lindsay', 3032, 1, 4, 32, 9999, NULL, 148, 1, '');
INSERT INTO 'recording' VALUES (439, NULL, '2012-01-20 12:55:03.774836+00', 'Snake Pass, The', 3032, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (440, NULL, '2012-01-20 12:55:03.78107+00', 'MacDonald of the Isles', 3032, 3, 3, 32, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (442, NULL, '2012-01-20 12:55:03.793555+00', 'Shiftin'' Bobbins', 3032, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (443, NULL, '2012-01-20 12:55:03.799952+00', 'Bruce & Margaret Urquhart', 3032, 3, 8, 32, 9999, NULL, 496, 0, '');
INSERT INTO 'recording' VALUES (444, NULL, '2012-01-20 12:55:03.806191+00', 'West''s Hornpipe', 3032, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (445, NULL, '2012-01-20 12:55:03.813233+00', 'Peggy Dewar', 3002, 1, 8, 32, 9999, 5, 282, 0, '');
INSERT INTO 'recording' VALUES (446, NULL, '2012-01-20 12:55:03.820502+00', 'My Friend Joe', 3002, 3, 8, 32, 9999, 5, 508, 0, '');
INSERT INTO 'recording' VALUES (447, NULL, '2012-01-20 12:55:03.827605+00', 'Follow Me Home', 3002, 2, 8, 32, 9999, 1, 286, 0, '');
INSERT INTO 'recording' VALUES (448, NULL, '2012-01-20 12:55:03.834694+00', 'Miss Florence Adams', 3002, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (3576, NULL, '2012-01-20 12:55:21.519795+00', 'Johnny McGill', 2184, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3577, NULL, '2012-01-20 12:55:21.524617+00', 'Rakes of Glasgow', 2184, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3578, NULL, '2012-01-20 12:55:21.529404+00', 'Bonnie Kate of Aberdeen', 2184, 3, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3579, NULL, '2012-01-20 12:55:21.534206+00', 'Round Reel of Eight', 2184, 1, 0, 88, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3580, NULL, '2012-01-20 12:55:21.539018+00', 'Seann Truibhas Willichan', 2184, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3581, NULL, '2012-01-20 12:55:21.54381+00', 'Flora, La', 2184, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3582, NULL, '2012-01-20 12:55:21.548584+00', 'Royal Exchange', 2184, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3583, NULL, '2012-01-20 12:55:21.55338+00', 'Bees of Maggieknockater, The', 2184, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (418, NULL, '2014-09-16 13:11:39.027258+00', 'Four Minute Reel', 3012, 1, 8, 32, 9999, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (3584, NULL, '2012-01-20 12:55:21.558204+00', 'Blooms of Bon Accord', 2184, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3585, NULL, '2012-01-20 12:55:21.562992+00', 'Caberfei', 2184, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3586, NULL, '2012-01-20 12:55:21.567779+00', 'Reel of the Edinburgh Military Tattoo, The', 2184, 1, 2, 56, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3587, NULL, '2012-01-20 12:55:21.625235+00', 'Airdrie Lassies', 2184, 2, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3588, NULL, '2012-01-20 12:55:21.630127+00', 'Mile to Ride, A', 2184, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3589, NULL, '2012-01-20 12:55:21.638701+00', 'Fairly Shot o'' Her', 2184, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3590, NULL, '2012-01-20 12:55:21.644975+00', 'Old Nick''s Lumber Room', 2184, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3592, NULL, '2012-01-20 12:55:21.657612+00', 'Lady Maxwell''s Reel', 2184, 4, 8, 32, 1, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3593, NULL, '2012-01-20 12:55:21.663944+00', 'Sugar Candie', 2184, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (426, NULL, '2016-11-15 01:13:09.16137+00', 'Bank Street Reel', 3026, 1, 4, 32, 9999, 1, 144, 0, '');
INSERT INTO 'recording' VALUES (10223, '2018-09-15 09:44:59.955329+00', '2018-11-06 21:54:11.264356+00', 'Aviator, The', 10659, 2, 8, 32, NULL, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (3594, NULL, '2012-01-20 12:55:21.670219+00', 'Frisky, The', 2184, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3595, NULL, '2012-01-20 12:55:21.676539+00', 'New Waterloo Reel, The', 2184, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (8881, '2012-05-09 15:57:55.429176+00', '2012-05-09 15:58:33.861676+00', 'Miss Emily Gordon''s Jig', 1502, 2, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (8894, '2012-05-31 07:56:45.508564+00', '2012-05-31 07:56:45.508574+00', 'Flying Scotsman, The', 10034, 2, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (8866, '2012-04-29 14:16:22.207924+00', '2012-06-05 00:33:05.858834+00', 'Strathspeys (Lyrical) (with pauses between turns)', 1502, 3, 3, 32, 9999, NULL, 239, 0, '');
INSERT INTO 'recording' VALUES (8970, '2012-12-28 10:59:37.18196+00', '2012-12-28 10:59:37.181971+00', 'Montgomeries'' Rant, The', 903, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (8988, '2012-12-28 14:58:39.300868+00', '2012-12-28 14:58:39.300878+00', 'Waltzes', 10679, 5, 0, 0, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (8998, '2012-12-28 16:25:37.864147+00', '2012-12-28 16:25:37.864158+00', 'Ruby Waltz', 2583, 5, 0, 0, 9999, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (9018, '2012-12-28 18:46:10.140604+00', '2012-12-28 18:46:10.140614+00', 'Sword Dance 3+1 SOBHD', 10687, 7, 4, 32, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (9033, '2013-01-01 18:02:54.907087+00', '2013-01-02 09:24:58.580697+00', 'Sword Dance Marathon 8 SOBHD', 10687, 7, 8, 32, 9999, NULL, 318, 0, '');
INSERT INTO 'recording' VALUES (9037, '2013-01-01 18:20:36.417108+00', '2013-01-02 12:01:14.960936+00', 'Seann Triubhas 4+2 SOBHD', 10687, 7, 6, 16, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (9057, '2013-01-02 14:52:43.590268+00', '2013-01-02 14:52:43.590278+00', 'Shepherd''s Crook, The', 3678, 3, 1, 72, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (492, NULL, '2012-01-20 12:55:04.107185+00', 'Ways in New Hall', 3217, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (441, NULL, '2020-12-28 20:18:04.860433+00', 'Barley Bree', 3032, 2, 4, 40, 9999, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (437, NULL, '2020-12-28 21:01:09.22746+00', 'Gavin''s Reel', 3032, 1, 5, 32, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (9066, '2013-01-02 16:12:11.730331+00', '2013-01-02 16:12:11.730341+00', 'Bay of Islands, The', 3678, 3, 5, 40, 9999, NULL, 520, 0, '');
INSERT INTO 'recording' VALUES (9068, '2013-01-02 16:41:03.159754+00', '2013-01-02 16:41:03.159764+00', 'It''s Just for Fun', 3678, 2, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (9070, '2013-01-02 16:54:48.626225+00', '2013-01-02 16:54:48.626236+00', 'George''s Strathspey', 3678, 3, 4, 40, 9999, NULL, 323, 0, '');
INSERT INTO 'recording' VALUES (9071, '2013-01-03 08:01:02.384125+00', '2013-01-03 08:01:02.384135+00', 'Hornes Set, The', 2088, 11, 12, 16, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (450, NULL, '2012-01-20 12:55:03.848988+00', 'Mr Robert H. Mackay', 3002, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (451, NULL, '2012-01-20 12:55:03.856074+00', 'Summer Wooing', 3002, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (452, NULL, '2012-01-20 12:55:03.863166+00', 'Trip to the Drakensberg, A', 3002, 2, 8, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (454, NULL, '2012-01-20 12:55:03.876208+00', 'Flowers o'' the Forest', 3002, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (455, NULL, '2012-01-20 12:55:03.881896+00', 'Petronella', 3018, 1, 8, 32, 9999, 1, 278, 0, '');
INSERT INTO 'recording' VALUES (456, NULL, '2012-01-20 12:55:03.892516+00', 'Rendezvous, The', 3048, 1, 8, 32, 9999, 5, 284, 0, '');
INSERT INTO 'recording' VALUES (457, NULL, '2012-01-20 12:55:03.898106+00', 'Nut, The', 3018, 2, 8, 24, 9999, 18, 0, 0, '');
INSERT INTO 'recording' VALUES (458, NULL, '2012-01-20 12:55:03.903614+00', 'Meg Merrilees', 3018, 1, 8, 24, 9999, 18, 0, 0, '');
INSERT INTO 'recording' VALUES (9062, '2013-01-02 15:38:35.251141+00', '2022-12-13 14:40:21.75698+00', 'Miss Lawson''s Reel', 3678, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (459, NULL, '2012-01-20 12:55:03.908432+00', 'Marchioness of Blandford''s Reel, The', 3049, 2, 8, 48, 9999, NULL, 416, 0, '');
INSERT INTO 'recording' VALUES (460, NULL, '2012-01-20 12:55:03.91353+00', 'Strip the Willow', 3018, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (461, NULL, '2012-01-20 12:55:03.918563+00', 'My Only Jo and Dearie, O', 3049, 3, 8, 32, 9999, NULL, 499, 0, '');
INSERT INTO 'recording' VALUES (463, NULL, '2012-01-20 12:55:03.929953+00', 'Fight About the Fireside', 3018, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (466, NULL, '2012-01-20 12:55:03.946347+00', 'Loch Leven Castle', 3049, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (468, NULL, '2012-01-20 12:55:03.959565+00', 'Finlay Stewart Skinner', 1502, 3, 8, 32, 9999, 5, 555, 0, '');
INSERT INTO 'recording' VALUES (469, NULL, '2012-01-20 12:55:03.965328+00', 'High Lodge, The', 1502, 2, 8, 32, 9999, 5, 285, 0, '');
INSERT INTO 'recording' VALUES (470, NULL, '2012-01-20 12:55:03.97096+00', '8th Battalion - The Royal Scots', 1502, 1, 8, 32, 9999, 5, 281, 0, '');
INSERT INTO 'recording' VALUES (471, NULL, '2012-01-20 12:55:03.975834+00', 'Waltz Selection', 1502, 5, 0, 0, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (472, NULL, '2012-01-20 12:55:03.980648+00', 'Air', 1502, 98, 0, 0, 9999, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (473, NULL, '2012-01-20 12:55:03.986467+00', 'Julian''s Jig', 1502, 2, 8, 32, 9999, 5, 286, 0, '');
INSERT INTO 'recording' VALUES (474, NULL, '2012-01-20 12:55:03.992427+00', 'Barbara McOwen''s Ceilidh', 1502, 3, 8, 32, 9999, 5, 554, 0, '');
INSERT INTO 'recording' VALUES (475, NULL, '2012-01-20 12:55:03.998027+00', 'Mrs Leslye Buchanan', 1502, 1, 8, 32, 9999, 5, 290, 0, '');
INSERT INTO 'recording' VALUES (476, NULL, '2012-01-20 12:55:04.003614+00', 'Duns 500', 1502, 3, 0, 64, 9999, 5, 150, 0, '');
INSERT INTO 'recording' VALUES (477, NULL, '2012-01-20 12:55:04.009201+00', 'Summer''s End', 1502, 2, 4, 32, 9999, 1, 150, 0, '');
INSERT INTO 'recording' VALUES (478, NULL, '2012-01-20 12:55:04.014227+00', 'Airs', 1502, 98, 0, 0, 9999, NULL, 376, 0, '');
INSERT INTO 'recording' VALUES (485, NULL, '2012-01-20 12:55:04.062497+00', 'Mr Iain Stuart Robertson', 3217, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (487, NULL, '2012-01-20 12:55:04.076185+00', 'Kirkbrae Welcome', 3060, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (488, NULL, '2012-01-20 12:55:04.082549+00', 'Chequered Court, The', 3217, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (3596, NULL, '2012-01-20 12:55:21.682802+00', 'Won''t You Join the Dance', 2184, 1, 0, 120, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3597, NULL, '2012-01-20 12:55:21.689047+00', 'Slow Waltz', 3063, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3598, NULL, '2012-01-20 12:55:21.695295+00', 'Marches', 3063, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3599, NULL, '2012-01-20 12:55:21.701565+00', 'Highland Schottische', 3063, 3, 0, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3600, NULL, '2012-01-20 12:55:21.707859+00', 'Polka', 3063, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3602, NULL, '2012-01-20 12:55:21.720104+00', 'Spanish Waltz', 3063, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3603, NULL, '2012-01-20 12:55:21.725056+00', 'Waltz', 3063, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3604, NULL, '2012-01-20 12:55:21.729864+00', 'Here''s To The Gordons', 3042, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3605, NULL, '2012-01-20 12:55:21.734651+00', 'Fiddle Solo', 3042, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3606, NULL, '2012-01-20 12:55:21.739415+00', 'Song of the Clyde', 3042, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3607, NULL, '2012-01-20 12:55:21.744206+00', 'Ye Banks and Braes', 3042, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (462, NULL, '2014-06-28 07:12:52.552753+00', 'Rory O'' More', 3018, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (453, NULL, '2014-08-21 06:38:34.20149+00', 'Land o'' Cakes', 3018, 3, 4, 32, 9999, 5, 247, 0, '');
INSERT INTO 'recording' VALUES (486, NULL, '2014-09-16 09:47:07.671938+00', 'Anna Holden''s Strathspey', 3217, 3, 8, 32, 9999, NULL, 499, 0, '');
INSERT INTO 'recording' VALUES (3608, NULL, '2012-01-20 12:55:21.749141+00', 'Trio', 3042, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3609, NULL, '2012-01-20 12:55:21.753997+00', 'Dancing in Kyle, The', 3042, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3611, NULL, '2012-01-20 12:55:21.764926+00', 'Old Nick''s Lumber Room', 2247, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (3612, NULL, '2012-01-20 12:55:21.770436+00', 'Fidget', 2247, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (3613, NULL, '2012-01-20 12:55:21.775929+00', 'Conundrum, The', 2247, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (3614, NULL, '2012-01-20 12:55:21.781423+00', 'Barley Bree', 2247, 2, 4, 40, 9999, 14, 0, 0, '');
INSERT INTO 'recording' VALUES (3615, NULL, '2012-01-20 12:55:21.786924+00', 'Duran Ranger, The', 2247, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (8867, '2012-04-29 14:21:50.078657+00', '2012-04-29 14:21:50.078667+00', 'Reels (with pauses between turns)', 1502, 1, 3, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (8882, '2012-05-09 16:00:35.68225+00', '2012-05-09 16:01:14.872532+00', 'David''s Delight', 1502, 3, 8, 32, 9999, NULL, 540, 0, '');
INSERT INTO 'recording' VALUES (8895, '2012-05-31 08:03:05.670209+00', '2012-05-31 08:03:05.670218+00', 'Gang the Same Gate', 10034, 3, 8, 32, 9999, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (8929, '2012-06-17 15:02:44.708285+00', '2012-06-17 15:02:44.708295+00', 'Carolynn''s Waltz', 10000, 5, 0, 0, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (480, NULL, '2015-07-16 18:43:17.253221+00', 'Dianne Murdoch''s Promenade', 2184, 1, 4, 32, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (481, NULL, '2015-07-16 18:45:02.021858+00', 'May Johnston''s Reel', 2184, 1, 4, 48, 9999, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (482, NULL, '2015-07-16 18:46:01.19382+00', 'Mrs Nona Craig', 2184, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (483, NULL, '2015-07-16 18:48:18.124405+00', 'Fairfield Bridge', 2184, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (484, NULL, '2015-07-16 18:50:48.198431+00', 'Nina Foulkes'' Reel', 2184, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (467, NULL, '2016-05-13 13:53:51.890836+00', 'Button Boy, The', 1502, 1, 8, 32, 9999, 5, 284, 0, '');
INSERT INTO 'recording' VALUES (465, NULL, '2019-01-23 17:50:00.267876+00', 'Merry Lads of Ayr', 3018, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (449, NULL, '2016-09-03 21:34:39.820905+00', 'Back to the Fireside', 3002, 1, 8, 32, 9999, 5, 282, 0, '');
INSERT INTO 'recording' VALUES (8971, '2012-12-28 11:08:20.083233+00', '2012-12-28 11:08:20.083243+00', 'Neidpath Castle', 903, 3, 3, 32, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (8989, '2012-12-28 15:03:15.544536+00', '2012-12-28 15:03:15.544547+00', 'Reels', 10679, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (8999, '2012-12-28 16:28:49.412516+00', '2012-12-28 16:28:49.412527+00', 'Festival Glide', 2583, 50, 0, 0, 9999, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (9019, '2012-12-28 18:48:29.519+00', '2012-12-28 18:48:29.51901+00', 'Sword Dance Marthon 12 SOBHD', 10687, 7, 12, 32, 9999, NULL, 318, 0, '');
INSERT INTO 'recording' VALUES (9034, '2013-01-01 18:06:43.420506+00', '2013-01-01 18:06:43.420517+00', 'Sword Dance QT Marathon 6 SOBHD', 10687, 7, 6, 32, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (9038, '2013-01-01 18:22:59.019175+00', '2013-01-02 12:00:57.083444+00', 'Seann Triubhas 4+2 Adult', 10687, 7, 6, 16, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (9058, '2013-01-02 15:00:56.583958+00', '2013-01-02 15:00:56.583968+00', 'Hunter''s Moon', 3678, 2, 4, 32, 9999, NULL, 149, 1, '');
INSERT INTO 'recording' VALUES (9063, '2013-01-02 15:44:52.442847+00', '2013-01-02 15:44:52.442857+00', 'Brig O'' Doon, The', 3678, 3, 1, 96, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (9067, '2013-01-02 16:15:12.032638+00', '2013-01-02 16:34:39.927726+00', 'Annan Tribute', 3678, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (9069, '2013-01-02 16:48:08.051302+00', '2013-01-02 16:48:08.051312+00', 'Highland Rambler, The', 3678, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (9072, '2013-01-03 08:09:17.026411+00', '2013-01-03 08:09:17.026422+00', 'Occasionals Jigs, The', 2088, 2, 8, 32, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (9075, '2013-01-03 08:36:35.533819+00', '2013-01-03 08:36:35.533829+00', 'Westringing Set, The', 2088, 1, 4, 64, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (3610, NULL, '2013-02-15 18:48:31.695577+00', 'Scottish Waltz', 2048, 5, 0, 0, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (490, NULL, '2012-01-20 12:55:04.092673+00', 'May Yarker''s Strathspey', 3217, 3, 8, 32, 9999, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (491, NULL, '2012-01-20 12:55:04.097941+00', 'Hall Change', 3217, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (493, NULL, '2012-01-20 12:55:04.112035+00', 'James Senior of St Andrews', 3217, 3, 4, 32, 9999, NULL, 257, 1, '');
INSERT INTO 'recording' VALUES (494, NULL, '2012-01-20 12:55:04.11686+00', 'David Russell Hall', 3217, 1, 4, 40, 9999, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (495, NULL, '2012-01-20 12:55:04.121864+00', 'James Gray', 3217, 2, 4, 32, 9999, NULL, 143, 1, '');
INSERT INTO 'recording' VALUES (496, NULL, '2012-01-20 12:55:04.126787+00', 'Maxwell''s Rant', 3034, 1, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (497, NULL, '2012-01-20 12:55:04.131612+00', 'Argyll''s Fancy', 3034, 2, 4, 48, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (500, NULL, '2012-01-20 12:55:04.153666+00', 'Laird of Milton''s Daughter, The', 3034, 2, 8, 32, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (501, NULL, '2012-01-20 12:55:04.411272+00', 'Winding Road, The', 3034, 3, 4, 32, 9999, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (502, NULL, '2012-01-20 12:55:04.416675+00', 'New Virginia Reel, The', 3034, 1, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (503, NULL, '2012-01-20 12:55:04.421499+00', 'Pinewoods Two-step, The', 3034, 50, 0, 0, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (505, NULL, '2012-01-20 12:55:04.431092+00', 'Victory Waltz, The', 3034, 5, 0, 0, 9999, NULL, 231, 0, '');
INSERT INTO 'recording' VALUES (506, NULL, '2012-01-20 12:55:04.435984+00', 'Baldovan Reel', 3034, 1, 4, 32, 9999, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (507, NULL, '2012-01-20 12:55:04.440803+00', 'White Heather Jig, The', 3034, 2, 4, 40, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (508, NULL, '2012-01-20 12:55:04.445605+00', 'Middleton Medley, The', 3034, 4, 8, 32, 8, NULL, 387, 0, '');
INSERT INTO 'recording' VALUES (509, NULL, '2012-01-20 12:55:04.451149+00', 'Highland Rambler, The', 3034, 1, 8, 40, 9999, 14, 335, 0, '');
INSERT INTO 'recording' VALUES (524, NULL, '2012-01-20 12:55:04.524061+00', 'White Heather Jig, The', 3010, 2, 4, 40, 9999, 10, 166, 0, '');
INSERT INTO 'recording' VALUES (525, NULL, '2012-01-20 12:55:04.529559+00', 'Grosvenor House Strathspey', 3010, 3, 0, 96, 9999, 5, 192, 1, '');
INSERT INTO 'recording' VALUES (526, NULL, '2012-01-20 12:55:04.535213+00', 'Campbells are Coming, The', 3010, 2, 4, 32, 9999, 1, 136, 0, '');
INSERT INTO 'recording' VALUES (527, NULL, '2012-01-20 12:55:04.540891+00', 'Balmoral Strathspey', 3010, 3, 4, 32, 9999, 5, 249, 0, '');
INSERT INTO 'recording' VALUES (528, NULL, '2012-01-20 12:55:04.546434+00', 'Miss Hadden''s Reel', 3010, 2, 8, 32, 9999, 1, 264, 0, '');
INSERT INTO 'recording' VALUES (530, NULL, '2012-01-20 12:55:04.556776+00', 'Speed the Plough', 2468, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (531, NULL, '2012-01-20 12:55:04.561648+00', 'Waltz Country Dance', 3010, 5, 4, 40, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (532, NULL, '2012-01-20 12:55:04.566453+00', 'Petronella', 2468, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (533, NULL, '2012-01-20 12:55:04.572165+00', 'Express, The', 3010, 2, 8, 40, 9999, 14, 328, 0, '');
INSERT INTO 'recording' VALUES (534, NULL, '2012-01-20 12:55:04.577836+00', 'Tempête, La', 3010, 1, 4, 48, 9999, 30, 200, 0, '');
INSERT INTO 'recording' VALUES (3617, NULL, '2012-01-20 12:55:21.797253+00', 'My Mother''s Coming In', 3041, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (3620, NULL, '2012-01-20 12:55:21.812383+00', 'West''s Hornpipe', 3041, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (3621, NULL, '2012-01-20 12:55:21.817223+00', 'Set of Jigs', 3041, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3622, NULL, '2012-01-20 12:55:21.82221+00', 'Waltz', 2065, 5, 0, 0, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (3624, NULL, '2012-01-20 12:55:21.83189+00', 'Gay Gordons', 1656, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3625, NULL, '2012-01-20 12:55:21.836741+00', 'Salute to Miss Jean Milligan', 3009, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3623, NULL, '2013-08-01 09:52:08.996248+00', 'Gay Gordons', 2092, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (511, NULL, '2014-09-16 13:11:57.294282+00', 'Lancastrian Wanderer', 3012, 2, 8, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (512, NULL, '2014-09-16 13:12:24.948094+00', 'Inn on the Moor', 3012, 3, 3, 32, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (513, NULL, '2014-09-16 13:12:47.840758+00', 'Allan Nixon''s Reel', 3012, 1, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (514, NULL, '2014-09-16 13:13:25.04888+00', 'Where Friends Meet', 3012, 3, 8, 32, 9999, NULL, 458, 0, '');
INSERT INTO 'recording' VALUES (515, NULL, '2014-09-16 13:13:57.882683+00', 'Gordon Young''s Reel', 3012, 1, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (516, NULL, '2014-09-16 13:14:30.847079+00', 'Shakin'' the Bottle', 3012, 2, 8, 32, 9999, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (504, NULL, '2014-09-30 00:07:23.683438+00', 'Riverside Jig, The', 3034, 2, 8, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (519, NULL, '2014-09-16 13:16:09.965833+00', 'Hugh Morrison''s Delight', 3012, 2, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (520, NULL, '2014-09-16 13:16:41.115899+00', 'Mike Hardie''s Reel', 3012, 1, 8, 40, 9999, NULL, 333, 0, '');
INSERT INTO 'recording' VALUES (522, NULL, '2014-09-16 13:26:33.569408+00', 'Newholme Jig', 3012, 2, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (523, NULL, '2014-09-16 13:27:00.509852+00', 'Hamish Smith''s Reel', 3012, 1, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (517, NULL, '2014-09-16 13:27:56.36937+00', 'Bill Hendry''s Reel', 3012, 1, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (489, NULL, '2014-10-19 16:18:03.108283+00', 'Dancing in the Street', 3217, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (3626, NULL, '2012-01-20 12:55:21.841539+00', 'Dundee Reel', 2182, 2, 8, 32, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (3627, NULL, '2012-01-20 12:55:21.846333+00', 'Mairi''s Wedding', 2182, 1, 4, 40, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (3628, NULL, '2012-01-20 12:55:21.851115+00', 'Polka', 2182, 13, 0, 0, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (3629, NULL, '2012-01-20 12:55:21.855909+00', 'Rambler Waltz Country Dance', 2182, 5, 4, 40, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (3630, NULL, '2012-01-20 12:55:21.860707+00', 'Eva Three Step', 2182, 11, 8, 16, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (3631, NULL, '2012-01-20 12:55:21.865507+00', 'Petronella', 2182, 1, 6, 32, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (3632, NULL, '2012-01-20 12:55:21.870549+00', 'Linton Ploughman', 2182, 2, 6, 32, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (3633, NULL, '2012-01-20 12:55:21.875546+00', 'Scottish Ramble', 2182, 3, 4, 32, 9999, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (8883, '2012-05-09 16:03:32.864162+00', '2012-05-09 16:04:21.388636+00', '50th Parallel, The', 1502, 1, 5, 48, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (8896, '2012-05-31 08:08:13.014397+00', '2012-05-31 08:08:13.014407+00', 'Inverneill House', 10034, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (8930, '2012-06-17 15:12:13.500528+00', '2012-06-17 15:12:13.500537+00', 'Chequered Court, The', 10000, 2, 8, 32, NULL, 21, 279, 0, '');
INSERT INTO 'recording' VALUES (8972, '2012-12-28 11:12:57.317612+00', '2012-12-28 11:12:57.317622+00', 'General Stuart''s Reel', 903, 1, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (3619, NULL, '2015-10-08 14:37:12.156878+00', 'Boston Two-Step, The', 3012, 2, 11, 16, 9999, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (499, NULL, '2016-08-01 08:33:08.81368+00', 'Corn Rigs', 3034, 1, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (510, NULL, '2016-09-03 20:41:48.285509+00', 'Ellwyn Strathspey', 3007, 3, 4, 48, 9999, NULL, 350, 0, '');
INSERT INTO 'recording' VALUES (8912, '2012-06-12 15:52:02.686478+00', '2019-01-05 12:28:34.836197+00', 'Silver Roses', 3012, 4, 1, 160, 10, NULL, 236, 0, '');
INSERT INTO 'recording' VALUES (8990, '2012-12-28 15:06:57.450112+00', '2012-12-28 15:06:57.450123+00', 'Two Step', 10679, 11, 4, 32, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (9000, '2012-12-28 16:33:07.288883+00', '2012-12-28 16:33:07.288895+00', 'Russian Ballet', 2583, 11, 4, 32, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (9039, '2013-01-01 18:24:29.665071+00', '2013-01-02 12:01:28.942303+00', 'Seann Triubhas Marathon 12 SOBHD', 10687, 7, 12, 16, 9999, NULL, 243, 0, '');
INSERT INTO 'recording' VALUES (9059, '2013-01-02 15:10:50.67962+00', '2013-01-02 15:10:50.67963+00', 'Tayside, The', 3678, 4, 4, 32, 1, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (9064, '2013-01-02 15:50:15.517474+00', '2013-01-02 15:50:15.517484+00', 'Kelloholm Jig, The', 3678, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (9073, '2013-01-03 08:15:48.072596+00', '2013-01-03 08:15:48.072606+00', 'Highland Wedding, The', 2088, 11, 12, 16, 9999, NULL, 238, 0, '');
INSERT INTO 'recording' VALUES (9076, '2013-01-03 08:48:13.475334+00', '2013-01-03 08:48:13.475345+00', 'Capstan Two Step, The', 2088, 11, 12, 16, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (9077, '2013-01-03 09:19:47.263392+00', '2013-01-03 09:19:47.263403+00', 'Gaelic Melodies', 2088, 5, 0, 16, 9999, NULL, 233, 0, '');
INSERT INTO 'recording' VALUES (535, NULL, '2012-01-20 12:55:04.582914+00', 'Tempête, La', 2246, 1, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (537, NULL, '2012-01-20 12:55:04.592644+00', 'Waverley', 3010, 2, 8, 48, 9999, NULL, 386, 0, '');
INSERT INTO 'recording' VALUES (538, NULL, '2012-01-20 12:55:04.597454+00', 'Gay Gordons', 3036, 11, 11, 16, 9999, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (539, NULL, '2012-01-20 12:55:04.602332+00', 'Irish Jigs', 3036, 2, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (540, NULL, '2012-01-20 12:55:04.60725+00', 'Canadian Barn Dance', 3036, 11, 8, 16, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (541, NULL, '2012-01-20 12:55:04.612083+00', 'Eva Three-Step', 3036, 11, 8, 16, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (542, NULL, '2012-01-20 12:55:04.616878+00', 'Gaelic Waltz', 3036, 5, 0, 0, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (543, NULL, '2012-01-20 12:55:04.621764+00', 'Dashing White Sergeant, The', 3036, 1, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (544, NULL, '2012-01-20 12:55:04.626573+00', 'Military Two-step', 3036, 11, 9, 16, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (545, NULL, '2012-01-20 12:55:04.631439+00', 'New Rigged Ship, The', 3036, 2, 8, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (529, NULL, '2021-04-04 11:37:02.543408+00', 'Quiet and Snug', 3010, 3, 8, 32, 9999, 5, 496, 0, '');
INSERT INTO 'recording' VALUES (521, NULL, '2021-07-03 09:13:14.428191+00', 'Golden Years', 3012, 3, 4, 48, 9999, NULL, 339, 0, '');
INSERT INTO 'recording' VALUES (498, NULL, '2021-06-21 21:35:13.890239+00', 'Let''s Meet Again', 3034, 3, 8, 32, 9999, NULL, 465, 0, '');
INSERT INTO 'recording' VALUES (546, NULL, '2012-01-20 12:55:04.636375+00', 'Modern Waltz', 3036, 5, 7, 16, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (547, NULL, '2012-01-20 12:55:04.641301+00', 'Kiss Me Quick, My Mither''s Coming', 3036, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (549, NULL, '2012-01-20 12:55:04.650985+00', 'Highland Schottische', 3036, 3, 10, 8, 9999, NULL, 232, 0, '');
INSERT INTO 'recording' VALUES (550, NULL, '2012-01-20 12:55:04.655913+00', 'Tribute to the Borders', 3036, 2, 4, 32, 9999, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (551, NULL, '2012-01-20 12:55:04.661211+00', 'Burns'' Hornpipe', 3036, 1, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (552, NULL, '2012-01-20 12:55:04.66625+00', 'Hollin Bus', 3018, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (553, NULL, '2012-01-20 12:55:04.671064+00', 'Valeta: Pierette', 3018, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (554, NULL, '2012-01-20 12:55:04.675852+00', 'Circassian Circle', 3018, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (555, NULL, '2012-01-20 12:55:04.680638+00', 'Boston Two Step', 3018, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (557, NULL, '2012-01-20 12:55:04.690402+00', 'Waltz', 3018, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (558, NULL, '2012-01-20 12:55:04.695189+00', 'Kelvingrove Two-Step', 3018, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (559, NULL, '2012-01-20 12:55:04.700015+00', 'Dunoon Barn Dance', 3018, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (560, NULL, '2012-01-20 12:55:04.705031+00', 'Gay Gordons', 3018, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (561, NULL, '2012-01-20 12:55:04.709848+00', 'Polka', 3018, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (562, NULL, '2012-01-20 12:55:04.714656+00', 'Achill Island', 3018, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (563, NULL, '2012-01-20 12:55:04.719599+00', 'Shores of Loch Alvie, The', 3018, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (564, NULL, '2012-01-20 12:55:04.72455+00', 'Gaelic Waltz', 3018, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (565, NULL, '2012-01-20 12:55:04.729435+00', 'Eightsome Reel, The', 3018, 1, 1, 464, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (567, NULL, '2012-01-20 12:55:04.739038+00', 'Hornpipe', 3018, 1, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (568, NULL, '2012-01-20 12:55:04.743827+00', 'Strip the Willow', 3018, 2, 4, 56, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (569, NULL, '2012-01-20 12:55:04.748848+00', 'Violin Solo', 3018, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (570, NULL, '2012-01-20 12:55:04.75366+00', 'Old Tyme Waltz', 3018, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (571, NULL, '2012-01-20 12:55:04.758455+00', 'Dundee Eight Hundred', 3018, 2, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (572, NULL, '2012-01-20 12:55:04.763413+00', 'Miss C. M. Barbour', 3012, 1, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (573, NULL, '2012-01-20 12:55:04.768286+00', 'Castle Park Jig, The', 3012, 2, 8, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (574, NULL, '2012-01-20 12:55:04.773478+00', 'Sandy Nixon''s Reel', 3012, 1, 8, 32, 9999, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (575, NULL, '2012-01-20 12:55:04.778571+00', 'For All the Ladies', 3012, 3, 8, 32, 9999, NULL, 451, 0, '');
INSERT INTO 'recording' VALUES (576, NULL, '2012-01-20 12:55:04.783399+00', 'Jiggery Pokery', 3012, 2, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (3634, NULL, '2012-01-20 12:55:21.880362+00', 'Two Step', 2182, 99, 0, 0, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (3635, NULL, '2012-01-20 12:55:21.885179+00', 'Scottish Waltz Medley', 2182, 5, 0, 0, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (3636, NULL, '2012-01-20 12:55:21.889989+00', 'Gay Gordons', 2182, 11, 0, 16, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (3637, NULL, '2012-01-20 12:55:21.894836+00', 'Reel Medley', 2182, 1, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (3638, NULL, '2012-01-20 12:55:21.899642+00', 'Hot Punch', 3042, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3639, NULL, '2012-01-20 12:55:21.904433+00', 'Trip to Bavaria, A', 3042, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3640, NULL, '2012-01-20 12:55:21.909218+00', 'Boston Two Step', 3042, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3641, NULL, '2012-01-20 12:55:21.914006+00', 'Keep Your Feet Still, Geordie Hinny', 3042, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3642, NULL, '2012-01-20 12:55:21.918805+00', 'Drops of Brandy', 3042, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3643, NULL, '2012-01-20 12:55:21.923584+00', 'Gay Gordons', 3042, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3644, NULL, '2012-01-20 12:55:21.928365+00', 'Scottish Waltz', 3042, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3645, NULL, '2012-01-20 12:55:21.933167+00', 'He''s Aye Kissing Me', 3042, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3646, NULL, '2012-01-20 12:55:21.937984+00', 'Mason''s Apron, The', 3042, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3647, NULL, '2012-01-20 12:55:21.942805+00', 'Skyline of Skye, The', 3042, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3648, NULL, '2012-01-20 12:55:21.947589+00', 'Morpeth Rant', 3042, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3649, NULL, '2012-01-20 12:55:21.952414+00', 'Gay Gordons', 2328, 11, 0, 16, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (3650, NULL, '2012-01-20 12:55:21.957257+00', 'Canadian Medley', 3067, 4, 0, 0, 9999, NULL, 125, 0, '');
INSERT INTO 'recording' VALUES (3651, NULL, '2012-01-20 12:55:21.962069+00', 'Strathspey and Reel Medley', 3067, 4, 0, 0, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (3652, NULL, '2012-01-20 12:55:21.96695+00', 'Waltz', 3067, 5, 0, 0, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (3653, NULL, '2012-01-20 12:55:21.971734+00', 'Hornpipe Medley', 3067, 1, 0, 0, 9999, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (536, NULL, '2012-02-11 14:22:51.947425+00', 'Barn Dance', 2246, 50, 0, 16, 9999, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (8869, '2012-04-29 14:28:26.076291+00', '2012-04-29 14:28:26.0763+00', 'Jigs (with pauses between turns)', 1502, 2, 3, 40, NULL, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (8897, '2012-05-31 08:13:13.221778+00', '2012-05-31 08:13:13.221787+00', 'Follow Me Home', 10034, 2, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (8931, '2012-06-17 15:15:04.921605+00', '2012-06-17 15:16:53.119698+00', 'Deil Amang the Tailors, The', 10000, 1, 8, 32, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (8973, '2012-12-28 11:15:30.629701+00', '2012-12-28 11:22:06.993337+00', 'Waltz and Auld Lang Syne', 903, 5, 1, 0, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (9001, '2012-12-28 16:36:29.408555+00', '2012-12-28 16:36:29.408565+00', 'Gypsy Tap', 2583, 11, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (9040, '2013-01-01 18:27:49.42519+00', '2013-01-02 12:02:45.855732+00', 'Half Hullachan 4 SOBHD', 10687, 7, 4, 16, 9999, NULL, 90, 0, '');
INSERT INTO 'recording' VALUES (9060, '2013-01-02 15:18:01.90099+00', '2013-01-02 15:18:01.901+00', 'Distaff Side, The', 3678, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (9065, '2013-01-02 15:58:27.403809+00', '2013-01-02 15:58:27.403819+00', 'Mairi''s Wedding', 3678, 1, 4, 40, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (9074, '2013-01-03 08:23:14.613244+00', '2013-01-03 08:23:14.613254+00', 'Orkney Memories', 2088, 5, 12, 16, 9999, NULL, 223, 0, '');
INSERT INTO 'recording' VALUES (9078, '2013-01-03 09:39:25.33555+00', '2013-01-03 09:39:25.33556+00', 'Northern Reels', 2088, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (577, NULL, '2012-01-20 12:55:04.788267+00', 'Lesley Nixon''s Reel', 3012, 1, 8, 32, 9999, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (579, NULL, '2012-01-20 12:55:04.797964+00', 'MO''s Jig', 3012, 2, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (580, NULL, '2012-01-20 12:55:04.802783+00', 'Miss Suzanne Barbour', 3012, 1, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (581, NULL, '2012-01-20 12:55:04.807713+00', 'By Dundonald', 3012, 3, 3, 32, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (582, NULL, '2012-01-20 12:55:04.812657+00', 'Cuckoo Clock, The', 3012, 1, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (583, NULL, '2012-01-20 12:55:04.817498+00', 'Whitby Wedding, The', 3012, 2, 4, 40, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (584, NULL, '2012-01-20 12:55:04.82234+00', 'C.J.''s Reel', 3012, 1, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (586, NULL, '2012-01-20 12:55:04.833391+00', 'Merry Oddfellows, The', 3002, 2, 8, 32, 9999, 1, 289, 0, '');
INSERT INTO 'recording' VALUES (587, NULL, '2012-01-20 12:55:04.839069+00', 'Marquis of Lorne, The', 3002, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (588, NULL, '2012-01-20 12:55:04.844721+00', 'Rosnor Abbey', 3002, 2, 8, 40, 9999, 6, 358, 0, '');
INSERT INTO 'recording' VALUES (589, NULL, '2012-01-20 12:55:04.850506+00', 'Lady Lucy Ramsay', 3002, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (590, NULL, '2012-01-20 12:55:04.855342+00', 'Johnny Groat''s House', 3023, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (591, NULL, '2012-01-20 12:55:04.86014+00', 'Lady Auckland''s Reel', 3023, 3, 8, 32, 9999, NULL, 488, 0, '');
INSERT INTO 'recording' VALUES (592, NULL, '2012-01-20 12:55:04.865046+00', 'Lady Baird''s Reel', 3023, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (593, NULL, '2012-01-20 12:55:04.869949+00', 'Lady Louisa MacDonald''s Strathspey', 3023, 3, 8, 32, 9999, NULL, 500, 0, '');
INSERT INTO 'recording' VALUES (594, NULL, '2012-01-20 12:55:04.875048+00', 'Lassies of Dunse, The', 3023, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (595, NULL, '2012-01-20 12:55:04.879862+00', 'Leith Country Dance', 3023, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (596, NULL, '2012-01-20 12:55:04.884676+00', 'Longwise Eightsome Reel', 3023, 4, 0, 64, 9999, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (597, NULL, '2012-01-20 12:55:04.88953+00', 'Off She Goes in the North', 3023, 2, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (598, NULL, '2012-01-20 12:55:04.894329+00', 'Prince of Wales Strathspey', 3023, 3, 8, 40, 9999, NULL, 612, 0, '');
INSERT INTO 'recording' VALUES (566, NULL, '2020-09-22 18:37:38.212468+00', 'Wind on Loch Fyne, The', 3018, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (578, NULL, '2021-06-21 21:30:58.137286+00', 'Iain Nixon''s Reel', 3012, 1, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (599, NULL, '2012-01-20 12:55:04.899203+00', 'Sutters of Selkirk, The', 3023, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (600, NULL, '2012-01-20 12:55:04.904101+00', 'Axum Reel, The', 3023, 3, 0, 32, 9999, NULL, 67, 0, '');
INSERT INTO 'recording' VALUES (601, NULL, '2012-01-20 12:55:04.908995+00', 'Axum Reel, The', 3023, 3, 0, 32, 9999, NULL, 68, 0, '');
INSERT INTO 'recording' VALUES (602, NULL, '2012-01-20 12:55:04.91458+00', 'Trip to Aberdeen, A', 3022, 2, 8, 32, 9999, 1, 287, 0, '');
INSERT INTO 'recording' VALUES (603, NULL, '2012-01-20 12:55:04.920211+00', 'Keppoch''s Rant', 3022, 3, 8, 32, 9999, 5, 502, 0, '');
INSERT INTO 'recording' VALUES (604, NULL, '2012-01-20 12:55:04.925702+00', 'Captain MacBean''s Reel', 3022, 1, 8, 32, 9999, 5, 274, 0, '');
INSERT INTO 'recording' VALUES (605, NULL, '2012-01-20 12:55:04.93126+00', 'Countess of Crawford''s Reel', 3022, 3, 8, 40, 9999, 6, 616, 0, '');
INSERT INTO 'recording' VALUES (606, NULL, '2012-01-20 12:55:04.936756+00', 'My Mother''s Coming In', 3021, 1, 8, 32, 9999, 5, 285, 0, '');
INSERT INTO 'recording' VALUES (607, NULL, '2012-01-20 12:55:04.942281+00', 'Miss Heyden', 3022, 3, 8, 40, 9999, 6, 627, 0, '');
INSERT INTO 'recording' VALUES (608, NULL, '2012-01-20 12:55:04.947764+00', 'Bonnie Kate of Aberdeen', 3022, 3, 8, 40, 9999, 6, 623, 0, '');
INSERT INTO 'recording' VALUES (609, NULL, '2012-01-20 12:55:04.953319+00', 'Bob Sanders', 3022, 2, 8, 40, 9999, 14, 354, 0, '');
INSERT INTO 'recording' VALUES (610, NULL, '2012-01-20 12:55:04.958816+00', 'Perthshire Highlanders, The', 3022, 3, 8, 32, 9999, 5, 497, 0, '');
INSERT INTO 'recording' VALUES (611, NULL, '2012-01-20 12:55:04.964373+00', 'Twenty-First of September', 3022, 1, 8, 40, 9999, 6, 343, 0, '');
INSERT INTO 'recording' VALUES (612, NULL, '2012-01-20 12:55:04.970068+00', 'Donald Bane', 3022, 3, 8, 32, 9999, 5, 500, 0, '');
INSERT INTO 'recording' VALUES (613, NULL, '2012-01-20 12:55:04.975905+00', 'Lord Rosslyn''s Fancy', 3041, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (615, NULL, '2012-01-20 12:55:04.985577+00', 'Bridge of Nairn', 3018, 3, 8, 32, 9999, NULL, 500, 0, '');
INSERT INTO 'recording' VALUES (616, NULL, '2012-01-20 12:55:04.990449+00', 'Willie wi'' his Tartan Trews', 3018, 2, 8, 40, 9999, NULL, 348, 0, '');
INSERT INTO 'recording' VALUES (3654, NULL, '2012-01-20 12:55:21.976531+00', 'Marches', 3067, 11, 0, 0, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (3655, NULL, '2012-01-20 12:55:21.981337+00', 'Polka', 3067, 13, 0, 0, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (3656, NULL, '2012-01-20 12:55:21.986133+00', 'Air, Strathspey and Reel Medley', 3067, 98, 0, 0, 9999, NULL, 224, 0, '');
INSERT INTO 'recording' VALUES (3657, NULL, '2012-01-20 12:55:21.990937+00', 'Dashing White Sgt.', 2180, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9083, '2013-01-03 10:19:57.184849+00', '2013-01-03 10:19:57.184874+00', 'Celebration, The', 2088, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (3659, NULL, '2012-01-20 12:55:22.000527+00', 'Circle Waltz', 2180, 5, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3660, NULL, '2012-01-20 12:55:22.005327+00', 'Gay Gordons', 2180, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3661, NULL, '2012-01-20 12:55:22.010114+00', 'Loch Leven Polka', 2180, 13, 0, 0, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (3663, NULL, '2012-01-20 12:55:22.019713+00', 'Reel of the 51st Division, The', 2180, 1, 8, 32, 9999, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (3664, NULL, '2012-01-20 12:55:22.024529+00', 'Fyket, The', 2180, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3665, NULL, '2012-01-20 12:55:22.029892+00', 'Duke of Perth', 2180, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3666, NULL, '2012-01-20 12:55:22.034726+00', 'Donald Bane', 3001, 3, 3, 32, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (3667, NULL, '2012-01-20 12:55:22.039599+00', 'Gaelic Waltz Selection', 2180, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3668, NULL, '2012-01-20 12:55:22.044504+00', 'Selection of Jigs', 3067, 2, 5, 32, 9999, NULL, 159, 0, '');
INSERT INTO 'recording' VALUES (3669, NULL, '2012-01-20 12:55:22.049316+00', 'Marches', 3067, 11, 0, 0, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (3670, NULL, '2012-01-20 12:55:22.054102+00', 'Strathspey and Reel Medley', 3067, 4, 0, 0, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (3671, NULL, '2012-01-20 12:55:22.058889+00', 'Waltz Medley', 3067, 5, 0, 0, 9999, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (3672, NULL, '2012-01-20 12:55:22.063988+00', 'Hornpipe Medley', 3067, 1, 0, 0, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (3673, NULL, '2012-01-20 12:55:22.068791+00', 'Scottish Fancy, A', 3067, 98, 0, 0, 9999, NULL, 346, 0, '');
INSERT INTO 'recording' VALUES (3674, NULL, '2012-01-20 12:55:22.073589+00', 'Reel', 2291, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (8870, '2012-04-29 14:31:33.442009+00', '2012-04-29 14:31:33.442019+00', 'Reels (Scotch Measure) (with pauses between turns)', 1502, 1, 3, 40, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (8898, '2012-05-31 08:16:38.820407+00', '2012-05-31 08:16:38.820417+00', 'Bruce''s Men', 10034, 3, 3, 32, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (9085, '2013-01-03 10:49:02.604801+00', '2013-01-03 10:49:02.604811+00', 'Irish Jigs', 2088, 2, 5, 48, 9999, NULL, 237, 0, '');
INSERT INTO 'recording' VALUES (3658, NULL, '2012-11-29 07:40:56.627855+00', 'Turriff Schottische, The', 2180, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9002, '2012-12-28 16:38:35.766379+00', '2012-12-28 16:38:35.76639+00', 'Kelvingrove Two Step', 2583, 11, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (9041, '2013-01-01 18:29:45.658557+00', '2013-01-02 12:03:18.816113+00', 'Hullachan 8 SOBHD', 10687, 7, 8, 16, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (3662, NULL, '2013-08-05 10:51:38.3948+00', 'Canadian Barn Dance', 2180, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9079, '2013-01-03 09:48:43.996718+00', '2013-01-03 09:48:43.996728+00', 'Drop of Brandy, A', 2088, 1, 6, 32, 9999, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (9086, '2013-01-03 11:06:16.326787+00', '2013-01-03 11:06:16.326797+00', 'Percy French Set, The', 2088, 5, 6, 32, 9999, NULL, 488, 0, '');
INSERT INTO 'recording' VALUES (9088, '2013-01-03 11:24:10.690464+00', '2013-01-03 11:24:10.690474+00', 'Dumfries & Galloway Reels', 2088, 1, 4, 48, 9999, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (9089, '2013-01-04 12:19:26.634209+00', '2013-01-04 12:19:26.634219+00', 'Deil Amang the Tailors, The', 3067, 1, 8, 32, 9999, NULL, 303, 0, '');
INSERT INTO 'recording' VALUES (9102, '2013-01-04 15:28:07.691886+00', '2013-01-04 15:28:07.691897+00', 'Meeting and Greeting', 10569, 2, 6, 32, 9999, NULL, 220, 0, '');
INSERT INTO 'recording' VALUES (9110, '2013-01-04 16:10:58.641812+00', '2013-01-04 16:10:58.641824+00', 'Homage à Canada', 3092, 98, 0, 0, 9999, NULL, 376, 0, '');
INSERT INTO 'recording' VALUES (9111, '2013-01-04 16:23:51.524695+00', '2013-01-04 16:23:51.524705+00', 'Susan''s Souvenir', 3483, 3, 3, 32, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (9115, '2013-01-05 16:09:02.413346+00', '2013-01-05 16:09:02.413356+00', 'Military Two-Step', 10108, 11, 12, 16, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (9124, '2013-01-05 17:09:25.856006+00', '2013-01-05 17:09:25.856017+00', 'Slow Air', 10108, 98, 0, 0, 9999, NULL, 124, 0, '');
INSERT INTO 'recording' VALUES (617, NULL, '2012-01-20 12:55:04.995363+00', 'Grant''s Reel', 3018, 3, 8, 32, 9999, NULL, 510, 0, '');
INSERT INTO 'recording' VALUES (618, NULL, '2012-01-20 12:55:05.000244+00', 'Push About the Jorum', 3018, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (619, NULL, '2012-01-20 12:55:05.005042+00', 'Miss Nancy Frowns', 3018, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (620, NULL, '2012-01-20 12:55:05.009836+00', 'Wild Geese, The', 1396, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (621, NULL, '2012-01-20 12:55:05.014779+00', 'Flower of the Quern, The', 1396, 3, 4, 32, 9999, NULL, 258, 1, '');
INSERT INTO 'recording' VALUES (622, NULL, '2012-01-20 12:55:05.019575+00', 'Gilly Flower, The', 1396, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (624, NULL, '2012-01-20 12:55:05.029293+00', 'Lullaby for Thomas', 1396, 98, 0, 0, 9999, NULL, 126, 0, '');
INSERT INTO 'recording' VALUES (625, NULL, '2012-01-20 12:55:05.034198+00', 'Maxwell''s Rant', 1396, 1, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (626, NULL, '2012-01-20 12:55:05.039081+00', 'Wicked Willy', 1396, 1, 8, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (627, NULL, '2012-01-20 12:55:05.043887+00', 'Miss Hadden''s Reel', 1396, 2, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (628, NULL, '2012-01-20 12:55:05.048675+00', 'Railway Man, The', 1396, 3, 4, 32, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (629, NULL, '2012-01-20 12:55:05.053537+00', 'College Hornpipe, The', 1396, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (630, NULL, '2012-01-20 12:55:05.058352+00', 'Miss Hilary Ann', 1396, 2, 8, 40, 9999, NULL, 340, 0, '');
INSERT INTO 'recording' VALUES (631, NULL, '2012-01-20 12:55:05.063868+00', 'Abernethy Lassies', 3002, 1, 8, 32, 9999, 5, 285, 0, '');
INSERT INTO 'recording' VALUES (632, NULL, '2012-01-20 12:55:05.069363+00', 'Brechin Fancy', 3002, 1, 8, 32, 9999, 5, 284, 0, '');
INSERT INTO 'recording' VALUES (633, NULL, '2012-01-20 12:55:05.074903+00', 'Duke of Roxburgh''s Reel', 3002, 1, 8, 24, 9999, 16, 216, 0, '');
INSERT INTO 'recording' VALUES (634, NULL, '2012-01-20 12:55:05.080408+00', 'Lady Charlotte Bruce', 3002, 3, 8, 32, 9999, 5, 505, 0, '');
INSERT INTO 'recording' VALUES (635, NULL, '2012-01-20 12:55:05.085989+00', 'Lady Glasgow', 3002, 3, 8, 32, 9999, 5, 498, 0, '');
INSERT INTO 'recording' VALUES (636, NULL, '2012-01-20 12:55:05.091558+00', 'Whiteadder Jig, The', 1502, 2, 8, 32, 9999, 1, 283, 0, '');
INSERT INTO 'recording' VALUES (637, NULL, '2012-01-20 12:55:05.097159+00', 'Anna Holden''s Strathspey', 1502, 3, 8, 32, 9999, 5, 533, 0, '');
INSERT INTO 'recording' VALUES (9087, '2013-01-03 11:15:40.740692+00', '2013-01-03 11:15:40.740703+00', 'Old 2/4''s, The', 2088, 11, 8, 16, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (639, NULL, '2012-01-20 12:55:05.108263+00', 'Flodigarry Strathspey', 1502, 3, 3, 40, 9999, 6, 257, 0, '');
INSERT INTO 'recording' VALUES (640, NULL, '2012-01-20 12:55:05.113764+00', 'Moffat Weavers, The', 1502, 2, 4, 32, 9999, 5, 147, 0, '');
INSERT INTO 'recording' VALUES (642, NULL, '2012-01-20 12:55:05.124215+00', 'McLaughlin''s Reel', 1502, 1, 8, 32, 9999, 1, 288, 0, '');
INSERT INTO 'recording' VALUES (643, NULL, '2012-01-20 12:55:05.12971+00', 'Scamp, The', 1502, 2, 8, 32, 9999, 1, 286, 0, '');
INSERT INTO 'recording' VALUES (644, NULL, '2012-01-20 12:55:05.135201+00', 'John Derek Evans', 1502, 3, 8, 32, 9999, 5, 544, 0, '');
INSERT INTO 'recording' VALUES (645, NULL, '2012-01-20 12:55:05.140774+00', 'Fraser''s Fiddle', 1502, 1, 8, 32, 9999, 5, 285, 0, '');
INSERT INTO 'recording' VALUES (647, NULL, '2012-01-20 12:55:05.151465+00', 'Fidget', 3018, 1, 8, 32, 9999, 5, 288, 0, '');
INSERT INTO 'recording' VALUES (648, NULL, '2012-01-20 12:55:05.157048+00', 'Lady Harriet Hope''s Reel', 3018, 1, 8, 32, 9999, 5, 284, 0, '');
INSERT INTO 'recording' VALUES (649, NULL, '2012-01-20 12:55:05.162549+00', 'Caledonian Rant, The', 3018, 3, 8, 32, 9999, 5, 505, 0, '');
INSERT INTO 'recording' VALUES (650, NULL, '2012-01-20 12:55:05.16806+00', 'Todlen Hame', 3018, 2, 8, 32, 9999, 5, 283, 0, '');
INSERT INTO 'recording' VALUES (651, NULL, '2012-01-20 12:55:05.174772+00', 'Struan Robertson''s Reel', 3018, 1, 8, 40, 9999, 6, 355, 0, '');
INSERT INTO 'recording' VALUES (652, NULL, '2012-01-20 12:55:05.180521+00', 'Golden Pheasant, The', 3018, 2, 8, 40, 9999, 28, 336, 0, '');
INSERT INTO 'recording' VALUES (653, NULL, '2012-01-20 12:55:05.186787+00', 'Lord Hume''s Reel', 3018, 3, 8, 40, 9999, 6, 633, 0, '');
INSERT INTO 'recording' VALUES (654, NULL, '2012-01-20 12:55:05.192538+00', 'Woo''d and Married and A''', 3018, 2, 8, 32, 9999, 5, 276, 0, '');
INSERT INTO 'recording' VALUES (655, NULL, '2012-01-20 12:55:05.198181+00', 'Reverend John MacFarlane, The', 3021, 1, 4, 32, 9999, 1, 141, 0, '');
INSERT INTO 'recording' VALUES (656, NULL, '2012-01-20 12:55:05.203721+00', 'Moment of Truth', 3021, 3, 8, 32, 9999, 5, 498, 0, '');
INSERT INTO 'recording' VALUES (657, NULL, '2012-01-20 12:55:05.209204+00', 'Gothenburg''s Welcome', 3021, 2, 8, 32, 9999, 1, 276, 0, '');
INSERT INTO 'recording' VALUES (3675, NULL, '2012-01-20 12:55:22.078398+00', 'Jig', 2291, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3676, NULL, '2012-01-20 12:55:22.083214+00', 'Scottische', 2291, 50, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3677, NULL, '2012-01-20 12:55:22.088024+00', 'Waltz', 2291, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (646, NULL, '2022-12-09 21:06:19.475464+00', 'Medley', 1502, 98, 0, 0, 9999, NULL, 305, 0, '');
INSERT INTO 'recording' VALUES (623, NULL, '2022-12-16 12:40:16.005876+00', 'Manchester Medley, A', 1396, 4, 0, 128, 2, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (3679, NULL, '2012-01-20 12:55:22.097907+00', 'Reel', 2291, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3680, NULL, '2012-01-20 12:55:22.102722+00', 'Duke of Perth', 2291, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3681, NULL, '2012-01-20 12:55:22.107515+00', 'Jig', 2291, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3682, NULL, '2012-01-20 12:55:22.11232+00', 'Stathspey', 2291, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3683, NULL, '2012-01-20 12:55:22.117131+00', 'Jig', 2291, 2, 8, 24, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3684, NULL, '2012-01-20 12:55:22.121949+00', 'Waltz', 2291, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3685, NULL, '2012-01-20 12:55:22.126773+00', 'Hamilton Rant, The', 2291, 1, 8, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3686, NULL, '2012-01-20 12:55:22.131581+00', 'Gay Gordons', 3026, 11, 0, 16, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (3687, NULL, '2012-01-20 12:55:22.136395+00', 'Scottish Waltz Medley', 3026, 5, 0, 0, 9999, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (3688, NULL, '2012-01-20 12:55:22.141177+00', 'Primrose Polka', 2189, 13, 0, 0, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (3689, NULL, '2012-01-20 12:55:22.145991+00', 'Northern Lights of Aberdeen, The', 3026, 5, 0, 0, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (3690, NULL, '2012-01-20 12:55:22.150872+00', 'Dundee Reel, The', 3026, 2, 8, 40, 9999, NULL, 338, 0, '');
INSERT INTO 'recording' VALUES (3691, NULL, '2012-01-20 12:55:22.15583+00', 'Liberton Pipe Band, The', 3026, 50, 0, 0, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (3692, NULL, '2012-01-20 12:55:22.160676+00', 'Veleta, The', 3026, 5, 0, 16, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (3693, NULL, '2012-01-20 12:55:22.165469+00', 'Baldovan Reel', 3026, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (3694, NULL, '2012-01-20 12:55:22.170319+00', 'Scottish Barn Dance', 3026, 50, 0, 0, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (3695, NULL, '2012-01-20 12:55:22.175104+00', 'Waltz Country Dance', 3026, 5, 0, 40, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (9090, '2013-01-04 12:21:10.446245+00', '2013-01-04 12:21:10.446256+00', 'Duke of Atholl''s Reel, The', 3067, 2, 6, 32, NULL, NULL, 222, 0, '');
INSERT INTO 'recording' VALUES (638, NULL, '2012-03-23 10:15:43.037733+00', 'Rain Dancin'', Da', 1502, 1, 8, 32, 9999, 5, 286, 0, '');
INSERT INTO 'recording' VALUES (8899, '2012-05-31 08:22:23.847884+00', '2012-05-31 08:22:23.847893+00', 'John of Bon Accord', 10034, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (9042, '2013-01-01 18:31:20.553958+00', '2013-01-02 12:03:02.881258+00', 'Hullachan 8 Adult', 10687, 7, 8, 16, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (9080, '2013-01-03 09:55:59.401453+00', '2013-01-03 09:55:59.401464+00', 'Set of 4/4 Marches', 2088, 11, 6, 32, 9999, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (9082, '2013-01-03 10:07:16.661215+00', '2013-01-03 10:07:16.661226+00', 'Hebridean, The', 2088, 5, 8, 16, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (9084, '2013-01-03 10:28:05.920929+00', '2013-01-03 10:28:05.920939+00', 'Happy We''ve Been', 2088, 3, 10, 8, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (9103, '2013-01-04 15:31:16.239279+00', '2013-01-04 15:31:16.239291+00', 'Isle of Aigas, The', 10695, 98, 0, 0, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (9112, '2013-01-04 16:26:13.680133+00', '2013-01-04 16:26:13.680145+00', 'Selkie, The', 10695, 98, 0, 0, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (9116, '2013-01-05 16:16:34.306036+00', '2013-01-05 16:16:34.306046+00', 'St Bernard''s Waltz', 10108, 5, 0, 32, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (9117, '2013-01-05 16:25:55.289197+00', '2013-01-05 16:33:38.057281+00', 'Shetland Eightsome Reel', 10108, 1, 1, 560, 9999, NULL, 569, 0, '');
INSERT INTO 'recording' VALUES (9125, '2013-01-05 17:13:09.86352+00', '2013-01-05 17:13:09.863531+00', 'Call of the Pipes', 10108, 11, 8, 16, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (9132, '2013-01-05 17:51:02.139454+00', '2013-01-05 17:51:02.139464+00', 'Jig & Reel', 10108, 98, 0, 128, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (658, NULL, '2012-01-20 12:55:05.214706+00', 'Wisp of Thistle', 3021, 3, 8, 32, 9999, 5, 492, 0, '');
INSERT INTO 'recording' VALUES (659, NULL, '2012-01-20 12:55:05.220619+00', 'Saint Andrew''s of Brampton', 3021, 1, 4, 32, 9999, 1, 145, 0, '');
INSERT INTO 'recording' VALUES (660, NULL, '2012-01-20 12:55:05.226568+00', 'Bonnie Ina Campbell', 3021, 3, 8, 32, 9999, 5, 493, 0, '');
INSERT INTO 'recording' VALUES (661, NULL, '2012-01-20 12:55:05.232227+00', 'Nurseryman, The', 3021, 2, 8, 32, 9999, 1, 276, 0, '');
INSERT INTO 'recording' VALUES (662, NULL, '2012-01-20 12:55:05.237739+00', 'Queen City Salute, The', 3021, 4, 4, 64, 5, 5, 387, 0, '');
INSERT INTO 'recording' VALUES (663, NULL, '2012-01-20 12:55:05.242658+00', 'Trip to Bavaria, A', 3038, 1, 4, 32, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (664, NULL, '2012-01-20 12:55:05.247469+00', 'Ian Powrie''s Farewell to Auchterarder', 3038, 2, 0, 128, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (665, NULL, '2012-01-20 12:55:05.252266+00', 'Wind on Loch Fyne, The', 3038, 3, 3, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (666, NULL, '2012-01-20 12:55:05.257127+00', 'Polharrow Burn', 3038, 1, 5, 32, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (667, NULL, '2012-01-20 12:55:05.262057+00', 'Bees of Maggieknockater, The', 3038, 2, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (668, NULL, '2012-01-20 12:55:05.266869+00', 'Schiehallion', 3038, 4, 0, 128, 2, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (669, NULL, '2012-01-20 12:55:05.271662+00', 'Equilibrium, The', 3038, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (10219, '2018-09-15 09:38:22.746373+00', '2018-11-06 21:54:11.322793+00', 'Scallywag, The', 10659, 2, 8, 40, NULL, NULL, 348, 0, '');
INSERT INTO 'recording' VALUES (670, NULL, '2012-01-20 12:55:05.276448+00', 'Earlstoun Loch', 3038, 1, 5, 32, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (671, NULL, '2012-01-20 12:55:05.281318+00', 'Round Reel of Eight, The', 3038, 1, 0, 88, 9999, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (672, NULL, '2012-01-20 12:55:05.286191+00', 'Weathercock, The', 3038, 2, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (673, NULL, '2012-01-20 12:55:05.291007+00', 'Autumn in Appin', 3038, 3, 4, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (674, NULL, '2012-01-20 12:55:05.295811+00', 'Earl of Mansfield, The', 3038, 1, 4, 48, 9999, NULL, 223, 0, '');
INSERT INTO 'recording' VALUES (675, NULL, '2012-01-20 12:55:05.300666+00', 'MacLeod''s Fancy', 3038, 2, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (676, NULL, '2012-01-20 12:55:05.305473+00', 'Johnnie Walker', 3038, 4, 0, 128, 13, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (678, NULL, '2012-01-20 12:55:05.315132+00', 'Life Begins at Forty', 3039, 2, 4, 40, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (679, NULL, '2012-01-20 12:55:05.319979+00', 'Tyneside Schottische, The', 3039, 3, 0, 80, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (681, NULL, '2012-01-20 12:55:05.329599+00', 'Octogenarian, The', 3039, 3, 4, 32, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (683, NULL, '2012-01-20 12:55:05.339265+00', 'Long Sands, The', 3039, 3, 8, 32, 9999, NULL, 457, 0, '');
INSERT INTO 'recording' VALUES (684, NULL, '2012-01-20 12:55:05.344142+00', 'Tosson Hill', 3039, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (685, NULL, '2012-01-20 12:55:05.348968+00', 'Ronda Blue', 3039, 3, 8, 32, 9999, NULL, 470, 0, '');
INSERT INTO 'recording' VALUES (686, NULL, '2012-01-20 12:55:05.353842+00', 'Snake Pass, The', 3039, 2, 8, 32, 9999, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (687, NULL, '2012-01-20 12:55:05.358645+00', 'Moorgate Ramble', 3039, 3, 4, 32, 9999, NULL, 236, 0, '');
INSERT INTO 'recording' VALUES (688, NULL, '2012-01-20 12:55:05.364144+00', 'Balcomie House', 3040, 2, 3, 48, 9999, 11, 159, 0, '');
INSERT INTO 'recording' VALUES (689, NULL, '2012-01-20 12:55:05.368955+00', 'Farewell to the North', 3040, 4, 0, 96, 21, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (690, NULL, '2012-01-20 12:55:05.374463+00', 'Black Mountain Reel, The', 3040, 1, 5, 32, 9999, 1, 180, 0, '');
INSERT INTO 'recording' VALUES (680, NULL, '2021-07-15 23:04:25.6235+00', 'Nice and Easy', 3039, 1, 4, 32, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (691, NULL, '2012-01-20 12:55:05.379939+00', 'Wee Cooper o'' Fife, The', 3040, 2, 4, 40, 9999, 3, 179, 0, '');
INSERT INTO 'recording' VALUES (9133, '2013-01-05 17:55:41.728039+00', '2013-01-05 17:55:41.72805+00', 'Old Time Waltz', 10108, 5, 0, 32, 9999, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (693, NULL, '2012-01-20 12:55:05.391341+00', 'Miss C. M. Barbour', 3040, 1, 4, 32, 9999, 1, 144, 0, '');
INSERT INTO 'recording' VALUES (694, NULL, '2012-01-20 12:55:05.396866+00', 'Hopetoun House', 3040, 2, 8, 32, 9999, 1, 267, 0, '');
INSERT INTO 'recording' VALUES (695, NULL, '2012-01-20 12:55:05.402381+00', 'None So Pretty', 3040, 1, 4, 40, 9999, 6, 176, 0, '');
INSERT INTO 'recording' VALUES (696, NULL, '2012-01-20 12:55:05.407952+00', 'Johnnie Walker', 3040, 4, 0, 128, 13, 1, 193, 0, '');
INSERT INTO 'recording' VALUES (697, NULL, '2012-01-20 12:55:05.413442+00', 'Argyll''s Fancy', 3040, 2, 4, 48, 9999, 13, 206, 0, '');
INSERT INTO 'recording' VALUES (698, NULL, '2012-01-20 12:55:05.418926+00', 'Strathglass House', 3040, 3, 4, 32, 9999, 5, 246, 0, '');
INSERT INTO 'recording' VALUES (3696, NULL, '2012-01-20 12:55:22.179919+00', 'Dashing White Sergeant, The', 3026, 1, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (3697, NULL, '2012-01-20 12:55:22.184726+00', 'Hesitation Waltz', 3026, 5, 8, 16, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (3698, NULL, '2012-01-20 12:55:22.189589+00', 'Royal Exchange', 3026, 2, 8, 32, 9999, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (3699, NULL, '2012-01-20 12:55:22.194408+00', 'Laird of Drumblair and The Mason''s Apron, The', 3026, 4, 0, 64, 9999, NULL, 86, 0, '');
INSERT INTO 'recording' VALUES (3700, NULL, '2012-01-20 12:55:22.199208+00', 'Gay Gordons', 3026, 11, 6, 16, 9999, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (3701, NULL, '2012-01-20 12:55:22.203996+00', 'Strathspey and Reel', 3026, 4, 0, 64, 5, NULL, 96, 0, '');
INSERT INTO 'recording' VALUES (3702, NULL, '2012-01-20 12:55:22.208815+00', 'Hamilton Rant, The', 3026, 1, 4, 48, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (3703, NULL, '2012-01-20 12:55:22.213626+00', 'George Black Polka, The', 3026, 13, 0, 0, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (3704, NULL, '2012-01-20 12:55:22.218413+00', 'Reel', 3026, 1, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (3706, NULL, '2012-01-20 12:55:22.227991+00', 'Pipe Marches', 3009, 11, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9135, '2013-01-06 13:40:10.426612+00', '2013-01-06 13:40:10.426623+00', 'Scottish Waltz', 3018, 5, 0, 32, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (3708, NULL, '2012-01-20 12:55:22.237707+00', 'Set of Reels', 3004, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3709, NULL, '2012-01-20 12:55:22.242494+00', 'Latheron Wheel Polka', 3004, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3710, NULL, '2012-01-20 12:55:22.247285+00', 'Set of Reels', 2296, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3711, NULL, '2012-01-20 12:55:22.252091+00', 'Pride of Scotland Waltz', 3004, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3712, NULL, '2012-01-20 12:55:22.257909+00', 'Set of Jigs', 2295, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3715, NULL, '2012-01-20 12:55:22.276952+00', 'Scandinavian Barn Dance', 3004, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3707, NULL, '2012-02-11 14:32:04.839671+00', 'Mason''s Apron, The', 2246, 1, 8, 32, 9999, NULL, 247, 0, '');
INSERT INTO 'recording' VALUES (692, NULL, '2012-08-30 05:33:26.567124+00', 'Duchess Tree, The', 3040, 3, 4, 32, 9999, 5, 253, 0, '');
INSERT INTO 'recording' VALUES (9004, '2012-12-28 16:46:15.842786+00', '2012-12-28 16:46:15.842796+00', 'Bratach Bana', 2583, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (9043, '2013-01-01 18:35:55.770758+00', '2013-01-01 18:35:55.770769+00', 'Strathspey & Highland Reel 2+2 SOBHD', 10687, 7, 4, 16, 9999, NULL, 120, 0, '');
INSERT INTO 'recording' VALUES (9104, '2013-01-04 15:33:04.913911+00', '2013-01-04 15:33:04.913924+00', 'Mungo', 10695, 98, 0, 0, 9999, NULL, 241, 0, '');
INSERT INTO 'recording' VALUES (9113, '2013-01-04 16:30:41.262741+00', '2013-01-04 16:30:41.262752+00', 'Lady Susan Stewart', 3483, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (9118, '2013-01-05 16:37:33.22222+00', '2013-01-05 16:37:33.22223+00', 'Palais Glide', 10108, 50, 0, 0, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (9126, '2013-01-05 17:20:40.078973+00', '2013-01-05 17:20:40.078984+00', 'Black Mountain Reel', 10108, 1, 5, 32, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (9151, '2013-01-06 16:48:19.030686+00', '2013-01-06 16:48:19.030696+00', 'Jigs 2x32', 2029, 2, 2, 32, 9999, NULL, 72, 0, '');
INSERT INTO 'recording' VALUES (9187, '2013-01-06 21:23:21.32977+00', '2013-01-06 21:23:21.32978+00', 'Strathspey & Reel 2x32+2x32', 2029, 4, 1, 128, 51, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (9194, '2013-01-16 12:31:31.332595+00', '2013-01-16 12:31:31.332606+00', 'Dandy Dancer, The', 10709, 2, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (9217, '2013-01-17 15:08:25.437929+00', '2013-01-17 15:08:25.43794+00', 'Gay Gordons, The', 10146, 11, 12, 16, NULL, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (9218, '2013-01-17 15:16:53.734616+00', '2013-01-17 15:16:53.734626+00', 'Canadian Barn Dance', 10146, 11, 6, 16, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (9220, '2013-01-17 15:52:47.928068+00', '2013-01-17 15:52:47.928079+00', 'Barracks Johnny', 10146, 2, 3, 32, 9999, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (9222, '2013-01-17 16:03:21.63995+00', '2013-01-17 16:03:21.639961+00', 'Cairn Bann Jig, The', 10146, 2, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (9223, '2013-02-02 13:40:44.80039+00', '2013-02-02 13:40:44.800401+00', 'Scottish Medley', 10146, 98, 0, 0, NULL, NULL, 103, 0, '');
INSERT INTO 'recording' VALUES (699, NULL, '2012-01-20 12:55:05.424483+00', 'Spey Royal', 3040, 4, 0, 120, 15, 6, 170, 0, '');
INSERT INTO 'recording' VALUES (700, NULL, '2012-01-20 12:55:05.430053+00', 'Postie''s Jig', 3040, 2, 4, 32, 9999, 5, 141, 0, '');
INSERT INTO 'recording' VALUES (701, NULL, '2012-01-20 12:55:05.43507+00', 'Jig for Joe, A', 3060, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (702, NULL, '2012-01-20 12:55:05.44055+00', 'Munro Rant, The', 3002, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (703, NULL, '2012-01-20 12:55:05.446152+00', 'Gramachie', 3002, 3, 8, 32, 9999, 5, 522, 0, '');
INSERT INTO 'recording' VALUES (704, NULL, '2012-01-20 12:55:05.451648+00', 'Shoulder to Shoulder', 3002, 2, 8, 40, 9999, 15, 352, 0, '');
INSERT INTO 'recording' VALUES (705, NULL, '2012-01-20 12:55:05.457112+00', 'Highlandman Kissed his Mother, The', 3002, 1, 8, 32, 9999, 5, 286, 0, '');
INSERT INTO 'recording' VALUES (707, NULL, '2012-01-20 12:55:05.468171+00', 'Lass o'' Loudon', 3002, 3, 8, 32, 9999, 5, 507, 0, '');
INSERT INTO 'recording' VALUES (708, NULL, '2012-01-20 12:55:05.473694+00', 'Portnacraig', 3038, 1, 8, 32, 9999, 5, 282, 0, '');
INSERT INTO 'recording' VALUES (709, NULL, '2012-01-20 12:55:05.479205+00', 'Road to Mallaig, The', 3038, 3, 4, 32, 9999, 5, 250, 0, '');
INSERT INTO 'recording' VALUES (710, NULL, '2012-01-20 12:55:05.484686+00', 'Quarries'' Jig', 3038, 2, 8, 32, 9999, 1, 277, 0, '');
INSERT INTO 'recording' VALUES (711, NULL, '2012-01-20 12:55:05.490289+00', 'Gang the Same Gate', 3038, 3, 8, 32, 9999, 5, 499, 0, '');
INSERT INTO 'recording' VALUES (713, NULL, '2012-01-20 12:55:05.501256+00', 'Argyll Ludging, The', 3038, 3, 8, 32, 9999, 5, 500, 0, '');
INSERT INTO 'recording' VALUES (677, NULL, '2017-02-25 17:14:47.77601+00', 'Rest and be Thankful', 3038, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (3713, NULL, '2019-02-16 22:04:12.5848+00', 'Kate Dalrymple', 3004, 1, 0, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (714, NULL, '2012-01-20 12:55:05.506892+00', 'Anniversary Reel', 3038, 1, 4, 32, 9999, 5, 142, 0, '');
INSERT INTO 'recording' VALUES (715, NULL, '2012-01-20 12:55:05.512449+00', 'Gilly Flower, The', 3038, 2, 8, 32, 9999, 5, 277, 0, '');
INSERT INTO 'recording' VALUES (717, NULL, '2012-01-20 12:55:05.523627+00', 'Inverneill House', 3009, 1, 8, 32, 9999, 1, 290, 0, '');
INSERT INTO 'recording' VALUES (718, NULL, '2012-01-20 12:55:05.529205+00', 'Argyll Strathspey', 3009, 3, 8, 32, 9999, 5, 522, 0, '');
INSERT INTO 'recording' VALUES (719, NULL, '2012-01-20 12:55:05.534721+00', 'Trysting Place, The', 3009, 3, 8, 32, 9999, 5, 514, 0, '');
INSERT INTO 'recording' VALUES (720, NULL, '2012-01-20 12:55:05.540204+00', 'Saint Andrews Gardens', 3009, 2, 8, 32, 9999, 1, 287, 0, '');
INSERT INTO 'recording' VALUES (723, NULL, '2012-01-20 12:55:05.556797+00', 'Genevieve''s Jig', 3022, 2, 4, 32, 9999, 1, 141, 0, '');
INSERT INTO 'recording' VALUES (725, NULL, '2012-01-20 12:55:05.567835+00', 'Farewell to Crumlin', 3022, 2, 4, 32, 9999, 1, 142, 0, '');
INSERT INTO 'recording' VALUES (716, NULL, '2018-03-18 23:25:58.407397+00', 'Rob Roy MacGregor', 3041, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (727, NULL, '2012-01-20 12:55:05.578876+00', 'Miss Nancy Arnott', 3022, 3, 8, 32, 9999, 5, 500, 0, '');
INSERT INTO 'recording' VALUES (728, NULL, '2012-01-20 12:55:05.583686+00', 'Set of Jigs', 3041, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (729, NULL, '2012-01-20 12:55:05.589494+00', 'I''ll gang Nae Mair tae yon Toon', 3021, 3, 8, 40, 9999, 6, 628, 0, '');
INSERT INTO 'recording' VALUES (730, NULL, '2012-01-20 12:55:05.595035+00', 'What a Beau my Granny Was', 3021, 1, 8, 32, 9999, 5, 280, 0, '');
INSERT INTO 'recording' VALUES (731, NULL, '2012-01-20 12:55:05.600562+00', 'Lochiel''s awa'' to France', 3021, 3, 8, 48, 9999, 4, 730, 0, '');
INSERT INTO 'recording' VALUES (732, NULL, '2012-01-20 12:55:05.606109+00', 'Camp of Pleasure, The', 3021, 3, 8, 32, 9999, 5, 503, 0, '');
INSERT INTO 'recording' VALUES (733, NULL, '2012-01-20 12:55:05.611689+00', 'Lord Rosslyn''s Fancy', 3021, 2, 8, 32, 9999, 5, 280, 0, '');
INSERT INTO 'recording' VALUES (734, NULL, '2012-01-20 12:55:05.617176+00', 'Theeket Hoose, The', 3021, 3, 8, 48, 9999, 4, 745, 0, '');
INSERT INTO 'recording' VALUES (735, NULL, '2012-01-20 12:55:05.622755+00', 'Argyll''s Bowling Green', 3021, 1, 8, 32, 9999, 5, 290, 0, '');
INSERT INTO 'recording' VALUES (736, NULL, '2012-01-20 12:55:05.628243+00', 'Campbell''s Frolic', 3021, 2, 8, 32, 9999, 1, 283, 0, '');
INSERT INTO 'recording' VALUES (706, NULL, '2021-07-02 10:47:37.201085+00', 'Edinburgh Jigs', 3002, 2, 8, 32, 9999, 1, 286, 0, '');
INSERT INTO 'recording' VALUES (724, NULL, '2021-08-30 21:01:32.408512+00', 'Trip to the Netherlands, A', 3022, 1, 8, 40, 9999, 6, 351, 0, '');
INSERT INTO 'recording' VALUES (9091, '2013-01-04 12:22:52.373877+00', '2021-08-20 11:14:41.700574+00', 'Selection of Strathspeys', 3067, 3, 8, 32, 9999, NULL, 529, 0, '');
INSERT INTO 'recording' VALUES (737, NULL, '2012-01-20 12:55:05.633807+00', 'Highland Reel, The', 3018, 1, 4, 32, 9999, 5, 142, 0, '');
INSERT INTO 'recording' VALUES (738, NULL, '2012-01-20 12:55:05.639307+00', 'Miss Cahoon''s Reel', 3018, 2, 8, 48, 9999, 13, 407, 0, '');
INSERT INTO 'recording' VALUES (3716, NULL, '2012-01-20 12:55:22.283235+00', 'Jigs', 2296, 2, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3717, NULL, '2012-01-20 12:55:22.289475+00', 'Jigs', 3004, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3718, NULL, '2012-01-20 12:55:22.295873+00', 'Set of Reels', 2295, 1, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3719, NULL, '2012-01-20 12:55:22.302129+00', 'Barn Dance', 3004, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3720, NULL, '2012-01-20 12:55:22.308384+00', 'Set of Reels', 2301, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3721, NULL, '2012-01-20 12:55:22.314836+00', 'Military Two-Step', 2301, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3722, NULL, '2012-01-20 12:55:22.321084+00', 'Irish Jigs', 2301, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3723, NULL, '2012-01-20 12:55:22.327327+00', 'Dunoon Barn Dance', 2301, 1, 8, 16, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (3724, NULL, '2012-01-20 12:55:22.333722+00', 'Gay Gordons', 2301, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3725, NULL, '2012-01-20 12:55:22.339966+00', 'Circle Waltz', 2301, 5, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3726, NULL, '2012-01-20 12:55:22.34624+00', 'Set of Jigs', 2301, 2, 4, 32, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (3727, NULL, '2012-01-20 12:55:22.352632+00', 'Air and Reel', 2301, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3728, NULL, '2012-01-20 12:55:22.359194+00', 'Strathspeys', 2301, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3729, NULL, '2012-01-20 12:55:22.365418+00', 'North Barn Dance, The', 2301, 1, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3730, NULL, '2012-01-20 12:55:22.371679+00', 'Scottish Waltz', 2301, 5, 0, 0, 9999, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (3731, NULL, '2012-01-20 12:55:22.378037+00', 'Reel', 2301, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3732, NULL, '2012-01-20 12:55:22.384398+00', 'Set of Jigs', 2301, 2, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (3733, NULL, '2012-01-20 12:55:22.391044+00', 'Drop of Brandy', 2301, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3734, NULL, '2012-01-20 12:55:22.397365+00', 'Danish Double Quadrilles', 3026, 1, 2, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3735, NULL, '2012-01-20 12:55:22.403764+00', 'Scottish Waltz Medley', 3026, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3736, NULL, '2012-01-20 12:55:22.410107+00', 'Reel 5x32', 3060, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9005, '2012-12-28 16:49:20.506037+00', '2012-12-28 16:49:20.506047+00', 'Iona Waltz', 2583, 5, 0, 0, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (9044, '2013-01-01 18:36:57.51974+00', '2013-01-01 18:36:57.519751+00', 'Strathspey & Highland Reel 2+2 Adult', 10687, 7, 4, 16, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (9105, '2013-01-04 15:41:36.123197+00', '2013-01-04 15:41:36.123207+00', 'Adieu Mon Ami', 3483, 3, 8, 32, 9999, NULL, 485, 0, '');
INSERT INTO 'recording' VALUES (9114, '2013-01-04 16:33:41.718323+00', '2013-01-04 16:33:41.718333+00', 'August 19', 10695, 98, 0, 0, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (9119, '2013-01-05 16:43:27.760186+00', '2013-01-05 16:43:27.760196+00', 'Gay Gordons Two-Step', 10108, 11, 0, 0, 9999, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (9127, '2013-01-05 17:24:28.439233+00', '2013-01-05 17:24:28.439243+00', 'Britannia Two-Step', 10108, 11, 8, 16, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (9134, '2013-01-05 17:59:50.889283+00', '2013-01-05 17:59:50.889293+00', 'Boston Two-Step', 10108, 11, 8, 16, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (9136, '2013-01-06 13:52:10.850571+00', '2013-01-06 13:52:10.850581+00', 'Foursome Reel', 2328, 4, 1, 112, 18, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (9152, '2013-01-06 16:50:37.358868+00', '2013-01-06 16:50:37.358878+00', 'Jigs 3x32', 2029, 2, 3, 32, 9999, NULL, 102, 0, '');
INSERT INTO 'recording' VALUES (9188, '2013-01-06 21:29:40.185863+00', '2013-01-06 21:29:40.185873+00', 'Strathspey & Reel 3x32+3x32', 2029, 4, 1, 192, 3, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (9195, '2013-01-16 12:37:34.084582+00', '2013-01-16 12:37:34.084593+00', 'Canadian Barn Dance', 10709, 11, 16, 16, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (9219, '2013-01-17 15:22:40.015732+00', '2013-01-17 15:22:40.015743+00', 'Waltz', 10146, 5, 3, 16, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (9221, '2013-01-17 15:55:42.611663+00', '2013-01-17 15:55:42.611675+00', 'Polka', 10146, 13, 0, 16, 9999, NULL, 86, 0, '');
INSERT INTO 'recording' VALUES (9224, '2013-02-02 13:44:27.874133+00', '2013-02-02 13:44:27.874143+00', 'Highland Medley', 10146, 11, 0, 0, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (9225, '2013-02-02 14:08:31.284896+00', '2013-02-02 14:08:31.284907+00', 'Sailor''s Hornpipe, The', 10146, 7, 3, 32, NULL, NULL, 119, 0, '');
INSERT INTO 'recording' VALUES (739, NULL, '2012-01-20 12:55:05.644847+00', 'Mrs Stewart''s Strathspey', 3018, 3, 8, 48, 9999, 5, 835, 0, '');
INSERT INTO 'recording' VALUES (740, NULL, '2012-01-20 12:55:05.650421+00', 'Barley Bree', 3018, 2, 4, 40, 9999, 15, 172, 0, '');
INSERT INTO 'recording' VALUES (741, NULL, '2012-01-20 12:55:05.655986+00', 'Duran Ranger, The', 3018, 1, 8, 32, 9999, 5, 280, 0, '');
INSERT INTO 'recording' VALUES (742, NULL, '2012-01-20 12:55:05.662034+00', 'Kiss For Nothing, A', 3018, 2, 8, 32, 9999, 5, 274, 0, '');
INSERT INTO 'recording' VALUES (743, NULL, '2012-01-20 12:55:05.667556+00', 'Strathglass House', 3018, 3, 8, 32, 9999, 5, 497, 0, '');
INSERT INTO 'recording' VALUES (744, NULL, '2012-01-20 12:55:05.673055+00', 'Fly Not yet', 3018, 2, 8, 48, 9999, 20, 407, 0, '');
INSERT INTO 'recording' VALUES (745, NULL, '2012-01-20 12:55:05.678726+00', 'Joe Foster''s Jig', 3040, 2, 6, 32, 9999, 1, 200, 0, '');
INSERT INTO 'recording' VALUES (746, NULL, '2012-01-20 12:55:05.684326+00', 'Dick''s Dram', 3040, 3, 4, 32, 9999, 5, 238, 0, '');
INSERT INTO 'recording' VALUES (748, NULL, '2012-01-20 12:55:05.695453+00', 'David''s Fancy', 3040, 3, 4, 40, 9999, 5, 300, 0, '');
INSERT INTO 'recording' VALUES (749, NULL, '2012-01-20 12:55:05.700335+00', 'Sparkenhoe Circle', 3040, 1, 0, 64, 9999, NULL, 77, 0, '');
INSERT INTO 'recording' VALUES (750, NULL, '2012-01-20 12:55:05.705819+00', 'Mid Fodderletter', 3040, 3, 4, 32, 9999, 5, 233, 0, '');
INSERT INTO 'recording' VALUES (751, NULL, '2012-01-20 12:55:05.711313+00', 'Borders Revisited', 3040, 1, 4, 32, 9999, 1, 145, 1, '');
INSERT INTO 'recording' VALUES (752, NULL, '2012-01-20 12:55:05.718296+00', 'Mrs Sybil Shaw', 3040, 3, 8, 32, 9999, 5, 463, 0, '');
INSERT INTO 'recording' VALUES (753, NULL, '2012-01-20 12:55:05.723822+00', 'Young Wilson''s Reel', 3040, 1, 4, 32, 9999, 1, 137, 0, '');
INSERT INTO 'recording' VALUES (754, NULL, '2012-01-20 12:55:05.729319+00', 'Inverugie Castle', 3040, 4, 0, 64, 5, 5, 100, 0, '');
INSERT INTO 'recording' VALUES (755, NULL, '2012-01-20 12:55:05.734309+00', 'Borders Welcome, A', 3003, 1, 6, 32, 9999, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (756, NULL, '2012-01-20 12:55:05.739134+00', 'Castle Varrich', 3003, 2, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (721, NULL, '2018-04-03 20:38:38.105633+00', 'Gates of Edinburgh, The', 3021, 1, 8, 32, 9999, 5, 285, 0, '');
INSERT INTO 'recording' VALUES (757, NULL, '2018-04-06 22:33:20.778918+00', 'Set of Strathspeys for Moray Rant', 3003, 3, 3, 48, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (758, NULL, '2012-01-20 12:55:05.74889+00', 'Black Black Oil, The', 3003, 1, 5, 32, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (759, NULL, '2012-01-20 12:55:05.753717+00', 'Phantom Piper, The', 3003, 2, 4, 32, 9999, NULL, 143, 1, '');
INSERT INTO 'recording' VALUES (760, NULL, '2012-01-20 12:55:05.758587+00', 'Pipe Medley for 1314', 3003, 4, 0, 128, 2, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (761, NULL, '2012-01-20 12:55:05.763392+00', 'Polka', 3003, 13, 0, 0, 9999, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (762, NULL, '2012-01-20 12:55:05.768184+00', 'Jennifer''s Jig', 3003, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (763, NULL, '2012-01-20 12:55:05.772998+00', 'Swelkie, The', 3003, 3, 3, 32, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (764, NULL, '2012-01-20 12:55:05.777957+00', 'Wesley Harry', 3003, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (765, NULL, '2012-01-20 12:55:05.782821+00', 'Set of Jigs for Geneva Park', 3003, 2, 4, 40, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (766, NULL, '2012-01-20 12:55:05.788014+00', 'Dundee Whaler, The', 3003, 3, 4, 32, 9999, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (767, NULL, '2012-01-20 12:55:05.792863+00', 'Slow Air', 3003, 98, 0, 0, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (768, NULL, '2012-01-20 12:55:05.79843+00', 'My Love She''s But a Lassie Yet', 3018, 1, 4, 32, 9999, 1, 145, 1, '');
INSERT INTO 'recording' VALUES (769, NULL, '2012-01-20 12:55:05.804037+00', 'Dalkeith''s Strathspey', 3018, 3, 8, 32, 9999, 5, 495, 0, '');
INSERT INTO 'recording' VALUES (770, NULL, '2012-01-20 12:55:05.809571+00', 'New Rigged Ship, The', 3018, 2, 8, 48, 9999, 25, 414, 0, '');
INSERT INTO 'recording' VALUES (772, NULL, '2012-01-20 12:55:05.820726+00', 'Braes of Busby, The', 3018, 3, 4, 32, 9999, 5, 244, 0, '');
INSERT INTO 'recording' VALUES (773, NULL, '2012-01-20 12:55:05.826229+00', 'Miss Clemy Stewart''s Reel', 3018, 1, 4, 32, 9999, 5, 150, 0, '');
INSERT INTO 'recording' VALUES (774, NULL, '2012-01-20 12:55:05.831798+00', 'Mrs Grant''s Fancy', 3018, 3, 4, 32, 9999, 5, 258, 0, '');
INSERT INTO 'recording' VALUES (775, NULL, '2012-01-20 12:55:05.83742+00', 'Jimp Waist, The', 3018, 3, 4, 32, 9999, 5, 252, 1, '');
INSERT INTO 'recording' VALUES (778, NULL, '2012-01-20 12:55:05.853386+00', 'Duchess of Atholl''s Slipper, The', 3018, 3, 4, 32, 9999, 5, 245, 0, '');
INSERT INTO 'recording' VALUES (3737, NULL, '2012-01-20 12:55:22.416346+00', 'Fiddle Solo', 3026, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3738, NULL, '2012-01-20 12:55:22.422737+00', 'Military Two-Step', 3026, 11, 6, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (777, NULL, '2021-09-24 10:29:10.98713+00', 'Birks of Abergeldie, The', 3018, 1, 4, 48, 9999, 4, 220, 0, '');
INSERT INTO 'recording' VALUES (3739, NULL, '2012-01-20 12:55:22.428968+00', 'Waltz-Along', 3026, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3740, NULL, '2012-01-20 12:55:22.435529+00', 'Haughs O'' Cromdale', 3026, 3, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3741, NULL, '2012-01-20 12:55:22.441954+00', 'Fandango, The', 3026, 2, 3, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3742, NULL, '2012-01-20 12:55:22.448372+00', 'Scottish Waltz Medley', 3026, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3743, NULL, '2012-01-20 12:55:22.45464+00', 'Balintore Fishermen, The', 3026, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3744, NULL, '2012-01-20 12:55:22.461015+00', 'Accordion Duet', 3026, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3745, NULL, '2012-01-20 12:55:22.467422+00', 'Linton Plooman, The', 3026, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3746, NULL, '2012-01-20 12:55:22.473691+00', 'Saint Bernard''s Waltz', 3026, 5, 10, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3747, NULL, '2012-01-20 12:55:22.479946+00', 'March with Rob Gordon', 3026, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3748, NULL, '2012-01-20 12:55:22.486621+00', 'Two Pipe Marches', 3056, 98, 0, 0, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (3749, NULL, '2012-01-20 12:55:22.49299+00', 'Merry Lads of Ayr', 2303, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3750, NULL, '2012-01-20 12:55:22.502978+00', 'Monymusk', 2303, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3751, NULL, '2012-01-20 12:55:22.509313+00', 'Peggy''s Wedding', 2303, 2, 4, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3752, NULL, '2012-01-20 12:55:22.515646+00', 'Highland Waltz', 2303, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3753, NULL, '2012-01-20 12:55:22.522042+00', 'Hamilton House', 2303, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3754, NULL, '2012-01-20 12:55:22.528415+00', 'Wee Cooper o'' Fife, The', 2303, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3755, NULL, '2012-01-20 12:55:22.534737+00', 'Peggy''s Love', 2303, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3756, NULL, '2012-01-20 12:55:22.541016+00', 'Highland Reel, The', 2317, 1, 6, 32, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (9006, '2012-12-28 16:53:11.210095+00', '2012-12-28 16:53:11.210105+00', 'Palais Glide', 2583, 50, 0, 0, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (9045, '2013-01-01 18:54:45.400663+00', '2013-01-01 18:54:45.400674+00', 'Strathspey & Half Tulloch 2+4 SOBHD', 10687, 7, 6, 16, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (9093, '2013-01-04 12:26:14.800718+00', '2013-01-04 12:42:00.367442+00', 'Selection of Strathspeys', 3067, 3, 6, 32, 9999, NULL, 408, 0, '');
INSERT INTO 'recording' VALUES (771, NULL, '2022-05-31 13:51:57.754687+00', 'Cauld Kail', 3018, 4, 4, 32, 1, 5, 199, 0, '');
INSERT INTO 'recording' VALUES (747, NULL, '2022-08-30 18:41:01.400987+00', 'Just a Dance', 3040, 2, 8, 32, 9999, 1, 275, 0, '');
INSERT INTO 'recording' VALUES (9106, '2013-01-04 15:45:21.808964+00', '2013-01-04 15:45:21.808974+00', 'Miss Bielby''s Waltz', 3483, 5, 0, 0, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (9120, '2013-01-05 16:48:46.025314+00', '2013-01-05 16:48:46.025324+00', 'Victoria Waltz', 10108, 5, 0, 0, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (9128, '2013-01-05 17:26:43.236325+00', '2013-01-05 17:26:43.236336+00', 'Blue Danube Waltz', 10108, 5, 0, 32, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (9137, '2013-01-06 13:55:12.642473+00', '2013-01-06 13:55:12.642483+00', 'Duke of Perth', 2301, 1, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (9153, '2013-01-06 16:55:28.66347+00', '2013-01-06 16:55:28.663481+00', 'Jigs 5x32', 2029, 2, 5, 32, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (9189, '2013-01-06 21:33:03.530065+00', '2013-01-06 21:33:03.530075+00', 'Strathspey & Reel 2x40+2x40', 2029, 4, 1, 160, 10, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (9196, '2013-01-16 12:42:12.472782+00', '2013-01-16 12:42:12.472793+00', 'Gay Gordons', 10709, 11, 6, 16, 9999, NULL, 118, 0, '');
INSERT INTO 'recording' VALUES (9238, '2013-02-02 15:42:32.085083+00', '2013-02-02 15:42:32.085094+00', 'Strip the Willow', 10146, 2, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (9246, '2013-02-02 16:59:47.175388+00', '2013-02-02 16:59:47.175399+00', 'Harvest Home', 10146, 98, 5, 32, 9999, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (9251, '2013-02-03 14:29:59.175957+00', '2013-02-03 14:29:59.175968+00', 'Grand March', 10547, 11, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (9253, '2013-02-03 15:05:09.725618+00', '2013-02-03 15:08:35.244624+00', 'Gaelic Waltz', 10547, 5, 0, 32, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (9254, '2013-02-03 15:22:57.404275+00', '2013-02-03 15:22:57.404286+00', 'Highland Scottische', 10547, 3, 16, 8, 9999, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (328, NULL, '2013-02-04 19:27:38.181107+00', 'Strip the Willow (9/8)', 3037, 101, 8, 40, 9999, NULL, 340, 0, '');
INSERT INTO 'recording' VALUES (9261, '2013-02-05 14:14:27.098681+00', '2013-02-05 14:14:27.098691+00', 'Sailor''s Hornpipe 4 steps', 10741, 7, 4, 16, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (780, NULL, '2012-01-20 12:55:05.866407+00', 'Come to the Ceilidh', 3009, 98, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (783, NULL, '2012-01-20 12:55:05.886145+00', 'All for Mary', 3002, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (784, NULL, '2012-01-20 12:55:05.892448+00', 'Ilka Joy', 3139, 1, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (785, NULL, '2012-01-20 12:55:05.898737+00', 'Alexandria Reel, The', 3039, 2, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (786, NULL, '2012-01-20 12:55:05.904977+00', 'Swiss Lassie', 3019, 1, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (787, NULL, '2012-01-20 12:55:05.911292+00', 'Joie de Vivre', 3019, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (788, NULL, '2012-01-20 12:55:05.917577+00', 'New Virginia Reel, The', 3019, 1, 0, 128, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (789, NULL, '2012-01-20 12:55:05.923888+00', 'Cape Town Wedding', 3019, 3, 8, 32, 9999, NULL, 492, 0, '');
INSERT INTO 'recording' VALUES (790, NULL, '2012-01-20 12:55:05.930167+00', 'Immigrant Lass, The', 3019, 2, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (791, NULL, '2012-01-20 12:55:05.93646+00', 'Moulin Rouge, Le', 3019, 1, 0, 64, 9999, NULL, 73, 0, '');
INSERT INTO 'recording' VALUES (792, NULL, '2012-01-20 12:55:05.942767+00', 'Duke and Duchess of Edinburgh, The', 3019, 1, 8, 40, 9999, NULL, 344, 0, '');
INSERT INTO 'recording' VALUES (793, NULL, '2012-01-20 12:55:05.949153+00', 'Robertson Rant, The', 3019, 3, 0, 80, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (794, NULL, '2012-01-20 12:55:05.955461+00', 'Prince Charles of Edinburgh', 3019, 1, 0, 160, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (795, NULL, '2012-01-20 12:55:05.962587+00', 'Corn Rigs', 3011, 1, 8, 32, 9999, 1, 280, 0, '');
INSERT INTO 'recording' VALUES (796, NULL, '2012-01-20 12:55:05.969722+00', 'Lamb Skinnet', 3023, 2, 8, 32, 9999, 1, 283, 0, '');
INSERT INTO 'recording' VALUES (797, NULL, '2012-01-20 12:55:05.977013+00', 'Rakes of Glasgow', 3038, 3, 8, 32, 9999, 5, 487, 0, '');
INSERT INTO 'recording' VALUES (798, NULL, '2012-01-20 12:55:05.984311+00', 'Saint Andrew''s Fair', 3044, 2, 8, 32, 9999, 1, 267, 0, '');
INSERT INTO 'recording' VALUES (799, NULL, '2012-01-20 12:55:05.991485+00', 'C''est L''Amour', 3022, 2, 8, 32, 9999, 1, 278, 0, '');
INSERT INTO 'recording' VALUES (800, NULL, '2012-01-20 12:55:05.998637+00', 'Royal Albert Country Dance', 3022, 1, 8, 32, 9999, 5, 285, 0, '');
INSERT INTO 'recording' VALUES (801, NULL, '2012-01-20 12:55:06.005931+00', 'Glasgow Lasses', 3022, 3, 8, 32, 9999, 5, 485, 0, '');
INSERT INTO 'recording' VALUES (802, NULL, '2012-01-20 12:55:06.013039+00', 'Niel Gow''s Farewell to Whisky', 3022, 1, 8, 48, 9999, 11, 410, 0, '');
INSERT INTO 'recording' VALUES (803, NULL, '2012-01-20 12:55:06.02027+00', 'Over the Water to Charlie (New Way)', 3022, 2, 8, 32, 9999, 1, 275, 0, '');
INSERT INTO 'recording' VALUES (804, NULL, '2012-01-20 12:55:06.027405+00', 'New Scotia Quadrille', 3022, 1, 2, 48, 9999, 11, 108, 0, '');
INSERT INTO 'recording' VALUES (805, NULL, '2012-01-20 12:55:06.034496+00', 'Couteraller''s Rant', 3022, 3, 8, 32, 9999, 5, 490, 0, '');
INSERT INTO 'recording' VALUES (806, NULL, '2012-01-20 12:55:06.041122+00', 'Open the Door to Three', 3022, 2, 8, 48, 9999, 29, 412, 0, '');
INSERT INTO 'recording' VALUES (807, NULL, '2012-01-20 12:55:06.046852+00', 'Dumbarton Drums', 3019, 1, 8, 32, 9999, 1, 274, 0, '');
INSERT INTO 'recording' VALUES (808, NULL, '2012-01-20 12:55:06.052343+00', 'Duke of Hamilton''s Reel', 3019, 3, 4, 32, 9999, 5, 246, 0, '');
INSERT INTO 'recording' VALUES (810, NULL, '2012-01-20 12:55:06.063295+00', 'Culloden''s Fancy', 3019, 1, 8, 16, 9999, 23, 143, 0, '');
INSERT INTO 'recording' VALUES (811, NULL, '2012-01-20 12:55:06.068788+00', 'Cold and Raw', 3019, 2, 8, 24, 9999, 18, 207, 0, '');
INSERT INTO 'recording' VALUES (812, NULL, '2012-01-20 12:55:06.074299+00', 'White Cockade, The', 3019, 1, 8, 32, 9999, 1, 274, 0, '');
INSERT INTO 'recording' VALUES (813, NULL, '2012-01-20 12:55:06.079788+00', 'Jenny''s Bawbee', 3019, 3, 4, 24, 9999, 16, 186, 0, '');
INSERT INTO 'recording' VALUES (814, NULL, '2012-01-20 12:55:06.085258+00', 'Scottish Ramble', 3019, 3, 8, 32, 9999, 5, 486, 0, '');
INSERT INTO 'recording' VALUES (815, NULL, '2012-01-20 12:55:06.090751+00', 'Round About Hullachan', 3019, 1, 4, 32, 9999, 5, 141, 0, '');
INSERT INTO 'recording' VALUES (816, NULL, '2012-01-20 12:55:06.095923+00', 'Queen''s View, The', 3045, 1, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (817, NULL, '2012-01-20 12:55:06.100768+00', 'Ship in Full Sail, The', 3045, 2, 5, 32, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (818, NULL, '2012-01-20 12:55:06.105587+00', 'Butterfly Bride', 3045, 1, 4, 48, 9999, NULL, 209, 1, '');
INSERT INTO 'recording' VALUES (819, NULL, '2012-01-20 12:55:06.11039+00', 'Kilkenny Castle', 3045, 3, 8, 32, 9999, NULL, 484, 0, '');
INSERT INTO 'recording' VALUES (3757, NULL, '2012-01-20 12:55:22.547463+00', 'River Cree, The', 2317, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3758, NULL, '2012-01-20 12:55:22.554586+00', 'Scottish Waltz', 2317, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3759, NULL, '2012-01-20 12:55:22.560847+00', 'Muirland Willie', 2317, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3760, NULL, '2012-01-20 12:55:22.567109+00', 'Kitty Campbell''s Reel', 2317, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3761, NULL, '2012-01-20 12:55:22.573344+00', 'Glasgow Flourish', 2317, 3, 8, 32, 9999, NULL, 474, 0, '');
INSERT INTO 'recording' VALUES (3762, NULL, '2012-01-20 12:55:22.579619+00', 'Gay Gordons', 2317, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3769, NULL, '2012-01-20 12:55:22.623448+00', 'Parkhill Two Step', 3025, 50, 0, 0, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (9007, '2012-12-28 16:57:45.390174+00', '2012-12-28 16:57:45.390184+00', 'Lads o'' Dunse', 2583, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (9046, '2013-01-01 18:56:20.93808+00', '2013-01-01 18:56:20.938092+00', 'Strathspey & Half Tulloch 2+4 Adult', 10687, 7, 6, 16, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (9094, '2013-01-04 12:29:21.406807+00', '2013-01-04 12:29:21.406818+00', 'Mairi''s Wedding', 3067, 1, 8, 40, 9999, NULL, 359, 0, '');
INSERT INTO 'recording' VALUES (9107, '2013-01-04 15:50:45.864154+00', '2013-01-04 15:50:45.864165+00', 'Ewing Fiddlers, The', 3483, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9121, '2013-01-05 16:54:03.154528+00', '2013-01-05 16:54:03.154538+00', 'Eva Three-Step', 10108, 11, 8, 16, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (9129, '2013-01-05 17:31:28.083298+00', '2013-01-05 17:31:28.083309+00', 'Orkney Eva Three-Step', 10108, 1, 6, 32, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (9138, '2013-01-06 14:02:25.030378+00', '2013-01-06 14:02:25.030388+00', 'Highland Schottische', 2337, 3, 16, 8, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (9154, '2013-01-06 17:02:22.095319+00', '2013-01-06 17:02:22.09533+00', 'Jigs 6x32', 2029, 2, 6, 32, 9999, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (782, NULL, '2021-12-21 10:35:06.544883+00', 'Wee Nothin'', A', 3399, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (3766, NULL, '2022-08-20 14:11:24.649207+00', 'Irish Barn Dance', 3037, 50, 0, 0, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (3763, NULL, '2022-08-20 13:57:46.186645+00', 'Set of Jigs', 3037, 2, 4, 32, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (3764, NULL, '2022-08-20 13:58:55.926359+00', 'Irish Waltz', 3037, 5, 0, 0, 9999, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (3765, NULL, '2022-08-20 14:10:46.430418+00', 'Tushker, Da', 3037, 1, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (3767, NULL, '2022-08-20 14:12:10.712694+00', 'Miss Hadden''s Reel', 3037, 2, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (3768, NULL, '2022-08-20 14:12:36.362832+00', 'Gay Gordons', 3037, 11, 0, 16, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (3771, NULL, '2022-08-20 14:30:19.923681+00', 'Scottish Waltz', 3037, 5, 0, 0, 9999, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (3773, NULL, '2022-08-20 14:31:28.68025+00', 'Military Two-Step', 3037, 11, 0, 16, 9999, NULL, 121, 0, '');
INSERT INTO 'recording' VALUES (3774, NULL, '2022-08-20 14:32:02.07257+00', 'Campbell''s Frolic', 3037, 2, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (3775, NULL, '2022-08-20 14:32:28.550945+00', 'Highland Schottische', 3037, 3, 0, 8, 9999, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (3776, NULL, '2022-08-20 14:33:02.332825+00', 'Polka', 3037, 13, 0, 0, 9999, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (3770, NULL, '2022-08-20 14:29:44.527996+00', 'Roxburgh Castle', 3037, 1, 4, 32, 9999, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (9190, '2013-01-06 21:36:12.055698+00', '2013-01-06 21:36:12.055709+00', 'Strathspey & Reel 2x48+2x48', 2029, 4, 1, 192, 3, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (9197, '2013-01-16 12:46:31.427826+00', '2013-01-16 12:46:31.427836+00', 'Jim Johnstone''s Reel', 10709, 1, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (9227, '2013-02-02 14:19:01.788124+00', '2013-02-02 14:19:01.788134+00', 'Duke of Perth, The', 10146, 1, 8, 32, NULL, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (9239, '2013-02-02 15:47:32.749032+00', '2013-02-02 15:47:32.749043+00', 'Highland Scottische', 10146, 3, 12, 8, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (9247, '2013-02-02 17:01:26.051408+00', '2013-02-02 17:01:26.051418+00', 'Irish Jig', 10146, 2, 4, 32, 9999, NULL, 102, 0, '');
INSERT INTO 'recording' VALUES (9252, '2013-02-03 14:34:02.574103+00', '2013-02-03 14:36:43.88039+00', 'Hollin Bus, The', 10547, 2, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (9255, '2013-02-03 15:27:54.111812+00', '2013-02-03 15:27:54.111823+00', 'Wee Heilan Laddie, The', 10547, 1, 4, 32, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (9262, '2013-02-05 14:21:40.839656+00', '2013-02-05 14:21:40.839667+00', 'Sailor''s Hornpipe 4 steps', 10742, 7, 4, 16, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (820, NULL, '2012-01-20 12:55:06.115197+00', 'Train Journey North, The', 3045, 1, 4, 40, 9999, NULL, 177, 1, '');
INSERT INTO 'recording' VALUES (821, NULL, '2012-01-20 12:55:06.120069+00', 'Laggan Bay', 3045, 2, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (822, NULL, '2012-01-20 12:55:06.124861+00', 'Teacher''s Pet, The', 3045, 1, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (824, NULL, '2012-01-20 12:55:06.134455+00', 'Riddlers Rant, The', 3045, 1, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (825, NULL, '2012-01-20 12:55:06.139234+00', 'Celtic Crossing', 3045, 2, 5, 32, 9999, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (827, NULL, '2012-01-20 12:55:06.149242+00', 'Duchess of Argyll, The', 3045, 3, 8, 32, 9999, NULL, 475, 0, '');
INSERT INTO 'recording' VALUES (831, NULL, '2012-01-20 12:55:06.16841+00', 'Summer Assembly', 3006, 1, 0, 88, 9999, NULL, 106, 0, '');
INSERT INTO 'recording' VALUES (832, NULL, '2012-01-20 12:55:06.181601+00', 'Trip to Bavaria, A', 3046, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (833, NULL, '2012-01-20 12:55:06.188215+00', 'Drumelzier', 3046, 3, 4, 32, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (834, NULL, '2012-01-20 12:55:06.1965+00', 'Midnight Oil', 3046, 2, 5, 48, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (835, NULL, '2012-01-20 12:55:06.204128+00', 'Iona Cross, The', 3046, 4, 0, 192, 3, NULL, 298, 0, '');
INSERT INTO 'recording' VALUES (836, NULL, '2012-01-20 12:55:06.210586+00', 'Silver Tassie, The', 3046, 3, 8, 32, 9999, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (837, NULL, '2012-01-20 12:55:06.216859+00', 'Welcome to Skye', 3046, 2, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (838, NULL, '2012-01-20 12:55:06.223228+00', 'Angus Reel, The', 3046, 1, 0, 128, 9999, NULL, 153, 1, '');
INSERT INTO 'recording' VALUES (839, NULL, '2012-01-20 12:55:06.230616+00', 'MacDonald of the Isles', 3046, 3, 3, 32, 9999, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (840, NULL, '2012-01-20 12:55:06.236893+00', 'MacPhail''s Magic', 3046, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (841, NULL, '2012-01-20 12:55:06.244165+00', 'Wind on Loch Fyne, The', 3046, 3, 3, 32, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (842, NULL, '2012-01-20 12:55:06.254806+00', 'Birkland Burn, The', 3046, 2, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (844, NULL, '2012-01-20 12:55:06.267563+00', 'Tambourine Reel, The', 3046, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (846, NULL, '2012-01-20 12:55:06.281753+00', 'Marquis of Lorne, The', 3047, 3, 8, 32, 9999, 5, 482, 0, '');
INSERT INTO 'recording' VALUES (843, NULL, '2019-01-30 00:08:28.533727+00', 'Rose Acre', 3046, 3, 4, 32, 9999, NULL, 265, 1, '');
INSERT INTO 'recording' VALUES (826, NULL, '2019-09-28 21:56:51.493014+00', 'Glen Alva', 3045, 1, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (847, NULL, '2012-01-20 12:55:06.288882+00', 'Carl Cam Ower the Croft, The', 3047, 1, 8, 32, 9999, 5, 282, 0, '');
INSERT INTO 'recording' VALUES (848, NULL, '2012-01-20 12:55:06.296007+00', 'Set of Strathspeys', 3047, 3, 8, 32, 9999, 5, 484, 0, '');
INSERT INTO 'recording' VALUES (849, NULL, '2012-01-20 12:55:06.303137+00', 'Barley Bree', 3047, 2, 4, 40, 9999, 9, 178, 0, '');
INSERT INTO 'recording' VALUES (850, NULL, '2012-01-20 12:55:06.309411+00', 'Waltz', 3047, 5, 0, 0, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (851, NULL, '2012-01-20 12:55:06.316501+00', 'Mairi''s Wedding', 3047, 1, 8, 40, 9999, 6, 345, 0, '');
INSERT INTO 'recording' VALUES (852, NULL, '2012-01-20 12:55:06.32517+00', 'John McAlpin', 3047, 3, 8, 32, 9999, 5, 484, 0, '');
INSERT INTO 'recording' VALUES (854, NULL, '2012-01-20 12:55:06.339567+00', 'Set of Jigs', 3047, 2, 8, 32, 9999, 1, 275, 0, '');
INSERT INTO 'recording' VALUES (856, NULL, '2012-01-20 12:55:06.352975+00', 'Canadian Barn Dance', 3047, 11, 5, 16, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (3778, NULL, '2012-01-20 12:55:22.679885+00', 'Mayfair Quickstep', 3010, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3779, NULL, '2012-01-20 12:55:22.686126+00', 'Barn Dance', 3010, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3780, NULL, '2012-01-20 12:55:22.692371+00', 'Galloway House', 2246, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (3781, NULL, '2012-01-20 12:55:22.69863+00', 'Green Grow the Rashes', 2246, 3, 4, 32, 9999, NULL, 234, 0, '');
INSERT INTO 'recording' VALUES (3782, NULL, '2012-01-20 12:55:22.704847+00', 'Waltzes', 2246, 5, 0, 0, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (3783, NULL, '2012-01-20 12:55:22.711091+00', 'Dumbarton''s Drums', 2246, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (3784, NULL, '2012-01-20 12:55:22.717351+00', 'Canadian Barn Dance', 2246, 11, 0, 16, 9999, NULL, 224, 0, '');
INSERT INTO 'recording' VALUES (3785, NULL, '2012-01-20 12:55:22.723602+00', 'Eva Three Step', 2246, 11, 8, 16, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (3786, NULL, '2012-01-20 12:55:22.729855+00', 'Polka', 2246, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3787, NULL, '2012-01-20 12:55:22.736087+00', 'Gay Gordons', 2246, 11, 8, 16, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (3788, NULL, '2012-01-20 12:55:22.742337+00', 'Minuet', 2246, 99, 0, 0, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (3789, NULL, '2012-01-20 12:55:22.748655+00', 'Admiral Nelson', 2246, 1, 4, 64, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (3790, NULL, '2012-01-20 12:55:22.754895+00', 'Jacky Tar Two-Step', 2246, 1, 4, 32, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (3791, NULL, '2012-01-20 12:55:22.761128+00', 'Va, La', 2246, 99, 0, 0, 9999, NULL, 124, 0, '');
INSERT INTO 'recording' VALUES (3792, NULL, '2012-01-20 12:55:22.767382+00', 'Machine Without Horses', 2246, 2, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (3793, NULL, '2012-01-20 12:55:22.77362+00', 'Foursome Reel, The', 2090, 4, 0, 144, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (3794, NULL, '2012-01-20 12:55:22.779886+00', 'Waltz', 2090, 5, 0, 0, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (3795, NULL, '2012-01-20 12:55:22.786119+00', 'Scottish Ramble', 3010, 3, 8, 32, 9999, NULL, 443, 0, '');
INSERT INTO 'recording' VALUES (3796, NULL, '2012-01-20 12:55:22.792376+00', 'Machine Without Horses, The', 2090, 2, 8, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (3797, NULL, '2012-01-20 12:55:22.798636+00', 'Machine Without Horses - Encore', 2090, 2, 8, 32, 9999, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (9008, '2012-12-28 17:13:45.369043+00', '2012-12-28 17:13:45.369053+00', '16 Pas De Basque', 10687, 7, 16, 1, 9999, NULL, 31, 0, '');
INSERT INTO 'recording' VALUES (9047, '2013-01-01 18:58:39.107071+00', '2013-01-01 18:58:39.107082+00', 'Strathspey, Highland Reel & Half Tulloch 2+6 SOBHD', 10687, 7, 8, 16, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (9095, '2013-01-04 12:31:00.973757+00', '2013-01-04 12:31:00.973768+00', 'Wild Geese, The', 3067, 2, 8, 32, 9999, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (9108, '2013-01-04 15:55:01.098984+00', '2013-01-04 15:55:01.098995+00', 'Farewell Suite, The', 10695, 98, 0, 0, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (9130, '2013-01-05 17:37:11.199799+00', '2013-01-05 17:37:11.199809+00', 'Postie''s Jig', 10108, 2, 4, 32, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (9139, '2013-01-06 14:08:34.095521+00', '2013-01-06 14:08:34.095532+00', 'Gaelic Waltz', 3051, 5, 4, 32, 9999, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (9155, '2013-01-06 17:08:42.74565+00', '2013-01-06 17:08:42.74566+00', 'Reels 2x32', 2029, 1, 2, 32, 9999, NULL, 73, 0, '');
INSERT INTO 'recording' VALUES (9191, '2013-01-06 21:38:44.990515+00', '2013-01-06 21:38:44.990525+00', 'Jig 4x32', 2029, 2, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (9198, '2013-01-16 12:49:25.761472+00', '2013-01-16 12:49:25.761482+00', 'St Bernard''s Waltz', 10709, 5, 0, 16, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (9228, '2013-02-02 14:22:45.060554+00', '2013-02-02 14:22:45.060564+00', 'Canadian Barn Dance', 10146, 11, 12, 16, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (9240, '2013-02-02 15:52:17.156993+00', '2013-02-02 15:52:17.157004+00', 'Marches', 10146, 11, 3, 32, 9999, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (9248, '2013-02-02 17:07:16.100324+00', '2013-02-02 17:07:16.100334+00', 'Gay Gordons', 10146, 11, 12, 16, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (9256, '2013-02-03 15:34:50.239374+00', '2013-02-03 15:34:50.239385+00', 'Kiss for Nothing, A', 10547, 2, 5, 32, 9999, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (9263, '2013-02-05 14:30:26.061216+00', '2013-02-05 14:30:26.061226+00', 'Sailor''s Hornpipe 5 steps', 10742, 7, 5, 16, 9999, NULL, 115, 0, '');
INSERT INTO 'recording' VALUES (9265, '2013-02-05 14:39:28.941451+00', '2013-02-05 14:39:28.941461+00', 'Irish Jig 4 steps', 10741, 7, 4, 16, 9999, NULL, 78, 0, '');
INSERT INTO 'recording' VALUES (9266, '2013-02-05 14:44:03.738673+00', '2013-02-05 14:44:03.738683+00', 'Irish Jig 4 steps', 10742, 7, 5, 16, 9999, NULL, 81, 0, '');
INSERT INTO 'recording' VALUES (9284, '2013-02-05 16:03:26.781665+00', '2013-02-05 16:03:26.781676+00', 'Choreography', 10746, 4, 1, 128, 9998, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (858, NULL, '2014-09-16 12:33:32.070689+00', 'Quarries'' Jig', 3039, 2, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (829, NULL, '2022-08-31 16:14:56.69817+00', 'Friday''s Child', 3045, 2, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (823, NULL, '2022-12-11 11:46:37.520229+00', 'Leaving Benbecula', 3045, 3, 4, 32, 9999, NULL, 225, 0, '');
INSERT INTO 'recording' VALUES (830, NULL, '2022-12-19 18:10:05.047631+00', 'Homeward Bound', 3045, 1, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (9122, '2013-01-05 17:00:46.121598+00', '2022-12-26 18:42:29.202845+00', 'Waves of Tory, The', 10108, 1, 5, 48, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (859, NULL, '2014-09-16 12:34:05.749723+00', 'Strathspey', 3039, 3, 4, 32, 9999, NULL, 247, 0, '');
INSERT INTO 'recording' VALUES (860, NULL, '2014-09-16 12:34:29.910733+00', 'Sailor, The', 3039, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (861, NULL, '2014-09-16 12:35:00.196219+00', 'Jig', 3039, 2, 5, 32, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (862, NULL, '2014-09-16 12:35:28.317687+00', 'Strathspey', 3039, 3, 3, 48, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (863, NULL, '2014-09-16 12:35:55.077522+00', 'Caddam Wood', 3039, 1, 5, 32, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (864, NULL, '2014-09-16 12:36:39.511192+00', 'Airs & Graces', 3039, 2, 8, 32, 9999, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (866, NULL, '2014-09-16 12:37:35.255053+00', 'Red Rose & White', 3039, 1, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (867, NULL, '2014-09-16 12:37:57.20217+00', 'Doune Ferryman', 3039, 2, 4, 40, 9999, NULL, 171, 1, '');
INSERT INTO 'recording' VALUES (868, NULL, '2014-09-16 12:39:47.728042+00', 'Reel', 3039, 1, 4, 40, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (853, NULL, '2014-10-19 16:11:57.21327+00', 'Set of Reels (Hornpipes)', 3047, 1, 8, 32, 9999, 5, 277, 0, '');
INSERT INTO 'recording' VALUES (871, NULL, '2012-01-20 12:55:06.44795+00', 'An'' Thou wert my Only Dear', 3049, 2, 8, 48, 9999, NULL, 415, 0, '');
INSERT INTO 'recording' VALUES (872, NULL, '2012-01-20 12:55:06.454239+00', 'Lea Rig, The', 3049, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (873, NULL, '2012-01-20 12:55:06.46048+00', 'Kingussie Flower', 3049, 1, 8, 40, 9999, NULL, 349, 0, '');
INSERT INTO 'recording' VALUES (874, NULL, '2012-01-20 12:55:06.466745+00', 'Braes of Breadalbane, The', 3049, 3, 8, 32, 9999, NULL, 492, 0, '');
INSERT INTO 'recording' VALUES (875, NULL, '2012-01-20 12:55:06.472988+00', 'Buchan Eightsome Reel, The', 3049, 1, 10, 40, 9999, NULL, 436, 0, '');
INSERT INTO 'recording' VALUES (876, NULL, '2012-01-20 12:55:06.479271+00', 'Muirland Willie', 3049, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (877, NULL, '2012-01-20 12:55:06.48551+00', 'Within a Mile of Edinburgh Toon', 3049, 3, 8, 32, 9999, NULL, 492, 0, '');
INSERT INTO 'recording' VALUES (878, NULL, '2012-01-20 12:55:06.491864+00', 'Maid of the Mill, The', 3049, 2, 8, 40, 9999, NULL, 351, 0, '');
INSERT INTO 'recording' VALUES (879, NULL, '2012-01-20 12:55:06.498134+00', 'Stoorie Miller, The', 3049, 3, 8, 32, 9999, NULL, 499, 0, '');
INSERT INTO 'recording' VALUES (880, NULL, '2012-01-20 12:55:06.504383+00', 'Reel of Mey, The', 3006, 2, 8, 48, 9999, NULL, 435, 0, '');
INSERT INTO 'recording' VALUES (881, NULL, '2012-01-20 12:55:06.510651+00', 'Hamilton Rant, The', 3006, 1, 8, 48, 9999, NULL, 419, 0, '');
INSERT INTO 'recording' VALUES (882, NULL, '2012-01-20 12:55:06.516938+00', 'Balmoral Strathspey', 3006, 3, 4, 32, 9999, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (883, NULL, '2012-01-20 12:55:06.523286+00', 'Holyrood House', 3006, 2, 4, 48, 9999, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (884, NULL, '2012-01-20 12:55:06.529524+00', 'Last of the Lairds, The', 3006, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (885, NULL, '2012-01-20 12:55:06.535671+00', 'Middleton Medley, The', 3006, 4, 8, 32, 8, NULL, 390, 0, '');
INSERT INTO 'recording' VALUES (887, NULL, '2012-01-20 12:55:06.545475+00', 'Minard Castle', 3006, 1, 8, 40, 9999, NULL, 347, 0, '');
INSERT INTO 'recording' VALUES (888, NULL, '2012-01-20 12:55:06.550284+00', 'Neidpath Castle', 3006, 3, 3, 32, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (890, NULL, '2012-01-20 12:55:06.559871+00', 'Laird of Milton''s Daughter, The', 3006, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (891, NULL, '2012-01-20 12:55:06.564663+00', 'Miss Janet Laing''s Strathspey', 3006, 3, 4, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (892, NULL, '2012-01-20 12:55:06.569444+00', 'Alyth Burn', 3006, 2, 8, 48, 9999, NULL, 414, 0, '');
INSERT INTO 'recording' VALUES (10229, '2018-09-15 09:55:20.374752+00', '2018-11-06 21:54:11.372383+00', 'Warm-Up Reel', 10659, 1, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (894, NULL, '2012-01-20 12:55:06.579291+00', 'Strathspey', 3006, 3, 8, 32, 9999, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (896, NULL, '2012-01-20 12:55:06.588955+00', 'Saint Andrews of Brampton', 3006, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (898, NULL, '2012-01-20 12:55:06.598559+00', 'Miss Mary Douglas', 3006, 2, 8, 48, 9999, NULL, 413, 0, '');
INSERT INTO 'recording' VALUES (9199, '2013-01-16 12:51:42.479952+00', '2013-01-16 12:51:42.479963+00', 'Boston Two-Step', 10709, 11, 8, 16, 9999, NULL, 125, 0, '');
INSERT INTO 'recording' VALUES (900, NULL, '2012-01-20 12:55:06.608249+00', 'Reel', 3006, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (901, NULL, '2012-01-20 12:55:06.613031+00', 'Wee Cooper o'' Fife, The', 3006, 2, 6, 40, 9999, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (3798, NULL, '2012-01-20 12:55:22.804889+00', 'Petronella', 3010, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (3799, NULL, '2012-01-20 12:55:22.811181+00', 'Montgomeries'' Rant, The', 3064, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3800, NULL, '2012-01-20 12:55:22.817408+00', 'Scottish Ramble', 3064, 3, 4, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3801, NULL, '2012-01-20 12:55:22.823641+00', 'Scottish Waltz', 3064, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3802, NULL, '2012-01-20 12:55:22.82992+00', 'River Cree', 3064, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3803, NULL, '2012-01-20 12:55:22.836178+00', 'Petronella', 3064, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3804, NULL, '2012-01-20 12:55:22.842411+00', 'Gay Gordons', 3064, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3805, NULL, '2012-01-20 12:55:22.84864+00', 'Bluebell Polka', 3064, 13, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3806, NULL, '2012-01-20 12:55:22.854991+00', 'Linton Ploughman', 3064, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3807, NULL, '2012-01-20 12:55:22.861228+00', 'Donald Bane', 3064, 3, 4, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3808, NULL, '2012-01-20 12:55:22.867452+00', 'Scottish Waltz', 3064, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3809, NULL, '2012-01-20 12:55:22.874097+00', 'Blue Bonnets', 3064, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3810, NULL, '2012-01-20 12:55:22.880337+00', 'Polka', 3064, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3811, NULL, '2012-01-20 12:55:22.886618+00', 'Isle of Skye', 3064, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3812, NULL, '2012-01-20 12:55:22.892862+00', 'Bonnie Ann', 3064, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3813, NULL, '2012-01-20 12:55:22.899135+00', 'Highland Schottische', 3064, 3, 0, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3814, NULL, '2012-01-20 12:55:22.905361+00', 'Hamilton Rant', 3059, 1, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3815, NULL, '2012-01-20 12:55:22.911588+00', 'Braes of Breadalbane', 3059, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3816, NULL, '2012-01-20 12:55:22.918348+00', 'Jessie''s Hornpipe', 3059, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3817, NULL, '2012-01-20 12:55:22.92458+00', 'Grand March', 3065, 11, 0, 160, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3818, NULL, '2012-01-20 12:55:22.930831+00', 'Circassian Circle', 3065, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (899, NULL, '2012-10-31 23:48:48.86751+00', 'Lea Rig, The', 3006, 3, 6, 32, 9999, NULL, 378, 0, '');
INSERT INTO 'recording' VALUES (9009, '2012-12-28 17:18:16.505668+00', '2012-12-28 17:18:16.505678+00', 'Pas De Basque & Hi Cuts', 10687, 7, 16, 1, 9999, NULL, 50, 0, '');
INSERT INTO 'recording' VALUES (9048, '2013-01-01 18:59:52.618391+00', '2013-01-01 18:59:52.618401+00', 'Strathspey, Highland Reel & Half Tulloch 2+6 Adult', 10687, 7, 8, 16, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (9096, '2013-01-04 12:32:24.116536+00', '2013-01-04 12:32:24.116548+00', 'Selection of Strathspeys', 3067, 3, 3, 32, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (9109, '2013-01-04 15:59:26.195435+00', '2013-01-04 15:59:26.195446+00', 'Home Again', 3092, 2, 8, 32, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (9123, '2013-01-05 17:05:03.596396+00', '2013-01-05 17:05:03.596406+00', 'Tango', 10108, 50, 0, 0, 9999, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (9131, '2013-01-05 17:44:50.098781+00', '2013-01-05 17:44:50.098791+00', 'Gay Gordons', 10108, 11, 8, 16, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (9140, '2013-01-06 14:12:11.512535+00', '2013-01-06 14:12:11.512545+00', 'Duke of Atholl''s Reel, The', 3010, 2, 8, 32, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (9156, '2013-01-06 17:11:52.411755+00', '2013-01-06 17:11:52.411766+00', 'Reels 3x32', 2029, 1, 3, 32, 9999, NULL, 106, 0, '');
INSERT INTO 'recording' VALUES (9192, '2013-01-06 21:40:49.514787+00', '2013-01-06 21:40:49.514797+00', 'Reel 4x32', 2029, 1, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (9229, '2013-02-02 14:28:18.804631+00', '2013-02-02 14:28:18.804642+00', 'Hielan'' Laddie', 10146, 7, 6, 16, NULL, NULL, 117, 0, '');
INSERT INTO 'recording' VALUES (9241, '2013-02-02 15:57:05.043196+00', '2013-02-02 15:57:05.043205+00', 'Eva Three Step', 10146, 11, 8, 16, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (9249, '2013-02-02 17:14:13.191896+00', '2013-02-02 17:14:13.191906+00', 'Strip the Willow', 10146, 2, 5, 32, 9999, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (9257, '2013-02-03 15:38:52.946979+00', '2013-02-03 15:38:52.94699+00', 'Reel of the 51st Division, The', 10547, 1, 6, 32, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (9264, '2013-02-05 14:34:06.074757+00', '2013-02-05 14:34:06.074767+00', 'Sailor''s Hornpipe 6 steps', 10743, 7, 6, 16, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (9267, '2013-02-05 14:46:33.351147+00', '2013-02-05 14:46:33.351157+00', 'Irish Jig 5 steps', 10742, 7, 5, 16, 9999, NULL, 97, 0, '');
INSERT INTO 'recording' VALUES (9285, '2013-02-05 16:10:08.41059+00', '2013-02-05 16:10:08.410601+00', 'Choreography', 10747, 4, 0, 0, 9998, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (903, NULL, '2012-01-20 12:55:06.622645+00', 'Flower o'' the Quern, The', 3050, 3, 4, 32, 9999, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (904, NULL, '2012-01-20 12:55:06.628164+00', 'Haymakers, The', 3018, 2, 4, 48, 9999, 20, 199, 0, '');
INSERT INTO 'recording' VALUES (905, NULL, '2012-01-20 12:55:06.632995+00', 'Hazel Tree, The', 3050, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (907, NULL, '2012-01-20 12:55:06.64392+00', 'Bob o'' Dowally, The', 3018, 3, 4, 32, 9999, 5, 241, 0, '');
INSERT INTO 'recording' VALUES (908, NULL, '2012-01-20 12:55:06.649418+00', 'Princess Royal, The', 3018, 1, 8, 28, 9999, 36, 244, 0, '');
INSERT INTO 'recording' VALUES (869, NULL, '2022-12-09 10:44:29.023018+00', 'Longhandled Broom, The', 3039, 3, 8, 32, 9999, NULL, 467, 0, '');
INSERT INTO 'recording' VALUES (910, NULL, '2012-01-20 12:55:06.660695+00', 'Speed the Plough', 3018, 1, 8, 32, 9999, 5, 267, 0, '');
INSERT INTO 'recording' VALUES (911, NULL, '2012-01-20 12:55:06.665611+00', 'Perth Medley, The', 3018, 4, 4, 64, 22, NULL, 450, 0, '');
INSERT INTO 'recording' VALUES (912, NULL, '2012-01-20 12:55:06.670409+00', 'Bumpkin, The', 3018, 2, 0, 224, 9999, NULL, 234, 0, '');
INSERT INTO 'recording' VALUES (913, NULL, '2012-01-20 12:55:06.675881+00', 'Delvine Side', 3018, 3, 4, 32, 9999, 5, 243, 0, '');
INSERT INTO 'recording' VALUES (886, NULL, '2014-08-25 17:44:39.599166+00', 'Peggy''s Wedding', 3006, 2, 4, 64, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (918, NULL, '2012-01-20 12:55:06.703245+00', 'Rock and the Wee Pickle Tow, The', 3018, 2, 8, 32, 9999, 1, 278, 0, '');
INSERT INTO 'recording' VALUES (922, NULL, '2012-01-20 12:55:06.725139+00', 'Aroon the Clachan of Dalry', 2029, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (927, NULL, '2012-01-20 12:55:06.75197+00', 'Torryburn Lassies', 3011, 1, 8, 32, 9999, 5, 286, 0, '');
INSERT INTO 'recording' VALUES (929, NULL, '2012-01-20 12:55:06.763024+00', 'Queen''s Welcome', 3011, 1, 8, 32, 9999, 5, 282, 0, '');
INSERT INTO 'recording' VALUES (930, NULL, '2012-01-20 12:55:06.76854+00', 'Kenmure''s On and Awa''', 3011, 2, 8, 24, 9999, 21, 214, 0, '');
INSERT INTO 'recording' VALUES (931, NULL, '2012-01-20 12:55:06.774291+00', 'Highland Laddie', 3011, 1, 8, 32, 9999, 5, 284, 0, '');
INSERT INTO 'recording' VALUES (932, NULL, '2012-01-20 12:55:06.77982+00', 'Ninety-Second, The', 3011, 3, 4, 24, 9999, 18, 0, 0, '');
INSERT INTO 'recording' VALUES (933, NULL, '2012-01-20 12:55:06.785297+00', 'Falkland Beauty, The', 3011, 2, 8, 24, 9999, 16, 212, 0, '');
INSERT INTO 'recording' VALUES (934, NULL, '2012-01-20 12:55:06.790114+00', 'Dancing Master, The', 3050, 2, 0, 96, 9999, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (935, NULL, '2012-01-20 12:55:06.794912+00', 'Mary Hamilton', 3050, 3, 4, 32, 9999, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (936, NULL, '2012-01-20 12:55:06.79972+00', 'Duncan Gray', 3050, 1, 8, 40, 9999, NULL, 359, 0, '');
INSERT INTO 'recording' VALUES (938, NULL, '2012-01-20 12:55:06.809352+00', 'Anna Holden''s Strathspey', 3050, 3, 8, 32, 9999, NULL, 516, 0, '');
INSERT INTO 'recording' VALUES (939, NULL, '2012-01-20 12:55:06.814159+00', 'Black Black Oil, The', 3050, 1, 5, 32, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (941, NULL, '2012-01-20 12:55:06.823728+00', 'Cradle Song, The', 3050, 3, 8, 32, 9999, NULL, 511, 0, '');
INSERT INTO 'recording' VALUES (942, NULL, '2012-01-20 12:55:06.828537+00', 'Ski Tow, The', 3050, 2, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (3819, NULL, '2012-01-20 12:55:22.937071+00', 'Cumberland Reel, The', 3065, 2, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3820, NULL, '2012-01-20 12:55:22.943321+00', 'Dashing White Sergeant', 3065, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (914, NULL, '2017-03-09 16:27:36.051494+00', 'Why Not?', 3014, 1, 4, 40, 9999, 14, 173, 0, '');
INSERT INTO 'recording' VALUES (919, NULL, '2017-03-09 16:27:50.44242+00', 'Culla Bay', 3014, 3, 4, 32, 9999, 5, 264, 0, '');
INSERT INTO 'recording' VALUES (10231, '2018-09-15 09:57:38.986356+00', '2018-11-06 21:54:11.154051+00', 'Foula Reel, The', 10659, 2, 4, 48, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (870, NULL, '2019-10-28 11:40:27.861707+00', 'Cramond Bridge', 3039, 1, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (928, NULL, '2019-01-23 18:12:16.857892+00', 'Foula Reel, The', 3011, 2, 4, 40, 9999, 14, 161, 0, '');
INSERT INTO 'recording' VALUES (3821, NULL, '2012-01-20 12:55:22.949556+00', 'Eightsome Reel', 3065, 1, 0, 464, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3822, NULL, '2012-01-20 12:55:22.955813+00', 'Red House', 3065, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3823, NULL, '2012-01-20 12:55:22.962053+00', 'Bonnie Kate of Aberdeen', 3065, 3, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3824, NULL, '2012-01-20 12:55:22.968271+00', 'Bottom of the Punch Bowl, The', 3065, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3825, NULL, '2012-01-20 12:55:22.974533+00', 'Mairrit Man''s Favourite, The', 3025, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3826, NULL, '2012-01-20 12:55:22.980766+00', 'Flowers of Edinburgh', 3025, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3827, NULL, '2012-01-20 12:55:22.987027+00', 'Scottish Waltz', 3025, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3828, NULL, '2012-01-20 12:55:22.993275+00', 'Miss Bennet''s Jig', 3025, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3829, NULL, '2012-01-20 12:55:22.999505+00', 'Baldovan Reel', 3025, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3830, NULL, '2012-01-20 12:55:23.005859+00', 'Hollin Buss, The', 3025, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3831, NULL, '2012-01-20 12:55:23.012096+00', 'Birks of Invermay, The', 1813, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3832, NULL, '2012-01-20 12:55:23.018325+00', 'Wild Geese, The', 1813, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3833, NULL, '2012-01-20 12:55:23.024542+00', 'Lady Auckland''s Reel', 1813, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3834, NULL, '2012-01-20 12:55:23.0308+00', 'Scotch Circle, The', 1813, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3835, NULL, '2012-01-20 12:55:23.037051+00', 'Duke of Atholl''s Reel, The', 1813, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3836, NULL, '2012-01-20 12:55:23.043349+00', 'Braes of Breadalbane, The', 1813, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3837, NULL, '2012-01-20 12:55:23.04957+00', 'Maxwell''s Rant', 1813, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3838, NULL, '2012-01-20 12:55:23.055795+00', 'Frisky, The', 1813, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9049, '2013-01-01 19:07:10.341713+00', '2013-01-02 12:05:07.942359+00', 'Irish Jig 4 Junior', 10687, 7, 4, 16, 9999, NULL, 78, 0, '');
INSERT INTO 'recording' VALUES (9141, '2013-01-06 14:14:51.806402+00', '2013-01-06 14:14:51.806412+00', 'Gay Gordons', 3065, 11, 0, 16, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (9157, '2013-01-06 17:18:15.650079+00', '2013-01-06 17:18:15.650089+00', 'Reels 5x32', 2029, 1, 5, 32, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (9193, '2013-01-06 21:43:04.92936+00', '2013-01-06 21:43:04.92937+00', 'Strathspey 4x32', 2029, 3, 4, 32, 9999, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (9200, '2013-01-16 13:18:36.302521+00', '2013-01-16 13:18:36.302531+00', 'Bradford Barn Dance', 10709, 50, 8, 16, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (9230, '2013-02-02 14:32:54.929733+00', '2013-02-02 14:32:54.929744+00', 'Dark Island, The', 10146, 98, 0, 0, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (9242, '2013-02-02 16:03:12.865391+00', '2013-02-02 16:08:23.05749+00', 'Eightsome Reel', 10146, 1, 1, 464, 9999, NULL, 485, 0, '');
INSERT INTO 'recording' VALUES (9250, '2013-02-02 17:16:56.710022+00', '2013-02-02 17:16:56.710032+00', 'Last Waltz, The', 10146, 5, 0, 32, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (9258, '2013-02-03 15:45:34.017286+00', '2013-02-03 15:45:34.0173+00', 'Pet O'' the Pipers', 10547, 4, 1, 96, 10027, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (9268, '2013-02-05 14:48:59.075643+00', '2013-02-05 14:48:59.075653+00', 'Irish Jig', 10743, 7, 5, 16, 9999, NULL, 98, 0, '');
INSERT INTO 'recording' VALUES (906, NULL, '2020-09-14 11:29:17.777629+00', 'Soldier''s Joy, The', 3018, 1, 8, 32, 9999, 1, 268, 0, '');
INSERT INTO 'recording' VALUES (940, NULL, '2021-03-27 15:55:07.773621+00', 'Quincentenary Jig, The', 3050, 2, 5, 32, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (943, NULL, '2012-01-20 12:55:06.833332+00', 'Prince Rupert''s Fancy', 3050, 3, 3, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (944, NULL, '2012-01-20 12:55:06.838287+00', 'Silver Fern Reel, The', 3050, 1, 8, 32, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (945, NULL, '2012-01-20 12:55:06.84309+00', 'Bydand', 3050, 3, 8, 32, 9999, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (946, NULL, '2012-01-20 12:55:06.847879+00', 'Glenalmond Gamekeeper, The', 3050, 1, 8, 40, 9999, NULL, 361, 0, '');
INSERT INTO 'recording' VALUES (953, NULL, '2018-04-13 20:29:15.965098+00', 'Black Potts', 3014, 3, 4, 32, 9999, 5, 251, 1, '');
INSERT INTO 'recording' VALUES (955, NULL, '2012-01-20 12:55:06.897213+00', 'Bill Martin''s Strathspey', 3060, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (956, NULL, '2012-01-20 12:55:06.902023+00', 'Reel of the Four Diamonds', 3060, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (957, NULL, '2012-01-20 12:55:06.906861+00', 'Lyne Valley Reel', 3060, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (958, NULL, '2012-01-20 12:55:06.911649+00', 'Caerleol Cross', 3060, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (959, NULL, '2012-01-20 12:55:06.916925+00', 'Honour Your Partner', 3060, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (960, NULL, '2012-01-20 12:55:06.921785+00', 'Kirkgate Reel', 3060, 1, 0, 88, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (961, NULL, '2012-01-20 12:55:06.926601+00', 'Tribute to the Ladies', 3060, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (962, NULL, '2012-01-20 12:55:06.931383+00', 'Blackford Jig', 3060, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (924, NULL, '2014-09-16 10:13:50.886173+00', 'Jenny, Come Down to Jock', 3018, 2, 8, 24, 9999, 18, 210, 0, '');
INSERT INTO 'recording' VALUES (916, NULL, '2014-09-16 10:17:35.297928+00', 'Blue Bonnets', 3018, 2, 8, 32, 9999, 1, 278, 0, '');
INSERT INTO 'recording' VALUES (915, NULL, '2014-09-16 10:18:06.484843+00', 'Fairy Dance, The', 3018, 1, 8, 32, 9999, 5, 282, 0, '');
INSERT INTO 'recording' VALUES (925, NULL, '2014-09-16 10:18:49.243736+00', 'Rachel Rae', 3018, 1, 8, 24, 9999, 18, 214, 0, '');
INSERT INTO 'recording' VALUES (917, NULL, '2014-09-16 10:20:11.305559+00', 'Eight Men of Moidart, The', 3018, 1, 8, 16, 9999, 1, 280, 0, '');
INSERT INTO 'recording' VALUES (926, NULL, '2014-09-16 10:20:34.663161+00', 'Foursome Reel, The', 3018, 4, 0, 128, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (963, NULL, '2012-01-20 12:55:06.936165+00', 'Rockcliffe Rant', 3060, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (964, NULL, '2012-01-20 12:55:06.940944+00', 'Huntsman, The', 3038, 2, 4, 40, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (966, NULL, '2012-01-20 12:55:06.950556+00', 'Reel of the Gordon Highlanders, The', 3038, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (967, NULL, '2012-01-20 12:55:06.955351+00', 'Travelling Men, The', 3038, 2, 5, 32, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (968, NULL, '2012-01-20 12:55:06.960142+00', 'MacDonald of the Isles', 3038, 3, 3, 32, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (969, NULL, '2012-01-20 12:55:06.96493+00', 'Barmkin, The', 3038, 1, 0, 88, 9999, NULL, 103, 0, '');
INSERT INTO 'recording' VALUES (970, NULL, '2012-01-20 12:55:06.969713+00', 'Immigrant Lass, The', 3038, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (971, NULL, '2012-01-20 12:55:06.974717+00', 'Saint Andrews of Brampton', 3038, 1, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (972, NULL, '2012-01-20 12:55:06.97952+00', 'Butterscotch and Honey', 3038, 3, 4, 32, 9999, NULL, 240, 0, '');
INSERT INTO 'recording' VALUES (973, NULL, '2012-01-20 12:55:06.984332+00', 'Ciamar a Tha', 3038, 2, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (974, NULL, '2012-01-20 12:55:06.989123+00', 'Niel Gow''s Farewell to Whisky', 3038, 1, 4, 48, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (975, NULL, '2012-01-20 12:55:06.993935+00', 'Rose of the North, The', 3038, 3, 8, 32, 9999, NULL, 475, 0, '');
INSERT INTO 'recording' VALUES (976, NULL, '2012-01-20 12:55:06.998728+00', 'Tae Fife and Back', 3038, 2, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (978, NULL, '2012-01-20 12:55:07.008458+00', 'Strathcare', 3002, 3, 8, 32, 9999, NULL, 525, 0, '');
INSERT INTO 'recording' VALUES (979, NULL, '2012-01-20 12:55:07.013254+00', 'Macleod''s Tables', 3002, 1, 2, 48, 9999, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (980, NULL, '2012-01-20 12:55:07.018178+00', 'Stan and Janet''s Jig', 3002, 2, 4, 32, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (982, NULL, '2012-01-20 12:55:07.027886+00', 'Marches', 3002, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (983, NULL, '2012-01-20 12:55:07.032663+00', 'Strathspey and Reel', 3002, 4, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (984, NULL, '2012-01-20 12:55:07.036797+00', 'March and Hornpipe', 3002, 4, 0, 128, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3839, NULL, '2012-01-20 12:55:23.062031+00', 'Barn Dance', 3056, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3840, NULL, '2012-01-20 12:55:23.068267+00', 'Waltz', 3056, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3841, NULL, '2012-01-20 12:55:23.074497+00', 'Turlers, Da', 3056, 1, 3, 96, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (948, NULL, '2017-03-09 16:28:31.029464+00', 'Forbes Rant', 3014, 2, 8, 32, 9999, 1, 266, 0, '');
INSERT INTO 'recording' VALUES (947, NULL, '2017-03-09 16:28:16.955225+00', 'Vale of Strathmore, The', 3014, 3, 3, 32, 9999, 5, 187, 0, '');
INSERT INTO 'recording' VALUES (949, NULL, '2017-03-09 16:28:47.352376+00', 'Haggis Hunters, The', 3014, 4, 0, 128, 2, 1, 190, 0, '');
INSERT INTO 'recording' VALUES (951, NULL, '2017-03-09 16:29:18.395083+00', 'Tom Steele', 3014, 3, 4, 32, 9999, 5, 255, 0, '');
INSERT INTO 'recording' VALUES (952, NULL, '2017-03-09 16:29:51.055035+00', 'Penny Whistle, The', 3014, 2, 8, 32, 9999, 1, 266, 0, '');
INSERT INTO 'recording' VALUES (954, NULL, '2017-03-09 16:30:25.398224+00', 'Bon Voyage', 3014, 1, 8, 32, 9999, 1, 276, 0, '');
INSERT INTO 'recording' VALUES (9286, '2013-02-06 11:25:47.268081+00', '2019-02-03 09:02:30.298445+00', 'Black Dance, The', 10748, 1, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (965, NULL, '2019-06-28 14:48:43.026688+00', 'Makin'' the Tartan', 3038, 3, 4, 40, 9999, NULL, 305, 0, '');
INSERT INTO 'recording' VALUES (3842, NULL, '2012-01-20 12:55:23.080711+00', 'Gay Gordons', 3056, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3843, NULL, '2012-01-20 12:55:23.087313+00', 'Gay Gordons', 3056, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3844, NULL, '2012-01-20 12:55:23.093532+00', 'Waltz', 3056, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3845, NULL, '2012-01-20 12:55:23.099759+00', 'To the Games', 2328, 98, 0, 0, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (3846, NULL, '2012-01-20 12:55:23.106004+00', 'Bonnie Kate of Aberdeen', 2328, 3, 0, 88, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3847, NULL, '2012-01-20 12:55:23.112217+00', 'Linton Ploughman', 2328, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3848, NULL, '2012-01-20 12:55:23.118481+00', 'Langshaw Lassies', 2328, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3849, NULL, '2012-01-20 12:55:23.124721+00', 'Highland Two Step', 2328, 7, 0, 0, 9999, NULL, 222, 0, '');
INSERT INTO 'recording' VALUES (3850, NULL, '2012-01-20 12:55:23.130982+00', 'Trip to Aberdeen, A', 2328, 2, 6, 32, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (3851, NULL, '2012-01-20 12:55:23.13723+00', 'Wee Pickle Tow', 2328, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3852, NULL, '2012-01-20 12:55:23.143465+00', 'Lassies of Dunse, The', 2328, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3853, NULL, '2012-01-20 12:55:23.149714+00', 'Kiss Me Quick, My Mither''s Coming', 2328, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3854, NULL, '2012-01-20 12:55:23.156003+00', 'Dance instruction: Lady Stewart Macpherson''s Reel', 1094, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3855, NULL, '2012-01-20 12:55:23.162255+00', 'Lady Stewart Macpherson''s Reel', 2330, 1, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3856, NULL, '2012-01-20 12:55:23.168489+00', 'Macphersons of Edinburgh, The', 2330, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3857, NULL, '2012-01-20 12:55:23.174762+00', 'Traditional Fiddling Interlude', 1541, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9050, '2013-01-01 19:08:20.313507+00', '2013-01-02 12:05:23.490559+00', 'Irish Jig 5 Medium', 10687, 7, 5, 16, 9999, NULL, 96, 0, '');
INSERT INTO 'recording' VALUES (9098, '2013-01-04 12:34:42.718973+00', '2013-01-04 12:34:42.718985+00', 'Selection of Jigs', 3067, 2, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (9142, '2013-01-06 14:20:43.348084+00', '2013-01-06 14:20:43.348094+00', 'Road to the Isles, The', 2038, 3, 4, 32, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (9158, '2013-01-06 17:23:20.019945+00', '2013-01-06 17:23:20.019961+00', 'Reels 6x32', 2029, 1, 6, 32, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (9201, '2013-01-16 13:22:52.150689+00', '2013-01-16 13:22:52.1507+00', 'Auld Meal Mill, The', 10713, 98, 0, 0, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (9231, '2013-02-02 14:37:17.190297+00', '2013-02-02 14:37:17.190308+00', 'Military Two Step, The', 10146, 11, 16, 16, 9999, NULL, 223, 0, '');
INSERT INTO 'recording' VALUES (9243, '2013-02-02 16:21:21.384556+00', '2013-02-02 16:21:21.384566+00', 'Seann Truibhas', 10146, 7, 6, 8, 9999, NULL, 94, 0, '');
INSERT INTO 'recording' VALUES (9259, '2013-02-03 15:48:19.419907+00', '2013-02-03 15:48:19.419928+00', 'Gay Gordons, The', 10547, 11, 8, 16, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (9269, '2013-02-05 14:52:16.227972+00', '2013-02-05 14:52:16.227982+00', 'Irish Jig 5 steps', 10742, 7, 5, 16, 9999, NULL, 97, 0, '');
INSERT INTO 'recording' VALUES (9287, '2013-02-06 11:28:39.848376+00', '2013-02-06 11:28:39.848386+00', 'Highland Piper''s Society of Glasgow', 10748, 11, 4, 16, 9999, NULL, 100, 0, '');
INSERT INTO 'recording' VALUES (9290, '2013-02-06 12:49:40.483399+00', '2013-02-06 12:49:40.483409+00', 'Scotland Yet', 10748, 11, 0, 32, 9999, NULL, 118, 0, '');
INSERT INTO 'recording' VALUES (9291, '2013-02-06 13:08:20.955323+00', '2013-02-06 13:08:20.955334+00', 'Road to the Isles', 10748, 2, 4, 32, NULL, NULL, 127, 0, '');
INSERT INTO 'recording' VALUES (9293, '2013-02-06 13:53:19.31916+00', '2013-02-06 13:53:19.31917+00', 'Reels', 10748, 1, 3, 32, 9999, NULL, 95, 0, '');
INSERT INTO 'recording' VALUES (9294, '2013-02-06 14:13:59.968222+00', '2013-02-06 14:13:59.968233+00', 'Gaelic Waltz', 10748, 5, 0, 32, 9999, NULL, 126, 0, '');
INSERT INTO 'recording' VALUES (9296, '2013-02-06 14:26:14.56193+00', '2013-02-06 14:26:14.561941+00', 'Flowers of Edinburgh Medley', 10748, 1, 3, 32, 9999, NULL, 86, 0, '');
INSERT INTO 'recording' VALUES (9297, '2013-02-06 14:31:03.939446+00', '2013-02-06 14:31:03.939456+00', 'Hornpipe Medley', 10748, 98, 2, 32, 9999, NULL, 92, 0, '');
INSERT INTO 'recording' VALUES (985, NULL, '2012-01-20 12:55:07.041624+00', 'Exciseman, The', 3002, 1, 5, 32, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (988, NULL, '2012-01-20 12:55:07.056145+00', 'Prince Charles Welcome to the Isle of Skye', 3002, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (989, NULL, '2012-01-20 12:55:07.060952+00', 'Hornpipe', 3002, 1, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (990, NULL, '2012-01-20 12:55:07.065787+00', 'Strathspey and Reel', 3002, 4, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (991, NULL, '2012-01-20 12:55:07.070595+00', 'Waltzes', 3002, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (992, NULL, '2012-01-20 12:55:07.076064+00', 'Set of Jigs', 3002, 2, 6, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (993, NULL, '2012-01-20 12:55:07.081582+00', 'South and North, or Both Sides of the Tweed', 3002, 4, 2, 0, 5, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (994, NULL, '2012-01-20 12:55:07.086092+00', 'Gentle Shepherd, The', 3002, 4, 0, 32, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (995, NULL, '2012-01-20 12:55:07.090917+00', 'Ca'' the Ewes', 3002, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (996, NULL, '2012-01-20 12:55:07.09572+00', 'Maxwell''s Rant', 3002, 1, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (997, NULL, '2012-01-20 12:55:07.100544+00', 'Go to Berwick, Johnnie', 3002, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (998, NULL, '2012-01-20 12:55:07.105368+00', 'Sir John Fenwick''s the Flower of Them All', 3002, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (999, NULL, '2012-01-20 12:55:07.110212+00', 'Tweedside', 3002, 50, 3, 36, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1000, NULL, '2012-01-20 12:55:07.115026+00', 'Set of 9/8 Jigs', 3002, 2, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1001, NULL, '2012-01-20 12:55:07.15664+00', 'Set of Reels', 3002, 1, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1002, NULL, '2012-01-20 12:55:07.160999+00', 'Mrs Fordyce of Ayton', 3002, 4, 0, 192, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1003, NULL, '2012-01-20 12:55:07.165792+00', 'Blue Bonnets over the Border', 3002, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1004, NULL, '2012-01-20 12:55:07.170714+00', 'Scottish Waltz Selection', 3063, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1005, NULL, '2012-01-20 12:55:07.175587+00', 'Ring of Friendship, A', 3055, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (1006, NULL, '2012-01-20 12:55:07.180434+00', 'Bratach Bana', 3055, 1, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (977, NULL, '2022-08-31 21:42:03.851966+00', 'Welcome to Skye', 3002, 2, 4, 32, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (986, NULL, '2022-09-01 20:51:39.409103+00', 'Anne Munro of Portree', 3002, 2, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (1007, NULL, '2012-01-20 12:55:07.185245+00', 'Mary Stewart Strathspey, The', 3055, 3, 4, 32, 9999, NULL, 244, 0, '');
INSERT INTO 'recording' VALUES (1008, NULL, '2012-01-20 12:55:07.190055+00', 'Reel of the 51st Division, The', 3055, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (1009, NULL, '2012-01-20 12:55:07.19486+00', 'Gay Gordons, The', 3055, 11, 0, 0, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (1011, NULL, '2012-01-20 12:55:07.204466+00', 'Kilt is my Delight, The', 3055, 1, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (1012, NULL, '2012-01-20 12:55:07.209266+00', 'Hamilton House', 3055, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (1013, NULL, '2012-01-20 12:55:07.214075+00', 'Follow the Fiddler', 3055, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (1014, NULL, '2012-01-20 12:55:07.219147+00', 'Donald''s Strathspey', 3055, 3, 3, 32, 9999, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (1015, NULL, '2012-01-20 12:55:07.224152+00', 'Joe MacDiarmid''s Jig', 3055, 2, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (1016, NULL, '2012-01-20 12:55:07.228969+00', 'Waltz Country Dance', 3055, 5, 4, 40, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (1017, NULL, '2012-01-20 12:55:07.233797+00', 'Caddam Wood', 3055, 1, 5, 32, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (1018, NULL, '2012-01-20 12:55:07.238661+00', 'Culla Bay', 3055, 3, 4, 32, 9999, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (1019, NULL, '2012-01-20 12:55:07.244641+00', 'Canadian Barn Dance', 3055, 11, 0, 16, 9999, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (1020, NULL, '2012-01-20 12:55:07.251144+00', 'Circassian Circle', 3055, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (1021, NULL, '2012-01-20 12:55:07.257581+00', 'Tribute to the Borders', 3055, 2, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (1022, NULL, '2012-01-20 12:55:07.263847+00', 'Shiftin'' Bobbins', 2570, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (1023, NULL, '2012-01-20 12:55:07.270163+00', 'Schiehallion', 2570, 4, 0, 128, 2, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (1024, NULL, '2012-01-20 12:55:07.276411+00', 'Bees of Maggieknockater, The', 2570, 2, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (1025, NULL, '2012-01-20 12:55:07.282908+00', 'Duchess Tree, The', 2570, 3, 8, 32, 9999, NULL, 510, 0, '');
INSERT INTO 'recording' VALUES (1026, NULL, '2012-01-20 12:55:07.289338+00', 'Jennifer''s Jig', 2570, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (1027, NULL, '2012-01-20 12:55:07.294839+00', 'Cold and Raw', 2570, 2, 8, 24, 9999, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (1029, NULL, '2012-01-20 12:55:07.304592+00', 'Johnnie''s Welcome Hame', 2570, 1, 8, 40, 9999, NULL, 345, 0, '');
INSERT INTO 'recording' VALUES (1030, NULL, '2012-01-20 12:55:07.309532+00', 'Balmoral Strathspey', 2570, 3, 4, 32, 9999, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (9202, '2013-01-16 13:29:27.743034+00', '2013-01-16 13:29:27.743045+00', 'Britannia Two-Step', 10709, 11, 8, 16, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (1032, NULL, '2012-01-20 12:55:07.31918+00', 'Shepherds Crook', 9998, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3858, NULL, '2012-01-20 12:55:23.18099+00', 'Canadian Barn Dance', 2090, 11, 0, 16, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (3859, NULL, '2012-01-20 12:55:23.187352+00', 'Strathspey', 2333, 3, 2, 40, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (3860, NULL, '2012-01-20 12:55:23.19358+00', 'Duke of Perth', 2090, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (3861, NULL, '2012-01-20 12:55:23.199803+00', 'Grand March', 2173, 11, 0, 0, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (3862, NULL, '2012-01-20 12:55:23.206113+00', 'Waltz Country Dance', 3001, 5, 6, 40, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (3863, NULL, '2012-01-20 12:55:23.212335+00', 'Fiona''s Polka', 3025, 13, 0, 0, 9999, NULL, 159, 0, '');
INSERT INTO 'recording' VALUES (3864, NULL, '2012-01-20 12:55:23.218588+00', 'Duke of Perth (Encore)', 2090, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (3865, NULL, '2012-01-20 12:55:23.224835+00', 'Hebridean Barn Dance', 2333, 50, 0, 0, 9999, NULL, 232, 0, '');
INSERT INTO 'recording' VALUES (3866, NULL, '2012-01-20 12:55:23.231086+00', 'Speed the Plough', 2090, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (3867, NULL, '2012-01-20 12:55:23.237301+00', 'Gay Gordons', 3025, 11, 0, 16, 9999, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (3868, NULL, '2012-01-20 12:55:23.243579+00', 'Montgomerys'' Rant, The', 3001, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (3869, NULL, '2012-01-20 12:55:23.249928+00', 'Highland Schottische', 2173, 3, 12, 8, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (3870, NULL, '2012-01-20 12:55:23.257004+00', 'Dashing White Sergeant, The', 2069, 1, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (3871, NULL, '2012-01-20 12:55:23.26407+00', 'Two Step', 2069, 2, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (3872, NULL, '2012-01-20 12:55:23.270397+00', 'Gaelic Waltz', 2069, 5, 0, 0, 9999, NULL, 226, 0, '');
INSERT INTO 'recording' VALUES (3873, NULL, '2012-01-20 12:55:23.276746+00', 'Drops of Brandy', 2069, 2, 4, 32, 9999, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (3874, NULL, '2012-01-20 12:55:23.283144+00', 'Highland Schottische', 2069, 3, 8, 8, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (9232, '2013-02-02 14:46:29.574546+00', '2013-02-02 14:46:29.574556+00', 'Scotch Measure', 10146, 7, 8, 16, 9999, NULL, 116, 0, '');
INSERT INTO 'recording' VALUES (9051, '2013-01-01 19:09:16.030442+00', '2013-01-02 12:05:38.570084+00', 'Irish Jig 6 Adult', 10687, 7, 6, 16, 9999, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (9099, '2013-01-04 12:35:59.673494+00', '2013-01-04 12:35:59.673505+00', 'Selection of Strathspeys', 3067, 3, 6, 32, 9999, NULL, 402, 0, '');
INSERT INTO 'recording' VALUES (9143, '2013-01-06 14:24:29.245188+00', '2013-01-06 14:24:29.245199+00', 'Gaelic Airs', 2246, 5, 4, 32, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (9159, '2013-01-06 17:37:50.650897+00', '2013-01-06 17:37:50.650907+00', 'Strathspeys 2x32', 2029, 3, 2, 32, 9999, NULL, 127, 0, '');
INSERT INTO 'recording' VALUES (9244, '2013-02-02 16:31:34.937392+00', '2013-02-02 16:31:34.937403+00', 'Scottish Waltz', 10146, 5, 8, 16, 9999, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (9260, '2013-02-03 15:56:11.697499+00', '2013-02-03 15:56:11.697509+00', 'Highland Reel', 10547, 1, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (9270, '2013-02-05 14:54:11.815024+00', '2013-02-05 14:54:11.815035+00', 'Irish Jig 5 steps', 10743, 7, 5, 16, 9999, NULL, 98, 0, '');
INSERT INTO 'recording' VALUES (9288, '2013-02-06 11:31:01.087505+00', '2013-02-06 11:31:01.087515+00', 'Lorna Ann Stirrat''s Waltz', 10748, 5, 0, 32, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (9292, '2013-02-06 13:12:06.877723+00', '2013-02-06 13:12:06.877734+00', 'Kiss Me Quick, My Mither''s Coming', 10748, 1, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (9295, '2013-02-06 14:19:13.307583+00', '2013-02-06 14:19:13.307593+00', 'River Cree, The', 10748, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (987, NULL, '2021-08-04 01:42:50.371106+00', 'Farewell to the Island', 3002, 3, 8, 32, 9999, NULL, 521, 0, '');
INSERT INTO 'recording' VALUES (9298, '2013-02-06 14:36:12.658388+00', '2013-02-06 14:36:12.658398+00', 'Circassian Circle', 10748, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (1033, NULL, '2012-01-20 12:55:07.324653+00', 'Highland Fling', 9998, 7, 0, 32, 9999, 8, 0, 0, '');
INSERT INTO 'recording' VALUES (1034, NULL, '2012-01-20 12:55:07.330256+00', 'Tribute to the Borders', 9998, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1037, NULL, '2012-01-20 12:55:07.346075+00', 'Waltz Country Dance', 3065, 5, 4, 40, 9999, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (1042, NULL, '2012-01-20 12:55:07.372297+00', 'Kicking Horse, The', 3008, 1, 8, 32, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (1043, NULL, '2012-01-20 12:55:07.377115+00', 'Jimmy Burgess Two-Step', 3008, 11, 10, 16, 9999, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (1044, NULL, '2012-01-20 12:55:07.381917+00', 'Veleta', 3008, 5, 10, 16, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (1045, NULL, '2012-01-20 12:55:07.386708+00', 'Highland Heritage', 3008, 11, 0, 0, 9999, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (1046, NULL, '2012-01-20 12:55:07.391493+00', 'Glayva', 3008, 2, 4, 32, 9999, NULL, 126, 0, '');
INSERT INTO 'recording' VALUES (1047, NULL, '2012-01-20 12:55:07.396273+00', 'Scandinavian Waltz', 3008, 5, 0, 0, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (1048, NULL, '2012-01-20 12:55:07.401042+00', 'Polka', 3008, 13, 0, 0, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (1049, NULL, '2012-01-20 12:55:07.405847+00', 'Irish Hornpipes', 3008, 1, 9, 16, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (1050, NULL, '2012-01-20 12:55:07.410669+00', 'New Killarney Waltz', 3008, 5, 0, 0, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (1051, NULL, '2012-01-20 12:55:07.415494+00', 'Trip to Bavaria, A', 3008, 1, 4, 32, 9999, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (1052, NULL, '2012-01-20 12:55:07.420547+00', 'Grand March', 3008, 11, 11, 16, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (1053, NULL, '2012-01-20 12:55:07.425376+00', 'Cockney Capers', 3008, 11, 4, 32, 9999, NULL, 125, 0, '');
INSERT INTO 'recording' VALUES (1054, NULL, '2012-01-20 12:55:07.430181+00', 'Brazilian Nights', 3008, 5, 0, 0, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (1055, NULL, '2012-01-20 12:55:07.434969+00', 'Rio Reel, The', 3008, 1, 4, 32, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (1056, NULL, '2012-01-20 12:55:07.439754+00', 'Square Tango', 3008, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1057, NULL, '2012-01-20 12:55:07.444564+00', 'Foula Reel, The', 3008, 2, 4, 32, 9999, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (1058, NULL, '2012-01-20 12:55:07.449378+00', 'Virginia Plantation Reel, The', 3008, 1, 5, 32, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (1040, NULL, '2022-08-21 22:10:40.344291+00', 'Dundee Reel', 3065, 2, 5, 32, 9999, 1, 167, 0, '');
INSERT INTO 'recording' VALUES (1041, NULL, '2022-08-21 22:13:11.122003+00', 'Hamilton House', 3065, 2, 5, 32, 9999, 1, 163, 0, '');
INSERT INTO 'recording' VALUES (1028, NULL, '2022-12-20 11:03:19.861934+00', 'Moray Rant, The', 2570, 3, 4, 48, 9999, NULL, 365, 0, '');
INSERT INTO 'recording' VALUES (1035, NULL, '2022-08-21 22:17:23.124421+00', 'Scottish Reform', 3065, 2, 5, 32, 9999, 1, 166, 0, '');
INSERT INTO 'recording' VALUES (1036, NULL, '2022-08-21 22:18:06.621336+00', 'Isle of Skye', 3065, 1, 5, 32, 9999, 1, 172, 0, '');
INSERT INTO 'recording' VALUES (1038, NULL, '2022-08-21 22:18:50.543421+00', 'Pride of Erin, The', 3065, 5, 5, 32, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (1010, NULL, '2023-02-14 13:06:24.635182+00', 'Saint Andrew''s Nicht', 3055, 2, 4, 48, 9999, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (1059, NULL, '2012-01-20 12:55:07.454183+00', 'Up Helly-Aa Two-step', 3008, 99, 0, 0, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (1060, NULL, '2012-01-20 12:55:07.45897+00', 'Balindean Castle', 3008, 98, 0, 0, 9999, NULL, 102, 0, '');
INSERT INTO 'recording' VALUES (1061, NULL, '2012-01-20 12:55:07.46383+00', 'Mississippi Dip, The', 3008, 11, 14, 16, 9999, NULL, 234, 0, '');
INSERT INTO 'recording' VALUES (1062, NULL, '2012-01-20 12:55:07.468611+00', 'Cape Breton Island', 3008, 1, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (1063, NULL, '2012-01-20 12:55:07.473405+00', 'Angus Reel, The', 3037, 1, 0, 128, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (1065, NULL, '2012-01-20 12:55:07.482976+00', '1314', 3037, 4, 0, 128, 2, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (1066, NULL, '2012-01-20 12:55:07.487761+00', 'Saint Bernard''s Waltz', 3037, 5, 8, 16, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (1067, NULL, '2012-01-20 12:55:07.492548+00', 'Shetland Jigs', 3025, 2, 6, 32, 9999, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (1068, NULL, '2012-01-20 12:55:07.497329+00', 'Jack o'' Tar Two-Step', 3037, 50, 4, 32, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (1069, NULL, '2012-01-20 12:55:07.502123+00', 'Nan, Anne and Leslie', 3025, 4, 0, 0, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (1070, NULL, '2012-01-20 12:55:07.506932+00', 'Selection of Reels', 3025, 1, 6, 32, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (1071, NULL, '2012-01-20 12:55:07.511725+00', 'Rona''s Voe Waltz', 3037, 5, 0, 0, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (1072, NULL, '2012-01-20 12:55:07.516509+00', 'Rock and the Wee Pickle Tow, The', 3037, 2, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (1073, NULL, '2012-01-20 12:55:07.521304+00', 'Leith Country Dance, The', 3037, 2, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (1074, NULL, '2012-01-20 12:55:07.526134+00', 'Gaelic Waltz Medley', 3025, 5, 0, 0, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (3875, NULL, '2012-01-20 12:55:23.289601+00', 'Flowers of Edinburgh', 2069, 1, 8, 32, 9999, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (3876, NULL, '2012-01-20 12:55:23.296013+00', 'Strip the Willow', 2069, 2, 8, 32, 9999, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (3877, NULL, '2012-01-20 12:55:23.302461+00', 'Reels', 2069, 1, 8, 32, 9999, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (3878, NULL, '2012-01-20 12:55:23.30874+00', 'Scottish Waltz', 2069, 5, 0, 0, 9999, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (3879, NULL, '2012-01-20 12:55:23.315214+00', 'Hullachan Jig', 2069, 2, 8, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (3880, NULL, '2012-01-20 12:55:23.321579+00', 'Gay Gordons', 2069, 11, 10, 16, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (3882, NULL, '2012-01-20 12:55:23.33429+00', 'Set of Jigs', 2553, 2, 6, 32, 9999, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (3883, NULL, '2012-01-20 12:55:23.340695+00', 'Speed the Plough', 2090, 1, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (3884, NULL, '2012-01-20 12:55:23.346993+00', 'Bratach Bana', 2553, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (3885, NULL, '2012-01-20 12:55:23.353416+00', 'MacDonald of the Isles', 2553, 3, 3, 32, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (3886, NULL, '2012-01-20 12:55:23.359747+00', 'Buchan Eightsome Reel, The', 2553, 1, 10, 40, 9999, NULL, 434, 0, '');
INSERT INTO 'recording' VALUES (3887, NULL, '2012-01-20 12:55:23.366056+00', 'Shepherd''s Crook, The', 2553, 3, 0, 72, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (3888, NULL, '2012-01-20 12:55:23.372553+00', 'Keltic Cracker', 2336, 1, 6, 32, 9999, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (3889, NULL, '2012-01-20 12:55:23.378851+00', 'Little Cascade, The', 3059, 98, 0, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (3890, NULL, '2012-01-20 12:55:23.385118+00', 'March, Strathspey and Reel', 2333, 98, 0, 0, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (3891, NULL, '2012-01-20 12:55:23.391623+00', 'Gaelic Waltzes', 2171, 5, 0, 0, 9999, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (3892, NULL, '2012-01-20 12:55:23.397896+00', 'Lord MacLay''s Reel', 3029, 1, 4, 40, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (3893, NULL, '2012-01-20 12:55:23.404213+00', 'Eva Three Step', 2337, 11, 0, 16, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (3894, NULL, '2012-01-20 12:55:23.410647+00', 'Piping Hot', 2336, 11, 0, 0, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (9052, '2013-01-01 19:13:27.139928+00', '2013-01-02 12:07:13.727258+00', 'Sailor''s Hornpipe 4 Junior', 10687, 7, 4, 16, 9999, NULL, 91, 0, '');
INSERT INTO 'recording' VALUES (9100, '2013-01-04 12:37:25.392475+00', '2013-01-04 12:37:25.392486+00', 'Shiftin'' Bobbins', 3067, 1, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (9144, '2013-01-06 14:28:35.484859+00', '2013-01-06 14:28:35.484869+00', 'Lamb Skinnet', 2301, 2, 8, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (9160, '2013-01-06 17:44:08.683317+00', '2013-01-06 17:44:08.683327+00', 'Strathspeys 3x32', 2029, 3, 3, 32, 9999, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (9203, '2013-01-16 13:32:05.909203+00', '2013-01-16 13:32:05.909214+00', 'Petronella', 10709, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (9245, '2013-02-02 16:45:53.531061+00', '2013-02-02 16:45:53.531072+00', 'Dusty Miller', 10146, 7, 6, 8, 9999, NULL, 87, 0, '');
INSERT INTO 'recording' VALUES (9271, '2013-02-05 14:58:07.97787+00', '2013-02-05 14:58:07.977879+00', 'Flora MacDonald 4 steps', 10741, 7, 4, 16, 9999, NULL, 98, 0, '');
INSERT INTO 'recording' VALUES (9289, '2013-02-06 11:35:06.213025+00', '2013-02-06 11:35:06.213035+00', 'Kiss for Nothing, A', 10748, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (9299, '2013-02-06 14:39:30.409188+00', '2013-02-06 14:39:30.409199+00', 'Jigs', 10748, 2, 4, 32, 9999, NULL, 117, 0, '');
INSERT INTO 'recording' VALUES (1075, NULL, '2012-01-20 12:55:07.53092+00', 'Polka', 3037, 13, 0, 0, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (1076, NULL, '2012-01-20 12:55:07.535784+00', 'Balmoral Strathspey', 3037, 3, 4, 32, 9999, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (1077, NULL, '2012-01-20 12:55:07.540578+00', 'Angus Macleod', 3037, 1, 2, 64, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (1078, NULL, '2012-01-20 12:55:07.545394+00', 'Grand March', 3038, 11, 0, 0, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (1079, NULL, '2012-01-20 12:55:07.550189+00', 'Circassian Circle', 3038, 1, 5, 32, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (1080, NULL, '2012-01-20 12:55:07.554989+00', 'Galloping Carousel', 3038, 2, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (1081, NULL, '2012-01-20 12:55:07.559779+00', 'Foursome and Half Reel of Tulloch', 3038, 4, 0, 192, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (1082, NULL, '2012-01-20 12:55:07.564572+00', 'Clutha', 3038, 1, 4, 48, 9999, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (1083, NULL, '2012-01-20 12:55:07.569357+00', 'Gothenburg''s Welcome', 3038, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (1084, NULL, '2012-01-20 12:55:07.574394+00', 'Partans in his Creel', 3038, 3, 4, 32, 9999, NULL, 243, 0, '');
INSERT INTO 'recording' VALUES (1085, NULL, '2012-01-20 12:55:07.579196+00', 'West''s Hornpipe', 3038, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (1086, NULL, '2012-01-20 12:55:07.584012+00', 'Campbeltown Loch', 3038, 2, 4, 48, 9999, NULL, 215, 1, '');
INSERT INTO 'recording' VALUES (1087, NULL, '2012-01-20 12:55:07.588864+00', 'Balmoral Strathspey', 3038, 3, 4, 32, 9999, NULL, 248, 0, '');
INSERT INTO 'recording' VALUES (1088, NULL, '2012-01-20 12:55:07.593662+00', 'Scotland''s Gardens', 3038, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (1089, NULL, '2012-01-20 12:55:07.598452+00', 'Swilcan, The', 3038, 2, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (1091, NULL, '2012-01-20 12:55:07.608032+00', 'Wicked Willy', 3038, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (1092, NULL, '2012-01-20 12:55:07.612819+00', 'Waltz Country Dance', 3038, 5, 6, 40, 9999, NULL, 253, 0, '');
INSERT INTO 'recording' VALUES (1093, NULL, '2012-01-20 12:55:07.617604+00', 'Baldovan Reel', 3038, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1094, NULL, '2012-01-20 12:55:07.622535+00', 'Moray Reel, The', 3038, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1095, NULL, '2012-01-20 12:55:07.627322+00', 'Silver Tassie, The', 3038, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1097, NULL, '2012-01-20 12:55:07.636896+00', 'Diamond Jubilee, The', 3038, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1098, NULL, '2012-01-20 12:55:07.64171+00', 'Irish Rover, The', 3038, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1099, NULL, '2012-01-20 12:55:07.646511+00', 'Blooms o'' Bon Accord, The', 3038, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1100, NULL, '2012-01-20 12:55:07.651301+00', 'Jimmy''s Fancy', 3038, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1101, NULL, '2012-01-20 12:55:07.656094+00', 'Welcome to Dufftown', 3038, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1102, NULL, '2012-01-20 12:55:07.661125+00', 'Black Mountain Reel, The', 3038, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1103, NULL, '2012-01-20 12:55:07.665949+00', 'Haughs o'' Cromdale', 3038, 3, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1104, NULL, '2012-01-20 12:55:07.670744+00', 'Rory O'' More', 3038, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1105, NULL, '2012-01-20 12:55:07.676209+00', 'Roxburgh Castle', 3001, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1106, NULL, '2012-01-20 12:55:07.681016+00', 'Saint Bernard''s Waltz', 3001, 5, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1107, NULL, '2012-01-20 12:55:07.685829+00', 'Royal Scots Polka', 3001, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1108, NULL, '2012-01-20 12:55:07.690645+00', 'Boston Two-Step', 3001, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1109, NULL, '2012-01-20 12:55:07.695429+00', 'Ian Mearns', 3001, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1110, NULL, '2012-01-20 12:55:07.700215+00', 'Gay Gordons', 3001, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1111, NULL, '2012-01-20 12:55:07.705672+00', 'Lamb Skinnet', 3001, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1112, NULL, '2012-01-20 12:55:07.711165+00', 'Eight Men of Moidart, The', 3001, 1, 5, 16, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1090, NULL, '2022-12-20 11:04:05.976374+00', 'Willbergs of Rechberg, The', 3038, 3, 4, 40, 9999, NULL, 304, 0, '');
INSERT INTO 'recording' VALUES (1113, NULL, '2012-01-20 12:55:07.716651+00', 'Trip to Bavaria, A', 3001, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1114, NULL, '2012-01-20 12:55:07.722134+00', 'Drumelzier', 3001, 3, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1115, NULL, '2012-01-20 12:55:07.727603+00', 'Delaney''s Delight', 3001, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (3895, NULL, '2012-01-20 12:55:23.416876+00', 'Gaelic Waltz', 3059, 5, 0, 0, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (3896, NULL, '2012-01-20 12:55:23.423147+00', 'Shamrock Schottische', 2333, 50, 0, 0, 9999, NULL, 254, 0, '');
INSERT INTO 'recording' VALUES (3897, NULL, '2012-01-20 12:55:23.429618+00', 'Dumbarton''s Drums', 2171, 1, 4, 32, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (3898, NULL, '2012-01-20 12:55:23.436387+00', 'Highland Barn Dance', 3029, 50, 0, 0, 9999, NULL, 232, 0, '');
INSERT INTO 'recording' VALUES (3899, NULL, '2012-01-20 12:55:23.442931+00', 'Trip to Bavaria, A', 2337, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (3900, NULL, '2012-01-20 12:55:23.449482+00', 'Teviot Brig', 2173, 2, 6, 32, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (3901, NULL, '2012-01-20 12:55:23.456015+00', 'Miss Jean Milligan', 2173, 1, 6, 32, 9999, NULL, 213, 1, '');
INSERT INTO 'recording' VALUES (3902, NULL, '2012-01-20 12:55:23.462546+00', 'Scottish Waltz Medley', 2173, 5, 0, 0, 9999, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (3903, NULL, '2012-01-20 12:55:23.469137+00', 'Fiddle Solo', 2173, 98, 0, 0, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (3904, NULL, '2012-01-20 12:55:23.475731+00', 'Border Marches', 2173, 11, 0, 0, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (3905, NULL, '2012-01-20 12:55:23.482012+00', 'Angus Two-Step', 2173, 2, 0, 0, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (3906, NULL, '2012-01-20 12:55:23.48841+00', 'Accordion Solo', 2173, 98, 0, 0, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (3907, NULL, '2012-01-20 12:55:23.494836+00', 'Retreat and March', 2173, 50, 0, 0, 9999, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (3908, NULL, '2012-01-20 12:55:23.501135+00', 'Black Dance', 2173, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (3909, NULL, '2012-01-20 12:55:23.507436+00', 'Retreat Airs', 2090, 98, 0, 0, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (3910, NULL, '2012-01-20 12:55:23.51384+00', 'Strip the Willow', 2090, 2, 0, 32, 9999, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (3911, NULL, '2012-01-20 12:55:23.520093+00', 'Waltz', 2090, 5, 0, 0, 9999, NULL, 127, 0, '');
INSERT INTO 'recording' VALUES (3912, NULL, '2012-01-20 12:55:23.526376+00', 'Mairi''s Wedding', 2090, 1, 8, 40, 9999, NULL, 327, 0, '');
INSERT INTO 'recording' VALUES (3913, NULL, '2012-01-20 12:55:23.532691+00', 'Gay Gordons', 2090, 11, 0, 16, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (3914, NULL, '2012-01-20 12:55:23.539055+00', 'Reel of the 51st Division, The', 2090, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (9053, '2013-01-01 19:14:31.2915+00', '2013-01-02 12:07:24.477111+00', 'Sailor''s Hornpipe 5 Medium', 10687, 7, 5, 16, 9999, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (9101, '2013-01-04 12:38:55.205765+00', '2013-01-04 12:38:55.205776+00', 'Shiftin'' Bobbins Encore', 3067, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (9145, '2013-01-06 14:34:05.888197+00', '2013-01-06 14:34:05.888208+00', 'Waltz Country Dance', 3010, 5, 4, 40, 9999, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (9161, '2013-01-06 17:48:08.595727+00', '2013-01-06 17:48:08.595737+00', 'Strathspeys 5x32', 2029, 3, 5, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (9204, '2013-01-16 13:37:51.193669+00', '2013-01-16 13:37:51.193681+00', 'Just the Girls', 10709, 98, 0, 0, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (9234, '2013-02-02 15:08:52.824391+00', '2013-02-02 15:08:52.824401+00', 'Polka', 10146, 13, 6, 16, 9999, NULL, 107, 0, '');
INSERT INTO 'recording' VALUES (9272, '2013-02-05 15:01:07.644276+00', '2013-02-05 15:01:07.644286+00', 'Flora MacDonald 4 steps', 10742, 7, 4, 16, 9999, NULL, 102, 0, '');
INSERT INTO 'recording' VALUES (10172, '2018-03-30 09:12:07.600743+00', '2018-03-30 09:13:28.277695+00', 'Mrs Jamieson''s Favourite', 11613, 5, 0, 0, NULL, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (9304, '2013-02-22 14:24:09.247522+00', '2013-02-22 15:44:17.687994+00', 'Edinburgh Mixture', 10209, 11, 5, 32, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (1116, NULL, '2012-01-20 12:55:07.733091+00', 'Eva Three Step', 3001, 11, 4, 16, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1117, NULL, '2012-01-20 12:55:07.738015+00', 'Scottish Waltz', 3001, 5, 9, 16, 9999, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (1118, NULL, '2012-01-20 12:55:07.74283+00', 'Britannia Two Step', 3001, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1119, NULL, '2012-01-20 12:55:07.747657+00', 'Pibroch Mackenzie''s Farewell', 3001, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1120, NULL, '2012-01-20 12:55:07.753131+00', 'Duke of Atholl''s Reel, The', 3001, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1121, NULL, '2012-01-20 12:55:07.758625+00', 'Island Fling, The', 3067, 2, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (1122, NULL, '2012-01-20 12:55:07.764096+00', 'Dalkeith''s Strathspey', 3067, 3, 8, 32, 9999, 5, 490, 0, '');
INSERT INTO 'recording' VALUES (1123, NULL, '2012-01-20 12:55:07.7696+00', 'Happy Meeting, The', 3067, 2, 8, 32, 9999, 1, 265, 0, '');
INSERT INTO 'recording' VALUES (1124, NULL, '2012-01-20 12:55:07.77546+00', 'Birks of Abergeldie, The', 3067, 1, 8, 48, 9999, 4, 406, 0, '');
INSERT INTO 'recording' VALUES (1125, NULL, '2012-01-20 12:55:07.781025+00', 'Haste to the Wedding', 3067, 2, 8, 32, 9999, 1, 265, 0, '');
INSERT INTO 'recording' VALUES (1126, NULL, '2012-01-20 12:55:07.786517+00', 'Mary Hamilton', 3067, 3, 4, 32, 9999, 5, 256, 0, '');
INSERT INTO 'recording' VALUES (1127, NULL, '2012-01-20 12:55:07.791997+00', 'Baldovan Reel, The', 3067, 1, 4, 32, 9999, 1, 140, 0, '');
INSERT INTO 'recording' VALUES (1128, NULL, '2012-01-20 12:55:07.797474+00', 'Northern Meeting, The', 3067, 3, 8, 32, 9999, 5, 495, 0, '');
INSERT INTO 'recording' VALUES (1129, NULL, '2012-01-20 12:55:07.802951+00', 'Irish Rover, The', 3067, 1, 8, 32, 9999, 3, 270, 0, '');
INSERT INTO 'recording' VALUES (1131, NULL, '2012-01-20 12:55:07.8139+00', 'Sir James Baird''s Strathspey', 3067, 3, 8, 32, 9999, 5, 496, 0, '');
INSERT INTO 'recording' VALUES (1133, NULL, '2012-01-20 12:55:07.824928+00', 'Bothkennar', 3067, 3, 4, 32, 9999, 1, 250, 0, '');
INSERT INTO 'recording' VALUES (1134, NULL, '2012-01-20 12:55:07.830473+00', 'Sutters of Selkirk, The', 3067, 1, 8, 32, 9999, 5, 275, 0, '');
INSERT INTO 'recording' VALUES (1135, NULL, '2012-01-20 12:55:07.835989+00', 'Village Reel, The', 3067, 3, 8, 32, 9999, 5, 500, 0, '');
INSERT INTO 'recording' VALUES (1136, NULL, '2012-01-20 12:55:07.841534+00', 'Hunting Horn, The', 3067, 2, 8, 32, 9999, 1, 267, 0, '');
INSERT INTO 'recording' VALUES (1137, NULL, '2012-01-20 12:55:07.847017+00', 'Twa Meenit Reel, The', 3067, 1, 4, 32, 9999, 7, 138, 0, '');
INSERT INTO 'recording' VALUES (1138, NULL, '2012-01-20 12:55:07.852495+00', 'Tarry a While', 3067, 2, 8, 32, 9999, 1, 267, 0, '');
INSERT INTO 'recording' VALUES (1139, NULL, '2012-01-20 12:55:07.857998+00', 'Duchess of Atholl''s Slipper, The', 3067, 3, 8, 32, 9999, 5, 497, 0, '');
INSERT INTO 'recording' VALUES (1140, NULL, '2012-01-20 12:55:07.863488+00', 'Falconer Hall', 3067, 2, 4, 48, 9999, 4, 212, 0, '');
INSERT INTO 'recording' VALUES (1141, NULL, '2012-01-20 12:55:07.868307+00', 'Glasgow Country Dance', 3067, 4, 8, 32, 1, NULL, 393, 0, '');
INSERT INTO 'recording' VALUES (1142, NULL, '2012-01-20 12:55:07.874259+00', 'There''s nae Luck Aboot the Hoose', 3067, 3, 8, 32, 9999, 5, 492, 0, '');
INSERT INTO 'recording' VALUES (1143, NULL, '2012-01-20 12:55:07.879816+00', 'Dumbarton''s Drums', 3067, 1, 8, 32, 9999, 1, 269, 0, '');
INSERT INTO 'recording' VALUES (1144, NULL, '2012-01-20 12:55:07.885357+00', 'Scots Bonnet, The', 3067, 2, 8, 32, 9999, 1, 267, 0, '');
INSERT INTO 'recording' VALUES (1146, NULL, '2012-01-20 12:55:07.895678+00', 'Dashing White Sergeant, The', 3068, 1, 9, 32, 9999, NULL, 356, 0, '');
INSERT INTO 'recording' VALUES (1147, NULL, '2012-01-20 12:55:07.900473+00', 'Eightsome Reel, The', 3068, 1, 0, 464, 9999, NULL, 465, 0, '');
INSERT INTO 'recording' VALUES (1148, NULL, '2012-01-20 12:55:07.905278+00', 'Hamilton House', 3068, 2, 10, 32, 9999, NULL, 320, 0, '');
INSERT INTO 'recording' VALUES (1149, NULL, '2012-01-20 12:55:07.910083+00', 'Duke of Perth', 3068, 1, 10, 32, 9999, NULL, 323, 0, '');
INSERT INTO 'recording' VALUES (1150, NULL, '2012-01-20 12:55:07.914876+00', 'Duke of Perth', 3068, 1, 10, 32, 9999, NULL, 318, 0, '');
INSERT INTO 'recording' VALUES (1151, NULL, '2012-01-20 12:55:07.919658+00', 'Duke and Duchess of Edinburgh, The', 3068, 1, 10, 40, 9999, NULL, 409, 0, '');
INSERT INTO 'recording' VALUES (1152, NULL, '2012-01-20 12:55:07.924491+00', 'Duke and Duchess of Edinburgh, The', 3068, 1, 12, 40, 9999, NULL, 483, 0, '');
INSERT INTO 'recording' VALUES (1153, NULL, '2012-01-20 12:55:07.929306+00', 'Inverness Country Dance', 3068, 1, 10, 32, 9999, NULL, 318, 0, '');
INSERT INTO 'recording' VALUES (1154, NULL, '2012-01-20 12:55:07.934132+00', 'Inverness Country Dance', 3068, 1, 10, 32, 9999, NULL, 313, 0, '');
INSERT INTO 'recording' VALUES (3916, NULL, '2012-01-20 12:55:23.551667+00', 'Jubilee Jig, The', 2339, 2, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (3917, NULL, '2012-01-20 12:55:23.557928+00', 'Whiteshell Park', 2339, 3, 8, 32, 9999, NULL, 494, 0, '');
INSERT INTO 'recording' VALUES (3918, NULL, '2012-01-20 12:55:23.5642+00', 'Lady Dumfries', 2339, 1, 8, 32, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (3919, NULL, '2012-01-20 12:55:23.570565+00', 'Waltz', 2339, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3920, NULL, '2012-01-20 12:55:23.576812+00', 'Golden Boy, The', 2339, 2, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (3921, NULL, '2012-01-20 12:55:23.583112+00', 'Gramachie', 2339, 3, 8, 32, 9999, NULL, 532, 0, '');
INSERT INTO 'recording' VALUES (3922, NULL, '2012-01-20 12:55:23.589421+00', 'Mairi''s Wedding', 2339, 1, 8, 40, 9999, NULL, 348, 0, '');
INSERT INTO 'recording' VALUES (3923, NULL, '2012-01-20 12:55:23.595684+00', 'Gay Gordons', 2339, 11, 8, 16, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (3924, NULL, '2012-01-20 12:55:23.601952+00', 'Kiss under the Stairs', 2339, 2, 8, 32, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (3926, NULL, '2012-01-20 12:55:23.614493+00', 'Reel of the 51st Division, The', 2339, 1, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (3927, NULL, '2012-01-20 12:55:23.620845+00', 'Foula Reel, The', 2344, 1, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (3928, NULL, '2012-01-20 12:55:23.627337+00', 'Strathspey', 2344, 3, 4, 40, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (3929, NULL, '2012-01-20 12:55:23.633642+00', 'Round Reel of Eight', 2344, 1, 0, 88, 9999, NULL, 96, 0, '');
INSERT INTO 'recording' VALUES (3930, NULL, '2012-01-20 12:55:23.639906+00', 'Scottish Waltz', 2344, 5, 0, 0, 9999, NULL, 236, 0, '');
INSERT INTO 'recording' VALUES (3931, NULL, '2012-01-20 12:55:23.646178+00', 'Postie''s Jig', 2344, 2, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (3932, NULL, '2012-01-20 12:55:23.65244+00', 'Grand March', 3056, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3933, NULL, '2012-01-20 12:55:23.658742+00', 'Scottish Waltz', 3056, 5, 0, 0, 9999, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (3934, NULL, '2012-01-20 12:55:23.664967+00', 'Gay Gordons', 3056, 11, 0, 16, 9999, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (3935, NULL, '2012-01-20 12:55:23.671247+00', 'Old Time Waltzes', 2328, 5, 0, 0, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (1132, NULL, '2012-11-02 22:38:39.968946+00', 'Wedderburn''s / Ha! Ha! The Wooin'' O'' It', 3067, 1, 8, 32, 9999, 5, 267, 0, '');
INSERT INTO 'recording' VALUES (9054, '2013-01-01 19:15:56.596711+00', '2013-01-02 12:07:33.794155+00', 'Sailor''s Hornpipe 6 Adult', 10687, 7, 6, 16, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (9146, '2013-01-06 14:36:42.104987+00', '2013-01-06 14:36:42.104998+00', 'Pipe Marches', 3018, 11, 0, 32, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (9162, '2013-01-06 17:52:26.238614+00', '2013-01-06 17:52:26.238625+00', 'Strathspeys 6x32', 2029, 3, 6, 32, 9999, NULL, 363, 0, '');
INSERT INTO 'recording' VALUES (9205, '2013-01-16 13:41:31.820866+00', '2013-01-16 14:26:59.015912+00', 'Highland Barn Dance', 10104, 11, 8, 16, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (9235, '2013-02-02 15:16:25.300547+00', '2013-02-02 15:16:25.300557+00', 'Gay Gordons', 10146, 11, 8, 16, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (9273, '2013-02-05 15:05:42.221445+00', '2013-02-05 15:05:42.221456+00', 'Blue Bonnets 4 steps', 10741, 7, 4, 16, 9999, NULL, 98, 0, '');
INSERT INTO 'recording' VALUES (9301, '2013-02-06 14:46:09.601125+00', '2013-02-06 14:46:09.601135+00', 'Stirrat''s Kate Dalrymple', 10748, 98, 5, 16, 9999, NULL, 77, 0, '');
INSERT INTO 'recording' VALUES (1155, NULL, '2012-01-20 12:55:07.938936+00', 'Reel of the 51st Division, The', 3068, 1, 10, 32, 9999, NULL, 326, 0, '');
INSERT INTO 'recording' VALUES (1156, NULL, '2012-01-20 12:55:07.943823+00', 'Reel of the 51st Division, The', 3068, 1, 10, 32, 9999, NULL, 326, 0, '');
INSERT INTO 'recording' VALUES (1157, NULL, '2012-01-20 12:55:07.94865+00', 'Scottish Reform', 3068, 2, 10, 32, 9999, NULL, 326, 0, '');
INSERT INTO 'recording' VALUES (1158, NULL, '2012-01-20 12:55:07.953448+00', 'Bonnie Anne', 2414, 2, 0, 96, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1130, NULL, '2016-05-24 22:40:08.341534+00', 'Maid of the Mill, The', 3067, 2, 8, 40, 9999, 6, 336, 0, '');
INSERT INTO 'recording' VALUES (1159, NULL, '2012-01-20 12:55:07.958234+00', 'Wild Geese, The', 2133, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1160, NULL, '2012-01-20 12:55:07.963018+00', 'White Heather Jig, The', 2414, 2, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1161, NULL, '2012-01-20 12:55:07.967817+00', 'Round Reel of Eight', 2133, 1, 0, 88, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1162, NULL, '2012-01-20 12:55:07.972816+00', 'Bonnie Lass O'' Bon Accord, The', 2414, 3, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1163, NULL, '2012-01-20 12:55:07.977645+00', 'Mairi''s Wedding', 2414, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1164, NULL, '2012-01-20 12:55:07.98248+00', 'None so Pretty', 2414, 1, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1165, NULL, '2012-01-20 12:55:07.987267+00', 'Nottingham Lace', 2414, 1, 0, 96, 9999, NULL, 0, 0, '2nd tune arranged AABBAB - not really suitable for the dance.');
INSERT INTO 'recording' VALUES (1166, NULL, '2012-01-20 12:55:07.992077+00', 'Saint Bernard''s Waltz', 3069, 5, 0, 16, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (1167, NULL, '2012-01-20 12:55:07.996866+00', 'Shiftin'' Bobbins', 2414, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1168, NULL, '2012-01-20 12:55:08.001678+00', 'Silver Tassie, The', 2133, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1169, NULL, '2012-01-20 12:55:08.006478+00', 'Hollin Buss, The', 3018, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (1170, NULL, '2012-01-20 12:55:08.011275+00', 'Air', 3018, 98, 0, 0, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (1171, NULL, '2012-01-20 12:55:08.016081+00', 'Bluebell Polka, The', 3018, 13, 0, 16, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (1172, NULL, '2012-01-20 12:55:08.021218+00', 'Veleta', 3018, 5, 0, 16, 9999, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (1173, NULL, '2012-01-20 12:55:08.026084+00', 'Boston Two Step', 3018, 50, 0, 16, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (1174, NULL, '2012-01-20 12:55:08.030932+00', 'Highland Medley, A', 3018, 98, 0, 0, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (1175, NULL, '2012-01-20 12:55:08.035783+00', 'Circassian Circle', 3018, 1, 5, 32, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (1176, NULL, '2012-01-20 12:55:08.040612+00', 'Eightsome Reel, The', 3018, 1, 1, 464, 9999, NULL, 487, 0, '');
INSERT INTO 'recording' VALUES (1177, NULL, '2012-01-20 12:55:08.045405+00', 'Dundee Eight Hundred', 3018, 98, 0, 64, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (1178, NULL, '2012-01-20 12:55:08.050205+00', 'Maxwell''s Rant', 3037, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1179, NULL, '2012-01-20 12:55:08.054994+00', 'Miss Alice Simpson''s Silver Jubilee', 3008, 2, 3, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1180, NULL, '2012-01-20 12:55:08.059783+00', 'Dunoon Barn Dance', 3042, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1181, NULL, '2012-01-20 12:55:08.064628+00', 'Hamilton House', 3037, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1182, NULL, '2012-01-20 12:55:08.069422+00', 'MacPhail Reels', 3008, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1183, NULL, '2012-01-20 12:55:08.07421+00', 'Polka', 3042, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1184, NULL, '2012-01-20 12:55:08.079013+00', 'Duke of Perth', 3037, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1185, NULL, '2012-01-20 12:55:08.083816+00', 'Scottish Waltz', 3008, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1186, NULL, '2012-01-20 12:55:08.08865+00', 'Scottish Reform', 3042, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1187, NULL, '2012-01-20 12:55:08.093444+00', 'Marching with Robin', 3037, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1188, NULL, '2012-01-20 12:55:08.098637+00', 'Bagpipe Medley', 3008, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1189, NULL, '2012-01-20 12:55:08.103453+00', 'Highland Laddie', 3042, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1190, NULL, '2012-01-20 12:55:08.108254+00', 'Lea Rig, The', 3037, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1191, NULL, '2012-01-20 12:55:08.113042+00', 'Hesitation Waltz', 3008, 5, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3915, NULL, '2021-09-07 01:01:31.555289+00', 'Jessie Wiseman''s Reel', 3217, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (1192, NULL, '2012-01-20 12:55:08.117863+00', 'Isle of Skye, The', 3042, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1193, NULL, '2012-01-20 12:55:08.122663+00', 'Ian Powrie''s Farewell to Auchterarder', 3037, 2, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1194, NULL, '2012-01-20 12:55:08.127479+00', 'Set of Reels', 3008, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1195, NULL, '2012-01-20 12:55:08.132263+00', 'Gay Gordons', 3042, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1196, NULL, '2012-01-20 12:55:08.137082+00', 'Highland Laddie', 3037, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3936, NULL, '2012-01-20 12:55:23.67753+00', 'Irish Jigs', 2328, 2, 8, 32, 9999, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (3937, NULL, '2012-01-20 12:55:23.683856+00', 'Corrinne', 2328, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3938, NULL, '2012-01-20 12:55:23.690224+00', 'Irish Marches', 2328, 1, 6, 32, 9999, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (3939, NULL, '2012-01-20 12:55:23.696573+00', 'Singalong Collection', 2328, 98, 0, 0, 9999, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (3940, NULL, '2012-01-20 12:55:23.702852+00', 'International Medley', 2328, 98, 0, 0, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (3941, NULL, '2012-01-20 12:55:23.709113+00', 'Hornpipes', 2328, 1, 0, 0, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (3942, NULL, '2012-01-20 12:55:23.715391+00', 'Madame Bonaparte', 2328, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3943, NULL, '2012-01-20 12:55:23.721645+00', 'Galic Waltz', 2328, 5, 0, 0, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (3944, NULL, '2012-01-20 12:55:23.727898+00', 'Road to the Isles Medley', 2328, 98, 0, 0, 9999, NULL, 220, 0, '');
INSERT INTO 'recording' VALUES (3945, NULL, '2012-01-20 12:55:23.734174+00', 'Pipe Marches', 2328, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3946, NULL, '2012-01-20 12:55:23.740424+00', 'Highland Fling', 1515, 7, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3947, NULL, '2012-01-20 12:55:23.746821+00', 'Sword Dance', 1515, 7, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3948, NULL, '2012-01-20 12:55:23.753151+00', 'Seann Thruibhas', 1515, 7, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3949, NULL, '2012-01-20 12:55:23.75947+00', 'Argyll Broadswords', 1515, 7, 5, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3950, NULL, '2012-01-20 12:55:23.765737+00', 'Sailor''s Hornpipe', 1515, 7, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3951, NULL, '2012-01-20 12:55:23.772113+00', 'Irish JIg', 1515, 7, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3952, NULL, '2012-01-20 12:55:23.778537+00', 'Scottish Lilt', 1515, 7, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3953, NULL, '2012-01-20 12:55:23.785297+00', 'Miss Forbes', 1515, 7, 5, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3954, NULL, '2012-01-20 12:55:23.791704+00', 'Flora MacDonald', 1515, 7, 6, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3955, NULL, '2012-01-20 12:55:23.798647+00', 'Highland Laddie', 1515, 7, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3956, NULL, '2012-01-20 12:55:23.805028+00', 'Blue Bonnets', 1515, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9147, '2013-01-06 14:38:45.926393+00', '2013-01-06 14:38:45.926404+00', 'To the Games', 2328, 11, 0, 32, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (9163, '2013-01-06 17:58:33.447578+00', '2013-01-06 17:58:33.447589+00', 'Jigs 2x40', 2029, 2, 2, 40, 9999, NULL, 89, 0, '');
INSERT INTO 'recording' VALUES (9236, '2013-02-02 15:20:18.99142+00', '2013-02-02 15:20:18.99143+00', 'Scottish Lilt', 10146, 7, 6, 8, 9999, NULL, 88, 0, '');
INSERT INTO 'recording' VALUES (9274, '2013-02-05 15:07:35.660295+00', '2013-02-05 15:07:35.660305+00', 'Blue Bonnets 4 steps', 10742, 7, 4, 16, 9999, NULL, 102, 0, '');
INSERT INTO 'recording' VALUES (1197, NULL, '2012-01-20 12:55:08.141899+00', 'Blue Bonnets, The', 3008, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1198, NULL, '2012-01-20 12:55:08.147205+00', 'Set of Reels', 2441, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1199, NULL, '2012-01-20 12:55:08.152032+00', 'Waltz', 3037, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1200, NULL, '2012-01-20 12:55:08.156828+00', 'Dunoon Barn Dance', 3008, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1201, NULL, '2012-01-20 12:55:08.161735+00', 'Scottish Ramble', 3042, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1202, NULL, '2012-01-20 12:55:08.166571+00', 'Trip to Bavaria, A', 3037, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1203, NULL, '2012-01-20 12:55:08.171577+00', 'Eva Three Step', 3042, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1204, NULL, '2012-01-20 12:55:08.176412+00', 'Dundee Whaler, The', 3008, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1205, NULL, '2012-01-20 12:55:08.181244+00', 'Waltz Selection', 2441, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1206, NULL, '2012-01-20 12:55:08.18608+00', 'Two and Two', 3042, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1207, NULL, '2012-01-20 12:55:08.190889+00', 'Polka', 3008, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1208, NULL, '2012-01-20 12:55:08.195704+00', 'New Ashludie Rant, The', 3037, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1209, NULL, '2012-01-20 12:55:08.200506+00', 'Scottish Waltz Selection', 3042, 3, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1210, NULL, '2012-01-20 12:55:08.205308+00', 'Penny Whistle Barn Dance', 3009, 50, 0, 96, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (1211, NULL, '2012-01-20 12:55:08.210099+00', 'Fare Thee Well, Annabelle', 3009, 98, 0, 0, 9999, NULL, 119, 0, '');
INSERT INTO 'recording' VALUES (1212, NULL, '2012-01-20 12:55:08.214896+00', 'Cumberland Reel', 3010, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1213, NULL, '2012-01-20 12:55:08.219698+00', 'Eight Men of Moidart, The', 2180, 1, 4, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1214, NULL, '2012-01-20 12:55:08.224502+00', 'Fiddle Faddle', 3042, 3, 2, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1215, NULL, '2012-01-20 12:55:08.229299+00', 'Wild Rover', 3061, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1216, NULL, '2012-01-20 12:55:08.234182+00', 'Shira''s Jig', 2062, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1217, NULL, '2012-01-20 12:55:08.239636+00', 'Kelso Polka, The', 3037, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1218, NULL, '2012-01-20 12:55:08.245149+00', 'Lament for Will Starr', 2441, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1219, NULL, '2012-01-20 12:55:08.250799+00', 'Gay Gordons', 3061, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1220, NULL, '2012-01-20 12:55:08.255691+00', 'George Harrison''s Reel', 3010, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1221, NULL, '2012-01-20 12:55:08.260494+00', 'Set of Jigs', 2441, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1222, NULL, '2012-01-20 12:55:08.265711+00', 'Minuet', 3037, 50, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1224, NULL, '2012-01-20 12:55:08.275439+00', 'Earl of Errol''s Reel, The', 2180, 2, 0, 200, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1225, NULL, '2012-01-20 12:55:08.28024+00', 'Flowers of Edinburgh, The', 3061, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1226, NULL, '2012-01-20 12:55:08.285045+00', 'Hooper''s Jig', 3011, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (1227, NULL, '2012-01-20 12:55:08.289862+00', 'Reel of the 51st Division, The', 3011, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (1228, NULL, '2012-01-20 12:55:08.294742+00', 'Set of 6/8 Marches, A', 3011, 11, 0, 16, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (1229, NULL, '2012-01-20 12:55:08.299539+00', 'Set of Reels, A', 3011, 1, 8, 40, 9999, NULL, 345, 0, '');
INSERT INTO 'recording' VALUES (1230, NULL, '2012-01-20 12:55:08.304335+00', 'Scottish Waltz, A', 3011, 5, 0, 0, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (1231, NULL, '2012-01-20 12:55:08.30912+00', 'Set of Jigs, A', 3011, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (1233, NULL, '2012-01-20 12:55:08.318789+00', 'Major Ian Stewart', 3011, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (1234, NULL, '2012-01-20 12:55:08.323611+00', 'Set of Strathspeys, A', 3011, 3, 8, 32, 9999, NULL, 507, 0, '');
INSERT INTO 'recording' VALUES (1235, NULL, '2012-01-20 12:55:08.328419+00', 'Set of 4/4 Marches, A', 3011, 11, 0, 16, 9999, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (1236, NULL, '2012-01-20 12:55:08.333223+00', 'Good Night and Joy be wi'' Ye A''', 3011, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (1237, NULL, '2012-01-20 12:55:08.338722+00', 'Bob of Fettercairn, The', 3011, 1, 8, 24, 9999, 18, 210, 0, '');
INSERT INTO 'recording' VALUES (3957, NULL, '2012-01-20 12:55:23.811591+00', 'Strathspey and Reel of Tulloch', 1515, 4, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3958, NULL, '2012-01-20 12:55:23.818436+00', 'Eightsome Reel, The', 1515, 1, 0, 464, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3959, NULL, '2012-01-20 12:55:23.824838+00', 'Waltz Country Dance', 1515, 5, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3960, NULL, '2012-01-20 12:55:23.831587+00', 'Hamilton House', 1515, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3961, NULL, '2012-01-20 12:55:23.838106+00', 'Petronella', 1515, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3962, NULL, '2012-01-20 12:55:23.84471+00', 'Six-Twenty Two-Step', 1605, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3963, NULL, '2012-01-20 12:55:23.85139+00', 'Mason''s Apron, The', 1605, 1, 4, 32, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (3964, NULL, '2012-01-20 12:55:23.85812+00', 'Royal Scots Polka', 1605, 13, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3965, NULL, '2012-01-20 12:55:23.864783+00', 'Agnes Waltz, The', 1605, 5, 0, 192, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3966, NULL, '2012-01-20 12:55:23.872018+00', 'Bel Fiore', 1605, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1232, NULL, '2021-08-23 15:01:36.645691+00', 'Set of Reels, A', 3011, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (3967, NULL, '2012-01-20 12:55:23.878772+00', 'Highland Wedding, The', 1605, 2, 3, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3968, NULL, '2012-01-20 12:55:23.885444+00', 'Dashing White Sergeant, The', 1605, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3969, NULL, '2012-01-20 12:55:23.891958+00', 'Waltz', 1605, 5, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3970, NULL, '2012-01-20 12:55:23.898192+00', 'Liberton Pipe Band', 1605, 13, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3971, NULL, '2012-01-20 12:55:23.904462+00', 'Household Brigade', 1605, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3972, NULL, '2012-01-20 12:55:23.910706+00', 'Life in the Finland Woods', 1605, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3973, NULL, '2012-01-20 12:55:23.916942+00', 'Polka', 1605, 13, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3974, NULL, '2012-01-20 12:55:23.92325+00', 'Grand March', 3010, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3975, NULL, '2012-01-20 12:55:23.929461+00', 'Canadian Barn Dance', 3010, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3976, NULL, '2012-01-20 12:55:23.935716+00', 'Glasgow Highlanders, The', 3010, 3, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9148, '2013-01-06 14:43:14.115136+00', '2013-01-06 14:43:14.115146+00', 'Jigs', 2337, 2, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (9164, '2013-01-06 18:03:00.953093+00', '2013-01-06 18:03:00.953103+00', 'Jigs 3x40', 2029, 2, 3, 40, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (9237, '2013-02-02 15:26:27.704019+00', '2013-02-02 15:26:27.70403+00', 'Waltz', 10146, 5, 4, 32, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (9275, '2013-02-05 15:15:53.710877+00', '2013-02-05 15:15:53.710888+00', 'Scottish Lilt 4 steps', 10741, 7, 4, 8, 9999, NULL, 73, 0, '');
INSERT INTO 'recording' VALUES (1238, NULL, '2012-01-20 12:55:08.344236+00', 'Prince of Orange', 3011, 2, 8, 16, 9999, 23, 140, 0, '');
INSERT INTO 'recording' VALUES (1239, NULL, '2012-01-20 12:55:08.349896+00', 'Edinburgh Volunteers, The', 3011, 3, 8, 24, 9999, 18, 368, 0, '');
INSERT INTO 'recording' VALUES (1240, NULL, '2012-01-20 12:55:08.355383+00', 'Lord Macdonald''s Reel', 3011, 1, 8, 32, 9999, 5, 289, 0, '');
INSERT INTO 'recording' VALUES (1241, NULL, '2012-01-20 12:55:08.361321+00', 'Threesome Reel, The', 3011, 4, 0, 48, 11, 4, 146, 0, '');
INSERT INTO 'recording' VALUES (1242, NULL, '2012-01-20 12:55:08.366469+00', 'Sixteensome Reel, The', 3011, 1, 0, 464, 9999, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (1244, NULL, '2012-01-20 12:55:08.377677+00', 'Roxburgh Castle', 3011, 1, 8, 32, 9999, 1, 283, 0, '');
INSERT INTO 'recording' VALUES (1245, NULL, '2012-01-20 12:55:08.383213+00', 'Lennox Love to Blantyre', 3011, 3, 4, 32, 9999, 5, 258, 0, '');
INSERT INTO 'recording' VALUES (1246, NULL, '2012-01-20 12:55:08.388741+00', 'I''ll Mak'' Ye Fain to Follow Me', 3011, 2, 8, 32, 9999, 1, 278, 0, '');
INSERT INTO 'recording' VALUES (1247, NULL, '2012-01-20 12:55:08.394239+00', 'Mrs Macleod', 3011, 1, 8, 32, 9999, 5, 277, 0, '');
INSERT INTO 'recording' VALUES (1248, NULL, '2012-01-20 12:55:08.399061+00', 'Oxton Reel, The', 3011, 3, 0, 144, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (1249, NULL, '2012-01-20 12:55:08.404534+00', 'Lady Mary Menzies'' Reel', 3020, 1, 8, 32, 9999, 5, 285, 0, '');
INSERT INTO 'recording' VALUES (1251, NULL, '2012-01-20 12:55:08.415562+00', 'Menzies'' Rant, The', 3020, 1, 8, 32, 9999, 5, 288, 1, '');
INSERT INTO 'recording' VALUES (1252, NULL, '2012-01-20 12:55:08.421174+00', 'Tartan Plaidie', 3020, 3, 4, 32, 9999, 5, 240, 0, '');
INSERT INTO 'recording' VALUES (1254, NULL, '2012-01-20 12:55:08.432347+00', 'Ye''re Welcome, Charly Stuart', 3020, 1, 8, 32, 9999, 5, 292, 0, '');
INSERT INTO 'recording' VALUES (1243, NULL, '2022-12-22 13:50:05.466288+00', 'Rothesay Country Dance', 3011, 2, 4, 48, 9999, 25, 206, 0, '');
INSERT INTO 'recording' VALUES (1256, NULL, '2012-01-20 12:55:08.44338+00', 'Ye''ll Aye be Welcome Back Again', 3020, 3, 4, 32, 9999, 5, 250, 0, '');
INSERT INTO 'recording' VALUES (1257, NULL, '2012-01-20 12:55:08.448894+00', 'Come Ashore, Jolly Tar', 3020, 1, 4, 32, 9999, 1, 145, 1, '');
INSERT INTO 'recording' VALUES (1258, NULL, '2012-01-20 12:55:08.454388+00', 'Priest and his Books, The', 3020, 2, 8, 24, 9999, 18, 213, 0, '');
INSERT INTO 'recording' VALUES (1259, NULL, '2012-01-20 12:55:08.459907+00', 'Braes of Tullimet, The', 3020, 3, 8, 32, 9999, 5, 475, 0, '');
INSERT INTO 'recording' VALUES (1260, NULL, '2012-01-20 12:55:08.465409+00', 'Captain Macdonald''s Fancy', 3020, 1, 4, 32, 9999, 5, 147, 0, '');
INSERT INTO 'recording' VALUES (1261, NULL, '2012-01-20 12:55:08.470908+00', 'Lass o'' Livingston, The', 3009, 1, 8, 32, 9999, 1, 290, 0, '');
INSERT INTO 'recording' VALUES (1262, NULL, '2012-01-20 12:55:08.476381+00', 'Tulloch Gorm', 3009, 3, 4, 32, 9999, 5, 240, 0, '');
INSERT INTO 'recording' VALUES (1263, NULL, '2012-01-20 12:55:08.481866+00', 'River Cree, The', 3009, 2, 8, 32, 9999, 1, 286, 0, '');
INSERT INTO 'recording' VALUES (1264, NULL, '2012-01-20 12:55:08.48736+00', 'Lovers'' Knot, The', 3009, 3, 4, 40, 9999, 5, 295, 0, '');
INSERT INTO 'recording' VALUES (1265, NULL, '2012-01-20 12:55:08.492835+00', 'Blue Ribbon, The', 3009, 1, 4, 40, 9999, 6, 175, 0, '');
INSERT INTO 'recording' VALUES (1266, NULL, '2012-01-20 12:55:08.498338+00', 'Tibby Fowler o'' the Glen', 3009, 3, 4, 32, 9999, 5, 240, 0, '');
INSERT INTO 'recording' VALUES (1267, NULL, '2012-01-20 12:55:08.503828+00', 'Jessie''s Hornpipe', 3009, 1, 8, 32, 9999, 1, 280, 0, '');
INSERT INTO 'recording' VALUES (1269, NULL, '2012-01-20 12:55:08.514817+00', 'Calver Lodge', 3009, 1, 4, 24, 9999, 16, 115, 0, '');
INSERT INTO 'recording' VALUES (1270, NULL, '2012-01-20 12:55:08.520294+00', 'Off She Goes', 3009, 2, 4, 16, 9999, 23, 78, 0, '');
INSERT INTO 'recording' VALUES (1271, NULL, '2012-01-20 12:55:08.525805+00', 'Braes of Atholl', 3009, 3, 4, 40, 9999, 5, 295, 0, '');
INSERT INTO 'recording' VALUES (1272, NULL, '2012-01-20 12:55:08.531311+00', 'Lassie Wi'' the Yellow Coatie, The', 3009, 1, 8, 32, 9999, 5, 290, 0, '');
INSERT INTO 'recording' VALUES (1273, NULL, '2012-01-20 12:55:08.536791+00', 'Lady Jean Murray''s Rant', 3020, 3, 4, 32, 9999, 5, 252, 0, '');
INSERT INTO 'recording' VALUES (1274, NULL, '2012-01-20 12:55:08.542285+00', 'Crieff Fair', 3020, 1, 4, 24, 9999, 18, 111, 0, '');
INSERT INTO 'recording' VALUES (1275, NULL, '2012-01-20 12:55:08.54781+00', 'Infare, The', 3020, 3, 4, 16, 9999, 23, 127, 0, '');
INSERT INTO 'recording' VALUES (1276, NULL, '2012-01-20 12:55:08.553336+00', 'Scots Bonnet, The', 3020, 2, 8, 32, 9999, 1, 275, 0, '');
INSERT INTO 'recording' VALUES (3977, NULL, '2012-01-20 12:55:23.942001+00', 'Hesitation Waltz', 3010, 5, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3978, NULL, '2012-01-20 12:55:23.948239+00', 'Highland Schottische', 3010, 3, 0, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3979, NULL, '2012-01-20 12:55:23.954476+00', 'Flooers o'' Edinburgh', 3010, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3980, NULL, '2012-01-20 12:55:23.960701+00', 'Pride of Erin', 3010, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3981, NULL, '2012-01-20 12:55:23.966935+00', 'Strip the Willow', 3010, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3982, NULL, '2012-01-20 12:55:23.97318+00', 'Selection of Jigs', 1811, 2, 11, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3983, NULL, '2012-01-20 12:55:23.979415+00', 'Under the Double Eagle', 1811, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3984, NULL, '2012-01-20 12:55:23.985642+00', 'Irish Jigs', 1811, 2, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3985, NULL, '2012-01-20 12:55:23.991889+00', 'Scottish Waltz', 1811, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3986, NULL, '2012-01-20 12:55:23.998242+00', 'Martallette', 1811, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3987, NULL, '2012-01-20 12:55:24.004474+00', 'Danny Boy', 1811, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3988, NULL, '2012-01-20 12:55:24.010721+00', 'Selection of Reels', 1811, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3989, NULL, '2012-01-20 12:55:24.016974+00', 'Bonnie Lass o'' Bon Accord, The', 1811, 3, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3990, NULL, '2012-01-20 12:55:24.023222+00', 'Medley', 1811, 4, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3991, NULL, '2012-01-20 12:55:24.029452+00', 'Harry Lauder Medley', 1811, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3992, NULL, '2012-01-20 12:55:24.035686+00', 'Marino Polka', 1811, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3993, NULL, '2012-01-20 12:55:24.041939+00', 'Strathspey Selection', 1811, 3, 6, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3994, NULL, '2012-01-20 12:55:24.048171+00', 'Slow Air, March, Strathspey & Reel', 1811, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3995, NULL, '2012-01-20 12:55:24.054413+00', 'Russe, La', 3067, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (3996, NULL, '2012-01-20 12:55:24.060658+00', 'Naomi''s Jig', 3067, 2, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (9149, '2013-01-06 14:47:15.067302+00', '2013-01-06 14:47:15.06731+00', 'Waltz Country Dance', 3065, 5, 4, 40, 9999, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (9165, '2013-01-06 18:06:24.969434+00', '2013-01-06 18:06:24.969445+00', 'Jigs 5x40', 2029, 2, 5, 40, 9999, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (9208, '2013-01-16 13:53:52.699603+00', '2013-01-16 14:28:13.827375+00', 'Hornpipes', 10104, 6, 4, 32, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (9276, '2013-02-05 15:17:47.873261+00', '2013-02-05 15:17:47.873272+00', 'Scottish Lilt 4 steps', 10742, 7, 4, 8, 9999, NULL, 77, 0, '');
INSERT INTO 'recording' VALUES (9308, '2013-02-22 14:40:12.456416+00', '2013-02-27 12:39:34.921201+00', 'Shiftin'' Bobbins', 10209, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (1277, NULL, '2012-01-20 12:55:08.558842+00', 'Maggie Lauder', 3020, 3, 4, 32, 9999, 5, 248, 0, '');
INSERT INTO 'recording' VALUES (1278, NULL, '2012-01-20 12:55:08.564411+00', 'Isle of Skye, The', 3020, 1, 8, 32, 9999, 1, 286, 0, '');
INSERT INTO 'recording' VALUES (1279, NULL, '2012-01-20 12:55:08.570057+00', 'Lady''s Breist Knot, The', 3020, 3, 4, 16, 9999, 23, 125, 0, '');
INSERT INTO 'recording' VALUES (1280, NULL, '2012-01-20 12:55:08.575649+00', 'Shepherd''s Crook, The', 3020, 3, 4, 32, 9999, 5, 255, 0, '');
INSERT INTO 'recording' VALUES (1281, NULL, '2012-01-20 12:55:08.581577+00', 'General Stuart''s Reel', 3020, 1, 8, 32, 9999, 5, 302, 0, '');
INSERT INTO 'recording' VALUES (1282, NULL, '2012-01-20 12:55:08.587183+00', 'Knit the Pocky', 3038, 1, 8, 32, 9999, 5, 283, 0, '');
INSERT INTO 'recording' VALUES (1283, NULL, '2012-01-20 12:55:08.592903+00', 'Monymusk', 3038, 3, 4, 32, 9999, 5, 251, 0, '');
INSERT INTO 'recording' VALUES (1284, NULL, '2012-01-20 12:55:08.598454+00', 'Johnny McGill', 3038, 2, 8, 40, 9999, 6, 340, 0, '');
INSERT INTO 'recording' VALUES (1286, NULL, '2012-01-20 12:55:08.609458+00', 'Sleepy Maggie', 3038, 1, 8, 32, 9999, 5, 277, 0, '');
INSERT INTO 'recording' VALUES (1287, NULL, '2012-01-20 12:55:08.614968+00', 'Glasgow Flourish', 3038, 3, 4, 32, 9999, 5, 254, 0, '');
INSERT INTO 'recording' VALUES (1288, NULL, '2012-01-20 12:55:08.620473+00', 'Dainty Davie', 3038, 3, 4, 16, 9999, 23, 130, 0, '');
INSERT INTO 'recording' VALUES (1289, NULL, '2012-01-20 12:55:08.625985+00', 'Moudiewort, The', 3038, 2, 8, 32, 9999, 5, 280, 0, '');
INSERT INTO 'recording' VALUES (1290, NULL, '2012-01-20 12:55:08.631492+00', 'Long Chase, The', 3038, 1, 4, 64, 9999, 26, 278, 0, '');
INSERT INTO 'recording' VALUES (1291, NULL, '2012-01-20 12:55:08.637055+00', 'Invercauld''s Reel', 3038, 3, 4, 32, 9999, 5, 244, 0, '');
INSERT INTO 'recording' VALUES (1292, NULL, '2012-01-20 12:55:08.642604+00', 'Miss Murray of Ochtertyre', 3038, 1, 8, 16, 9999, 23, 142, 0, '');
INSERT INTO 'recording' VALUES (1293, NULL, '2012-01-20 12:55:08.648094+00', 'Grant''s Rant, The', 3023, 1, 8, 48, 9999, 4, 431, 0, '');
INSERT INTO 'recording' VALUES (1294, NULL, '2012-01-20 12:55:08.65359+00', 'Green Grow the Rashes', 3023, 3, 4, 32, 9999, 5, 253, 0, '');
INSERT INTO 'recording' VALUES (1295, NULL, '2012-01-20 12:55:08.659207+00', 'Jenny Dang the Weaver', 3023, 1, 4, 32, 9999, 5, 147, 0, '');
INSERT INTO 'recording' VALUES (1296, NULL, '2012-01-20 12:55:08.664847+00', 'Laird of Dumbiedyke''s Favourite, The', 3023, 1, 8, 40, 9999, 6, 354, 0, '');
INSERT INTO 'recording' VALUES (1297, NULL, '2012-01-20 12:55:08.67036+00', 'Fiddle Faddle', 3023, 3, 4, 32, 9999, 5, 252, 0, '');
INSERT INTO 'recording' VALUES (1298, NULL, '2012-01-20 12:55:08.675886+00', 'Yellow-Haired Laddie, The', 3023, 50, 4, 64, 9999, 26, 523, 0, '');
INSERT INTO 'recording' VALUES (1299, NULL, '2012-01-20 12:55:08.681377+00', 'Reel of Glamis, The', 3023, 3, 4, 32, 9999, 5, 250, 0, '');
INSERT INTO 'recording' VALUES (1300, NULL, '2012-01-20 12:55:08.686871+00', 'Sodger Laddie', 3023, 2, 4, 32, 9999, 1, 145, 0, '');
INSERT INTO 'recording' VALUES (1301, NULL, '2012-01-20 12:55:08.692381+00', 'Black Dance, The', 3023, 1, 4, 32, 9999, 5, 145, 0, '');
INSERT INTO 'recording' VALUES (1250, NULL, '2014-08-21 06:39:11.101929+00', 'Lord Kilmory''s Delight', 3018, 1, 8, 32, 9999, 1, 277, 0, '');
INSERT INTO 'recording' VALUES (1302, NULL, '2012-01-20 12:55:08.697889+00', 'Earl of Home, The', 3023, 3, 4, 32, 9999, 5, 252, 0, '');
INSERT INTO 'recording' VALUES (1303, NULL, '2012-01-20 12:55:08.70346+00', 'Kiss Me Quick, My Mither''s Coming', 3023, 1, 8, 32, 9999, 1, 285, 0, '');
INSERT INTO 'recording' VALUES (1304, NULL, '2012-01-20 12:55:08.708964+00', 'She''s Ower Young to Marry Yet', 3023, 3, 8, 32, 9999, 5, 505, 0, '');
INSERT INTO 'recording' VALUES (1305, NULL, '2012-01-20 12:55:08.71449+00', 'Keep the Country Bonnie Lassie', 3023, 3, 8, 40, 9999, 27, 630, 0, '');
INSERT INTO 'recording' VALUES (1306, NULL, '2012-01-20 12:55:08.719983+00', 'Crooket Horned Ewie, The', 3023, 3, 8, 32, 9999, 5, 506, 0, '');
INSERT INTO 'recording' VALUES (1307, NULL, '2012-01-20 12:55:08.724801+00', 'Lochiel''s Rant', 3028, 3, 8, 32, 9999, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (1308, NULL, '2012-01-20 12:55:08.729592+00', 'Alewife and her Barrel, The', 3028, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (1309, NULL, '2012-01-20 12:55:08.734383+00', 'Rakish Highlandman, The', 3028, 2, 8, 40, 9999, NULL, 347, 0, '');
INSERT INTO 'recording' VALUES (1310, NULL, '2012-01-20 12:55:08.73918+00', 'Widows, The', 3028, 3, 8, 32, 9999, NULL, 492, 0, '');
INSERT INTO 'recording' VALUES (1311, NULL, '2012-01-20 12:55:08.743967+00', 'Admiral Nelson', 3028, 1, 4, 64, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (1312, NULL, '2012-01-20 12:55:08.748852+00', 'Trip to Holland, A', 3028, 3, 8, 32, 9999, NULL, 490, 0, '');
INSERT INTO 'recording' VALUES (1313, NULL, '2012-01-20 12:55:08.753679+00', 'Sandal, The', 3028, 1, 8, 48, 9999, NULL, 412, 0, '');
INSERT INTO 'recording' VALUES (1314, NULL, '2012-01-20 12:55:08.758513+00', 'Captain McBride''s Hornpipe', 3071, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (1315, NULL, '2012-01-20 12:55:08.763299+00', 'Up in the Air', 3071, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (1316, NULL, '2012-01-20 12:55:08.768079+00', 'Miss Bennet''s Jig', 3071, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (3997, NULL, '2012-01-20 12:55:24.066904+00', 'Yetts of Muckart, The', 3067, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (3998, NULL, '2012-01-20 12:55:24.07314+00', 'Old Tyme Waltz Medley', 3067, 5, 0, 0, 9999, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (3999, NULL, '2012-01-20 12:55:24.079389+00', 'Marches in 2/4 Time', 3067, 11, 0, 0, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (4000, NULL, '2012-01-20 12:55:24.085621+00', 'Vocal Selection: Christine Scott', 3067, 98, 0, 0, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (4001, NULL, '2012-01-20 12:55:24.341048+00', 'Marches in 6/8 Time', 3067, 11, 0, 0, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (4002, NULL, '2012-01-20 12:55:24.347371+00', 'Violin Solo: Kleis Swan', 3067, 98, 0, 0, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (4003, NULL, '2012-01-20 12:55:24.353613+00', 'Ena Smith''s Reel', 3067, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (4004, NULL, '2012-01-20 12:55:24.360149+00', 'Sing Along Jigs', 3067, 2, 5, 32, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (4005, NULL, '2012-01-20 12:55:24.366435+00', 'Celtic Medley, A', 3067, 98, 0, 0, 9999, NULL, 317, 0, '');
INSERT INTO 'recording' VALUES (4006, NULL, '2012-01-20 12:55:24.372664+00', 'Polka', 3067, 13, 0, 0, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (4007, NULL, '2012-01-20 12:55:24.378928+00', 'Highland Minstrel Boy, The', 3067, 3, 3, 32, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (4008, NULL, '2012-01-20 12:55:24.385255+00', 'Irish Waltz Medley', 3067, 5, 0, 0, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (4009, NULL, '2012-01-20 12:55:24.391883+00', 'Marches in 2/4 and 6/8', 3067, 11, 0, 0, 9999, NULL, 159, 0, '');
INSERT INTO 'recording' VALUES (4011, NULL, '2012-01-20 12:55:24.404577+00', 'Irish Jigs', 3067, 2, 0, 0, 9999, NULL, 120, 0, '');
INSERT INTO 'recording' VALUES (4013, NULL, '2012-01-20 12:55:24.41706+00', 'Marches in 6/8 Time', 3067, 11, 0, 0, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (4014, NULL, '2012-01-20 12:55:24.422581+00', 'Miller''s Maid, The', 3067, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (4015, NULL, '2012-01-20 12:55:24.42741+00', 'Slow Air, Marches and Reel', 3067, 98, 0, 0, 9999, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (4016, NULL, '2012-01-20 12:55:24.432198+00', 'Home Waltz, The and Auld Lang Syne', 3067, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4017, NULL, '2012-01-20 12:55:24.43697+00', 'Insomniac March, The', 3067, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4012, NULL, '2012-10-23 22:44:51.093155+00', 'Violin Solo: Kleis Swan', 3067, 99, 0, 0, 9999, NULL, 120, 0, '');
INSERT INTO 'recording' VALUES (4010, NULL, '2012-10-23 22:51:16.92675+00', 'Vocal Selection: Warren Beesley', 3067, 98, 0, 0, 9999, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (9150, '2013-01-06 14:49:47.422483+00', '2013-01-06 14:49:47.422494+00', 'Highland Schottische', 3007, 3, 0, 8, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (9166, '2013-01-06 18:09:14.53561+00', '2013-01-06 18:09:14.535621+00', 'Jigs 6x40', 2029, 2, 6, 40, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (9209, '2013-01-16 13:58:38.58025+00', '2013-01-16 13:58:38.58026+00', 'Hesitation Waltz', 10709, 5, 0, 16, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (1285, NULL, '2013-02-05 13:05:52.014289+00', 'Inch of Perth', 3038, 3, 4, 32, 9999, 5, 248, 0, '');
INSERT INTO 'recording' VALUES (9277, '2013-02-05 15:22:55.982169+00', '2013-02-05 15:22:55.982179+00', 'Barracks Johnnie 4 steps', 10741, 7, 4, 16, 9999, NULL, 91, 0, '');
INSERT INTO 'recording' VALUES (1317, NULL, '2012-01-20 12:55:08.773064+00', 'Village Reel', 3071, 3, 8, 32, 9999, NULL, 493, 0, '');
INSERT INTO 'recording' VALUES (1318, NULL, '2012-01-20 12:55:08.777985+00', 'Miss Burns''s Reel', 3071, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (1319, NULL, '2012-01-20 12:55:08.782792+00', 'Miss Devon''s Reel', 3071, 3, 8, 32, 9999, NULL, 493, 0, '');
INSERT INTO 'recording' VALUES (1320, NULL, '2012-01-20 12:55:08.787576+00', 'Drummer, The', 3071, 1, 8, 48, 9999, NULL, 417, 0, '');
INSERT INTO 'recording' VALUES (1321, NULL, '2012-01-20 12:55:08.792886+00', 'Miss Ogilvie''s Fancy', 3071, 3, 8, 32, 9999, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (1322, NULL, '2012-01-20 12:55:08.79775+00', 'Miss Jessie Dalrymple''s Reel', 3071, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (1323, NULL, '2012-01-20 12:55:08.802554+00', 'Quiet and Snug', 3071, 3, 8, 32, 9999, NULL, 499, 0, '');
INSERT INTO 'recording' VALUES (1324, NULL, '2012-01-20 12:55:08.807365+00', 'Express, The', 3071, 2, 8, 40, 9999, NULL, 345, 0, '');
INSERT INTO 'recording' VALUES (1325, NULL, '2012-01-20 12:55:08.812165+00', 'College Hornpipe, The', 3071, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (1326, NULL, '2012-01-20 12:55:08.81764+00', 'Miss Murray of Lintrose', 3024, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1328, NULL, '2012-01-20 12:55:08.828701+00', 'Duchess of York, The', 3024, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1329, NULL, '2012-01-20 12:55:08.834416+00', 'Burns'' Hornpipe', 3024, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1330, NULL, '2012-01-20 12:55:08.839348+00', 'Reel of Five, The', 3024, 4, 0, 32, 5, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1331, NULL, '2012-01-20 12:55:08.844866+00', 'Sally''s Fancy', 3024, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1333, NULL, '2012-01-20 12:55:08.855892+00', 'Miss Nellie Wemyss', 3024, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1334, NULL, '2012-01-20 12:55:08.8614+00', 'Auld Lang Syne', 3024, 3, 4, 32, 9999, 5, 243, 0, '');
INSERT INTO 'recording' VALUES (9309, '2013-02-22 14:42:42.934489+00', '2019-11-21 17:58:12.074116+00', 'Marine Four Step', 10209, 11, 8, 16, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (1335, NULL, '2012-01-20 12:55:08.866889+00', 'Trip O''er the Tweed, A', 3025, 2, 4, 48, 9999, 4, 201, 0, '');
INSERT INTO 'recording' VALUES (1336, NULL, '2012-01-20 12:55:08.87283+00', 'Pretty Polly', 3025, 3, 4, 32, 9999, 5, 241, 0, '');
INSERT INTO 'recording' VALUES (1337, NULL, '2012-01-20 12:55:08.878403+00', 'Bonnie Lass', 3025, 1, 8, 32, 9999, 5, 280, 0, '');
INSERT INTO 'recording' VALUES (1339, NULL, '2012-01-20 12:55:08.891178+00', 'Mairi''s Fancy', 3025, 3, 4, 32, 9999, 5, 243, 0, '');
INSERT INTO 'recording' VALUES (1340, NULL, '2012-01-20 12:55:08.896743+00', 'Mrs Hill''s Delight', 3025, 1, 8, 32, 9999, 1, 271, 0, '');
INSERT INTO 'recording' VALUES (1341, NULL, '2012-01-20 12:55:08.90255+00', 'Euan''s Jig', 3025, 2, 8, 32, 9999, 1, 269, 0, '');
INSERT INTO 'recording' VALUES (1342, NULL, '2012-01-20 12:55:08.908069+00', 'Miss Shaftesbury''s Fancy', 3025, 3, 4, 32, 9999, 5, 248, 0, '');
INSERT INTO 'recording' VALUES (1343, NULL, '2012-01-20 12:55:08.91356+00', 'Two to One', 3025, 2, 8, 32, 9999, 1, 270, 0, '');
INSERT INTO 'recording' VALUES (1344, NULL, '2012-01-20 12:55:08.925131+00', 'Not I', 3025, 1, 8, 32, 9999, 5, 281, 0, '');
INSERT INTO 'recording' VALUES (1348, NULL, '2012-01-20 12:55:08.947246+00', 'Collichur', 3018, 2, 8, 32, 9999, 1, 261, 0, '');
INSERT INTO 'recording' VALUES (1350, NULL, '2012-01-20 12:55:08.958236+00', 'Highland Lass, The', 3018, 1, 8, 32, 9999, 5, 268, 0, '');
INSERT INTO 'recording' VALUES (1351, NULL, '2012-01-20 12:55:08.96373+00', 'Bawk, The', 3018, 2, 8, 32, 9999, 1, 261, 0, '');
INSERT INTO 'recording' VALUES (1353, NULL, '2012-01-20 12:55:08.974232+00', 'Man''s a Man for A'' That, A', 3018, 3, 8, 32, 9999, 5, 470, 0, '');
INSERT INTO 'recording' VALUES (1354, NULL, '2012-01-20 12:55:08.97974+00', 'Cadies Lady, The', 3018, 1, 8, 40, 9999, 27, 330, 0, '');
INSERT INTO 'recording' VALUES (1355, NULL, '2012-01-20 12:55:08.984583+00', 'Short and Sweet', 3018, 2, 8, 40, 9999, NULL, 325, 0, '');
INSERT INTO 'recording' VALUES (1356, NULL, '2012-01-20 12:55:08.990044+00', 'Scotland', 3026, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1347, NULL, '2014-08-21 06:42:33.703868+00', 'Ross Meor', 3018, 3, 4, 32, 9999, 5, 247, 0, '');
INSERT INTO 'recording' VALUES (1338, NULL, '2014-10-19 16:39:04.481971+00', 'Star, The', 3025, 3, 6, 32, 9999, 5, 367, 0, '');
INSERT INTO 'recording' VALUES (1357, NULL, '2012-01-20 12:55:08.99553+00', 'Sir Murdoch McDonald''s Strathspey', 3026, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (4018, NULL, '2012-01-20 12:55:24.441756+00', 'Field of Bannockburn', 3009, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4020, NULL, '2012-01-20 12:55:24.45141+00', 'Galloway House', 3009, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4021, NULL, '2012-01-20 12:55:24.456233+00', 'Queen''s Welcome, The', 2062, 1, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (4022, NULL, '2012-01-20 12:55:24.461024+00', 'Flower of the Quern, The', 2062, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4023, NULL, '2012-01-20 12:55:24.46586+00', 'There''s Nae Luck Aboot The Hoose', 3020, 3, 8, 32, 9999, NULL, 484, 0, '');
INSERT INTO 'recording' VALUES (4024, NULL, '2012-01-20 12:55:24.470641+00', 'Harmonica Tricks', 2062, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4025, NULL, '2012-01-20 12:55:24.475407+00', 'Hamilton Rant, The', 2062, 1, 4, 48, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (4026, NULL, '2012-01-20 12:55:24.480195+00', 'Heather on the Hills, The', 2062, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4027, NULL, '2012-01-20 12:55:24.484975+00', 'Gay Gordons', 2062, 11, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4028, NULL, '2012-01-20 12:55:24.489771+00', 'Miss Mary Douglas', 3020, 2, 8, 48, 9999, NULL, 405, 0, '');
INSERT INTO 'recording' VALUES (4029, NULL, '2012-01-20 12:55:24.494547+00', 'Bandboys', 2062, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4030, NULL, '2012-01-20 12:55:24.499324+00', 'Gaelic Waltzes', 2062, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4031, NULL, '2012-01-20 12:55:24.504097+00', 'Seaside Schottische', 2062, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4032, NULL, '2012-01-20 12:55:24.508881+00', 'Eva Three Step', 2062, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4033, NULL, '2012-01-20 12:55:24.51367+00', 'Bovaglie''s Plaid', 2062, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4034, NULL, '2012-01-20 12:55:24.518455+00', 'Because He Was a Bonnie Lad', 2062, 4, 0, 128, 19, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4035, NULL, '2012-01-20 12:55:24.523238+00', 'General Stuart''s Reel', 3026, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4036, NULL, '2012-01-20 12:55:24.528027+00', 'Just As I Was in the Morning', 3026, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4019, NULL, '2012-02-11 14:32:51.198118+00', 'Inch of Perth', 2246, 3, 4, 32, 9999, NULL, 221, 0, '');
INSERT INTO 'recording' VALUES (9167, '2013-01-06 18:11:14.769357+00', '2013-01-06 18:11:14.769367+00', 'Reels 2x40', 2029, 1, 2, 40, 9999, NULL, 90, 0, '');
INSERT INTO 'recording' VALUES (9210, '2013-01-16 14:02:21.179032+00', '2013-01-16 14:02:21.179042+00', 'Eva Three Step', 10709, 11, 8, 16, 9999, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (1352, NULL, '2013-02-04 19:28:50.115251+00', 'Strip the Willow - 9/8 Time', 3018, 101, 8, 40, 9999, NULL, 335, 0, '');
INSERT INTO 'recording' VALUES (9278, '2013-02-05 15:28:26.028109+00', '2013-02-05 15:28:26.028119+00', 'Barracks Johnnie 4 steps', 10742, 7, 4, 16, 9999, NULL, 99, 0, '');
INSERT INTO 'recording' VALUES (9310, '2013-02-22 14:45:16.946776+00', '2013-02-27 12:47:41.665378+00', 'Nottingham Lace', 10209, 1, 4, 24, 9999, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (1358, NULL, '2012-01-20 12:55:09.001006+00', 'Cromartie''s Rant', 3026, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1359, NULL, '2012-01-20 12:55:09.006593+00', 'Music Makars, The', 3019, 1, 8, 32, 9999, 5, 258, 0, '');
INSERT INTO 'recording' VALUES (1360, NULL, '2012-01-20 12:55:09.012085+00', 'Stuttgart Strathspey, The', 3019, 3, 8, 32, 9999, 5, 478, 0, '');
INSERT INTO 'recording' VALUES (1332, NULL, '2019-03-16 04:03:21.074226+00', 'Tayport Beauty', 3024, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1361, NULL, '2012-01-20 12:55:09.017595+00', 'It''s Just For Fun', 3019, 2, 8, 32, 9999, 1, 264, 0, '');
INSERT INTO 'recording' VALUES (1362, NULL, '2012-01-20 12:55:09.023121+00', 'Bedrule', 3019, 3, 8, 32, 9999, 1, 471, 0, '');
INSERT INTO 'recording' VALUES (1363, NULL, '2012-01-20 12:55:09.028629+00', 'Leap Year', 3026, 2, 8, 24, 9999, 18, 204, 0, '');
INSERT INTO 'recording' VALUES (1364, NULL, '2012-01-20 12:55:09.034119+00', 'Davy''s Locker', 3026, 1, 8, 24, 9999, 18, 215, 0, '');
INSERT INTO 'recording' VALUES (1365, NULL, '2012-01-20 12:55:09.040295+00', 'Highland Fair, The', 3026, 2, 8, 32, 9999, 5, 270, 0, '');
INSERT INTO 'recording' VALUES (1366, NULL, '2012-01-20 12:55:09.045897+00', 'Galloway House', 3026, 1, 8, 32, 9999, 5, 273, 0, '');
INSERT INTO 'recording' VALUES (1367, NULL, '2012-01-20 12:55:09.051395+00', 'Berwick Johnnie', 3026, 2, 8, 32, 9999, 5, 268, 0, '');
INSERT INTO 'recording' VALUES (1368, NULL, '2012-01-20 12:55:09.056962+00', 'Miss Flora''s Favourite', 3026, 1, 8, 32, 9999, 5, 280, 0, '');
INSERT INTO 'recording' VALUES (1369, NULL, '2012-01-20 12:55:09.062481+00', 'Merry Reapers, The', 3026, 2, 8, 24, 9999, 18, 200, 0, '');
INSERT INTO 'recording' VALUES (1370, NULL, '2012-01-20 12:55:09.06798+00', 'Wedderburn''s Reel', 3026, 1, 8, 32, 9999, 5, 273, 0, '');
INSERT INTO 'recording' VALUES (1372, NULL, '2012-01-20 12:55:09.07899+00', 'Regent''s Favourite', 3026, 1, 8, 32, 9999, 5, 275, 0, '');
INSERT INTO 'recording' VALUES (1374, NULL, '2012-01-20 12:55:09.090301+00', 'Argyll''s Fancy', 3026, 2, 4, 48, 9999, 4, 205, 0, '');
INSERT INTO 'recording' VALUES (1375, NULL, '2012-01-20 12:55:09.095805+00', 'Sunday Morning', 3044, 1, 4, 32, 9999, 5, 146, 0, '');
INSERT INTO 'recording' VALUES (4050, NULL, '2013-02-15 17:22:36.099807+00', 'Across The Tay', 3024, 2, 4, 48, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (1378, NULL, '2012-01-20 12:55:09.112313+00', 'Ladies of Dingwall, The', 3044, 1, 8, 48, 9999, 4, 0, 0, '');
INSERT INTO 'recording' VALUES (1380, NULL, '2012-01-20 12:55:09.123326+00', 'Bonnie Kitty', 3044, 1, 8, 40, 9999, 14, 0, 0, '');
INSERT INTO 'recording' VALUES (1381, NULL, '2012-01-20 12:55:09.128833+00', 'Haig of Bemersyde', 3044, 3, 4, 32, 9999, 5, 244, 0, '');
INSERT INTO 'recording' VALUES (1382, NULL, '2012-01-20 12:55:09.133694+00', 'Reel of the Royal Scots, The', 3072, 1, 8, 32, 9999, NULL, 303, 0, '');
INSERT INTO 'recording' VALUES (1383, NULL, '2012-01-20 12:55:09.139184+00', 'Mettle in yer Heels', 2029, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1384, NULL, '2012-01-20 12:55:09.145093+00', 'Fraser''s Favourite', 3018, 1, 8, 32, 9999, 10, 285, 0, '');
INSERT INTO 'recording' VALUES (1385, NULL, '2012-01-20 12:55:09.150703+00', 'From Scotia''s Shores We''re Noo Awa''', 3018, 3, 8, 32, 9999, 5, 495, 0, '');
INSERT INTO 'recording' VALUES (1386, NULL, '2012-01-20 12:55:09.156193+00', 'Weel Done, Cutty Sark', 2029, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1387, NULL, '2012-01-20 12:55:09.16168+00', 'Auld Davie McClemmet''s Fiddle', 2029, 2, 4, 40, 9999, 14, 0, 0, '');
INSERT INTO 'recording' VALUES (1388, NULL, '2012-01-20 12:55:09.167198+00', 'Jubilee Jig, The', 3018, 2, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (1389, NULL, '2012-01-20 12:55:09.172901+00', 'Drumtochty Glen', 3018, 3, 8, 32, 9999, 5, 495, 0, '');
INSERT INTO 'recording' VALUES (1390, NULL, '2012-01-20 12:55:09.177754+00', 'Queen Victoria''s Visit Quadrilles', 3018, 10, 5, 40, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (1391, NULL, '2012-01-20 12:55:09.183231+00', 'Meg, Tam''s Auld Grey Mare', 2029, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1392, NULL, '2012-01-20 12:55:09.188721+00', 'Tribute to the Borders', 3042, 2, 8, 32, 9999, 1, 266, 0, '');
INSERT INTO 'recording' VALUES (1393, NULL, '2012-01-20 12:55:09.194334+00', 'Frae A'' the Airts', 3042, 4, 8, 32, 1, 5, 377, 0, '');
INSERT INTO 'recording' VALUES (1394, NULL, '2012-01-20 12:55:09.199852+00', 'Dalry Kirk Reel', 2029, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1373, NULL, '2021-07-02 09:24:57.814976+00', 'Lady Catherine Bruce''s Reel', 3026, 2, 8, 32, 9999, 5, 268, 0, '');
INSERT INTO 'recording' VALUES (1395, NULL, '2012-01-20 12:55:09.204684+00', 'McCulloch Strathspey, The', 3042, 3, 0, 80, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (1396, NULL, '2012-01-20 12:55:09.21018+00', 'Miss Allie Anderson', 3042, 2, 8, 32, 9999, 1, 265, 0, '');
INSERT INTO 'recording' VALUES (4037, NULL, '2012-01-20 12:55:24.532836+00', 'Ship of Grace', 3026, 3, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4038, NULL, '2012-01-20 12:55:24.537706+00', 'Ellwyn''s Fairy Glen', 3026, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4039, NULL, '2012-01-20 12:55:24.542549+00', 'Duke of Perth', 3026, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4040, NULL, '2012-01-20 12:55:24.547349+00', 'Donald Bane', 3026, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4041, NULL, '2012-01-20 12:55:24.552201+00', 'Hebridean Weaving Lilt', 3026, 3, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4042, NULL, '2012-01-20 12:55:24.557023+00', 'Argyll''s Fancy', 3026, 2, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4043, NULL, '2012-01-20 12:55:24.561824+00', 'Back o'' Bennachie', 3026, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4044, NULL, '2012-01-20 12:55:24.566605+00', 'Marches', 2358, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4045, NULL, '2012-01-20 12:55:24.571387+00', 'Set of Hornpipes', 2681, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (4046, NULL, '2012-01-20 12:55:24.576169+00', 'Dashing White Sergeant Encore', 3009, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4052, NULL, '2013-02-15 17:28:17.24624+00', 'Highland Schottische', 3024, 3, 8, 8, 9999, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (4053, NULL, '2013-02-15 17:28:56.404266+00', 'Happy Returns', 3024, 1, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (1377, NULL, '2012-08-30 05:32:48.736009+00', 'Royal Wedding, The', 3044, 3, 8, 32, 9999, 5, 484, 0, '');
INSERT INTO 'recording' VALUES (9168, '2013-01-06 18:13:08.236281+00', '2013-01-06 18:13:08.236292+00', 'Reels 3x40', 2029, 1, 3, 40, 9999, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (9211, '2013-01-16 14:05:35.829831+00', '2013-01-16 14:05:35.829842+00', 'Saddle the Pony', 10709, 2, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (9279, '2013-02-05 15:33:22.360412+00', '2013-02-05 15:33:22.360422+00', 'Highland Laddie 4 steps', 10741, 7, 4, 16, 9999, NULL, 94, 0, '');
INSERT INTO 'recording' VALUES (4054, NULL, '2013-02-15 17:10:11.649984+00', 'Maxwell''s Rant', 3024, 1, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (4056, NULL, '2013-02-15 17:12:35.551302+00', 'Scottish Waltz', 3024, 5, 0, 0, 9999, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (4057, NULL, '2013-02-15 17:14:53.576297+00', 'Gay Gordons', 3024, 11, 8, 16, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (4051, NULL, '2013-02-15 17:16:07.520148+00', 'Gay Gordons', 3024, 11, 6, 16, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (4047, NULL, '2013-02-15 17:19:47.200753+00', 'Baldovan Reel', 3024, 1, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (4048, NULL, '2013-02-15 17:20:25.63105+00', 'Swilcan, The', 3024, 2, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (4049, NULL, '2013-02-15 17:21:18.687693+00', 'Jenny''s Bawbee', 3024, 3, 4, 24, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (1397, NULL, '2012-01-20 12:55:09.215696+00', 'Miss Catherine Allan', 3042, 3, 8, 32, 9999, 5, 477, 0, '');
INSERT INTO 'recording' VALUES (1399, NULL, '2012-01-20 12:55:09.226801+00', 'Sauchie Haugh', 3042, 3, 8, 32, 9999, 5, 471, 0, '');
INSERT INTO 'recording' VALUES (1400, NULL, '2012-01-20 12:55:09.232312+00', 'Fife Ness', 3018, 1, 8, 32, 9999, 5, 279, 0, '');
INSERT INTO 'recording' VALUES (1401, NULL, '2012-01-20 12:55:09.237814+00', 'Staffin Harvest', 3018, 3, 4, 32, 9999, 5, 247, 0, '');
INSERT INTO 'recording' VALUES (1402, NULL, '2012-01-20 12:55:09.244+00', 'West''s Hornpipe', 3018, 1, 4, 32, 9999, 1, 140, 0, '');
INSERT INTO 'recording' VALUES (1405, NULL, '2012-01-20 12:55:09.260596+00', 'Adam Forrester of Knocksheen''s Night Out', 2029, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1406, NULL, '2012-01-20 12:55:09.26611+00', 'Dancers Cleekit, The', 2029, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1407, NULL, '2012-01-20 12:55:09.2716+00', 'Lowp and Fling', 2029, 1, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1408, NULL, '2012-01-20 12:55:09.276435+00', 'Rouken Glen', 2430, 3, 0, 72, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1409, NULL, '2012-01-20 12:55:09.281907+00', 'Triumph, The', 3018, 1, 6, 24, 9999, 18, 156, 0, '');
INSERT INTO 'recording' VALUES (1412, NULL, '2012-01-20 12:55:09.298416+00', 'Highlandman''s Umbrella, The', 3067, 1, 4, 32, 9999, 1, 137, 0, '');
INSERT INTO 'recording' VALUES (1413, NULL, '2012-01-20 12:55:09.303907+00', 'Salute to Summer', 3067, 1, 4, 32, 9999, 1, 137, 0, '');
INSERT INTO 'recording' VALUES (1415, NULL, '2012-01-20 12:55:09.314907+00', 'Duran Ranger, The', 3067, 1, 8, 32, 9999, 1, 264, 0, '');
INSERT INTO 'recording' VALUES (1403, NULL, '2015-09-16 16:06:19.224611+00', 'Her Majesty is Welcome', 3018, 4, 4, 64, 5, NULL, 376, 0, '');
INSERT INTO 'recording' VALUES (1371, NULL, '2018-01-22 21:58:27.888488+00', 'Kitty Campbell''s Reel', 3026, 2, 8, 32, 9999, 1, 268, 0, '');
INSERT INTO 'recording' VALUES (1416, NULL, '2018-02-07 00:58:10.886922+00', 'Reel of the Royal Scots, The', 3067, 1, 8, 32, 9999, 8, 264, 0, '');
INSERT INTO 'recording' VALUES (1379, NULL, '2019-02-25 16:35:04.285816+00', 'Rifleman, The', 2029, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1417, NULL, '2012-01-20 12:55:09.325879+00', 'Bonnie Breist Knots, The', 3067, 3, 8, 32, 9999, 5, 484, 0, '');
INSERT INTO 'recording' VALUES (1418, NULL, '2012-01-20 12:55:09.331369+00', 'Bonnie Stronshiray', 3067, 3, 8, 32, 9999, 5, 484, 0, '');
INSERT INTO 'recording' VALUES (1420, NULL, '2012-01-20 12:55:09.342386+00', 'New Rigged Ship, The', 2032, 2, 8, 48, 9999, 25, 392, 0, '');
INSERT INTO 'recording' VALUES (1421, NULL, '2012-01-20 12:55:09.347898+00', 'Bonnie Anne', 2032, 2, 0, 96, 9999, 1, 107, 0, '');
INSERT INTO 'recording' VALUES (1423, NULL, '2012-01-20 12:55:09.359217+00', 'Gates of Edinburgh, The', 2032, 1, 8, 32, 9999, 5, 264, 0, '');
INSERT INTO 'recording' VALUES (1424, NULL, '2012-01-20 12:55:09.364707+00', 'Duke and Duchess of Edinburgh, The', 2032, 1, 8, 40, 9999, 6, 316, 0, '');
INSERT INTO 'recording' VALUES (1425, NULL, '2012-01-20 12:55:09.370369+00', 'Cadgers in the Canongate', 2032, 1, 8, 48, 9999, 4, 370, 0, '');
INSERT INTO 'recording' VALUES (1426, NULL, '2012-01-20 12:55:09.37596+00', 'Dalkeith''s Strathspey', 2032, 3, 8, 32, 9999, 5, 448, 0, '');
INSERT INTO 'recording' VALUES (1427, NULL, '2012-01-20 12:55:09.381451+00', 'Davy Nick Nack', 2033, 1, 8, 32, 9999, 1, 269, 0, '');
INSERT INTO 'recording' VALUES (1428, NULL, '2012-01-20 12:55:09.386949+00', 'Teviot Bridge', 2033, 2, 8, 24, 9999, 18, 199, 0, '');
INSERT INTO 'recording' VALUES (1429, NULL, '2012-01-20 12:55:09.392444+00', 'Gentle Shepherd, The', 2033, 2, 4, 32, 9999, 5, 148, 0, '');
INSERT INTO 'recording' VALUES (1430, NULL, '2012-01-20 12:55:09.397963+00', 'Laird of Milton''s Daughter, The', 2033, 2, 8, 32, 9999, 5, 268, 0, '');
INSERT INTO 'recording' VALUES (1431, NULL, '2012-01-20 12:55:09.403443+00', 'Miss Nancy Frowns', 2033, 2, 8, 32, 9999, 5, 270, 0, '');
INSERT INTO 'recording' VALUES (1432, NULL, '2012-01-20 12:55:09.409038+00', 'Fight About the Fireside', 2033, 1, 8, 32, 9999, 5, 264, 0, '');
INSERT INTO 'recording' VALUES (1433, NULL, '2012-01-20 12:55:09.414612+00', 'Triumph, The', 2033, 1, 4, 24, 9999, 5, 103, 0, '');
INSERT INTO 'recording' VALUES (1434, NULL, '2012-01-20 12:55:09.420147+00', 'Bridge of Nairn', 2033, 3, 8, 32, 9999, 5, 499, 0, '');
INSERT INTO 'recording' VALUES (1435, NULL, '2012-01-20 12:55:09.425665+00', 'Monymusk', 2033, 3, 8, 32, 9999, 5, 496, 0, '');
INSERT INTO 'recording' VALUES (1436, NULL, '2012-01-20 12:55:09.431152+00', 'Gay Gordons', 3006, 11, 4, 16, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (4061, NULL, '2012-01-20 12:55:24.648145+00', 'Quite Contrary', 3057, 2, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4062, NULL, '2012-01-20 12:55:24.652925+00', 'Shetland Waltz', 3057, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4063, NULL, '2012-01-20 12:55:24.65774+00', 'Canadian Barn Dance', 3057, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4064, NULL, '2012-01-20 12:55:24.6628+00', 'Wicked Willy', 3057, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4065, NULL, '2012-01-20 12:55:24.667607+00', 'Leven Lassies', 3057, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4066, NULL, '2012-01-20 12:55:24.672388+00', 'Last of the Lairds, The', 3057, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4067, NULL, '2012-01-20 12:55:24.677179+00', 'Glen Cova', 3057, 1, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4068, NULL, '2012-01-20 12:55:24.682005+00', 'Doreen''s Waltz', 3057, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4070, NULL, '2012-01-20 12:55:24.691562+00', 'Polka-Musette', 3057, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4071, NULL, '2012-01-20 12:55:24.696347+00', 'Fiddler''s Fancy', 3057, 2, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4073, NULL, '2012-01-20 12:55:24.706734+00', 'MacDonald of Sleat', 3010, 2, 0, 120, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (4074, NULL, '2012-01-20 12:55:24.711553+00', 'Waltz Country Dance', 3010, 5, 4, 40, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (4075, NULL, '2012-01-20 12:55:24.716354+00', 'Haddo House', 3010, 2, 6, 32, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (4076, NULL, '2012-01-20 12:55:24.72116+00', 'Shepherd''s Crook, The', 3010, 3, 0, 72, 9999, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (4077, NULL, '2012-01-20 12:55:24.725962+00', 'Two-Step -- Looking for a Partner', 3010, 11, 0, 0, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (1422, NULL, '2021-05-11 08:11:26.546267+00', 'Back o'' Bennachie, The', 2032, 1, 8, 32, 9999, 1, 262, 0, '');
INSERT INTO 'recording' VALUES (1404, NULL, '2021-06-21 21:34:12.753448+00', 'Cuillins of Skye', 3018, 3, 8, 32, 9999, 5, 484, 0, '');
INSERT INTO 'recording' VALUES (1414, NULL, '2021-06-16 14:04:13.849829+00', 'Bauldy Bain''s Fiddle', 3067, 1, 8, 32, 9999, 1, 265, 0, '');
INSERT INTO 'recording' VALUES (1398, NULL, '2021-06-22 20:06:43.827983+00', 'My Spouse Nancy', 3042, 1, 8, 32, 9999, 1, 274, 0, '');
INSERT INTO 'recording' VALUES (9169, '2013-01-06 18:19:07.53755+00', '2013-01-06 18:19:07.537561+00', 'Reels 5x40', 2029, 1, 5, 40, 9999, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (9212, '2013-01-16 14:08:13.798512+00', '2013-01-16 14:08:13.798522+00', 'Victoria Waltz', 10104, 5, 4, 32, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (9280, '2013-02-05 15:35:49.48578+00', '2013-02-05 15:35:49.48579+00', 'Highland Laddie 4 steps', 10742, 7, 4, 16, 9999, NULL, 94, 0, '');
INSERT INTO 'recording' VALUES (4058, NULL, '2013-02-15 17:18:00.067093+00', 'Glasgow Country Dance', 3024, 4, 4, 32, 1, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (1437, NULL, '2012-01-20 12:55:09.436685+00', 'Duke of Atholl''s Reel, The', 3006, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1438, NULL, '2012-01-20 12:55:09.442279+00', 'Lamb Skinnet', 3006, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1439, NULL, '2012-01-20 12:55:09.447823+00', 'Dashing White Sergeant, The', 3006, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1440, NULL, '2012-01-20 12:55:09.453329+00', 'Duke of Perth', 3006, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1441, NULL, '2012-01-20 12:55:09.458855+00', 'Jessie''s Hornpipe', 3006, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1442, NULL, '2012-01-20 12:55:09.463671+00', 'Eightsome Reel, The', 3006, 1, 0, 464, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1443, NULL, '2012-01-20 12:55:09.469121+00', 'Axum Reel, The', 3006, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1444, NULL, '2012-01-20 12:55:09.473956+00', 'Scottish Waltz', 3006, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1411, NULL, '2014-10-19 14:16:23.415005+00', 'Old Nick''s Lumber Room', 3067, 2, 8, 32, 9999, 1, 267, 0, '');
INSERT INTO 'recording' VALUES (4059, NULL, '2014-10-19 16:43:12.724008+00', 'Miss Hadden''s Reel', 3024, 2, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (1445, NULL, '2012-01-20 12:55:09.479453+00', 'Jubilee Jig, The', 2046, 2, 8, 32, 9999, 1, 276, 0, '');
INSERT INTO 'recording' VALUES (1447, NULL, '2012-01-20 12:55:09.490456+00', 'Waverley', 2046, 2, 8, 48, 9999, 4, 403, 0, '');
INSERT INTO 'recording' VALUES (1449, NULL, '2012-01-20 12:55:09.501428+00', 'Fraser''s Favourite', 2046, 1, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (1450, NULL, '2012-01-20 12:55:09.506928+00', 'Salute to Miss Milligan', 2046, 1, 8, 32, 9999, 5, 277, 0, '');
INSERT INTO 'recording' VALUES (1451, NULL, '2012-01-20 12:55:09.511755+00', 'White Heather Jig, The', 2303, 2, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1452, NULL, '2012-01-20 12:55:09.517229+00', 'Silver Tassie, The', 2046, 3, 8, 32, 9999, 5, 506, 0, '');
INSERT INTO 'recording' VALUES (1455, NULL, '2012-01-20 12:55:09.533794+00', 'Set of Jigs', 1502, 2, 4, 32, 9999, 1, 153, 0, '');
INSERT INTO 'recording' VALUES (1456, NULL, '2012-01-20 12:55:09.538637+00', 'Waltzes', 1502, 5, 0, 0, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (1457, NULL, '2012-01-20 12:55:09.544122+00', 'Hornpipes', 1502, 1, 5, 32, 9999, 1, 224, 0, '');
INSERT INTO 'recording' VALUES (1458, NULL, '2012-01-20 12:55:09.548943+00', 'Air', 1502, 98, 0, 0, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (1459, NULL, '2012-01-20 12:55:09.554437+00', 'Set of Reels', 1502, 1, 4, 32, 9999, 1, 155, 0, '');
INSERT INTO 'recording' VALUES (1461, NULL, '2012-01-20 12:55:09.564821+00', 'Waltzes', 1502, 5, 0, 0, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (1462, NULL, '2012-01-20 12:55:09.570349+00', 'March', 1502, 11, 0, 0, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (1463, NULL, '2012-01-20 12:55:09.575242+00', 'Air', 1502, 98, 0, 0, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (1464, NULL, '2012-01-20 12:55:09.580765+00', 'Slow Reels', 1502, 1, 5, 32, 9999, 5, 224, 0, '');
INSERT INTO 'recording' VALUES (1466, NULL, '2012-01-20 12:55:09.591108+00', 'Ian Powrie''s Farewell to Auchterarder', 2033, 2, 0, 128, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (1467, NULL, '2012-01-20 12:55:09.595909+00', 'Rothesay Rant, The', 2033, 2, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (1468, NULL, '2012-01-20 12:55:09.600752+00', 'Jean''s Jig', 3006, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9312, '2013-02-22 14:53:19.239331+00', '2022-12-14 16:37:42.516079+00', 'Killarney Waltz', 10209, 5, 0, 32, 9999, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (1470, NULL, '2012-01-20 12:55:09.611835+00', 'Blooms of Bon Accord, The', 2033, 1, 4, 32, 9999, 1, 141, 1, '');
INSERT INTO 'recording' VALUES (1472, NULL, '2012-01-20 12:55:09.622846+00', 'West''s Hornpipe', 2033, 1, 4, 32, 9999, 5, 136, 0, '');
INSERT INTO 'recording' VALUES (1474, NULL, '2012-01-20 12:55:09.633872+00', 'New Petronella, The', 2033, 1, 2, 48, 9999, 4, 106, 0, '');
INSERT INTO 'recording' VALUES (1448, NULL, '2015-09-16 15:59:37.694691+00', 'Hame O'' Mine', 2046, 4, 0, 64, 5, 5, 198, 0, '');
INSERT INTO 'recording' VALUES (1453, NULL, '2015-11-09 23:10:28.872272+00', 'Set of Reels', 1502, 1, 4, 32, 9999, 5, 158, 0, '');
INSERT INTO 'recording' VALUES (1454, NULL, '2016-09-04 15:39:04.025676+00', 'Set of Strathspeys', 1502, 3, 4, 32, 9999, 5, 285, 0, '');
INSERT INTO 'recording' VALUES (4060, NULL, '2017-02-03 17:06:43.349181+00', 'Grand March', 3057, 11, 1, 0, 9999, NULL, 223, 0, '');
INSERT INTO 'recording' VALUES (4069, NULL, '2017-02-03 17:46:12.008416+00', 'Gay Gordons', 3057, 11, 10, 16, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (1460, NULL, '2017-09-26 14:43:27.83455+00', 'Medley', 1502, 4, 4, 32, 1, 5, 221, 0, '');
INSERT INTO 'recording' VALUES (1476, NULL, '2012-01-20 12:55:09.644877+00', 'Strathglass House', 2033, 3, 8, 32, 9999, 5, 501, 0, '');
INSERT INTO 'recording' VALUES (1477, NULL, '2012-01-20 12:55:09.649693+00', 'Scotian''s Waltz, The', 2033, 5, 0, 0, 9999, NULL, 115, 0, '');
INSERT INTO 'recording' VALUES (4078, NULL, '2012-01-20 12:55:24.730749+00', 'Buchan Waltz, The', 3010, 5, 0, 0, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (4079, NULL, '2012-01-20 12:55:24.735621+00', 'Gay Gordons', 3010, 11, 12, 16, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (4080, NULL, '2012-01-20 12:55:24.740467+00', 'New Claret (Jigs & Reels)', 3056, 4, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4081, NULL, '2012-01-20 12:55:24.745253+00', 'Irish Medley', 3056, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4082, NULL, '2012-01-20 12:55:24.750093+00', 'Folk Waltz Selection', 3056, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4083, NULL, '2012-01-20 12:55:24.754878+00', 'Gay Gordons', 3056, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4084, NULL, '2012-01-20 12:55:24.759655+00', 'Jubilee Jig, The', 3056, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4085, NULL, '2012-01-20 12:55:24.764437+00', 'Gaelic Medley', 3056, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4086, NULL, '2012-01-20 12:55:24.769214+00', 'Strathspey & Reel', 3056, 4, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4087, NULL, '2012-01-20 12:55:24.773999+00', 'Grand March', 3056, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4088, NULL, '2012-01-20 12:55:24.778796+00', 'Miss Dumbreck', 3056, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4089, NULL, '2012-01-20 12:55:24.783578+00', 'Scottish Waltz', 3056, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4090, NULL, '2012-01-20 12:55:24.788391+00', 'Moray Reel, The', 3056, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4091, NULL, '2012-01-20 12:55:24.793175+00', 'Redondo Beach', 3056, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4092, NULL, '2012-01-20 12:55:24.797965+00', 'Highland Scottische', 3056, 3, 0, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4093, NULL, '2012-01-20 12:55:24.802746+00', 'Gaelic Waltz Selection', 3056, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4094, NULL, '2012-01-20 12:55:24.807567+00', 'Gay Gordons', 3056, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4095, NULL, '2012-01-20 12:55:24.812362+00', 'Eightsome Reel, The', 3068, 1, 1, 464, 9999, NULL, 465, 0, '');
INSERT INTO 'recording' VALUES (4096, NULL, '2012-01-20 12:55:24.817155+00', 'Foursome Reel', 3068, 4, 0, 0, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (4097, NULL, '2012-01-20 12:55:24.821953+00', 'Hamilton House', 3068, 2, 10, 32, 9999, NULL, 323, 0, '');
INSERT INTO 'recording' VALUES (4098, NULL, '2012-01-20 12:55:24.826763+00', 'Duke and Duchess of Edinburgh, The', 3068, 1, 10, 40, 9999, NULL, 409, 0, '');
INSERT INTO 'recording' VALUES (9170, '2013-01-06 18:20:59.217922+00', '2013-01-06 18:20:59.217932+00', 'Reels 6x40', 2029, 1, 6, 40, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (9213, '2013-01-16 14:14:14.744002+00', '2013-01-16 14:31:16.544419+00', 'Lauder Medley', 10713, 98, 0, 0, 9999, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (9281, '2013-02-05 15:40:10.186003+00', '2013-02-05 15:40:10.186013+00', 'Earl of Erroll 4 steps', 10741, 7, 4, 16, 9999, NULL, 126, 0, '');
INSERT INTO 'recording' VALUES (1478, NULL, '2012-01-20 12:55:09.655174+00', 'Hamilton House', 9998, 2, 4, 32, 9999, 34, 0, 0, '');
INSERT INTO 'recording' VALUES (1479, NULL, '2012-01-20 12:55:09.660251+00', 'MacDonald of Sleat', 9998, 2, 0, 120, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1480, NULL, '2012-01-20 12:55:09.665837+00', 'Puirt-a-Beul', 9998, 4, 0, 48, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1481, NULL, '2012-01-20 12:55:09.671348+00', 'East Neuk of Fife, The', 9998, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1482, NULL, '2012-01-20 12:55:09.676841+00', 'Loch Maben Hornpipe', 9998, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1483, NULL, '2012-01-20 12:55:09.682377+00', 'Back O'' Bennachie, The', 9998, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1484, NULL, '2012-01-20 12:55:09.687885+00', 'Duke of Perth', 9998, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1485, NULL, '2012-01-20 12:55:09.693363+00', 'Petronella', 9998, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1446, NULL, '2020-01-15 00:59:10.713722+00', 'Geneva Park', 2046, 2, 4, 40, 9999, 6, 173, 0, '');
INSERT INTO 'recording' VALUES (1486, NULL, '2012-01-20 12:55:09.698924+00', 'Lady Stewart MacPherson''s Reel', 9998, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1487, NULL, '2012-01-20 12:55:09.704436+00', 'Duke and Duchess of Edinburgh, The', 9998, 1, 2, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (1488, NULL, '2012-01-20 12:55:09.709973+00', 'Bramble Bush, The', 2034, 2, 8, 32, 9999, 5, 268, 0, '');
INSERT INTO 'recording' VALUES (1490, NULL, '2012-01-20 12:55:09.720951+00', 'Flowers of Edinburgh, The', 2035, 1, 8, 32, 9999, 1, 285, 0, '');
INSERT INTO 'recording' VALUES (1491, NULL, '2012-01-20 12:55:09.726459+00', 'Johnny Groat''s House', 2035, 1, 8, 32, 9999, 5, 300, 0, '');
INSERT INTO 'recording' VALUES (1492, NULL, '2012-01-20 12:55:09.731953+00', 'Red House', 2035, 1, 8, 40, 9999, 31, 520, 0, '');
INSERT INTO 'recording' VALUES (1493, NULL, '2012-01-20 12:55:09.737449+00', 'Camp of Pleasure, The', 2035, 3, 8, 32, 9999, 5, 510, 0, '');
INSERT INTO 'recording' VALUES (1494, NULL, '2012-01-20 12:55:09.742968+00', 'Monymusk', 2035, 3, 8, 32, 9999, 5, 500, 0, '');
INSERT INTO 'recording' VALUES (1495, NULL, '2012-01-20 12:55:09.748575+00', 'Snow in Summer', 2035, 3, 8, 40, 9999, 32, 620, 0, '');
INSERT INTO 'recording' VALUES (1496, NULL, '2012-01-20 12:55:09.754095+00', 'Grand March', 2037, 11, 0, 128, 9999, 1, 154, 0, '');
INSERT INTO 'recording' VALUES (1497, NULL, '2012-01-20 12:55:09.759659+00', 'Circassian Circle', 2037, 1, 5, 32, 9999, 5, 182, 0, '');
INSERT INTO 'recording' VALUES (1498, NULL, '2012-01-20 12:55:09.764487+00', 'Military Two-step', 2037, 11, 8, 16, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (1499, NULL, '2012-01-20 12:55:09.769285+00', 'Barn Dance', 2037, 11, 16, 8, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (1500, NULL, '2012-01-20 12:55:09.774335+00', 'Saint Bernard''s Waltz', 2037, 5, 10, 16, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (1501, NULL, '2012-01-20 12:55:09.816586+00', 'Eva Three Step', 2037, 11, 4, 16, 9999, 1, 156, 0, '');
INSERT INTO 'recording' VALUES (1502, NULL, '2012-01-20 12:55:09.822222+00', 'Broun''s Reel', 2037, 1, 8, 32, 9999, 1, 284, 0, '');
INSERT INTO 'recording' VALUES (1503, NULL, '2012-01-20 12:55:09.827954+00', 'Strip the Willow', 2037, 2, 6, 32, 9999, 33, 204, 0, '');
INSERT INTO 'recording' VALUES (1504, NULL, '2012-01-20 12:55:09.832864+00', 'Polka', 2037, 13, 0, 80, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (1505, NULL, '2012-01-20 12:55:09.837665+00', 'Gay Gordons', 2037, 11, 8, 16, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (1506, NULL, '2012-01-20 12:55:09.842466+00', 'Scottish Waltz', 2037, 5, 0, 160, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (1507, NULL, '2012-01-20 12:55:09.848261+00', 'Scottish Reform', 2037, 2, 8, 32, 9999, 1, 271, 0, '');
INSERT INTO 'recording' VALUES (1508, NULL, '2012-01-20 12:55:09.853234+00', 'Highland Schottische', 2037, 3, 12, 8, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (1510, NULL, '2012-01-20 12:55:09.864284+00', 'Reels', 3067, 1, 4, 32, 9999, 1, 140, 0, '');
INSERT INTO 'recording' VALUES (1511, NULL, '2012-01-20 12:55:09.869156+00', 'Boston Two-Step', 3067, 11, 8, 16, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (1513, NULL, '2012-01-20 12:55:09.880655+00', 'Eva Three Step', 3067, 11, 4, 16, 9999, 1, 173, 0, '');
INSERT INTO 'recording' VALUES (1514, NULL, '2012-01-20 12:55:09.885522+00', 'Waltz', 3067, 5, 6, 16, 9999, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (1515, NULL, '2012-01-20 12:55:09.891007+00', 'Gala Night', 3067, 2, 6, 32, 9999, 1, 210, 0, '');
INSERT INTO 'recording' VALUES (1517, NULL, '2012-01-20 12:55:09.901319+00', 'O my America', 3067, 1, 0, 88, 9999, NULL, 95, 0, '');
INSERT INTO 'recording' VALUES (1518, NULL, '2012-01-20 12:55:09.906806+00', 'Gay Gordons', 3067, 11, 8, 16, 9999, 1, 151, 0, '');
INSERT INTO 'recording' VALUES (1519, NULL, '2012-01-20 12:55:09.911611+00', 'Saint Bernard''s Waltz', 3067, 5, 8, 16, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (1520, NULL, '2012-01-20 12:55:09.916412+00', 'Grandfather Mountain Barn Dance', 3067, 50, 8, 16, 9999, NULL, 120, 0, '');
INSERT INTO 'recording' VALUES (1521, NULL, '2012-01-20 12:55:09.921886+00', 'Strathspey', 3067, 3, 3, 32, 9999, 5, 192, 0, '');
INSERT INTO 'recording' VALUES (1524, NULL, '2012-01-20 12:55:09.938457+00', 'Laird of Milton''s Daughter, The', 3051, 2, 8, 32, 9999, 1, 266, 0, '');
INSERT INTO 'recording' VALUES (1525, NULL, '2012-01-20 12:55:09.943945+00', 'Jig', 3051, 2, 8, 40, 9999, 6, 337, 0, '');
INSERT INTO 'recording' VALUES (1471, NULL, '2022-05-07 21:35:11.549928+00', 'Let''s Have a Ceilidh', 2033, 1, 4, 32, 9999, 1, 138, 0, '');
INSERT INTO 'recording' VALUES (1473, NULL, '2022-05-07 21:40:37.360812+00', 'Rest and be Thankful', 2033, 1, 8, 32, 9999, 5, 265, 0, '');
INSERT INTO 'recording' VALUES (1509, NULL, '2023-01-11 19:02:24.680595+00', 'Hamilton House', 2037, 2, 6, 32, 9999, 1, 207, 0, '');
INSERT INTO 'recording' VALUES (1526, NULL, '2012-01-20 12:55:09.949442+00', 'College Hornpipe, The', 3051, 1, 8, 32, 9999, 1, 277, 0, '');
INSERT INTO 'recording' VALUES (1527, NULL, '2012-01-20 12:55:09.954953+00', 'Duke of Perth', 3051, 1, 8, 32, 9999, 1, 273, 0, '');
INSERT INTO 'recording' VALUES (1528, NULL, '2012-01-20 12:55:09.960444+00', 'Duke and Duchess of Edinburgh, The', 3051, 1, 8, 40, 9999, 6, 345, 0, '');
INSERT INTO 'recording' VALUES (1529, NULL, '2012-01-20 12:55:09.965269+00', 'Eightsome Reel, The', 3051, 1, 0, 464, 9999, NULL, 494, 0, '');
INSERT INTO 'recording' VALUES (4099, NULL, '2012-01-20 12:55:24.83155+00', 'Duke of Perth', 3068, 1, 10, 32, 9999, NULL, 327, 0, '');
INSERT INTO 'recording' VALUES (4100, NULL, '2012-01-20 12:55:24.836403+00', 'Scottish Reform', 3068, 2, 10, 32, 9999, NULL, 329, 0, '');
INSERT INTO 'recording' VALUES (4101, NULL, '2012-01-20 12:55:24.841219+00', 'Reel of the 51st Division', 3068, 1, 10, 32, 9999, NULL, 328, 0, '');
INSERT INTO 'recording' VALUES (4102, NULL, '2012-01-20 12:55:24.846006+00', 'Inverness Country Dance', 3068, 1, 10, 32, 9999, NULL, 318, 0, '');
INSERT INTO 'recording' VALUES (1516, NULL, '2016-05-29 21:04:53.408482+00', 'Balgeddie Reel', 3067, 1, 5, 32, 9999, 5, 169, 0, '');
INSERT INTO 'recording' VALUES (1489, NULL, '2017-07-01 00:54:13.929409+00', 'Merry Reapers, The', 2035, 2, 8, 24, 9999, 18, 200, 0, '');
INSERT INTO 'recording' VALUES (1522, NULL, '2019-10-20 23:21:45.233344+00', 'Yellow-Haired Laddie, The', 3067, 5, 0, 64, 9999, 1, 135, 0, '');
INSERT INTO 'recording' VALUES (4103, NULL, '2012-01-20 12:55:24.850784+00', 'Eva Three Step', 3056, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4104, NULL, '2012-01-20 12:55:24.855591+00', 'Highland Scottische', 3056, 3, 0, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4105, NULL, '2012-01-20 12:55:24.860363+00', 'Gaelic Waltzes', 3056, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4106, NULL, '2012-01-20 12:55:24.865147+00', 'Miss Hadden''s Reel', 3056, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4107, NULL, '2012-01-20 12:55:24.87027+00', 'Peggy''s Wedding', 3056, 2, 2, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4108, NULL, '2012-01-20 12:55:24.87524+00', 'Twa Braw Reels', 3056, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4109, NULL, '2012-01-20 12:55:24.880133+00', 'Polka', 3056, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4110, NULL, '2012-01-20 12:55:24.88496+00', 'Gay Gordons', 3056, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4111, NULL, '2012-01-20 12:55:24.889835+00', 'Sutters of Selkirk, The', 2328, 1, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4112, NULL, '2012-01-20 12:55:24.89467+00', 'Miss Cahoon''s Reel', 2328, 2, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9171, '2013-01-06 18:22:42.759159+00', '2013-01-06 18:22:42.75917+00', 'Strathspeys 2x40', 2029, 3, 2, 40, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (9214, '2013-01-16 14:19:26.509403+00', '2013-01-16 14:19:26.509415+00', 'Polka', 10709, 13, 4, 16, 9999, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (9282, '2013-02-05 15:45:59.643412+00', '2013-02-05 15:45:59.643422+00', 'Village Maid 4 steps', 10744, 7, 4, 16, 9999, NULL, 103, 0, '');
INSERT INTO 'recording' VALUES (1530, NULL, '2012-01-20 12:55:09.970964+00', 'Balmoral Strathspey', 3051, 3, 4, 32, 9999, 5, 245, 0, '');
INSERT INTO 'recording' VALUES (1531, NULL, '2012-01-20 12:55:09.976603+00', 'Strathspey', 3051, 3, 8, 32, 9999, 5, 482, 0, '');
INSERT INTO 'recording' VALUES (1532, NULL, '2012-01-20 12:55:09.982105+00', 'Postie''s Jig', 2057, 2, 4, 32, 9999, 1, 136, 0, '');
INSERT INTO 'recording' VALUES (1533, NULL, '2012-01-20 12:55:09.987607+00', 'Dundee Reel', 2057, 2, 4, 40, 9999, 14, 170, 0, '');
INSERT INTO 'recording' VALUES (1534, NULL, '2012-01-20 12:55:09.993144+00', 'Argyll''s Fancy', 2057, 2, 4, 48, 9999, 4, 204, 0, '');
INSERT INTO 'recording' VALUES (1535, NULL, '2012-01-20 12:55:09.997997+00', 'Schiehallion', 2057, 4, 0, 128, 2, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (1537, NULL, '2012-01-20 12:55:10.008959+00', 'Duke of Perth', 2057, 1, 4, 32, 9999, 1, 135, 0, '');
INSERT INTO 'recording' VALUES (1538, NULL, '2012-01-20 12:55:10.015142+00', 'Montgomeries'' Rant, The', 2057, 1, 4, 32, 9999, 1, 140, 0, '');
INSERT INTO 'recording' VALUES (1539, NULL, '2012-01-20 12:55:10.020691+00', 'Mairi''s Wedding', 2057, 1, 4, 40, 9999, 6, 171, 0, '');
INSERT INTO 'recording' VALUES (1540, NULL, '2012-01-20 12:55:10.026259+00', 'Atlantic Bridge', 2057, 3, 3, 32, 9999, 5, 184, 0, '');
INSERT INTO 'recording' VALUES (1541, NULL, '2012-01-20 12:55:10.031828+00', 'Monymusk', 2057, 3, 4, 32, 9999, 5, 242, 0, '');
INSERT INTO 'recording' VALUES (1543, NULL, '2012-01-20 12:55:10.042905+00', 'Newton Park', 3009, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1544, NULL, '2012-01-20 12:55:10.048389+00', 'Starry Eyed Lassie, The', 3009, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1545, NULL, '2012-01-20 12:55:10.053898+00', 'Hamilton House', 3009, 2, 8, 32, 9999, 34, 0, 0, '');
INSERT INTO 'recording' VALUES (1546, NULL, '2012-01-20 12:55:10.059402+00', 'Cramond Bridge', 3009, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1547, NULL, '2012-01-20 12:55:10.064875+00', 'Fraser''s Favourite', 3009, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1548, NULL, '2012-01-20 12:55:10.070376+00', 'Mrs MacPherson of Inveran', 3009, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1549, NULL, '2012-01-20 12:55:10.075895+00', 'Neidpath Castle', 3009, 3, 3, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1550, NULL, '2012-01-20 12:55:10.081378+00', 'Ennismore Strathspey, The', 3009, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1551, NULL, '2012-01-20 12:55:10.086196+00', 'Sloane Square', 3009, 3, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1536, NULL, '2021-05-19 10:58:14.550296+00', 'Duchess of Buccleuch''s Favourite, The', 2057, 1, 4, 32, 9999, 1, 138, 0, '');
INSERT INTO 'recording' VALUES (1542, NULL, '2021-05-25 12:45:53.931472+00', 'Jubilee Jig, The', 3009, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1552, NULL, '2012-01-20 12:55:10.091717+00', 'Togetherness', 3014, 1, 8, 32, 9999, 1, 276, 0, '');
INSERT INTO 'recording' VALUES (1553, NULL, '2012-01-20 12:55:10.097585+00', 'Rigmarie', 3014, 2, 4, 32, 9999, 1, 144, 1, '');
INSERT INTO 'recording' VALUES (1554, NULL, '2012-01-20 12:55:10.10313+00', 'Middleton Medley, The', 3014, 4, 8, 32, 8, 5, 393, 0, '');
INSERT INTO 'recording' VALUES (1555, NULL, '2012-01-20 12:55:10.108641+00', 'Caberfei', 3014, 1, 8, 32, 9999, 5, 278, 0, '');
INSERT INTO 'recording' VALUES (1556, NULL, '2012-01-20 12:55:10.113464+00', 'Fiddle Solo', 3014, 98, 0, 0, 9999, NULL, 306, 0, '');
INSERT INTO 'recording' VALUES (1559, NULL, '2012-01-20 12:55:10.130025+00', 'Ayer''s Rock', 3014, 3, 4, 32, 9999, 5, 261, 1, '');
INSERT INTO 'recording' VALUES (1560, NULL, '2012-01-20 12:55:10.135529+00', 'Mairrit Man''s Favourite, The', 3014, 1, 8, 32, 9999, 1, 274, 0, '');
INSERT INTO 'recording' VALUES (1561, NULL, '2012-01-20 12:55:10.141018+00', 'Dancing Master, The', 3014, 2, 3, 96, 9999, 1, 106, 0, '');
INSERT INTO 'recording' VALUES (1562, NULL, '2012-01-20 12:55:10.14689+00', 'Blue Mess Jacket, The', 3014, 3, 4, 32, 9999, 5, 255, 0, '');
INSERT INTO 'recording' VALUES (1564, NULL, '2012-01-20 12:55:10.157937+00', 'Dennis Tucker Two-Step, The', 3014, 50, 0, 0, 9999, 10, 136, 0, '');
INSERT INTO 'recording' VALUES (1565, NULL, '2012-01-20 12:55:10.162805+00', 'Highland Barn Dance', 3042, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1566, NULL, '2012-01-20 12:55:10.167625+00', 'Swinging Sporran, The', 3042, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1567, NULL, '2012-01-20 12:55:10.173213+00', 'Call of the Pipes, The', 3042, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1568, NULL, '2012-01-20 12:55:10.178768+00', 'Postie''s Jig', 3042, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1569, NULL, '2012-01-20 12:55:10.183599+00', 'Accordian Polka', 3042, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4113, NULL, '2012-01-20 12:55:24.899446+00', 'Scottish Waltz', 2328, 5, 0, 0, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (4115, NULL, '2012-01-20 12:55:24.9091+00', 'Lassies of Dunse', 2328, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4116, NULL, '2012-01-20 12:55:24.914371+00', 'Kiss Me Quick My Mither''s Coming', 2328, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4117, NULL, '2012-01-20 12:55:24.919335+00', 'Kiss for Nothing, A', 2328, 2, 6, 32, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (4118, NULL, '2012-01-20 12:55:24.924131+00', 'Bluebell Polka', 2328, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4119, NULL, '2012-01-20 12:55:24.928915+00', 'Keppoch''s Rant', 2328, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4120, NULL, '2012-01-20 12:55:24.933705+00', 'Mason''s Apron, The', 2328, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4121, NULL, '2012-01-20 12:55:24.93864+00', 'Black Dance', 2328, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4122, NULL, '2012-01-20 12:55:24.943459+00', 'Bonnie Kate of Aberdeen', 2328, 3, 2, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4123, NULL, '2012-01-20 12:55:24.948248+00', 'Duke and Duchess of Edinburgh, The', 3009, 1, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4125, NULL, '2012-01-20 12:55:24.957885+00', 'Scottish Waltz', 3009, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4127, NULL, '2012-01-20 12:55:24.967444+00', 'Circassian Circle', 3009, 1, 6, 32, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (4128, NULL, '2012-01-20 12:55:24.972221+00', 'Gay Gordons', 3009, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4129, NULL, '2012-01-20 12:55:24.977026+00', 'MacDonald of Sleat', 3009, 2, 0, 120, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4130, NULL, '2012-01-20 12:55:24.98182+00', 'Duke of Perth', 3009, 1, 8, 32, 9999, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (4131, NULL, '2012-01-20 12:55:24.986609+00', 'Scottish Waltz', 2090, 5, 0, 0, 9999, NULL, 126, 0, '');
INSERT INTO 'recording' VALUES (4132, NULL, '2012-01-20 12:55:24.991413+00', 'Gay Gordons', 2090, 11, 0, 16, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (4126, NULL, '2012-02-11 14:34:08.965089+00', 'Gay Gordons', 2246, 11, 0, 16, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (9172, '2013-01-06 18:25:45.846839+00', '2013-01-06 18:25:45.84685+00', 'Strathspeys 3x40', 2029, 3, 3, 40, 9999, NULL, 227, 0, '');
INSERT INTO 'recording' VALUES (1558, NULL, '2022-12-22 13:50:25.462117+00', 'Diamond Celebration', 3014, 2, 8, 32, 9999, 1, 274, 0, '');
INSERT INTO 'recording' VALUES (9215, '2013-01-16 14:22:28.112146+00', '2013-01-16 14:22:28.112157+00', 'Gay Gordons Two-Step', 10104, 11, 8, 16, 9999, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (9283, '2013-02-05 15:51:35.640526+00', '2013-02-05 15:51:35.640536+00', 'Earl of Erroll 4 steps', 10744, 7, 4, 16, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (1570, NULL, '2012-01-20 12:55:10.188401+00', 'Bluebell Polka', 3042, 13, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1571, NULL, '2012-01-20 12:55:10.19398+00', 'Blarney Reel, The', 3042, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1572, NULL, '2012-01-20 12:55:10.199496+00', 'Plantation Reel, The', 3042, 1, 5, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1573, NULL, '2012-01-20 12:55:10.204985+00', 'Irish Rover, The', 3042, 1, 8, 32, 9999, 10, 0, 0, '');
INSERT INTO 'recording' VALUES (1574, NULL, '2012-01-20 12:55:10.210477+00', 'Scotch Hop', 3042, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1575, NULL, '2012-01-20 12:55:10.215289+00', 'Dreaming', 3042, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1576, NULL, '2012-01-20 12:55:10.220106+00', 'Gaelic Memories', 3042, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1577, NULL, '2012-01-20 12:55:10.224896+00', 'Singalong Waltz', 3042, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1579, NULL, '2012-01-20 12:55:10.235274+00', 'Hollin Buss, The', 2034, 2, 8, 32, 9999, 1, 268, 0, '');
INSERT INTO 'recording' VALUES (1580, NULL, '2012-01-20 12:55:10.241129+00', 'Sailor, The', 2034, 1, 8, 32, 9999, 5, 277, 0, '');
INSERT INTO 'recording' VALUES (1581, NULL, '2012-01-20 12:55:10.247255+00', 'Wild Geese, The', 2034, 2, 8, 32, 9999, 1, 267, 0, '');
INSERT INTO 'recording' VALUES (1582, NULL, '2012-01-20 12:55:10.253111+00', 'Miss Dumbreck', 2034, 1, 8, 32, 9999, 5, 272, 0, '');
INSERT INTO 'recording' VALUES (1583, NULL, '2012-01-20 12:55:10.258673+00', 'Kingussie Flower', 2034, 1, 8, 40, 9999, 6, 341, 0, '');
INSERT INTO 'recording' VALUES (1584, NULL, '2012-01-20 12:55:10.264199+00', 'Braes of Mellinish, The', 2034, 3, 8, 32, 9999, 5, 480, 0, '');
INSERT INTO 'recording' VALUES (1585, NULL, '2012-01-20 12:55:10.269028+00', 'Over the Dee and Over the Don', 9998, 2, 0, 96, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1586, NULL, '2012-01-20 12:55:10.274507+00', 'Three Bonnie Maidens, The', 2034, 3, 8, 32, 9999, 5, 487, 0, '');
INSERT INTO 'recording' VALUES (1587, NULL, '2012-01-20 12:55:10.280021+00', 'Cumberland Reel', 1456, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1589, NULL, '2012-01-20 12:55:10.291092+00', 'Express, The', 1456, 2, 8, 40, 9999, 14, 0, 0, '');
INSERT INTO 'recording' VALUES (1590, NULL, '2012-01-20 12:55:10.296591+00', 'Dumbarton Drums', 1456, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1591, NULL, '2012-01-20 12:55:10.302293+00', 'Flowers of Edinburgh, The', 1456, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1592, NULL, '2012-01-20 12:55:10.307814+00', 'Mrs MacLeod of Raasay', 1456, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1593, NULL, '2012-01-20 12:55:10.313307+00', 'Perthshire Highlanders, The', 1456, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1594, NULL, '2012-01-20 12:55:10.3188+00', 'Jessie''s Hornpipe', 3010, 1, 8, 32, 9999, 1, 255, 0, '');
INSERT INTO 'recording' VALUES (1595, NULL, '2012-01-20 12:55:10.324323+00', 'Express, The', 3010, 2, 8, 40, 9999, 14, 319, 0, '');
INSERT INTO 'recording' VALUES (1596, NULL, '2012-01-20 12:55:10.329822+00', 'Waverley', 3010, 2, 8, 48, 9999, 4, 376, 0, '');
INSERT INTO 'recording' VALUES (1597, NULL, '2012-01-20 12:55:10.33465+00', 'Gaelic Waltzes', 3056, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1598, NULL, '2012-01-20 12:55:10.340133+00', 'White Cockade, The', 3010, 1, 8, 32, 9999, 1, 255, 0, '');
INSERT INTO 'recording' VALUES (1599, NULL, '2012-01-20 12:55:10.345626+00', 'Duke and Duchess of Edinburgh, The', 3010, 1, 8, 40, 9999, 6, 445, 0, '');
INSERT INTO 'recording' VALUES (1600, NULL, '2012-01-20 12:55:10.351141+00', 'Tempête, La', 3010, 1, 4, 48, 9999, 35, 188, 0, '');
INSERT INTO 'recording' VALUES (1601, NULL, '2012-01-20 12:55:10.356664+00', 'Donald Bane', 3010, 3, 8, 32, 9999, 5, 445, 0, '');
INSERT INTO 'recording' VALUES (1602, NULL, '2012-01-20 12:55:10.362179+00', 'Jimmy''s Fancy', 3010, 3, 8, 32, 9999, 5, 445, 0, '');
INSERT INTO 'recording' VALUES (1603, NULL, '2012-01-20 12:55:10.367673+00', 'Berwick Johnnie', 3010, 2, 8, 32, 9999, 1, 256, 0, '');
INSERT INTO 'recording' VALUES (1604, NULL, '2012-01-20 12:55:10.373364+00', 'Sailor, The', 2035, 1, 8, 32, 9999, 5, 270, 0, '');
INSERT INTO 'recording' VALUES (1605, NULL, '2012-01-20 12:55:10.378889+00', 'Gentle Shepherd, The', 2035, 2, 4, 32, 9999, 5, 175, 0, '');
INSERT INTO 'recording' VALUES (1606, NULL, '2012-01-20 12:55:10.384403+00', 'I''ll Mak'' Ye Fain to Follow Me', 2035, 2, 8, 32, 9999, 1, 275, 0, '');
INSERT INTO 'recording' VALUES (1607, NULL, '2012-01-20 12:55:10.389913+00', 'Willie Wi'' His Tartan Trews', 2035, 2, 8, 40, 9999, 6, 350, 0, '');
INSERT INTO 'recording' VALUES (1609, NULL, '2012-01-20 12:55:10.400907+00', 'Petronella', 2035, 1, 8, 32, 9999, 1, 270, 0, '');
INSERT INTO 'recording' VALUES (4135, NULL, '2012-01-20 12:55:25.005869+00', 'J.B. Milne', 2397, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1563, NULL, '2021-07-03 09:17:01.747549+00', 'Earlstoun Loch', 3014, 1, 5, 32, 9999, 1, 174, 0, '');
INSERT INTO 'recording' VALUES (4136, NULL, '2012-01-20 12:55:25.010662+00', 'Dundee Whaler, The', 2397, 3, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4137, NULL, '2012-01-20 12:55:25.015482+00', 'Dundee Reel', 2397, 2, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4138, NULL, '2012-01-20 12:55:25.020293+00', 'Waltz', 2397, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4139, NULL, '2012-01-20 12:55:25.02508+00', 'Gay Gordons', 2397, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4140, NULL, '2012-01-20 12:55:25.029877+00', 'Hollin Buss, The', 2397, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4141, NULL, '2012-01-20 12:55:25.034655+00', 'Barn Dance', 2397, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4142, NULL, '2012-01-20 12:55:25.039475+00', 'Broun''s Reel', 2397, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4144, NULL, '2012-01-20 12:55:25.049027+00', 'Trip to Bavaria, A', 2397, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4145, NULL, '2012-01-20 12:55:25.053815+00', 'Baldovan Reel', 2397, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4146, NULL, '2012-01-20 12:55:25.058605+00', 'Miss Hadden''s Reel', 2397, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4151, NULL, '2012-01-20 12:55:25.083604+00', 'Bonnie Lass of Bon Accord', 3041, 3, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4148, NULL, '2012-04-23 09:37:13.089811+00', 'Suitable for Ian Powrie''s Farewell to Auchterarder', 3041, 2, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (4147, NULL, '2012-04-23 09:39:18.983203+00', 'Suitable for General Stuart''s Reel, etc.', 3041, 1, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (4150, NULL, '2012-04-23 09:41:08.254366+00', 'Suitable for Wicked Willie', 3041, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (4149, NULL, '2012-04-23 09:41:56.613818+00', 'Suitable for Neidpath Castle, Ailsa Craig, etc.', 3041, 3, 3, 32, 9999, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (9173, '2013-01-06 18:28:04.95257+00', '2013-01-06 18:28:04.952581+00', 'Strathspeys 5x40', 2029, 3, 5, 40, 9999, NULL, 380, 0, '');
INSERT INTO 'recording' VALUES (9216, '2013-01-16 14:25:28.643268+00', '2013-01-16 14:25:28.643278+00', 'Glenburnie Rant', 10104, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (1610, NULL, '2012-01-20 12:55:10.406409+00', 'Trip to Tobermory, A', 2035, 3, 8, 24, 9999, 18, 375, 0, '');
INSERT INTO 'recording' VALUES (1611, NULL, '2012-01-20 12:55:10.41198+00', 'Rakes of Glasgow', 2035, 3, 8, 32, 9999, 5, 480, 0, '');
INSERT INTO 'recording' VALUES (1612, NULL, '2012-01-20 12:55:10.417492+00', 'H.I.S.C.D.', 2040, 1, 8, 32, 9999, 1, 278, 0, '');
INSERT INTO 'recording' VALUES (1615, NULL, '2012-01-20 12:55:10.434137+00', 'Wood of Fyvie, The', 2040, 1, 8, 32, 9999, 3, 271, 0, '');
INSERT INTO 'recording' VALUES (1616, NULL, '2012-01-20 12:55:10.439628+00', 'Good Hearted Glasgow Jig, The', 2040, 2, 8, 32, 9999, 1, 278, 0, '');
INSERT INTO 'recording' VALUES (1619, NULL, '2012-01-20 12:55:10.456151+00', 'Kiss under the Stairs', 2040, 2, 8, 32, 9999, 1, 278, 0, '');
INSERT INTO 'recording' VALUES (1621, NULL, '2012-01-20 12:55:10.467142+00', 'Maple Leaf Rant', 2040, 1, 8, 40, 9999, 14, 343, 0, '');
INSERT INTO 'recording' VALUES (1622, NULL, '2012-01-20 12:55:10.471965+00', 'Last Waltz', 2040, 5, 0, 0, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (1623, NULL, '2012-01-20 12:55:10.476764+00', 'Hebridean Weaving Lilt', 2041, 3, 0, 104, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (1624, NULL, '2012-01-20 12:55:10.482261+00', 'Bees of Maggieknockater, The', 2041, 2, 4, 32, 9999, 1, 132, 0, '');
INSERT INTO 'recording' VALUES (1626, NULL, '2012-01-20 12:55:10.494318+00', 'New Rigged Ship, The', 2041, 2, 8, 48, 9999, 11, 387, 0, '');
INSERT INTO 'recording' VALUES (1627, NULL, '2012-01-20 12:55:10.499141+00', 'Polka, The', 2041, 13, 0, 0, 9999, NULL, 65, 0, '');
INSERT INTO 'recording' VALUES (1630, NULL, '2012-01-20 12:55:10.515625+00', 'Reel of the 51st Division, The', 2041, 1, 8, 32, 9999, 1, 261, 0, '');
INSERT INTO 'recording' VALUES (1631, NULL, '2012-01-20 12:55:10.521126+00', 'Mairi''s Wedding', 2041, 1, 8, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (1632, NULL, '2012-01-20 12:55:10.52668+00', 'Linkumdoddie', 2041, 1, 5, 48, 9999, 11, 252, 0, '');
INSERT INTO 'recording' VALUES (1633, NULL, '2012-01-20 12:55:10.532171+00', 'Dunsinane', 2041, 3, 3, 32, 9999, 5, 177, 0, '');
INSERT INTO 'recording' VALUES (1578, NULL, '2015-10-08 15:41:59.164129+00', 'Medley', 3002, 4, 0, 0, 9999, NULL, 201, 0, 'S+R');
INSERT INTO 'recording' VALUES (4133, NULL, '2022-08-21 16:17:34.990775+00', 'Scottish Reform (encore)', 2090, 2, 8, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (1588, NULL, '2022-12-09 19:58:32.261975+00', 'Muirland Willie', 1456, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1629, NULL, '2022-08-22 21:54:51.825848+00', 'Irish Rover (Encore), The', 2041, 1, 4, 32, 9999, 1, 131, 0, '');
INSERT INTO 'recording' VALUES (9316, '2013-02-22 15:02:47.49852+00', '2022-12-20 21:25:58.955642+00', 'Jacky Tar Two-Step', 10209, 11, 8, 16, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (1608, NULL, '2017-07-21 22:48:24.230532+00', 'Princess Royal, The', 2035, 1, 8, 28, 9999, 36, 245, 0, '');
INSERT INTO 'recording' VALUES (1618, NULL, '2016-05-10 23:24:32.476266+00', 'Ythanside', 2040, 3, 8, 32, 9999, 10, 491, 0, '');
INSERT INTO 'recording' VALUES (1634, NULL, '2012-01-20 12:55:10.537652+00', 'Winding Road, The', 2041, 3, 4, 32, 9999, 1, 248, 0, '');
INSERT INTO 'recording' VALUES (1635, NULL, '2012-01-20 12:55:10.542472+00', 'Shetland Waltz', 2041, 5, 0, 0, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (1636, NULL, '2012-01-20 12:55:10.547957+00', 'Campbell''s Frolic', 2042, 2, 8, 32, 9999, 1, 270, 0, '');
INSERT INTO 'recording' VALUES (1637, NULL, '2012-01-20 12:55:10.55349+00', 'Corn Rigs', 2042, 1, 8, 32, 9999, 1, 273, 0, '');
INSERT INTO 'recording' VALUES (1638, NULL, '2012-01-20 12:55:10.558993+00', 'Concord Wedding', 2042, 3, 0, 64, 9999, 5, 120, 0, '');
INSERT INTO 'recording' VALUES (1639, NULL, '2012-01-20 12:55:10.564483+00', 'Crockett''s Victory Garden', 2042, 1, 4, 32, 9999, 1, 153, 0, '');
INSERT INTO 'recording' VALUES (1640, NULL, '2012-01-20 12:55:10.570143+00', 'Hunting Horn', 2042, 2, 8, 32, 9999, 37, 257, 0, '');
INSERT INTO 'recording' VALUES (1641, NULL, '2012-01-20 12:55:10.575719+00', 'Hey, Johnny Cope', 2042, 1, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (1642, NULL, '2012-01-20 12:55:10.580544+00', 'Round Reel of Eight', 2042, 1, 0, 88, 9999, NULL, 98, 0, '');
INSERT INTO 'recording' VALUES (1643, NULL, '2012-01-20 12:55:10.586054+00', 'Set of Jigs', 2042, 2, 8, 32, 9999, 1, 270, 0, '');
INSERT INTO 'recording' VALUES (1644, NULL, '2012-01-20 12:55:10.591561+00', 'Queen City Strathspey, The', 2042, 3, 3, 32, 9999, 5, 182, 0, '');
INSERT INTO 'recording' VALUES (1645, NULL, '2012-01-20 12:55:10.596392+00', 'Waltz', 2042, 5, 0, 0, 9999, NULL, 229, 0, '');
INSERT INTO 'recording' VALUES (1646, NULL, '2012-01-20 12:55:10.601864+00', 'Roundabout', 2044, 2, 8, 32, 9999, 1, 282, 0, '');
INSERT INTO 'recording' VALUES (4154, NULL, '2013-02-04 16:02:04.136554+00', 'Suitable for Balmoral Strathspey, Dundee Whaler,', 3041, 3, 4, 32, 9999, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (4156, NULL, '2012-01-20 12:55:25.107692+00', 'Suitable for Airie Bennan', 3041, 2, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4159, NULL, '2012-01-20 12:55:25.12214+00', 'Jig 40 bar sequence', 2412, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4160, NULL, '2012-01-20 12:55:25.126959+00', 'Strathspey 32 bar sequence', 2412, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4161, NULL, '2012-01-20 12:55:25.131752+00', 'Waltz Country Dance', 2412, 5, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4162, NULL, '2012-01-20 12:55:25.137088+00', 'Reel 32 bar sequence', 2412, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4163, NULL, '2012-01-20 12:55:25.142178+00', 'Jig 32 bar sequence', 2412, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4164, NULL, '2012-01-20 12:55:25.147046+00', 'Reel 32 bar sequence', 2412, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4165, NULL, '2012-01-20 12:55:25.152019+00', 'Strathspey 40 bar sequence', 2412, 3, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4166, NULL, '2012-01-20 12:55:25.156934+00', 'Jig 32 bar sequence', 2412, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4167, NULL, '2012-01-20 12:55:25.161738+00', 'Waltz Country Dance', 2412, 5, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4170, NULL, '2012-01-20 12:55:25.176145+00', 'Bonnie Anne', 3009, 2, 0, 96, 9999, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (4157, NULL, '2012-04-23 09:33:14.047442+00', 'Strathspey, Reel Medley', 3041, 4, 1, 128, 2, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (4155, NULL, '2012-04-23 09:37:57.684455+00', 'For the Black Mountain Reel, Polharrow Burn', 3041, 1, 5, 32, 9999, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (4152, NULL, '2012-04-23 09:40:03.097417+00', 'Suitable for Luckenbooth Brooch, Wild Geese, etc.', 3041, 2, 8, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (1647, NULL, '2012-04-27 22:41:50.656285+00', 'Flag of Saint Andrew, The', 2044, 4, 4, 64, 22, 1, 389, 0, '');
INSERT INTO 'recording' VALUES (1649, NULL, '2012-04-27 22:44:32.915176+00', 'Elizabeth Thomson of Saint Andrews', 2044, 3, 6, 32, 9999, 1, 374, 0, '');
INSERT INTO 'recording' VALUES (1648, NULL, '2012-04-27 22:45:02.031283+00', 'Snibbett Bibliotheck', 2044, 1, 8, 32, 9999, 1, 284, 0, '');
INSERT INTO 'recording' VALUES (9174, '2013-01-06 18:31:52.737147+00', '2013-01-06 18:31:52.737159+00', 'Strathspeys 6x40', 2029, 3, 6, 40, 9999, NULL, 436, 0, '');
INSERT INTO 'recording' VALUES (4153, NULL, '2013-02-04 15:57:20.947264+00', 'Suitable for Baldovan Reel, etc.', 3041, 1, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (1653, NULL, '2012-01-20 12:55:10.640602+00', 'Trip to Gatlinburg', 3030, 2, 8, 32, 9999, 1, 284, 0, '');
INSERT INTO 'recording' VALUES (1654, NULL, '2012-01-20 12:55:10.646114+00', 'Jessie''s Hornpipe', 3030, 1, 8, 32, 9999, 5, 275, 0, '');
INSERT INTO 'recording' VALUES (4143, NULL, '2021-05-13 21:19:26.485843+00', 'Cornet''s Lass, The', 2397, 3, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1614, NULL, '2021-06-19 21:45:20.51713+00', 'Armstrong''s Rant, The', 2040, 3, 8, 32, 9999, 5, 499, 0, '');
INSERT INTO 'recording' VALUES (1617, NULL, '2021-06-19 22:27:06.484443+00', 'Smashing Set of Reels, A', 2040, 1, 4, 32, 9999, 5, 141, 0, '');
INSERT INTO 'recording' VALUES (1613, NULL, '2021-06-20 21:54:47.343464+00', 'Ring of Friendship, A', 2040, 2, 4, 32, 9999, 10, 140, 0, '');
INSERT INTO 'recording' VALUES (1655, NULL, '2012-01-20 12:55:10.651611+00', 'Minister on the Loch, The', 3030, 3, 3, 32, 9999, 5, 192, 0, '');
INSERT INTO 'recording' VALUES (1656, NULL, '2012-01-20 12:55:10.657105+00', 'Kendall''s Hornpipe', 3030, 2, 8, 32, 9999, 5, 282, 0, '');
INSERT INTO 'recording' VALUES (1657, NULL, '2012-01-20 12:55:10.662866+00', 'Cadgers in the Canongate', 3030, 1, 8, 48, 9999, 4, 415, 0, '');
INSERT INTO 'recording' VALUES (1658, NULL, '2012-01-20 12:55:10.668389+00', 'Lea Rig, The', 3030, 3, 6, 32, 9999, 5, 379, 0, '');
INSERT INTO 'recording' VALUES (1661, NULL, '2012-01-20 12:55:10.685026+00', 'Beauty of the North', 3030, 3, 8, 32, 9999, 5, 500, 0, '');
INSERT INTO 'recording' VALUES (1625, NULL, '2013-08-05 10:52:22.116765+00', 'Airie Bennan', 2041, 2, 5, 32, 9999, 1, 164, 0, '');
INSERT INTO 'recording' VALUES (1662, NULL, '2012-01-20 12:55:10.690531+00', 'Clarsach, The', 3030, 2, 4, 32, 9999, 5, 147, 0, '');
INSERT INTO 'recording' VALUES (1663, NULL, '2012-01-20 12:55:10.696014+00', 'Haste Ye Back', 3030, 1, 0, 88, 9999, 1, 100, 0, '');
INSERT INTO 'recording' VALUES (1664, NULL, '2012-01-20 12:55:10.701512+00', 'Dancing Airs', 3030, 3, 4, 32, 9999, 5, 260, 0, '');
INSERT INTO 'recording' VALUES (1665, NULL, '2012-01-20 12:55:10.707001+00', 'Crabbit Shona', 3030, 2, 6, 32, 9999, 1, 208, 0, '');
INSERT INTO 'recording' VALUES (1666, NULL, '2012-01-20 12:55:10.71182+00', 'Jessie, The Flower of Dunblane', 3030, 5, 0, 0, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (1667, NULL, '2012-01-20 12:55:10.717291+00', 'Strathspey and Reel Medley', 3030, 4, 4, 32, 1, 5, 204, 0, '');
INSERT INTO 'recording' VALUES (1668, NULL, '2012-01-20 12:55:10.722138+00', 'Military Two-step', 2039, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1669, NULL, '2012-01-20 12:55:10.727604+00', 'Wild Geese, The', 2035, 2, 8, 32, 9999, 1, 265, 0, '');
INSERT INTO 'recording' VALUES (1670, NULL, '2012-01-20 12:55:10.733093+00', 'Shetland Fiddler, The', 2035, 1, 4, 32, 9999, 1, 145, 0, '');
INSERT INTO 'recording' VALUES (1671, NULL, '2012-01-20 12:55:10.738593+00', 'Montgomeries'' Rant, The', 2035, 1, 8, 32, 9999, 5, 265, 0, '');
INSERT INTO 'recording' VALUES (1672, NULL, '2012-01-20 12:55:10.744135+00', 'Ye''re Welcome, Charlie Stuart', 2035, 1, 8, 32, 9999, 5, 280, 0, '');
INSERT INTO 'recording' VALUES (1673, NULL, '2012-01-20 12:55:10.749737+00', 'None So Pretty', 2035, 1, 8, 40, 9999, 6, 340, 0, '');
INSERT INTO 'recording' VALUES (1676, NULL, '2012-01-20 12:55:10.765586+00', 'Wandering Waltzes', 2035, 5, 0, 0, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (1677, NULL, '2012-01-20 12:55:10.771239+00', 'Duke of Perth', 2039, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1678, NULL, '2012-01-20 12:55:10.776763+00', 'Scottish Ramble', 2039, 3, 3, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1679, NULL, '2012-01-20 12:55:10.782884+00', 'Morpeth Rant, The', 2039, 1, 6, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1680, NULL, '2012-01-20 12:55:10.788498+00', 'Gay Gordons', 2039, 11, 0, 16, 9999, 3, 0, 0, '');
INSERT INTO 'recording' VALUES (1681, NULL, '2012-01-20 12:55:10.79402+00', 'Flowers of Edinburgh, The', 2039, 1, 6, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1682, NULL, '2012-01-20 12:55:10.799525+00', 'Dashing White Sergeant, The', 2039, 1, 6, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1683, NULL, '2012-01-20 12:55:10.805022+00', 'Hamilton House', 2039, 2, 6, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1684, NULL, '2012-01-20 12:55:10.809857+00', 'Scottish Waltz', 2039, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1685, NULL, '2012-01-20 12:55:10.81533+00', 'Maxwell''s Rant', 2039, 1, 6, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1686, NULL, '2012-01-20 12:55:10.820137+00', 'Highland Schottische', 2039, 3, 0, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1687, NULL, '2012-01-20 12:55:10.82561+00', 'Strip the Willow', 2039, 2, 5, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1688, NULL, '2012-01-20 12:55:10.8306+00', 'Duke of Atholl''s Reel, The', 1556, 2, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (1689, NULL, '2012-01-20 12:55:10.83543+00', 'Cauld Kail', 1556, 4, 8, 32, 1, NULL, 385, 0, '');
INSERT INTO 'recording' VALUES (4172, NULL, '2012-01-20 12:55:25.185726+00', 'Gaelic Waltz', 3009, 5, 0, 0, 9999, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (4173, NULL, '2012-01-20 12:55:25.190566+00', 'Pipe Jig', 1615, 2, 0, 0, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (4174, NULL, '2012-01-20 12:55:25.195358+00', 'Air', 1615, 98, 0, 0, 9999, NULL, 115, 0, '');
INSERT INTO 'recording' VALUES (4169, NULL, '2015-10-08 14:39:13.694397+00', 'Saint Andrew''s Fair', 3012, 2, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (4158, NULL, '2022-12-26 21:16:44.124386+00', 'Irish Rover, The', 3041, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4171, NULL, '2015-10-08 14:40:17.484118+00', 'Tribute to George Fleming, A', 3012, 98, 0, 0, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (1660, NULL, '2016-09-04 14:03:20.864025+00', 'Fire in the Rye', 3030, 1, 6, 32, 9999, 1, 209, 0, '');
INSERT INTO 'recording' VALUES (1659, NULL, '2015-12-20 14:03:19.373143+00', 'Dancing Master, The', 3030, 2, 1, 96, 9999, 1, 107, 0, '');
INSERT INTO 'recording' VALUES (1674, NULL, '2016-05-15 21:01:46.502059+00', 'Adieu Mon Ami', 2035, 3, 8, 32, 9999, 5, 490, 0, '');
INSERT INTO 'recording' VALUES (4175, NULL, '2012-01-20 12:55:25.200148+00', 'Air & Scotch Measure', 1615, 98, 0, 0, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (4176, NULL, '2012-01-20 12:55:25.205116+00', 'March, Strathspey and Reel', 1615, 4, 0, 0, 9999, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (4177, NULL, '2012-01-20 12:55:25.210131+00', 'Fiddler from Crieff, The', 1615, 2, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (4178, NULL, '2012-01-20 12:55:25.215206+00', 'Old Scottish Psalm Tunes', 1615, 98, 0, 0, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (4179, NULL, '2012-01-20 12:55:25.220208+00', 'March, Strathspey and Reel', 1615, 4, 0, 0, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (4180, NULL, '2012-01-20 12:55:25.225057+00', 'March and Hornpipes', 1615, 4, 0, 0, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (4181, NULL, '2012-01-20 12:55:25.229854+00', 'Air', 1615, 98, 0, 0, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (4182, NULL, '2012-01-20 12:55:25.234636+00', 'Colonel Anne of Moy Hall', 1615, 1, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (4183, NULL, '2012-01-20 12:55:25.239426+00', 'Air, Jig and Strathspey', 1615, 98, 0, 0, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (4184, NULL, '2012-01-20 12:55:25.244217+00', 'Air', 1615, 98, 0, 0, 9999, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (4185, NULL, '2012-01-20 12:55:25.249014+00', 'March, Strathspey and Reel', 1615, 4, 0, 0, 9999, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (4186, NULL, '2012-01-20 12:55:25.253823+00', 'Air, Strathspey and Reel', 1615, 98, 0, 0, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (4187, NULL, '2012-01-20 12:55:25.259861+00', 'Welcome to Whitney', 3057, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4188, NULL, '2012-01-20 12:55:25.265359+00', 'Mrs Muriel Skinner', 3057, 4, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4189, NULL, '2012-01-20 12:55:25.270339+00', 'What Do You Want?', 3057, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1652, NULL, '2012-04-27 22:42:55.754308+00', 'Georgie''s Jig', 2044, 2, 4, 32, 9999, 1, 144, 0, '');
INSERT INTO 'recording' VALUES (1650, NULL, '2012-04-27 22:45:42.948743+00', 'Square Tower, The', 2044, 1, 1, 64, 9999, 1, 77, 0, '');
INSERT INTO 'recording' VALUES (9175, '2013-01-06 18:34:53.925995+00', '2013-01-06 18:34:53.926006+00', 'Jigs 2x48', 2029, 2, 2, 48, 9999, NULL, 107, 0, '');
INSERT INTO 'recording' VALUES (1690, NULL, '2012-01-20 12:55:10.840331+00', 'Foursome and Half Reel of Tulloch', 1556, 7, 0, 128, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (1691, NULL, '2012-01-20 12:55:10.845206+00', 'Honour the Piper', 1556, 4, 0, 96, 11, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (1692, NULL, '2012-01-20 12:55:10.850043+00', 'Reel of the 51st Division, The', 1556, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (1693, NULL, '2012-01-20 12:55:10.855528+00', 'Montgomeries'' Rant, The', 1556, 1, 8, 32, 9999, 1, 273, 0, '');
INSERT INTO 'recording' VALUES (1694, NULL, '2012-01-20 12:55:10.860443+00', 'Eightsome Reel, The', 1556, 1, 1, 464, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1695, NULL, '2012-01-20 12:55:10.86597+00', 'Monymusk', 1556, 3, 8, 32, 9999, 5, 471, 0, '');
INSERT INTO 'recording' VALUES (1696, NULL, '2012-01-20 12:55:10.871899+00', 'Highland Rambler, The', 2043, 1, 8, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (1697, NULL, '2012-01-20 12:55:10.877463+00', 'Rose of the North, The', 2043, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1699, NULL, '2012-01-20 12:55:10.888509+00', 'Loch Linnhe', 2043, 3, 3, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1700, NULL, '2012-01-20 12:55:10.894062+00', 'Marchioness of Hartington''s Jig, The', 2043, 2, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1701, NULL, '2012-01-20 12:55:10.89957+00', 'Weathercock, The', 2043, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1702, NULL, '2012-01-20 12:55:10.905067+00', 'West Park', 2043, 3, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1703, NULL, '2012-01-20 12:55:10.910584+00', 'Tocher Band, The', 2043, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1704, NULL, '2012-01-20 12:55:10.91665+00', 'Marquesse of Hartington''s Strathspey, The', 2043, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1705, NULL, '2012-01-20 12:55:10.922213+00', 'Porridge Bowl, The', 2043, 2, 4, 48, 9999, 11, 0, 0, '');
INSERT INTO 'recording' VALUES (1714, NULL, '2012-01-20 12:55:10.96556+00', 'Craven Jig, The', 3217, 2, 4, 32, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (1717, NULL, '2012-01-20 12:55:10.980924+00', 'Ellwyn''s Fairy Glen', 2036, 1, 8, 32, 9999, 1, 286, 0, '');
INSERT INTO 'recording' VALUES (1718, NULL, '2012-01-20 12:55:10.985745+00', 'Eva Three Step', 2036, 11, 8, 16, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (1719, NULL, '2012-01-20 12:55:10.990548+00', 'Gay Gordons', 2036, 11, 8, 16, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (1720, NULL, '2012-01-20 12:55:10.99535+00', 'Konfetti Valse', 2036, 5, 0, 0, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (1721, NULL, '2012-01-20 12:55:11.00016+00', 'Pipe March', 2036, 11, 14, 16, 9999, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (1722, NULL, '2012-01-20 12:55:11.00563+00', 'Hollin Buss, The', 2036, 2, 8, 32, 9999, 1, 276, 0, '');
INSERT INTO 'recording' VALUES (1723, NULL, '2012-01-20 12:55:11.010482+00', 'MacDonald of Sleat', 2036, 2, 0, 120, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (1724, NULL, '2012-01-20 12:55:11.015274+00', 'Accordion Solo', 2036, 13, 0, 160, 9999, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (1725, NULL, '2012-01-20 12:55:11.020789+00', 'Roxburgh Castle', 2036, 1, 8, 32, 9999, 1, 273, 0, '');
INSERT INTO 'recording' VALUES (1726, NULL, '2012-01-20 12:55:11.026891+00', 'Strathspey', 2036, 3, 4, 32, 9999, 5, 248, 0, '');
INSERT INTO 'recording' VALUES (1727, NULL, '2012-01-20 12:55:11.031857+00', 'Waltz', 2036, 5, 0, 144, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (1728, NULL, '2012-01-20 12:55:11.036731+00', 'Highland Schottische', 3018, 3, 16, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4190, NULL, '2012-01-20 12:55:25.275161+00', 'Caddam Woods', 3057, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4191, NULL, '2012-01-20 12:55:25.279981+00', 'Linton Ploughman', 3057, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4192, NULL, '2012-01-20 12:55:25.284788+00', 'Alamein', 3057, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4193, NULL, '2012-01-20 12:55:25.292205+00', 'Mickleton Hall', 3057, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4194, NULL, '2012-01-20 12:55:25.297384+00', 'Rollright Reel, The', 3057, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4195, NULL, '2012-01-20 12:55:25.302241+00', 'Saltire Society Reel', 2183, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4196, NULL, '2012-01-20 12:55:25.307096+00', 'Dancing Master, The', 2183, 2, 0, 96, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4197, NULL, '2012-01-20 12:55:25.311919+00', 'Dancing Master, The', 2183, 2, 0, 96, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4198, NULL, '2012-01-20 12:55:25.31676+00', 'Swelkie, The', 2183, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4199, NULL, '2012-01-20 12:55:25.322492+00', 'Anniversary Reel', 2183, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4200, NULL, '2012-01-20 12:55:25.327346+00', 'Anniversary Reel (encore)', 2183, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4201, NULL, '2012-01-20 12:55:25.332176+00', 'Flying Spur, The', 2183, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4202, NULL, '2012-01-20 12:55:25.337016+00', 'Belle of Bon Accord, The', 2183, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4203, NULL, '2012-01-20 12:55:25.341843+00', 'Plantation Reels', 2183, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4204, NULL, '2012-01-20 12:55:25.346646+00', 'Weathercock, The', 2183, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4205, NULL, '2012-01-20 12:55:25.351459+00', 'Weathercock, The', 2183, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4206, NULL, '2012-01-20 12:55:25.356248+00', 'Back to the Fireside', 2183, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4207, NULL, '2012-01-20 12:55:25.361027+00', 'Cambuskenneth', 2183, 3, 0, 80, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4208, NULL, '2012-01-20 12:55:25.365819+00', 'Quarries'' Jig', 2183, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4209, NULL, '2012-01-20 12:55:25.370646+00', 'Flower of the Quern', 2183, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9176, '2013-01-06 18:36:39.425249+00', '2013-01-06 18:36:39.42526+00', 'Jigs 3x48', 2029, 2, 3, 48, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (1730, NULL, '2013-02-04 15:49:52.288522+00', 'Wild Geese, The', 3018, 2, 5, 32, 9999, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (1708, NULL, '2015-10-08 14:23:16.448132+00', 'Shiftin'' Bobbins', 3012, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (1709, NULL, '2015-10-08 14:24:50.004335+00', 'Eva Three Step', 3012, 11, 8, 16, 9999, NULL, 149, 0, '4 bar intro');
INSERT INTO 'recording' VALUES (1710, NULL, '2015-10-08 14:26:05.493651+00', 'Duchess of Buccleuch''s Favourite, The', 3012, 1, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (1711, NULL, '2015-10-08 14:26:52.281468+00', 'Express, The', 3012, 2, 4, 40, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (1712, NULL, '2015-10-08 14:27:57.987559+00', 'Gay Gordons', 3012, 11, 8, 16, 9999, NULL, 151, 0, '4 bar intro');
INSERT INTO 'recording' VALUES (1713, NULL, '2015-10-08 14:28:43.653675+00', 'Reel of the 51st Division, The', 3012, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (1715, NULL, '2015-10-08 14:33:09.192162+00', 'Hogmanay Jig, The', 3012, 2, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (1698, NULL, '2022-12-11 11:43:38.676517+00', 'Travelling Men, The', 2043, 2, 5, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1716, NULL, '2015-10-08 14:34:22.968502+00', 'Dance of the Diamonds, The', 3012, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (1732, NULL, '2012-04-23 10:23:22.521703+00', 'Threesome Reel, The', 3018, 4, 1, 48, 11, 4, 149, 0, '');
INSERT INTO 'recording' VALUES (1733, NULL, '2012-01-20 12:55:11.06193+00', 'Galloway House', 3018, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1739, NULL, '2012-04-23 10:25:52.189022+00', 'Logan Brig, The', 3018, 3, 2, 32, 9999, 3, 123, 0, '');
INSERT INTO 'recording' VALUES (1738, NULL, '2012-04-23 10:35:59.173469+00', 'Drumelzier', 3018, 3, 2, 32, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (1737, NULL, '2012-01-20 12:55:11.082047+00', 'Tempête, La', 3018, 1, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1736, NULL, '2012-04-23 10:39:17.868498+00', 'Mairrit Man''s Favourite, The', 3018, 1, 4, 32, 9999, 1, 141, 0, '');
INSERT INTO 'recording' VALUES (9177, '2013-01-06 18:38:25.222205+00', '2013-01-06 18:38:25.222215+00', 'Jigs 5x48', 2029, 2, 5, 48, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (1740, NULL, '2012-01-20 12:55:11.098412+00', 'Bill Hendry''s Gaelic Waltz', 3018, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1741, NULL, '2012-01-20 12:55:11.103251+00', 'Scottish Waltz', 3018, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1742, NULL, '2012-01-20 12:55:11.10806+00', 'Captain McBride''s Hornpipe', 1815, 1, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (1744, NULL, '2012-01-20 12:55:11.117739+00', 'Glayva', 1815, 2, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (1745, NULL, '2012-01-20 12:55:11.122599+00', 'Merry Dancers, The', 1815, 2, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (1746, NULL, '2012-01-20 12:55:11.127417+00', 'Black Dance, The', 1815, 1, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (1747, NULL, '2012-01-20 12:55:11.132218+00', 'Knit the Pocky', 1815, 1, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (1748, NULL, '2012-01-20 12:55:11.137019+00', 'Strathglass House', 1815, 3, 8, 32, 9999, NULL, 491, 0, '');
INSERT INTO 'recording' VALUES (1749, NULL, '2012-01-20 12:55:11.141833+00', 'There''s Nae Luck Aboot the Hoose', 1815, 3, 8, 32, 9999, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (1750, NULL, '2012-01-20 12:55:11.14704+00', 'Merry Uplanders', 2045, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1751, NULL, '2012-01-20 12:55:11.151893+00', 'Cumberland Reel', 2045, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1752, NULL, '2012-01-20 12:55:11.156687+00', 'Postie''s Jig', 2045, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1753, NULL, '2012-01-20 12:55:11.161482+00', 'Hollin Buss, The', 2045, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1754, NULL, '2012-01-20 12:55:11.166281+00', 'Jessie''s Hornpipe', 2045, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1755, NULL, '2012-01-20 12:55:11.171265+00', 'Scottish Reform', 2045, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1756, NULL, '2012-01-20 12:55:11.176106+00', 'Beyond the Black Stump', 2045, 2, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1757, NULL, '2012-01-20 12:55:11.180913+00', 'Triumph, The', 2045, 1, 4, 24, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1758, NULL, '2012-01-20 12:55:11.185748+00', 'Flying Scotsman, The', 2045, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1759, NULL, '2012-01-20 12:55:11.190557+00', 'British Grenadiers, The', 2045, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1760, NULL, '2012-01-20 12:55:11.195351+00', 'Cromdel Hill', 2045, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1761, NULL, '2012-01-20 12:55:11.200151+00', 'Mr Watson''s Favourite', 2045, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1770, NULL, '2012-01-20 12:55:11.251377+00', 'Lad o'' Kyle, The', 3044, 1, 4, 32, 9999, 5, 139, 0, '');
INSERT INTO 'recording' VALUES (1771, NULL, '2012-01-20 12:55:11.256935+00', 'Duff''s House', 3044, 2, 8, 32, 9999, 1, 271, 0, '');
INSERT INTO 'recording' VALUES (4210, NULL, '2012-01-20 12:55:25.375435+00', 'Spiffin''', 2183, 2, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4211, NULL, '2012-01-20 12:55:25.380231+00', 'Lady Sophia Lindsay', 2183, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4212, NULL, '2012-01-20 12:55:25.385027+00', 'Lady Sophia Lindsay (encore)', 2183, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4213, NULL, '2012-01-20 12:55:25.389914+00', 'Alasdair''s Reel', 2418, 1, 4, 32, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (4214, NULL, '2012-01-20 12:55:25.394752+00', 'George Will''s Jig', 2418, 2, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (4215, NULL, '2012-01-20 12:55:25.399554+00', 'Miss Becky Flower', 2418, 3, 4, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (4216, NULL, '2012-01-20 12:55:25.404364+00', 'Dominie, The', 2418, 2, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (4217, NULL, '2012-01-20 12:55:25.409886+00', 'Radyr Dancers, The', 2418, 3, 8, 32, 9999, NULL, 482, 0, '');
INSERT INTO 'recording' VALUES (4218, NULL, '2012-01-20 12:55:25.423366+00', 'WIllie''s Wife', 2418, 2, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (4220, NULL, '2012-01-20 12:55:25.436235+00', 'Old Clarsach, The', 2418, 3, 4, 32, 9999, NULL, 253, 0, '');
INSERT INTO 'recording' VALUES (4221, NULL, '2012-01-20 12:55:25.442516+00', 'Rachan Mill', 2418, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (4223, NULL, '2012-01-20 12:55:25.455588+00', 'Alison''s Round Reel', 2418, 1, 6, 32, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (4224, NULL, '2012-01-20 12:55:25.462115+00', 'Merlindale House', 2418, 3, 4, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (4226, NULL, '2012-01-20 12:55:25.475021+00', 'MacLeod of Harris', 1556, 1, 0, 144, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4227, NULL, '2012-01-20 12:55:25.481307+00', 'Rouken Glen', 1556, 3, 0, 72, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4228, NULL, '2012-01-20 12:55:25.487582+00', 'Over the Dee and Over the Don', 1556, 2, 0, 120, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4229, NULL, '2012-01-20 12:55:25.493421+00', 'McNeil of Barra', 1556, 4, 0, 112, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1731, NULL, '2012-04-23 10:08:19.154502+00', 'Cauld Kail', 3018, 4, 4, 32, 1, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (1734, NULL, '2012-04-23 10:10:48.308879+00', 'Reivers, The', 3018, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (1735, NULL, '2012-04-23 10:13:17.476568+00', 'Saint Johnstoun Reel', 3018, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (1772, NULL, '2012-01-20 12:55:11.262452+00', 'Lassies of Melrose, The', 3044, 2, 8, 32, 9999, 1, 273, 0, '');
INSERT INTO 'recording' VALUES (1773, NULL, '2012-01-20 12:55:11.268055+00', 'Roxburgh Castle', 3044, 1, 8, 32, 9999, 1, 271, 0, '');
INSERT INTO 'recording' VALUES (1774, NULL, '2012-01-20 12:55:11.273556+00', 'Vale of Atholl', 3044, 2, 8, 32, 9999, 1, 273, 0, '');
INSERT INTO 'recording' VALUES (1775, NULL, '2012-01-20 12:55:11.279786+00', 'Inverness Country Dance', 3044, 1, 8, 32, 9999, 1, 280, 0, '');
INSERT INTO 'recording' VALUES (1776, NULL, '2012-01-20 12:55:11.285312+00', 'Cairnsmore of Carsphairn', 3044, 3, 5, 32, 9999, 5, 301, 0, '');
INSERT INTO 'recording' VALUES (1777, NULL, '2012-01-20 12:55:11.290192+00', 'Kinfauns Castle', 3044, 3, 5, 32, 9999, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (1778, NULL, '2012-01-20 12:55:11.295718+00', 'Postie''s Jig', 3026, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1779, NULL, '2012-01-20 12:55:11.300557+00', 'Bonnie Anne', 3026, 2, 0, 96, 9999, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (1780, NULL, '2012-01-20 12:55:11.306019+00', 'Trip to Bavaria, A', 3026, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1781, NULL, '2012-01-20 12:55:11.311504+00', 'New Waterloo Reel, The', 3026, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1782, NULL, '2012-01-20 12:55:11.316989+00', 'Mrs Hepburn Belches of Invermay', 3026, 1, 8, 48, 9999, 30, 0, 0, '');
INSERT INTO 'recording' VALUES (1783, NULL, '2012-01-20 12:55:11.322487+00', 'Angus MacLeod', 3026, 1, 2, 64, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1784, NULL, '2012-01-20 12:55:11.328006+00', 'MacDonald of the Isles', 3026, 3, 3, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1785, NULL, '2012-01-20 12:55:11.333505+00', 'Alison Rose', 3026, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1787, NULL, '2012-01-20 12:55:11.343845+00', 'Pretty Ladies', 3026, 3, 0, 80, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1788, NULL, '2012-01-20 12:55:11.34932+00', 'Golden Pheasant, The', 3026, 2, 8, 40, 9999, 28, 0, 0, '');
INSERT INTO 'recording' VALUES (1789, NULL, '2012-01-20 12:55:11.354151+00', 'Foursome Reel and Reel of Tulloch', 3026, 4, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1790, NULL, '2012-01-20 12:55:11.359636+00', 'Baldovan Reel', 3026, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (4222, NULL, '2019-01-23 23:46:56.381362+00', 'Border Weavers, The', 2418, 3, 3, 32, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (1791, NULL, '2012-01-20 12:55:11.365157+00', 'Burns'' Hornpipe', 3026, 1, 4, 32, 9999, 5, 148, 0, '');
INSERT INTO 'recording' VALUES (1762, NULL, '2022-08-20 22:09:18.831877+00', 'Ladies'' Fancy', 2252, 2, 8, 32, 9999, 1, 269, 0, '');
INSERT INTO 'recording' VALUES (1769, NULL, '2022-08-20 22:09:46.616358+00', 'Peggy''s Love', 2252, 3, 8, 32, 9999, 5, 498, 0, '');
INSERT INTO 'recording' VALUES (1767, NULL, '2022-08-20 22:10:07.582997+00', 'Lady Harriet Hope''s Reel', 2252, 1, 8, 32, 9999, 5, 273, 0, '');
INSERT INTO 'recording' VALUES (1765, NULL, '2022-08-20 22:10:45.97785+00', 'Fireside Reel, The', 2252, 1, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (1763, NULL, '2022-08-20 22:11:05.613113+00', 'River Cree, The', 2252, 2, 8, 32, 9999, 1, 266, 0, '');
INSERT INTO 'recording' VALUES (1768, NULL, '2022-08-20 22:11:28.921126+00', 'Duchess of Atholl''s Slipper, The', 2252, 3, 8, 32, 9999, 5, 502, 0, '');
INSERT INTO 'recording' VALUES (1764, NULL, '2022-08-20 22:11:48.679841+00', 'Merrily Danced the Quaker''s Wife', 2252, 2, 8, 40, 9999, 6, 327, 0, '');
INSERT INTO 'recording' VALUES (4225, NULL, '2022-08-20 23:27:31.054404+00', 'Argyle Broadswords', 1556, 7, 0, 0, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (1743, NULL, '2022-12-09 20:00:34.29982+00', 'Merry Reapers, The', 1815, 2, 8, 24, 9999, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (1792, NULL, '2012-01-20 12:55:11.370847+00', 'Kiss Me Quick, My Mither''s Comin''', 3026, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1793, NULL, '2012-01-20 12:55:11.376381+00', 'Miss Murray of Lintrose', 3026, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1794, NULL, '2012-01-20 12:55:11.381994+00', 'Miss Milligan''s Strathspey', 3026, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1795, NULL, '2012-01-20 12:55:11.387503+00', 'New Scotland Strathspey, The', 3026, 3, 4, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (1796, NULL, '2012-01-20 12:55:11.392994+00', 'Lassie What Mair Wad ye Ha''e?', 2054, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1797, NULL, '2012-01-20 12:55:11.398523+00', 'Miss Nancy Frowns', 2054, 2, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1798, NULL, '2012-01-20 12:55:11.404028+00', 'Triumph, The', 2054, 1, 8, 24, 9999, 19, 0, 0, '');
INSERT INTO 'recording' VALUES (1799, NULL, '2012-01-20 12:55:11.409515+00', 'Mary Branigan''s Delight', 2054, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1800, NULL, '2012-01-20 12:55:11.415004+00', 'Fight About the Fireside', 2054, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1801, NULL, '2012-01-20 12:55:11.420494+00', 'King''s Rant, The', 2054, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1802, NULL, '2012-01-20 12:55:11.426008+00', 'Miss Catherine Allan', 2054, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1803, NULL, '2012-01-20 12:55:11.431524+00', 'Sauchie Haugh', 2054, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1804, NULL, '2012-01-20 12:55:11.437055+00', 'Strathclair', 2054, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (4230, NULL, '2012-01-20 12:55:25.499905+00', 'Wood Duck, The', 2179, 5, 0, 0, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (4231, NULL, '2012-01-20 12:55:25.506497+00', 'Saint Andrew''s Fair', 2179, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (4232, NULL, '2012-01-20 12:55:25.512923+00', 'Twelvesome Reel, The', 2179, 1, 6, 32, 9999, NULL, 222, 0, '');
INSERT INTO 'recording' VALUES (4233, NULL, '2012-01-20 12:55:25.519198+00', 'Wisp of Thistle', 2179, 3, 8, 32, 9999, NULL, 519, 0, '');
INSERT INTO 'recording' VALUES (4234, NULL, '2012-01-20 12:55:25.525417+00', 'Quarries'' Jig', 2179, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (4235, NULL, '2012-01-20 12:55:25.531825+00', 'Blooms of Bon Accord', 2179, 1, 4, 32, 9999, NULL, 151, 1, '');
INSERT INTO 'recording' VALUES (4236, NULL, '2012-01-20 12:55:25.538075+00', 'Merry Reapers, The', 2179, 2, 8, 24, 9999, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (4237, NULL, '2012-01-20 12:55:25.544657+00', 'Anniversary Reel', 2179, 1, 4, 32, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (4238, NULL, '2012-01-20 12:55:25.551015+00', 'Laird of Milton''s Daughter, The', 2179, 2, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (4239, NULL, '2012-01-20 12:55:25.557358+00', 'Button Boy, The', 2179, 1, 8, 32, 9999, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (4240, NULL, '2012-01-20 12:55:25.563603+00', 'Miss Gibson''s Strathspey', 2179, 3, 8, 32, 9999, NULL, 522, 0, '');
INSERT INTO 'recording' VALUES (4241, NULL, '2012-01-20 12:55:25.56985+00', 'Deil amang the Tailors, The', 2179, 1, 8, 32, 9999, NULL, 298, 0, '');
INSERT INTO 'recording' VALUES (4242, NULL, '2012-01-20 12:55:25.576329+00', 'Dashing White Sergeant, The', 2430, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4243, NULL, '2012-01-20 12:55:25.582589+00', 'Duke of Perth', 2430, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4244, NULL, '2012-01-20 12:55:25.588956+00', 'Bonnie Anne', 2430, 2, 0, 96, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4245, NULL, '2012-01-20 12:55:25.596271+00', 'Madge Wildfire''s Strathspey', 2430, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4246, NULL, '2012-01-20 12:55:25.602608+00', 'Maxwell''s Rant', 2430, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4247, NULL, '2012-01-20 12:55:25.608911+00', 'Gay Gordons', 2429, 11, 10, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4248, NULL, '2012-01-20 12:55:25.615208+00', 'Strip the Willow', 2429, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4249, NULL, '2012-01-20 12:55:25.621642+00', 'Highland Schottische', 2429, 3, 0, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9178, '2013-01-06 18:40:20.84521+00', '2013-01-06 18:40:20.845221+00', 'Jigs 6x48', 2029, 2, 6, 48, 9999, NULL, 312, 0, '');
INSERT INTO 'recording' VALUES (1813, NULL, '2012-01-20 12:55:11.486633+00', 'Kendall''s Hornpipe', 3040, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1814, NULL, '2012-01-20 12:55:11.492159+00', 'Seton''s Ceilidh Band', 3040, 2, 4, 64, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1816, NULL, '2012-01-20 12:55:11.503152+00', 'Irish Rover, The', 3040, 1, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1817, NULL, '2012-01-20 12:55:11.508641+00', 'Falls of Rogie, The', 3040, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1818, NULL, '2012-01-20 12:55:11.514149+00', 'Mrs Stewart of Fasnacloich', 3040, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1821, NULL, '2012-01-20 12:55:11.530756+00', 'Miss Ogilvie''s Fancy', 3040, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1822, NULL, '2012-01-20 12:55:11.536255+00', 'Silver Tassie, The', 3040, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1823, NULL, '2012-01-20 12:55:11.541764+00', 'Reels', 1502, 1, 8, 40, 9999, 14, 0, 0, '');
INSERT INTO 'recording' VALUES (1824, NULL, '2012-01-20 12:55:11.547262+00', 'Founder''s Jig', 1502, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1825, NULL, '2012-01-20 12:55:11.55277+00', 'Strathcare', 1502, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1826, NULL, '2012-01-20 12:55:11.558271+00', 'Whisky Association Reel, The', 1502, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1827, NULL, '2012-01-20 12:55:11.563752+00', 'Scots Guards, The', 1502, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1828, NULL, '2012-01-20 12:55:11.569238+00', '8th Battalion - The Royal Scots', 1502, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1829, NULL, '2012-01-20 12:55:11.574966+00', 'Duns 500', 1502, 3, 0, 64, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1830, NULL, '2012-01-20 12:55:11.58046+00', 'Campbell of Laphroaig', 1502, 4, 8, 32, 1, 23, 0, 0, '');
INSERT INTO 'recording' VALUES (1832, NULL, '2012-01-20 12:55:11.591469+00', 'Peggy''s Joy', 1502, 2, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1833, NULL, '2012-01-20 12:55:11.596972+00', 'Ruby Strathspey, The', 1502, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1834, NULL, '2012-01-20 12:55:11.602469+00', 'Saint Ebba''s Strand', 1502, 1, 4, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (1835, NULL, '2012-01-20 12:55:11.60796+00', 'Millerton Brig', 1502, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1836, NULL, '2012-01-20 12:55:11.613462+00', 'Border Bridge, The', 1502, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1837, NULL, '2012-01-20 12:55:11.618998+00', 'Scots Gate, The', 1502, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1838, NULL, '2012-01-20 12:55:11.62383+00', 'Canadian Barn Dance', 2038, 11, 11, 8, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (1839, NULL, '2012-01-20 12:55:11.628643+00', 'Gay Gordons', 2038, 11, 8, 16, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (1840, NULL, '2012-01-20 12:55:11.633428+00', 'Highland Schottische', 2038, 3, 10, 8, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (1841, NULL, '2012-01-20 12:55:11.638226+00', 'Military Two-Step', 2038, 11, 8, 16, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (1842, NULL, '2012-01-20 12:55:11.643707+00', 'Weaver, The', 2038, 2, 8, 32, 9999, 1, 260, 0, '');
INSERT INTO 'recording' VALUES (1843, NULL, '2012-01-20 12:55:11.648622+00', 'MacDonald of Sleat', 2038, 2, 0, 120, 9999, NULL, 126, 0, '');
INSERT INTO 'recording' VALUES (1844, NULL, '2012-01-20 12:55:11.654123+00', 'Queen''s Argyll''s, The', 2038, 1, 4, 32, 9999, 1, 138, 0, '');
INSERT INTO 'recording' VALUES (1845, NULL, '2012-01-20 12:55:11.659835+00', 'Argyll''s Farewell to Stirling', 2038, 1, 4, 40, 9999, 38, 171, 0, '');
INSERT INTO 'recording' VALUES (1846, NULL, '2012-01-20 12:55:11.665465+00', 'Lady Sophia Anne of Bute', 2038, 1, 4, 48, 9999, 4, 203, 0, '');
INSERT INTO 'recording' VALUES (1847, NULL, '2012-01-20 12:55:11.670299+00', 'McLeod of Harris', 2038, 1, 0, 144, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (1848, NULL, '2012-01-20 12:55:11.675829+00', 'Balmoral Strathspey, The', 2038, 3, 4, 32, 9999, 5, 238, 0, '');
INSERT INTO 'recording' VALUES (1849, NULL, '2012-01-20 12:55:11.680727+00', 'Scottish Waltz', 2038, 5, 0, 0, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (1850, NULL, '2012-01-20 12:55:11.686237+00', 'Edinburgh Castle Reel, The', 2047, 1, 8, 32, 9999, 5, 275, 0, '');
INSERT INTO 'recording' VALUES (1851, NULL, '2012-01-20 12:55:11.691807+00', 'Roaring Jelly', 2047, 2, 8, 32, 9999, 5, 265, 0, '');
INSERT INTO 'recording' VALUES (4250, NULL, '2012-01-20 12:55:25.627927+00', 'Waltz Country Dance', 2429, 5, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4251, NULL, '2012-01-20 12:55:25.634244+00', 'Drummer, The', 2429, 1, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4257, NULL, '2012-01-20 12:55:25.672519+00', 'Shetland Reels', 2177, 1, 7, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1808, NULL, '2022-08-20 15:59:30.657186+00', 'Calver Lodge', 3037, 1, 8, 24, 9999, 16, 202, 0, '');
INSERT INTO 'recording' VALUES (1807, NULL, '2022-08-20 15:58:42.064701+00', 'Peggy''s Wedding', 3037, 2, 4, 64, 9999, 3, 264, 0, '');
INSERT INTO 'recording' VALUES (1812, NULL, '2022-08-20 15:58:49.964156+00', 'Bonnie Kate of Aberdeen', 3037, 3, 8, 40, 9999, 6, 585, 0, '');
INSERT INTO 'recording' VALUES (1810, NULL, '2022-08-20 16:00:16.646869+00', 'Drummer, The', 3037, 1, 8, 48, 9999, 4, 398, 0, '');
INSERT INTO 'recording' VALUES (1806, NULL, '2022-08-20 16:01:09.193578+00', 'Bob Sanders', 3037, 2, 8, 40, 9999, 14, 329, 0, '');
INSERT INTO 'recording' VALUES (1811, NULL, '2022-08-20 16:02:04.291593+00', 'Stirling Castle', 3037, 3, 4, 32, 9999, 5, 236, 0, '');
INSERT INTO 'recording' VALUES (1809, NULL, '2022-08-20 16:02:35.739473+00', 'Galloway House', 3037, 1, 8, 32, 9999, 1, 262, 0, '');
INSERT INTO 'recording' VALUES (4258, NULL, '2012-01-20 12:55:25.677311+00', 'Pipe Marches', 2177, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4259, NULL, '2012-01-20 12:55:25.682137+00', 'Set of Jigs', 2177, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4260, NULL, '2012-01-20 12:55:25.686944+00', 'Shetland Waltzes', 2177, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4261, NULL, '2012-01-20 12:55:25.691732+00', 'Norwegian Waltz', 2177, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4262, NULL, '2012-01-20 12:55:25.6965+00', 'Polka', 2177, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4263, NULL, '2012-01-20 12:55:25.701276+00', 'Shetland Marches', 2177, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4264, NULL, '2012-01-20 12:55:25.706087+00', 'Shetland Reels', 2177, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4265, NULL, '2012-01-20 12:55:25.710877+00', 'Waltzes', 2177, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4266, NULL, '2012-01-20 12:55:25.715667+00', 'Selection of Marches', 2177, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4267, NULL, '2012-01-20 12:55:25.720448+00', 'Fiddle Solo', 2177, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4268, NULL, '2012-01-20 12:55:25.725221+00', 'Set of Reels', 2177, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4269, NULL, '2012-01-20 12:55:25.730011+00', 'Pipe Marches', 2177, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9179, '2013-01-06 18:41:57.33707+00', '2013-01-06 18:41:57.33708+00', 'Reels 2x48', 2029, 1, 2, 48, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (1852, NULL, '2012-01-20 12:55:11.6973+00', 'John McAlpin', 2047, 3, 8, 32, 9999, 5, 498, 0, '');
INSERT INTO 'recording' VALUES (1853, NULL, '2012-01-20 12:55:11.7029+00', 'J.B. Milne', 2047, 1, 8, 32, 9999, 10, 273, 0, '');
INSERT INTO 'recording' VALUES (1854, NULL, '2012-01-20 12:55:11.708403+00', 'Starry-Eyed Lassie, The', 2047, 2, 8, 32, 9999, 3, 267, 0, '');
INSERT INTO 'recording' VALUES (1856, NULL, '2012-01-20 12:55:11.719383+00', 'Luckenbooth Brooch, The', 2047, 2, 8, 32, 9999, 1, 266, 0, '');
INSERT INTO 'recording' VALUES (1858, NULL, '2012-01-20 12:55:11.730385+00', 'Australian Ladies, The', 2047, 1, 8, 32, 9999, 1, 270, 0, '');
INSERT INTO 'recording' VALUES (1867, NULL, '2012-01-20 12:55:11.791594+00', 'Lord Rosslyn''s Fancy', 3026, 2, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1868, NULL, '2012-01-20 12:55:11.798684+00', 'White Heather Jig, The', 3026, 2, 4, 40, 9999, 15, 0, 0, '');
INSERT INTO 'recording' VALUES (1869, NULL, '2012-01-20 12:55:11.80495+00', 'Medley', 3026, 4, 0, 64, 5, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1870, NULL, '2012-01-20 12:55:11.812028+00', 'Irish Rover, The', 3026, 1, 8, 32, 9999, 3, 0, 0, '');
INSERT INTO 'recording' VALUES (1871, NULL, '2012-01-20 12:55:11.819135+00', 'Lord MacLay''s Reel', 3026, 1, 4, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (1872, NULL, '2012-01-20 12:55:11.826217+00', 'Red House', 3026, 1, 8, 40, 9999, 39, 0, 0, '');
INSERT INTO 'recording' VALUES (1874, NULL, '2012-01-20 12:55:11.840454+00', 'Letham Ladies', 3026, 3, 4, 40, 9999, 40, 0, 0, '');
INSERT INTO 'recording' VALUES (1875, NULL, '2012-01-20 12:55:11.846728+00', 'Robertson Rant, The', 3026, 3, 0, 80, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1876, NULL, '2012-01-20 12:55:11.852972+00', 'Waltz Country Dance', 3026, 5, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1877, NULL, '2012-01-20 12:55:11.860089+00', 'Frisky, The', 3026, 2, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1819, NULL, '2021-06-20 22:25:28.160668+00', 'Whippety Stourie', 3040, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1855, NULL, '2021-06-21 21:40:02.7042+00', 'Anniversary, The', 2047, 4, 4, 64, 5, 5, 392, 0, '');
INSERT INTO 'recording' VALUES (1815, NULL, '2021-07-02 20:17:28.79038+00', 'Silver Rose, The', 3040, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1820, NULL, '2021-07-03 12:25:36.298803+00', 'Sleepy Maggie', 3040, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (4254, NULL, '2014-08-05 20:46:01.681242+00', 'Slow Air, Strathspey and Reel', 3037, 98, 0, 0, 9999, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (4253, NULL, '2014-08-05 20:43:38.494286+00', 'Doreen''s Waltz', 3037, 5, 3, 32, 9999, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (4255, NULL, '2014-08-05 20:46:28.76355+00', 'Gay Gordons', 3037, 11, 0, 16, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (4256, NULL, '2014-08-05 20:47:20.786117+00', 'Duran Ranger, The', 3037, 1, 4, 32, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (1878, NULL, '2012-01-20 12:55:11.867206+00', 'Leith Country Dance', 2053, 2, 8, 32, 9999, 5, 274, 0, '');
INSERT INTO 'recording' VALUES (1879, NULL, '2012-01-20 12:55:11.874688+00', 'Machine Without Horses, The', 2053, 2, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (1880, NULL, '2012-01-20 12:55:11.881782+00', 'Flowers of Edinburgh, The', 2053, 1, 8, 32, 9999, 1, 268, 0, '');
INSERT INTO 'recording' VALUES (1881, NULL, '2012-01-20 12:55:11.889024+00', 'General Stuart''s Reel', 2053, 1, 8, 32, 9999, 5, 270, 0, '');
INSERT INTO 'recording' VALUES (1882, NULL, '2012-01-20 12:55:11.896141+00', 'Montgomeries'' Rant, The', 2053, 1, 8, 32, 9999, 5, 275, 0, '');
INSERT INTO 'recording' VALUES (1883, NULL, '2012-01-20 12:55:11.903233+00', 'Hamilton Rant, The', 2053, 1, 8, 48, 9999, 4, 408, 0, '');
INSERT INTO 'recording' VALUES (1884, NULL, '2012-01-20 12:55:11.910337+00', 'Lochiel''s Rant', 2053, 3, 8, 32, 9999, 5, 480, 0, '');
INSERT INTO 'recording' VALUES (1885, NULL, '2012-01-20 12:55:11.917428+00', 'Up in the Air', 2053, 3, 8, 32, 9999, 5, 485, 0, '');
INSERT INTO 'recording' VALUES (1886, NULL, '2012-01-20 12:55:11.923703+00', 'Scottish Waltz', 2053, 5, 0, 0, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (1887, NULL, '2012-01-20 12:55:11.930781+00', 'Duke of Atholl''s Reel, The', 2053, 2, 8, 32, 9999, 1, 271, 0, '');
INSERT INTO 'recording' VALUES (1888, NULL, '2012-01-20 12:55:11.937858+00', 'Isle, The', 2053, 2, 8, 32, 9999, 1, 268, 0, '');
INSERT INTO 'recording' VALUES (1889, NULL, '2012-01-20 12:55:11.944948+00', 'Corn Rigs', 2053, 1, 8, 32, 9999, 1, 270, 0, '');
INSERT INTO 'recording' VALUES (1890, NULL, '2012-01-20 12:55:11.952037+00', 'Mrs MacLeod of Raasay', 2053, 1, 8, 32, 9999, 1, 268, 0, '');
INSERT INTO 'recording' VALUES (1891, NULL, '2012-01-20 12:55:11.959129+00', 'Reel of the 51st Division, The', 2053, 1, 8, 32, 9999, 1, 266, 0, '');
INSERT INTO 'recording' VALUES (4270, NULL, '2012-01-20 12:55:25.734798+00', 'Strathspeys', 2177, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4271, NULL, '2012-01-20 12:55:25.739593+00', 'Up-Helley-Aa', 2177, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4273, NULL, '2012-01-20 12:55:25.749406+00', 'Grand March, The', 3061, 11, 0, 0, 9999, NULL, 127, 0, '');
INSERT INTO 'recording' VALUES (4274, NULL, '2012-01-20 12:55:25.754229+00', 'Military Two Step', 3061, 11, 0, 16, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (4275, NULL, '2012-01-20 12:55:25.759014+00', 'Gay Gordons', 3061, 11, 0, 16, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (4276, NULL, '2012-01-20 12:55:25.763819+00', 'Duke of Perth', 3061, 1, 6, 32, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (4277, NULL, '2012-01-20 12:55:25.768616+00', 'Fiddle Solo', 3061, 98, 0, 0, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (4278, NULL, '2012-01-20 12:55:25.773397+00', 'Va, La', 3061, 99, 0, 0, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (4279, NULL, '2012-01-20 12:55:25.782119+00', 'Eva Three Step', 3061, 11, 0, 16, 9999, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (4280, NULL, '2012-01-20 12:55:25.791808+00', 'Swedish Masquerade', 3061, 4, 8, 32, 33, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (4281, NULL, '2012-01-20 12:55:25.798082+00', 'Virginia Reel', 3061, 1, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (4282, NULL, '2012-01-20 12:55:25.80434+00', 'Waltz Country Dance', 3061, 5, 4, 40, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (4283, NULL, '2012-01-20 12:55:25.81059+00', 'Pride Of Erin Waltz', 3061, 5, 0, 32, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (4284, NULL, '2012-01-20 12:55:25.816824+00', 'Mississippi Dip', 3061, 50, 0, 16, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (4285, NULL, '2012-01-20 12:55:25.823118+00', 'Strip the Willow', 3061, 2, 6, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (4286, NULL, '2012-01-20 12:55:25.82952+00', 'Melodeon Solo', 3061, 98, 0, 0, 9999, NULL, 100, 0, '');
INSERT INTO 'recording' VALUES (4287, NULL, '2012-01-20 12:55:25.83722+00', 'Victory Waltz', 3061, 5, 0, 0, 9999, NULL, 236, 0, '');
INSERT INTO 'recording' VALUES (4288, NULL, '2012-01-20 12:55:25.843492+00', 'Bluebell Polka', 3061, 13, 0, 16, 9999, NULL, 99, 0, '');
INSERT INTO 'recording' VALUES (4289, NULL, '2012-01-20 12:55:25.849723+00', 'Military Two-Step', 3061, 11, 0, 16, 9999, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (4290, NULL, '2012-01-20 12:55:25.855963+00', 'Saint Bernard''s Waltz', 3061, 5, 0, 16, 9999, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (9180, '2013-01-06 18:43:35.896547+00', '2013-01-06 18:43:35.896557+00', 'Reels 3x48', 2029, 1, 3, 48, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (1892, NULL, '2012-01-20 12:55:11.966248+00', 'White Cockade, The', 2053, 1, 8, 32, 9999, 1, 267, 0, '');
INSERT INTO 'recording' VALUES (1893, NULL, '2012-01-20 12:55:11.973631+00', 'Braes of Tulliemet, The', 2053, 3, 8, 32, 9999, 5, 494, 0, '');
INSERT INTO 'recording' VALUES (1865, NULL, '2022-08-20 22:35:54.003681+00', 'Braes of Tulliemet, The', 2231, 3, 8, 32, 9999, 5, 467, 0, '');
INSERT INTO 'recording' VALUES (1860, NULL, '2022-08-20 22:35:24.045086+00', 'Tillietudlum', 2231, 2, 8, 32, 9999, 1, 287, 0, '');
INSERT INTO 'recording' VALUES (1863, NULL, '2022-08-20 22:36:26.101268+00', 'Lass o'' Livingstone, The', 2231, 1, 8, 32, 9999, 1, 283, 0, '');
INSERT INTO 'recording' VALUES (1859, NULL, '2022-08-20 22:37:06.743092+00', 'Scottish Fiddle Jig, The', 2231, 2, 8, 32, 9999, 1, 294, 0, '');
INSERT INTO 'recording' VALUES (1862, NULL, '2022-08-20 22:37:26.76035+00', 'Caber Feidh', 2231, 1, 8, 32, 9999, 1, 283, 0, '');
INSERT INTO 'recording' VALUES (1866, NULL, '2022-08-20 22:37:50.099675+00', 'Mrs Grant''s Fancy', 2231, 3, 8, 32, 9999, 5, 471, 0, '');
INSERT INTO 'recording' VALUES (1861, NULL, '2022-08-20 22:38:09.204373+00', 'Deuk''s Dang Ower my Daddie O'', The', 2231, 2, 8, 40, 9999, 6, 357, 0, '');
INSERT INTO 'recording' VALUES (1873, NULL, '2023-01-17 11:54:36.972423+00', 'Blue Mess Jacket, The', 3026, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1894, NULL, '2012-01-20 12:55:11.98074+00', 'Maggie Lauder', 2053, 3, 8, 32, 9999, 5, 495, 0, '');
INSERT INTO 'recording' VALUES (1895, NULL, '2012-01-20 12:55:11.987841+00', 'Gay Gordons', 3040, 11, 3, 16, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1896, NULL, '2012-01-20 12:55:11.994955+00', 'Canadian Barn Dance', 3040, 11, 4, 16, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1897, NULL, '2012-01-20 12:55:12.002066+00', 'Highland Schottische', 3040, 3, 16, 8, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1900, NULL, '2012-01-20 12:55:12.022624+00', 'Glayva', 3040, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1901, NULL, '2012-01-20 12:55:12.029703+00', 'Rakish Highlandman, The', 3040, 2, 4, 40, 9999, 14, 0, 0, '');
INSERT INTO 'recording' VALUES (1902, NULL, '2012-01-20 12:55:12.035995+00', 'Polka', 3040, 13, 0, 96, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1903, NULL, '2012-01-20 12:55:12.043108+00', 'College Hornpipe, The', 3040, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1904, NULL, '2012-01-20 12:55:12.050256+00', 'Dashing White Sergeant, The', 3040, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1905, NULL, '2012-01-20 12:55:12.057337+00', 'Galloway House', 3040, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1906, NULL, '2012-01-20 12:55:12.063624+00', 'Continental Waltz', 3040, 5, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1907, NULL, '2012-01-20 12:55:12.069889+00', 'Gaelic Waltz', 3040, 5, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1908, NULL, '2012-01-20 12:55:12.076161+00', 'Scottish Waltz', 3040, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1909, NULL, '2012-01-20 12:55:12.083267+00', 'Peat Fire Flame, The', 3040, 1, 8, 40, 9999, 39, 304, 0, '');
INSERT INTO 'recording' VALUES (1910, NULL, '2012-01-20 12:55:12.090365+00', 'Baldovan Square, The', 3040, 3, 0, 96, 9999, 5, 183, 0, '');
INSERT INTO 'recording' VALUES (1911, NULL, '2012-01-20 12:55:12.097904+00', 'Prince Charlie''s Quickstep', 3040, 2, 4, 48, 9999, 11, 210, 0, '');
INSERT INTO 'recording' VALUES (1912, NULL, '2012-01-20 12:55:12.104998+00', 'Black Black Oil, The', 3040, 1, 5, 32, 9999, 1, 177, 0, '');
INSERT INTO 'recording' VALUES (1913, NULL, '2012-01-20 12:55:12.112104+00', 'Silver Glen, The', 3040, 3, 4, 32, 9999, 1, 244, 0, '');
INSERT INTO 'recording' VALUES (1915, NULL, '2012-01-20 12:55:12.126428+00', 'Polharrow Burn', 3040, 1, 5, 32, 9999, 1, 175, 0, '');
INSERT INTO 'recording' VALUES (1916, NULL, '2012-01-20 12:55:12.13353+00', 'Gearasdan, An', 3040, 2, 8, 32, 9999, 1, 281, 0, '');
INSERT INTO 'recording' VALUES (1917, NULL, '2012-01-20 12:55:12.140654+00', 'Clints of Dromore, The', 3040, 1, 4, 32, 9999, 1, 147, 0, '');
INSERT INTO 'recording' VALUES (1918, NULL, '2012-01-20 12:55:12.147787+00', 'Glencoe', 3040, 3, 4, 32, 9999, 5, 240, 0, '');
INSERT INTO 'recording' VALUES (1920, NULL, '2012-01-20 12:55:12.162008+00', 'Company at the Manor', 3040, 2, 4, 32, 9999, 1, 146, 0, '');
INSERT INTO 'recording' VALUES (1921, NULL, '2012-01-20 12:55:12.169106+00', 'Deveron Reel, The', 3040, 1, 4, 40, 9999, 14, 174, 0, '');
INSERT INTO 'recording' VALUES (4291, NULL, '2012-01-20 12:55:25.862224+00', 'Continental Waltz', 3025, 5, 0, 0, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (4292, NULL, '2012-01-20 12:55:25.868445+00', 'Selection of Jigs', 3025, 2, 6, 32, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (4293, NULL, '2012-01-20 12:55:25.875113+00', 'Pipe Medley', 3025, 98, 0, 0, 9999, NULL, 240, 0, '');
INSERT INTO 'recording' VALUES (4294, NULL, '2012-01-20 12:55:25.881342+00', 'Continental Waltz', 3025, 5, 0, 0, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (4295, NULL, '2012-01-20 12:55:25.890713+00', 'Selection of Reels', 3025, 1, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (4296, NULL, '2012-01-20 12:55:25.896951+00', 'Gay Gordons', 3025, 11, 0, 16, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (4297, NULL, '2012-01-20 12:55:25.903214+00', 'Hornpipe, Jig and Hornpipe', 3025, 4, 0, 0, 9999, NULL, 232, 0, '');
INSERT INTO 'recording' VALUES (4298, NULL, '2012-01-20 12:55:25.909476+00', 'Gaelic Waltzes', 2062, 5, 0, 0, 9999, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (4299, NULL, '2012-01-20 12:55:25.91575+00', 'Hornpipe Selection', 2451, 1, 4, 32, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (4300, NULL, '2012-01-20 12:55:25.922032+00', 'Peat Fire Flame', 2452, 1, 2, 40, 9999, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (4301, NULL, '2012-01-20 12:55:25.928256+00', 'Strathspey & Reel', 2062, 4, 0, 128, 2, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (4302, NULL, '2012-01-20 12:55:25.936194+00', 'Medley', 2062, 4, 0, 112, 19, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (4303, NULL, '2012-01-20 12:55:25.942457+00', 'March, Strathspey and Reel', 2451, 4, 0, 0, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (4304, NULL, '2012-01-20 12:55:25.948682+00', 'Petronella', 3069, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1919, NULL, '2021-08-20 13:43:41.047591+00', 'Loch Torridon', 3040, 1, 8, 32, 9999, 1, 281, 0, '');
INSERT INTO 'recording' VALUES (1899, NULL, '2021-11-26 22:50:04.355996+00', 'Boston Two Step', 3040, 50, 8, 16, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (4305, NULL, '2012-01-20 12:55:25.954933+00', 'Highland Schottische', 3069, 3, 32, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4306, NULL, '2012-01-20 12:55:25.961159+00', 'Gay Gordons', 3069, 11, 10, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4307, NULL, '2012-01-20 12:55:25.976914+00', 'Waltz Medley', 3069, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4308, NULL, '2012-01-20 12:55:25.984181+00', 'Auld Maid, The', 3069, 1, 0, 172, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4309, NULL, '2012-01-20 12:55:25.990451+00', 'Honeymoon, The', 3069, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4310, NULL, '2012-01-20 12:55:25.996682+00', 'Military Two-Step', 3069, 11, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1926, NULL, '2012-03-06 12:52:21.773863+00', 'Last of the Lairds, The', 2057, 2, 4, 32, 9999, 1, 137, 0, '');
INSERT INTO 'recording' VALUES (1928, NULL, '2012-03-06 12:53:17.440454+00', 'Party Polka', 2057, 13, 0, 0, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (1925, NULL, '2012-03-06 12:55:00.785554+00', 'Eva Three Step', 2057, 11, 4, 16, 9999, 1, 151, 0, '');
INSERT INTO 'recording' VALUES (1922, NULL, '2012-03-06 12:56:15.979099+00', 'Boston Two Step', 2057, 50, 0, 16, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (1923, NULL, '2012-03-06 12:56:46.699796+00', 'Gay Gordons', 2057, 11, 0, 16, 9999, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (1929, NULL, '2012-03-06 12:57:39.398784+00', 'Fireside Reel, The', 2057, 1, 4, 32, 9999, 1, 144, 0, '');
INSERT INTO 'recording' VALUES (1924, NULL, '2012-03-06 12:59:14.058997+00', 'Highland Schottische', 2057, 3, 0, 8, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (1927, NULL, '2012-03-06 13:00:31.682922+00', 'Ian Powrie''s Farewell to Auchterarder', 2057, 2, 0, 128, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (1931, NULL, '2012-03-06 13:01:26.620745+00', 'Dinky One Step', 2057, 1, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (1930, NULL, '2012-03-06 13:02:08.069821+00', 'Dashing White Sergeant, The', 2057, 1, 6, 32, 9999, 1, 210, 0, '');
INSERT INTO 'recording' VALUES (9181, '2013-01-06 18:46:19.885111+00', '2013-01-06 18:46:19.885121+00', 'Reels 5x48', 2029, 1, 5, 48, 9999, NULL, 254, 0, '');
INSERT INTO 'recording' VALUES (1932, NULL, '2012-01-20 12:55:12.241085+00', 'Doris Waltz, The', 3026, 5, 4, 32, 9999, NULL, 228, 0, '');
INSERT INTO 'recording' VALUES (1936, NULL, '2012-01-20 12:55:12.262169+00', 'Hornpipes', 3008, 1, 0, 0, 9999, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (1937, NULL, '2012-01-20 12:55:12.266998+00', 'Shepherd''s Crook, The', 3008, 3, 0, 72, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (1938, NULL, '2012-01-20 12:55:12.271815+00', 'Accordion Duet', 3008, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1939, NULL, '2012-01-20 12:55:12.279118+00', 'Joan''s Jig', 3008, 2, 4, 32, 9999, 1, 127, 0, '');
INSERT INTO 'recording' VALUES (1940, NULL, '2012-01-20 12:55:12.284646+00', 'Tarry a While', 3008, 2, 4, 32, 9999, 1, 127, 0, '');
INSERT INTO 'recording' VALUES (1941, NULL, '2012-01-20 12:55:12.290152+00', 'Argyll''s Fancy', 3008, 2, 4, 48, 9999, 4, 187, 0, '');
INSERT INTO 'recording' VALUES (1942, NULL, '2012-01-20 12:55:12.295665+00', 'Shiftin'' Bobbins', 3008, 1, 4, 32, 9999, 1, 128, 0, '');
INSERT INTO 'recording' VALUES (1943, NULL, '2012-01-20 12:55:12.301147+00', 'Dram o'' Dalwhinnie', 3008, 1, 4, 32, 9999, 5, 128, 0, '');
INSERT INTO 'recording' VALUES (1944, NULL, '2012-01-20 12:55:12.306626+00', 'Dashing White Sergeant, The', 3008, 1, 5, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1945, NULL, '2012-01-20 12:55:12.312109+00', 'Flowers of Edinburgh, The', 3008, 1, 8, 32, 9999, 1, 248, 0, '');
INSERT INTO 'recording' VALUES (1946, NULL, '2012-01-20 12:55:12.31693+00', 'Elizabeth''s Waltz', 3008, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1947, NULL, '2012-01-20 12:55:12.321725+00', 'Pride of Erin Waltz', 3008, 5, 0, 32, 9999, NULL, 243, 0, '');
INSERT INTO 'recording' VALUES (1948, NULL, '2012-01-20 12:55:12.327185+00', 'Miss Mary Douglas', 2132, 2, 8, 48, 9999, 4, 0, 0, '');
INSERT INTO 'recording' VALUES (1949, NULL, '2012-01-20 12:55:12.332684+00', 'Captain McBride''s Hornpipe', 2132, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1950, NULL, '2012-01-20 12:55:12.33822+00', 'Loch Leven Castle', 1491, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1951, NULL, '2012-01-20 12:55:12.343726+00', 'Kingussie Flower', 1491, 1, 8, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (1952, NULL, '2012-01-20 12:55:12.349203+00', 'Braes of Breadalbane, The', 1491, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1953, NULL, '2012-01-20 12:55:12.354696+00', 'Lea Rig, The', 1491, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1954, NULL, '2012-01-20 12:55:12.360168+00', 'Gay Gordons', 3009, 11, 5, 16, 9999, 1, 173, 0, '');
INSERT INTO 'recording' VALUES (1955, NULL, '2012-01-20 12:55:12.365647+00', 'Duke of Atholl''s Reel, The', 3009, 2, 8, 32, 9999, 1, 276, 0, '');
INSERT INTO 'recording' VALUES (1957, NULL, '2012-01-20 12:55:12.376154+00', 'Holyrood House', 3009, 2, 4, 48, 9999, 4, 207, 0, '');
INSERT INTO 'recording' VALUES (1959, NULL, '2012-01-20 12:55:12.385818+00', 'MacDonald of Sleat', 3009, 2, 0, 120, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (1960, NULL, '2012-01-20 12:55:12.39127+00', 'Schiehallion', 3009, 4, 0, 128, 2, 5, 182, 0, '');
INSERT INTO 'recording' VALUES (1962, NULL, '2012-01-20 12:55:12.40161+00', 'Dashing White Sergeant, The', 3009, 1, 6, 32, 9999, 1, 201, 0, '');
INSERT INTO 'recording' VALUES (1963, NULL, '2012-01-20 12:55:12.407103+00', 'Deil amang the Tailors, The', 3009, 1, 8, 32, 9999, 1, 260, 0, '');
INSERT INTO 'recording' VALUES (1965, NULL, '2012-01-20 12:55:12.417361+00', 'Duke and Duchess of Edinburgh, The', 3009, 1, 8, 40, 9999, 6, 328, 0, '');
INSERT INTO 'recording' VALUES (1966, NULL, '2012-01-20 12:55:12.422859+00', 'Mairi''s Wedding', 3009, 1, 8, 40, 9999, 6, 324, 0, '');
INSERT INTO 'recording' VALUES (1971, NULL, '2012-01-20 12:55:12.448919+00', 'Ship in Full Sail', 3014, 2, 5, 32, 9999, 1, 170, 0, '');
INSERT INTO 'recording' VALUES (1972, NULL, '2012-01-20 12:55:12.454412+00', 'Salute to Bath', 3014, 1, 3, 40, 9999, 14, 130, 0, '');
INSERT INTO 'recording' VALUES (4311, NULL, '2012-01-20 12:55:26.002953+00', 'Gay Gordons', 3069, 11, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4312, NULL, '2012-01-20 12:55:26.018104+00', 'Reel of the 51st Division, The', 3069, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4313, NULL, '2012-01-20 12:55:26.024862+00', 'Last of the Lairds, The', 3069, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4314, NULL, '2012-01-20 12:55:26.029817+00', 'Hamilton Rant, The', 3069, 1, 0, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4315, NULL, '2012-01-20 12:55:26.034682+00', 'Jig Selection', 3069, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4316, NULL, '2012-01-20 12:55:26.039602+00', 'Bethena', 2136, 98, 0, 0, 9999, NULL, 300, 0, '');
INSERT INTO 'recording' VALUES (4317, NULL, '2012-01-20 12:55:26.045793+00', 'Golliwog''s Cakewalk', 2136, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4318, NULL, '2012-01-20 12:55:26.050688+00', 'Memories of Lindsay Ross', 3018, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4319, NULL, '2012-01-20 12:55:26.05553+00', 'Pipe Marches in 2/4 & 6/8 Time', 3018, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4320, NULL, '2012-01-20 12:55:26.069316+00', 'Saint Bernard''s Waltz', 3018, 5, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4322, NULL, '2012-01-20 12:55:26.082413+00', 'Slow Air', 3018, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4323, NULL, '2012-01-20 12:55:26.088858+00', 'Military Two-Step', 3018, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4324, NULL, '2012-01-20 12:55:26.095192+00', 'Modern Waltz', 3018, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4325, NULL, '2012-01-20 12:55:26.101591+00', 'Pigeon Pie', 3018, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4326, NULL, '2012-01-20 12:55:26.107914+00', 'Opening of the Forth Railway Bridge 1890, The', 3018, 4, 0, 64, 5, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4327, NULL, '2012-01-20 12:55:26.114272+00', 'Air', 3018, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4328, NULL, '2012-01-20 12:55:26.1206+00', 'Call of the Pipes, The', 3018, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4329, NULL, '2012-01-20 12:55:26.126858+00', 'Gaelic Waltz', 3018, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4330, NULL, '2012-01-20 12:55:26.1331+00', 'Scandinavian Schottische', 3018, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1958, NULL, '2012-02-11 14:24:30.707041+00', 'Scottish Airs', 2246, 5, 0, 0, 9999, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (1956, NULL, '2012-02-11 14:25:46.197571+00', 'Ladies'' Fancy', 2246, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (1961, NULL, '2012-02-11 14:26:46.523289+00', 'Polkas', 2246, 13, 0, 0, 9999, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (1964, NULL, '2012-02-11 14:27:29.508778+00', 'Retreat Airs', 2246, 98, 0, 0, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (1967, NULL, '2012-02-11 14:29:18.080045+00', 'Irish Hornpipes', 2246, 1, 3, 32, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (1934, NULL, '2012-03-06 12:54:03.637401+00', 'Circle Waltz', 2057, 5, 0, 32, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (1933, NULL, '2012-03-06 12:55:40.669024+00', 'MacDonald of the Isles', 2057, 3, 3, 32, 9999, 5, 182, 0, '');
INSERT INTO 'recording' VALUES (1935, NULL, '2012-03-06 13:00:00.532224+00', 'Pride of Erin', 2057, 5, 0, 32, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (9182, '2013-01-06 18:48:10.081773+00', '2013-01-06 18:48:10.081784+00', 'Reels 6x48', 2029, 1, 6, 48, 9999, NULL, 308, 0, '');
INSERT INTO 'recording' VALUES (1973, NULL, '2012-01-20 12:55:12.459924+00', 'Scotch Mist', 3014, 3, 5, 32, 9999, 5, 301, 0, '');
INSERT INTO 'recording' VALUES (1975, NULL, '2012-01-20 12:55:12.470364+00', 'Slow Air and Pipe Reel', 3014, 98, 0, 0, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (1976, NULL, '2012-01-20 12:55:12.475822+00', 'Aird of Coigach', 3014, 2, 4, 48, 9999, 11, 203, 0, '');
INSERT INTO 'recording' VALUES (1977, NULL, '2012-01-20 12:55:12.481285+00', 'Polharrow Burn', 3014, 1, 5, 32, 9999, 1, 167, 0, '');
INSERT INTO 'recording' VALUES (1974, NULL, '2014-05-16 21:47:48.265454+00', 'Angus MacLeod', 3014, 1, 2, 64, 9999, 1, 137, 0, '');
INSERT INTO 'recording' VALUES (1978, NULL, '2012-01-20 12:55:12.486776+00', 'Belle of Bon Accord, The', 3014, 3, 4, 32, 9999, 1, 236, 0, '');
INSERT INTO 'recording' VALUES (1979, NULL, '2012-01-20 12:55:12.492264+00', 'Equilibrium', 3014, 2, 8, 32, 9999, 1, 263, 0, '');
INSERT INTO 'recording' VALUES (1981, NULL, '2012-01-20 12:55:12.503217+00', 'Weathercock, The', 3014, 2, 4, 32, 9999, 1, 137, 0, '');
INSERT INTO 'recording' VALUES (1982, NULL, '2012-01-20 12:55:12.508717+00', 'Tricorne, The', 3014, 4, 0, 64, 5, 5, 101, 0, '');
INSERT INTO 'recording' VALUES (1983, NULL, '2012-01-20 12:55:12.514197+00', 'Set of Reels', 3002, 1, 4, 32, 9999, 5, 154, 0, '');
INSERT INTO 'recording' VALUES (1987, NULL, '2012-01-20 12:55:12.534891+00', 'Air and March', 3002, 98, 0, 0, 9999, NULL, 233, 0, '');
INSERT INTO 'recording' VALUES (1992, NULL, '2012-01-20 12:55:12.561583+00', 'Slow Airs', 3002, 3, 3, 32, 9999, 1, 220, 0, '');
INSERT INTO 'recording' VALUES (1994, NULL, '2012-01-20 12:55:12.572791+00', 'Oh, Whistle and I''ll Come Tae ye, My Lad', 3024, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1995, NULL, '2012-01-20 12:55:12.578312+00', 'Twizell Bridge', 3024, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (1996, NULL, '2012-01-20 12:55:12.58382+00', 'Lady Catherine Bruce''s Reel', 3024, 2, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1997, NULL, '2012-01-20 12:55:12.589361+00', 'Middling, Thank You', 3024, 2, 8, 40, 9999, 14, 0, 0, '');
INSERT INTO 'recording' VALUES (1999, NULL, '2012-01-20 12:55:12.600372+00', 'Glens of Angus, The', 3024, 1, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2000, NULL, '2012-01-20 12:55:12.605887+00', 'Minard Castle', 3024, 1, 8, 40, 9999, 14, 0, 0, '');
INSERT INTO 'recording' VALUES (2002, NULL, '2012-01-20 12:55:12.655167+00', 'From Scotia''s Shores we''re Noo Awa''', 3024, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2004, NULL, '2012-01-20 12:55:12.665818+00', 'Reel', 2180, 1, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2005, NULL, '2012-01-20 12:55:12.670621+00', 'Directors, The', 3063, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2006, NULL, '2012-01-20 12:55:12.676093+00', 'RIver Cree Jig, The', 3064, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2007, NULL, '2012-01-20 12:55:12.681568+00', 'Modern Scottish Jigs', 1474, 2, 7, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2008, NULL, '2012-01-20 12:55:12.687045+00', 'Peggy''s Wedding', 3037, 2, 8, 64, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2009, NULL, '2012-01-20 12:55:12.692524+00', 'Express, The', 2180, 2, 8, 40, 9999, 14, 0, 0, '');
INSERT INTO 'recording' VALUES (2010, NULL, '2012-01-20 12:55:12.697344+00', 'Bonnie Anne', 3064, 2, 0, 96, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2011, NULL, '2012-01-20 12:55:12.702228+00', 'Dancer''s Delight', 3037, 4, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2012, NULL, '2012-01-20 12:55:12.707043+00', 'Polkas', 1474, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2013, NULL, '2012-01-20 12:55:12.712503+00', 'Crusader''s March', 2062, 11, 0, 0, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2014, NULL, '2012-01-20 12:55:12.718556+00', 'Braes of Breadalbane, The', 2062, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1985, NULL, '2015-10-08 15:36:29.503047+00', 'Set of Jigs', 3002, 2, 4, 32, 9999, 1, 248, 0, '');
INSERT INTO 'recording' VALUES (1986, NULL, '2015-10-08 15:37:59.513933+00', 'Waltzes', 3002, 5, 4, 32, 9999, NULL, 183, 0, '8 bar intro');
INSERT INTO 'recording' VALUES (1988, NULL, '2015-10-08 15:43:29.17953+00', 'Set of Reels', 3002, 1, 8, 32, 9999, 1, 284, 0, '');
INSERT INTO 'recording' VALUES (1990, NULL, '2015-10-08 15:40:25.953272+00', 'Medley', 3002, 4, 0, 0, 9999, NULL, 282, 0, 'W+R+J+R');
INSERT INTO 'recording' VALUES (1989, NULL, '2015-10-08 15:44:16.590766+00', 'Set of Strathspeys', 3002, 3, 4, 32, 9999, 5, 275, 0, '');
INSERT INTO 'recording' VALUES (1991, NULL, '2015-10-08 15:45:10.847107+00', 'Set of Jigs', 3002, 2, 8, 32, 9999, 1, 283, 0, '');
INSERT INTO 'recording' VALUES (1993, NULL, '2015-10-08 15:47:32.879203+00', 'Medley', 3002, 4, 0, 0, 9999, 5, 143, 0, '9/8J+R');
INSERT INTO 'recording' VALUES (1970, NULL, '2019-08-12 07:50:47.531447+00', 'Brigs o'' Ayr, The', 3014, 3, 3, 32, 9999, 5, 184, 0, '');
INSERT INTO 'recording' VALUES (2015, NULL, '2012-01-20 12:55:12.723439+00', 'Saturday Waltz', 3063, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2016, NULL, '2012-01-20 12:55:12.728221+00', 'Gloomy Winter', 2062, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2018, NULL, '2012-01-20 12:55:12.737802+00', 'Skyline of Skye, The', 2062, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2020, NULL, '2012-01-20 12:55:12.748179+00', 'Ian Powrie''s Farewell to Auchterarder', 2062, 2, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2022, NULL, '2012-01-20 12:55:12.758506+00', 'Medley', 2062, 4, 0, 64, 5, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2023, NULL, '2012-01-20 12:55:12.764006+00', 'Duke of Perth', 2062, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (10173, '2018-03-31 10:45:06.085869+00', '2018-03-31 10:45:06.085869+00', 'Posties Jig', 11611, 2, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (2026, NULL, '2012-01-20 12:55:12.779299+00', 'John Carmichael''s Farewell to Scotland', 2062, 3, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4331, NULL, '2012-01-20 12:55:26.139592+00', 'Strip the Willow (6/8)', 3018, 2, 4, 56, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4332, NULL, '2012-01-20 12:55:26.146876+00', 'Gay Gordons', 3018, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4333, NULL, '2012-01-20 12:55:26.154467+00', 'Palais Glide, The', 3018, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4334, NULL, '2012-01-20 12:55:26.160804+00', 'Polka', 3018, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4335, NULL, '2012-01-20 12:55:26.167079+00', 'Gaelic Medley, A', 3018, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4336, NULL, '2012-01-20 12:55:26.173323+00', 'Forth Railway Bridge Centenary Reel, The', 3018, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4337, NULL, '2012-01-20 12:55:26.179679+00', 'Lomond Waltz, The', 2088, 5, 0, 0, 9999, NULL, 298, 0, '');
INSERT INTO 'recording' VALUES (4338, NULL, '2012-01-20 12:55:26.191047+00', 'Happy Hours', 3009, 98, 0, 0, 9999, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (4339, NULL, '2012-01-20 12:55:26.197498+00', 'My Highland Home', 3009, 98, 0, 0, 9999, NULL, 126, 0, '');
INSERT INTO 'recording' VALUES (4340, NULL, '2012-01-20 12:55:26.203752+00', 'Bedrule', 3029, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4341, NULL, '2012-01-20 12:55:26.209972+00', 'Waltz Country Dance', 3029, 5, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4342, NULL, '2012-01-20 12:55:26.216182+00', 'MacDonald of the Isles', 3029, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4343, NULL, '2012-01-20 12:55:26.222422+00', 'Earlstoun Loch', 1734, 1, 5, 32, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (9183, '2013-01-06 18:50:21.22453+00', '2013-01-06 18:50:21.22454+00', 'Strathspeys 2x48', 2029, 3, 2, 48, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (2028, NULL, '2012-01-20 12:55:12.789723+00', 'Mull of the Cold High Burns', 2062, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2030, NULL, '2012-01-20 12:55:12.800052+00', 'Saint Johnstoun Reel', 2062, 1, 4, 32, 9999, 1, 130, 0, '');
INSERT INTO 'recording' VALUES (2031, NULL, '2012-01-20 12:55:12.804882+00', 'Margaret Anne Robertson', 2062, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2032, NULL, '2012-01-20 12:55:12.810355+00', 'Garry Strathspey, The', 2062, 3, 4, 32, 9999, 1, 213, 0, '');
INSERT INTO 'recording' VALUES (2033, NULL, '2012-01-20 12:55:12.815827+00', 'Last of the Lairds, The', 2062, 2, 5, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2034, NULL, '2012-01-20 12:55:12.820629+00', 'Strathspey & Reel', 3056, 4, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2035, NULL, '2012-01-20 12:55:12.825421+00', 'Bonnie Lass o'' Bon Accord, The', 2062, 98, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2036, NULL, '2012-01-20 12:55:12.830922+00', 'Set of Reels', 2062, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2038, NULL, '2012-01-20 12:55:12.840558+00', 'Grand March', 3056, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2039, NULL, '2012-01-20 12:55:12.845389+00', 'Old Maid in a Garret', 2062, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2040, NULL, '2012-01-20 12:55:12.850204+00', 'Silver City Waltz', 2062, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2041, NULL, '2012-01-20 12:55:12.854995+00', 'Montgomeries'' Rant, The', 3020, 1, 8, 32, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (2042, NULL, '2012-01-20 12:55:12.860587+00', 'Shetland Reels', 2062, 1, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2043, NULL, '2012-01-20 12:55:12.866113+00', 'Jennifer''s Jig', 3042, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2044, NULL, '2012-01-20 12:55:12.872098+00', 'Luckenbooth Brooch, The', 3042, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2045, NULL, '2012-01-20 12:55:12.877652+00', 'Let the Hackles Rise', 3042, 2, 4, 48, 9999, 30, 0, 0, '');
INSERT INTO 'recording' VALUES (2046, NULL, '2012-01-20 12:55:12.883302+00', 'Wicked Willy', 3042, 1, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2047, NULL, '2012-01-20 12:55:12.888807+00', 'General Stuart''s Reel', 3042, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2049, NULL, '2012-01-20 12:55:12.899786+00', 'Cadgers in the Canongate', 3042, 1, 8, 48, 9999, 4, 0, 0, '');
INSERT INTO 'recording' VALUES (2048, NULL, '2021-06-21 11:45:53.613696+00', 'Toast to Saint Andrews, A', 3042, 1, 4, 48, 9999, 11, 0, 0, '');
INSERT INTO 'recording' VALUES (2003, NULL, '2021-06-13 19:55:55.274864+00', 'Lassie from Stirling, The', 3024, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (1980, NULL, '2021-06-13 20:03:51.686833+00', 'Up Helly'' Aa', 3014, 1, 4, 48, 9999, 4, 204, 0, '');
INSERT INTO 'recording' VALUES (1998, NULL, '2021-06-20 21:46:54.897672+00', 'Buchan Gate', 3024, 1, 4, 32, 9999, 14, 0, 0, '');
INSERT INTO 'recording' VALUES (2001, NULL, '2021-09-19 13:02:42.606154+00', 'Cairn Strathspey, The', 3024, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2050, NULL, '2012-01-20 12:55:12.905261+00', 'Byron Strathspey, The', 3042, 3, 3, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2052, NULL, '2012-01-20 12:55:12.916721+00', 'Sugar Candie', 3042, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2056, NULL, '2012-01-20 12:55:12.937337+00', 'Gay Gordons', 3056, 11, 0, 16, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (2057, NULL, '2012-01-20 12:55:12.942813+00', 'Gates of Edinburgh, The', 3056, 1, 4, 32, 9999, 5, 140, 0, '');
INSERT INTO 'recording' VALUES (2058, NULL, '2012-01-20 12:55:12.947625+00', 'Highland Schottische', 3056, 3, 0, 8, 9999, NULL, 98, 0, '');
INSERT INTO 'recording' VALUES (2059, NULL, '2012-01-20 12:55:12.953126+00', 'Quaker, The', 3056, 2, 2, 64, 9999, 1, 138, 0, '');
INSERT INTO 'recording' VALUES (2060, NULL, '2012-01-20 12:55:12.95797+00', 'Fiddle Air', 3056, 98, 0, 0, 9999, NULL, 67, 0, '');
INSERT INTO 'recording' VALUES (2061, NULL, '2012-01-20 12:55:12.96348+00', '6/8 Marches', 3056, 11, 0, 0, 9999, 1, 143, 0, '');
INSERT INTO 'recording' VALUES (2062, NULL, '2012-01-20 12:55:12.968303+00', 'Gaelic Waltz', 3056, 5, 0, 0, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (2063, NULL, '2012-01-20 12:55:12.973992+00', 'Pipe Marches', 3056, 11, 0, 0, 9999, 1, 145, 0, '');
INSERT INTO 'recording' VALUES (2064, NULL, '2012-01-20 12:55:12.978825+00', 'Pipe March and Reel', 3056, 4, 0, 0, 9999, NULL, 237, 0, '');
INSERT INTO 'recording' VALUES (2065, NULL, '2012-01-20 12:55:12.984282+00', 'Eight Men of Moidart, The', 3056, 1, 8, 16, 9999, 1, 141, 0, '');
INSERT INTO 'recording' VALUES (2066, NULL, '2012-01-20 12:55:12.989086+00', 'Polka', 3056, 13, 0, 0, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (2067, NULL, '2012-01-20 12:55:12.993877+00', 'Hornpipe and Reel', 3056, 98, 0, 0, 9999, NULL, 86, 0, '');
INSERT INTO 'recording' VALUES (4344, NULL, '2012-01-20 12:55:26.228638+00', 'Cock o'' the North', 1734, 99, 0, 0, 9999, NULL, 116, 0, '');
INSERT INTO 'recording' VALUES (4345, NULL, '2012-01-20 12:55:26.234897+00', 'Gaelic Waltzes', 1734, 5, 0, 0, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (4346, NULL, '2012-01-20 12:55:26.24111+00', 'Miss M. H. Alexander', 1734, 99, 0, 0, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (4347, NULL, '2012-01-20 12:55:26.247373+00', 'Montgomeries'' Rant, The', 1734, 1, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (4348, NULL, '2012-01-20 12:55:26.253612+00', 'She Moved Through the Fair', 1734, 99, 0, 0, 9999, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (4349, NULL, '2012-01-20 12:55:26.259977+00', 'Jacqueline Waltz', 1734, 5, 0, 0, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (4350, NULL, '2012-01-20 12:55:26.266223+00', 'March, Strathspey and Reel', 1734, 98, 0, 0, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (4351, NULL, '2012-01-20 12:55:26.272446+00', 'Fear A'' Bhata', 1734, 99, 0, 0, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (4352, NULL, '2012-01-20 12:55:26.278675+00', 'Buachaille Etive Mor', 1734, 99, 0, 0, 9999, NULL, 48, 0, '');
INSERT INTO 'recording' VALUES (4353, NULL, '2012-01-20 12:55:26.285007+00', 'Cutting Bracken', 1734, 99, 0, 0, 9999, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (4354, NULL, '2012-01-20 12:55:26.291274+00', 'Winter Draws On', 1734, 99, 0, 0, 9999, NULL, 62, 0, '');
INSERT INTO 'recording' VALUES (4355, NULL, '2012-01-20 12:55:26.298778+00', 'Spey in Spate intro.', 1734, 99, 0, 0, 9999, NULL, 70, 0, '');
INSERT INTO 'recording' VALUES (4356, NULL, '2012-01-20 12:55:26.305014+00', 'Spey in Spate', 1734, 1, 3, 32, 9999, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (4357, NULL, '2012-01-20 12:55:26.31125+00', 'Rakes of Mallow, The', 1734, 99, 0, 0, 9999, NULL, 90, 0, '');
INSERT INTO 'recording' VALUES (2019, NULL, '2017-08-11 15:17:48.245118+00', 'Crusader''s March', 2062, 11, 0, 0, 9999, 1, 110, 0, '');
INSERT INTO 'recording' VALUES (2021, NULL, '2017-08-11 15:22:15.175316+00', 'Middleton Medley, The', 2062, 4, 4, 32, 8, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (2017, NULL, '2017-08-11 15:23:30.431691+00', 'Slow Air', 2062, 98, 0, 0, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (2027, NULL, '2017-08-11 15:29:52.3256+00', 'Braes of Breadalbane, The', 2062, 3, 4, 32, 9999, 5, 219, 0, '');
INSERT INTO 'recording' VALUES (4358, NULL, '2012-01-20 12:55:26.317465+00', 'Alison Rose', 1734, 3, 4, 32, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (4359, NULL, '2012-01-20 12:55:26.32374+00', 'Isle of Arran', 1734, 99, 0, 0, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (4360, NULL, '2012-01-20 12:55:26.32998+00', 'Muirland Willie', 1734, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (4361, NULL, '2012-01-20 12:55:26.336182+00', 'Rowan Tree, The', 1734, 98, 0, 0, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (4362, NULL, '2012-01-20 12:55:26.343244+00', 'Shetland Reel', 2059, 1, 9, 16, 9999, 4, 165, 0, '');
INSERT INTO 'recording' VALUES (9184, '2013-01-06 18:52:16.422669+00', '2013-01-06 18:52:16.422679+00', 'Strathspeys 3x48', 2029, 3, 3, 48, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (2068, NULL, '2012-01-20 12:55:12.998656+00', 'Scottish Waltz', 3056, 5, 0, 0, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (2069, NULL, '2012-01-20 12:55:13.003511+00', 'Pipe Hornpipes', 3056, 1, 0, 0, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (2070, NULL, '2012-01-20 12:55:13.008298+00', '4/4 March Strathspey and Reel', 3056, 98, 0, 0, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (2071, NULL, '2012-01-20 12:55:13.013083+00', 'Highland Schottische', 3056, 3, 0, 8, 9999, NULL, 93, 0, '');
INSERT INTO 'recording' VALUES (2072, NULL, '2012-01-20 12:55:13.018553+00', 'Reel Kick, A', 3056, 1, 0, 88, 9999, 1, 105, 0, '');
INSERT INTO 'recording' VALUES (2053, NULL, '2022-08-21 22:16:17.046405+00', 'Broun''s Reel', 3065, 1, 5, 32, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (2079, NULL, '2013-02-15 19:05:28.850189+00', 'Harry Lauder Medley', 2048, 1, 4, 32, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (2084, NULL, '2012-01-20 12:55:13.078268+00', 'Baldovan Jig, The', 2053, 2, 8, 32, 9999, 5, 275, 0, '');
INSERT INTO 'recording' VALUES (2086, NULL, '2012-01-20 12:55:13.089601+00', 'College Hornpipe, The', 2053, 1, 8, 32, 9999, 5, 281, 0, '');
INSERT INTO 'recording' VALUES (2087, NULL, '2012-01-20 12:55:13.095094+00', 'Duke Of Perth, The', 2053, 1, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (2088, NULL, '2012-01-20 12:55:13.100572+00', 'Buchan Eightsome, The', 2053, 1, 10, 40, 9999, 6, 418, 0, '');
INSERT INTO 'recording' VALUES (2089, NULL, '2012-01-20 12:55:13.106054+00', 'Cadgers in the Canongate', 2053, 1, 8, 48, 9999, 4, 405, 0, '');
INSERT INTO 'recording' VALUES (2090, NULL, '2012-01-20 12:55:13.111538+00', 'Braes of Breadalbane, The', 2053, 3, 8, 32, 9999, 5, 503, 0, '');
INSERT INTO 'recording' VALUES (2091, NULL, '2012-01-20 12:55:13.117035+00', 'Lea Rig, The', 2053, 3, 8, 32, 9999, 5, 492, 0, '');
INSERT INTO 'recording' VALUES (2092, NULL, '2012-01-20 12:55:13.121869+00', 'Gay Gordons', 1656, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2093, NULL, '2012-01-20 12:55:13.126685+00', 'Highland Schottische', 1656, 3, 0, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2094, NULL, '2012-01-20 12:55:13.132169+00', 'Hooper''s Jig', 1656, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2095, NULL, '2012-01-20 12:55:13.137687+00', 'Kenmure''s On and Awa''', 1656, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2096, NULL, '2012-01-20 12:55:13.143216+00', 'Hollin Buss, The', 1656, 2, 5, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2097, NULL, '2012-01-20 12:55:13.148068+00', 'Polka', 1656, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2098, NULL, '2012-01-20 12:55:13.153781+00', 'Highland Laddie', 1656, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2099, NULL, '2012-01-20 12:55:13.159785+00', 'Maxwell''s Rant', 1656, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2100, NULL, '2012-01-20 12:55:13.165411+00', 'Miss Hadden''s Reel', 1656, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2101, NULL, '2012-01-20 12:55:13.171178+00', 'Roxburgh Castle', 1656, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2102, NULL, '2012-01-20 12:55:13.176727+00', 'Mairrit Man''s Favourite, The', 1656, 1, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2103, NULL, '2012-01-20 12:55:13.182445+00', 'Reel', 1656, 1, 6, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2104, NULL, '2012-01-20 12:55:13.187972+00', 'Jimmy''s Fancy', 1656, 3, 3, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2105, NULL, '2012-01-20 12:55:13.192788+00', 'Gaelic Waltz', 1656, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2106, NULL, '2012-01-20 12:55:13.197582+00', 'Scottish Waltz', 1656, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2107, NULL, '2012-01-20 12:55:13.203086+00', 'Whitesands Jig, The', 3051, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (4363, NULL, '2012-01-20 12:55:26.352011+00', 'Waylen Bay Jig, The', 2462, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4364, NULL, '2012-01-20 12:55:26.358454+00', 'Flowers of the West', 2462, 3, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4365, NULL, '2012-01-20 12:55:26.36485+00', 'Captain Stirling''s Reel', 2462, 1, 2, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4366, NULL, '2012-01-20 12:55:26.371683+00', 'Down Came the Troopers', 2462, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4367, NULL, '2012-01-20 12:55:26.377958+00', 'Mary''s Delight', 2462, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4368, NULL, '2012-01-20 12:55:26.384187+00', 'Fairbridge Reel, The', 2462, 1, 3, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4369, NULL, '2012-01-20 12:55:26.390969+00', 'Come O''er the Stream Charlie, Waltz', 3010, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4370, NULL, '2012-01-20 12:55:26.397528+00', 'Waltz', 2036, 5, 0, 96, 9999, NULL, 127, 0, '');
INSERT INTO 'recording' VALUES (4371, NULL, '2012-01-20 12:55:26.404032+00', 'Glen Affric', 2465, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2024, NULL, '2021-04-05 12:11:48.161338+00', 'Reel', 2062, 1, 8, 32, 9999, 1, 254, 0, '');
INSERT INTO 'recording' VALUES (2051, NULL, '2021-06-13 20:18:38.320896+00', 'Twixt Don and Dee', 3042, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (4372, NULL, '2012-01-20 12:55:26.410442+00', 'Sea Caves, The', 2465, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4373, NULL, '2012-01-20 12:55:26.416665+00', 'Waltz Country Dance', 3065, 5, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4374, NULL, '2012-01-20 12:55:26.422937+00', 'Trip to Aberdeen, A', 3065, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4375, NULL, '2012-01-20 12:55:26.42927+00', 'Russe, La', 3065, 1, 4, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4377, NULL, '2012-01-20 12:55:26.442185+00', 'Duke of Perth, The', 3065, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4378, NULL, '2012-01-20 12:55:26.448614+00', 'Jeannie O'' the Witchin'' E''e', 3065, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4379, NULL, '2012-01-20 12:55:26.45488+00', 'Waltz Country Dance', 3065, 5, 6, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4380, NULL, '2012-01-20 12:55:26.461119+00', 'Broun''s Reel', 3065, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4381, NULL, '2012-01-20 12:55:26.467605+00', 'Russe, La', 3065, 1, 4, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4382, NULL, '2012-01-20 12:55:26.47423+00', 'Strip the Willow', 3065, 2, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4383, NULL, '2012-01-20 12:55:26.480469+00', 'Scottish Reform', 3065, 2, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9185, '2013-01-06 18:54:20.645837+00', '2013-01-06 18:54:20.645847+00', 'Strathspeys 5x48', 2029, 3, 5, 48, 9999, NULL, 463, 0, '');
INSERT INTO 'recording' VALUES (2076, NULL, '2013-02-15 18:02:22.410315+00', 'Cumberland Reel', 2048, 2, 6, 32, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (2082, NULL, '2013-02-15 18:04:58.811894+00', 'Strathspey', 2048, 3, 3, 32, 9999, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (2073, NULL, '2013-02-15 18:06:20.738962+00', 'Balkan Hills', 2048, 3, 3, 32, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (2083, NULL, '2013-02-15 18:10:48.620024+00', 'Scottish Waltz', 2048, 5, 0, 0, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (2078, NULL, '2013-02-15 18:13:08.246615+00', 'Woodland Flower', 2048, 13, 4, 32, 9999, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (2080, NULL, '2013-02-15 18:44:10.229231+00', 'Dashing White Sergeant, The', 2048, 1, 6, 32, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (2075, NULL, '2013-02-15 18:56:20.876784+00', 'Gay Gordons', 2048, 11, 8, 16, 9999, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (2074, NULL, '2013-02-15 18:59:14.290558+00', 'Flower o'' the Quern, The', 2048, 3, 0, 32, 9999, NULL, 100, 0, '');
INSERT INTO 'recording' VALUES (2081, NULL, '2013-02-15 19:02:38.470768+00', 'Flowers of Edinburgh, The', 2048, 1, 6, 32, 9999, 1, 204, 0, '');
INSERT INTO 'recording' VALUES (2108, NULL, '2012-01-20 12:55:13.20858+00', 'Laird o'' Dochart''s Reel', 3051, 2, 2, 80, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (2109, NULL, '2012-01-20 12:55:13.21348+00', 'Bonnie Anne', 3051, 2, 0, 96, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2110, NULL, '2012-01-20 12:55:13.218277+00', 'MacDonald of Sleat', 3051, 2, 0, 120, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2111, NULL, '2012-01-20 12:55:13.22306+00', 'MacNeil of Barra', 3051, 4, 0, 112, 18, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2112, NULL, '2012-01-20 12:55:13.228514+00', 'Bonnie Brux', 3051, 4, 0, 80, 4, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (2114, NULL, '2012-01-20 12:55:13.238958+00', 'Doon Hame', 3051, 1, 2, 56, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2115, NULL, '2012-01-20 12:55:13.244273+00', 'Round Reel of Eight', 3051, 1, 0, 88, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2116, NULL, '2012-01-20 12:55:13.250316+00', 'Lamont of Inveryne', 3051, 1, 0, 208, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2117, NULL, '2012-01-20 12:55:13.255898+00', 'Winding Nith, The', 3051, 3, 4, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (2118, NULL, '2012-01-20 12:55:13.260755+00', 'Shepherd''s Crook, The', 3051, 3, 0, 72, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2119, NULL, '2012-01-20 12:55:13.26623+00', 'Rouken Glen', 3051, 3, 0, 72, 9999, 23, 0, 0, '');
INSERT INTO 'recording' VALUES (2120, NULL, '2012-01-20 12:55:13.271073+00', 'Rose of Benbecula, The', 3051, 5, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2121, NULL, '2012-01-20 12:55:13.276562+00', 'Off She Goes in the North', 9998, 2, 5, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2122, NULL, '2012-01-20 12:55:13.282051+00', 'Lamb Skinnet', 9998, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2123, NULL, '2012-01-20 12:55:13.28753+00', 'Jeannie o'' the Witchin'' E''e', 2056, 2, 6, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (2124, NULL, '2012-01-20 12:55:13.293032+00', 'Longwise Eightsome Reel', 9998, 4, 0, 64, 5, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2125, NULL, '2012-01-20 12:55:13.298539+00', 'Petronella', 2056, 1, 3, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2126, NULL, '2012-01-20 12:55:13.304028+00', 'Fidget', 9998, 1, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2127, NULL, '2012-01-20 12:55:13.309508+00', 'Strathglass House', 2056, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2128, NULL, '2012-01-20 12:55:13.315003+00', 'Lady Baird''s Reel', 9998, 1, 5, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2129, NULL, '2012-01-20 12:55:13.320488+00', 'Mrs MacLeod of Raasay', 2132, 1, 5, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2130, NULL, '2012-01-20 12:55:13.325979+00', 'Sutters of Selkirk, The', 9998, 1, 5, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2131, NULL, '2012-01-20 12:55:13.33145+00', 'Russe, La', 9998, 1, 4, 64, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2132, NULL, '2012-01-20 12:55:13.336941+00', 'Rakes of Glasgow', 2132, 3, 3, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2133, NULL, '2012-01-20 12:55:13.342431+00', 'Lady Auckland''s Reel', 2056, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2134, NULL, '2012-01-20 12:55:13.347917+00', 'Lord Hume''s Reel', 9998, 3, 3, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (2135, NULL, '2012-01-20 12:55:13.353453+00', 'Gavin''s Reel', 3040, 1, 5, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2136, NULL, '2012-01-20 12:55:13.358956+00', 'Hot Toddy', 3040, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2137, NULL, '2012-01-20 12:55:13.364443+00', 'Singing Sands, The', 3040, 3, 3, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2138, NULL, '2012-01-20 12:55:13.370139+00', 'Lady Sophia Lindsay', 3040, 1, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2139, NULL, '2012-01-20 12:55:13.375795+00', 'Argyll is my Name', 3040, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2140, NULL, '2012-01-20 12:55:13.38142+00', 'Wind on Loch Fyne, The', 3040, 3, 3, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2142, NULL, '2012-01-20 12:55:13.392521+00', 'Reel of the Royal Scots, The', 3040, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2143, NULL, '2012-01-20 12:55:13.398038+00', 'Phantom Piper, The', 3040, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2144, NULL, '2012-01-20 12:55:13.40355+00', 'Butterscotch and Honey', 3040, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2146, NULL, '2012-01-20 12:55:13.414601+00', 'Wild Goose Chase', 3040, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2148, NULL, '2012-01-20 12:55:13.425562+00', 'Tam O'' Shanter', 3040, 1, 8, 48, 9999, 11, 0, 0, '');
INSERT INTO 'recording' VALUES (4384, NULL, '2012-01-20 12:55:26.486716+00', 'Wateraid Strathspey', 2566, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4385, NULL, '2012-01-20 12:55:26.493122+00', 'Waltz Country Dance', 3065, 5, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4386, NULL, '2012-01-20 12:55:26.499441+00', 'Pride of Erin Waltz', 3065, 5, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4387, NULL, '2012-01-20 12:55:26.510752+00', 'Glasgow Highlanders, The', 3065, 3, 4, 32, 9999, NULL, 0, 1, '');
INSERT INTO 'recording' VALUES (4388, NULL, '2012-01-20 12:55:26.517033+00', 'William''s Jig', 2197, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4389, NULL, '2012-01-20 12:55:26.523341+00', 'Hamilton House', 3065, 2, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4390, NULL, '2012-01-20 12:55:26.529574+00', 'Canadian Barn Dance', 3065, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4391, NULL, '2012-01-20 12:55:26.535823+00', 'Gay Gordons', 3065, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4392, NULL, '2012-01-20 12:55:26.542166+00', 'Scottish Waltz', 3065, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4393, NULL, '2012-01-20 12:55:26.548395+00', 'Muckin'' O'' Geordie''s Byre', 3061, 2, 4, 32, 9999, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (4394, NULL, '2012-01-20 12:55:26.554654+00', 'Set of Reels', 3061, 1, 4, 32, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (4395, NULL, '2012-01-20 12:55:26.560895+00', 'Piper''s Retreat', 3061, 11, 0, 0, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (4396, NULL, '2012-01-20 12:55:26.567139+00', 'Gay Gordons', 3061, 11, 0, 16, 9999, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (4397, NULL, '2012-01-20 12:55:26.573371+00', 'Va, La', 3061, 99, 0, 0, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (4398, NULL, '2012-01-20 12:55:26.579663+00', 'Set of Irish Marches', 3061, 11, 0, 0, 9999, NULL, 100, 0, '');
INSERT INTO 'recording' VALUES (4399, NULL, '2012-01-20 12:55:26.585935+00', 'Irish Waltz', 3061, 5, 0, 0, 9999, NULL, 90, 0, '');
INSERT INTO 'recording' VALUES (4400, NULL, '2012-01-20 12:55:26.592177+00', 'Circassian Circle', 3061, 1, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (4401, NULL, '2012-01-20 12:55:26.598416+00', 'Silverton Polka', 3061, 13, 0, 0, 9999, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (4376, NULL, '2014-08-24 15:14:01.557719+00', 'Dunoon Barn Dance', 3065, 3, 12, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4402, NULL, '2012-01-20 12:55:26.604643+00', 'Eva Three Step', 3061, 11, 0, 16, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (2141, NULL, '2021-06-21 21:30:06.016071+00', 'Devil''s Elbow, The', 3040, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (4403, NULL, '2012-01-20 12:55:26.610907+00', 'Pride of Erin Waltz', 3061, 5, 0, 32, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (9186, '2013-01-06 18:56:16.046216+00', '2013-01-06 18:56:16.046226+00', 'Strathspeys 6x48', 2029, 3, 6, 48, 9999, NULL, 541, 0, '');
INSERT INTO 'recording' VALUES (2149, NULL, '2012-01-20 12:55:13.430402+00', 'Ladykirk Bridge', 3006, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2150, NULL, '2012-01-20 12:55:13.435282+00', 'Silver Thistle, The', 3006, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2151, NULL, '2012-01-20 12:55:13.440764+00', 'Set of Jigs', 2058, 2, 8, 32, 9999, 1, 262, 0, '');
INSERT INTO 'recording' VALUES (2152, NULL, '2012-01-20 12:55:13.446287+00', 'Frisky, The', 2058, 2, 8, 32, 9999, 5, 255, 0, '');
INSERT INTO 'recording' VALUES (2153, NULL, '2012-01-20 12:55:13.451788+00', 'Angus MacLeod', 2058, 1, 2, 64, 9999, 1, 135, 0, '');
INSERT INTO 'recording' VALUES (10174, '2018-03-31 10:51:14.260755+00', '2018-03-31 10:51:14.260755+00', 'Lomond Waltz', 11611, 5, 0, 0, NULL, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (2155, NULL, '2012-01-20 12:55:13.462845+00', 'Black Mountain Reel, The', 2058, 1, 5, 32, 9999, 1, 171, 0, '');
INSERT INTO 'recording' VALUES (2156, NULL, '2012-01-20 12:55:13.468336+00', 'College Hornpipe, The', 2058, 1, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (2157, NULL, '2012-01-20 12:55:13.473835+00', 'Irish Rover, The', 2058, 1, 8, 32, 9999, 1, 251, 0, '');
INSERT INTO 'recording' VALUES (2158, NULL, '2012-01-20 12:55:13.47933+00', 'New Waterloo Reel, The', 2058, 1, 8, 32, 9999, 1, 261, 0, '');
INSERT INTO 'recording' VALUES (2159, NULL, '2012-01-20 12:55:13.484835+00', 'Madge Wildfire''s Strathspey', 2058, 3, 4, 32, 9999, 5, 236, 0, '');
INSERT INTO 'recording' VALUES (2161, NULL, '2012-01-20 12:55:13.495177+00', 'Bonnie Lass O'' Bon Accord, The', 2058, 3, 0, 64, 9999, NULL, 126, 0, '');
INSERT INTO 'recording' VALUES (2162, NULL, '2012-01-20 12:55:13.500652+00', 'Gay Gordons', 2553, 11, 8, 16, 9999, 1, 162, 0, '');
INSERT INTO 'recording' VALUES (2163, NULL, '2012-01-20 12:55:13.506153+00', 'Hebridean Weaving Lilt, The', 2553, 3, 10, 8, 9999, 5, 130, 0, '');
INSERT INTO 'recording' VALUES (2164, NULL, '2012-01-20 12:55:13.51164+00', 'Last of the Lairds, The', 2553, 2, 8, 32, 9999, 1, 286, 0, '');
INSERT INTO 'recording' VALUES (2165, NULL, '2012-01-20 12:55:13.517195+00', 'Balmoral Strathspey', 2553, 3, 4, 32, 9999, 5, 253, 0, '');
INSERT INTO 'recording' VALUES (2166, NULL, '2012-01-20 12:55:13.522704+00', 'Reel of the Royal Scots, The', 2553, 1, 8, 32, 9999, 5, 287, 0, '');
INSERT INTO 'recording' VALUES (2167, NULL, '2012-01-20 12:55:13.527522+00', 'Waltz', 2553, 5, 3, 64, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (2168, NULL, '2012-01-20 12:55:13.532319+00', 'Circle Waltz', 3010, 5, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2170, NULL, '2012-01-20 12:55:13.541953+00', 'Reel of the Blackcocks', 2059, 1, 4, 32, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (2172, NULL, '2012-01-20 12:55:13.552269+00', 'Gay Gordons', 2505, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2173, NULL, '2012-01-20 12:55:13.557078+00', 'Two Step', 2505, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2174, NULL, '2012-01-20 12:55:13.562559+00', 'Set O'' Reels', 2505, 1, 3, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2175, NULL, '2012-01-20 12:55:13.567434+00', 'Canadian Barn Dance', 2505, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2176, NULL, '2012-01-20 12:55:13.572503+00', 'David Findlay Jig', 2505, 2, 0, 112, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2177, NULL, '2012-01-20 12:55:13.577335+00', 'Saint Bernard''s Waltz', 2505, 5, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2178, NULL, '2012-01-20 12:55:13.582589+00', 'Eva Three Step', 2505, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2179, NULL, '2012-01-20 12:55:13.588167+00', 'Petronella', 2505, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2180, NULL, '2012-01-20 12:55:13.593705+00', 'Handfu'' o'' Reels', 2505, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2181, NULL, '2012-01-20 12:55:13.598543+00', 'Highland Schottische', 2505, 3, 0, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2182, NULL, '2012-01-20 12:55:13.604013+00', 'Strip the Willow', 2505, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2183, NULL, '2012-01-20 12:55:13.608843+00', 'Fiddle Solo', 2505, 4, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2184, NULL, '2012-01-20 12:55:13.613639+00', 'Peu de Francais, Un', 2505, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2185, NULL, '2012-01-20 12:55:13.619117+00', 'Maxwell''s Rant', 2505, 1, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2186, NULL, '2012-01-20 12:55:13.623996+00', 'Highland Medley', 2505, 4, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2187, NULL, '2012-01-20 12:55:13.630007+00', 'Airie Bennan', 2379, 2, 5, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2188, NULL, '2012-01-20 12:55:13.635636+00', 'Todlen Hame', 2379, 2, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2189, NULL, '2012-01-20 12:55:13.641122+00', 'Rakish Highlandman, The', 2379, 2, 8, 40, 9999, 39, 0, 0, '');
INSERT INTO 'recording' VALUES (4404, NULL, '2012-01-20 12:55:26.617128+00', 'Military Two Step', 3061, 11, 0, 16, 9999, NULL, 118, 0, '');
INSERT INTO 'recording' VALUES (4405, NULL, '2012-01-20 12:55:26.62342+00', 'Set of Reels', 3061, 1, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (4406, NULL, '2012-01-20 12:55:26.629659+00', 'Waltz Country Dance', 3061, 5, 3, 40, 9999, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (4407, NULL, '2012-01-20 12:55:26.63589+00', 'Set of Jigs', 3061, 2, 0, 0, 9999, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (4408, NULL, '2012-01-20 12:55:26.650897+00', 'Gay Gordons', 3061, 11, 0, 16, 9999, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (4409, NULL, '2012-01-20 12:55:26.657309+00', 'Dean Brig O'' Edinburgh', 3056, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4410, NULL, '2012-01-20 12:55:26.664015+00', 'Carnegie''s March', 3056, 11, 2, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2160, NULL, '2023-01-12 22:30:56.677379+00', 'Silver Tassie, The', 2058, 3, 4, 32, 9999, 5, 236, 0, '');
INSERT INTO 'recording' VALUES (4411, NULL, '2012-01-20 12:55:26.67029+00', 'Earl of Mansfield', 1396, 1, 4, 48, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (4412, NULL, '2012-01-20 12:55:26.676812+00', 'Barn Dance', 1396, 50, 0, 0, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (4413, NULL, '2012-01-20 12:55:26.683139+00', 'Fiddle Solo', 1396, 98, 0, 0, 9999, NULL, 237, 0, '');
INSERT INTO 'recording' VALUES (4414, NULL, '2012-01-20 12:55:26.689489+00', 'Medley', 1396, 98, 0, 0, 9999, NULL, 240, 0, '');
INSERT INTO 'recording' VALUES (4415, NULL, '2012-01-20 12:55:26.695832+00', 'Nurseryman, The', 1396, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (4416, NULL, '2012-01-20 12:55:26.702092+00', 'Cape Town Wedding', 1396, 3, 8, 32, 9999, NULL, 486, 0, '');
INSERT INTO 'recording' VALUES (4417, NULL, '2012-01-20 12:55:26.708322+00', 'Set of Reels', 1396, 1, 5, 32, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (4418, NULL, '2012-01-20 12:55:26.714659+00', 'Accordion Solo', 1396, 98, 0, 0, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (4419, NULL, '2012-01-20 12:55:26.721047+00', 'Red House', 1396, 1, 8, 40, 9999, NULL, 353, 0, '');
INSERT INTO 'recording' VALUES (4421, NULL, '2012-01-20 12:55:26.733526+00', 'Culla Bay', 1396, 3, 4, 32, 9999, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (4422, NULL, '2012-01-20 12:55:26.739985+00', 'Gaelic Waltz', 1396, 5, 0, 0, 9999, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (4423, NULL, '2012-01-20 12:55:26.746318+00', 'Grimaldi 700', 1396, 1, 0, 88, 9999, NULL, 106, 0, '');
INSERT INTO 'recording' VALUES (2190, NULL, '2012-01-20 12:55:13.646633+00', 'Earlstoun Loch', 2379, 1, 5, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2191, NULL, '2012-01-20 12:55:13.652232+00', 'Alewife and her Barrel, The', 2379, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2193, NULL, '2012-01-20 12:55:13.663816+00', 'Admiral Nelson''s Hornpipe', 2379, 1, 4, 64, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2194, NULL, '2012-01-20 12:55:13.669354+00', 'Ca'' the Ewes tae the Knowes', 2379, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2195, NULL, '2012-01-20 12:55:13.674871+00', 'She''s Ower Young to Marry Yet', 2379, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2196, NULL, '2012-01-20 12:55:13.68036+00', 'Merry Oddfellows, The', 2398, 2, 8, 32, 9999, 1, 275, 0, '');
INSERT INTO 'recording' VALUES (2197, NULL, '2012-01-20 12:55:13.685857+00', 'Dundee Whaler, The', 2398, 3, 4, 32, 9999, 5, 238, 0, '');
INSERT INTO 'recording' VALUES (2198, NULL, '2012-01-20 12:55:13.690678+00', 'Morag Murray of Dunning', 2398, 98, 0, 0, 9999, NULL, 100, 0, '');
INSERT INTO 'recording' VALUES (2199, NULL, '2012-01-20 12:55:13.695481+00', 'Robertson Rant, The', 2398, 3, 0, 80, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (2200, NULL, '2012-01-20 12:55:13.70028+00', 'Lass of Humberside', 2398, 98, 0, 0, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (2201, NULL, '2012-01-20 12:55:13.705753+00', 'Loon Mountain Reel, The', 2398, 1, 4, 32, 9999, 1, 139, 0, '');
INSERT INTO 'recording' VALUES (2202, NULL, '2012-01-20 12:55:13.711362+00', 'Senator Robert C. Byrd of West Virginia', 2398, 1, 8, 32, 9999, 1, 268, 0, '');
INSERT INTO 'recording' VALUES (2203, NULL, '2012-01-20 12:55:13.716903+00', 'From Scotia''s Shores We''re Noo Awa''', 2398, 3, 8, 32, 9999, 5, 481, 0, '');
INSERT INTO 'recording' VALUES (2204, NULL, '2012-01-20 12:55:13.722405+00', 'Black Craig of Dee, The', 2398, 1, 8, 32, 9999, 1, 267, 0, '');
INSERT INTO 'recording' VALUES (2205, NULL, '2012-01-20 12:55:13.727225+00', 'Molly Blair''s Cradle Song', 2398, 98, 0, 0, 9999, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (2208, NULL, '2012-01-20 12:55:13.743713+00', 'Reel of Mey, The', 2053, 2, 8, 48, 9999, 41, 415, 0, '');
INSERT INTO 'recording' VALUES (2169, NULL, '2019-11-22 19:24:44.779598+00', 'Strathspey and Reel', 2059, 4, 0, 112, 18, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (2192, NULL, '2021-04-24 09:49:20.947617+00', 'Wind That Shakes the Barley, The', 2379, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2209, NULL, '2012-01-20 12:55:13.748693+00', 'Cauld Kail in Aberdeen', 2053, 4, 8, 32, 1, NULL, 408, 0, '');
INSERT INTO 'recording' VALUES (2210, NULL, '2012-01-20 12:55:13.754322+00', 'Gates of Edinburgh, The', 2053, 1, 8, 32, 9999, 5, 280, 0, '');
INSERT INTO 'recording' VALUES (2211, NULL, '2012-01-20 12:55:13.759818+00', 'Jessie''s Hornpipe', 2053, 1, 8, 32, 9999, 1, 276, 0, '');
INSERT INTO 'recording' VALUES (2212, NULL, '2012-01-20 12:55:13.765308+00', 'Kingussie Flower', 2053, 1, 8, 40, 9999, 6, 348, 0, '');
INSERT INTO 'recording' VALUES (2213, NULL, '2012-01-20 12:55:13.771025+00', 'Mairi''s Wedding', 2053, 1, 8, 40, 9999, 6, 334, 0, '');
INSERT INTO 'recording' VALUES (2214, NULL, '2012-01-20 12:55:13.776552+00', 'MacPhersons of Edinburgh, The', 2053, 3, 8, 32, 9999, 5, 516, 0, '');
INSERT INTO 'recording' VALUES (2215, NULL, '2012-01-20 12:55:13.782091+00', 'Sailor, The', 2053, 1, 8, 32, 9999, 5, 260, 0, '');
INSERT INTO 'recording' VALUES (2216, NULL, '2012-01-20 12:55:13.787582+00', 'Haddington Assembly, The', 2053, 2, 8, 32, 9999, 1, 265, 0, '');
INSERT INTO 'recording' VALUES (2217, NULL, '2012-01-20 12:55:13.793063+00', 'Hollin Buss, The', 2053, 2, 8, 32, 9999, 1, 260, 0, '');
INSERT INTO 'recording' VALUES (2218, NULL, '2012-01-20 12:55:13.798572+00', 'Wild Geese, The', 2053, 2, 8, 32, 9999, 1, 259, 0, '');
INSERT INTO 'recording' VALUES (2219, NULL, '2012-01-20 12:55:13.804083+00', 'Miss Mary Douglas', 2053, 2, 8, 48, 9999, 4, 390, 0, '');
INSERT INTO 'recording' VALUES (2220, NULL, '2012-01-20 12:55:13.809604+00', 'Maxwell''s Rant', 2053, 1, 8, 32, 9999, 5, 260, 0, '');
INSERT INTO 'recording' VALUES (2221, NULL, '2012-01-20 12:55:13.815094+00', 'Saint John River, The', 2053, 3, 4, 32, 9999, 1, 256, 0, '');
INSERT INTO 'recording' VALUES (2223, NULL, '2012-01-20 12:55:13.825455+00', 'Gay Gordons', 3037, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2224, NULL, '2012-01-20 12:55:13.830256+00', 'Heroes of Vittoria', 3037, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2225, NULL, '2012-01-20 12:55:13.835062+00', 'Highland Wedding', 3037, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2226, NULL, '2012-01-20 12:55:13.83986+00', 'Military Two-Step', 3037, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2227, NULL, '2012-01-20 12:55:13.845314+00', 'Canadian Barn Dance', 3037, 11, 4, 16, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2228, NULL, '2012-01-20 12:55:13.850796+00', 'Ashludie Rant', 3037, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (4424, NULL, '2012-01-20 12:55:26.753302+00', 'Accordion Duet', 1396, 98, 0, 0, 9999, NULL, 85, 0, '');
INSERT INTO 'recording' VALUES (4425, NULL, '2012-01-20 12:55:26.75985+00', 'Highland Schottische', 1396, 3, 0, 8, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (4426, NULL, '2012-01-20 12:55:26.766187+00', 'Follow Me Home', 1396, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (4427, NULL, '2012-01-20 12:55:26.772434+00', 'Cumberland Square Eight', 3010, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4428, NULL, '2012-01-20 12:55:26.778773+00', 'Newcastle Reel', 3010, 1, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4429, NULL, '2012-01-20 12:55:26.785075+00', 'Westminster Reel, The', 3040, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (4430, NULL, '2012-01-20 12:55:26.790603+00', 'Pins and Needles', 3010, 2, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4431, NULL, '2012-01-20 12:55:26.79622+00', 'Ploughboy, The', 3010, 99, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4432, NULL, '2012-01-20 12:55:26.801087+00', 'Three Drops of Brandy', 3010, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4434, NULL, '2012-01-20 12:55:26.810698+00', 'Winister Gallop', 3010, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4435, NULL, '2012-01-20 12:55:26.815479+00', 'Selection of Jigs', 3067, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (4436, NULL, '2012-01-20 12:55:26.820292+00', 'Palais Glide, The', 3067, 50, 0, 0, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (4437, NULL, '2012-01-20 12:55:26.825077+00', 'Selection of Reels', 3067, 1, 5, 32, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (4438, NULL, '2012-01-20 12:55:26.830918+00', 'Military Two Step, The', 3067, 11, 0, 16, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (4439, NULL, '2012-01-20 12:55:26.835983+00', 'Selection of Strathspeys', 3067, 3, 6, 32, 9999, NULL, 382, 0, '');
INSERT INTO 'recording' VALUES (4440, NULL, '2012-01-20 12:55:26.840839+00', 'Gay Gordons', 3067, 11, 0, 16, 9999, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (4443, NULL, '2012-01-20 12:55:26.855215+00', 'Selection of Reels', 3067, 1, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (2229, NULL, '2012-01-20 12:55:13.856266+00', 'Scottish Reform', 3037, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2230, NULL, '2012-01-20 12:55:13.861852+00', 'Cumberland Reel', 3037, 2, 5, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2231, NULL, '2012-01-20 12:55:13.866704+00', 'Polka', 3037, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2232, NULL, '2012-01-20 12:55:13.872604+00', 'Reivers, The', 3037, 1, 5, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2233, NULL, '2012-01-20 12:55:13.878164+00', 'Highland Laddie', 3037, 1, 6, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2234, NULL, '2012-01-20 12:55:13.88305+00', 'Morag''s Waltz', 3037, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2235, NULL, '2012-01-20 12:55:13.888552+00', 'Memory Lane', 2182, 1, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (2236, NULL, '2012-01-20 12:55:13.894049+00', 'Teviot Brig', 3026, 2, 8, 24, 9999, 18, 197, 0, '');
INSERT INTO 'recording' VALUES (2237, NULL, '2012-01-20 12:55:13.899543+00', 'Off She Goes in the North', 3026, 2, 4, 32, 9999, 1, 140, 0, '');
INSERT INTO 'recording' VALUES (2238, NULL, '2012-01-20 12:55:13.905045+00', 'Tribute to the Borders', 3026, 2, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (2239, NULL, '2012-01-20 12:55:13.910563+00', 'Reel of Five, The', 3026, 4, 0, 64, 5, 5, 98, 0, '');
INSERT INTO 'recording' VALUES (2240, NULL, '2012-01-20 12:55:13.916047+00', 'Ellwyn''s Fairy Glen', 3026, 1, 8, 32, 9999, 1, 263, 0, '');
INSERT INTO 'recording' VALUES (4420, NULL, '2022-12-09 19:55:31.983946+00', 'Pipe Jigs', 1396, 2, 0, 0, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (4442, NULL, '2022-12-20 14:54:42.814487+00', 'Viennese Swing, The', 3067, 5, 0, 0, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (2241, NULL, '2012-01-20 12:55:13.921602+00', 'Maxwell''s Rant', 3026, 1, 8, 32, 9999, 1, 268, 0, '');
INSERT INTO 'recording' VALUES (2242, NULL, '2012-01-20 12:55:13.927097+00', 'Garry Strathspey, The', 3026, 3, 4, 32, 9999, 10, 254, 0, '');
INSERT INTO 'recording' VALUES (2243, NULL, '2012-01-20 12:55:13.9326+00', 'Seann Truibhas Willichan', 3026, 3, 4, 32, 9999, 1, 268, 0, '');
INSERT INTO 'recording' VALUES (10175, '2018-03-31 10:56:59.909288+00', '2018-03-31 10:56:59.909288+00', '4/4 Marches', 11611, 11, 0, 0, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (2245, NULL, '2012-01-20 12:55:13.942995+00', 'Waltz Country Dance', 3026, 5, 4, 40, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (2246, NULL, '2012-01-20 12:55:13.948465+00', 'Half and Half', 2055, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2247, NULL, '2012-01-20 12:55:13.95396+00', 'Ladies'' Fancy', 2055, 2, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2248, NULL, '2012-01-20 12:55:13.959465+00', 'Lady Catherine Bruce''s Reel', 2055, 2, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2249, NULL, '2012-01-20 12:55:13.964967+00', 'Triumph, The', 2055, 1, 4, 24, 9999, 18, 0, 0, '');
INSERT INTO 'recording' VALUES (2250, NULL, '2012-01-20 12:55:13.970644+00', 'Princess Royal, The', 2055, 1, 8, 28, 9999, 12, 0, 0, '');
INSERT INTO 'recording' VALUES (2251, NULL, '2012-01-20 12:55:13.97617+00', 'Australian Ladies', 2055, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2252, NULL, '2012-01-20 12:55:13.981705+00', 'Lass O'' Livingston, The', 2055, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2253, NULL, '2012-01-20 12:55:13.987217+00', 'Ca'' the Ewes tae the Knowes', 2055, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2254, NULL, '2012-01-20 12:55:13.99273+00', 'Gramachie', 2055, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2255, NULL, '2012-01-20 12:55:13.99755+00', 'Gay Gordons', 3051, 11, 8, 16, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (2256, NULL, '2012-01-20 12:55:14.002967+00', 'Highland Schottische', 3051, 3, 16, 8, 9999, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (2257, NULL, '2012-01-20 12:55:14.008534+00', 'Honeymoon, The', 3051, 2, 4, 32, 9999, 5, 136, 0, '');
INSERT INTO 'recording' VALUES (2258, NULL, '2012-01-20 12:55:14.014035+00', 'Duke of Atholl''s Reel, The', 3051, 2, 6, 32, 9999, 1, 199, 0, '');
INSERT INTO 'recording' VALUES (2259, NULL, '2012-01-20 12:55:14.01953+00', 'Devorgilla Reel, The', 3051, 1, 4, 32, 9999, 5, 140, 0, '');
INSERT INTO 'recording' VALUES (2260, NULL, '2012-01-20 12:55:14.025029+00', 'Jean''s Reel', 3051, 1, 6, 32, 9999, 1, 203, 0, '');
INSERT INTO 'recording' VALUES (2261, NULL, '2012-01-20 12:55:14.030575+00', 'Kelso Races', 3051, 1, 8, 32, 9999, 1, 262, 0, '');
INSERT INTO 'recording' VALUES (2262, NULL, '2012-01-20 12:55:14.08446+00', 'Madge Wildfire''s Strathspey', 3051, 3, 4, 32, 9999, 5, 228, 0, '');
INSERT INTO 'recording' VALUES (2263, NULL, '2012-01-20 12:55:14.091722+00', 'Rob Roy MacGregor', 3051, 3, 4, 32, 9999, 5, 247, 0, '');
INSERT INTO 'recording' VALUES (2264, NULL, '2012-01-20 12:55:14.09848+00', 'Gaelic Waltz', 3051, 5, 0, 0, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (2265, NULL, '2012-01-20 12:55:14.104412+00', 'Shetland Waltz', 3051, 5, 0, 0, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (2266, NULL, '2012-01-20 12:55:14.110039+00', 'Rakes of Glasgow', 9998, 3, 4, 32, 9999, 23, 0, 0, '');
INSERT INTO 'recording' VALUES (2267, NULL, '2012-01-20 12:55:14.115571+00', 'Moray Reel, The', 3067, 2, 8, 32, 9999, 1, 269, 0, '');
INSERT INTO 'recording' VALUES (4444, NULL, '2012-01-20 12:55:26.859999+00', 'Lambeth Walk, The', 3067, 50, 0, 16, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (4445, NULL, '2012-01-20 12:55:26.865809+00', 'Selection of Strathspeys', 3067, 3, 4, 32, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (4441, NULL, '2021-03-29 00:35:17.444123+00', 'Selection of Jigs', 3067, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (2268, NULL, '2021-03-30 17:06:42.242413+00', 'Birks of Invermay, The', 2276, 3, 8, 32, 9999, 5, 519, 0, '');
INSERT INTO 'recording' VALUES (4446, NULL, '2012-01-20 12:55:26.878959+00', 'Polka', 3067, 13, 0, 0, 9999, NULL, 126, 0, '');
INSERT INTO 'recording' VALUES (4447, NULL, '2012-01-20 12:55:26.885334+00', 'Jig Selection', 3067, 2, 4, 40, 9999, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (4448, NULL, '2012-01-20 12:55:26.891672+00', 'Tango', 3067, 50, 0, 0, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (4449, NULL, '2012-01-20 12:55:26.90117+00', 'Selection of Reels', 3067, 1, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (4450, NULL, '2012-01-20 12:55:26.907451+00', 'Selection of Strathspeys', 3067, 3, 6, 32, 9999, NULL, 374, 0, '');
INSERT INTO 'recording' VALUES (4452, NULL, '2012-01-20 12:55:26.921131+00', 'Selection of Jigs', 3067, 2, 6, 32, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (2270, NULL, '2012-01-20 12:55:14.13218+00', 'Off She Goes in the North', 2053, 2, 4, 32, 9999, 1, 142, 0, '');
INSERT INTO 'recording' VALUES (2271, NULL, '2012-01-20 12:55:14.137703+00', 'Dancing Man, The', 2276, 1, 8, 32, 9999, 1, 279, 0, '');
INSERT INTO 'recording' VALUES (2272, NULL, '2012-01-20 12:55:14.143231+00', 'Glasgow Highlanders, The', 2182, 3, 8, 32, 9999, 5, 475, 1, '');
INSERT INTO 'recording' VALUES (2273, NULL, '2012-01-20 12:55:14.148745+00', 'Todlen Hame', 2053, 2, 8, 32, 9999, 5, 275, 0, '');
INSERT INTO 'recording' VALUES (2274, NULL, '2012-01-20 12:55:14.154682+00', 'Strathspeys: Bandleader Choice', 2033, 3, 4, 32, 9999, 5, 250, 0, '');
INSERT INTO 'recording' VALUES (2275, NULL, '2012-01-20 12:55:14.160264+00', 'Reels: Bandleaders Choice', 3067, 1, 4, 32, 9999, 5, 142, 0, '');
INSERT INTO 'recording' VALUES (2276, NULL, '2012-01-20 12:55:14.165751+00', 'Merrily Danced the Quaker''s Wife', 2276, 2, 8, 40, 9999, 6, 344, 0, '');
INSERT INTO 'recording' VALUES (2277, NULL, '2012-01-20 12:55:14.171506+00', 'Peggy''s Love', 2053, 3, 8, 32, 9999, 5, 507, 0, '');
INSERT INTO 'recording' VALUES (2278, NULL, '2012-01-20 12:55:14.177037+00', 'Lamb Skinnet', 2182, 2, 8, 32, 9999, 1, 273, 0, '');
INSERT INTO 'recording' VALUES (2279, NULL, '2012-01-20 12:55:14.182539+00', 'Wind that Shakes the Barley, The', 3067, 1, 8, 32, 9999, 5, 275, 0, '');
INSERT INTO 'recording' VALUES (2280, NULL, '2012-01-20 12:55:14.188029+00', 'White Heather Jig, The', 2033, 2, 4, 40, 9999, 15, 171, 0, '');
INSERT INTO 'recording' VALUES (2281, NULL, '2012-01-20 12:55:14.193539+00', 'General Stuart''s Reel', 2053, 1, 8, 32, 9999, 5, 269, 0, '');
INSERT INTO 'recording' VALUES (2282, NULL, '2012-01-20 12:55:14.199048+00', 'Banks of Clyde, The', 3067, 3, 8, 32, 9999, 5, 509, 0, '');
INSERT INTO 'recording' VALUES (2283, NULL, '2012-01-20 12:55:14.204642+00', 'British Immigrant, The', 2182, 2, 4, 32, 9999, 10, 141, 0, '');
INSERT INTO 'recording' VALUES (2284, NULL, '2012-01-20 12:55:14.210172+00', 'Reels: Bandleaders Choice', 2276, 1, 4, 32, 9999, 1, 143, 0, '');
INSERT INTO 'recording' VALUES (2285, NULL, '2012-01-20 12:55:14.2157+00', 'Last of the Lairds, The', 2033, 2, 8, 32, 9999, 1, 273, 0, '');
INSERT INTO 'recording' VALUES (4457, NULL, '2015-11-15 15:28:39.369975+00', 'Amazing Grace', 1556, 98, 0, 0, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (4458, NULL, '2015-11-15 15:29:28.959961+00', 'Green Hills of Tyrol, The', 1556, 98, 0, 0, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (4459, NULL, '2015-11-15 15:30:19.271461+00', 'Cock O'' the North, The', 1556, 98, 0, 0, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (4460, NULL, '2015-11-15 15:31:20.894386+00', 'Scotland the Brave', 1556, 98, 0, 0, 9999, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (4461, NULL, '2015-11-15 15:32:33.534386+00', 'Highland Fling', 1556, 7, 6, 8, 9999, NULL, 100, 0, '');
INSERT INTO 'recording' VALUES (4463, NULL, '2015-11-15 15:34:13.33972+00', 'Scottish Lilt', 1556, 7, 6, 8, 9999, NULL, 101, 0, '');
INSERT INTO 'recording' VALUES (4462, NULL, '2015-11-15 15:33:31.106852+00', 'Flora MacDonald''s Fancy', 1556, 7, 6, 8, 9999, NULL, 124, 0, '');
INSERT INTO 'recording' VALUES (4464, NULL, '2015-11-15 15:35:04.429108+00', 'Seann Truibhas', 1556, 7, 6, 8, 9999, NULL, 116, 0, '');
INSERT INTO 'recording' VALUES (4454, NULL, '2017-01-27 19:36:56.848041+00', 'Selection of Strathspeys (pastoral)', 3067, 3, 3, 32, 9999, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (2287, NULL, '2012-01-20 12:55:14.226016+00', 'Braes of Breadalbane, The', 3026, 3, 4, 32, 9999, NULL, 239, 0, '');
INSERT INTO 'recording' VALUES (2290, NULL, '2012-01-20 12:55:14.242941+00', 'Sound of Harris, The', 3014, 1, 3, 48, 9999, 4, 151, 0, '');
INSERT INTO 'recording' VALUES (2291, NULL, '2012-01-20 12:55:14.249162+00', 'Airie Bennan', 3014, 2, 5, 32, 9999, 1, 162, 0, '');
INSERT INTO 'recording' VALUES (2292, NULL, '2012-01-20 12:55:14.254817+00', 'Autumn in Appin', 3014, 3, 4, 32, 9999, 5, 250, 0, '');
INSERT INTO 'recording' VALUES (2293, NULL, '2012-01-20 12:55:14.260338+00', 'Earl of Mansfield, The', 3014, 1, 4, 48, 9999, 11, 200, 0, '');
INSERT INTO 'recording' VALUES (2294, NULL, '2012-01-20 12:55:14.265172+00', 'Lament and Reel', 3014, 98, 0, 0, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (2295, NULL, '2012-01-20 12:55:14.270668+00', 'Montgomeries'' Rant, The', 3014, 1, 8, 32, 9999, 5, 265, 0, '');
INSERT INTO 'recording' VALUES (2296, NULL, '2012-01-20 12:55:14.275533+00', 'Cambuskenneth', 3014, 3, 0, 80, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (2297, NULL, '2012-01-20 12:55:14.280422+00', 'Peterhead Express, The', 3014, 2, 4, 64, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (2298, NULL, '2012-01-20 12:55:14.285903+00', 'Cobblestones, The', 3014, 1, 8, 32, 9999, 1, 268, 0, '');
INSERT INTO 'recording' VALUES (2299, NULL, '2012-01-20 12:55:14.290737+00', 'Slow Air and Reel', 3014, 98, 0, 0, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (2300, NULL, '2012-01-20 12:55:14.296269+00', 'Argyll''s Fancy', 3014, 2, 4, 48, 9999, 4, 201, 0, '');
INSERT INTO 'recording' VALUES (2301, NULL, '2012-01-20 12:55:14.301099+00', 'Schottische', 9998, 3, 8, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2302, NULL, '2012-01-20 12:55:14.306578+00', 'Hollin Buss, The', 3024, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2269, NULL, '2022-09-01 11:11:45.16141+00', 'Meeting of the Waters, The', 2033, 1, 8, 48, 9999, 29, 405, 0, '');
INSERT INTO 'recording' VALUES (4451, NULL, '2022-12-25 19:25:05.326237+00', 'Barn Dance', 3067, 50, 0, 0, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (4456, NULL, '2022-12-25 21:59:47.715318+00', 'Trew Waltz, The', 3067, 5, 0, 0, 9999, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (2305, NULL, '2012-01-20 12:55:14.323465+00', 'Airdrie Lassies', 3024, 2, 4, 48, 9999, 11, 0, 0, '');
INSERT INTO 'recording' VALUES (2306, NULL, '2012-01-20 12:55:14.328426+00', 'MacDonald of Sleat', 3024, 2, 0, 120, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2307, NULL, '2012-01-20 12:55:14.333963+00', 'New Waterloo Reel, The', 3024, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (10177, '2018-03-31 11:02:49.141621+00', '2018-03-31 11:02:49.141621+00', '6/8 Marches', 11611, 11, 0, 0, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (4469, NULL, '2012-01-20 12:55:27.028645+00', 'Marches', 3036, 11, 0, 0, 9999, NULL, 225, 0, '');
INSERT INTO 'recording' VALUES (4470, NULL, '2012-01-20 12:55:27.036977+00', 'Bonnie Lass', 3011, 1, 5, 32, 9999, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (4471, NULL, '2012-01-20 12:55:27.043275+00', '6/8 Marches - Eva Three Step', 3056, 11, 0, 16, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (4472, NULL, '2012-01-20 12:55:27.049547+00', 'Modern Gaelic Waltz', 2498, 5, 0, 0, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (4473, NULL, '2012-01-20 12:55:27.055847+00', 'Reels', 2501, 1, 0, 0, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (4474, NULL, '2012-01-20 12:55:27.063007+00', 'Strip the Willow (6/8)', 2502, 2, 0, 0, 9999, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (4475, NULL, '2012-01-20 12:55:27.069682+00', 'Strathspey', 2503, 3, 0, 0, 9999, NULL, 240, 0, '');
INSERT INTO 'recording' VALUES (4476, NULL, '2012-01-20 12:55:27.075948+00', 'Red House', 2504, 1, 4, 40, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (4477, NULL, '2012-01-20 12:55:27.08227+00', 'Jig', 3037, 2, 6, 32, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (4478, NULL, '2012-01-20 12:55:27.088788+00', 'Dashing White Sargeant', 2505, 1, 6, 32, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (4479, NULL, '2012-01-20 12:55:27.095042+00', 'Baron''s Piper, The', 3025, 99, 0, 0, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (4480, NULL, '2012-01-20 12:55:27.10135+00', 'Canadian Barn Dance', 3023, 11, 0, 16, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (4481, NULL, '2012-01-20 12:55:27.107591+00', 'Speed the Plough', 3021, 1, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (4482, NULL, '2012-01-20 12:55:27.113835+00', 'Old Tyme Waltz', 2507, 5, 0, 0, 9999, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (4483, NULL, '2012-01-20 12:55:27.120089+00', 'Campbell''s Frolic', 2037, 2, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (4484, NULL, '2012-01-20 12:55:27.126335+00', 'Roxborough Castle', 3020, 1, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (4453, NULL, '2014-03-25 15:41:37.039902+00', 'Quickstep', 3067, 50, 0, 0, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (2308, NULL, '2012-01-20 12:55:14.339521+00', 'White Cockade, The', 3024, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2309, NULL, '2012-01-20 12:55:14.345206+00', 'Ladies of Dunse, The', 3024, 1, 8, 40, 9999, 28, 0, 0, '');
INSERT INTO 'recording' VALUES (2310, NULL, '2012-01-20 12:55:14.350826+00', 'Lord Elgin''s Reel', 3024, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2319, NULL, '2012-01-20 12:55:14.399986+00', 'Rothesay Rant, The', 2414, 2, 4, 32, 9999, 10, 132, 0, '');
INSERT INTO 'recording' VALUES (2320, NULL, '2012-01-20 12:55:14.405472+00', 'Twa Rogueish E''en', 2414, 2, 8, 40, 9999, 6, 328, 0, '');
INSERT INTO 'recording' VALUES (2321, NULL, '2012-01-20 12:55:14.411014+00', 'My Heather Hills', 2414, 2, 3, 48, 9999, 11, 152, 0, '');
INSERT INTO 'recording' VALUES (2322, NULL, '2012-01-20 12:55:14.415853+00', 'Schiehallion', 2414, 4, 0, 128, 2, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (2288, NULL, '2021-05-30 12:05:33.365289+00', 'Good Hearted Glasgow', 3014, 2, 8, 32, 9999, 1, 266, 0, '');
INSERT INTO 'recording' VALUES (2323, NULL, '2012-01-20 12:55:14.421319+00', 'Baldovan Reel', 2414, 1, 4, 32, 9999, 1, 133, 0, '');
INSERT INTO 'recording' VALUES (2324, NULL, '2012-01-20 12:55:14.426835+00', 'Campbell''s Hornpipe', 2414, 1, 4, 32, 9999, 1, 135, 0, '');
INSERT INTO 'recording' VALUES (2325, NULL, '2012-01-20 12:55:14.432333+00', 'Arran Chase', 2414, 1, 8, 32, 9999, 1, 264, 0, '');
INSERT INTO 'recording' VALUES (2326, NULL, '2012-01-20 12:55:14.437825+00', 'Hamilton Rant, The', 2414, 1, 8, 48, 9999, 11, 389, 0, '');
INSERT INTO 'recording' VALUES (2328, NULL, '2012-01-20 12:55:14.44887+00', 'Summer in Assynt', 2414, 3, 8, 32, 9999, 5, 487, 0, '');
INSERT INTO 'recording' VALUES (2329, NULL, '2012-01-20 12:55:14.453707+00', 'Shepherd''s Crook, The', 2414, 3, 0, 72, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (2330, NULL, '2012-01-20 12:55:14.459192+00', 'Waltz Country Dance', 2414, 5, 6, 40, 9999, 1, 261, 0, '');
INSERT INTO 'recording' VALUES (2331, NULL, '2012-01-20 12:55:14.464718+00', 'Miss Mary Douglas', 3069, 2, 4, 48, 9999, 25, 202, 0, '');
INSERT INTO 'recording' VALUES (2332, NULL, '2012-01-20 12:55:14.46956+00', 'Wind on Loch Fyne, The', 2414, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2333, NULL, '2012-01-20 12:55:14.47506+00', 'Flowers of Edinburgh, The', 3069, 1, 4, 32, 9999, 1, 139, 0, '');
INSERT INTO 'recording' VALUES (2334, NULL, '2012-01-20 12:55:14.479892+00', 'Scottish Waltz', 3069, 5, 0, 0, 9999, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (2335, NULL, '2012-01-20 12:55:14.485374+00', 'Kiss me Quick, my Mither''s Coming', 3069, 1, 6, 32, 9999, 1, 205, 0, '');
INSERT INTO 'recording' VALUES (2336, NULL, '2012-01-20 12:55:14.490882+00', 'Set of Jigs', 3069, 2, 6, 32, 9999, 1, 201, 0, '');
INSERT INTO 'recording' VALUES (2337, NULL, '2012-01-20 12:55:14.49637+00', 'Military Two-Step', 3069, 11, 4, 16, 9999, 42, 181, 0, '');
INSERT INTO 'recording' VALUES (2339, NULL, '2012-01-20 12:55:14.506705+00', 'Seton''s Ceilidh Band', 2414, 2, 4, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2340, NULL, '2012-01-20 12:55:14.511538+00', 'Gay Gordons', 3069, 11, 0, 16, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (2341, NULL, '2012-01-20 12:55:14.517045+00', 'Lady Louisa MacDonald''s Strathspey', 3069, 3, 3, 32, 9999, 5, 176, 0, '');
INSERT INTO 'recording' VALUES (2342, NULL, '2012-01-20 12:55:14.522605+00', 'Abercairney Highlanders, The', 3069, 98, 0, 0, 9999, 3, 112, 0, '');
INSERT INTO 'recording' VALUES (2343, NULL, '2012-01-20 12:55:14.5281+00', 'Jig for Mrs Dunn, A', 1502, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2344, NULL, '2012-01-20 12:55:14.533604+00', 'Papillon, Le', 1502, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2345, NULL, '2012-01-20 12:55:14.539111+00', 'Misses Cramb of Linlithgow, The', 1502, 2, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2346, NULL, '2012-01-20 12:55:14.544614+00', 'Dhoon, The', 1502, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2347, NULL, '2012-01-20 12:55:14.550301+00', 'Braes of Balluder, The', 1502, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (4485, NULL, '2012-01-20 12:55:27.132624+00', 'Gay Gordons', 2510, 11, 0, 16, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (4486, NULL, '2012-01-20 12:55:27.138912+00', 'Reel', 3071, 1, 6, 32, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (4488, NULL, '2012-01-20 12:55:27.151377+00', 'Culla Bay', 2188, 3, 4, 32, 9999, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (4489, NULL, '2012-01-20 12:55:27.157855+00', 'McPherson''s Jig', 2188, 2, 3, 32, 9999, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (4490, NULL, '2012-01-20 12:55:27.164284+00', 'Saint Bernard''s Waltz', 2188, 5, 0, 16, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (4492, NULL, '2012-01-20 12:55:27.176794+00', 'Singing Sands, The', 2188, 3, 3, 32, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (4525, NULL, '2012-01-20 12:55:27.477465+00', 'Military Two-Step', 3050, 11, 0, 16, 9999, NULL, 125, 0, '');
INSERT INTO 'recording' VALUES (4466, NULL, '2015-11-15 15:37:03.581319+00', 'Belle O'' Bon Accord, The', 1556, 3, 4, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (4467, NULL, '2015-11-15 15:38:58.352474+00', 'Lamb Skinnet', 1556, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (4468, NULL, '2015-11-15 15:40:08.6963+00', 'Triumph, The', 1556, 1, 4, 24, 9999, NULL, 119, 0, '');
INSERT INTO 'recording' VALUES (4493, NULL, '2012-01-20 12:55:27.183019+00', 'Nottingham Lace', 2188, 1, 0, 96, 9999, NULL, 107, 0, 'Tune 2 phrased AABBCB - not really suitable.');
INSERT INTO 'recording' VALUES (4494, NULL, '2012-01-20 12:55:27.18925+00', 'Rob of Balbeggie', 2188, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (4495, NULL, '2012-01-20 12:55:27.195744+00', 'Roberta Buckel''s Strathspey', 2188, 3, 5, 32, 9999, NULL, 300, 0, '');
INSERT INTO 'recording' VALUES (4496, NULL, '2012-01-20 12:55:27.201992+00', 'Military Two-Step', 2188, 11, 8, 16, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (4497, NULL, '2012-01-20 12:55:27.208215+00', 'Fisherman''s Reel', 2188, 1, 5, 32, 9999, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (4498, NULL, '2012-01-20 12:55:27.214467+00', 'Eva 3-Step or Gay Gordons', 2188, 11, 0, 16, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (4499, NULL, '2012-01-20 12:55:27.220687+00', 'Rothesay Rant, The', 2188, 2, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (4500, NULL, '2012-01-20 12:55:27.226928+00', 'Scottish Waltz', 2188, 5, 0, 0, 9999, NULL, 106, 0, '');
INSERT INTO 'recording' VALUES (4501, NULL, '2012-01-20 12:55:27.322271+00', 'Irish Reels', 2519, 1, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (4502, NULL, '2012-01-20 12:55:27.328691+00', 'Gay Gordons', 2519, 11, 0, 16, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (4503, NULL, '2012-01-20 12:55:27.335023+00', 'Lord Rosslyn''s Fancy', 3010, 2, 8, 32, 9999, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (4504, NULL, '2012-01-20 12:55:27.341291+00', 'Saint Bernard''s Waltz', 3010, 5, 0, 16, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (4506, NULL, '2012-01-20 12:55:27.354168+00', 'Peggy''s Love', 3026, 3, 4, 32, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (4507, NULL, '2012-01-20 12:55:27.360488+00', 'Alewife and her Barrel, The', 3037, 1, 3, 32, 9999, NULL, 103, 0, '');
INSERT INTO 'recording' VALUES (4508, NULL, '2012-01-20 12:55:27.366751+00', 'Medley', 3037, 4, 0, 0, 9999, NULL, 100, 0, '');
INSERT INTO 'recording' VALUES (4509, NULL, '2012-01-20 12:55:27.372972+00', 'Lamb Skinnet', 3037, 2, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (2304, NULL, '2022-06-01 18:34:43.979639+00', 'Jeannie o'' the Witchin'' E''e', 3024, 2, 5, 40, 9999, 14, 0, 0, '');
INSERT INTO 'recording' VALUES (2303, NULL, '2022-12-09 20:01:11.428774+00', 'Friskey, The', 3024, 2, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (4491, NULL, '2023-01-11 19:37:38.244786+00', 'Clutha', 2188, 1, 4, 48, 9999, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (4510, NULL, '2012-01-20 12:55:27.379324+00', 'Pure Scotch Twostep', 2171, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4511, NULL, '2012-01-20 12:55:27.385826+00', 'Forres Accordion & Fiddle Club', 2171, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2348, NULL, '2012-01-20 12:55:14.555892+00', 'Come Under my Plaidie', 1502, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2349, NULL, '2012-01-20 12:55:14.561474+00', 'Edinburgh Castle Reel, The', 1502, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2350, NULL, '2012-01-20 12:55:14.567032+00', 'Maids of Currie, The', 1502, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2351, NULL, '2012-01-20 12:55:14.57275+00', 'Miss Falconer''s Fancy', 1502, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2352, NULL, '2012-01-20 12:55:14.578307+00', 'Old Man of Storr, The', 1502, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2354, NULL, '2012-01-20 12:55:14.589337+00', 'Capelthwaite', 2065, 1, 8, 32, 9999, 5, 279, 0, '');
INSERT INTO 'recording' VALUES (2355, NULL, '2012-01-20 12:55:14.594856+00', 'Laird of Atherton, The', 903, 3, 3, 32, 9999, 5, 203, 0, '');
INSERT INTO 'recording' VALUES (2356, NULL, '2012-01-20 12:55:14.60035+00', 'On the Port Tack', 3048, 1, 8, 32, 9999, 5, 266, 0, '');
INSERT INTO 'recording' VALUES (2357, NULL, '2012-01-20 12:55:14.605856+00', 'Coming Through the Rye', 1498, 2, 8, 40, 9999, 9, 351, 0, '');
INSERT INTO 'recording' VALUES (2358, NULL, '2012-01-20 12:55:14.61137+00', 'Asilomar Romantic', 2486, 3, 8, 32, 9999, 5, 501, 0, '');
INSERT INTO 'recording' VALUES (2359, NULL, '2012-01-20 12:55:14.616908+00', 'Fizzbin - The Next Generation', 2065, 1, 4, 48, 9999, 11, 211, 0, '');
INSERT INTO 'recording' VALUES (2360, NULL, '2012-01-20 12:55:14.622444+00', 'Tiraluin', 3016, 2, 8, 32, 9999, 1, 273, 0, '');
INSERT INTO 'recording' VALUES (2313, NULL, '2014-08-05 15:27:48.877962+00', 'Hogmanay Jig, The', 3042, 2, 8, 32, 9999, 1, 262, 0, '');
INSERT INTO 'recording' VALUES (2318, NULL, '2014-08-05 15:28:43.672769+00', 'Braes of Balquhidder, The', 3042, 3, 0, 128, 9999, NULL, 235, 0, '');
INSERT INTO 'recording' VALUES (2316, NULL, '2014-08-05 15:29:47.899558+00', 'Peat Fire Flame, The', 3042, 1, 8, 40, 9999, 14, 347, 0, '');
INSERT INTO 'recording' VALUES (2311, NULL, '2014-08-05 15:30:23.789296+00', 'Duke of Atholl''s Reel, The', 3042, 2, 8, 32, 9999, 1, 260, 0, '');
INSERT INTO 'recording' VALUES (2315, NULL, '2014-08-05 15:30:52.129136+00', 'Water Kelpie, The', 3042, 1, 8, 32, 9999, 1, 276, 0, '');
INSERT INTO 'recording' VALUES (2317, NULL, '2014-08-05 15:31:41.037435+00', 'Dundee Whaler, The', 3042, 3, 4, 32, 9999, 5, 236, 0, '');
INSERT INTO 'recording' VALUES (2312, NULL, '2014-08-05 15:32:07.390085+00', 'Haste to the Wedding', 3042, 2, 8, 32, 9999, 1, 263, 0, '');
INSERT INTO 'recording' VALUES (4487, NULL, '2014-10-04 00:35:57.202373+00', 'Lassie Come and Dance Wi'' Me', 2188, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (2361, NULL, '2012-01-20 12:55:14.628004+00', 'Tomalena', 2486, 1, 5, 32, 9999, 5, 178, 0, '');
INSERT INTO 'recording' VALUES (2362, NULL, '2012-01-20 12:55:14.634055+00', 'Rose Garden, The', 3048, 3, 8, 24, 9999, 18, 381, 0, '');
INSERT INTO 'recording' VALUES (2363, NULL, '2012-01-20 12:55:14.639639+00', 'Remaking the Circle', 3016, 1, 4, 40, 9999, 5, 174, 0, '');
INSERT INTO 'recording' VALUES (2364, NULL, '2012-01-20 12:55:14.644494+00', 'Lang Frae Glasgow', 3016, 5, 8, 32, 9999, NULL, 435, 0, '');
INSERT INTO 'recording' VALUES (2327, NULL, '2021-06-13 20:13:02.439287+00', 'Belle of Bon Accord, The', 2414, 3, 4, 32, 9999, 1, 248, 0, '');
INSERT INTO 'recording' VALUES (2365, NULL, '2012-01-20 12:55:14.649301+00', 'Monterey Mixer', 3016, 1, 5, 32, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (2366, NULL, '2012-01-20 12:55:14.654125+00', 'Miss Bennet''s Jig', 3010, 2, 8, 32, 9999, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (2367, NULL, '2012-01-20 12:55:14.659757+00', 'Haddington Assembly', 3010, 2, 8, 32, 9999, 1, 255, 0, '');
INSERT INTO 'recording' VALUES (2368, NULL, '2012-01-20 12:55:14.665378+00', 'Lassies of Dunse, The', 3010, 2, 8, 32, 9999, 5, 255, 0, '');
INSERT INTO 'recording' VALUES (2369, NULL, '2012-01-20 12:55:14.670881+00', 'New Rigged Ship, The', 3010, 2, 8, 48, 9999, 25, 376, 0, '');
INSERT INTO 'recording' VALUES (2370, NULL, '2012-01-20 12:55:14.676395+00', 'Reel of Mey, The', 3010, 2, 8, 48, 9999, 4, 379, 0, '');
INSERT INTO 'recording' VALUES (2371, NULL, '2012-01-20 12:55:14.681899+00', 'Dashing White Sergeant, The', 3010, 1, 6, 32, 9999, 1, 195, 0, '');
INSERT INTO 'recording' VALUES (2372, NULL, '2012-01-20 12:55:14.687413+00', 'Highland Laddie', 3010, 1, 8, 32, 9999, 1, 257, 0, '');
INSERT INTO 'recording' VALUES (2373, NULL, '2012-01-20 12:55:14.692893+00', 'Kiss me Quick, my Mither''s Coming', 3010, 1, 8, 32, 9999, 1, 254, 0, '');
INSERT INTO 'recording' VALUES (2374, NULL, '2012-01-20 12:55:14.698416+00', 'Duchess of Atholl''s Slipper, The', 3010, 3, 8, 32, 9999, 5, 460, 0, '');
INSERT INTO 'recording' VALUES (2375, NULL, '2012-01-20 12:55:14.703915+00', 'Two and Two', 3010, 2, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2376, NULL, '2012-01-20 12:55:14.709432+00', 'Just as I Was in the Morning', 3010, 2, 8, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (2377, NULL, '2012-01-20 12:55:14.714958+00', 'Peggy''s Wedding', 3010, 2, 4, 64, 9999, 3, 0, 0, '');
INSERT INTO 'recording' VALUES (2378, NULL, '2012-01-20 12:55:14.720476+00', 'Bonnie Anne', 3010, 2, 0, 96, 9999, 1, 100, 0, '');
INSERT INTO 'recording' VALUES (2380, NULL, '2012-01-20 12:55:14.73146+00', 'De''il Amang the Tailors, The', 3010, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2381, NULL, '2012-01-20 12:55:14.736976+00', 'Angus MacLeod', 3010, 1, 2, 64, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2382, NULL, '2012-01-20 12:55:14.749352+00', 'Dalkeith''s Strathspey', 3010, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2383, NULL, '2012-01-20 12:55:14.757129+00', 'Lochiel''s Rant', 3010, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2384, NULL, '2012-01-20 12:55:14.763847+00', 'Waltz Country Dance', 3010, 5, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2385, NULL, '2012-01-20 12:55:14.771079+00', 'Reel of the 51st Division, The', 2069, 1, 8, 32, 9999, 1, 259, 0, '');
INSERT INTO 'recording' VALUES (2386, NULL, '2012-01-20 12:55:14.778342+00', 'Linton Ploughman, The', 2069, 2, 8, 32, 9999, 1, 257, 0, '');
INSERT INTO 'recording' VALUES (4512, NULL, '2012-01-20 12:55:27.394557+00', 'Clutha', 2171, 1, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4513, NULL, '2012-01-20 12:55:27.401169+00', 'Frisco Waltz', 2171, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4514, NULL, '2012-01-20 12:55:27.407452+00', 'Royal Burgh Forres'' Wlcm to Citizens of Vienenburg', 2171, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4515, NULL, '2012-01-20 12:55:27.413717+00', 'Gay Gordons', 2171, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4516, NULL, '2012-01-20 12:55:27.420176+00', 'It''s Just for Fun', 2171, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4517, NULL, '2012-01-20 12:55:27.426535+00', 'Maureen & Neil''s Waltz', 2171, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4518, NULL, '2012-01-20 12:55:27.432854+00', 'Fiddle Solo', 2171, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4519, NULL, '2012-01-20 12:55:27.439425+00', 'New Petronella, The', 2171, 1, 2, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4520, NULL, '2012-01-20 12:55:27.445686+00', 'Linton Ploughman', 2171, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4521, NULL, '2012-01-20 12:55:27.452075+00', 'Canadian Barn Dance', 2171, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4522, NULL, '2012-01-20 12:55:27.458437+00', 'Gay Gordons', 3050, 11, 0, 16, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (4523, NULL, '2012-01-20 12:55:27.464922+00', 'Punch Bowl, The', 3050, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (4524, NULL, '2012-01-20 12:55:27.471224+00', 'Pride of Erin Waltz', 3050, 5, 0, 32, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (4526, NULL, '2012-01-20 12:55:27.483809+00', 'Continental Feature', 3050, 13, 0, 0, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (4527, NULL, '2012-01-20 12:55:27.490075+00', 'College Hornpipe', 3050, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (4528, NULL, '2012-01-20 12:55:27.496294+00', 'Pipe Medley', 3050, 98, 0, 0, 9999, NULL, 396, 0, '');
INSERT INTO 'recording' VALUES (4529, NULL, '2012-01-20 12:55:27.502657+00', 'Haste to the Wedding', 3050, 2, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (4530, NULL, '2012-01-20 12:55:27.50888+00', 'Itchy Fingers', 3050, 98, 0, 0, 9999, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (4531, NULL, '2012-01-20 12:55:27.515321+00', 'Saint Bernard''s Waltz', 3050, 5, 0, 16, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (2387, NULL, '2012-01-20 12:55:14.784679+00', 'Scottish Waltz', 2069, 5, 0, 0, 9999, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (2389, NULL, '2012-01-20 12:55:14.799866+00', 'Dashing White Sergeant, The', 2069, 1, 8, 32, 9999, 1, 264, 0, '');
INSERT INTO 'recording' VALUES (2390, NULL, '2012-01-20 12:55:14.806959+00', 'Duke of Perth', 2069, 1, 8, 32, 9999, 1, 241, 0, '');
INSERT INTO 'recording' VALUES (2391, NULL, '2012-01-20 12:55:14.812652+00', 'Strip the Willow', 2069, 2, 8, 32, 9999, 1, 252, 0, '');
INSERT INTO 'recording' VALUES (2392, NULL, '2012-01-20 12:55:14.818349+00', 'Gay Gordons', 2069, 11, 0, 16, 9999, 1, 145, 0, '');
INSERT INTO 'recording' VALUES (2393, NULL, '2012-01-20 12:55:14.824056+00', 'Petronella', 2069, 1, 8, 32, 9999, 1, 257, 0, '');
INSERT INTO 'recording' VALUES (2394, NULL, '2012-01-20 12:55:14.82893+00', 'Highland Schottische', 2069, 3, 0, 8, 9999, NULL, 122, 0, '');
INSERT INTO 'recording' VALUES (2395, NULL, '2012-01-20 12:55:14.835147+00', 'Circassian Circle', 2069, 1, 8, 32, 9999, 1, 257, 0, '');
INSERT INTO 'recording' VALUES (2396, NULL, '2012-01-20 12:55:14.840805+00', 'Wemyss Place Hornpipe, The', 2064, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2397, NULL, '2012-01-20 12:55:14.846556+00', 'Merrily Danced the Quaker''s Wife', 2064, 2, 8, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (2353, NULL, '2023-01-22 12:43:32.042482+00', 'Swashbuckling Iain', 3048, 2, 8, 32, 9999, 1, 281, 0, '');
INSERT INTO 'recording' VALUES (2398, NULL, '2012-01-20 12:55:14.852102+00', 'Royal Mile, The', 2064, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2399, NULL, '2012-01-20 12:55:14.857557+00', 'Earl of Errol''s Reel, The', 2064, 2, 0, 200, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2401, NULL, '2012-01-20 12:55:14.868065+00', 'Bothwell Brig', 2064, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2402, NULL, '2012-01-20 12:55:14.873707+00', 'Brig o'' Aboyne', 2064, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2403, NULL, '2012-01-20 12:55:14.879429+00', 'Lorn Strathspey, The', 2064, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2404, NULL, '2012-01-20 12:55:14.885204+00', 'Miss Irene Fidler''s Strathspey', 2064, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2413, NULL, '2012-01-20 12:55:14.935278+00', 'Jigs', 2068, 2, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2414, NULL, '2012-01-20 12:55:14.94077+00', 'Corn Rigs', 2068, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2415, NULL, '2012-01-20 12:55:14.946376+00', 'Braes of Breadalbane, The', 2068, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2417, NULL, '2012-01-20 12:55:14.957768+00', 'Jigs', 2068, 2, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2418, NULL, '2012-01-20 12:55:14.963347+00', 'Strathspeys', 2068, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2419, NULL, '2012-01-20 12:55:14.969058+00', 'Loch Leven Castle', 2068, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2420, NULL, '2012-01-20 12:55:14.973948+00', 'Waltzes', 2068, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2421, NULL, '2012-01-20 12:55:14.978756+00', 'Highland Schottische', 3001, 3, 0, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2422, NULL, '2012-01-20 12:55:14.984239+00', 'Hollin Buss, The', 3001, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2425, NULL, '2012-01-20 12:55:14.999434+00', 'Wild Geese, The', 3001, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2427, NULL, '2012-01-20 12:55:15.009838+00', 'Duran Ranger, The', 3001, 1, 8, 32, 9999, 1, 279, 0, '');
INSERT INTO 'recording' VALUES (4532, NULL, '2012-01-20 12:55:27.522022+00', 'Polka', 3050, 13, 0, 0, 9999, NULL, 121, 0, '');
INSERT INTO 'recording' VALUES (4533, NULL, '2012-01-20 12:55:27.528313+00', 'Express, The', 3050, 2, 4, 40, 9999, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (2423, NULL, '2014-09-16 11:33:00.713195+00', 'Buckshaw Reel', 2188, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (2426, NULL, '2014-09-16 11:39:21.654199+00', 'Muriel''s Fancy', 2188, 2, 4, 40, 9999, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (4534, NULL, '2012-01-20 12:55:27.534591+00', 'Slow Air', 3050, 98, 0, 0, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (4535, NULL, '2012-01-20 12:55:27.540823+00', 'Canadian Barn Dance', 3050, 11, 0, 16, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (4536, NULL, '2012-01-20 12:55:27.547205+00', 'Dashing White Sergeant, The', 3050, 1, 6, 32, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (4537, NULL, '2012-01-20 12:55:27.553433+00', 'Jig 3x32', 3060, 2, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4538, NULL, '2012-01-20 12:55:27.559834+00', 'Strathspey 4x32', 3060, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4539, NULL, '2012-01-20 12:55:27.566183+00', 'Hornpipe', 3060, 1, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2379, NULL, '2021-04-05 21:47:16.787783+00', 'Back o'' Bennachie, The', 3010, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2400, NULL, '2021-06-13 13:03:24.023477+00', 'Pulling Bracken', 2064, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (4541, NULL, '2012-01-20 12:55:27.578664+00', 'Strathspey 4x32', 3060, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4542, NULL, '2012-01-20 12:55:27.585094+00', 'Reel 3x32', 3060, 1, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4543, NULL, '2012-01-20 12:55:27.591507+00', 'Jig 4x32', 3060, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4544, NULL, '2012-01-20 12:55:27.597757+00', 'Reel 4x32', 3060, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4545, NULL, '2012-01-20 12:55:27.604264+00', 'Jig 4x40', 3060, 2, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4546, NULL, '2012-01-20 12:55:27.610722+00', 'Strathspey 2x40', 3060, 3, 2, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4547, NULL, '2012-01-20 12:55:27.617144+00', 'Reel 4x32', 3060, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4548, NULL, '2012-01-20 12:55:27.627576+00', 'Jig 4x32', 3060, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4549, NULL, '2012-01-20 12:55:27.633858+00', 'Strathspey 4x40', 3060, 3, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4550, NULL, '2012-01-20 12:55:27.640094+00', 'Reel 3x40', 3060, 1, 3, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4551, NULL, '2012-01-20 12:55:27.646334+00', 'Jig 5x32', 3060, 2, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4552, NULL, '2012-01-20 12:55:27.652656+00', 'Across the Border', 2566, 1, 4, 48, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (2408, NULL, '2013-02-04 14:34:33.061206+00', 'Celtic Brooch, The', 2067, 2, 6, 32, 9999, 1, 204, 0, '');
INSERT INTO 'recording' VALUES (2406, NULL, '2013-02-04 14:39:22.478111+00', 'Cairn Edward', 2067, 2, 8, 24, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (2412, NULL, '2013-02-04 14:41:07.684064+00', 'John McAlpin', 2067, 3, 8, 32, 9999, 5, 502, 0, '');
INSERT INTO 'recording' VALUES (2409, NULL, '2013-02-04 14:42:22.720692+00', 'Black Craig of Dee', 2067, 1, 8, 32, 9999, 1, 277, 0, '');
INSERT INTO 'recording' VALUES (2428, NULL, '2012-01-20 12:55:15.015337+00', 'Highland Laddie', 3001, 1, 8, 32, 9999, 1, 267, 0, '');
INSERT INTO 'recording' VALUES (2429, NULL, '2012-01-20 12:55:15.0209+00', 'Kiss Me Quick, Ma Mither''s Comin''', 3001, 1, 8, 32, 9999, 1, 266, 0, '');
INSERT INTO 'recording' VALUES (2430, NULL, '2012-01-20 12:55:15.025731+00', 'White Heather Jig, The', 2133, 2, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2431, NULL, '2012-01-20 12:55:15.03133+00', 'Caledonian Rant', 3001, 3, 3, 32, 9999, 5, 178, 0, '');
INSERT INTO 'recording' VALUES (2432, NULL, '2012-01-20 12:55:15.036162+00', 'Irish Waltz Medley', 2173, 5, 0, 0, 9999, NULL, 243, 0, '');
INSERT INTO 'recording' VALUES (2433, NULL, '2012-01-20 12:55:15.04181+00', 'Champagne Reel, The', 1590, 1, 8, 32, 9999, 1, 278, 0, '');
INSERT INTO 'recording' VALUES (2434, NULL, '2012-01-20 12:55:15.047313+00', 'Monday Night', 1590, 2, 4, 32, 9999, 1, 152, 0, '');
INSERT INTO 'recording' VALUES (2435, NULL, '2012-01-20 12:55:15.052941+00', 'Blenheim Butterfly, The', 1590, 3, 3, 32, 9999, 5, 205, 0, '');
INSERT INTO 'recording' VALUES (2436, NULL, '2012-01-20 12:55:15.058463+00', 'Road to Auchnafree, The', 1590, 1, 5, 32, 9999, 1, 181, 0, '');
INSERT INTO 'recording' VALUES (2437, NULL, '2012-01-20 12:55:15.063957+00', 'Suffolk Lanes', 1590, 2, 4, 48, 9999, 11, 219, 0, '');
INSERT INTO 'recording' VALUES (2438, NULL, '2012-01-20 12:55:15.069539+00', 'Humming Bird, The', 1590, 2, 5, 32, 9999, 1, 182, 0, '');
INSERT INTO 'recording' VALUES (2439, NULL, '2012-01-20 12:55:15.074504+00', 'MacPhail Medley, A', 1590, 99, 0, 0, 9999, NULL, 364, 0, '');
INSERT INTO 'recording' VALUES (2440, NULL, '2012-01-20 12:55:15.080028+00', 'Garthmyl', 1590, 3, 4, 32, 9999, 5, 269, 0, '');
INSERT INTO 'recording' VALUES (2441, NULL, '2012-01-20 12:55:15.085591+00', 'Diamond Celebration, The', 1590, 2, 8, 32, 9999, 1, 282, 0, '');
INSERT INTO 'recording' VALUES (2442, NULL, '2012-01-20 12:55:15.091225+00', 'Polite Strathspey, The', 1590, 3, 8, 32, 9999, 5, 535, 0, '');
INSERT INTO 'recording' VALUES (2443, NULL, '2012-01-20 12:55:15.096722+00', 'Radcliffe Square', 1590, 4, 0, 128, 2, 1, 209, 0, '');
INSERT INTO 'recording' VALUES (2411, NULL, '2017-09-16 14:20:21.695193+00', 'Curleywee', 2067, 3, 8, 32, 9999, 5, 523, 0, '');
INSERT INTO 'recording' VALUES (2407, NULL, '2017-09-16 14:23:38.283026+00', 'Captain Whiteside', 2067, 2, 8, 32, 9999, 1, 266, 0, '');
INSERT INTO 'recording' VALUES (2410, NULL, '2017-09-18 11:16:15.418127+00', 'New Howford Brig', 2067, 1, 8, 32, 9999, 5, 263, 0, '');
INSERT INTO 'recording' VALUES (556, NULL, '2018-12-07 17:27:59.433946+00', 'Highland Medley, A', 3018, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2445, NULL, '2012-01-20 12:55:15.107969+00', 'Dancing Years, The', 3002, 1, 0, 88, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2446, NULL, '2012-01-20 12:55:15.1149+00', 'Minister on the Loch, The', 3002, 3, 3, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2447, NULL, '2012-01-20 12:55:15.12045+00', 'Ciamar a Tha', 3002, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2449, NULL, '2012-01-20 12:55:15.131595+00', 'Auld Friends Meet', 3002, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2450, NULL, '2012-01-20 12:55:15.137302+00', 'Kingston Jig, The', 3002, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2451, NULL, '2012-01-20 12:55:15.14301+00', 'South From Oban', 3002, 2, 8, 40, 9999, 14, 0, 0, '');
INSERT INTO 'recording' VALUES (2452, NULL, '2012-01-20 12:55:15.148589+00', 'Walled Garden, The', 3002, 3, 6, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2453, NULL, '2012-01-20 12:55:15.15562+00', 'Dancing Bees, The', 3002, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2456, NULL, '2012-01-20 12:55:15.173796+00', 'Lantern of the North, The', 3042, 2, 8, 32, 9999, 1, 258, 0, '');
INSERT INTO 'recording' VALUES (2458, NULL, '2012-01-20 12:55:15.18492+00', 'Mary Rose Hornpipe, The', 3042, 1, 8, 40, 9999, 6, 332, 0, '');
INSERT INTO 'recording' VALUES (2459, NULL, '2012-01-20 12:55:15.190496+00', 'Sound of Harris, The', 3042, 1, 3, 48, 9999, 11, 156, 0, '');
INSERT INTO 'recording' VALUES (2460, NULL, '2012-01-20 12:55:15.196101+00', 'Courage Reel, The', 3042, 1, 8, 48, 9999, 4, 389, 0, '');
INSERT INTO 'recording' VALUES (2461, NULL, '2012-01-20 12:55:15.201609+00', 'Flower of the Quern, The', 3042, 3, 4, 32, 9999, 5, 264, 0, '');
INSERT INTO 'recording' VALUES (2462, NULL, '2012-01-20 12:55:15.207101+00', 'Birks of Invermay, The', 3042, 3, 8, 32, 9999, 5, 474, 0, '');
INSERT INTO 'recording' VALUES (2464, NULL, '2012-01-20 12:55:15.218241+00', 'Bob Gilmour''s return to Scotland', 2414, 2, 5, 32, 9999, 1, 164, 0, '');
INSERT INTO 'recording' VALUES (2466, NULL, '2012-01-20 12:55:15.228565+00', 'MacDonald of Sleat', 2414, 2, 0, 120, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (4553, NULL, '2012-01-20 12:55:27.658897+00', 'Ardchoille Park', 2566, 3, 4, 32, 9999, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (4554, NULL, '2012-01-20 12:55:27.665277+00', 'Crosshills Jig', 2566, 2, 4, 32, 9999, NULL, 145, 1, '');
INSERT INTO 'recording' VALUES (4555, NULL, '2012-01-20 12:55:27.671524+00', 'Donald''s Fancy', 2566, 1, 0, 88, 9999, NULL, 100, 0, '');
INSERT INTO 'recording' VALUES (4556, NULL, '2012-01-20 12:55:27.677746+00', 'Frae Near and Far', 2566, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (4557, NULL, '2012-01-20 12:55:27.683973+00', 'Heather Dewar', 2566, 3, 4, 32, 9999, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (4558, NULL, '2012-01-20 12:55:27.690213+00', 'Kirkbrae Jig', 2566, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (4559, NULL, '2012-01-20 12:55:27.696438+00', 'Tigh Mor', 2566, 1, 5, 40, 9999, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (4560, NULL, '2012-01-20 12:55:27.702683+00', 'Langholm Braes', 2566, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (4561, NULL, '2012-01-20 12:55:27.708889+00', 'Longtown Rant', 2566, 1, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (4562, NULL, '2012-01-20 12:55:27.715144+00', 'O''er the Esk', 2566, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (4563, NULL, '2012-01-20 12:55:27.721377+00', 'Saint Barnabas Strathspey', 2566, 3, 5, 32, 9999, NULL, 313, 0, '');
INSERT INTO 'recording' VALUES (4564, NULL, '2012-01-20 12:55:27.727628+00', 'Sunset Over Solway', 2566, 3, 4, 32, 9999, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (4565, NULL, '2012-01-20 12:55:27.733865+00', 'Upper Tarr', 2566, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (4566, NULL, '2012-01-20 12:55:27.740099+00', 'Fisherman''s Reel', 2570, 1, 5, 32, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (4567, NULL, '2012-01-20 12:55:27.746359+00', 'Flying Spur, The', 2570, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (4568, NULL, '2012-01-20 12:55:27.752574+00', 'Scotch Mist', 2570, 3, 5, 32, 9999, NULL, 324, 0, '');
INSERT INTO 'recording' VALUES (4569, NULL, '2012-01-20 12:55:27.758912+00', 'Swiss Lassie', 2162, 1, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (4570, NULL, '2012-01-20 12:55:27.765129+00', 'Wapenshaw', 2570, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (4572, NULL, '2012-01-20 12:55:27.775696+00', 'Campbell''s Hornpipe', 2570, 1, 4, 32, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (4573, NULL, '2012-01-20 12:55:27.780521+00', 'Joie De Vivre', 2570, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (2467, NULL, '2012-01-20 12:55:15.233369+00', 'Ian Powrie''s Farewell to Auchterarder', 2414, 2, 0, 128, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (2468, NULL, '2012-01-20 12:55:15.239215+00', 'Duke of Perth', 2414, 1, 8, 32, 9999, 1, 263, 0, '');
INSERT INTO 'recording' VALUES (2469, NULL, '2012-01-20 12:55:15.245177+00', 'Duke of Perth - Encore', 2414, 1, 4, 32, 9999, 1, 134, 0, '');
INSERT INTO 'recording' VALUES (2470, NULL, '2012-01-20 12:55:15.251322+00', 'Sailor, The', 2414, 1, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (2455, NULL, '2021-06-13 19:30:55.147124+00', 'Flying Spur, The', 3042, 2, 8, 32, 9999, 1, 260, 0, '');
INSERT INTO 'recording' VALUES (2454, NULL, '2021-08-20 15:08:39.025216+00', 'Cabrach, The', 3002, 4, 4, 32, 5, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2457, NULL, '2021-07-03 12:24:30.332053+00', 'Dance of Diamonds, The', 3042, 1, 8, 32, 9999, 1, 264, 0, '');
INSERT INTO 'recording' VALUES (2472, NULL, '2012-01-20 12:55:15.262512+00', 'Irish Rover, The', 2414, 1, 8, 32, 9999, 10, 259, 0, '');
INSERT INTO 'recording' VALUES (2473, NULL, '2012-01-20 12:55:15.268192+00', 'Mrs Hepburn Belches', 2414, 1, 8, 48, 9999, 30, 396, 0, '');
INSERT INTO 'recording' VALUES (2474, NULL, '2012-01-20 12:55:15.273028+00', 'Strathspey Medley', 3010, 3, 8, 32, 9999, NULL, 475, 0, '');
INSERT INTO 'recording' VALUES (2475, NULL, '2012-01-20 12:55:15.278555+00', 'Duchess Tree, The', 2414, 3, 8, 32, 9999, 1, 487, 0, '');
INSERT INTO 'recording' VALUES (2476, NULL, '2012-01-20 12:55:15.283425+00', 'Petronella', 2133, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2477, NULL, '2012-01-20 12:55:15.288888+00', 'Happy Meeting, The', 1502, 2, 4, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2478, NULL, '2012-01-20 12:55:15.294405+00', 'Kendall''s Hornpipe', 1502, 2, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2479, NULL, '2012-01-20 12:55:15.300109+00', 'Miss Mary Douglas', 1502, 2, 4, 48, 9999, 41, 0, 0, '');
INSERT INTO 'recording' VALUES (2480, NULL, '2012-01-20 12:55:15.305016+00', 'Glasgow Country Dance', 1502, 4, 4, 32, 1, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2481, NULL, '2012-01-20 12:55:15.310508+00', 'Gates of Edinburgh', 1502, 1, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2482, NULL, '2012-01-20 12:55:15.317957+00', 'General Stuart''s Reel', 1502, 1, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2483, NULL, '2012-01-20 12:55:15.325196+00', 'Kingussie Flower', 1502, 1, 4, 40, 9999, 6, 0, 0, '');
INSERT INTO 'recording' VALUES (2484, NULL, '2012-01-20 12:55:15.33154+00', 'Glasgow Highlanders, The', 1502, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2485, NULL, '2012-01-20 12:55:15.338666+00', 'Miss Milligan''s Strathspey', 1502, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2486, NULL, '2012-01-20 12:55:15.345783+00', 'Peggy''s Love', 1502, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2487, NULL, '2012-01-20 12:55:15.352061+00', 'Wateraid Jig', 2566, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2488, NULL, '2012-01-20 12:55:15.359173+00', 'Village Reel', 1502, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (10176, '2018-03-31 11:01:31.824565+00', '2018-03-31 11:01:31.824565+00', 'Madge Wildfire''s Strathspey', 11611, 3, 4, 32, NULL, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (2501, NULL, '2012-01-20 12:55:15.474915+00', 'Jigtime Medley', 2038, 2, 5, 32, 9999, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (2502, NULL, '2012-01-20 12:55:15.479866+00', 'Reel of the 51st Division, The', 2038, 1, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (2503, NULL, '2012-01-20 12:55:15.484673+00', 'Jigtime Polka', 2038, 13, 0, 0, 9999, NULL, 115, 0, '');
INSERT INTO 'recording' VALUES (2504, NULL, '2012-01-20 12:55:15.489489+00', 'Highland Schottische', 2038, 3, 0, 8, 9999, NULL, 159, 0, '');
INSERT INTO 'recording' VALUES (2505, NULL, '2012-01-20 12:55:15.494302+00', 'Jacobite Waltz Medley', 2038, 5, 0, 0, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (2506, NULL, '2012-01-20 12:55:15.499094+00', 'Mairi''s Wedding', 2038, 1, 8, 40, 9999, NULL, 358, 0, '');
INSERT INTO 'recording' VALUES (2497, NULL, '2016-05-25 14:32:38.691407+00', 'Sarona', 883, 3, 4, 32, 9999, 5, 247, 1, '');
INSERT INTO 'recording' VALUES (2492, NULL, '2016-05-25 14:33:25.316407+00', 'Bonnie Anne', 883, 2, 0, 96, 9999, 1, 107, 0, '');
INSERT INTO 'recording' VALUES (2493, NULL, '2016-05-25 14:34:20.084102+00', '1314', 883, 4, 0, 128, 2, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (2495, NULL, '2016-05-25 14:35:04.689132+00', 'Highland Lass, The', 883, 1, 8, 32, 9999, 1, 269, 0, '');
INSERT INTO 'recording' VALUES (2498, NULL, '2016-05-25 14:36:06.74143+00', 'Ellwyn Strathspey, The', 883, 3, 4, 48, 9999, 4, 347, 0, '');
INSERT INTO 'recording' VALUES (2491, NULL, '2016-05-25 14:37:30.620051+00', 'Gleneagle''s Dominie', 883, 2, 4, 48, 9999, 4, 202, 1, '');
INSERT INTO 'recording' VALUES (2496, NULL, '2016-05-25 14:38:22.488652+00', 'Montgomeries'' Rant, The', 883, 1, 8, 32, 9999, 5, 273, 0, '');
INSERT INTO 'recording' VALUES (2500, NULL, '2016-05-25 14:39:11.008893+00', 'Ullapool Waltz, The', 883, 5, 0, 0, 9999, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (4571, NULL, '2017-09-04 21:05:56.326874+00', 'Rose of the North, The', 2570, 3, 8, 32, 9999, NULL, 511, 0, '');
INSERT INTO 'recording' VALUES (2508, NULL, '2012-01-20 12:55:15.509554+00', 'Military Two-Step', 2038, 11, 0, 16, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (2509, NULL, '2012-01-20 12:55:15.514383+00', 'Waltz Country Dance', 2038, 5, 4, 40, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (2510, NULL, '2012-01-20 12:55:15.519178+00', 'Lamb Skinnet', 2038, 2, 8, 32, 9999, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (2511, NULL, '2012-01-20 12:55:15.523984+00', 'Gay Gordons', 2038, 11, 0, 16, 9999, NULL, 220, 0, '');
INSERT INTO 'recording' VALUES (2513, NULL, '2012-01-20 12:55:15.533576+00', 'Gates of Edinburgh, The', 2092, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2514, NULL, '2012-01-20 12:55:15.53906+00', 'Swilcan, The', 2065, 2, 4, 32, 9999, 1, 151, 0, '');
INSERT INTO 'recording' VALUES (2516, NULL, '2012-01-20 12:55:15.550193+00', 'Leaving Saint Kilda', 2065, 99, 0, 0, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (2517, NULL, '2012-01-20 12:55:15.555668+00', 'Braes of Mellinish, The', 2065, 3, 8, 32, 9999, 1, 500, 0, '');
INSERT INTO 'recording' VALUES (2518, NULL, '2012-01-20 12:55:15.560489+00', 'Bastringue, La', 2065, 99, 6, 0, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (2520, NULL, '2012-01-20 12:55:15.570912+00', 'Back Home', 2065, 99, 0, 0, 9999, NULL, 410, 0, '');
INSERT INTO 'recording' VALUES (2521, NULL, '2012-01-20 12:55:15.576147+00', 'Thistle on the Faultline', 2065, 98, 0, 0, 9999, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (2522, NULL, '2012-01-20 12:55:15.581757+00', 'Brisk Young Lad, The', 2065, 2, 5, 48, 9999, 11, 270, 0, '');
INSERT INTO 'recording' VALUES (2523, NULL, '2012-01-20 12:55:15.587251+00', 'Any Good Jig', 2066, 2, 8, 32, 9999, 1, 280, 0, '');
INSERT INTO 'recording' VALUES (4574, NULL, '2012-01-20 12:55:27.785319+00', 'Mrs Milne of Kinneff', 2570, 3, 4, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (4575, NULL, '2012-01-20 12:55:27.790342+00', 'Minard Castle', 2570, 1, 8, 40, 9999, NULL, 343, 0, '');
INSERT INTO 'recording' VALUES (4576, NULL, '2012-01-20 12:55:27.795156+00', 'Frisky, The', 2570, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (4577, NULL, '2012-01-20 12:55:27.799951+00', 'Our Lady Of The Snows', 2570, 3, 4, 32, 9999, NULL, 264, 1, '');
INSERT INTO 'recording' VALUES (4578, NULL, '2012-01-20 12:55:27.804964+00', 'Merrily Danced The Quaker''s Wife', 2570, 2, 8, 40, 9999, NULL, 351, 0, '');
INSERT INTO 'recording' VALUES (4579, NULL, '2012-01-20 12:55:27.809891+00', 'Angus MacLeod', 2570, 1, 2, 64, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (2512, NULL, '2022-12-25 23:57:47.446465+00', 'Primrose Polka', 2038, 13, 0, 0, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (2489, NULL, '2023-01-20 10:20:03.253262+00', 'Mamie''s Jig', 883, 2, 4, 32, 9999, 1, 135, 0, '');
INSERT INTO 'recording' VALUES (4580, NULL, '2012-01-20 12:55:27.81478+00', 'Kelpie Of Loch Coruisk, The', 3036, 1, 7, 32, 9999, NULL, 239, 0, '');
INSERT INTO 'recording' VALUES (4581, NULL, '2012-01-20 12:55:27.819619+00', 'Flying Scotsman, The', 3036, 2, 8, 32, 9999, NULL, 254, 0, '');
INSERT INTO 'recording' VALUES (4582, NULL, '2012-01-20 12:55:27.824453+00', 'Mrs Garthland''s Strathspey', 3036, 3, 8, 32, 9999, NULL, 479, 0, '');
INSERT INTO 'recording' VALUES (4583, NULL, '2012-01-20 12:55:27.829303+00', 'Mrs MacPherson of Inveran', 3036, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (2507, NULL, '2012-04-22 18:03:19.014756+00', 'Road to the Isles, The', 2038, 3, 4, 32, 9999, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (2524, NULL, '2012-01-20 12:55:15.595468+00', 'Light and Airy', 2066, 2, 8, 32, 9999, 1, 275, 0, '');
INSERT INTO 'recording' VALUES (2526, NULL, '2012-01-20 12:55:15.609794+00', 'Fireside Reel, The', 2066, 1, 8, 32, 9999, 5, 270, 0, '');
INSERT INTO 'recording' VALUES (2527, NULL, '2012-01-20 12:55:15.616876+00', 'Highlandman Kissed his Mother, The', 2066, 1, 8, 32, 9999, 5, 270, 0, '');
INSERT INTO 'recording' VALUES (2528, NULL, '2012-01-20 12:55:15.623177+00', 'Goat Fell Gallop', 3002, 2, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (2529, NULL, '2012-01-20 12:55:15.630343+00', 'Invercauld''s Reel', 2066, 3, 8, 32, 9999, 5, 485, 0, '');
INSERT INTO 'recording' VALUES (2530, NULL, '2012-01-20 12:55:15.636044+00', 'This is No My Ain Hoose', 2066, 3, 8, 32, 9999, 5, 490, 0, '');
INSERT INTO 'recording' VALUES (2531, NULL, '2012-01-20 12:55:15.640899+00', 'Wateraid Reel', 2566, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2532, NULL, '2012-01-20 12:55:15.646366+00', 'Campbeltown Loch', 3039, 2, 4, 48, 9999, 11, 0, 1, '');
INSERT INTO 'recording' VALUES (2533, NULL, '2012-01-20 12:55:15.651866+00', 'Alexandria Reel, The', 3039, 2, 4, 48, 9999, 30, 0, 0, '');
INSERT INTO 'recording' VALUES (2534, NULL, '2012-01-20 12:55:15.657354+00', 'Pines of Pitlochry, The', 3039, 2, 8, 48, 9999, 30, 0, 0, '');
INSERT INTO 'recording' VALUES (2535, NULL, '2012-01-20 12:55:15.66171+00', 'Foursome and Half Reel of Tulloch', 3039, 4, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2536, NULL, '2012-01-20 12:55:15.667246+00', 'Montgomeries'' Rant, The', 3039, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2537, NULL, '2012-01-20 12:55:15.673035+00', 'Pinewoods Reel', 3039, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2538, NULL, '2012-01-20 12:55:15.678666+00', 'Lady Susan Stewart''s Reel', 3039, 1, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2539, NULL, '2012-01-20 12:55:15.683467+00', 'Dunvegan Castle', 3039, 4, 4, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2540, NULL, '2012-01-20 12:55:15.688264+00', 'Round Reel of Eight', 3039, 1, 0, 88, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2541, NULL, '2012-01-20 12:55:15.693743+00', 'Mary Hamilton', 3039, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2542, NULL, '2012-01-20 12:55:15.699216+00', 'Dunsinane', 3039, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2544, NULL, '2012-01-20 12:55:15.709911+00', 'Muirland Willie', 3039, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2545, NULL, '2012-01-20 12:55:15.715391+00', 'Ladies'' Fancy', 3039, 2, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2546, NULL, '2012-01-20 12:55:15.720861+00', 'Miss Cahoon''s Reel', 3039, 2, 8, 48, 9999, 11, 0, 0, '');
INSERT INTO 'recording' VALUES (2547, NULL, '2012-01-20 12:55:15.725709+00', 'Barn Dance', 2173, 50, 0, 0, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (2548, NULL, '2012-01-20 12:55:15.731179+00', 'Lauderdale Lads or Corn Rigs', 3039, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2549, NULL, '2012-01-20 12:55:15.736784+00', 'Maxwell''s Rant', 3039, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2550, NULL, '2012-01-20 12:55:15.742395+00', 'Mr Wilson''s Hornpipe', 3039, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2551, NULL, '2012-01-20 12:55:15.750341+00', 'Red House', 3039, 1, 8, 40, 9999, 39, 0, 0, '');
INSERT INTO 'recording' VALUES (2552, NULL, '2012-01-20 12:55:15.757599+00', 'Drumelzier', 3039, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2553, NULL, '2012-01-20 12:55:15.764646+00', 'Jimmy''s Fancy', 3039, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2554, NULL, '2012-01-20 12:55:15.769676+00', 'Robertson Rant, The', 3039, 3, 0, 80, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2563, NULL, '2012-01-20 12:55:15.828236+00', 'Rumle Quadrille', 2061, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4587, NULL, '2012-01-20 12:55:27.848536+00', 'Kiss For Nothing, A', 3036, 2, 8, 32, 9999, NULL, 254, 0, '');
INSERT INTO 'recording' VALUES (4588, NULL, '2012-01-20 12:55:27.853436+00', 'Cape Town Wedding', 3036, 3, 8, 32, 9999, NULL, 474, 0, '');
INSERT INTO 'recording' VALUES (4589, NULL, '2012-01-20 12:55:27.858246+00', 'Old Nick''s Lumber Room', 3036, 2, 8, 32, 9999, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (4590, NULL, '2012-01-20 12:55:27.863239+00', 'Braes Of Mellinish, The', 3036, 3, 8, 32, 9999, NULL, 476, 0, '');
INSERT INTO 'recording' VALUES (4591, NULL, '2012-01-20 12:55:27.868042+00', 'Moving Cloud, The', 3036, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (4592, NULL, '2012-01-20 12:55:27.873034+00', 'Prince Of Orange', 3036, 2, 8, 16, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (4593, NULL, '2012-01-20 12:55:27.878107+00', 'Punch Bowl, The', 3036, 1, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (4594, NULL, '2012-01-20 12:55:27.882965+00', 'Take Care', 3006, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4595, NULL, '2012-01-20 12:55:27.887776+00', 'Damaris Reel, The', 3006, 1, 2, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4596, NULL, '2012-01-20 12:55:27.892795+00', 'Spring Chicken', 3006, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4597, NULL, '2012-01-20 12:55:27.897687+00', '96 Ten, The', 3006, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4598, NULL, '2012-01-20 12:55:27.90248+00', 'ABC Jig, The', 3006, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4599, NULL, '2012-01-20 12:55:27.907268+00', 'Come to Fiona''s Wedding', 3009, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4600, NULL, '2012-01-20 12:55:27.912108+00', 'Happy Hours', 3009, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4601, NULL, '2012-01-20 12:55:27.916934+00', 'Foursome Reel and Reel of Tulloch', 3009, 4, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4602, NULL, '2012-01-20 12:55:27.921754+00', 'Gaelic Waltz', 3009, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4603, NULL, '2012-01-20 12:55:27.926868+00', 'Dashing White Sergeant, The', 3009, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4604, NULL, '2012-01-20 12:55:27.93177+00', 'Bonnie Anne', 3009, 2, 0, 96, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2490, NULL, '2016-05-25 14:28:34.034772+00', 'Waggle of the Kilt, The', 883, 2, 8, 40, 9999, 43, 323, 0, '');
INSERT INTO 'recording' VALUES (2494, NULL, '2016-05-25 14:30:05.988487+00', 'Blooms of Bon Accord, The', 883, 1, 4, 32, 9999, 5, 145, 1, '');
INSERT INTO 'recording' VALUES (4586, NULL, '2017-09-22 16:14:16.038024+00', 'Admiral Nelson', 3036, 1, 4, 64, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (10178, '2018-03-31 11:06:49.316987+00', '2018-03-31 11:06:49.316987+00', 'Scandinavian Sweetie, A', 11611, 5, 0, 0, NULL, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (2559, NULL, '2013-02-04 14:11:18.359289+00', 'Earlstoun Loch', 2067, 1, 5, 32, 9999, 1, 176, 0, '');
INSERT INTO 'recording' VALUES (2557, NULL, '2013-02-04 14:11:55.700673+00', 'Tillietudlum', 2067, 2, 8, 32, 9999, 1, 273, 0, '');
INSERT INTO 'recording' VALUES (2555, NULL, '2013-02-04 14:12:36.178142+00', 'Clachan, The', 2067, 2, 8, 32, 9999, 3, 270, 0, '');
INSERT INTO 'recording' VALUES (2556, NULL, '2013-02-04 14:14:30.931346+00', 'Miss Stewart''s Jig', 2067, 2, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (2564, NULL, '2012-01-20 12:55:15.833684+00', 'Boston Hospitality', 2061, 2, 5, 32, 9999, 1, 181, 0, '');
INSERT INTO 'recording' VALUES (2565, NULL, '2012-01-20 12:55:15.839455+00', 'Stow Alert', 2061, 1, 4, 40, 9999, 6, 176, 0, '');
INSERT INTO 'recording' VALUES (2567, NULL, '2012-01-20 12:55:15.850591+00', 'Boston Fiddle Club Jig, The', 2061, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2568, NULL, '2012-01-20 12:55:15.855413+00', 'Pipe Marches', 2173, 2, 0, 0, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (2569, NULL, '2012-01-20 12:55:15.860924+00', 'Pinewoods Reel', 2061, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (2570, NULL, '2012-01-20 12:55:15.865741+00', 'Waltzes', 2061, 5, 0, 0, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (2571, NULL, '2012-01-20 12:55:15.871684+00', 'Postie''s Jig', 2414, 2, 4, 32, 9999, 10, 135, 0, '');
INSERT INTO 'recording' VALUES (2572, NULL, '2012-01-20 12:55:15.877243+00', 'Set of Jigs', 2414, 2, 8, 32, 9999, 1, 270, 0, '');
INSERT INTO 'recording' VALUES (2573, NULL, '2012-01-20 12:55:15.882767+00', 'Hooper''s Jig', 2414, 2, 8, 32, 9999, 1, 270, 0, '');
INSERT INTO 'recording' VALUES (2574, NULL, '2012-01-20 12:55:15.888258+00', 'Blooms of Bon Accord, The', 2414, 1, 4, 32, 9999, 1, 145, 1, '');
INSERT INTO 'recording' VALUES (2575, NULL, '2012-01-20 12:55:15.89308+00', 'Lomond Waltz, The', 2414, 5, 0, 0, 9999, NULL, 298, 0, '');
INSERT INTO 'recording' VALUES (2577, NULL, '2012-01-20 12:55:15.904081+00', 'Polharrow Burn', 2414, 1, 5, 32, 9999, 1, 175, 0, '');
INSERT INTO 'recording' VALUES (2578, NULL, '2012-01-20 12:55:15.9098+00', 'Reel Eleven', 2414, 1, 8, 32, 9999, 1, 270, 0, '');
INSERT INTO 'recording' VALUES (2579, NULL, '2012-01-20 12:55:15.915674+00', 'J.B. Milne', 2414, 1, 8, 32, 9999, 10, 270, 0, '');
INSERT INTO 'recording' VALUES (2580, NULL, '2012-01-20 12:55:15.921189+00', 'Mrs MacPherson of Inveran', 2414, 1, 8, 32, 9999, 5, 280, 0, '');
INSERT INTO 'recording' VALUES (2581, NULL, '2012-01-20 12:55:15.926764+00', 'Meeting of the Waters, The', 2414, 1, 8, 48, 9999, 41, 405, 0, '');
INSERT INTO 'recording' VALUES (2582, NULL, '2012-01-20 12:55:15.93225+00', 'MacDonald of the Isles', 2414, 3, 3, 32, 9999, 5, 180, 0, '');
INSERT INTO 'recording' VALUES (2543, NULL, '2022-12-20 12:00:52.745321+00', 'St Andrews Platinum Reel, The', 3006, 1, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (4584, NULL, '2023-01-15 18:38:14.424092+00', 'MacPherson''s Jig', 3036, 2, 3, 32, 9999, NULL, 99, 0, '');
INSERT INTO 'recording' VALUES (2583, NULL, '2012-01-20 12:55:15.937727+00', 'Scotch Mist', 2414, 3, 5, 32, 9999, 5, 305, 0, '');
INSERT INTO 'recording' VALUES (2584, NULL, '2012-01-20 12:55:15.942571+00', 'Robertson Rant, The', 2414, 3, 0, 80, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (2585, NULL, '2012-01-20 12:55:15.947388+00', 'Scottish Waltz', 2414, 5, 0, 0, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (2590, NULL, '2013-02-03 17:10:16.4333+00', 'Campbell''s Frolic', 2060, 2, 8, 32, 9999, 1, 262, 0, '');
INSERT INTO 'recording' VALUES (2598, NULL, '2012-01-20 12:55:16.016335+00', 'Bees of Maggieknockater, The', 883, 2, 4, 32, 9999, 1, 137, 0, '');
INSERT INTO 'recording' VALUES (2599, NULL, '2012-01-20 12:55:16.021279+00', 'Kincaid Medley, The', 883, 4, 4, 32, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (2600, NULL, '2012-01-20 12:55:16.026804+00', 'Schiehallion Medley', 883, 4, 0, 128, 2, 5, 194, 0, '');
INSERT INTO 'recording' VALUES (2601, NULL, '2012-01-20 12:55:16.032294+00', 'Princess Royal, The', 883, 1, 8, 28, 9999, 21, 239, 0, '');
INSERT INTO 'recording' VALUES (2602, NULL, '2012-01-20 12:55:16.03786+00', 'Polharrow Burn', 883, 1, 5, 32, 9999, 1, 230, 0, '');
INSERT INTO 'recording' VALUES (2603, NULL, '2012-01-20 12:55:16.043375+00', 'Bratach Bana', 883, 1, 8, 32, 9999, 1, 265, 0, '');
INSERT INTO 'recording' VALUES (2604, NULL, '2012-01-20 12:55:16.049071+00', 'Neidpath Castle', 883, 3, 3, 32, 9999, 5, 203, 0, '');
INSERT INTO 'recording' VALUES (4606, NULL, '2012-01-20 12:55:27.941402+00', 'Strip the Willow', 3009, 2, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4607, NULL, '2012-01-20 12:55:27.946197+00', 'Penny Whistle Barn Dance', 3009, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4608, NULL, '2012-01-20 12:55:27.950983+00', 'Pipe Marches', 3009, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4609, NULL, '2012-01-20 12:55:27.955839+00', 'Forty Shades of Green', 3009, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4610, NULL, '2012-01-20 12:55:27.960628+00', 'My Love She''s but a Lassie Yet', 3010, 1, 8, 32, 9999, NULL, 0, 1, '');
INSERT INTO 'recording' VALUES (4612, NULL, '2012-01-20 12:55:27.970209+00', 'Miss Catherine Ann', 3139, 3, 3, 32, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (4613, NULL, '2012-01-20 12:55:27.975084+00', 'Last of the Lairds, The', 2162, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (4614, NULL, '2012-01-20 12:55:27.97988+00', 'Adieu mon Ami', 2162, 3, 8, 32, 9999, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (4615, NULL, '2012-01-20 12:55:27.98467+00', 'Blue Bonnets', 2162, 2, 8, 32, 9999, NULL, 299, 0, '');
INSERT INTO 'recording' VALUES (4616, NULL, '2012-01-20 12:55:27.989446+00', 'Deil amang the Tailors, The', 2162, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (4617, NULL, '2012-01-20 12:55:27.994336+00', 'Waltz', 2162, 5, 0, 0, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (4618, NULL, '2012-01-20 12:55:27.999164+00', 'Fireside Reel, The', 2162, 1, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (4619, NULL, '2012-01-20 12:55:28.003957+00', 'Flock of Geese, A', 2162, 2, 5, 32, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (4620, NULL, '2012-01-20 12:55:28.00878+00', 'Sailor, The', 2162, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (4621, NULL, '2012-01-20 12:55:28.014052+00', 'Miss Gibson''s Strathspey', 2162, 3, 8, 32, 9999, NULL, 501, 0, '');
INSERT INTO 'recording' VALUES (2562, NULL, '2021-03-28 13:17:49.746681+00', 'Iron Gray', 2067, 3, 8, 32, 9999, 1, 530, 0, '');
INSERT INTO 'recording' VALUES (4622, NULL, '2012-01-20 12:55:28.019631+00', 'Mrs Stewart''s Jig', 2162, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (4623, NULL, '2012-01-20 12:55:28.025572+00', 'Montgomeries'' Rant or The Full Monty', 2162, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (4611, NULL, '2012-08-18 16:03:18.754415+00', 'Birks of Invermay, The', 3010, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2586, NULL, '2013-02-03 16:15:06.494539+00', 'Barn Dance', 2060, 11, 4, 32, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (2587, NULL, '2013-02-03 16:18:35.070039+00', 'Gay Gordons', 2060, 11, 8, 16, 9999, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (2588, NULL, '2013-02-03 16:23:08.63408+00', 'College Hornpipe', 2060, 1, 4, 32, 9999, 1, 138, 0, '');
INSERT INTO 'recording' VALUES (2589, NULL, '2013-02-03 16:27:49.350031+00', 'Swilcan Jig, The', 2060, 2, 4, 32, 9999, 1, 136, 0, '');
INSERT INTO 'recording' VALUES (2597, NULL, '2013-02-03 16:41:58.330617+00', 'Waltz', 2060, 5, 0, 0, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (2596, NULL, '2013-02-03 16:49:36.761121+00', 'Braes of Breadalbane, The', 2060, 3, 4, 32, 9999, 5, 238, 0, '');
INSERT INTO 'recording' VALUES (2595, NULL, '2013-02-03 16:52:13.588563+00', 'Mairi''s Wedding Reel', 2060, 1, 4, 40, 9999, 27, 170, 0, '');
INSERT INTO 'recording' VALUES (2593, NULL, '2013-02-03 16:58:29.319262+00', 'Primrose Polka, The', 2060, 13, 0, 0, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (2592, NULL, '2013-02-03 17:01:25.509152+00', 'Happy Harry Polka', 2060, 13, 5, 16, 9999, NULL, 119, 0, '');
INSERT INTO 'recording' VALUES (2591, NULL, '2013-02-03 17:05:36.977157+00', 'Wild Geese', 2060, 2, 8, 32, 9999, 1, 262, 0, '');
INSERT INTO 'recording' VALUES (2605, NULL, '2012-01-20 12:55:16.054588+00', 'Belle of Bon Accord, The', 883, 3, 4, 32, 9999, 1, 246, 0, '');
INSERT INTO 'recording' VALUES (2606, NULL, '2012-01-20 12:55:16.060797+00', 'Scotch Mist', 883, 3, 5, 32, 9999, 5, 310, 0, '');
INSERT INTO 'recording' VALUES (2607, NULL, '2012-01-20 12:55:16.065621+00', 'Mount Seymour Waltz', 883, 5, 0, 0, 9999, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (2608, NULL, '2013-02-04 14:26:39.052127+00', 'Airie Bennan', 2067, 2, 5, 32, 9999, 5, 164, 0, '');
INSERT INTO 'recording' VALUES (2612, NULL, '2013-02-04 14:27:03.71957+00', 'J.B. Milne', 2067, 1, 8, 32, 9999, 5, 264, 0, '');
INSERT INTO 'recording' VALUES (2614, NULL, '2013-02-04 14:27:33.000778+00', 'Anne', 2067, 3, 8, 32, 9999, 5, 495, 0, '');
INSERT INTO 'recording' VALUES (2610, NULL, '2013-02-04 14:28:16.928741+00', 'Wee Cooper o'' Fife, The', 2067, 2, 8, 40, 9999, NULL, 314, 0, '');
INSERT INTO 'recording' VALUES (2611, NULL, '2013-02-04 14:28:48.488832+00', 'Polharrow Burn', 2067, 1, 5, 32, 9999, 1, 155, 0, '');
INSERT INTO 'recording' VALUES (2609, NULL, '2013-02-04 14:29:15.103665+00', 'Roaring Jelly', 2067, 2, 8, 32, 9999, 1, 258, 0, '');
INSERT INTO 'recording' VALUES (2616, NULL, '2012-01-20 12:55:16.182196+00', 'Duke of Atholl''s Reel, The', 1502, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2617, NULL, '2012-01-20 12:55:16.201471+00', 'Golden Pheasant, The', 1502, 2, 4, 40, 9999, 41, 0, 0, '');
INSERT INTO 'recording' VALUES (2618, NULL, '2012-01-20 12:55:16.20714+00', 'Glasgow Country Dance', 1502, 4, 4, 32, 1, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2619, NULL, '2012-01-20 12:55:16.212636+00', 'Gates of Edinburgh, The', 1502, 1, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2566, NULL, '2018-11-20 13:50:18.751179+00', 'Ms Gillian McMullen of Cambridge', 2061, 3, 4, 32, 9999, 5, 248, 0, '');
INSERT INTO 'recording' VALUES (2558, NULL, '2019-02-25 13:33:53.316985+00', 'Rob Roy', 2067, 1, 4, 32, 9999, 1, 138, 0, '');
INSERT INTO 'recording' VALUES (2561, NULL, '2019-07-24 18:18:14.994266+00', 'Castles in the Air', 2067, 3, 8, 32, 9999, 5, 499, 0, '');
INSERT INTO 'recording' VALUES (2594, NULL, '2019-09-30 22:07:01.939554+00', 'Black Dance, The', 2060, 1, 8, 32, 9999, 1, 273, 0, '');
INSERT INTO 'recording' VALUES (4605, NULL, '2019-10-29 11:03:35.754424+00', 'Megan''s Favourite', 3139, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (2620, NULL, '2012-01-20 12:55:16.2183+00', 'Miss Hadden''s Reel', 1502, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2621, NULL, '2012-01-20 12:55:16.225361+00', 'General Stuart''s Reel', 1502, 1, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2622, NULL, '2012-01-20 12:55:16.231775+00', 'Cumbrae Reel, The', 1502, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2623, NULL, '2012-01-20 12:55:16.238061+00', 'Mrs Hamilton of Wishaw', 1502, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2624, NULL, '2012-01-20 12:55:16.244341+00', 'Alltshellach', 1502, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2625, NULL, '2012-01-20 12:55:16.250654+00', 'Miss Gibson''s Strathspey', 1502, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2626, NULL, '2012-01-20 12:55:16.257706+00', 'Up in the Air', 1502, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2627, NULL, '2012-01-20 12:55:16.264131+00', 'Village Reel', 1502, 3, 4, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (2628, NULL, '2012-01-20 12:55:16.269066+00', 'Friday''s Child', 2414, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2629, NULL, '2012-01-20 12:55:16.273868+00', 'Bon Voyage', 2414, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2630, NULL, '2012-01-20 12:55:16.278647+00', 'Whistlin'' In the Kitchen', 2414, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2631, NULL, '2012-01-20 12:55:16.28346+00', 'Wee Cooper o'' Fife, The', 2414, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2632, NULL, '2012-01-20 12:55:16.288265+00', 'Ship of Grace', 2414, 3, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2633, NULL, '2012-01-20 12:55:16.293074+00', 'Peat Fire Flame, The', 2414, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2634, NULL, '2012-01-20 12:55:16.29789+00', 'MacLeod''s Fancy', 2414, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2636, NULL, '2012-01-20 12:55:16.307477+00', 'Mrs MacPherson of Inveran', 2414, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2637, NULL, '2012-01-20 12:55:16.312259+00', 'MacDonald of the Isles', 2414, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2638, NULL, '2012-01-20 12:55:16.317041+00', 'Ray''s Waltzes', 2414, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2639, NULL, '2012-01-20 12:55:16.321831+00', 'Blithe and Cheerie', 3067, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (2640, NULL, '2012-01-20 12:55:16.326614+00', 'From Scotia''s Shores We''re Noo Awa''', 3067, 3, 8, 32, 9999, NULL, 507, 0, '');
INSERT INTO 'recording' VALUES (2641, NULL, '2012-01-20 12:55:16.331406+00', 'John Anderson''s Reel', 3067, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (2642, NULL, '2012-01-20 12:55:16.336434+00', 'Gushet Neuk', 3067, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (2644, NULL, '2012-01-20 12:55:16.34618+00', 'Maskelia', 3067, 1, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (4625, NULL, '2012-01-20 12:55:28.035513+00', 'Waltz', 2162, 5, 0, 0, 9999, NULL, 222, 0, '');
INSERT INTO 'recording' VALUES (4626, NULL, '2012-01-20 12:55:28.040333+00', 'Visit to Kelburn, A', 2583, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4627, NULL, '2012-01-20 12:55:28.045125+00', 'Gay Gordons Two-step', 2583, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4629, NULL, '2012-01-20 12:55:28.054799+00', 'White Heather Jig, The', 2583, 2, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4630, NULL, '2012-01-20 12:55:28.059616+00', 'Alloway Rant, The', 2583, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4631, NULL, '2012-01-20 12:55:28.072256+00', 'Canadian Barn Dance', 2583, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4632, NULL, '2012-01-20 12:55:28.078609+00', 'Waltz Country Dance', 2583, 5, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4633, NULL, '2012-01-20 12:55:28.084853+00', 'North Ayrshire Welcome, A', 2583, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4634, NULL, '2012-01-20 12:55:28.091137+00', 'Danure Castle', 2583, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4635, NULL, '2012-01-20 12:55:28.097467+00', 'Eva Three Step', 2583, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4636, NULL, '2012-01-20 12:55:28.10395+00', 'New Kilarney Waltz', 2583, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4637, NULL, '2012-01-20 12:55:28.110507+00', 'Balmoral Strathspey', 2583, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4638, NULL, '2012-01-20 12:55:28.116824+00', 'Dunoon Barn Dance', 2583, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4639, NULL, '2012-01-20 12:55:28.123415+00', 'Marine Four Step', 2583, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4640, NULL, '2012-01-20 12:55:28.130324+00', 'Jacky Tar Two-step', 2583, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4641, NULL, '2012-01-20 12:55:28.138104+00', 'Salute to Ayr Branch', 2583, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4642, NULL, '2012-01-20 12:55:28.144665+00', 'Mrs MacLeod', 2584, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (4643, NULL, '2012-01-20 12:55:28.151096+00', 'Culla Bay', 2584, 3, 4, 32, 9999, NULL, 247, 0, '');
INSERT INTO 'recording' VALUES (4644, NULL, '2012-01-20 12:55:28.157415+00', 'Jennifer''s Jig', 2584, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (2613, NULL, '2013-02-04 14:25:12.303082+00', 'Caller Herrin''', 2067, 1, 8, 40, 9999, 27, 330, 0, '');
INSERT INTO 'recording' VALUES (2615, NULL, '2013-02-04 14:26:06.480283+00', 'Kendoon Strathspey, The', 2067, 3, 8, 32, 9999, 3, 476, 0, '');
INSERT INTO 'recording' VALUES (2647, NULL, '2012-01-20 12:55:16.36066+00', 'Riggs of Corn', 3067, 1, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (2648, NULL, '2012-01-20 12:55:16.365449+00', 'Glasgow Assembly', 3067, 4, 0, 64, 5, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (2649, NULL, '2012-01-20 12:55:16.370455+00', 'Geneva Park', 3067, 2, 4, 40, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (2650, NULL, '2012-01-20 12:55:16.380281+00', 'Links o'' Forth, The', 3067, 1, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (2651, NULL, '2012-01-20 12:55:16.386634+00', 'Ashokan Farewell', 3067, 5, 0, 0, 9999, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (2643, NULL, '2021-06-21 21:36:30.43995+00', 'Golden Ring, The', 3067, 3, 4, 32, 9999, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (2652, NULL, '2012-01-20 12:55:16.398903+00', 'Memories', 2042, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (2653, NULL, '2012-01-20 12:55:16.405428+00', 'Auld Toon o'' Ayr, The', 2042, 3, 8, 32, 9999, NULL, 477, 0, '');
INSERT INTO 'recording' VALUES (2654, NULL, '2012-01-20 12:55:16.411812+00', 'Amelia''s Waltz', 2042, 5, 0, 0, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (2655, NULL, '2012-01-20 12:55:16.418114+00', 'Icebreaker', 2042, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (2656, NULL, '2012-01-20 12:55:16.424631+00', 'Perfect Ending, The', 2042, 3, 4, 40, 9999, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (2657, NULL, '2012-01-20 12:55:16.431012+00', 'Hairy Mary', 2042, 1, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (2658, NULL, '2012-01-20 12:55:16.437306+00', 'Sweet Basil', 2042, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (10179, '2018-03-31 11:09:04.82235+00', '2018-03-31 11:09:04.82235+00', 'Canadian Barn Dance', 11611, 99, 0, 0, NULL, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (2660, NULL, '2012-01-20 12:55:16.463128+00', 'Cool as a Cucumber', 2042, 2, 3, 32, 9999, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (2661, NULL, '2012-01-20 12:55:16.469424+00', 'Beal''s Reel', 2042, 1, 5, 40, 9999, NULL, 226, 0, '');
INSERT INTO 'recording' VALUES (2662, NULL, '2012-01-20 12:55:16.475746+00', 'Pinewoods Medley', 2042, 4, 4, 64, 5, NULL, 405, 0, '');
INSERT INTO 'recording' VALUES (2663, NULL, '2012-01-20 12:55:16.482148+00', 'Piper''s Leg, The', 2042, 2, 5, 32, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (2664, NULL, '2012-01-20 12:55:16.488536+00', 'Reel of the 51st Division, The', 3045, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2665, NULL, '2012-01-20 12:55:16.495121+00', 'Eva Three Step', 3045, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2681, NULL, '2012-01-20 12:55:16.596979+00', 'Hamilton Rant, The', 2062, 1, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2682, NULL, '2012-01-20 12:55:16.603282+00', 'Haymakers, The', 3063, 2, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2635, NULL, '2017-02-22 14:22:30.774266+00', 'Kilkenny Castle', 2414, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4628, NULL, '2017-06-17 10:50:47.712072+00', 'Southern Rose Waltz', 2583, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2666, NULL, '2017-06-17 10:51:12.90382+00', 'Southern Rose Waltz', 3045, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2683, NULL, '2012-01-20 12:55:16.609532+00', 'Mairi''s Wedding', 3010, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2684, NULL, '2012-01-20 12:55:16.615961+00', 'Duke of Perth', 3010, 1, 8, 32, 9999, NULL, 254, 0, '');
INSERT INTO 'recording' VALUES (2685, NULL, '2012-01-20 12:55:16.622295+00', 'Dundee Reel', 3010, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2687, NULL, '2012-01-20 12:55:16.635434+00', 'Russe, La', 3010, 1, 6, 32, 9999, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (4645, NULL, '2012-01-20 12:55:28.163956+00', 'Ellwyn''s Fairy Glen', 2584, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (4646, NULL, '2012-01-20 12:55:28.170229+00', 'Moray Rant, The', 2584, 3, 3, 48, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (4647, NULL, '2012-01-20 12:55:28.17654+00', 'Campbell''s Frolic', 2584, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (4648, NULL, '2012-01-20 12:55:28.182913+00', 'Chevy Chase', 2584, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (4649, NULL, '2012-01-20 12:55:28.189146+00', 'Lamb Skinnet', 2584, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (4650, NULL, '2012-01-20 12:55:28.195402+00', 'Rob Roy', 2584, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (4651, NULL, '2012-01-20 12:55:28.201725+00', 'Moment Of Truth', 2584, 3, 8, 32, 9999, NULL, 481, 0, '');
INSERT INTO 'recording' VALUES (4652, NULL, '2012-01-20 12:55:28.207976+00', 'Blacksmith Of Elgin', 2584, 2, 8, 48, 9999, NULL, 414, 0, '');
INSERT INTO 'recording' VALUES (4653, NULL, '2012-01-20 12:55:28.214256+00', 'Miss Thompson''s Reel', 2584, 1, 5, 32, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (4654, NULL, '2012-01-20 12:55:28.220594+00', 'Off She Goes In The North', 2584, 2, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (4655, NULL, '2012-01-20 12:55:28.227045+00', 'Bolt Court', 2584, 1, 4, 48, 9999, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (4656, NULL, '2012-01-20 12:55:28.233287+00', 'Rory O''More', 2585, 2, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (4657, NULL, '2012-01-20 12:55:28.239595+00', 'Man''s a Man for A'' That, A', 2585, 3, 8, 32, 9999, NULL, 469, 0, '');
INSERT INTO 'recording' VALUES (4658, NULL, '2012-01-20 12:55:28.245873+00', 'Dance Of Diamonds, The', 2585, 1, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (4659, NULL, '2012-01-20 12:55:28.252297+00', 'Farewell to Crumlin', 2585, 2, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (4660, NULL, '2012-01-20 12:55:28.258571+00', 'Blue Bonnets', 2585, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (4661, NULL, '2012-01-20 12:55:28.265116+00', 'Frae A'' the Airts', 2585, 4, 8, 32, 1, NULL, 381, 0, '');
INSERT INTO 'recording' VALUES (4662, NULL, '2012-01-20 12:55:28.271674+00', 'Bonnie Dundee', 2585, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (4663, NULL, '2012-01-20 12:55:28.277938+00', 'Gypsy Glen', 2585, 3, 3, 32, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (4664, NULL, '2012-01-20 12:55:28.284285+00', 'Meeting Of The Waters, The', 2585, 1, 8, 48, 9999, NULL, 421, 0, '');
INSERT INTO 'recording' VALUES (2646, NULL, '2012-05-06 22:02:53.750534+00', 'Campsie Glen', 3067, 3, 8, 32, 9999, NULL, 515, 0, '');
INSERT INTO 'recording' VALUES (2688, NULL, '2012-01-20 12:55:16.641993+00', 'Machine Without Horses, The', 3010, 2, 6, 32, 9999, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (2689, NULL, '2012-01-20 12:55:16.648043+00', 'Merrily Danced the Quaker''s Wife', 3010, 2, 12, 16, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (2690, NULL, '2012-01-20 12:55:16.653158+00', 'New Rigged Ship, The', 3010, 2, 6, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (2691, NULL, '2012-01-20 12:55:16.659528+00', 'Petronella', 3010, 1, 0, 0, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (2692, NULL, '2012-01-20 12:55:16.664484+00', 'Reel of the 51st Division, The', 3010, 1, 5, 32, 9999, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (2693, NULL, '2012-01-20 12:55:16.66929+00', 'Circassian Circle', 2088, 1, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (2694, NULL, '2012-01-20 12:55:16.67424+00', 'Drops of Brandy', 2088, 1, 6, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (2695, NULL, '2012-01-20 12:55:16.679051+00', 'Duke of Perth', 2088, 1, 8, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (2696, NULL, '2012-01-20 12:55:16.683848+00', 'Flying Scotsman, The', 2088, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (2698, NULL, '2012-01-20 12:55:16.693516+00', 'Orcadian Strip the Willow, The', 2088, 2, 8, 32, 9999, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (2699, NULL, '2012-01-20 12:55:16.699533+00', 'Cumberland Square Eight', 2089, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2700, NULL, '2012-01-20 12:55:16.704355+00', 'Dashing White Sergeant, The', 2089, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2701, NULL, '2012-01-20 12:55:16.709144+00', 'Eightsome Reel, The', 2089, 1, 0, 464, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2702, NULL, '2012-01-20 12:55:16.713951+00', 'Flying Scotsman, The', 2089, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2703, NULL, '2012-01-20 12:55:16.718886+00', 'Orcadian Strip the Willow, The', 2089, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2704, NULL, '2012-01-20 12:55:16.723683+00', 'Strip the Willow', 2089, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2705, NULL, '2012-01-20 12:55:16.728529+00', 'Virginia Reel', 2089, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2707, NULL, '2012-01-20 12:55:16.738913+00', 'Dashing White Sergeant, The', 2088, 1, 8, 32, 9999, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (2708, NULL, '2012-01-20 12:55:16.743721+00', 'Eightsome Reel, The', 2088, 1, 1, 464, 9999, NULL, 464, 0, '');
INSERT INTO 'recording' VALUES (2709, NULL, '2012-01-20 12:55:16.748539+00', 'Foula Reel, The', 2088, 2, 8, 32, 9999, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (2710, NULL, '2012-01-20 12:55:16.754085+00', 'Strip the Willow', 2088, 2, 8, 32, 9999, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (2711, NULL, '2012-01-20 12:55:16.759065+00', 'Waltz Country Dance', 2088, 5, 0, 40, 9999, NULL, 243, 0, '');
INSERT INTO 'recording' VALUES (2712, NULL, '2012-01-20 12:55:16.763879+00', 'Dashing White Sergeant, The', 2090, 1, 8, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (2668, NULL, '2020-05-22 20:49:44.28209+00', 'Major Ian Stewart', 3045, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2667, NULL, '2020-05-22 21:27:41.981841+00', 'Barn Dance', 3045, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2669, NULL, '2020-05-22 21:32:00.905834+00', 'Slow Foxtrot', 3045, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2671, NULL, '2020-05-22 21:37:36.174716+00', 'Polka', 3045, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2672, NULL, '2020-05-22 21:42:14.488088+00', 'Boston Two-step', 3045, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2673, NULL, '2020-05-22 21:46:19.325293+00', 'Modern Waltz', 3045, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2674, NULL, '2020-05-22 21:48:16.651946+00', 'Call of the Pipes', 3045, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2676, NULL, '2020-05-22 22:04:21.48956+00', 'Gay Gordons', 3045, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2677, NULL, '2020-05-22 21:58:42.0843+00', 'Medley', 3045, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2678, NULL, '2020-05-22 22:06:28.136416+00', 'Saint Bernard''s Waltz', 3045, 5, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2679, NULL, '2020-05-22 22:08:29.827543+00', 'Canadian Barn Dance', 3045, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2680, NULL, '2020-05-22 22:11:23.740133+00', 'College Hornpipe, The', 3045, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2670, NULL, '2020-05-22 22:13:22.768441+00', 'Tribute To Alex MacArthur', 3045, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2714, NULL, '2012-01-20 12:55:16.77452+00', 'Duke and Duchess of Edinburgh, The (encore)', 2090, 1, 8, 40, 9999, NULL, 331, 0, '');
INSERT INTO 'recording' VALUES (2715, NULL, '2012-01-20 12:55:16.779443+00', 'Duke and Duchess of Edinburgh, The', 2090, 1, 8, 40, 9999, NULL, 329, 0, '');
INSERT INTO 'recording' VALUES (2716, NULL, '2012-01-20 12:55:16.784251+00', 'Duke of Perth', 2090, 1, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (2717, NULL, '2012-01-20 12:55:16.793675+00', 'Duke of Perth (encore)', 2090, 1, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (2719, NULL, '2012-01-20 12:55:16.806218+00', 'Foursome Reel', 2090, 4, 0, 0, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (2720, NULL, '2012-01-20 12:55:16.812106+00', 'Hamilton House', 2090, 2, 8, 32, 9999, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (2721, NULL, '2012-01-20 12:55:16.817072+00', 'Hamilton House (encore)', 2090, 2, 8, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (2722, NULL, '2012-01-20 12:55:16.821901+00', 'Reel of the 51st Division, The', 2090, 1, 8, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (2723, NULL, '2012-01-20 12:55:16.82671+00', 'Reel of the 51st Division, The', 2090, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2724, NULL, '2012-01-20 12:55:16.839204+00', 'Scottish Reform', 2090, 2, 8, 32, 9999, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (2725, NULL, '2012-01-20 12:55:16.845509+00', 'Strip the Willow', 2090, 2, 8, 32, 9999, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (2726, NULL, '2012-01-20 12:55:16.851813+00', 'Strip the Willow (encore)', 2090, 2, 8, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (2727, NULL, '2012-01-20 12:55:16.858114+00', 'Reel Medley', 1595, 1, 8, 16, 9999, NULL, 128, 0, '');
INSERT INTO 'recording' VALUES (4665, NULL, '2012-01-20 12:55:28.290587+00', 'Rothesay Country Dance', 2585, 2, 8, 48, 9999, NULL, 399, 0, '');
INSERT INTO 'recording' VALUES (4666, NULL, '2012-01-20 12:55:28.297066+00', 'Soldier''s Joy, The', 2585, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (4667, NULL, '2012-01-20 12:55:28.303474+00', 'Stirling Castle', 2585, 3, 4, 32, 9999, NULL, 238, 0, '');
INSERT INTO 'recording' VALUES (4668, NULL, '2012-01-20 12:55:28.309723+00', 'Swiss Lassie', 2585, 1, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (4669, NULL, '2012-01-20 12:55:28.316447+00', 'Deveron Reel, The', 2585, 1, 4, 40, 9999, NULL, 177, 1, '');
INSERT INTO 'recording' VALUES (4671, NULL, '2012-01-20 12:55:28.329232+00', 'Auchinellan Jig', 3040, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (4672, NULL, '2012-01-20 12:55:28.335722+00', 'Cambuskenneth', 3040, 3, 0, 80, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (4673, NULL, '2012-01-20 12:55:28.3424+00', 'Tullyvolan', 3040, 1, 5, 32, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (4675, NULL, '2012-01-20 12:55:28.354964+00', 'Dancing Dominie, The', 3040, 3, 4, 32, 9999, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (4676, NULL, '2012-01-20 12:55:28.361206+00', 'Dunivard Reel, The', 3040, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (4677, NULL, '2012-01-20 12:55:28.367529+00', 'Spiffin''', 3040, 2, 5, 32, 9999, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (4678, NULL, '2012-01-20 12:55:28.373806+00', 'Kinfauns Castle', 3040, 3, 5, 32, 9999, NULL, 300, 0, '');
INSERT INTO 'recording' VALUES (4679, NULL, '2012-01-20 12:55:28.380046+00', 'Kenora Reel, The', 3040, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (4680, NULL, '2012-01-20 12:55:28.386743+00', 'Faraway Isle, The', 3040, 2, 4, 48, 9999, NULL, 206, 1, '');
INSERT INTO 'recording' VALUES (4670, NULL, '2019-04-12 16:14:58.707701+00', 'Crossing The Line', 3040, 1, 6, 32, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (4681, NULL, '2012-01-20 12:55:28.393512+00', 'Royal Wedding, The', 3040, 3, 8, 32, 9999, NULL, 482, 0, '');
INSERT INTO 'recording' VALUES (4682, NULL, '2012-01-20 12:55:28.40069+00', 'Anniversary Reel', 3040, 1, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (4683, NULL, '2012-01-20 12:55:28.407201+00', 'Equilibrium', 3040, 2, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (4684, NULL, '2012-01-20 12:55:28.413507+00', 'Machine Without Horses, The', 2586, 2, 8, 32, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (2728, NULL, '2012-01-20 12:55:16.864369+00', 'Reel Medley', 1595, 1, 6, 16, 9999, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (2729, NULL, '2012-01-20 12:55:16.87123+00', 'Mairi''s Wedding', 1595, 1, 0, 64, 9999, NULL, 78, 0, '');
INSERT INTO 'recording' VALUES (2730, NULL, '2012-01-20 12:55:16.8785+00', 'Jig Medley', 1595, 2, 5, 32, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (2731, NULL, '2012-01-20 12:55:16.885489+00', 'Hamilton House', 2092, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2732, NULL, '2012-01-20 12:55:16.892475+00', 'Camp of Pleasure, The', 2092, 3, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2733, NULL, '2012-01-20 12:55:16.898727+00', 'Mairi''s Wedding', 2092, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2734, NULL, '2012-01-20 12:55:16.904976+00', 'Waltz Country Dance', 2092, 5, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2735, NULL, '2012-01-20 12:55:16.91124+00', 'Duke of Perth', 2092, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2736, NULL, '2012-01-20 12:55:16.918046+00', 'Bonnie Anne', 2092, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2737, NULL, '2012-01-20 12:55:16.922915+00', 'Highland Laddie', 2092, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2738, NULL, '2012-01-20 12:55:16.927708+00', 'Hamilton House', 2092, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2739, NULL, '2012-01-20 12:55:16.932684+00', 'Russe, La', 2039, 1, 8, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2740, NULL, '2012-01-20 12:55:16.937519+00', 'Eight Men of Moidart, The', 2039, 1, 4, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2741, NULL, '2012-01-20 12:55:16.942347+00', 'Waltz Country Dance', 2039, 5, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2742, NULL, '2012-01-20 12:55:16.947713+00', 'Circassian Circle', 2039, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2743, NULL, '2012-01-20 12:55:16.952785+00', 'White Cockade, The', 2039, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2744, NULL, '2012-01-20 12:55:16.957599+00', 'Foursome Reel, The', 2039, 4, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2745, NULL, '2012-01-20 12:55:16.962387+00', 'Gaelic Waltz', 2039, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2746, NULL, '2012-01-20 12:55:16.967192+00', 'Rory O'' More', 2039, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2747, NULL, '2012-01-20 12:55:16.971987+00', 'Mr Wilson''s Hornpipe', 2039, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2748, NULL, '2012-01-20 12:55:16.976875+00', 'Express, The', 2039, 2, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2749, NULL, '2012-01-20 12:55:16.981706+00', 'Lochiel''s Rant', 2039, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2750, NULL, '2012-01-20 12:55:16.987136+00', 'Madge Wildfire''s Strathspey', 2039, 3, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2751, NULL, '2012-01-20 12:55:16.99207+00', 'Reels', 2093, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2752, NULL, '2012-01-20 12:55:16.996918+00', 'Davie''s Brae', 2093, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2753, NULL, '2012-01-20 12:55:17.001732+00', 'Braes of Breadalbane, The', 2093, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2754, NULL, '2012-01-20 12:55:17.006568+00', 'Reel Medley', 2093, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2755, NULL, '2012-01-20 12:55:17.011358+00', 'Mr & Mrs MacRogerson', 2093, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2756, NULL, '2012-01-20 12:55:17.016145+00', 'Bratach Bana', 2093, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2757, NULL, '2012-01-20 12:55:17.020973+00', 'Reels', 2093, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2758, NULL, '2012-01-20 12:55:17.026752+00', 'Minard Castle', 2303, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2759, NULL, '2012-01-20 12:55:17.031628+00', 'Seann Triubhas Willichan', 2303, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2760, NULL, '2012-01-20 12:55:17.036423+00', 'Duke and Duchess of Edinburgh, The', 2303, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2761, NULL, '2012-01-20 12:55:17.041226+00', 'Merry Reapers, The', 2303, 2, 8, 24, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2763, NULL, '2012-01-20 12:55:17.050875+00', 'Bryony', 3006, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2765, NULL, '2012-01-20 12:55:17.065468+00', 'Corryvreckan', 3006, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2766, NULL, '2012-01-20 12:55:17.071853+00', 'Reel Medley', 2094, 1, 5, 32, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (2767, NULL, '2012-01-20 12:55:17.078192+00', 'Jig Medley', 2094, 2, 5, 32, 9999, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (2768, NULL, '2012-01-20 12:55:17.08475+00', 'March Reel Medley', 2094, 98, 0, 0, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (2769, NULL, '2012-01-20 12:55:17.091055+00', 'Strathspey and Reel Medley', 2094, 98, 0, 0, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (4685, NULL, '2012-01-20 12:55:28.419945+00', 'Saltire Society Reel, The', 2586, 1, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (4686, NULL, '2012-01-20 12:55:28.42696+00', 'Braes Of Breadalbane, The', 2586, 3, 8, 32, 9999, NULL, 518, 0, '');
INSERT INTO 'recording' VALUES (4687, NULL, '2012-01-20 12:55:28.433304+00', 'Music Makars, The', 2586, 1, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (4688, NULL, '2012-01-20 12:55:28.439574+00', 'Maid Of The Mill, The', 2586, 2, 8, 40, 9999, NULL, 365, 0, '');
INSERT INTO 'recording' VALUES (10180, '2018-03-31 11:19:07.794454+00', '2018-03-31 11:19:07.794454+00', 'Piping Hot Medlley', 11611, 98, 0, 0, NULL, NULL, 479, 0, '');
INSERT INTO 'recording' VALUES (4691, NULL, '2012-01-20 12:55:28.458563+00', 'Lassie Wi'' The Yellow Coatie, The', 2586, 1, 8, 32, 9999, NULL, 317, 0, '');
INSERT INTO 'recording' VALUES (4689, NULL, '2021-01-20 10:06:47.63327+00', 'Summer Assembly, The', 2586, 1, 0, 88, 9999, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (4674, NULL, '2019-11-17 14:55:30.648436+00', 'Look Aboot Ye''', 3040, 2, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (2764, NULL, '2021-03-30 13:26:07.603113+00', 'New Brudenell Jig, The', 3006, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4693, NULL, '2012-01-20 12:55:28.471184+00', 'Summer Wooing', 2586, 1, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (4694, NULL, '2012-01-20 12:55:28.477414+00', 'Alltshellach', 2586, 3, 8, 32, 9999, NULL, 521, 0, '');
INSERT INTO 'recording' VALUES (4695, NULL, '2012-01-20 12:55:28.483667+00', 'Major Ian Stewart', 2586, 2, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (4696, NULL, '2012-01-20 12:55:28.490811+00', 'Ladies of Dunse, The', 2586, 1, 8, 40, 9999, 44, 360, 0, '');
INSERT INTO 'recording' VALUES (2771, NULL, '2012-01-20 12:55:17.10378+00', 'Polka Medley', 2094, 13, 0, 0, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (2772, NULL, '2012-01-20 12:55:17.110064+00', 'Hornpipe Medley', 2094, 1, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (2773, NULL, '2012-01-20 12:55:17.116349+00', 'Schottische Reel Medley', 2094, 4, 0, 0, 2, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (2774, NULL, '2012-01-20 12:55:17.122643+00', 'March Reel Medley', 2094, 98, 0, 0, 9999, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (2775, NULL, '2012-01-20 12:55:17.129128+00', 'Jig Medley', 2094, 2, 5, 32, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (2776, NULL, '2012-01-20 12:55:17.136026+00', 'Strathspey and Reel Medley', 2094, 98, 0, 0, 9999, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (2777, NULL, '2012-01-20 12:55:17.142488+00', 'Reel Medley', 2094, 98, 0, 0, 9999, NULL, 225, 0, '');
INSERT INTO 'recording' VALUES (2779, NULL, '2012-01-20 12:55:17.155279+00', 'Happy Meeting, The', 2095, 2, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (2780, NULL, '2012-01-20 12:55:17.161533+00', 'Trip to Bavaria, A', 2095, 1, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (2781, NULL, '2012-01-20 12:55:17.167674+00', 'Garry Strathspey, The', 2095, 3, 4, 32, 9999, NULL, 221, 0, '');
INSERT INTO 'recording' VALUES (2782, NULL, '2012-01-20 12:55:17.172678+00', 'Postie''s Jig', 2095, 2, 4, 32, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (2783, NULL, '2012-01-20 12:55:17.177778+00', 'Ellwyn''s Fairy Glen', 2095, 1, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (2784, NULL, '2012-01-20 12:55:17.182604+00', 'Saint Andrew''s Fair', 2095, 2, 8, 32, 9999, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (2785, NULL, '2012-01-20 12:55:17.187412+00', 'Mairi''s Wedding', 2095, 1, 4, 40, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (2786, NULL, '2012-01-20 12:55:17.192392+00', 'Luckenbooth Brooch', 2095, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (2787, NULL, '2012-01-20 12:55:17.197202+00', 'Winding Road, The', 2095, 3, 4, 32, 9999, NULL, 238, 0, '');
INSERT INTO 'recording' VALUES (2788, NULL, '2012-01-20 12:55:17.202011+00', 'Round Reel of Eight', 2095, 1, 0, 88, 9999, NULL, 96, 0, '');
INSERT INTO 'recording' VALUES (2789, NULL, '2012-01-20 12:55:17.2068+00', 'Bonnie Anne', 2095, 2, 0, 96, 9999, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (2790, NULL, '2012-01-20 12:55:17.212841+00', 'Irish Rover, The', 2095, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2791, NULL, '2012-01-20 12:55:17.217786+00', 'Baldovan Reel', 2095, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (2792, NULL, '2012-01-20 12:55:17.222592+00', 'Johnny Groat''s House', 3056, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2793, NULL, '2012-01-20 12:55:17.227382+00', 'Swilcan, The', 3056, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2794, NULL, '2012-01-20 12:55:17.232174+00', 'Cuckoo Waltz, The', 3056, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2795, NULL, '2012-01-20 12:55:17.236961+00', 'Canadian Barn Dance', 3056, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2796, NULL, '2012-01-20 12:55:17.24212+00', 'Military Two-Step', 3056, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2797, NULL, '2012-01-20 12:55:17.247549+00', 'Minard Castle', 3056, 1, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2798, NULL, '2012-01-20 12:55:17.252493+00', 'Gay Gordons', 3056, 11, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2799, NULL, '2012-01-20 12:55:17.257284+00', 'Trip to Aberdeen, A', 3056, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2800, NULL, '2012-01-20 12:55:17.262093+00', 'Highland Schottische', 3056, 3, 16, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2801, NULL, '2012-01-20 12:55:17.266921+00', 'Starry Eyed Lassie, The', 3056, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2802, NULL, '2012-01-20 12:55:17.27172+00', 'Scottish Waltz', 3056, 5, 0, 0, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (2803, NULL, '2012-01-20 12:55:17.276491+00', 'Longwise Eightsome Reel', 3056, 4, 0, 64, 5, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2804, NULL, '2012-01-20 12:55:17.281747+00', 'Gay Gordons', 3056, 11, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2805, NULL, '2012-01-20 12:55:17.286603+00', 'Highland Laddie', 3056, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2806, NULL, '2012-01-20 12:55:17.291444+00', 'Gay Gordons', 2042, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2807, NULL, '2012-01-20 12:55:17.296368+00', 'Seashells', 2042, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2808, NULL, '2012-01-20 12:55:17.30129+00', 'Sins of My Youth, The', 2042, 3, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2809, NULL, '2012-01-20 12:55:17.306097+00', 'Myrtle and Joy', 2042, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2810, NULL, '2012-01-20 12:55:17.310906+00', 'Strathaven', 2042, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2811, NULL, '2012-01-20 12:55:17.31572+00', 'Beatles'' Reel', 2042, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2812, NULL, '2012-01-20 12:55:17.320524+00', 'Sugar on Snow', 2042, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4711, NULL, '2012-01-20 12:55:28.565038+00', 'Jigs', 2592, 2, 0, 0, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (4712, NULL, '2012-01-20 12:55:28.569859+00', 'Waltzes', 2592, 5, 0, 0, 9999, NULL, 493, 0, '');
INSERT INTO 'recording' VALUES (4713, NULL, '2012-01-20 12:55:28.574671+00', 'White Cockade, The', 2592, 1, 0, 32, 9999, NULL, 222, 0, '');
INSERT INTO 'recording' VALUES (4714, NULL, '2012-01-20 12:55:28.57951+00', 'Strathspey', 2592, 3, 0, 0, 9999, NULL, 404, 0, '');
INSERT INTO 'recording' VALUES (4715, NULL, '2012-01-20 12:55:28.585156+00', 'Eightsome Reel, The', 2592, 1, 0, 464, 9999, NULL, 517, 0, '');
INSERT INTO 'recording' VALUES (4716, NULL, '2012-01-20 12:55:28.590043+00', 'Waltzes', 2592, 5, 0, 0, 9999, NULL, 473, 0, '');
INSERT INTO 'recording' VALUES (4717, NULL, '2012-01-20 12:55:28.594861+00', 'Gay Gordons', 2592, 11, 0, 16, 9999, NULL, 239, 0, '');
INSERT INTO 'recording' VALUES (4700, NULL, '2014-09-16 12:45:13.793539+00', 'Shiftin'' Bobbins', 3039, 1, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (4701, NULL, '2014-09-16 12:45:42.271365+00', 'Miss Bennet''s Jig', 3039, 2, 8, 32, 9999, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (4702, NULL, '2014-09-16 12:46:07.661796+00', 'New Scotland Strathspey, The', 3039, 3, 4, 40, 9999, NULL, 304, 0, '');
INSERT INTO 'recording' VALUES (4703, NULL, '2014-09-16 12:46:36.654542+00', 'Lieutenant Shortland''s Reel', 3039, 1, 5, 40, 9999, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (4705, NULL, '2014-09-16 12:47:30.873262+00', 'Garry Strathspey, The', 3039, 3, 4, 32, 9999, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (4706, NULL, '2014-09-16 12:47:59.08064+00', 'Crossing the Line', 3039, 1, 6, 32, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (2770, NULL, '2023-02-21 12:32:54.009834+00', 'Hornpipe Medley', 2094, 1, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (4707, NULL, '2014-09-16 12:48:26.455629+00', 'To & Fro', 3039, 2, 8, 32, 9999, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (4708, NULL, '2014-09-16 12:48:56.84169+00', 'Strathspey', 3039, 3, 5, 32, 9999, NULL, 298, 0, '');
INSERT INTO 'recording' VALUES (4709, NULL, '2014-09-16 12:49:42.593853+00', 'Follow Me Home', 3039, 2, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (4710, NULL, '2014-09-16 12:50:03.365422+00', 'Irish Rover, The', 3039, 1, 8, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (4718, NULL, '2012-01-20 12:55:28.599637+00', 'Auld Lang Syne', 2592, 98, 0, 0, 9999, NULL, 82, 0, '');
INSERT INTO 'recording' VALUES (4719, NULL, '2012-01-20 12:55:28.604418+00', 'Gay Gordons', 3056, 11, 0, 16, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (4720, NULL, '2012-01-20 12:55:28.609207+00', 'College Hornpipe, The', 3055, 1, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (4721, NULL, '2012-01-20 12:55:28.614005+00', 'Two Step Medley', 3055, 50, 0, 0, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (4722, NULL, '2012-01-20 12:55:28.618982+00', 'Scottish Waltzes', 3055, 5, 0, 0, 9999, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (4723, NULL, '2012-01-20 12:55:28.623856+00', 'Gay Gordons', 3055, 11, 0, 16, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (4724, NULL, '2012-01-20 12:55:28.628648+00', 'Jigs Medley', 3055, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (2813, NULL, '2012-01-20 12:55:17.325323+00', 'Old Mill, The', 2042, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2814, NULL, '2012-01-20 12:55:17.330208+00', 'Madeline''s Rant', 2042, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2815, NULL, '2012-01-20 12:55:17.334988+00', 'Mrs Watt''s Teakettle', 2042, 1, 8, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2816, NULL, '2012-01-20 12:55:17.339775+00', 'Waltz', 2042, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2817, NULL, '2012-01-20 12:55:17.344569+00', 'Regent''s Favourite', 3056, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (2818, NULL, '2012-01-20 12:55:17.349449+00', 'Fairy Dance, The', 3056, 1, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (2819, NULL, '2012-01-20 12:55:17.358038+00', 'Dundee Reel', 3056, 2, 4, 40, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (2820, NULL, '2012-01-20 12:55:17.362845+00', 'Hornpipe Medley', 3056, 1, 2, 32, 9999, NULL, 88, 0, '');
INSERT INTO 'recording' VALUES (2821, NULL, '2012-01-20 12:55:17.367627+00', 'Strathspey and Reel Medley', 3056, 4, 0, 0, 9999, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (2824, NULL, '2012-01-20 12:55:17.382148+00', 'Reels and Jig', 1782, 4, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2889, NULL, '2012-01-20 12:55:17.710659+00', 'Garry Strathspey, The', 2303, 3, 4, 32, 9999, NULL, 221, 0, '');
INSERT INTO 'recording' VALUES (4698, NULL, '2021-06-21 21:32:42.983753+00', 'Happy Meeting, The', 3039, 2, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (2826, NULL, '2012-01-20 12:55:17.395967+00', 'Tribute to Jimmy Shand, A', 3057, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2827, NULL, '2012-01-20 12:55:17.402237+00', 'Gordon Waltz, The', 3026, 5, 0, 0, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (2828, NULL, '2012-01-20 12:55:17.408467+00', 'Boston Two Step', 3057, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4699, NULL, '2019-06-28 15:17:55.910428+00', 'Strathspey', 3039, 3, 3, 32, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (2830, NULL, '2012-01-20 12:55:17.419792+00', 'Carse of Stirling', 3057, 1, 6, 32, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (2831, NULL, '2012-01-20 12:55:17.424596+00', 'Gay Gordons', 3057, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2832, NULL, '2012-01-20 12:55:17.429422+00', 'Fairly Shot O'' Her', 3057, 2, 6, 32, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (2833, NULL, '2012-01-20 12:55:17.434234+00', 'Scottish Waltz', 3057, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2834, NULL, '2012-01-20 12:55:17.439028+00', 'Happy Returns', 3057, 1, 6, 32, 9999, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (2835, NULL, '2012-01-20 12:55:17.443805+00', 'Duff''s House', 3057, 2, 4, 32, 9999, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (2836, NULL, '2012-01-20 12:55:17.448623+00', 'Jig Medley', 2098, 2, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2837, NULL, '2012-01-20 12:55:17.453452+00', 'Reel Medley', 2098, 1, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2838, NULL, '2012-01-20 12:55:17.45828+00', 'Jig Medley', 2098, 2, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2839, NULL, '2012-01-20 12:55:17.463074+00', 'Rosnor Abbey', 3026, 2, 4, 40, 9999, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (2840, NULL, '2012-01-20 12:55:17.467856+00', 'Mr Wilson''s Hornpipe', 3026, 1, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (2841, NULL, '2012-01-20 12:55:17.472649+00', 'Lea Rig, The', 3026, 3, 4, 32, 9999, NULL, 248, 0, '');
INSERT INTO 'recording' VALUES (2842, NULL, '2012-01-20 12:55:17.477428+00', 'Rakish Highlandman, The', 3026, 2, 4, 40, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (2843, NULL, '2012-01-20 12:55:17.482231+00', 'Threesome Reel, The', 3026, 4, 2, 48, 11, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (2844, NULL, '2012-01-20 12:55:17.487013+00', 'Over the Dee and Over the Don', 3026, 2, 0, 120, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (2845, NULL, '2012-01-20 12:55:17.492415+00', 'Hooper''s Jig', 3026, 2, 8, 32, 9999, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (2846, NULL, '2012-01-20 12:55:17.497365+00', 'Alltshellach', 3026, 3, 4, 32, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (2847, NULL, '2012-01-20 12:55:17.502168+00', 'Lady Sophia Anne of Bute', 3026, 1, 4, 48, 9999, NULL, 225, 0, '');
INSERT INTO 'recording' VALUES (2848, NULL, '2012-01-20 12:55:17.507005+00', 'Buchan Eightsome Reel, The', 3026, 1, 10, 40, 9999, NULL, 428, 0, '');
INSERT INTO 'recording' VALUES (4725, NULL, '2012-01-20 12:55:28.633453+00', 'Grand March, The', 3055, 11, 5, 32, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (4726, NULL, '2012-01-20 12:55:28.638248+00', 'Jigs Medley', 3055, 2, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (4727, NULL, '2012-01-20 12:55:28.643024+00', 'Highland Schottishe', 3055, 3, 32, 8, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (4728, NULL, '2012-01-20 12:55:28.647809+00', 'Gaelic Waltz Medley', 3055, 5, 0, 0, 9999, NULL, 228, 0, '');
INSERT INTO 'recording' VALUES (4729, NULL, '2012-01-20 12:55:28.652593+00', 'Eva Three Step', 3055, 11, 8, 16, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (4730, NULL, '2012-01-20 12:55:28.657371+00', 'Trip to Bavaria, A', 3055, 1, 4, 32, 9999, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (4731, NULL, '2012-01-20 12:55:28.66215+00', 'Polka', 3010, 13, 0, 0, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (4732, NULL, '2012-01-20 12:55:28.667051+00', 'Gay Gordons', 2596, 11, 0, 16, 9999, NULL, 225, 0, '');
INSERT INTO 'recording' VALUES (4733, NULL, '2012-01-20 12:55:28.672025+00', 'Monymusk', 2596, 3, 4, 32, 9999, NULL, 220, 0, '');
INSERT INTO 'recording' VALUES (4734, NULL, '2012-01-20 12:55:28.677078+00', 'Strip the Willow', 2596, 2, 8, 32, 9999, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (4735, NULL, '2012-01-20 12:55:28.681887+00', 'Scottish Waltz', 2596, 5, 0, 0, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (4736, NULL, '2012-01-20 12:55:28.686666+00', 'Duke of Perth', 2596, 1, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (4737, NULL, '2012-01-20 12:55:28.691448+00', 'Barn Dance', 2596, 50, 0, 0, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (4738, NULL, '2012-01-20 12:55:28.696253+00', 'Scottish Reform', 2596, 2, 8, 32, 9999, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (4739, NULL, '2012-01-20 12:55:28.70103+00', 'Flowers of Edinburgh', 2596, 1, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (4740, NULL, '2012-01-20 12:55:28.705815+00', 'Highland Schottische', 2596, 3, 0, 8, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (4741, NULL, '2012-01-20 12:55:28.710597+00', 'Eva Three Step', 2596, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4742, NULL, '2012-01-20 12:55:28.715409+00', 'Strathspey', 3026, 3, 6, 32, 9999, NULL, 358, 0, '');
INSERT INTO 'recording' VALUES (4743, NULL, '2012-01-20 12:55:28.720185+00', 'Hebridean Weaving Lilt', 3026, 3, 0, 88, 9999, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (4744, NULL, '2012-01-20 12:55:28.724958+00', 'Reel', 3026, 1, 4, 48, 9999, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (2825, NULL, '2012-08-30 05:32:00.932945+00', 'Royal Wedding, The', 2046, 3, 8, 32, 9999, 5, 500, 0, '');
INSERT INTO 'recording' VALUES (2860, NULL, '2012-01-20 12:55:17.570879+00', 'Twa Braw Reels Encore', 3056, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2861, NULL, '2012-01-20 12:55:17.575774+00', 'White Cockade, The', 2133, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2862, NULL, '2012-01-20 12:55:17.580599+00', 'Veleta', 3046, 5, 0, 16, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (2863, NULL, '2012-01-20 12:55:17.585378+00', 'Selection of Pipe Marches', 3061, 11, 0, 0, 9999, NULL, 88, 0, '');
INSERT INTO 'recording' VALUES (2864, NULL, '2012-01-20 12:55:17.590185+00', 'Braes of Breadalbane, The', 3026, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2865, NULL, '2012-01-20 12:55:17.59506+00', 'Dashing White Sergeant, The', 3026, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2850, NULL, '2022-08-20 17:09:55.459663+00', 'Tolsta Rant, The', 3026, 2, 5, 32, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (2851, NULL, '2022-08-20 17:10:23.789963+00', 'Silver Tassie, The', 3026, 3, 4, 32, 9999, NULL, 244, 0, '');
INSERT INTO 'recording' VALUES (2852, NULL, '2022-08-20 17:10:49.526691+00', 'Sailor, The', 3026, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (2853, NULL, '2022-08-20 17:11:28.488103+00', 'Bonnie Brux', 3026, 4, 0, 80, 4, NULL, 127, 0, '');
INSERT INTO 'recording' VALUES (2856, NULL, '2022-08-20 17:13:04.08924+00', 'Muirland Willie', 3026, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (2855, NULL, '2022-08-20 17:12:23.486756+00', 'Petronella', 3026, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (2857, NULL, '2022-08-20 17:13:43.316617+00', 'Winding Road, The', 3026, 3, 4, 32, 9999, NULL, 253, 0, '');
INSERT INTO 'recording' VALUES (2858, NULL, '2022-08-20 17:14:08.126335+00', 'Angus MacLeod', 3026, 1, 2, 64, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (2859, NULL, '2022-08-20 17:14:47.705271+00', 'Gay Gordons', 3026, 11, 0, 16, 9999, NULL, 118, 0, '');
INSERT INTO 'recording' VALUES (2823, NULL, '2022-12-22 13:48:33.814417+00', 'Jigs', 1782, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2866, NULL, '2012-01-20 12:55:17.599888+00', 'Royal Exchange, The', 3026, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2867, NULL, '2012-01-20 12:55:17.604682+00', 'Medley', 3026, 4, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2868, NULL, '2012-01-20 12:55:17.609458+00', 'Hamilton Rant, The', 3026, 1, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2869, NULL, '2012-01-20 12:55:17.614295+00', 'Medley-Reels', 2124, 1, 8, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (2870, NULL, '2012-01-20 12:55:17.619102+00', 'Medley-Strathspeys', 2124, 3, 8, 32, 9999, NULL, 482, 0, '');
INSERT INTO 'recording' VALUES (2871, NULL, '2012-01-20 12:55:17.623893+00', 'Medley-Jigs', 2124, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (2872, NULL, '2012-01-20 12:55:17.628674+00', 'Medley-Strathspeys and Reels', 2124, 4, 2, 64, 5, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (2874, NULL, '2012-01-20 12:55:17.638302+00', 'Medley-Jigs', 2124, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (2875, NULL, '2012-01-20 12:55:17.643083+00', 'Medley-Strathspeys', 2124, 3, 8, 32, 9999, NULL, 487, 0, '');
INSERT INTO 'recording' VALUES (2876, NULL, '2012-01-20 12:55:17.647852+00', 'Medley-Reels', 2124, 1, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (2877, NULL, '2012-01-20 12:55:17.652634+00', 'Medley-Strathspeys', 2124, 3, 4, 32, 9999, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (2878, NULL, '2012-01-20 12:55:17.657459+00', 'Medley-Jigs', 2124, 2, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (2879, NULL, '2012-01-20 12:55:17.662641+00', 'Mairi''s Wedding', 2303, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2880, NULL, '2012-01-20 12:55:17.667475+00', 'Glasgow Highlanders, The', 2303, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2881, NULL, '2012-01-20 12:55:17.672258+00', 'Nineteenth of December', 2303, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2882, NULL, '2012-01-20 12:55:17.677065+00', 'Waltz Country Dance', 2303, 5, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2883, NULL, '2012-01-20 12:55:17.681907+00', 'Blooms of Bon Accord, The', 2303, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2884, NULL, '2012-01-20 12:55:17.686698+00', 'Galloway House', 2303, 1, 8, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (2885, NULL, '2012-01-20 12:55:17.691479+00', 'Jubilee Jig, The', 2303, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (2886, NULL, '2012-01-20 12:55:17.69627+00', 'Flowers of Edinburgh', 2303, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (2887, NULL, '2012-01-20 12:55:17.701078+00', 'Hollin Buss, The', 2303, 2, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (2888, NULL, '2012-01-20 12:55:17.705864+00', 'West''s Hornpipe', 2303, 1, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (2890, NULL, '2012-01-20 12:55:17.715442+00', 'Frisky, The', 2303, 2, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (2891, NULL, '2012-01-20 12:55:17.720216+00', 'Lea Rig, The', 2303, 3, 8, 32, 9999, NULL, 521, 0, '');
INSERT INTO 'recording' VALUES (2892, NULL, '2012-01-20 12:55:17.72526+00', 'Waltz Medley', 2303, 5, 5, 32, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (4745, NULL, '2012-01-20 12:55:28.729744+00', 'Jig', 3026, 2, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (4746, NULL, '2012-01-20 12:55:28.734559+00', 'Hebridean Weaving Lilt', 3026, 3, 0, 88, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (4747, NULL, '2012-01-20 12:55:28.739337+00', 'Reel', 3026, 1, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (4748, NULL, '2012-01-20 12:55:28.744099+00', 'Jig', 3026, 2, 8, 40, 9999, NULL, 368, 0, '');
INSERT INTO 'recording' VALUES (4749, NULL, '2012-01-20 12:55:28.748868+00', 'Strathspey', 3026, 3, 4, 40, 9999, NULL, 302, 0, '');
INSERT INTO 'recording' VALUES (4750, NULL, '2012-01-20 12:55:28.753655+00', 'Jig', 3026, 2, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (4751, NULL, '2012-01-20 12:55:28.758528+00', 'Saint Bernard''s Waltz', 3010, 5, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4754, NULL, '2012-01-20 12:55:28.773065+00', 'Lord Hume''s Reel', 3010, 3, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4755, NULL, '2012-01-20 12:55:28.777875+00', 'Primrose Polka', 3010, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4757, NULL, '2012-01-20 12:55:28.78742+00', 'Comin'' thro'' the rye', 3010, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4758, NULL, '2012-01-20 12:55:28.792235+00', 'Heartfell Polka', 3010, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4759, NULL, '2012-01-20 12:55:28.797109+00', 'Scottish Waltz', 3010, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4760, NULL, '2012-01-20 12:55:28.801892+00', 'Gay Gordons', 3010, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4761, NULL, '2012-01-20 12:55:28.806663+00', 'Gordon Waltz, The', 3010, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4762, NULL, '2012-01-20 12:55:28.81144+00', 'Dundee Reel', 3010, 2, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4763, NULL, '2012-01-20 12:55:28.816958+00', 'Scottish Waltz', 3010, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4764, NULL, '2012-01-20 12:55:28.821915+00', 'Deirdre''s Polka', 3010, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4765, NULL, '2012-01-20 12:55:28.826762+00', 'Reel of the 51st Division, The', 3010, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4756, NULL, '2012-08-18 16:06:19.37935+00', 'Cumberland Reel', 3010, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4753, NULL, '2012-08-18 16:09:26.336065+00', 'Deil amang the Tailors, The', 3010, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4752, NULL, '2012-08-18 16:10:56.152554+00', 'Teviot Brig', 3010, 2, 8, 24, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2895, NULL, '2018-07-31 13:33:37.688159+00', 'Cannonhill Assembly', 1701, 3, 4, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (2894, NULL, '2018-07-31 13:32:51.637047+00', 'Bannocks and Brose', 1701, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (2896, NULL, '2018-07-31 13:34:42.657057+00', 'Rothesay Rant, The', 1701, 2, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (2897, NULL, '2018-07-31 13:35:59.534437+00', 'Rosette, The', 1701, 4, 4, 32, 1, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (2898, NULL, '2018-07-31 13:36:44.709577+00', 'Culag', 1701, 2, 4, 24, 9999, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (2905, NULL, '2012-01-20 12:55:17.788749+00', 'Mrs MacLeod of Raasay', 3037, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (2908, NULL, '2012-01-20 12:55:17.80311+00', 'Nethy Bridge', 3217, 3, 6, 32, 9999, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (2912, NULL, '2012-01-20 12:55:17.822288+00', 'Thingummyjig Polka, The', 3037, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2913, NULL, '2012-01-20 12:55:17.827133+00', 'Lewisvale Waltz, The', 3037, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2914, NULL, '2012-01-20 12:55:17.831923+00', 'Strip the Willow', 3037, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2915, NULL, '2012-01-20 12:55:17.836726+00', 'March of the Marches, The', 3037, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2916, NULL, '2012-01-20 12:55:17.841508+00', 'Jack o'' Tar Hornpipe', 3037, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2917, NULL, '2012-01-20 12:55:17.846295+00', 'Drowsy Maggie', 3037, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2918, NULL, '2012-01-20 12:55:17.85108+00', 'Military Two-Step', 3037, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2919, NULL, '2012-01-20 12:55:17.855852+00', 'Air, Strathspey and Reel', 3037, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2920, NULL, '2012-01-20 12:55:17.860629+00', 'Continental Waltz', 3037, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2921, NULL, '2012-01-20 12:55:17.86541+00', 'Britannia Two Step', 3037, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2922, NULL, '2012-01-20 12:55:17.870455+00', 'Jigs', 3037, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2923, NULL, '2012-01-20 12:55:17.875414+00', 'Reel Medley', 3037, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2924, NULL, '2012-01-20 12:55:17.880226+00', 'Glenburnie Rant', 3037, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2926, NULL, '2012-01-20 12:55:17.891436+00', 'Scottish Waltz', 3037, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2927, NULL, '2012-01-20 12:55:17.896264+00', 'Gay Gordons', 3037, 11, 8, 16, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (2928, NULL, '2012-01-20 12:55:17.901061+00', 'Military Two-Step', 3037, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2929, NULL, '2012-01-20 12:55:17.905856+00', 'Saint Bernard''s Waltz', 3037, 5, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2930, NULL, '2012-01-20 12:55:17.910689+00', 'Highland Schottische', 3037, 3, 0, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2931, NULL, '2012-01-20 12:55:17.915472+00', 'Reel Medley', 3037, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2932, NULL, '2012-01-20 12:55:17.920317+00', 'Happy Harry Polka, The', 3037, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2907, NULL, '2014-08-05 20:46:57.122475+00', '1314', 3037, 4, 0, 128, 2, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (2909, NULL, '2014-08-05 20:48:22.121999+00', 'Fight About the Fireside', 3037, 1, 0, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (2911, NULL, '2014-08-05 20:44:59.993143+00', 'Rory O''More', 3037, 2, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (2910, NULL, '2014-08-05 20:49:14.073382+00', 'Ellwyn''s Fairy Glen', 3037, 1, 0, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (2933, NULL, '2012-01-20 12:55:17.925097+00', 'Waltz Meldey', 3037, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2934, NULL, '2012-01-20 12:55:17.929909+00', 'Jig Medley', 3037, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2935, NULL, '2012-01-20 12:55:17.934696+00', 'Barn Dance', 3037, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2936, NULL, '2012-01-20 12:55:17.939475+00', 'Rory O'' More', 3037, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2937, NULL, '2012-01-20 12:55:17.944248+00', 'Circassian Circle', 1502, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2938, NULL, '2012-01-20 12:55:17.9492+00', 'Machine Without Horses, The', 1502, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4766, NULL, '2012-01-20 12:55:28.831574+00', 'Victory Waltz', 3010, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4767, NULL, '2012-01-20 12:55:28.8364+00', 'Eightsome Reel, The', 2611, 1, 0, 464, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4768, NULL, '2012-01-20 12:55:28.841423+00', 'Scottish Waltz Medley', 2611, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4769, NULL, '2012-01-20 12:55:28.846446+00', 'Highland Barn Dance', 2611, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4770, NULL, '2012-01-20 12:55:28.851238+00', 'Lamb Skinnet', 2611, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4771, NULL, '2012-01-20 12:55:28.856037+00', 'Gay Gordons', 2611, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4772, NULL, '2012-01-20 12:55:28.86086+00', 'Strip the Willow', 2611, 2, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4773, NULL, '2012-01-20 12:55:28.865651+00', 'Dashing White Sergeant', 2611, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4774, NULL, '2012-01-20 12:55:28.870425+00', 'Highland Gaelic Waltz', 2611, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4775, NULL, '2012-01-20 12:55:28.8752+00', 'Braes of Tulliemet, The', 2611, 3, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4776, NULL, '2012-01-20 12:55:28.880426+00', 'Hamilton House', 2611, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4777, NULL, '2012-01-20 12:55:28.885275+00', 'Irish Military Two-Step', 2611, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4778, NULL, '2012-01-20 12:55:28.890117+00', 'Pride of Erin Waltz', 2611, 5, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4779, NULL, '2012-01-20 12:55:28.894901+00', 'Stacks of Barley', 2611, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4780, NULL, '2012-01-20 12:55:28.899695+00', 'Medley of Irish Jigs', 2611, 2, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4781, NULL, '2012-01-20 12:55:28.904475+00', 'Irish Hornpipe', 2611, 1, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4782, NULL, '2012-01-20 12:55:28.909259+00', 'Reel of the 51st', 2182, 1, 0, 32, 9999, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (4783, NULL, '2012-01-20 12:55:28.91414+00', 'Scottish Waltz', 2182, 5, 0, 0, 9999, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (4784, NULL, '2012-01-20 12:55:28.919036+00', 'Eva Three Step, The', 2182, 11, 0, 16, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (4785, NULL, '2012-01-20 12:55:28.923963+00', 'Foursome Reel', 2182, 4, 0, 0, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (2939, NULL, '2012-01-20 12:55:17.954038+00', 'Ca'' the Ewes tae the Knowes', 1502, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2940, NULL, '2012-01-20 12:55:17.958955+00', 'Seann Triubhas Willichan', 1502, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2941, NULL, '2012-01-20 12:55:17.963746+00', 'Duke of Perth', 1502, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2942, NULL, '2012-01-20 12:55:17.968548+00', 'Lady Catherine Bruce''s Reel', 1502, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2943, NULL, '2012-01-20 12:55:17.973344+00', 'Bridge of Nairn', 1502, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2944, NULL, '2012-01-20 12:55:17.978291+00', 'Dalkeith''s Strathspey', 1502, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2945, NULL, '2012-01-20 12:55:17.983086+00', 'Monymusk', 1502, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2946, NULL, '2012-01-20 12:55:17.987868+00', 'Sugar Candie', 1502, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2947, NULL, '2012-01-20 12:55:17.992655+00', 'Fidget', 1502, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2948, NULL, '2012-01-20 12:55:17.997467+00', 'Isle, The', 1502, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10181, '2018-03-31 11:20:31.079971+00', '2018-03-31 11:20:31.079971+00', 'Boston 2 Step', 11611, 50, 0, 0, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (2950, NULL, '2012-01-20 12:55:18.007072+00', 'Strathspey Medley', 2328, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2951, NULL, '2012-01-20 12:55:18.011855+00', 'Reel Medley', 2328, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2953, NULL, '2012-01-20 12:55:18.021427+00', 'Jig Medley', 2328, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2954, NULL, '2012-01-20 12:55:18.026239+00', 'Strathspey Medley', 2328, 3, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2955, NULL, '2012-01-20 12:55:18.031024+00', 'Reel Medley', 2328, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2956, NULL, '2012-01-20 12:55:18.035816+00', 'Gay Gordons', 2328, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2967, NULL, '2012-01-20 12:55:18.088649+00', 'Petronella', 3009, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2968, NULL, '2012-01-20 12:55:18.093422+00', 'Frisky, The', 3009, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2969, NULL, '2012-01-20 12:55:18.098492+00', 'Up in the Air', 3009, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2970, NULL, '2012-01-20 12:55:18.103298+00', 'New Rigged Ship, The', 3009, 2, 8, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2971, NULL, '2012-01-20 12:55:18.108082+00', 'None so Pretty', 3009, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2972, NULL, '2012-01-20 12:55:18.112867+00', 'Miss Hadden''s Reel', 3009, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2973, NULL, '2012-01-20 12:55:18.117671+00', 'Airdrie Lassies', 3009, 2, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2974, NULL, '2012-01-20 12:55:18.122472+00', 'Musselburgh Reel', 3008, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2900, NULL, '2018-07-31 13:39:06.155292+00', 'Glenmor', 1701, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (2901, NULL, '2018-07-31 13:40:42.70824+00', 'Campbell''s Hornpipe', 1701, 1, 4, 32, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (2902, NULL, '2018-07-31 13:41:26.547923+00', 'Ailsa Craig', 1701, 3, 4, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (2903, NULL, '2018-07-31 13:42:53.187853+00', 'Lad''s Awa'', The', 1701, 1, 4, 40, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (2904, NULL, '2018-07-31 13:43:50.030833+00', 'Campbell of Cawdor', 1701, 3, 4, 32, 9999, NULL, 531, 0, '');
INSERT INTO 'recording' VALUES (2975, NULL, '2012-01-20 12:55:18.127498+00', 'Eva Three Step', 3008, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2976, NULL, '2012-01-20 12:55:18.132329+00', 'Wild Geese, The', 3008, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2977, NULL, '2012-01-20 12:55:18.137151+00', 'Bridgecastle Reel, The', 3008, 1, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2978, NULL, '2012-01-20 12:55:18.141971+00', 'Pet o'' the Pipers', 3008, 2, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2979, NULL, '2012-01-20 12:55:18.147551+00', 'De''il''s Conundrum, The', 3008, 4, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2980, NULL, '2012-01-20 12:55:18.152639+00', 'Polharrow Burn', 3008, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4786, NULL, '2012-01-20 12:55:28.928786+00', 'Pipe Marches 2/4', 2182, 11, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4787, NULL, '2012-01-20 12:55:28.933584+00', 'Bluebell Polka', 2182, 50, 0, 16, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (4788, NULL, '2012-01-20 12:55:28.938378+00', 'Cock o'' The North', 2182, 99, 0, 0, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (4789, NULL, '2012-01-20 12:55:28.943212+00', 'Gay Gordons', 2182, 11, 0, 16, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (4790, NULL, '2012-01-20 12:55:28.948023+00', 'March Strathspey and Reel', 2182, 4, 0, 0, 9999, NULL, 237, 0, '');
INSERT INTO 'recording' VALUES (4791, NULL, '2012-01-20 12:55:28.952821+00', 'Harry Lauder Medley', 2182, 99, 0, 0, 9999, NULL, 118, 0, '');
INSERT INTO 'recording' VALUES (4792, NULL, '2012-01-20 12:55:28.957626+00', 'Gaelic Waltz', 2182, 5, 0, 0, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (4793, NULL, '2012-01-20 12:55:28.962423+00', 'Set of Reels', 3061, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4794, NULL, '2012-01-20 12:55:28.967205+00', 'Alyth Burn', 3061, 2, 0, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4795, NULL, '2012-01-20 12:55:28.971978+00', 'Glens of Angus, The', 3061, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4796, NULL, '2012-01-20 12:55:28.976776+00', 'Reels', 2185, 1, 6, 32, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (4797, NULL, '2012-01-20 12:55:28.981558+00', 'Jigs', 2185, 2, 6, 32, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (4798, NULL, '2012-01-20 12:55:28.986334+00', 'Scottish waltz medley', 2185, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4799, NULL, '2012-01-20 12:55:28.991114+00', 'Gay Gordons', 2185, 11, 8, 16, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (4800, NULL, '2012-01-20 12:55:28.995924+00', 'Reels', 2185, 1, 5, 32, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (4801, NULL, '2012-01-20 12:55:29.000746+00', 'Valeta, The', 2185, 5, 0, 32, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (4802, NULL, '2012-01-20 12:55:29.005564+00', 'Gay Gordons', 2185, 11, 10, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2957, NULL, '2014-10-08 15:07:55.419147+00', 'Dumbarton Drums', 2328, 1, 4, 32, 9999, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (2958, NULL, '2014-10-08 15:08:31.450396+00', 'Bonnie Dundee', 2328, 2, 0, 144, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (2961, NULL, '2014-10-08 15:17:15.955912+00', 'Mrs MacLeod''s Reel', 2328, 1, 4, 32, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (2960, NULL, '2014-10-08 15:15:43.303637+00', 'Gay Gordons', 2328, 11, 8, 16, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (2963, NULL, '2014-10-08 15:18:56.963639+00', 'Hamilton House', 2328, 2, 6, 32, 9999, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (2964, NULL, '2014-10-08 15:19:31.43188+00', 'Flowers of Edinburgh, The', 2328, 1, 6, 32, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (2965, NULL, '2014-10-08 15:19:57.101752+00', 'Corn Rigs', 2328, 1, 6, 32, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (2966, NULL, '2014-10-08 15:28:11.156294+00', 'Gatherings, The', 2328, 4, 0, 128, 13, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (4803, NULL, '2012-01-20 12:55:29.010348+00', 'Saint Bernard Waltz', 2185, 5, 0, 16, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (4805, NULL, '2012-01-20 12:55:29.019917+00', 'Strathspeys', 2185, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4806, NULL, '2012-01-20 12:55:29.024794+00', 'Looking for a partner', 2185, 50, 0, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2981, NULL, '2012-01-20 12:55:18.157578+00', 'Irish Rover, The', 3008, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2982, NULL, '2012-01-20 12:55:18.163029+00', 'Waggle o'' the Kilt, The', 3008, 2, 8, 40, 9999, NULL, 323, 0, '');
INSERT INTO 'recording' VALUES (2983, NULL, '2012-01-20 12:55:18.167898+00', 'Alison Rose', 3008, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2984, NULL, '2012-01-20 12:55:18.172697+00', 'Bees of Maggieknockater, The', 3008, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2987, NULL, '2012-01-20 12:55:18.187388+00', 'Airie Bennan', 3008, 2, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2988, NULL, '2012-01-20 12:55:18.192229+00', 'Miss Milligan''s Strathspey', 3008, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2989, NULL, '2012-01-20 12:55:18.197033+00', 'Jennifer''s Jig', 3008, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2990, NULL, '2012-01-20 12:55:18.201837+00', 'Schiehallion', 3008, 4, 0, 128, 2, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2991, NULL, '2012-01-20 12:55:18.207057+00', 'Rest and be Thankful', 3008, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2992, NULL, '2012-01-20 12:55:18.211877+00', 'Merry Dancers, The', 1549, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2993, NULL, '2012-01-20 12:55:18.216656+00', 'Peggy''s Love', 1549, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2994, NULL, '2012-01-20 12:55:18.221433+00', 'Fidget', 1549, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2995, NULL, '2012-01-20 12:55:18.226226+00', 'Strathglass House', 1549, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2996, NULL, '2012-01-20 12:55:18.235201+00', 'None so Pretty', 1549, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2997, NULL, '2012-01-20 12:55:18.241471+00', 'Tibby Fowler o'' The Glen', 1549, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2998, NULL, '2012-01-20 12:55:18.247787+00', 'Miss Nancy Frowns', 1549, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2999, NULL, '2012-01-20 12:55:18.254159+00', 'Earl of Home, The', 1549, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3000, NULL, '2012-01-20 12:55:18.26047+00', 'Jessie''s Hornpipe', 2057, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3001, NULL, '2012-01-20 12:55:18.307767+00', 'Hamilton House', 2057, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3002, NULL, '2012-01-20 12:55:18.312834+00', 'Robertson Rant, The', 2057, 3, 0, 80, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3003, NULL, '2012-01-20 12:55:18.317792+00', 'Angus MacLeod', 2057, 1, 2, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3004, NULL, '2012-01-20 12:55:18.322612+00', 'Captain Bain''s Tribute', 2057, 2, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3005, NULL, '2012-01-20 12:55:18.327414+00', 'Medley', 2057, 4, 4, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3006, NULL, '2012-01-20 12:55:18.332218+00', 'Waltz Country Dance', 2057, 5, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3007, NULL, '2012-01-20 12:55:18.337018+00', 'Lions International', 2057, 2, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3008, NULL, '2012-01-20 12:55:18.34205+00', 'Wood of Fyvie, The', 2057, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3009, NULL, '2012-01-20 12:55:18.346848+00', 'MacDonald of Sleat', 2057, 2, 0, 120, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3011, NULL, '2012-01-20 12:55:18.356451+00', 'Corn Rigs', 2356, 1, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (3012, NULL, '2012-01-20 12:55:18.361345+00', 'Braes of Mellinish, The', 2356, 3, 8, 32, 9999, NULL, 476, 0, '');
INSERT INTO 'recording' VALUES (3013, NULL, '2012-01-20 12:55:18.366325+00', 'Argyll''s Fancy', 2356, 2, 4, 48, 9999, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (3014, NULL, '2012-01-20 12:55:18.371122+00', 'Davy Nick Nack', 2356, 1, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (3015, NULL, '2012-01-20 12:55:18.37612+00', 'Loch Leven Castle', 2356, 1, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (3016, NULL, '2012-01-20 12:55:18.381104+00', 'Jimmy''s Fancy', 2356, 3, 8, 32, 9999, NULL, 484, 0, '');
INSERT INTO 'recording' VALUES (3017, NULL, '2012-01-20 12:55:18.385937+00', 'Roaring Jelly', 2356, 2, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (3018, NULL, '2012-01-20 12:55:18.390735+00', 'Angus Mackinnon''s Hornpipe', 2356, 1, 8, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (3019, NULL, '2012-01-20 12:55:18.395545+00', 'Jessie''s Hornpipe', 2058, 1, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (3020, NULL, '2012-01-20 12:55:18.400407+00', 'Braes of Breadalbane, The', 2058, 3, 8, 32, 9999, NULL, 465, 0, '');
INSERT INTO 'recording' VALUES (3021, NULL, '2012-01-20 12:55:18.40523+00', 'Swilcan, The', 2058, 2, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (3022, NULL, '2012-01-20 12:55:18.410058+00', '5x32 Bar Reels', 2058, 1, 5, 32, 9999, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (3023, NULL, '2012-01-20 12:55:18.414871+00', 'Fyket, The', 2058, 2, 8, 40, 9999, NULL, 330, 0, '');
INSERT INTO 'recording' VALUES (3024, NULL, '2012-01-20 12:55:18.419662+00', 'Winding Road, The', 2058, 3, 4, 32, 9999, NULL, 239, 0, '');
INSERT INTO 'recording' VALUES (3025, NULL, '2012-01-20 12:55:18.424545+00', '5x32 Bar Jigs', 2058, 2, 5, 32, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (3026, NULL, '2012-01-20 12:55:18.429353+00', 'J.B. Milne', 2058, 1, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (3027, NULL, '2012-01-20 12:55:18.434155+00', 'Last of the Lairds, The', 2058, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (3029, NULL, '2012-01-20 12:55:18.443823+00', 'Waltz Country Dance', 3010, 5, 4, 40, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (3030, NULL, '2012-01-20 12:55:18.448838+00', 'Honeymoon Jig, The', 3010, 2, 4, 32, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (3031, NULL, '2012-01-20 12:55:18.453635+00', 'Queen''s Bridge', 3010, 1, 4, 40, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (3028, NULL, '2013-02-04 19:28:16.76167+00', 'Strip the Willow (9/8)', 2468, 101, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3032, NULL, '2012-01-20 12:55:18.458431+00', 'Angus MacLeod', 2173, 1, 8, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3033, NULL, '2012-01-20 12:55:18.463409+00', 'Accordion Solo', 2173, 98, 0, 0, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (3034, NULL, '2012-01-20 12:55:18.468231+00', 'Light and Airy', 3010, 2, 8, 32, 9999, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (3035, NULL, '2012-01-20 12:55:18.473029+00', 'Elliot''s Fancy', 3010, 4, 0, 64, 5, NULL, 100, 0, '');
INSERT INTO 'recording' VALUES (3036, NULL, '2012-01-20 12:55:18.47784+00', 'Machine Without Horses, The', 2133, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3037, NULL, '2012-01-20 12:55:18.482701+00', 'Heather Mixture Jig', 3010, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3038, NULL, '2012-01-20 12:55:18.487535+00', 'Weaving Lilt, The', 3010, 1, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10182, '2018-03-31 11:23:21.815362+00', '2018-03-31 11:23:21.815362+00', 'Irish Hornpipes', 11611, 50, 0, 0, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (3040, NULL, '2012-01-20 12:55:18.497109+00', 'Dashing White Sergeant, The', 3042, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3042, NULL, '2012-01-20 12:55:18.506903+00', 'Deil amang the Tailors, The', 3042, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3043, NULL, '2012-01-20 12:55:18.511734+00', 'Eva Three Step', 3042, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3044, NULL, '2012-01-20 12:55:18.516538+00', 'Polka', 3042, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3045, NULL, '2012-01-20 12:55:18.521332+00', 'Highland Schottische', 3042, 3, 0, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3047, NULL, '2012-01-20 12:55:18.531017+00', 'Campbell''s Frolic', 2038, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3048, NULL, '2012-01-20 12:55:18.535861+00', 'Stirling Castle', 2038, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3049, NULL, '2012-01-20 12:55:18.540755+00', 'Strip the Willow (9/8)', 2038, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3050, NULL, '2012-01-20 12:55:18.545585+00', 'Buchan Eightsome Reel, The', 2038, 1, 0, 400, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3051, NULL, '2012-01-20 12:55:18.550453+00', 'Lord Rosslyn''s Fancy', 2038, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3052, NULL, '2012-01-20 12:55:18.555368+00', 'Kingussie Flower', 2038, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3053, NULL, '2012-01-20 12:55:18.560176+00', 'Letham Ladies', 2038, 3, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3054, NULL, '2012-01-20 12:55:18.565255+00', 'March, Strathspey and Reel', 2038, 4, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3055, NULL, '2012-01-20 12:55:18.570193+00', 'Royal Exchange, The', 2038, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3056, NULL, '2012-01-20 12:55:18.575314+00', 'Mairi''s Wedding', 3010, 1, 8, 40, 9999, NULL, 336, 0, '');
INSERT INTO 'recording' VALUES (3058, NULL, '2012-01-20 12:55:18.585541+00', 'Waltz Country Dance', 3010, 5, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3060, NULL, '2012-01-20 12:55:18.595439+00', 'Duke of Perth', 3010, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3064, NULL, '2012-01-20 12:55:18.614851+00', 'Road to the Isles, The', 3010, 3, 4, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (3065, NULL, '2012-01-20 12:55:18.619666+00', 'Machine Without Horses, The', 3010, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2986, NULL, '2014-09-16 14:40:31.379593+00', 'Blooms of Bon Accord, The', 3008, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3066, NULL, '2012-01-20 12:55:18.624588+00', 'Dashing White Sergeant, The', 3018, 1, 0, 32, 9999, NULL, 240, 0, '');
INSERT INTO 'recording' VALUES (3067, NULL, '2012-01-20 12:55:18.629466+00', 'Eightsome Reel, The', 3018, 1, 1, 464, 9999, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (3068, NULL, '2012-01-20 12:55:18.634378+00', 'Foursome Reel, The', 3018, 4, 0, 128, 9999, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (3069, NULL, '2012-01-20 12:55:18.639198+00', 'Monymusk', 3018, 3, 8, 32, 9999, NULL, 478, 0, '');
INSERT INTO 'recording' VALUES (3070, NULL, '2012-01-20 12:55:18.643999+00', 'Mairi''s Wedding', 3018, 1, 8, 40, 9999, NULL, 350, 0, '');
INSERT INTO 'recording' VALUES (3071, NULL, '2012-01-20 12:55:18.6488+00', 'Reel of the 51st Division, The', 3018, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (3072, NULL, '2012-01-20 12:55:18.653636+00', 'Duke of Perth', 3018, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (3041, NULL, '2012-08-30 05:34:16.725396+00', 'Scottish Waltz', 3042, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3057, NULL, '2013-02-04 15:51:51.324587+00', 'Jenny''s Bawbee', 3010, 3, 8, 24, 9999, NULL, 362, 0, '');
INSERT INTO 'recording' VALUES (3063, NULL, '2013-02-04 15:53:06.108632+00', 'Maxwell''s Rant', 3010, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (3059, NULL, '2013-02-04 15:55:40.618728+00', 'Miss Mary Douglas', 3010, 2, 8, 48, 9999, NULL, 402, 0, '');
INSERT INTO 'recording' VALUES (3062, NULL, '2013-02-04 15:58:41.424567+00', 'Braes of Tullymet, The', 3010, 3, 8, 32, 9999, NULL, 477, 0, '');
INSERT INTO 'recording' VALUES (3061, NULL, '2013-02-04 16:02:52.551731+00', 'Scottish Reform', 3010, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (3073, NULL, '2012-01-20 12:55:18.658963+00', 'Postie''s Jig', 3018, 2, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (3074, NULL, '2012-01-20 12:55:18.664083+00', 'Postie''s Jig', 3018, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (3075, NULL, '2012-01-20 12:55:18.668915+00', 'Duke and Duchess of Edinburgh, The', 3018, 1, 8, 40, 9999, NULL, 357, 0, '');
INSERT INTO 'recording' VALUES (3077, NULL, '2012-01-20 12:55:18.681233+00', 'Sportsman''s Charity Reel, The', 3018, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (3078, NULL, '2012-01-20 12:55:18.687508+00', 'Strathspey Set played for Cannon Hill Assembly', 2414, 3, 4, 32, 9999, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (3079, NULL, '2012-01-20 12:55:18.693208+00', 'Ladies'' Fancy', 3067, 2, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (3080, NULL, '2012-01-20 12:55:18.69807+00', 'New Petronella, The', 3067, 1, 2, 48, 9999, NULL, 106, 0, '');
INSERT INTO 'recording' VALUES (3081, NULL, '2012-01-20 12:55:18.702862+00', 'Seann Triubhas Willichan', 3067, 3, 6, 32, 9999, NULL, 405, 0, '');
INSERT INTO 'recording' VALUES (3082, NULL, '2012-01-20 12:55:18.707639+00', 'Dundee Reel', 3010, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3083, NULL, '2012-01-20 12:55:18.712417+00', 'Russe, La', 3010, 1, 4, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3084, NULL, '2012-01-20 12:55:18.717246+00', 'Gay Gordons', 2173, 11, 0, 16, 9999, NULL, 223, 0, '');
INSERT INTO 'recording' VALUES (3085, NULL, '2012-01-20 12:55:18.722037+00', 'Isle of Skye', 3010, 1, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (3086, NULL, '2012-01-20 12:55:18.726824+00', 'Montgomeries'' Rant, The', 3010, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3087, NULL, '2012-01-20 12:55:18.731618+00', 'Eightsome Reel, The', 2090, 1, 1, 464, 9999, NULL, 497, 0, '');
INSERT INTO 'recording' VALUES (3088, NULL, '2012-01-20 12:55:18.736421+00', 'Madge Wildfire''s Strathspey', 3010, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3089, NULL, '2012-01-20 12:55:18.741227+00', 'Flowers of Edinburgh, The', 3010, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3090, NULL, '2012-01-20 12:55:18.746051+00', 'Mason''s Apron, The', 3010, 1, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (3091, NULL, '2012-01-20 12:55:18.750876+00', 'Off She Goes in the North', 3010, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3092, NULL, '2012-01-20 12:55:18.755674+00', 'Reel of Glamis, The', 3010, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3093, NULL, '2012-01-20 12:55:18.76048+00', 'Royal Salute, The', 3010, 1, 0, 112, 9999, NULL, 119, 0, '');
INSERT INTO 'recording' VALUES (3094, NULL, '2012-01-20 12:55:18.765372+00', 'Jimmy Shand''s Jig', 3010, 2, 4, 32, 9999, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (3095, NULL, '2012-01-20 12:55:18.770192+00', 'Heather Mixture Jig, The', 3010, 2, 4, 32, 9999, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (3096, NULL, '2012-01-20 12:55:18.775024+00', 'Punch Bowl, The', 3010, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3097, NULL, '2012-01-20 12:55:18.779845+00', 'Argyll''s Fancy', 3010, 2, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3099, NULL, '2012-01-20 12:55:18.789411+00', 'Kendall''s Hornpipe', 3010, 2, 4, 32, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (3100, NULL, '2012-01-20 12:55:18.794198+00', 'Ellwyn''s Fairy Glen', 3010, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3101, NULL, '2012-01-20 12:55:18.799006+00', 'Rory O'' More', 3010, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3102, NULL, '2012-01-20 12:55:18.803811+00', 'Drumelzier', 3010, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3103, NULL, '2012-01-20 12:55:18.808591+00', 'Ian Powrie''s Farewell to Auchterarder', 3010, 2, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3104, NULL, '2012-01-20 12:55:18.813369+00', 'Hollin Buss, The', 3010, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3105, NULL, '2012-01-20 12:55:18.818172+00', 'Lamb Skinnet', 3009, 2, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (3106, NULL, '2012-01-20 12:55:18.822977+00', 'Rock and the Wee Pickle Tow', 3010, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3107, NULL, '2012-01-20 12:55:18.827783+00', 'Bonnie Lass O'' Bon Accord, The', 3010, 3, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3108, NULL, '2012-01-20 12:55:18.832565+00', 'Ashludie Rant', 3010, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3110, NULL, '2012-01-20 12:55:18.842281+00', 'Buchan Waltz, The', 3010, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3111, NULL, '2012-01-20 12:55:18.847071+00', 'Heather Mixture Jig', 3010, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3113, NULL, '2012-01-20 12:55:18.856641+00', 'Reel', 3051, 98, 0, 0, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (3112, NULL, '2012-02-11 14:31:02.183172+00', 'Gaelic Airs', 2246, 98, 0, 0, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (3114, NULL, '2012-01-20 12:55:18.861438+00', 'Balmoral Circle Dance', 3010, 99, 0, 160, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3116, NULL, '2012-01-20 12:55:18.871512+00', 'Birks of Invermay, The', 3010, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3117, NULL, '2012-01-20 12:55:18.876377+00', 'Saint Bernard''s Waltz', 3010, 5, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3118, NULL, '2012-01-20 12:55:18.881185+00', 'Teviot Brig', 3010, 2, 8, 24, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3119, NULL, '2012-01-20 12:55:18.886029+00', 'De''il Amang the Tailors, The', 3010, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3121, NULL, '2012-01-20 12:55:18.895614+00', 'Primrose Polka', 3010, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3122, NULL, '2012-01-20 12:55:18.900396+00', 'Cumberland Reel, The', 3010, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3123, NULL, '2012-01-20 12:55:18.905187+00', 'Duke of Perth', 3010, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3124, NULL, '2012-01-20 12:55:18.91+00', 'Glasgow Highlanders, The', 3010, 3, 4, 32, 9999, NULL, 0, 1, '');
INSERT INTO 'recording' VALUES (3125, NULL, '2012-01-20 12:55:18.915296+00', 'Gordon Waltz', 3010, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3126, NULL, '2012-01-20 12:55:18.920196+00', 'Merrily Danced the Quaker''s Wife', 3010, 2, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3128, NULL, '2012-01-20 12:55:18.92988+00', 'Duke of Atholl''s Reel, The', 3010, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3129, NULL, '2012-01-20 12:55:18.934688+00', 'Glasgow Highlanders, The', 3010, 3, 9, 32, 9999, NULL, 0, 1, '');
INSERT INTO 'recording' VALUES (3130, NULL, '2012-01-20 12:55:18.939507+00', 'Reel of the 51st Division, The', 3010, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3131, NULL, '2012-01-20 12:55:18.944301+00', 'Hamilton House', 3010, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3133, NULL, '2012-01-20 12:55:18.95392+00', 'Double Foursome', 3010, 7, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3134, NULL, '2012-01-20 12:55:18.958705+00', 'Waltz Country Dance', 3010, 5, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3135, NULL, '2012-01-20 12:55:18.963603+00', 'Eightsome Reel, The', 3010, 1, 0, 464, 9999, NULL, 461, 0, '');
INSERT INTO 'recording' VALUES (3136, NULL, '2012-01-20 12:55:18.968476+00', 'Black Dance, The', 1456, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3137, NULL, '2012-01-20 12:55:18.973304+00', 'Kiss For Nothing, A', 1456, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3138, NULL, '2012-01-20 12:55:18.978166+00', 'Kiss Quick, My Mither''s Coming', 1456, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3139, NULL, '2012-01-20 12:55:18.982977+00', 'River Cree, The', 1456, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3140, NULL, '2012-01-20 12:55:18.987775+00', 'Circassian Circle', 1456, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3141, NULL, '2012-01-20 12:55:18.992579+00', 'My Love She''s but a Lassie Yet', 1456, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3151, NULL, '2012-01-20 12:55:19.040855+00', 'Prince Charles of Edinburgh', 3039, 1, 0, 160, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3152, NULL, '2012-01-20 12:55:19.045673+00', 'Reel of Six', 2131, 1, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3153, NULL, '2012-01-20 12:55:19.050485+00', 'Barn Dance', 2131, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3154, NULL, '2012-01-20 12:55:19.055323+00', 'Jig Medley', 2131, 2, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3142, NULL, '2012-05-06 22:03:28.258033+00', 'Ye''ll Aye be Welcome Back Again', 1456, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3144, NULL, '2013-02-04 14:50:24.578612+00', 'Princess Margaret''s Jig', 2067, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (3115, NULL, '2018-03-02 23:07:54.283409+00', 'Derwentside', 2566, 2, 5, 32, 9999, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (3145, NULL, '2013-02-04 14:54:20.689908+00', 'Lucy of Lammermoor', 2067, 3, 4, 48, 9999, NULL, 372, 0, '');
INSERT INTO 'recording' VALUES (3146, NULL, '2013-02-04 14:55:10.820594+00', 'Duncan MacCalman', 2067, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (3149, NULL, '2013-02-04 14:56:55.127096+00', 'Fountain, The', 2067, 2, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (3076, NULL, '2022-12-09 20:00:48.090681+00', 'Hamilton House', 3018, 2, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (3147, NULL, '2022-12-22 13:48:56.896416+00', 'Miss McPherson Grant''s Jig', 2067, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (3109, NULL, '2022-12-26 18:42:08.344724+00', 'Waves of Tory', 3010, 2, 5, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3150, NULL, '2013-02-04 14:57:44.073393+00', 'Mr Edward Wagstaff''s Fancy', 2067, 1, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (3155, NULL, '2012-01-20 12:55:19.060123+00', 'Galloway House', 2131, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3156, NULL, '2012-01-20 12:55:19.06498+00', 'Lea Rig, The', 2131, 3, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3157, NULL, '2012-01-20 12:55:19.069778+00', 'Roxburgh Castle', 2131, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3158, NULL, '2012-01-20 12:55:19.074592+00', 'South of the Grampians', 2133, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3159, NULL, '2012-01-20 12:55:19.07939+00', 'Selection of Jigs', 3067, 2, 0, 0, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (3160, NULL, '2012-01-20 12:55:19.08433+00', 'Strathspey and Reel Medley', 3067, 4, 0, 0, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (3161, NULL, '2012-01-20 12:55:19.089159+00', 'Hornpipe Medley', 3067, 1, 0, 0, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (3162, NULL, '2012-01-20 12:55:19.093975+00', 'March and Reel Medley', 3067, 4, 0, 0, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (3163, NULL, '2012-01-20 12:55:19.098774+00', 'Selection of Reels', 3067, 1, 0, 0, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (3164, NULL, '2012-01-20 12:55:19.103562+00', 'Strathspey and Reel Medley', 3067, 4, 0, 0, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (3165, NULL, '2012-01-20 12:55:19.108369+00', 'Selection of Jigs', 3067, 2, 0, 0, 9999, NULL, 126, 0, '');
INSERT INTO 'recording' VALUES (3166, NULL, '2012-01-20 12:55:19.113156+00', 'Strip the Willow (6/8)', 3056, 2, 0, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (3167, NULL, '2012-01-20 12:55:19.117996+00', 'Fife Hunt, The', 3056, 1, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (3168, NULL, '2012-01-20 12:55:19.122825+00', 'Highland Lass, The', 3056, 1, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (3169, NULL, '2012-01-20 12:55:19.127797+00', 'Saint Andrew''s Fair', 2133, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3170, NULL, '2012-01-20 12:55:19.132654+00', 'Monymusk', 2133, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3171, NULL, '2012-01-20 12:55:19.137465+00', 'Baldovan Reel', 2133, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3172, NULL, '2012-01-20 12:55:19.142576+00', 'Kendall''s Hornpipe', 2133, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3173, NULL, '2012-01-20 12:55:19.147508+00', 'Reel of the 51st Division, The', 2133, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3174, NULL, '2012-01-20 12:55:19.1525+00', 'Hooper''s Jig', 2133, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3175, NULL, '2012-01-20 12:55:19.157536+00', 'Isle, The', 2133, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3176, NULL, '2012-01-20 12:55:19.162899+00', 'Mr Watson''s Favourite', 2133, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3177, NULL, '2012-01-20 12:55:19.167931+00', 'Braes of Breadalbane, The', 2133, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3178, NULL, '2012-01-20 12:55:19.172793+00', 'Jessie''s Hornpipe', 2133, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3179, NULL, '2012-01-20 12:55:19.177761+00', 'Flowers of Edinburgh, The', 2133, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3180, NULL, '2012-01-20 12:55:19.182789+00', 'Flora, La', 2133, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3181, NULL, '2012-01-20 12:55:19.187665+00', 'Balmoral Strathspey', 2133, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3182, NULL, '2012-01-20 12:55:19.192667+00', 'Diamond Jubilee, The', 2133, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3183, NULL, '2012-01-20 12:55:19.197506+00', 'Gay Gordons', 2133, 11, 12, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3184, NULL, '2012-01-20 12:55:19.20665+00', 'Robertson Rant, The', 2133, 3, 0, 80, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3185, NULL, '2012-01-20 12:55:19.212984+00', 'Hollin Buss, The', 2133, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3186, NULL, '2012-01-20 12:55:19.219265+00', 'From Scotia''s Shores we''re Noo Awa''', 2133, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3187, NULL, '2012-01-20 12:55:19.225524+00', 'Montgomeries'' Rant, The', 2133, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3188, NULL, '2012-01-20 12:55:19.231231+00', 'Frisky, The', 2133, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3192, NULL, '2012-01-20 12:55:19.250507+00', 'Eightsome Reel, The', 3009, 1, 0, 464, 9999, NULL, 487, 0, '');
INSERT INTO 'recording' VALUES (3195, NULL, '2012-01-20 12:55:19.265388+00', 'Happy Returns', 1556, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (3148, NULL, '2017-10-12 23:06:08.608696+00', 'Earl of Angus and Arran, The', 2067, 3, 8, 32, 9999, NULL, 494, 0, '');
INSERT INTO 'recording' VALUES (3120, NULL, '2017-07-23 19:53:25.812853+00', 'Lord Hume''s Reel', 3010, 3, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3197, NULL, '2012-01-20 12:55:19.275127+00', 'MacDonald of Sleat', 1556, 2, 0, 120, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (3198, NULL, '2012-01-20 12:55:19.279925+00', 'Bonnie Ann', 1556, 2, 0, 96, 9999, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (3199, NULL, '2012-01-20 12:55:19.284719+00', 'Shepherd''s Crook, The', 1556, 3, 0, 72, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (3200, NULL, '2012-01-20 12:55:19.289499+00', 'Cary''s Waltz', 2066, 5, 0, 0, 9999, NULL, 240, 0, '');
INSERT INTO 'recording' VALUES (3201, NULL, '2012-01-20 12:55:19.294314+00', 'Reel Medley', 2094, 1, 0, 0, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (3202, NULL, '2012-01-20 12:55:19.299128+00', 'Jig Medley', 2094, 2, 0, 0, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (3203, NULL, '2012-01-20 12:55:19.303932+00', 'Hornpipe Medley', 2094, 1, 0, 0, 9999, NULL, 120, 0, '');
INSERT INTO 'recording' VALUES (3204, NULL, '2012-01-20 12:55:19.308723+00', 'Strathspey and Reel Medley', 2094, 4, 0, 0, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (3205, NULL, '2012-01-20 12:55:19.313512+00', 'Reel Medley', 2094, 1, 0, 0, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (3206, NULL, '2012-01-20 12:55:19.318307+00', 'Reel Medley', 2094, 1, 0, 0, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (3207, NULL, '2012-01-20 12:55:19.323087+00', 'Jig Medley', 2094, 2, 0, 0, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (3208, NULL, '2012-01-20 12:55:19.327906+00', 'Strathspey and Reel Medley', 2094, 4, 0, 0, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (3209, NULL, '2012-01-20 12:55:19.332718+00', 'Strathspey and Reel Medley', 2094, 4, 0, 0, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (3210, NULL, '2012-01-20 12:55:19.33751+00', 'Hornpipe Medley', 2094, 1, 0, 0, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (3211, NULL, '2012-01-20 12:55:19.342301+00', 'Strathspey and Reel Medley', 2094, 4, 0, 0, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (3212, NULL, '2012-01-20 12:55:19.347107+00', 'Canadian Barn Dance', 3063, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3213, NULL, '2012-01-20 12:55:19.351897+00', 'Mason''s Apron, The', 3063, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3214, NULL, '2012-01-20 12:55:19.356677+00', 'Irish Jig Medley', 3063, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3215, NULL, '2012-01-20 12:55:19.36146+00', 'Gay Gordons', 3063, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3216, NULL, '2012-01-20 12:55:19.366259+00', 'Waltz Medley', 3063, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3217, NULL, '2012-01-20 12:55:19.371047+00', 'Bottom of the Punch Bowl', 3063, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3218, NULL, '2012-01-20 12:55:19.375838+00', 'Caledonian Country Dance', 3063, 3, 0, 24, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3219, NULL, '2012-01-20 12:55:19.380636+00', 'Jessie''s Hornpipe', 3063, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3220, NULL, '2012-01-20 12:55:19.38542+00', 'Craighall Jig', 3063, 2, 4, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3221, NULL, '2012-01-20 12:55:19.3904+00', 'Crossing to Shetland', 3063, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3222, NULL, '2012-01-20 12:55:19.395224+00', 'Haymakers, The', 3063, 2, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3223, NULL, '2012-01-20 12:55:19.40001+00', 'Merrily Danced the Quaker''s Wife', 2173, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3190, NULL, '2014-04-29 17:57:03.540997+00', 'Reel of the 51st Division, The', 3009, 1, 6, 32, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (3191, NULL, '2014-04-29 17:58:03.095438+00', 'Strip the Willow', 3009, 2, 6, 32, 9999, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (3224, NULL, '2012-01-20 12:55:19.404795+00', 'Waltz Country Dance', 2173, 5, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3225, NULL, '2012-01-20 12:55:19.409584+00', 'Aiken Drum', 2173, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3226, NULL, '2012-01-20 12:55:19.414477+00', 'Lamb Skinnet', 2173, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3228, NULL, '2012-01-20 12:55:19.424853+00', 'Caller Herrin''', 2231, 1, 8, 40, 9999, NULL, 350, 0, '');
INSERT INTO 'recording' VALUES (3230, NULL, '2012-01-20 12:55:19.435754+00', 'Our Compliments to WIlliam Marshall', 2231, 3, 4, 32, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (3231, NULL, '2012-01-20 12:55:19.441117+00', 'Douglas Henderson of Dundee', 2231, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (3232, NULL, '2012-01-20 12:55:19.448382+00', 'Netherby Hall', 2231, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (3233, NULL, '2012-01-20 12:55:19.454693+00', 'Wha''ll be King but Charlie?', 2231, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (3234, NULL, '2012-01-20 12:55:19.460991+00', 'Waltz Medley', 2231, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3235, NULL, '2012-01-20 12:55:19.467358+00', 'Highlandman Kissed his Mother, The', 2231, 1, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (3236, NULL, '2012-01-20 12:55:19.473748+00', 'Rumbling Brig', 2231, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (3237, NULL, '2012-01-20 12:55:19.479899+00', 'Miss Stewart''s Jig', 2231, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (3229, NULL, '2023-01-27 12:06:05.135472+00', 'Murdochcairnie', 2231, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (3238, NULL, '2012-01-20 12:55:19.484958+00', 'Traditional Fiddle Set', 2136, 4, 0, 0, 9999, NULL, 434, 0, '');
INSERT INTO 'recording' VALUES (3239, NULL, '2012-01-20 12:55:19.489777+00', 'Grand Set', 2136, 98, 0, 0, 9999, NULL, 1022, 0, '');
INSERT INTO 'recording' VALUES (3240, NULL, '2012-01-20 12:55:19.494563+00', 'Waltz Medley', 2136, 5, 0, 0, 9999, NULL, 463, 0, '');
INSERT INTO 'recording' VALUES (3241, NULL, '2012-01-20 12:55:19.499354+00', 'Reels in Strict Tempo for Scottish Country Dancing', 2136, 1, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (10184, '2018-03-31 11:33:48.284694+00', '2018-03-31 11:33:48.284694+00', 'Gaelic Waltzes', 11611, 5, 0, 0, NULL, NULL, 312, 0, '');
INSERT INTO 'recording' VALUES (3248, NULL, '2012-01-20 12:55:19.536008+00', 'Farewell to Paternoster Square', 3014, 4, 0, 72, 39, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3249, NULL, '2012-01-20 12:55:19.542438+00', 'Farewell to Paternoster Square', 3014, 4, 0, 72, 39, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3250, NULL, '2012-01-20 12:55:19.548693+00', 'Valerie Rixon''s Jig', 3014, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3252, NULL, '2012-01-20 12:55:19.561648+00', 'J.B. Milne', 3014, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3255, NULL, '2012-01-20 12:55:19.580719+00', 'Wild Geese, The', 3014, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3256, NULL, '2012-01-20 12:55:19.587699+00', 'Robertson Rant, The', 3014, 3, 0, 80, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3257, NULL, '2012-01-20 12:55:19.593993+00', 'Ian Powrie''s Farewell to Auchterarder', 3014, 2, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3258, NULL, '2012-01-20 12:55:19.600265+00', 'Balkeerie Two-Step, The', 2173, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3259, NULL, '2012-01-20 12:55:19.606734+00', 'Innes Russell of Perth', 2173, 3, 0, 96, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3260, NULL, '2012-01-20 12:55:19.612984+00', 'Barn Dance', 2173, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3261, NULL, '2012-01-20 12:55:19.619267+00', 'Duchess of Buccleuch''s Favourite, The', 2173, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3263, NULL, '2012-01-20 12:55:19.632916+00', 'Montgomeries'' Rant, The', 3020, 1, 8, 32, 9999, 5, 299, 0, '');
INSERT INTO 'recording' VALUES (3272, NULL, '2012-01-20 12:55:19.691939+00', 'Eight Men of Moidart, The', 3057, 1, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3273, NULL, '2012-01-20 12:55:19.698359+00', 'Autumn in Appin', 3057, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3274, NULL, '2012-01-20 12:55:19.704631+00', 'Saltire Society Reel, The', 3057, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3275, NULL, '2012-01-20 12:55:19.711472+00', 'Tempête, La', 3057, 1, 3, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3276, NULL, '2012-01-20 12:55:19.717834+00', 'Johnnie Walker', 3057, 4, 0, 128, 13, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3277, NULL, '2012-01-20 12:55:19.724142+00', 'Blooms of Bon Accord', 3057, 1, 4, 32, 9999, NULL, 0, 1, '');
INSERT INTO 'recording' VALUES (3278, NULL, '2012-01-20 12:55:19.730567+00', 'Major Ian Stewart', 3057, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3279, NULL, '2012-01-20 12:55:19.736834+00', 'Russe, La', 3057, 1, 4, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3280, NULL, '2012-01-20 12:55:19.743241+00', 'Garry Strathspey, The', 3057, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3281, NULL, '2012-01-20 12:55:19.749502+00', 'New Petronella, The', 3057, 1, 2, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3282, NULL, '2012-01-20 12:55:19.755808+00', 'Happy Meeting, The', 3057, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3243, NULL, '2015-06-13 14:42:16.896213+00', 'Kingussie Flower', 2137, 1, 4, 40, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (3245, NULL, '2015-06-13 14:46:31.854329+00', 'Johnnie Walker', 2137, 4, 0, 128, 13, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (3246, NULL, '2015-06-13 14:47:36.657796+00', 'Swilcan, The', 2137, 2, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (3247, NULL, '2015-06-13 14:48:27.208732+00', 'Mrs MacLeod', 2137, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (3271, NULL, '2017-02-03 17:10:49.122596+00', 'Bonnie Anne', 3057, 2, 1, 96, 9999, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (3283, NULL, '2012-01-20 12:55:19.762217+00', 'Midwinter', 2029, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3284, NULL, '2012-01-20 12:55:19.768486+00', 'Abegweit', 2029, 3, 0, 96, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3285, NULL, '2012-01-20 12:55:19.775015+00', 'Marylou''s Reel', 2029, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3286, NULL, '2012-01-20 12:55:19.781435+00', 'Rossington Strathspey, The', 2029, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3287, NULL, '2012-01-20 12:55:19.78804+00', 'Jolicure Jig, The', 2029, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3288, NULL, '2012-01-20 12:55:19.794336+00', 'Graelynda Strathspey, The', 2029, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3289, NULL, '2012-01-20 12:55:19.800722+00', 'Trip to Bavaria, A', 2178, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (3291, NULL, '2012-01-20 12:55:19.811908+00', 'Dundee Whaler, The', 2178, 3, 4, 32, 9999, NULL, 243, 0, '');
INSERT INTO 'recording' VALUES (3292, NULL, '2012-01-20 12:55:19.816872+00', 'Sailor, The', 2178, 1, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (3293, NULL, '2012-01-20 12:55:19.821922+00', 'Duke of Atholl''s Reel, The', 2178, 2, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (3294, NULL, '2012-01-20 12:55:19.826756+00', 'Wind on Loch Fyne, The', 2178, 3, 3, 32, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (3295, NULL, '2012-01-20 12:55:19.831743+00', 'Waltz', 2178, 5, 0, 0, 9999, NULL, 224, 0, '');
INSERT INTO 'recording' VALUES (3296, NULL, '2012-01-20 12:55:19.836641+00', 'Postie''s Jig', 2178, 2, 4, 32, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (3297, NULL, '2012-01-20 12:55:19.841538+00', 'Luckenbooth Brooch, The', 2178, 2, 8, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (3298, NULL, '2012-01-20 12:55:19.84637+00', 'Autumn in Appin', 2178, 3, 4, 32, 9999, NULL, 261, 1, '');
INSERT INTO 'recording' VALUES (3299, NULL, '2012-01-20 12:55:19.851182+00', 'College Hornpipe, The', 2178, 1, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (3300, NULL, '2012-01-20 12:55:19.855974+00', 'Butterscotch and Honey', 2178, 3, 4, 32, 9999, NULL, 243, 0, '');
INSERT INTO 'recording' VALUES (3301, NULL, '2012-01-20 12:55:19.86077+00', 'Blooms of Bon Accord', 2178, 1, 4, 32, 9999, NULL, 142, 1, '');
INSERT INTO 'recording' VALUES (3302, NULL, '2012-01-20 12:55:19.865712+00', 'Byron Strathspey, The', 2178, 3, 3, 32, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (3303, NULL, '2012-01-20 12:55:19.870734+00', 'Duke of Perth', 2178, 1, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (3304, NULL, '2012-01-20 12:55:19.878014+00', 'Duke of Perth', 2189, 1, 6, 32, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (3265, NULL, '2014-09-16 11:34:50.27265+00', 'Up and Coming', 2188, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (3266, NULL, '2014-09-16 11:35:36.595075+00', 'Rumpledethumps', 2188, 2, 4, 48, 9999, NULL, 213, 1, '');
INSERT INTO 'recording' VALUES (3267, NULL, '2014-09-16 11:36:17.321719+00', 'North to Inverness', 2188, 3, 4, 40, 9999, NULL, 294, 1, '');
INSERT INTO 'recording' VALUES (3268, NULL, '2014-09-16 11:36:58.265751+00', 'Ben Wyvis', 2188, 2, 8, 40, 9999, NULL, 330, 0, '');
INSERT INTO 'recording' VALUES (3269, NULL, '2014-09-16 11:37:32.107436+00', 'Road to Wigan Pier, The', 2188, 3, 4, 32, 9999, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (3270, NULL, '2014-09-16 11:38:17.141711+00', 'Eighteenth Anniversary, The', 2188, 2, 8, 40, 9999, NULL, 338, 0, '');
INSERT INTO 'recording' VALUES (3305, NULL, '2012-01-20 12:55:19.883166+00', 'Rakes of Glasgow', 2189, 3, 3, 32, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (3306, NULL, '2012-01-20 12:55:19.888157+00', 'MacDonald of Sleat', 2189, 2, 0, 120, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (3308, NULL, '2012-01-20 12:55:19.898667+00', 'Cadgers in the Canongate', 2189, 1, 4, 48, 9999, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (3309, NULL, '2012-01-20 12:55:19.905658+00', 'Golden Pheasant, The', 2189, 2, 5, 40, 9999, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (3310, NULL, '2012-01-20 12:55:19.91067+00', 'Cumberland Reel', 2189, 2, 6, 32, 9999, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (3311, NULL, '2012-01-20 12:55:19.916362+00', 'Birks of Invermay, The', 2189, 3, 3, 32, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (3312, NULL, '2012-01-20 12:55:19.921343+00', 'Duke of Atholl''s Reel, The', 2189, 2, 6, 32, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (3313, NULL, '2012-01-20 12:55:19.926227+00', 'Scottish Reform', 2189, 2, 6, 32, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (3314, NULL, '2012-01-20 12:55:19.932246+00', 'Fidget', 2189, 1, 6, 32, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (3315, NULL, '2012-01-20 12:55:19.937095+00', 'Lady Harriet Hope''s Reel', 2189, 1, 6, 32, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (3316, NULL, '2012-01-20 12:55:19.941912+00', 'Foursome Reel & Half Reel of Tulloch', 2189, 4, 0, 128, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (3317, NULL, '2012-01-20 12:55:19.946719+00', 'Eight Men of Moidart, The', 2189, 1, 6, 32, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (3318, NULL, '2012-01-20 12:55:19.951647+00', 'Flowers of Edinburgh', 2189, 1, 6, 32, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (3319, NULL, '2012-01-20 12:55:19.956726+00', 'Roaring Jelly', 2065, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (3320, NULL, '2012-01-20 12:55:19.962521+00', 'Flowers of Edinburgh', 2065, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (3321, NULL, '2012-01-20 12:55:19.967388+00', 'Sauchie Haugh, The', 2065, 3, 8, 32, 9999, NULL, 500, 0, '');
INSERT INTO 'recording' VALUES (3322, NULL, '2012-01-20 12:55:19.97247+00', 'Pinewoods Reel', 2065, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (3290, NULL, '2022-12-09 19:54:41.029978+00', 'Across the Tay', 2178, 2, 4, 48, 9999, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (3254, NULL, '2022-12-13 18:06:23.160496+00', 'London Highland Club''s Farewell to Fetter Lane, The', 3014, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3262, NULL, '2022-12-26 18:18:51.024782+00', 'Gay Gordons', 2173, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3323, NULL, '2012-01-20 12:55:19.977746+00', 'Mrs Stewart''s Jig', 2065, 2, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (3324, NULL, '2012-01-20 12:55:19.982586+00', 'Neidpath Castle', 2065, 3, 3, 32, 9999, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (3325, NULL, '2012-01-20 12:55:19.987607+00', 'Cadgers in the Canongate', 2065, 1, 8, 48, 9999, NULL, 430, 0, '');
INSERT INTO 'recording' VALUES (3326, NULL, '2012-01-20 12:55:19.992669+00', 'Follow Me Home', 2065, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (3328, NULL, '2012-01-20 12:55:20.002653+00', 'Deil amang the Tailors, The', 2065, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (3329, NULL, '2012-01-20 12:55:20.007467+00', 'Jennifer''s Jig', 2065, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (3330, NULL, '2012-01-20 12:55:20.012486+00', 'John McAlpin', 2065, 3, 8, 32, 9999, NULL, 496, 0, '');
INSERT INTO 'recording' VALUES (3331, NULL, '2012-01-20 12:55:20.017365+00', 'Mrs MacLeod', 2065, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (3332, NULL, '2012-01-20 12:55:20.022457+00', 'Seann Triubhas Willichan', 3024, 3, 8, 32, 9999, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (3334, NULL, '2012-01-20 12:55:20.032091+00', 'Kirrie Lads, The', 2188, 2, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (3335, NULL, '2012-01-20 12:55:20.03695+00', 'Pride of Erin Waltz, The', 2188, 5, 0, 32, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (3242, NULL, '2021-03-20 00:38:16.798402+00', 'Strathspeys in Strict Tempo', 2136, 3, 5, 32, 9999, NULL, 312, 0, '');
INSERT INTO 'recording' VALUES (3333, NULL, '2021-09-24 10:27:25.210031+00', 'Dalkeith''s Strathspey', 3018, 3, 4, 32, 9999, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (3336, NULL, '2012-01-20 12:55:20.043233+00', 'Square Tango', 2188, 50, 0, 0, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (3337, NULL, '2012-01-20 12:55:20.04857+00', 'Caddam Wood', 2188, 1, 5, 32, 9999, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (3339, NULL, '2012-01-20 12:55:20.060491+00', 'Military Two-step', 2188, 11, 0, 16, 9999, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (3340, NULL, '2012-01-20 12:55:20.065601+00', 'Canadian Barn Dance', 2188, 11, 0, 16, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (3341, NULL, '2012-01-20 12:55:20.071727+00', 'Fisherman''s Reel', 2188, 1, 5, 32, 9999, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (3342, NULL, '2012-01-20 12:55:20.076702+00', 'Luckenbooth Brooch, The', 2188, 2, 0, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (3343, NULL, '2012-01-20 12:55:20.082455+00', 'MacDonald of the Isles', 2188, 3, 3, 32, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (3344, NULL, '2012-01-20 12:55:20.091355+00', 'Gay Gordons', 2188, 11, 0, 16, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (3345, NULL, '2012-01-20 12:55:20.096271+00', 'Rumba Royale', 2188, 50, 0, 0, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (3346, NULL, '2012-01-20 12:55:20.102214+00', 'Gay Gordons', 2188, 11, 0, 16, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (3347, NULL, '2012-01-20 12:55:20.107054+00', 'Veleta', 2188, 5, 0, 16, 9999, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (3348, NULL, '2012-01-20 12:55:20.111889+00', 'Round Reel of Eight', 2188, 1, 0, 88, 9999, NULL, 102, 0, '');
INSERT INTO 'recording' VALUES (3349, NULL, '2012-01-20 12:55:20.116826+00', 'Grand March', 2088, 11, 0, 0, 9999, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (3350, NULL, '2012-01-20 12:55:20.124953+00', 'Boston Two step', 2088, 50, 0, 16, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (3351, NULL, '2012-01-20 12:55:20.131248+00', 'Hesitation Waltz, The', 2088, 5, 0, 0, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (3352, NULL, '2012-01-20 12:55:20.137778+00', 'Jacky Tar Two Step, The', 2088, 50, 0, 0, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (3354, NULL, '2012-01-20 12:55:20.151465+00', 'Hullichan''s Jig', 2088, 2, 8, 32, 9999, NULL, 244, 0, '');
INSERT INTO 'recording' VALUES (3355, NULL, '2012-01-20 12:55:20.157849+00', 'Russian Ballet, The', 2088, 99, 0, 0, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (3356, NULL, '2012-01-20 12:55:20.164185+00', 'Friendly Waltz, The', 2088, 5, 0, 0, 9999, NULL, 321, 0, '');
INSERT INTO 'recording' VALUES (3357, NULL, '2012-01-20 12:55:20.170547+00', 'Gypsy Tap, The', 2088, 99, 0, 0, 9999, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (10185, '2018-03-31 11:36:18.965929+00', '2018-03-31 11:36:18.965929+00', 'Reel Irish Finale, A', 11611, 1, 0, 0, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (3359, NULL, '2012-01-20 12:55:20.183246+00', 'Call of the Pipes, The', 2088, 99, 0, 0, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (3360, NULL, '2012-01-20 12:55:20.189774+00', 'Foursome Reel', 2186, 4, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3361, NULL, '2012-01-20 12:55:20.196056+00', 'Weaving Lilt, The', 2186, 1, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3363, NULL, '2012-01-20 12:55:20.208582+00', 'Shepherd''s Crook, The', 2186, 3, 0, 72, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3364, NULL, '2012-01-20 12:55:20.214876+00', 'Ellwyn''s Fairy Glen', 2038, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3365, NULL, '2012-01-20 12:55:20.221138+00', 'Dundee Reel, The', 2038, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3366, NULL, '2012-01-20 12:55:20.227396+00', 'Hebridean Waltz Medley', 2038, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3367, NULL, '2012-01-20 12:55:20.233681+00', 'Scotsman in America, The', 2038, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3368, NULL, '2012-01-20 12:55:20.239934+00', 'MacDonald of Sleat', 2038, 2, 0, 120, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3369, NULL, '2012-01-20 12:55:20.246198+00', 'Para Handy Polka, The', 2038, 13, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3370, NULL, '2012-01-20 12:55:20.252455+00', 'Deil amang the Tailors, The', 2038, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3371, NULL, '2012-01-20 12:55:20.258841+00', 'Irish Jig Medley', 2038, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3372, NULL, '2012-01-20 12:55:20.265098+00', 'Baldovan Strathspey, The', 2038, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3373, NULL, '2012-01-20 12:55:20.271381+00', 'Coming Through the Rye', 2038, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3374, NULL, '2012-01-20 12:55:20.27763+00', 'Bluebell Polka', 2038, 13, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3375, NULL, '2012-01-20 12:55:20.283883+00', 'March, Strathspey and Reel', 2038, 4, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3376, NULL, '2012-01-20 12:55:20.291375+00', 'Harry Lauder Medley', 2038, 50, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3377, NULL, '2012-01-20 12:55:20.297674+00', 'Tartan Track Reel, The', 1701, 1, 0, 128, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3378, NULL, '2012-01-20 12:55:20.303945+00', 'Tartan Track Jig, The', 1701, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3379, NULL, '2012-01-20 12:55:20.310228+00', 'Circassian Circle', 1701, 1, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4807, NULL, '2012-01-20 12:55:29.029795+00', 'Waltzes', 2185, 5, 0, 0, 9999, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (4808, NULL, '2012-01-20 12:55:29.034598+00', 'Reels', 2185, 1, 6, 32, 9999, NULL, 222, 0, '');
INSERT INTO 'recording' VALUES (4809, NULL, '2012-01-20 12:55:29.039396+00', 'Fête, The', 3038, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (4810, NULL, '2012-01-20 12:55:29.044185+00', 'Chapman, The', 3038, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (4811, NULL, '2012-01-20 12:55:29.04904+00', 'Bramble Bush, The', 3038, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (4812, NULL, '2012-01-20 12:55:29.053828+00', 'Deacon of the Weavers', 3038, 3, 8, 32, 9999, NULL, 499, 0, '');
INSERT INTO 'recording' VALUES (4813, NULL, '2012-01-20 12:55:29.058616+00', 'Miss Brown''s Reel', 3038, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (4814, NULL, '2012-01-20 12:55:29.063402+00', 'Haste to the Wedding', 3038, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (4815, NULL, '2012-01-20 12:55:29.068195+00', 'Miss Isabella McLeod', 3038, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (4816, NULL, '2012-01-20 12:55:29.07298+00', 'Lady of the Lake, The', 3038, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (4817, NULL, '2012-01-20 12:55:29.077773+00', 'Saw Ye my Wee Thing', 3038, 2, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (4818, NULL, '2012-01-20 12:55:29.082562+00', 'Three Bonnie Maidens', 3038, 3, 8, 32, 9999, NULL, 497, 0, '');
INSERT INTO 'recording' VALUES (4819, NULL, '2012-01-20 12:55:29.087379+00', 'Miss Dumbreck', 3038, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (4820, NULL, '2012-01-20 12:55:29.092337+00', 'Braes of Mellinish, The', 3038, 3, 8, 32, 9999, NULL, 497, 0, '');
INSERT INTO 'recording' VALUES (4821, NULL, '2012-01-20 12:55:29.097144+00', 'Dashing White Sergeant', 3009, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4822, NULL, '2012-01-20 12:55:29.101937+00', 'Bluebell Polka', 3009, 50, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4823, NULL, '2012-01-20 12:55:29.106725+00', 'Gay Gordons', 3009, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4824, NULL, '2012-01-20 12:55:29.111499+00', 'Gay Gordons (encore)', 3009, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4825, NULL, '2012-01-20 12:55:29.116292+00', 'Shetland Fiddler, The', 2631, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4826, NULL, '2012-01-20 12:55:29.121074+00', 'Something Old - Something New', 2631, 2, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4827, NULL, '2012-01-20 12:55:29.125897+00', 'Braes of Busby, The', 2631, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4828, NULL, '2012-01-20 12:55:29.130685+00', 'McLeod of Dunvegan', 2631, 1, 0, 160, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4829, NULL, '2012-01-20 12:55:29.135488+00', 'Jeannie O'' The Witchin'' E''e', 2631, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4830, NULL, '2012-01-20 12:55:29.140275+00', 'Minard Castle', 2631, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4831, NULL, '2012-01-20 12:55:29.145074+00', 'Mrs Hay of Angus', 2631, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4832, NULL, '2012-01-20 12:55:29.149919+00', 'Auld Alliance, The', 2631, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4938, NULL, '2012-01-20 12:55:29.69596+00', 'Red House', 2681, 1, 6, 40, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (4833, NULL, '2012-01-20 12:55:29.154694+00', 'Border Reiver''s Bride, The', 2631, 4, 0, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4834, NULL, '2012-01-20 12:55:29.159466+00', 'Miss Hadden''s Reel', 2631, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4853, NULL, '2012-01-20 12:55:29.251883+00', 'Queen Victoria Hornpipe', 3063, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4854, NULL, '2012-01-20 12:55:29.256759+00', 'Gay Gordons', 3063, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4855, NULL, '2012-01-20 12:55:29.261551+00', 'Slow Waltz', 3063, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4856, NULL, '2012-01-20 12:55:29.266332+00', 'Set of Reels', 3063, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4857, NULL, '2012-01-20 12:55:29.271125+00', 'Laird of Milton''s Daughter, The', 3063, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4858, NULL, '2012-01-20 12:55:29.276737+00', 'Hen''s March, The', 3063, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4859, NULL, '2012-01-20 12:55:29.281646+00', 'Gaelic Waltz', 3063, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4860, NULL, '2012-01-20 12:55:29.286446+00', 'Ennis Reel', 2045, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4861, NULL, '2012-01-20 12:55:29.292197+00', 'Orpington Caledonians', 2045, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4862, NULL, '2012-01-20 12:55:29.297054+00', 'Five Barred Gate, The', 2045, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4863, NULL, '2012-01-20 12:55:29.301851+00', '1066 and all that', 2045, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4864, NULL, '2012-01-20 12:55:29.306632+00', 'Irish Rover, The', 2045, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4865, NULL, '2012-01-20 12:55:29.311428+00', 'Thistle, The', 2045, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4866, NULL, '2012-01-20 12:55:29.316218+00', 'Maria Stewart', 2045, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4867, NULL, '2012-01-20 12:55:29.320984+00', 'Kettle Drum', 2045, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10183, '2018-03-31 11:26:39.029231+00', '2018-03-31 12:00:59.191642+00', 'Strip the Willow', 11611, 2, 8, 32, NULL, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (4882, NULL, '2012-01-20 12:55:29.393422+00', 'Montgomeries'' Rant, The', 2645, 1, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (4883, NULL, '2012-01-20 12:55:29.398213+00', 'Gentle Shepherd, The', 2645, 2, 4, 32, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (4884, NULL, '2012-01-20 12:55:29.403037+00', 'Braes of Breadalbane, The', 2645, 3, 8, 32, 9999, NULL, 475, 0, '');
INSERT INTO 'recording' VALUES (4869, NULL, '2015-07-28 13:03:31.93547+00', 'Laird and the Mason, The', 3037, 4, 0, 64, 5, NULL, 125, 0, '');
INSERT INTO 'recording' VALUES (4870, NULL, '2015-07-28 13:04:52.207837+00', 'Gay Gordons', 3037, 11, 0, 16, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (4871, NULL, '2015-07-28 13:05:37.507152+00', 'Saint Bernard''s Waltz', 3037, 5, 0, 16, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (4872, NULL, '2015-07-28 13:06:27.263857+00', 'Eight Men of Moidart, The', 3037, 1, 8, 16, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (4875, NULL, '2015-07-28 13:14:31.893854+00', 'Isle of Skye', 3037, 1, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (4876, NULL, '2015-07-28 13:16:20.27108+00', 'Highland Barn Dance', 3037, 50, 10, 16, 9999, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (4878, NULL, '2015-07-28 13:18:02.18515+00', 'Scottish Waltz', 3037, 5, 0, 0, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (4879, NULL, '2015-07-28 13:19:11.894175+00', 'Military Two-Step', 3037, 11, 8, 16, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (4880, NULL, '2015-07-28 13:20:25.011606+00', 'Hooper''s Jig', 3037, 2, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (4873, NULL, '2015-07-28 13:23:36.004462+00', 'Jacky Tar Two-Step', 3037, 1, 0, 0, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (4877, NULL, '2015-07-28 13:24:19.215493+00', 'Miss Bennet''s Jig', 3037, 2, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (4885, NULL, '2012-01-20 12:55:29.407818+00', 'Reverend John MacFarlane, The', 2645, 1, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (4886, NULL, '2012-01-20 12:55:29.41261+00', 'It''s Just for Fun', 2645, 2, 8, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (4887, NULL, '2012-01-20 12:55:29.417492+00', 'Rouken Glen, The', 2645, 3, 0, 72, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (4888, NULL, '2012-01-20 12:55:29.422296+00', 'Inverness Country Dance', 2645, 1, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (4889, NULL, '2012-01-20 12:55:29.427093+00', 'Foursome Reel', 2645, 4, 0, 136, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (4890, NULL, '2012-01-20 12:55:29.431885+00', 'Reel of the 51st Division, The', 2645, 1, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (4891, NULL, '2012-01-20 12:55:29.436898+00', 'Hamilton House', 2645, 2, 8, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (4892, NULL, '2012-01-20 12:55:29.441716+00', 'Duke of Perth', 2645, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10165, '2018-03-30 08:26:29.199908+00', '2018-04-03 10:48:14.31962+00', 'Unicoi Unlimited', 11613, 2, 5, 32, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (4894, NULL, '2012-01-20 12:55:29.451296+00', 'Waverley or Fergus McIver', 2645, 2, 8, 48, 9999, NULL, 379, 0, '');
INSERT INTO 'recording' VALUES (4895, NULL, '2012-01-20 12:55:29.456179+00', 'Triumph, The', 2645, 1, 4, 24, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (4896, NULL, '2012-01-20 12:55:29.460966+00', 'Triumph, The (encore)', 2645, 1, 4, 24, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4897, NULL, '2012-01-20 12:55:29.465742+00', 'Balmoral Strathspey', 2645, 3, 4, 32, 9999, NULL, 237, 0, '');
INSERT INTO 'recording' VALUES (4898, NULL, '2012-01-20 12:55:29.470532+00', 'Strip the WIllow', 2645, 2, 4, 56, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (4900, NULL, '2012-01-20 12:55:29.480137+00', 'Airdrie Lassies', 3036, 2, 4, 48, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (4901, NULL, '2012-01-20 12:55:29.484927+00', 'Mile to Ride, A', 3036, 3, 8, 32, 9999, NULL, 496, 0, '');
INSERT INTO 'recording' VALUES (4902, NULL, '2012-01-20 12:55:29.489717+00', 'Fairly Shot O'' Her', 3036, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (4903, NULL, '2012-01-20 12:55:29.494505+00', 'Lady Mary Cochrane''s Reel', 3036, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (4904, NULL, '2012-01-20 12:55:29.499298+00', 'Lord Elgin''s Reel', 3036, 3, 8, 32, 9999, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (4905, NULL, '2012-01-20 12:55:29.504113+00', 'Old Nick''s Lumber Room', 3036, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (4906, NULL, '2012-01-20 12:55:29.508899+00', 'Rob Roy MacGregor', 3036, 3, 8, 32, 9999, NULL, 501, 0, '');
INSERT INTO 'recording' VALUES (4908, NULL, '2012-01-20 12:55:29.518517+00', 'Sugar Candie', 3036, 3, 8, 32, 9999, NULL, 496, 0, '');
INSERT INTO 'recording' VALUES (4910, NULL, '2012-01-20 12:55:29.528071+00', 'Ladies of Dunse, The', 3036, 1, 8, 40, 9999, NULL, 354, 0, '');
INSERT INTO 'recording' VALUES (4911, NULL, '2012-01-20 12:55:29.532882+00', 'New Waterloo Reel, The', 3036, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (4914, NULL, '2012-01-20 12:55:29.55499+00', 'Nice to See You', 2137, 1, 5, 32, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (4915, NULL, '2012-01-20 12:55:29.561468+00', 'Forth Bridge Jig', 2137, 2, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (4916, NULL, '2012-01-20 12:55:29.56939+00', '12 Coates Crescent', 2137, 3, 4, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (4917, NULL, '2012-01-20 12:55:29.575659+00', 'EH3 7AF', 2137, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (4919, NULL, '2012-01-20 12:55:29.588148+00', 'Airyhall Delight', 2137, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (4920, NULL, '2012-01-20 12:55:29.594448+00', 'Royal Deeside Railway, The', 2137, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (4921, NULL, '2012-01-20 12:55:29.600682+00', 'Simon''s Dance', 2137, 1, 0, 128, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (4922, NULL, '2012-01-20 12:55:29.606933+00', 'Dhoon, The', 2137, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (4923, NULL, '2012-01-20 12:55:29.613155+00', 'Papillon, Le', 2137, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (4924, NULL, '2012-01-20 12:55:29.619387+00', 'Jig for Mrs Dunn, A', 2137, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (4925, NULL, '2012-01-20 12:55:29.625623+00', 'Misses Cramb of Linlithgow, The', 2137, 2, 3, 32, 9999, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (4926, NULL, '2012-01-20 12:55:29.631865+00', 'Miss Falconer''s Fancy', 2137, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (4927, NULL, '2012-01-20 12:55:29.63825+00', 'Old Man of Storr, The', 2137, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (4928, NULL, '2012-01-20 12:55:29.644509+00', 'Maids of Currie, The', 2137, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (4929, NULL, '2012-01-20 12:55:29.650752+00', 'Edinburgh Castle Reel, The', 2137, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (4930, NULL, '2012-01-20 12:55:29.65706+00', 'Braes of Balluder, The', 2137, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (4931, NULL, '2012-01-20 12:55:29.662671+00', 'Come Under my Plaidie', 2137, 2, 5, 32, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (4932, NULL, '2012-01-20 12:55:29.667511+00', 'Dunoon Barn Dance', 2328, 50, 0, 16, 9999, NULL, 122, 0, '');
INSERT INTO 'recording' VALUES (4934, NULL, '2012-01-20 12:55:29.677001+00', 'Spiffin''', 2681, 2, 5, 32, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (4935, NULL, '2012-01-20 12:55:29.681943+00', 'Jan Wilson''s Strathspey', 2681, 3, 8, 32, 9999, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (4937, NULL, '2012-01-20 12:55:29.691156+00', 'Wee Cooper of Fife, The', 2681, 2, 8, 40, 9999, NULL, 357, 0, '');
INSERT INTO 'recording' VALUES (4836, NULL, '2022-08-20 23:09:03.95755+00', 'Pipe Marches', 3064, 11, 0, 0, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (4913, NULL, '2022-12-09 19:57:11.625368+00', 'Cutty Sark', 2137, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (4933, NULL, '2022-12-10 21:19:25.755259+00', 'Burning of Paddy''s Breeches, The', 2328, 4, 0, 128, 10044, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4939, NULL, '2012-01-20 12:55:29.700997+00', 'Demonstration Medley', 2681, 4, 0, 280, 49, NULL, 365, 0, '');
INSERT INTO 'recording' VALUES (4940, NULL, '2012-01-20 12:55:29.70584+00', 'Cairn Edward', 2681, 2, 8, 24, 9999, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (4941, NULL, '2012-01-20 12:55:29.710668+00', 'Cauld Comfort', 2681, 1, 4, 40, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (4942, NULL, '2012-01-20 12:55:29.715473+00', 'Monadh Liath', 2681, 3, 8, 32, 9999, NULL, 507, 0, '');
INSERT INTO 'recording' VALUES (4943, NULL, '2012-01-20 12:55:29.720271+00', 'Travelling Dancers, The', 2681, 2, 4, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4944, NULL, '2012-01-20 12:55:29.725181+00', 'Demonstration Medley', 2681, 4, 0, 0, 2, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (4945, NULL, '2012-01-20 12:55:29.729987+00', 'Waltz', 2681, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4946, NULL, '2012-01-20 12:55:29.734783+00', 'Gay Gordons', 2583, 11, 8, 16, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (4947, NULL, '2012-01-20 12:55:29.739579+00', 'Military Two-step', 2583, 11, 8, 16, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (4948, NULL, '2012-01-20 12:55:29.748133+00', 'L.A. XXth Anniversary', 2583, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (4949, NULL, '2012-01-20 12:55:29.754545+00', 'Gaelic Waltz', 2583, 5, 4, 32, 9999, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (4936, NULL, '2021-04-22 18:38:13.257224+00', 'Demonstration Medley', 2681, 4, 0, 256, NULL, NULL, 344, 0, '');
INSERT INTO 'recording' VALUES (4950, NULL, '2012-01-20 12:55:29.760838+00', 'Abbott of Unreason, The', 2583, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (4951, NULL, '2012-01-20 12:55:29.767973+00', 'Tin Woodman, The', 2583, 3, 8, 32, 9999, NULL, 493, 0, '');
INSERT INTO 'recording' VALUES (4952, NULL, '2012-01-20 12:55:29.77446+00', 'Flying Scotsman, The', 2583, 1, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (4953, NULL, '2012-01-20 12:55:29.780729+00', 'Eva Three Step', 2583, 11, 8, 16, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (4954, NULL, '2012-01-20 12:55:29.787004+00', 'Polka', 2583, 13, 4, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (4955, NULL, '2012-01-20 12:55:29.793262+00', 'Ballantine House', 2583, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (4956, NULL, '2012-01-20 12:55:29.799538+00', 'Banjo Paterson', 2583, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (4957, NULL, '2012-01-20 12:55:29.805799+00', 'Canadian Barn Dance', 2583, 11, 8, 16, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (4958, NULL, '2012-01-20 12:55:29.812056+00', 'Hoolighan''s Jig', 2583, 2, 4, 32, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (4959, NULL, '2012-01-20 12:55:29.818985+00', 'Dogsbody', 2583, 3, 8, 32, 9999, NULL, 493, 0, '');
INSERT INTO 'recording' VALUES (4960, NULL, '2012-01-20 12:55:29.82523+00', 'Reel of the Gordon Highlanders, The', 2696, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (4962, NULL, '2012-01-20 12:55:29.837752+00', 'Lady Lucy Ramsay', 2696, 3, 8, 32, 9999, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (4963, NULL, '2012-01-20 12:55:29.844213+00', '4 x 32 Jigs', 2696, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (4964, NULL, '2012-01-20 12:55:29.850458+00', 'Shiftin'' Bobbins', 2696, 1, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (4965, NULL, '2012-01-20 12:55:29.856674+00', '4 x 32 Strathspey Airs', 2696, 3, 4, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (4966, NULL, '2012-01-20 12:55:29.862919+00', 'West''s Hornpipe', 2696, 1, 4, 32, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (4967, NULL, '2012-01-20 12:55:29.86914+00', 'Medley', 2696, 98, 0, 0, 9999, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (4968, NULL, '2012-01-20 12:55:29.875372+00', 'Mrs Stewart''s Jig', 2696, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (4918, NULL, '2019-01-23 18:23:03.586995+00', 'Rabbie''s Reel', 2137, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (4907, NULL, '2019-01-23 23:41:52.788706+00', 'Lady Maxwell''s Reel', 3036, 4, 8, 32, 1, NULL, 389, 0, '');
INSERT INTO 'recording' VALUES (4969, NULL, '2012-01-20 12:55:29.881808+00', 'Triumph, The', 2696, 1, 4, 24, 9999, NULL, 116, 0, '');
INSERT INTO 'recording' VALUES (4970, NULL, '2012-01-20 12:55:29.888266+00', 'Gang the Same Gate', 2696, 3, 8, 32, 9999, NULL, 515, 0, '');
INSERT INTO 'recording' VALUES (4972, NULL, '2012-01-20 12:55:29.900728+00', 'Airs', 2696, 98, 0, 0, 9999, NULL, 224, 0, '');
INSERT INTO 'recording' VALUES (4973, NULL, '2012-01-20 12:55:29.906955+00', 'Not I', 2696, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (10159, '2018-03-29 18:50:45.514551+00', '2018-04-03 10:48:45.784813+00', 'Stone Mountain Reel', 11613, 1, 4, 32, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (4975, NULL, '2012-01-20 12:55:29.919419+00', '5 x 32 Reels', 2696, 1, 5, 32, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (4976, NULL, '2012-01-20 12:55:29.925652+00', 'Jack O'' Carron', 2038, 2, 4, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4977, NULL, '2012-01-20 12:55:29.931924+00', 'Angus MacLeod', 2038, 1, 2, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4978, NULL, '2012-01-20 12:55:29.938271+00', 'Trip to Tobermory, A', 2038, 3, 4, 24, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4979, NULL, '2012-01-20 12:55:29.944623+00', 'Nut, The', 2038, 2, 8, 24, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4980, NULL, '2012-01-20 12:55:29.95087+00', 'Waltz Country Dance', 2038, 5, 0, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4981, NULL, '2012-01-20 12:55:29.957091+00', 'Bonspiel, The', 2038, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4982, NULL, '2012-01-20 12:55:29.963327+00', 'Bumpkin, The', 2038, 2, 0, 112, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4983, NULL, '2012-01-20 12:55:29.969562+00', 'West''s Hornpipe', 2038, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4984, NULL, '2012-01-20 12:55:29.975801+00', 'Scottish Lilt', 2038, 7, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4985, NULL, '2012-01-20 12:55:29.982039+00', 'Moulin Dhu, The', 2038, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4986, NULL, '2012-01-20 12:55:29.988265+00', 'Fykit, The', 2038, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4987, NULL, '2012-01-20 12:55:29.994515+00', 'Hielan'' Laddie', 2038, 7, 0, 88, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4997, NULL, '2012-01-20 12:55:30.057106+00', 'Nice to See You', 2188, 1, 6, 32, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (4998, NULL, '2012-01-20 12:55:30.063348+00', 'Immigrant Lass, The', 2188, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (4999, NULL, '2012-01-20 12:55:30.069579+00', 'Indian River Strathspey', 2188, 3, 3, 32, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (5000, NULL, '2012-01-20 12:55:30.075829+00', 'Flight of the Falcon, The', 2188, 2, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (5001, NULL, '2012-01-20 12:55:30.122639+00', 'Jacky Tar', 2188, 1, 4, 32, 9999, NULL, 155, 1, '');
INSERT INTO 'recording' VALUES (5002, NULL, '2012-01-20 12:55:30.129134+00', 'Aird of Coigach', 2188, 2, 4, 48, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (5003, NULL, '2012-01-20 12:55:30.135518+00', 'Blue Mess Jacket, The', 2188, 3, 4, 32, 9999, NULL, 238, 0, '');
INSERT INTO 'recording' VALUES (5004, NULL, '2012-01-20 12:55:30.142005+00', 'Midnight Oil', 2188, 2, 5, 48, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (5006, NULL, '2012-01-20 12:55:30.154743+00', 'Sloane Square', 2188, 3, 0, 64, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (5007, NULL, '2012-01-20 12:55:30.160987+00', 'Welcome to Dufftown', 2188, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (5008, NULL, '2012-01-20 12:55:30.166505+00', 'Caddam Wood', 2188, 1, 5, 32, 9999, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (5009, NULL, '2012-01-20 12:55:30.171783+00', 'Bees of MaggieKnockater, The', 2188, 2, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (5010, NULL, '2012-01-20 12:55:30.176647+00', 'Bonnie Lass of Bon Accord', 2188, 3, 0, 64, 9999, NULL, 127, 0, '');
INSERT INTO 'recording' VALUES (5011, NULL, '2012-01-20 12:55:30.181425+00', 'White Heather Jig, The', 2188, 2, 4, 40, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (5012, NULL, '2012-01-20 12:55:30.186241+00', 'One o''Clock Canon, The', 2583, 1, 5, 32, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (5013, NULL, '2012-01-20 12:55:30.191026+00', 'Good Hearted Glasgow', 2583, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5014, NULL, '2012-01-20 12:55:30.195842+00', 'Bob Campbell', 2583, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (5015, NULL, '2012-01-20 12:55:30.20064+00', 'Celtic Bicentenary, The', 2583, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (5016, NULL, '2012-01-20 12:55:30.205409+00', 'Gothenburg''s Welcome', 2583, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5017, NULL, '2012-01-20 12:55:30.210208+00', 'Derwent Strathspey', 2583, 3, 4, 32, 9999, NULL, 253, 0, '');
INSERT INTO 'recording' VALUES (5018, NULL, '2012-01-20 12:55:30.214992+00', 'Davy Nick Nack', 2583, 1, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (5019, NULL, '2012-01-20 12:55:30.220804+00', 'Moudiewort, The', 2583, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (5020, NULL, '2012-01-20 12:55:30.225646+00', 'Glittering Caves, The', 2583, 4, 8, 32, 1, NULL, 395, 0, '');
INSERT INTO 'recording' VALUES (4988, NULL, '2022-07-24 17:42:50.122505+00', 'Frisky, The', 3049, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (4990, NULL, '2022-07-24 17:44:01.674704+00', 'Dalkeith''s Strathspey', 3049, 3, 4, 32, 9999, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (4991, NULL, '2022-07-24 17:44:31.152948+00', 'Mrs Stewart''s Jig', 3049, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (4992, NULL, '2022-07-24 17:45:12.723898+00', 'Trip to Bavaria, A', 3049, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (4993, NULL, '2022-07-24 17:45:55.892058+00', 'Soldier''s Joy, The', 3049, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (4994, NULL, '2022-07-24 17:46:40.495851+00', 'Follow Me Home', 3049, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (4995, NULL, '2022-07-24 17:49:03.40175+00', 'Duke of Perth', 3049, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (4996, NULL, '2022-07-24 17:50:55.680053+00', 'Strip the Willow', 3049, 2, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (4961, NULL, '2022-12-01 14:46:47.236637+00', 'Mr Morison', 2696, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5005, NULL, '2022-12-14 09:37:20.501223+00', 'Lord McLay''s Reel', 2188, 1, 4, 40, 9999, NULL, 182, 0, 'Most likely a typo on the CD. Should read "Lord MacLay''s Reel".');
INSERT INTO 'recording' VALUES (5022, NULL, '2012-01-20 12:55:30.235291+00', 'Eilean Donan Castle', 2583, 2, 3, 48, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (5023, NULL, '2012-01-20 12:55:30.240213+00', 'Kildrummy Castle', 2583, 3, 2, 32, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (5024, NULL, '2012-01-20 12:55:30.245088+00', 'Waggle of the Kilt', 2583, 2, 8, 40, 9999, NULL, 334, 0, '');
INSERT INTO 'recording' VALUES (5025, NULL, '2012-01-20 12:55:30.250052+00', 'Inverneill House', 2583, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (5026, NULL, '2012-01-20 12:55:30.254894+00', 'Auld Reekie Hornpipe', 1924, 1, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5027, NULL, '2012-01-20 12:55:30.259689+00', 'Anna''s Wedding Cake', 2737, 3, 3, 32, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (5029, NULL, '2012-01-20 12:55:30.269269+00', 'Maine Medley, The', 2727, 4, 8, 32, 1, NULL, 394, 0, '');
INSERT INTO 'recording' VALUES (5032, NULL, '2012-01-20 12:55:30.284723+00', 'Stoner House', 2042, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (5033, NULL, '2012-01-20 12:55:30.289537+00', 'Highland Schottische', 2730, 3, 0, 8, 9999, NULL, 128, 0, '');
INSERT INTO 'recording' VALUES (5035, NULL, '2012-01-20 12:55:30.299166+00', 'Earl of Northampton, The', 2732, 3, 8, 32, 9999, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (5036, NULL, '2012-01-20 12:55:30.303968+00', '25th Reel, The', 2733, 1, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (5037, NULL, '2012-01-20 12:55:30.308747+00', 'Latvian Lass, The', 3047, 4, 8, 32, 1, NULL, 371, 0, '');
INSERT INTO 'recording' VALUES (5041, NULL, '2012-01-20 12:55:30.32788+00', 'Waltzes', 2736, 5, 0, 0, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (5042, NULL, '2012-01-20 12:55:30.332696+00', 'Earl of Mansfield, The', 3023, 1, 4, 48, 9999, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (5043, NULL, '2012-01-20 12:55:30.337489+00', 'Gentleman, The', 3023, 3, 8, 32, 9999, NULL, 497, 0, '');
INSERT INTO 'recording' VALUES (5044, NULL, '2012-01-20 12:55:30.342741+00', 'Gothenburg''s Welcome', 3023, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (5045, NULL, '2012-01-20 12:55:30.347572+00', 'Plantation Reel, The', 3023, 1, 5, 32, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (5046, NULL, '2012-01-20 12:55:30.352361+00', 'Distillery Reel, The', 3023, 1, 4, 48, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (5047, NULL, '2012-01-20 12:55:30.35714+00', 'Broadford Bay', 3023, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5048, NULL, '2012-01-20 12:55:30.361961+00', 'Schiehallion', 3023, 4, 0, 128, 2, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (5049, NULL, '2012-01-20 12:55:30.366789+00', 'New Rigged Ship, The', 3023, 2, 8, 48, 9999, NULL, 411, 0, '');
INSERT INTO 'recording' VALUES (5050, NULL, '2012-01-20 12:55:30.371576+00', 'Montgomeries'' Rant, The', 3023, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5051, NULL, '2012-01-20 12:55:30.376365+00', 'Wee Cooper o'' Fife, The', 3023, 2, 6, 40, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (5052, NULL, '2012-01-20 12:55:30.381174+00', 'Moray Rant, The', 3023, 3, 3, 48, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (5021, NULL, '2016-03-01 00:16:48.585845+00', 'Trinity Tensome', 2583, 1, 5, 40, 9999, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (4971, NULL, '2017-10-10 11:06:14.751021+00', 'Old Spedling Castle''s Ghost''s Dance, The', 2696, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (5053, NULL, '2012-01-20 12:55:30.38598+00', 'Water of Dryfe, The', 3023, 1, 5, 32, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (5054, NULL, '2012-01-20 12:55:30.39076+00', 'Kinfauns Castle', 3023, 3, 5, 32, 9999, NULL, 311, 0, '');
INSERT INTO 'recording' VALUES (5055, NULL, '2012-01-20 12:55:30.39559+00', 'Tribute to the Borders, A', 2036, 2, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (5056, NULL, '2012-01-20 12:55:30.400388+00', 'Trip to Bavaria, A', 2036, 1, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (5057, NULL, '2012-01-20 12:55:30.40519+00', 'Autumn in Appin', 2036, 3, 4, 32, 9999, NULL, 254, 0, '');
INSERT INTO 'recording' VALUES (5058, NULL, '2012-01-20 12:55:30.409997+00', 'Postie''s Jig', 2036, 2, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (5059, NULL, '2012-01-20 12:55:30.414775+00', 'Reel of the 51st Division', 2036, 1, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (5060, NULL, '2012-01-20 12:55:30.420327+00', 'Seton''s Ceilidh Band', 2036, 2, 4, 64, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (5061, NULL, '2012-01-20 12:55:30.425266+00', 'Brisk Young Lads', 2036, 2, 5, 48, 9999, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (5062, NULL, '2012-01-20 12:55:30.430122+00', 'Winds on Loch Fyne', 2036, 3, 3, 32, 9999, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (5063, NULL, '2012-01-20 12:55:30.435042+00', 'Earl of Mansfield', 2036, 1, 4, 48, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (5064, NULL, '2012-01-20 12:55:30.439833+00', 'Major Ian Stewart', 2036, 2, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (5065, NULL, '2012-01-20 12:55:30.444649+00', 'Johnny Walker', 2036, 4, 0, 128, 13, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (5066, NULL, '2012-01-20 12:55:30.449462+00', 'Shiftin'' Bobbins', 2036, 1, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (5067, NULL, '2012-01-20 12:55:30.454456+00', 'White Heather Jig, The', 9998, 2, 4, 40, 9999, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (5069, NULL, '2012-01-20 12:55:30.464096+00', 'Ian Powrie''s Farewell to Auchterarder', 9998, 2, 0, 128, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (5070, NULL, '2012-01-20 12:55:30.468892+00', 'Monymusk', 9998, 3, 4, 32, 9999, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (5071, NULL, '2012-01-20 12:55:30.473709+00', 'Irish Rover, The', 9998, 1, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (5072, NULL, '2012-01-20 12:55:30.478499+00', 'Trip To Bavaria, A', 9998, 1, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (5073, NULL, '2012-01-20 12:55:30.483356+00', 'Janet''s Delight', 9998, 5, 8, 16, 9999, NULL, 128, 0, '');
INSERT INTO 'recording' VALUES (5074, NULL, '2012-01-20 12:55:30.488145+00', 'Pasadena Prom', 9998, 3, 4, 32, 9999, NULL, 247, 0, '');
INSERT INTO 'recording' VALUES (5075, NULL, '2012-01-20 12:55:30.492921+00', 'Meeting of the Water', 9998, 1, 4, 48, 9999, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (5076, NULL, '2012-01-20 12:55:30.497711+00', 'MacLaine of Lochbuie', 9998, 1, 0, 160, 9999, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (5077, NULL, '2012-01-20 12:55:30.502492+00', 'Glasgow Country Dance', 9998, 4, 4, 32, 1, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (5078, NULL, '2012-01-20 12:55:30.507279+00', 'Bonnie Anne', 9998, 2, 0, 96, 9999, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (5079, NULL, '2012-01-20 12:55:30.512063+00', 'Bull Stane, The', 9998, 1, 5, 40, 9999, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (5080, NULL, '2012-01-20 12:55:30.516847+00', 'Traditional Black Watch Tunes', 1556, 98, 0, 0, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (5081, NULL, '2012-01-20 12:55:30.521639+00', 'Saltire Society Reel, The', 1556, 1, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (5082, NULL, '2012-01-20 12:55:30.526428+00', 'Major Iain Stewart', 1556, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (5083, NULL, '2012-01-20 12:55:30.531254+00', 'Mr Yasumuro''s Strathspey', 1556, 3, 4, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (5084, NULL, '2012-01-20 12:55:30.536031+00', 'Highland Schottische', 1556, 3, 0, 8, 9999, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (5085, NULL, '2012-01-20 12:55:30.540815+00', 'Church Music Selection', 1556, 98, 0, 0, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (5086, NULL, '2012-01-20 12:55:30.545613+00', 'Atsuko''s Wedding', 1556, 1, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (5087, NULL, '2012-01-20 12:55:30.550402+00', 'Joe MacDiarmid''s Jig', 1556, 2, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (5088, NULL, '2012-01-20 12:55:30.555214+00', 'Duchess of Atholl''s Slipper, The', 1556, 3, 8, 32, 9999, NULL, 529, 0, '');
INSERT INTO 'recording' VALUES (5089, NULL, '2012-01-20 12:55:30.560006+00', 'Blue Bonnets over the Border', 1556, 7, 6, 0, 9999, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (5090, NULL, '2012-01-20 12:55:30.564783+00', 'Reel of the Royal Scots, The', 1556, 1, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (5091, NULL, '2012-01-20 12:55:30.569588+00', 'Waltz', 1556, 5, 0, 0, 9999, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (5092, NULL, '2012-01-20 12:55:30.574391+00', 'Church Music Selection', 1556, 98, 0, 0, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (5093, NULL, '2012-01-20 12:55:30.579167+00', 'Earl of Mansfield, The', 1556, 1, 4, 48, 9999, NULL, 222, 0, '');
INSERT INTO 'recording' VALUES (5094, NULL, '2012-01-20 12:55:30.583943+00', 'Colonel is a Lady, The', 1556, 2, 8, 40, 9999, NULL, 357, 0, '');
INSERT INTO 'recording' VALUES (5095, NULL, '2012-01-20 12:55:30.588746+00', 'Eightsome Reel, The', 1556, 1, 1, 464, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (5096, NULL, '2012-01-20 12:55:30.593572+00', 'Sine Bhan', 1556, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5097, NULL, '2012-01-20 12:55:30.598355+00', 'Betty Wilde''s Delight', 2197, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5098, NULL, '2012-01-20 12:55:30.603131+00', 'East of Yeadon', 1556, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (5099, NULL, '2012-01-20 12:55:30.607928+00', 'Alastair Hunter''s Reel', 3002, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (5100, NULL, '2012-01-20 12:55:30.612732+00', 'Cramond Wedding, The', 3002, 3, 3, 32, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (5101, NULL, '2012-01-20 12:55:30.617511+00', 'Miller of Sessnie, The', 3002, 2, 5, 32, 9999, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (5102, NULL, '2012-01-20 12:55:30.622332+00', 'Grants'' New Rant, The', 3002, 3, 8, 32, 9999, NULL, 522, 0, '');
INSERT INTO 'recording' VALUES (5104, NULL, '2012-01-20 12:55:30.631932+00', 'Monique''s Jig', 3002, 2, 4, 40, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (5038, NULL, '2022-10-21 07:09:41.534322+00', 'Northern Harmony', 2734, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5040, NULL, '2022-08-31 21:30:38.149462+00', 'Sprig of Ivy, The', 2735, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5103, NULL, '2022-08-31 21:55:25.555301+00', 'Bartons'' Reel, The', 3002, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (5039, NULL, '2022-09-01 10:56:46.801403+00', 'Fill the Fetters', 2066, 3, 4, 32, 9999, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (5034, NULL, '2022-12-22 13:51:07.9139+00', 'Burns Night', 2731, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (5106, NULL, '2012-01-20 12:55:30.641506+00', 'Eric''s Jubilee', 3002, 1, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (5107, NULL, '2012-01-20 12:55:30.646293+00', 'My Jo', 3002, 3, 8, 32, 9999, NULL, 531, 0, '');
INSERT INTO 'recording' VALUES (5108, NULL, '2012-01-20 12:55:30.651144+00', 'Side by Side', 3002, 2, 8, 40, 9999, NULL, 364, 0, '');
INSERT INTO 'recording' VALUES (10160, '2018-03-29 18:53:42.626946+00', '2018-04-03 10:49:14.109289+00', 'Randall Allen of Country Troup', 11613, 3, 3, 32, NULL, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (5110, NULL, '2012-01-20 12:55:30.660943+00', 'Mary Erskine', 3002, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (5111, NULL, '2012-01-20 12:55:30.66574+00', 'Thirty Years On', 3002, 3, 4, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (5112, NULL, '2012-01-20 12:55:30.670531+00', 'Water of Fleet, The', 3002, 2, 4, 32, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (5114, NULL, '2012-01-20 12:55:30.680429+00', 'Balmullo Reel, The', 3002, 1, 0, 88, 9999, NULL, 106, 0, '');
INSERT INTO 'recording' VALUES (5115, NULL, '2012-01-20 12:55:30.685225+00', 'Celebration Jig, The', 3002, 2, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (5116, NULL, '2012-01-20 12:55:30.690811+00', 'Pelorus Jack', 3006, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (5117, NULL, '2012-01-20 12:55:30.695678+00', 'Culla Bay', 3006, 3, 4, 32, 9999, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (5118, NULL, '2012-01-20 12:55:30.700669+00', 'Dancers'' Wedding, The', 3006, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (5119, NULL, '2012-01-20 12:55:30.705467+00', 'Connie''s Jig', 3006, 2, 8, 48, 9999, NULL, 419, 0, '');
INSERT INTO 'recording' VALUES (5120, NULL, '2012-01-20 12:55:30.710283+00', 'Peggy''s Strathspey', 3006, 3, 8, 32, 9999, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (5121, NULL, '2012-01-20 12:55:30.71511+00', 'Music Will Tell You, The', 3006, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (5122, NULL, '2012-01-20 12:55:30.7199+00', 'Milltimber Jig, The', 3006, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5123, NULL, '2012-01-20 12:55:30.724686+00', 'S-Locomotion', 3006, 3, 4, 32, 9999, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (5124, NULL, '2012-01-20 12:55:30.729484+00', 'Blackwater Reel, The', 3006, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5125, NULL, '2012-01-20 12:55:30.734292+00', 'Roselath Cross, The', 3006, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5126, NULL, '2012-01-20 12:55:30.739088+00', 'Strathspey for Eric, A', 2197, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5127, NULL, '2012-01-20 12:55:30.743867+00', 'Luck to You', 2197, 1, 3, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5128, NULL, '2012-01-20 12:55:30.748643+00', 'Luck to You', 2197, 4, 0, 144, 10010, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5129, NULL, '2012-01-20 12:55:30.753432+00', 'Follow Your Love', 2197, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5130, NULL, '2012-01-20 12:55:30.758225+00', '75 Years Young', 2197, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5131, NULL, '2012-01-20 12:55:30.763008+00', 'Spiffin''', 3038, 2, 5, 32, 9999, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (5132, NULL, '2012-01-20 12:55:30.767892+00', 'Hamilton Welcome', 3038, 3, 5, 32, 9999, NULL, 308, 0, '');
INSERT INTO 'recording' VALUES (5133, NULL, '2012-01-20 12:55:30.77274+00', 'Domino 5', 3038, 1, 5, 32, 9999, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (5134, NULL, '2012-01-20 12:55:30.777542+00', 'Flight of the Falcon, The', 3038, 2, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (5105, NULL, '2017-02-05 09:20:41.787522+00', 'Elisabeth Hunter''s Strathspey', 3002, 3, 3, 32, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (5135, NULL, '2012-01-20 12:55:30.782353+00', 'Cradle Song, The', 3038, 3, 4, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5136, NULL, '2012-01-20 12:55:30.78716+00', 'Highland Lass, The', 3038, 1, 8, 32, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (5137, NULL, '2012-01-20 12:55:30.791961+00', 'Summer''s End', 3038, 2, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (5139, NULL, '2012-01-20 12:55:30.801557+00', 'Elizabeth Hunter''s Strathspey', 3038, 3, 3, 32, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (5140, NULL, '2012-01-20 12:55:30.812393+00', 'Donald''s Awa tae the War', 3038, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (5142, NULL, '2012-01-20 12:55:30.825266+00', 'Cuillins of Skye', 3038, 3, 8, 32, 9999, NULL, 491, 0, '');
INSERT INTO 'recording' VALUES (5143, NULL, '2012-01-20 12:55:30.83162+00', 'Tattie Bogle, The', 3038, 2, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (10166, '2018-03-30 08:30:10.963448+00', '2018-04-03 10:49:38.409523+00', 'Well Done, Bernard', 11613, 2, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (5147, NULL, '2012-01-20 12:55:30.857748+00', 'Ceres Games', 3002, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (5148, NULL, '2012-01-20 12:55:30.864031+00', 'Leslie House', 3002, 4, 0, 128, 2, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (5149, NULL, '2012-01-20 12:55:30.870338+00', 'Mamie''s Jig', 3002, 2, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (5150, NULL, '2012-01-20 12:55:30.876749+00', 'Lundin Links Strathspey, The', 3002, 3, 8, 32, 9999, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (5152, NULL, '2012-01-20 12:55:30.889371+00', 'Pittenweem', 3002, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (5153, NULL, '2012-01-20 12:55:30.89579+00', 'Rodger''s Five-O Reel', 3002, 1, 3, 64, 9999, NULL, 246, 1, '');
INSERT INTO 'recording' VALUES (5154, NULL, '2012-01-20 12:55:30.902067+00', 'Willie''s Girl', 3002, 1, 4, 48, 9999, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (5141, NULL, '2012-04-27 23:17:22.054251+00', 'Celtic Cross', 3038, 1, 4, 48, 9999, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (5155, NULL, '2012-01-20 12:55:30.908328+00', 'Wedding in St. Monans', 3002, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5156, NULL, '2012-01-20 12:55:30.914917+00', 'Anstruther Lassies', 3002, 1, 8, 40, 9999, NULL, 344, 0, '');
INSERT INTO 'recording' VALUES (5157, NULL, '2012-01-20 12:55:30.921207+00', 'Fife Ness', 3002, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (5159, NULL, '2012-01-20 12:55:30.934373+00', 'Australian Ladies', 2846, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (5160, NULL, '2012-01-20 12:55:30.940767+00', 'Follow Me Home', 2846, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5161, NULL, '2012-01-20 12:55:30.947743+00', 'Duke of Wellington, The', 2846, 1, 8, 32, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (5162, NULL, '2012-01-20 12:55:30.95403+00', 'Duke of Wellington, The', 2846, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (5163, NULL, '2012-01-20 12:55:30.960453+00', 'Mrs Milne of Kinneff', 2846, 3, 4, 32, 9999, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (5164, NULL, '2012-01-20 12:55:30.966773+00', 'Flight of the Falcon', 2846, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5165, NULL, '2012-01-20 12:55:30.973049+00', 'Reel of the Royal Scots, The', 2846, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5166, NULL, '2012-01-20 12:55:30.979467+00', 'Reel of the Royal Scots, The', 2846, 1, 4, 32, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (5167, NULL, '2012-01-20 12:55:30.985834+00', 'Silver Tassie', 2846, 3, 8, 32, 9999, NULL, 487, 0, '');
INSERT INTO 'recording' VALUES (5169, NULL, '2012-01-20 12:55:30.998568+00', 'Falls of Rogie', 2846, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (5171, NULL, '2012-01-20 12:55:31.011117+00', 'Riviera Reel, The', 1396, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (5173, NULL, '2012-01-20 12:55:31.023828+00', 'Allison''s Jig', 1396, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5174, NULL, '2012-01-20 12:55:31.03013+00', 'MacPhail''s Magic', 1396, 1, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (5175, NULL, '2012-01-20 12:55:31.036406+00', 'Gordonian Strathspey, The', 1396, 3, 3, 32, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (5176, NULL, '2012-01-20 12:55:31.043078+00', 'Plum Tree JIg', 1396, 2, 5, 32, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (5178, NULL, '2012-01-20 12:55:31.055794+00', 'Muirs of Greywell, The', 1396, 2, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (5180, NULL, '2012-01-20 12:55:31.070083+00', 'Brunette d''Ecosse', 1396, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (5182, NULL, '2012-01-20 12:55:31.083954+00', 'Tri-Mariner, The', 1396, 1, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (5183, NULL, '2012-01-20 12:55:31.091499+00', 'Ye''re Welcome, Charlie Stuart', 3030, 1, 4, 32, 9999, 5, 146, 0, '');
INSERT INTO 'recording' VALUES (5184, NULL, '2012-01-20 12:55:31.098699+00', 'Flora, La', 3030, 2, 8, 32, 9999, 1, 292, 0, '');
INSERT INTO 'recording' VALUES (5185, NULL, '2012-01-20 12:55:31.106005+00', 'Sauchie Haugh', 3030, 3, 8, 32, 9999, 5, 495, 0, '');
INSERT INTO 'recording' VALUES (5186, NULL, '2012-01-20 12:55:31.113096+00', 'Reel for Andersons Rant', 3030, 1, 8, 32, 9999, 5, 286, 0, '');
INSERT INTO 'recording' VALUES (5187, NULL, '2012-01-20 12:55:31.121078+00', 'Ellie''s Jig', 3030, 2, 8, 32, 9999, 1, 290, 0, '');
INSERT INTO 'recording' VALUES (5188, NULL, '2012-01-20 12:55:31.128437+00', 'Mary Hamilton', 3030, 3, 4, 32, 9999, 5, 266, 0, '');
INSERT INTO 'recording' VALUES (5189, NULL, '2012-01-20 12:55:31.135911+00', 'Davy Nick Nack', 3030, 1, 8, 32, 9999, 1, 283, 0, '');
INSERT INTO 'recording' VALUES (5190, NULL, '2012-01-20 12:55:31.143727+00', 'Collichur', 3030, 2, 8, 32, 9999, 1, 290, 0, '');
INSERT INTO 'recording' VALUES (5191, NULL, '2012-01-20 12:55:31.151222+00', 'J.B. Milne', 3030, 1, 8, 32, 9999, 23, 279, 0, '');
INSERT INTO 'recording' VALUES (5192, NULL, '2012-01-20 12:55:31.158762+00', 'Sugar Candie', 3030, 3, 8, 32, 9999, 5, 497, 0, '');
INSERT INTO 'recording' VALUES (5193, NULL, '2012-01-20 12:55:31.166546+00', 'De''il Amang the Tailors', 3030, 1, 4, 32, 9999, 5, 142, 0, '');
INSERT INTO 'recording' VALUES (5194, NULL, '2012-01-20 12:55:31.173012+00', 'Waltz', 3030, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5195, NULL, '2012-01-20 12:55:31.179354+00', 'Eightsome Reel', 3011, 1, 1, 464, 9999, NULL, 478, 0, '');
INSERT INTO 'recording' VALUES (5196, NULL, '2012-01-20 12:55:31.18573+00', 'Foursome Reel', 3011, 4, 0, 136, 10011, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (5177, NULL, '2022-08-13 21:27:08.452902+00', 'Welcome Aboard', 1396, 4, 0, 128, 2, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (5158, NULL, '2022-12-23 14:11:27.610381+00', 'Happy 75th', 3002, 4, 0, 196, 53, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (5197, NULL, '2012-01-20 12:55:31.19217+00', 'Reel of the 51st Division, The', 3011, 1, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (5198, NULL, '2012-01-20 12:55:31.198914+00', 'Machine Without Horses', 3011, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (5199, NULL, '2012-01-20 12:55:31.205297+00', 'Mairi''s Wedding', 3011, 1, 8, 40, 9999, NULL, 340, 0, '');
INSERT INTO 'recording' VALUES (5200, NULL, '2012-01-20 12:55:31.211578+00', 'Duke and Duchess of Edinburgh, The', 3011, 1, 8, 40, 9999, NULL, 337, 0, '');
INSERT INTO 'recording' VALUES (5201, NULL, '2012-01-20 12:55:31.218015+00', 'Gay Gordons', 3011, 11, 6, 16, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (5202, NULL, '2012-01-20 12:55:31.224558+00', 'Hamilton House', 3011, 2, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (5203, NULL, '2012-01-20 12:55:31.230917+00', 'Duke of Perth', 3011, 1, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (5204, NULL, '2012-01-20 12:55:31.237205+00', 'Saint Bernard''s Waltz', 3011, 5, 0, 16, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (5205, NULL, '2012-01-20 12:55:31.243613+00', 'Petronella', 3011, 1, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (5206, NULL, '2012-01-20 12:55:31.249878+00', 'Strip the Willow', 3011, 2, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (5207, NULL, '2012-01-20 12:55:31.256286+00', 'Dashing White Sergeant, The', 3011, 1, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (5208, NULL, '2012-01-20 12:55:31.262537+00', 'Gay Gordons', 3069, 11, 8, 16, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (5209, NULL, '2012-01-20 12:55:31.268893+00', 'Gay Gordons, The', 3026, 11, 8, 16, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (5210, NULL, '2012-01-20 12:55:31.275238+00', 'Hesitation Waltz', 3026, 5, 10, 16, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (5211, NULL, '2012-01-20 12:55:31.281468+00', 'Maxina, The', 3026, 99, 0, 0, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (5212, NULL, '2012-01-20 12:55:31.28838+00', 'Dinkie One-Step', 3026, 99, 0, 0, 9999, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (5213, NULL, '2012-01-20 12:55:31.294641+00', 'Haddo House', 2944, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5214, NULL, '2012-01-20 12:55:31.300875+00', 'Mrs Ernest Allan''s Strathspey', 2944, 3, 4, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (5215, NULL, '2012-01-20 12:55:31.307327+00', 'Miss A. O. Cumming', 2944, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5181, NULL, '2019-06-28 14:29:01.900019+00', 'At the Top of the Hill', 1396, 2, 3, 32, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (5219, NULL, '2012-01-20 12:55:31.332532+00', 'Langstane Kirk Jig, The', 2944, 2, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (5151, NULL, '2016-09-04 14:04:40.076446+00', 'Murray''s Jig', 3002, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (5146, NULL, '2017-06-05 08:06:14.952042+00', 'Cellardyke', 3002, 2, 0, 144, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (5170, NULL, '2019-06-28 15:07:36.046566+00', 'Jackdaw, The', 1396, 2, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (5145, NULL, '2019-09-06 20:17:39.086155+00', 'Bull Stane, The', 3002, 1, 8, 40, 9999, NULL, 348, 0, '');
INSERT INTO 'recording' VALUES (5220, NULL, '2012-01-20 12:55:31.338799+00', 'Beechwood Strathspey, The', 2944, 3, 8, 32, 9999, NULL, 514, 0, '');
INSERT INTO 'recording' VALUES (5221, NULL, '2012-01-20 12:55:31.344731+00', 'Gladys McDonald of Glencoe', 2944, 2, 8, 40, 9999, NULL, 343, 0, '');
INSERT INTO 'recording' VALUES (5222, NULL, '2012-01-20 12:55:31.349688+00', 'Welcome to Queen''s Cross', 2944, 3, 4, 48, 9999, NULL, 387, 0, '');
INSERT INTO 'recording' VALUES (5223, NULL, '2012-01-20 12:55:31.357416+00', 'Blooms of Bon Accord', 2944, 1, 4, 32, 9999, NULL, 145, 1, '');
INSERT INTO 'recording' VALUES (5224, NULL, '2012-01-20 12:55:31.363762+00', 'Bonnie Banchory', 2944, 1, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (5225, NULL, '2012-01-20 12:55:31.37006+00', 'Warm-Up Waltz', 3067, 5, 5, 32, 9999, NULL, 238, 0, '');
INSERT INTO 'recording' VALUES (5226, NULL, '2012-01-20 12:55:31.376388+00', 'Warm-Up March', 3067, 11, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (5227, NULL, '2012-01-20 12:55:31.382649+00', 'Selection of Jigs', 3067, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (5228, NULL, '2012-01-20 12:55:31.388903+00', 'Selection of Reels', 3067, 1, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (5230, NULL, '2012-01-20 12:55:31.401416+00', 'Selection of Jigs', 3067, 2, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (5231, NULL, '2012-01-20 12:55:31.407687+00', 'Selection of Reels', 3067, 1, 5, 32, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (5232, NULL, '2012-01-20 12:55:31.413944+00', 'Selection of Strathspeys', 3067, 3, 3, 32, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (5233, NULL, '2012-01-20 12:55:31.420381+00', 'Selection of Jigs', 3067, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5234, NULL, '2012-01-20 12:55:31.426707+00', 'Selection of Reels', 3067, 1, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (5236, NULL, '2012-01-20 12:55:31.439185+00', 'Selection of Jigs', 3067, 2, 6, 32, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (5237, NULL, '2012-01-20 12:55:31.44541+00', 'Selection of Strathspeys', 3067, 3, 4, 32, 9999, NULL, 247, 0, '');
INSERT INTO 'recording' VALUES (5238, NULL, '2012-01-20 12:55:31.451818+00', 'Selection of Reels', 3067, 1, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (5239, NULL, '2012-01-20 12:55:31.458072+00', 'Cool-Down Waltz', 3067, 5, 0, 104, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (5240, NULL, '2012-01-20 12:55:31.464463+00', 'Soft Horse Reel, The', 3012, 1, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (5241, NULL, '2012-01-20 12:55:31.470706+00', 'Sandy Nixon''s Jig', 3012, 2, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (5242, NULL, '2012-01-20 12:55:31.47694+00', 'Tribute to Stan Saunders, A', 3012, 98, 0, 0, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (5243, NULL, '2012-01-20 12:55:31.483172+00', 'Two-step', 3012, 11, 0, 0, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (5244, NULL, '2012-01-20 12:55:31.489392+00', 'Hamish''s 2/4 Marches', 3012, 11, 0, 0, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (5245, NULL, '2012-01-20 12:55:31.495784+00', 'Helen Frame''s Jig', 3012, 2, 4, 32, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (5246, NULL, '2012-01-20 12:55:31.502156+00', 'Polka', 3012, 13, 0, 0, 9999, NULL, 107, 0, '');
INSERT INTO 'recording' VALUES (5247, NULL, '2012-01-20 12:55:31.508412+00', 'Dumfries House', 3012, 2, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (5248, NULL, '2012-01-20 12:55:31.514685+00', 'Angus Reel, The', 3012, 1, 0, 128, 9999, NULL, 140, 1, '');
INSERT INTO 'recording' VALUES (5249, NULL, '2012-01-20 12:55:31.520911+00', 'Pride of Erin Waltz', 3012, 5, 0, 32, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (5250, NULL, '2012-01-20 12:55:31.527182+00', 'Gay Gordons', 3012, 11, 0, 16, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (5251, NULL, '2012-01-20 12:55:31.53356+00', 'Two-step', 3012, 11, 0, 0, 9999, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (5252, NULL, '2012-01-20 12:55:31.53991+00', 'Water Aid Reel', 3012, 1, 0, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (5253, NULL, '2012-01-20 12:55:31.546152+00', 'Eva Three Step', 3012, 11, 0, 16, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (5254, NULL, '2012-01-20 12:55:31.552374+00', 'Polka', 3012, 13, 0, 0, 9999, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (5255, NULL, '2012-01-20 12:55:31.558631+00', 'Iain Peterson''s Waltz', 3012, 5, 0, 0, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (5256, NULL, '2012-01-20 12:55:31.564915+00', 'Gay Gordons', 3012, 11, 0, 16, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (5257, NULL, '2012-01-20 12:55:31.571167+00', 'Black Mountain Reel, The', 3012, 1, 5, 32, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (5258, NULL, '2012-01-20 12:55:31.577414+00', 'Tribute to the Borders', 3012, 2, 4, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (5259, NULL, '2012-01-20 12:55:31.583645+00', 'Medley', 3012, 98, 0, 0, 9999, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (5260, NULL, '2012-01-20 12:55:31.589964+00', 'Two-step', 3012, 11, 0, 0, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (5261, NULL, '2012-01-20 12:55:31.596205+00', 'March Medley', 3012, 11, 0, 0, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (5262, NULL, '2012-01-20 12:55:31.602439+00', 'Pipe Medley', 3012, 98, 0, 0, 9999, NULL, 234, 0, '');
INSERT INTO 'recording' VALUES (5263, NULL, '2012-01-20 12:55:31.608654+00', 'Roxburgh Castle', 3012, 1, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (5264, NULL, '2012-01-20 12:55:31.614893+00', 'Diamond Jubilee, The', 3032, 2, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (5265, NULL, '2012-01-20 12:55:31.621219+00', 'Miss Nancy Arnott', 3032, 3, 8, 32, 9999, NULL, 482, 0, '');
INSERT INTO 'recording' VALUES (5266, NULL, '2012-01-20 12:55:31.627935+00', 'Luck to Loyne', 3032, 1, 5, 40, 9999, NULL, 226, 0, '');
INSERT INTO 'recording' VALUES (5267, NULL, '2012-01-20 12:55:31.63514+00', 'Airie Bennan', 3032, 2, 5, 32, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (5269, NULL, '2012-01-20 12:55:31.647777+00', 'Dog''s Breakfast, A', 3032, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5270, NULL, '2012-01-20 12:55:31.654163+00', 'Garry Strathspey, The', 3032, 3, 4, 32, 9999, NULL, 227, 0, '');
INSERT INTO 'recording' VALUES (5271, NULL, '2012-01-20 12:55:31.670959+00', 'Gannochy Reel, The', 3032, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (5272, NULL, '2012-01-20 12:55:31.678472+00', 'Miss Mary Douglas', 3032, 2, 8, 48, 9999, NULL, 406, 0, '');
INSERT INTO 'recording' VALUES (5273, NULL, '2012-01-20 12:55:31.684748+00', 'Whistling Wind, The', 3032, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5274, NULL, '2012-01-20 12:55:31.691037+00', 'Braw, Braw Lads', 3032, 3, 4, 32, 9999, NULL, 353, 0, '');
INSERT INTO 'recording' VALUES (5276, NULL, '2012-01-20 12:55:31.703595+00', 'Hamilton Rant, The', 3032, 1, 8, 48, 9999, NULL, 413, 0, '');
INSERT INTO 'recording' VALUES (5277, NULL, '2012-01-20 12:55:31.709879+00', 'Cadgers in the Canongate', 3045, 1, 8, 48, 9999, NULL, 412, 0, '');
INSERT INTO 'recording' VALUES (5278, NULL, '2012-01-20 12:55:31.716165+00', 'Achnacarry House', 3045, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5279, NULL, '2012-01-20 12:55:31.722443+00', 'Partans in his Creel', 3045, 3, 4, 32, 9999, NULL, 248, 0, '');
INSERT INTO 'recording' VALUES (5275, NULL, '2022-12-12 22:47:58.519666+00', 'Johnnie Cope', 3032, 2, 3, 32, 9999, NULL, 107, 0, '');
INSERT INTO 'recording' VALUES (5280, NULL, '2012-01-20 12:55:31.728865+00', 'Whistling Wind, The', 3045, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5281, NULL, '2012-01-20 12:55:31.735147+00', 'Jubilee Jig', 3045, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (5282, NULL, '2012-01-20 12:55:31.741433+00', 'Royal Deeside', 3045, 3, 4, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (5283, NULL, '2012-01-20 12:55:31.747718+00', 'Double Top Jig, The', 3045, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5284, NULL, '2012-01-20 12:55:31.75408+00', 'Hamilton Rant, The', 3045, 1, 8, 48, 9999, NULL, 419, 0, '');
INSERT INTO 'recording' VALUES (5235, NULL, '2021-08-20 12:31:33.657493+00', 'Selection of Strathspeys', 3067, 3, 8, 32, 9999, NULL, 497, 0, '');
INSERT INTO 'recording' VALUES (5285, NULL, '2012-01-20 12:55:31.760364+00', 'Airie Bennan', 3045, 2, 5, 32, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (5286, NULL, '2012-01-20 12:55:31.766869+00', 'Up in the Air', 3045, 3, 8, 32, 9999, NULL, 486, 0, '');
INSERT INTO 'recording' VALUES (5287, NULL, '2012-01-20 12:55:31.773124+00', 'Moulin Rouge, Le', 3045, 1, 0, 64, 9999, NULL, 78, 0, '');
INSERT INTO 'recording' VALUES (5288, NULL, '2012-01-20 12:55:31.77941+00', 'Moulin Rouge, Le', 3045, 1, 0, 64, 9999, NULL, 78, 0, '');
INSERT INTO 'recording' VALUES (5289, NULL, '2012-01-20 12:55:31.785677+00', 'Langholm Fair', 3045, 3, 3, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (5290, NULL, '2012-01-20 12:55:31.791915+00', 'Trip to Windsor', 3045, 1, 4, 48, 9999, NULL, 222, 1, '');
INSERT INTO 'recording' VALUES (5291, NULL, '2012-01-20 12:55:31.798184+00', 'Miss Hadden''s Reel', 3045, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (5292, NULL, '2012-01-20 12:55:31.804424+00', 'Andrew Carnegie', 3038, 3, 8, 32, 9999, NULL, 482, 0, '');
INSERT INTO 'recording' VALUES (5293, NULL, '2012-01-20 12:55:31.810752+00', 'Scots Brigade, The', 9998, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (5294, NULL, '2012-01-20 12:55:31.81734+00', 'Pauline Cathcart''s Strathspey', 9998, 3, 8, 32, 9999, NULL, 548, 0, '');
INSERT INTO 'recording' VALUES (5295, NULL, '2012-01-20 12:55:31.823602+00', 'Wonderful TIme in the Warenar', 9998, 1, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (5296, NULL, '2012-01-20 12:55:31.829849+00', 'Miss Cynthia Mackay', 9998, 2, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (5297, NULL, '2012-01-20 12:55:31.836156+00', 'Reel of the Gordon Highlanders, The', 3038, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (5298, NULL, '2012-01-20 12:55:31.842404+00', 'Tom and Anja''s Silver Wedding', 9998, 3, 8, 40, 9999, NULL, 608, 0, '');
INSERT INTO 'recording' VALUES (5299, NULL, '2012-01-20 12:55:31.848626+00', 'Life begins at Fifty', 9998, 1, 4, 32, 9999, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (5300, NULL, '2012-01-20 12:55:31.854856+00', 'Jarig Jetje', 9998, 1, 4, 32, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (5301, NULL, '2012-01-20 12:55:31.86107+00', 'Aad''s Farewell to Delft', 9998, 1, 0, 64, 9999, NULL, 78, 0, '');
INSERT INTO 'recording' VALUES (5302, NULL, '2012-01-20 12:55:31.867463+00', 'Bell-Founders, The', 9998, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5303, NULL, '2012-01-20 12:55:31.873697+00', 'Caddam Wood', 2993, 1, 5, 32, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (5304, NULL, '2012-01-20 12:55:31.879931+00', 'Red Rose of Dunoon, The', 2993, 3, 4, 32, 9999, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (5305, NULL, '2012-01-20 12:55:31.886173+00', 'Whigmaleeries', 2993, 1, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (5306, NULL, '2012-01-20 12:55:31.892887+00', 'Dancing Master, The', 2993, 2, 0, 96, 9999, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (5307, NULL, '2012-01-20 12:55:31.899136+00', 'Blue Mess Jacket', 2993, 3, 4, 32, 9999, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (5308, NULL, '2012-01-20 12:55:31.905359+00', 'Nottingham Lace', 2993, 1, 4, 24, 9999, NULL, 106, 0, '');
INSERT INTO 'recording' VALUES (5309, NULL, '2012-01-20 12:55:31.911614+00', 'Scotch Mist', 2993, 3, 5, 32, 9999, NULL, 309, 0, '');
INSERT INTO 'recording' VALUES (5310, NULL, '2012-01-20 12:55:31.917847+00', 'Tattie Bogle, The', 2993, 2, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (5311, NULL, '2012-01-20 12:55:31.924072+00', 'Duchess Tree, The', 2993, 3, 8, 32, 9999, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (5312, NULL, '2012-01-20 12:55:31.930317+00', 'Earl and Countess of Wessex, The', 2993, 1, 8, 40, 9999, NULL, 338, 0, '');
INSERT INTO 'recording' VALUES (5313, NULL, '2012-01-20 12:55:31.936533+00', 'Hot Toddy, A', 2993, 2, 8, 32, 9999, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (5314, NULL, '2012-01-20 12:55:31.942789+00', 'Singing Sands', 2993, 3, 3, 32, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (5315, NULL, '2012-01-20 12:55:31.949017+00', 'Lochnagar', 2993, 1, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (5316, NULL, '2012-01-20 12:55:31.955264+00', 'Hunting Horn, The', 2993, 2, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (5317, NULL, '2012-01-20 12:55:31.961506+00', 'Plantation Reel', 2993, 1, 5, 32, 9999, NULL, 159, 0, '');
INSERT INTO 'recording' VALUES (5319, NULL, '2012-01-20 12:55:31.97397+00', 'Angel''s Flight', 3002, 2, 5, 48, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (5321, NULL, '2012-01-20 12:55:31.986441+00', 'Chrissiejean', 3002, 2, 4, 40, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (5322, NULL, '2012-01-20 12:55:31.992869+00', 'Pasadena Prom, The', 3002, 3, 4, 32, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (5323, NULL, '2012-01-20 12:55:31.999173+00', 'Corsair Field', 3002, 1, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (5324, NULL, '2012-01-20 12:55:32.00539+00', 'Over the Garden Wall', 3002, 1, 4, 48, 9999, NULL, 229, 0, '');
INSERT INTO 'recording' VALUES (5325, NULL, '2012-01-20 12:55:32.011629+00', 'Double Sixsome, The', 3002, 1, 3, 64, 9999, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (5326, NULL, '2012-01-20 12:55:32.017857+00', 'Circassian Quadrille', 3002, 1, 3, 64, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (5327, NULL, '2012-01-20 12:55:32.02408+00', 'Mary Stewart Strathspey', 3002, 3, 4, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (5328, NULL, '2012-01-20 12:55:32.030332+00', 'Lord MacDonald''s Quadrille', 3002, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (5329, NULL, '2012-01-20 12:55:32.036579+00', 'Gift for Mamie, A', 3002, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5330, NULL, '2012-01-20 12:55:32.042838+00', 'Geneva Makes Three', 3002, 3, 8, 32, 9999, NULL, 516, 0, '');
INSERT INTO 'recording' VALUES (5333, NULL, '2012-01-20 12:55:32.069055+00', 'Buchan Tensome Reel, The', 3002, 1, 4, 40, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (5334, NULL, '2012-01-20 12:55:32.075444+00', 'De''il Amang the Sailors', 3002, 4, 3, 96, 56, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (5335, NULL, '2012-01-20 12:55:32.082+00', 'March Hare, The', 3092, 1, 6, 32, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (5336, NULL, '2012-01-20 12:55:32.089036+00', 'EH3 7AF', 3092, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5337, NULL, '2012-01-20 12:55:32.09538+00', 'Bill Little''s Strathspey', 3092, 3, 8, 32, 9999, NULL, 526, 0, '');
INSERT INTO 'recording' VALUES (5338, NULL, '2012-01-20 12:55:32.101972+00', 'Whigmaleeries', 3092, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5339, NULL, '2012-01-20 12:55:32.108341+00', 'Scallywag, The', 3092, 2, 8, 40, 9999, NULL, 359, 0, '');
INSERT INTO 'recording' VALUES (5340, NULL, '2012-01-20 12:55:32.114628+00', 'Highlandman''s Umbrella, The', 3092, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (5342, NULL, '2012-01-20 12:55:32.127118+00', 'Peat Fire Flame', 3092, 1, 8, 40, 9999, NULL, 349, 0, '');
INSERT INTO 'recording' VALUES (5343, NULL, '2012-01-20 12:55:32.133645+00', 'Wha''s at the Window', 3092, 2, 5, 40, 9999, NULL, 222, 0, '');
INSERT INTO 'recording' VALUES (5344, NULL, '2012-01-20 12:55:32.140028+00', 'Drumelzier', 3092, 3, 4, 32, 9999, NULL, 253, 0, '');
INSERT INTO 'recording' VALUES (5345, NULL, '2012-01-20 12:55:32.146293+00', 'Reel of the 51st Division, The', 3092, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5346, NULL, '2012-01-20 12:55:32.152882+00', 'Hibiscus Waltz, The', 3092, 5, 8, 32, 9999, NULL, 321, 0, '');
INSERT INTO 'recording' VALUES (5347, NULL, '2012-01-20 12:55:32.159214+00', 'Trip to Glasgow, A', 3137, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (5348, NULL, '2012-01-20 12:55:32.165456+00', 'Earl of Mansfield, The', 3137, 1, 4, 48, 9999, NULL, 224, 0, '');
INSERT INTO 'recording' VALUES (5349, NULL, '2012-01-20 12:55:32.171853+00', 'Frost and Snow', 3137, 3, 8, 32, 9999, NULL, 525, 0, '');
INSERT INTO 'recording' VALUES (5350, NULL, '2012-01-20 12:55:32.178151+00', 'Ratcatcher''s Reel, The', 3139, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5351, NULL, '2012-01-20 12:55:32.184403+00', 'Sarah Elizabeth''s Jig', 3139, 2, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (5352, NULL, '2012-01-20 12:55:32.190921+00', 'Scholars Strathspey, The', 3139, 3, 8, 32, 9999, NULL, 517, 0, '');
INSERT INTO 'recording' VALUES (5353, NULL, '2012-01-20 12:55:32.197918+00', 'Alex T. Queen', 3139, 1, 4, 48, 9999, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (5356, NULL, '2012-01-20 12:55:32.217485+00', 'Bridgwater Geordie, The', 3139, 1, 4, 32, 9999, NULL, 153, 1, '');
INSERT INTO 'recording' VALUES (5357, NULL, '2012-01-20 12:55:32.22402+00', 'W. James', 3139, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5358, NULL, '2012-01-20 12:55:32.230311+00', 'Shooglie, The', 3139, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (5359, NULL, '2012-01-20 12:55:32.236647+00', 'Carleton Strathspey, The', 3139, 3, 8, 32, 9999, NULL, 507, 0, '');
INSERT INTO 'recording' VALUES (5360, NULL, '2012-01-20 12:55:32.24401+00', 'Agitator, The', 3139, 2, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (5361, NULL, '2012-01-20 12:55:32.250273+00', 'Mrs Minto', 3139, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (5341, NULL, '2012-08-30 05:31:01.959044+00', 'Royal Wedding', 3092, 3, 8, 32, 9999, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (5362, NULL, '2012-01-20 12:55:32.256616+00', 'Ali''s Jig', 3139, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5363, NULL, '2012-01-20 12:55:32.264368+00', 'Somerled Square', 3023, 2, 4, 64, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (5364, NULL, '2012-01-20 12:55:32.271227+00', 'Breakish Postie, The', 3023, 3, 4, 32, 9999, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (5268, NULL, '2022-08-29 04:11:46.035275+00', 'Perth Medley', 3032, 4, 4, 64, 22, NULL, 384, 0, '');
INSERT INTO 'recording' VALUES (5354, NULL, '2023-02-16 13:20:18.306187+00', 'Merlin''s Thorn', 3139, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5365, NULL, '2012-01-20 12:55:32.277522+00', 'Lochalsh Reel, The', 3023, 1, 8, 40, 9999, NULL, 355, 0, '');
INSERT INTO 'recording' VALUES (5366, NULL, '2012-01-20 12:55:32.283775+00', 'Beekeeper''s Medley, The', 3023, 4, 2, 64, 17, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (5367, NULL, '2012-01-20 12:55:32.290139+00', 'Mrs Helen Baillie', 3023, 3, 8, 32, 9999, NULL, 493, 0, '');
INSERT INTO 'recording' VALUES (5368, NULL, '2012-01-20 12:55:32.296492+00', 'Pensioner''s Reel, The', 3023, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5369, NULL, '2012-01-20 12:55:32.302954+00', 'Waternish Tangle, The', 3023, 2, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5370, NULL, '2012-01-20 12:55:32.309207+00', 'Eilean Ban', 3023, 3, 4, 32, 9999, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (5371, NULL, '2012-01-20 12:55:32.315579+00', 'Sarah''s Favourite', 3050, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5372, NULL, '2012-01-20 12:55:32.321923+00', 'Welcome to Callum', 3050, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (5373, NULL, '2012-01-20 12:55:32.328162+00', 'Falkirk Bairn, The', 3050, 3, 4, 32, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (5374, NULL, '2012-01-20 12:55:32.334601+00', 'Falkirk Millennium Wheel, The', 3050, 1, 0, 96, 9999, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (5375, NULL, '2012-01-20 12:55:32.340858+00', 'Old Spedling Castle''s Ghost''s Dance', 3050, 2, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (5377, NULL, '2012-01-20 12:55:32.353377+00', 'Wellington Connection, The', 3050, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5378, NULL, '2012-01-20 12:55:32.359739+00', 'Miss Frances Martin Medley', 3050, 4, 2, 64, 5, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (5380, NULL, '2012-01-20 12:55:32.372433+00', 'Crieff Hydro, The', 3050, 2, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (5381, NULL, '2012-01-20 12:55:32.378828+00', 'Tribute to Patsy Rennie, A', 3050, 4, 0, 128, 2, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (5382, NULL, '2012-01-20 12:55:32.385075+00', 'Holywood Romance, The', 3050, 3, 4, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (5383, NULL, '2012-01-20 12:55:32.391329+00', 'Luckenbooth Brooch', 3050, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (5384, NULL, '2012-01-20 12:55:32.397954+00', 'Irene Mclean of Duns', 3050, 1, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (5386, NULL, '2012-01-20 12:55:32.410477+00', 'Jubilee Quadrille, The', 3050, 1, 2, 88, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (5379, NULL, '2019-06-28 08:37:33.074596+00', 'Civil Engineer, The', 3050, 1, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (5376, NULL, '2019-08-09 14:46:37.112971+00', 'Charlie''s Silver Jubilee', 3050, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5387, NULL, '2012-01-20 12:55:32.416904+00', 'Chas Reel, The', 3050, 1, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (5388, NULL, '2012-01-20 12:55:32.423152+00', 'Leandor''s Jig', 3137, 2, 4, 64, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5389, NULL, '2012-01-20 12:55:32.429387+00', 'Frae A'' the Airts', 3137, 4, 8, 32, 1, NULL, 407, 0, '');
INSERT INTO 'recording' VALUES (5390, NULL, '2012-01-20 12:55:32.435767+00', 'Miss Allie Anderson', 3137, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5391, NULL, '2012-01-20 12:55:32.442221+00', 'Sauchie Haugh, The', 3137, 3, 8, 32, 9999, NULL, 531, 0, '');
INSERT INTO 'recording' VALUES (5392, NULL, '2012-01-20 12:55:32.44846+00', 'Reel of the Royal Scots, The', 3137, 1, 8, 32, 9999, NULL, 300, 0, '');
INSERT INTO 'recording' VALUES (5393, NULL, '2012-01-20 12:55:32.454827+00', 'Miss Gibson''s Strathspey', 3137, 3, 8, 32, 9999, NULL, 527, 0, '');
INSERT INTO 'recording' VALUES (5395, NULL, '2012-01-20 12:55:32.468007+00', 'Grand March', 3008, 11, 4, 32, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (5396, NULL, '2012-01-20 12:55:32.474316+00', 'Eightsome Reel, The', 3008, 1, 0, 464, 9999, NULL, 477, 0, '');
INSERT INTO 'recording' VALUES (5397, NULL, '2012-01-20 12:55:32.480664+00', 'Scottish Reform', 3008, 2, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (5398, NULL, '2012-01-20 12:55:32.486946+00', 'Waltz Country Dance', 3008, 5, 4, 40, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (5399, NULL, '2012-01-20 12:55:32.493366+00', 'Circassian Circle', 3008, 1, 5, 32, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (5400, NULL, '2012-01-20 12:55:32.499763+00', 'Hamilton House', 3008, 2, 8, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (5401, NULL, '2012-01-20 12:55:32.506017+00', 'Glasgow Highlanders', 3008, 3, 8, 32, 9999, NULL, 500, 1, '');
INSERT INTO 'recording' VALUES (5402, NULL, '2012-01-20 12:55:32.512251+00', 'Dashing White Sergeant', 3008, 1, 6, 32, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (5403, NULL, '2012-01-20 12:55:32.518647+00', 'Gay Gordons', 3008, 11, 12, 16, 9999, NULL, 225, 0, '');
INSERT INTO 'recording' VALUES (5404, NULL, '2012-01-20 12:55:32.525267+00', 'Strip The Willow', 3008, 2, 4, 64, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5405, NULL, '2012-01-20 12:55:32.531567+00', 'Petronella', 3008, 1, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (5406, NULL, '2012-01-20 12:55:32.537977+00', 'Lamb Skinnet', 3008, 2, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (5407, NULL, '2012-01-20 12:55:32.544275+00', 'Duke and Duchess of Edinburgh', 3008, 1, 8, 40, 9999, NULL, 334, 0, '');
INSERT INTO 'recording' VALUES (5409, NULL, '2012-01-20 12:55:32.556999+00', 'Gay Gordons', 3050, 11, 6, 16, 9999, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (5410, NULL, '2012-01-20 12:55:32.563764+00', 'Circassian Circle', 3050, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (5411, NULL, '2012-01-20 12:55:32.570018+00', 'Saint Bernard''s Waltz', 3050, 5, 8, 16, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (5412, NULL, '2012-01-20 12:55:32.57625+00', 'Britannia Two-Step', 3050, 11, 8, 16, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (5413, NULL, '2012-01-20 12:55:32.582654+00', 'Dashing White Sergeant', 3050, 1, 5, 32, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (5414, NULL, '2012-01-20 12:55:32.588898+00', 'Pride of Erin Waltz', 3050, 5, 5, 32, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (5415, NULL, '2012-01-20 12:55:32.595152+00', 'Virginia Reel, The', 3050, 50, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (5416, NULL, '2012-01-20 12:55:32.601523+00', 'Riverside, The', 3050, 2, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (5417, NULL, '2012-01-20 12:55:32.607775+00', 'Canadian Barn Dance', 3050, 11, 16, 16, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (5418, NULL, '2012-01-20 12:55:32.614037+00', 'Lomond Waltz', 3050, 5, 9, 16, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (5419, NULL, '2012-01-20 12:55:32.620357+00', 'Flying Scotsman, The', 3050, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (5420, NULL, '2012-01-20 12:55:32.62677+00', 'Bridge of Athlone, The', 3050, 2, 5, 48, 9999, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (5422, NULL, '2012-01-20 12:55:32.638544+00', 'Swedish Masquerade, The', 3050, 4, 2, 48, 33, NULL, 116, 0, '');
INSERT INTO 'recording' VALUES (5423, NULL, '2012-01-20 12:55:32.643389+00', 'Friendship Waltz', 3050, 5, 7, 16, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (5424, NULL, '2012-01-20 12:55:32.648208+00', 'Call of the Pipes, The', 3050, 11, 8, 16, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (5426, NULL, '2012-01-20 12:55:32.657778+00', 'Sons of the Rock', 3050, 1, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (5427, NULL, '2012-01-20 12:55:32.662691+00', 'Eva Three Step', 3050, 11, 8, 16, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (5428, NULL, '2012-01-20 12:55:32.667651+00', 'Orcadian Strip the Willow', 3050, 2, 8, 16, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (5429, NULL, '2012-01-20 12:55:32.672505+00', 'Blackadder Jig, The', 1502, 2, 8, 32, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (5430, NULL, '2012-01-20 12:55:32.677323+00', 'Blackadder House', 1502, 3, 8, 32, 9999, NULL, 542, 0, '');
INSERT INTO 'recording' VALUES (5431, NULL, '2012-01-20 12:55:32.68231+00', 'Hastings Welcome, A', 1502, 1, 4, 32, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (5432, NULL, '2012-01-20 12:55:32.687248+00', 'Ewan Telford''s Strathspey', 1502, 3, 4, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (5433, NULL, '2012-01-20 12:55:32.692038+00', 'Celebration Jig', 1502, 2, 4, 32, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (5434, NULL, '2012-01-20 12:55:32.696828+00', 'Carol Palmer''s Strathspey', 1502, 3, 8, 32, 9999, NULL, 545, 0, '');
INSERT INTO 'recording' VALUES (5435, NULL, '2012-01-20 12:55:32.701617+00', 'Hawkesbury Rant, The', 1502, 1, 4, 32, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (5436, NULL, '2012-01-20 12:55:32.706475+00', 'Bonnie Gallowa''', 1502, 3, 4, 40, 9999, NULL, 353, 0, '');
INSERT INTO 'recording' VALUES (5437, NULL, '2012-01-20 12:55:32.711261+00', 'Lassie Frae Glasgow, The', 1502, 2, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (5439, NULL, '2012-01-20 12:55:32.720855+00', 'Craven Jig, The', 1502, 2, 4, 32, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (5440, NULL, '2012-01-20 12:55:32.725748+00', 'West Highland Line, The', 1502, 1, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (5443, NULL, '2012-01-20 12:55:32.740122+00', 'Trip Around the World', 1502, 2, 4, 32, 9999, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (5444, NULL, '2012-01-20 12:55:32.744918+00', 'Nothing in Common', 1502, 3, 6, 32, 9999, NULL, 413, 0, '');
INSERT INTO 'recording' VALUES (5445, NULL, '2012-01-20 12:55:32.749844+00', 'Irene McLean of Duns', 1502, 1, 4, 32, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (5446, NULL, '2012-01-20 12:55:32.754631+00', 'Falkirk Lass, The', 1502, 3, 8, 32, 9999, NULL, 539, 0, '');
INSERT INTO 'recording' VALUES (5447, NULL, '2012-01-20 12:55:32.759422+00', 'See You Down Under', 1502, 2, 4, 32, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (5449, NULL, '2012-01-20 12:55:32.769144+00', 'Ruby Hornpipe, The', 1502, 1, 3, 32, 9999, NULL, 118, 0, '');
INSERT INTO 'recording' VALUES (5453, NULL, '2012-01-20 12:55:32.78846+00', 'Machine Without Horses, The', 3185, 2, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (5454, NULL, '2012-01-20 12:55:32.793255+00', 'Dashing White Sergeant, The', 3185, 1, 7, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5455, NULL, '2012-01-20 12:55:32.798046+00', 'Saint Bernard''s Waltz', 3185, 5, 0, 16, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (5456, NULL, '2012-01-20 12:55:32.802831+00', 'Montgomeries'' Rant, The', 3185, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5457, NULL, '2012-01-20 12:55:32.807627+00', 'Boston Two Step', 3185, 50, 0, 16, 9999, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (5385, NULL, '2021-03-10 18:43:41.671203+00', 'Mrs May Anderson''s Strathspey', 3050, 3, 3, 32, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (5442, NULL, '2021-10-02 14:41:45.574753+00', 'Highland Welcome in Switzerland, A', 1502, 3, 1, 64, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (5450, NULL, '2021-10-02 14:42:17.35091+00', 'Scottish Castle, The', 1502, 3, 1, 64, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (5452, NULL, '2021-10-14 09:19:34.374726+00', 'Par for the Course', 1502, 1, 8, 32, 9999, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (5458, NULL, '2012-01-20 12:55:32.812408+00', 'Flowers of Edinburgh, The', 3185, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5459, NULL, '2012-01-20 12:55:32.817192+00', 'Mairi''s Wedding', 3185, 1, 8, 40, 9999, NULL, 345, 0, '');
INSERT INTO 'recording' VALUES (5460, NULL, '2012-01-20 12:55:32.821974+00', 'Scottish Waltz', 3185, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5461, NULL, '2012-01-20 12:55:32.826752+00', 'Scottish Reform', 3185, 2, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (5462, NULL, '2012-01-20 12:55:32.831596+00', 'Bluebell Polka', 3185, 50, 0, 16, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (5463, NULL, '2012-01-20 12:55:32.836402+00', 'Neidpath Castle', 3185, 3, 3, 32, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (5464, NULL, '2012-01-20 12:55:32.841181+00', 'Jacqueline Waltz, The', 3185, 5, 0, 0, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (5467, NULL, '2012-01-20 12:55:32.85558+00', 'Corrievreckan', 3217, 4, 0, 128, 2, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (5469, NULL, '2012-01-20 12:55:32.865133+00', 'Neko''s Reel', 3217, 1, 4, 32, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (5470, NULL, '2012-01-20 12:55:32.870082+00', 'Maggie Lauder', 3217, 3, 8, 32, 9999, NULL, 521, 0, '');
INSERT INTO 'recording' VALUES (5421, NULL, '2019-06-28 12:37:44.466143+00', 'Robin''s Easy Circle', 3050, 1, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (5448, NULL, '2016-12-27 11:00:45.578861+00', 'Rocking Horse, The', 1502, 4, 2, 96, 54, NULL, 315, 0, '');
INSERT INTO 'recording' VALUES (5425, NULL, '2017-06-17 10:48:53.828419+00', 'Southern Rose Waltz, The', 3050, 5, 5, 32, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (5394, NULL, '2019-09-23 20:28:45.888665+00', 'Tribute to the Borders', 3137, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5471, NULL, '2012-01-20 12:55:32.87491+00', 'Good Friends', 3217, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (5472, NULL, '2012-01-20 12:55:32.879731+00', 'Kirkmaiden Strathspey', 3217, 3, 0, 80, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (5473, NULL, '2012-01-20 12:55:32.884506+00', 'Falls of Rogie, The', 3217, 1, 8, 32, 9999, NULL, 299, 0, '');
INSERT INTO 'recording' VALUES (5474, NULL, '2012-01-20 12:55:32.889302+00', 'Wedding Link, The', 3217, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (5475, NULL, '2012-01-20 12:55:32.89453+00', 'Starry Eyed Lassie, The', 2696, 2, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (5476, NULL, '2012-01-20 12:55:32.899412+00', 'Swiss Lassie', 2696, 1, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (5479, NULL, '2012-01-20 12:55:32.913891+00', 'Waltzes', 2696, 5, 0, 0, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (5483, NULL, '2012-01-20 12:55:32.933439+00', 'Plantation Reel, The', 2696, 1, 5, 32, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (5484, NULL, '2012-01-20 12:55:32.938235+00', 'Slow Air', 2696, 98, 0, 0, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (5487, NULL, '2012-01-20 12:55:32.952766+00', 'Clansman, The', 2696, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (5489, NULL, '2012-01-20 12:55:32.962347+00', 'General Stuart''s Reel', 2696, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5491, NULL, '2014-08-23 16:34:02.606327+00', 'Cadgers in the Cannongate', 3023, 1, 8, 48, 9999, NULL, 426, 0, '(Title of the recording as given on the CD.)');
INSERT INTO 'recording' VALUES (5493, NULL, '2012-01-20 12:55:32.981513+00', 'Welcome to Dufftown', 3023, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5494, NULL, '2012-01-20 12:55:32.986481+00', 'Inverneill House', 3023, 1, 8, 32, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (5495, NULL, '2012-01-20 12:55:32.991375+00', 'Culla Bay', 3023, 3, 4, 32, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (5496, NULL, '2012-01-20 12:55:32.996177+00', 'Recumbent Stone, The', 3023, 1, 5, 48, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (10163, '2018-03-29 19:05:02.960297+00', '2018-04-03 10:50:42.811989+00', 'Clumsy Lover', 11613, 1, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (5499, NULL, '2012-01-20 12:55:33.010507+00', 'Irish Rover, The', 3023, 1, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (5500, NULL, '2012-01-20 12:55:33.015325+00', 'EH3 7AF', 3023, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (5502, NULL, '2012-01-20 12:55:33.080089+00', 'Reel of the Gordon Highlanders', 3023, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (5503, NULL, '2012-01-20 12:55:33.084898+00', 'Pelorous Jack', 3023, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5504, NULL, '2012-01-20 12:55:33.089684+00', 'Portnacraig', 3008, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5505, NULL, '2012-01-20 12:55:33.094469+00', 'Road to Mallaig, The', 3008, 3, 4, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (5507, NULL, '2012-01-20 12:55:33.104295+00', 'Gang the Same Gate', 3008, 3, 8, 32, 9999, NULL, 527, 0, '');
INSERT INTO 'recording' VALUES (5508, NULL, '2012-01-20 12:55:33.109076+00', 'Whistling Wind, The', 3008, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5509, NULL, '2012-01-20 12:55:33.113861+00', 'Argyll Ludging, The', 3008, 3, 8, 32, 9999, NULL, 509, 0, '');
INSERT INTO 'recording' VALUES (5510, NULL, '2012-01-20 12:55:33.118663+00', 'Anniversary Reel, The', 3008, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (5511, NULL, '2012-01-20 12:55:33.123451+00', 'Gilly Flower, The', 3008, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (5512, NULL, '2012-01-20 12:55:33.128241+00', 'Reverend John MacFarlane, The', 3008, 1, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (5513, NULL, '2012-01-20 12:55:33.133017+00', 'Moment of Truth', 3008, 3, 8, 32, 9999, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (5514, NULL, '2012-01-20 12:55:33.137829+00', 'Gothenburg''s Welcome', 3008, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (5515, NULL, '2012-01-20 12:55:33.142618+00', 'Wisp of Thistle', 3008, 3, 8, 32, 9999, NULL, 509, 0, '');
INSERT INTO 'recording' VALUES (5516, NULL, '2012-01-20 12:55:33.147415+00', 'Saint Andrew''s of Brampton', 3008, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (5517, NULL, '2012-01-20 12:55:33.152241+00', 'Bonnie Ina Campbell', 3008, 3, 8, 32, 9999, NULL, 516, 0, '');
INSERT INTO 'recording' VALUES (5518, NULL, '2012-01-20 12:55:33.157028+00', 'Nurseryman, The', 3008, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5519, NULL, '2012-01-20 12:55:33.161923+00', 'Queen City Salute, The', 3008, 4, 4, 64, 5, NULL, 403, 0, '');
INSERT INTO 'recording' VALUES (5520, NULL, '2012-01-20 12:55:33.166706+00', 'Antarctica Bound', 3011, 2, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (5522, NULL, '2012-01-20 12:55:33.176253+00', 'Ice Cap, The', 3011, 3, 3, 32, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (5523, NULL, '2012-01-20 12:55:33.181046+00', 'Coats Land', 3011, 2, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5524, NULL, '2012-01-20 12:55:33.186241+00', 'Bruce''s Men', 3011, 3, 3, 32, 9999, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (5525, NULL, '2012-01-20 12:55:33.19107+00', 'Piper and the Penguin, The', 3011, 1, 0, 88, 9999, NULL, 101, 0, '');
INSERT INTO 'recording' VALUES (5526, NULL, '2012-01-20 12:55:33.195865+00', 'Speirs Bruce - The Pole Star', 3011, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (5527, NULL, '2012-01-20 12:55:33.200686+00', 'March & Reel Medley', 3320, 98, 0, 0, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (5528, NULL, '2012-01-20 12:55:33.205466+00', '3/4 Retreat Marches', 3320, 11, 0, 0, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (5529, NULL, '2012-01-20 12:55:33.210263+00', 'South', 3321, 98, 0, 0, 9999, NULL, 1442, 0, '');
INSERT INTO 'recording' VALUES (5530, NULL, '2012-01-20 12:55:33.21504+00', 'Pelorus Jack', 3032, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5531, NULL, '2012-01-20 12:55:33.219826+00', 'Saint Columba''s Strathspey', 3032, 3, 5, 32, 9999, NULL, 309, 0, '');
INSERT INTO 'recording' VALUES (5532, NULL, '2012-01-20 12:55:33.224607+00', 'Weary Willie''s Reel', 3032, 1, 4, 32, 9999, NULL, 149, 1, '');
INSERT INTO 'recording' VALUES (5533, NULL, '2012-01-20 12:55:33.22939+00', 'Argyll''s Fancy', 3032, 2, 4, 48, 9999, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (5534, NULL, '2012-01-20 12:55:33.234173+00', 'Road to Forfar', 3032, 3, 8, 32, 9999, NULL, 490, 0, '');
INSERT INTO 'recording' VALUES (5535, NULL, '2012-01-20 12:55:33.239034+00', 'Sailor, The', 3032, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (5536, NULL, '2012-01-20 12:55:33.243815+00', 'Watson''s Reel', 3032, 2, 8, 24, 9999, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (5537, NULL, '2012-01-20 12:55:33.248634+00', 'Lady Sophia Anne of Bute', 3032, 1, 4, 48, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (5538, NULL, '2012-01-20 12:55:33.25342+00', 'Drumelzier', 3032, 3, 4, 32, 9999, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (5539, NULL, '2012-01-20 12:55:33.258277+00', 'Anne Fraser MacKenzie', 3032, 2, 8, 40, 9999, NULL, 340, 0, '');
INSERT INTO 'recording' VALUES (5540, NULL, '2012-01-20 12:55:33.263119+00', 'Kiss Me Quick, My Mither''s Coming', 3032, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5541, NULL, '2012-01-20 12:55:33.268001+00', 'Moray Rant, The', 3032, 3, 3, 48, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5488, NULL, '2019-11-25 00:40:57.007474+00', '6 x 32 Jigs', 2696, 2, 6, 32, 9999, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (5468, NULL, '2022-10-16 21:56:33.970564+00', 'Haddington Assembly', 3217, 2, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (5506, NULL, '2022-12-23 23:35:00.45672+00', 'Quarries'' Jig', 3008, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (5490, NULL, '2023-01-12 22:31:08.832229+00', 'Listening medley', 2696, 98, 0, 0, 9999, NULL, 323, 0, '');
INSERT INTO 'recording' VALUES (5466, NULL, '2023-02-06 16:17:55.519153+00', 'Woodland Assembly', 3217, 2, 2, 64, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (5521, NULL, '2020-01-24 21:26:12.962394+00', 'Scotia Sea', 3011, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5465, NULL, '2020-06-05 18:01:37.688568+00', 'Mid Fodderletter', 3217, 3, 4, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (5501, NULL, '2021-06-17 01:02:20.193616+00', 'Lady Peak''s Strathspey', 3023, 3, 8, 32, 9999, NULL, 497, 0, '');
INSERT INTO 'recording' VALUES (5542, NULL, '2012-01-20 12:55:33.272778+00', 'Farewell to Crumlin', 3032, 2, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (5543, NULL, '2012-01-20 12:55:33.277866+00', 'Earlstoun Loch', 3032, 1, 5, 32, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (5544, NULL, '2012-01-20 12:55:33.282712+00', 'Highland Barn Dance, The', 2328, 99, 0, 0, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (5545, NULL, '2012-01-20 12:55:33.287534+00', 'Irish Jigs', 2328, 2, 0, 0, 9999, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (5546, NULL, '2012-01-20 12:55:33.292945+00', 'Gaelic Waltz', 2328, 5, 0, 0, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (5547, NULL, '2012-01-20 12:55:33.299357+00', 'Gatherings, The', 2328, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5548, NULL, '2012-01-20 12:55:33.305733+00', 'Duke and Duchess of Edinburgh, The', 2328, 1, 4, 40, 9999, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (5549, NULL, '2012-01-20 12:55:33.311983+00', 'Eva Three Step', 2328, 11, 0, 16, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (5550, NULL, '2012-01-20 12:55:33.318268+00', 'Highland Waltz', 2328, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5551, NULL, '2012-01-20 12:55:33.324687+00', 'Marches in 2/4', 2328, 11, 0, 0, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (5552, NULL, '2012-01-20 12:55:33.330958+00', 'Isle of Skye, The', 2328, 1, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5482, NULL, '2019-06-24 22:27:54.920118+00', '3 x 32 Song Airs', 2696, 3, 3, 32, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (5553, NULL, '2012-01-20 12:55:33.337205+00', 'March Medley No 1', 2328, 11, 0, 0, 9999, NULL, 159, 0, '');
INSERT INTO 'recording' VALUES (5554, NULL, '2012-01-20 12:55:33.343601+00', 'Hebridean Waltz, The', 2328, 5, 0, 0, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (5555, NULL, '2012-01-20 12:55:33.34989+00', 'Prince Charles of Edinburgh', 2328, 1, 0, 160, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (5556, NULL, '2012-01-20 12:55:33.356133+00', 'After the Games', 2328, 98, 0, 0, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (5557, NULL, '2012-01-20 12:55:33.362497+00', '4 x 32 Strathspeys', 2885, 3, 4, 32, 9999, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (5558, NULL, '2012-01-20 12:55:33.368995+00', '8 x 32 Jigs', 2885, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5559, NULL, '2012-01-20 12:55:33.375255+00', '8 x 32 Strathspey Airs', 2885, 3, 8, 32, 9999, NULL, 497, 0, '');
INSERT INTO 'recording' VALUES (5561, NULL, '2012-01-20 12:55:33.38799+00', 'Outskirts, The', 2885, 5, 3, 32, 9999, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (5564, NULL, '2012-01-20 12:55:33.407149+00', '4 x 64 Jigs', 2885, 2, 4, 64, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (5565, NULL, '2012-01-20 12:55:33.413375+00', '8 x 32 Reels', 2885, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (5566, NULL, '2012-01-20 12:55:33.419637+00', 'Waiting for Jim', 2885, 5, 0, 0, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (5569, NULL, '2014-09-16 11:52:30.574295+00', 'Asilomar Romantic', 2162, 3, 8, 32, 9999, NULL, 523, 0, '');
INSERT INTO 'recording' VALUES (5570, NULL, '2014-09-16 11:53:04.462045+00', 'Duke of Atholl''s Reel, The', 2162, 2, 8, 32, 9999, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (5571, NULL, '2014-09-16 11:53:43.470243+00', 'Denise''s Waltz', 2162, 5, 5, 32, 9999, NULL, 233, 0, '');
INSERT INTO 'recording' VALUES (5572, NULL, '2014-09-16 11:54:15.605725+00', 'Royal Deeside Railway, The', 2162, 1, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (5573, NULL, '2014-09-16 11:54:38.870374+00', 'Set of Strathspeys', 2162, 3, 3, 32, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (5574, NULL, '2014-09-16 11:55:17.557945+00', 'Waverley', 2162, 2, 8, 48, 9999, NULL, 422, 0, '');
INSERT INTO 'recording' VALUES (5575, NULL, '2014-09-16 11:55:40.012904+00', 'Round Reel of Eight', 2162, 1, 0, 88, 9999, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (5581, NULL, '2012-01-20 12:55:33.51546+00', 'Wellington Street', 3006, 1, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5584, NULL, '2012-01-20 12:55:33.534412+00', 'Doris''s Delight', 3006, 3, 4, 32, 9999, NULL, 256, 1, '');
INSERT INTO 'recording' VALUES (5585, NULL, '2012-01-20 12:55:33.540648+00', 'Flight to Melbourne', 3006, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (5586, NULL, '2012-01-20 12:55:33.547083+00', 'Silver Threads', 3006, 3, 4, 40, 9999, NULL, 322, 0, '');
INSERT INTO 'recording' VALUES (10164, '2018-03-29 19:06:37.37009+00', '2018-04-03 10:50:59.928858+00', 'Kudzu Reel', 11613, 3, 5, 32, NULL, NULL, 314, 0, '');
INSERT INTO 'recording' VALUES (5587, NULL, '2019-08-09 14:48:10.046238+00', 'January Jig', 3006, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (5590, NULL, '2012-01-20 12:55:33.572394+00', 'Silver Targe, The', 3006, 3, 0, 80, 9999, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (5591, NULL, '2012-01-20 12:55:33.578661+00', 'Jaunty Jack', 3006, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5592, NULL, '2012-01-20 12:55:33.584915+00', 'Jovial Gentleman, The', 3006, 2, 5, 48, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5593, NULL, '2012-01-20 12:55:33.592656+00', 'Daunder in the Glen', 3006, 3, 4, 32, 9999, NULL, 254, 0, '');
INSERT INTO 'recording' VALUES (5594, NULL, '2012-01-20 12:55:33.597591+00', 'Heather Bank Jig, The', 3006, 2, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (5595, NULL, '2012-01-20 12:55:33.602418+00', 'Bonnie Buchanhaven', 3006, 3, 4, 32, 9999, NULL, 260, 1, '');
INSERT INTO 'recording' VALUES (5596, NULL, '2012-01-20 12:55:33.607251+00', 'Grace Hay''s Delight', 3372, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5597, NULL, '2012-01-20 12:55:33.612037+00', 'Sauchie Haugh', 3372, 3, 8, 32, 9999, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (5598, NULL, '2012-01-20 12:55:33.616828+00', 'Caberfei', 3372, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5599, NULL, '2012-01-20 12:55:33.621609+00', 'Athole Volunteers, The', 3372, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5600, NULL, '2012-01-20 12:55:33.626395+00', 'John McAlpin', 3372, 3, 8, 32, 9999, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (5601, NULL, '2012-01-20 12:55:33.631178+00', 'Marchioness of Cornwallis', 3372, 98, 0, 0, 9999, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (5602, NULL, '2012-01-20 12:55:33.635967+00', 'Left-Handed Fiddler, The', 3372, 1, 8, 32, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (5603, NULL, '2012-01-20 12:55:33.640736+00', 'Marquis of Huntly''s Farewell, The', 3372, 3, 8, 32, 9999, NULL, 523, 0, '');
INSERT INTO 'recording' VALUES (5604, NULL, '2012-01-20 12:55:33.645525+00', 'Niel Gow''s Lament for the Death of his Second Wife', 3372, 98, 0, 0, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (5605, NULL, '2012-01-20 12:55:33.650308+00', 'Reel of the 51st Division', 3372, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5606, NULL, '2012-01-20 12:55:33.655102+00', 'Blue Bonnets over the Border', 3372, 5, 0, 0, 9999, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (5607, NULL, '2012-01-20 12:55:33.659893+00', 'Nuptial Knot, The', 3372, 98, 0, 0, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (5608, NULL, '2012-01-20 12:55:33.664667+00', 'Emigrant''s Adieu, The', 3372, 98, 0, 0, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (5609, NULL, '2012-01-20 12:55:33.66944+00', 'Nice to See You', 3019, 1, 5, 32, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (5610, NULL, '2012-01-20 12:55:33.674448+00', 'Chequered Court, The', 3019, 2, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (5611, NULL, '2012-01-20 12:55:33.679266+00', 'S-Locomotion', 3019, 3, 4, 32, 9999, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (5612, NULL, '2012-01-20 12:55:33.684052+00', 'Beeswing', 3019, 1, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (5613, NULL, '2012-01-20 12:55:33.689097+00', 'Pelorus Jack', 3019, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (5614, NULL, '2012-01-20 12:55:33.694024+00', 'Anna Holden''s Strathspey', 3019, 3, 8, 32, 9999, NULL, 490, 0, '');
INSERT INTO 'recording' VALUES (5615, NULL, '2012-01-20 12:55:33.698832+00', 'Waltz Country Dance', 3019, 5, 4, 40, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (5616, NULL, '2012-01-20 12:55:33.703626+00', 'Ways in New Hall', 3019, 1, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (5619, NULL, '2012-01-20 12:55:33.718774+00', 'Highland Rambler, The', 3019, 1, 8, 40, 9999, 15, 339, 0, '');
INSERT INTO 'recording' VALUES (5620, NULL, '2012-01-20 12:55:33.72358+00', 'Byron Strathspey, The', 3019, 3, 3, 32, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (5621, NULL, '2012-01-20 12:55:33.72836+00', 'Mrs Stewart''s Jig', 3019, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (5623, NULL, '2012-01-20 12:55:33.738614+00', 'Fifty Years On', 3008, 2, 4, 40, 9999, 14, 183, 1, '');
INSERT INTO 'recording' VALUES (5624, NULL, '2012-01-20 12:55:33.744097+00', 'Fifty Years On', 3008, 2, 4, 40, 9999, 14, 179, 0, '');
INSERT INTO 'recording' VALUES (5627, NULL, '2012-01-20 12:55:33.759168+00', 'Queen''s Quadrille, The', 3008, 1, 0, 128, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (5628, NULL, '2012-01-20 12:55:33.763953+00', 'Queen''s Quadrille, The', 3008, 1, 0, 128, 9999, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (5630, NULL, '2012-01-20 12:55:33.773628+00', 'Strathmore', 3008, 3, 4, 40, 9999, NULL, 332, 0, '');
INSERT INTO 'recording' VALUES (5631, NULL, '2012-01-20 12:55:33.779097+00', 'Noah''s Ark', 3008, 2, 8, 32, 9999, 1, 269, 0, '');
INSERT INTO 'recording' VALUES (5632, NULL, '2012-01-20 12:55:33.784583+00', 'Bea''s Delight', 3008, 1, 8, 32, 9999, 1, 270, 0, '');
INSERT INTO 'recording' VALUES (5633, NULL, '2012-01-20 12:55:33.789398+00', 'Corian Strathspey, The', 3008, 3, 3, 32, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (5618, NULL, '2022-08-30 18:33:44.967871+00', 'Castle Douglas', 3019, 3, 8, 32, 9999, NULL, 491, 0, '');
INSERT INTO 'recording' VALUES (5560, NULL, '2022-08-31 10:50:23.606214+00', '8 x 40 Reels', 2885, 1, 8, 40, 9999, NULL, 357, 0, '');
INSERT INTO 'recording' VALUES (5562, NULL, '2022-09-01 10:41:18.281559+00', '8 x 32 Reels: Hornpipes', 2885, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5625, NULL, '2022-12-19 17:37:56.85036+00', 'Celebration Strathspey, The', 3008, 3, 8, 32, 9999, NULL, 522, 0, '');
INSERT INTO 'recording' VALUES (5634, NULL, '2012-01-20 12:55:33.794199+00', 'Corian Strathspey, The', 3008, 3, 3, 32, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (5635, NULL, '2012-01-20 12:55:33.799668+00', 'Castle in the Air, A', 3008, 1, 8, 32, 9999, 1, 272, 0, '');
INSERT INTO 'recording' VALUES (5636, NULL, '2012-01-20 12:55:33.804495+00', 'Argyll Square, The', 3008, 2, 0, 96, 9999, NULL, 106, 0, '');
INSERT INTO 'recording' VALUES (5637, NULL, '2012-01-20 12:55:33.809285+00', 'Argyll Square, The', 3008, 2, 0, 96, 9999, NULL, 106, 0, '');
INSERT INTO 'recording' VALUES (5638, NULL, '2012-01-20 12:55:33.814072+00', 'Deuks Dang Ow''re My Daddie, The', 2058, 2, 8, 40, 9999, NULL, 363, 0, '');
INSERT INTO 'recording' VALUES (5639, NULL, '2012-01-20 12:55:33.818866+00', 'Set of Strathspeys', 2058, 3, 4, 48, 9999, NULL, 352, 0, '');
INSERT INTO 'recording' VALUES (5641, NULL, '2012-01-20 12:55:33.828471+00', 'Set of Reels', 2058, 1, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (5642, NULL, '2012-01-20 12:55:33.83326+00', 'Bonnie Lass of Bon Accord', 2058, 3, 0, 64, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (5563, NULL, '2015-10-19 13:26:50.828155+00', '8 x 32 Strathspeys', 2885, 3, 8, 32, 9999, NULL, 513, 0, '');
INSERT INTO 'recording' VALUES (5567, NULL, '2016-09-04 13:56:13.46045+00', 'Hornpipes Suitable for Catch the Wind', 2162, 1, 8, 32, 9999, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (5626, NULL, '2016-09-04 15:29:37.733583+00', 'Royal Yacht Britannia, The', 3008, 1, 8, 40, 9999, 14, 343, 0, '');
INSERT INTO 'recording' VALUES (5629, NULL, '2019-10-25 09:54:12.06063+00', 'Strathmore', 3008, 3, 2, 40, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (5643, NULL, '2012-01-20 12:55:33.838061+00', 'Bonnie Anne', 2058, 2, 0, 96, 9999, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (5644, NULL, '2012-01-20 12:55:33.842843+00', 'Bonnie Anne', 2058, 2, 0, 96, 9999, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (5645, NULL, '2012-01-20 12:55:33.847634+00', 'Bratach Bana', 2058, 1, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (5646, NULL, '2012-01-20 12:55:33.852429+00', 'Bratach Bana (encore)', 2058, 1, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (5647, NULL, '2012-01-20 12:55:33.857212+00', 'Dundee Strathspey', 2058, 3, 4, 32, 9999, NULL, 238, 0, '');
INSERT INTO 'recording' VALUES (5648, NULL, '2012-01-20 12:55:33.862+00', 'Jack''s Delight', 2058, 1, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (5649, NULL, '2012-01-20 12:55:33.866772+00', 'Jack''s Delight (encore)', 2058, 1, 4, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (5650, NULL, '2012-01-20 12:55:33.871559+00', 'Letham Ladies', 2058, 3, 4, 40, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (5651, NULL, '2012-01-20 12:55:33.876538+00', 'J.B. Milne', 2058, 1, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (5652, NULL, '2012-01-20 12:55:33.881352+00', 'J.B. Milne (encore)', 2058, 1, 4, 32, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (5654, NULL, '2012-01-20 12:55:33.890919+00', 'Fiddlin'' Round', 3403, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5622, NULL, '2014-09-16 09:45:35.325325+00', 'Angus Macleod', 3019, 1, 2, 64, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (5577, NULL, '2014-09-16 11:56:43.328342+00', 'EH3 7AF', 2162, 2, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (5578, NULL, '2014-09-16 11:57:15.542383+00', 'Balquidder Strathspey', 2162, 3, 8, 32, 9999, NULL, 520, 0, '');
INSERT INTO 'recording' VALUES (5579, NULL, '2014-09-16 11:57:40.185895+00', 'Mason''s Apron, The', 2162, 1, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (5580, NULL, '2014-09-16 11:58:11.569545+00', 'Bonnie at Morn', 2162, 5, 4, 32, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (5658, NULL, '2012-01-20 12:55:33.910774+00', 'Marilyn''s Reel', 3403, 1, 8, 32, 9999, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (5660, NULL, '2012-01-20 12:55:33.920394+00', 'Catch Me If You Can', 3403, 2, 2, 48, 9999, NULL, 115, 0, '');
INSERT INTO 'recording' VALUES (5663, NULL, '2012-01-20 12:55:33.934762+00', 'Devil''s Quandary', 3403, 3, 8, 40, 9999, NULL, 628, 0, '');
INSERT INTO 'recording' VALUES (5665, NULL, '2012-01-20 12:55:33.944379+00', 'Green Isle Waltzes', 3403, 5, 4, 32, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (5673, NULL, '2012-01-20 12:55:33.98268+00', 'Gay Gordons', 3071, 11, 8, 16, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (5674, NULL, '2012-01-20 12:55:33.987471+00', 'Dumbarton''s Drums', 3071, 1, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (5675, NULL, '2012-01-20 12:55:33.992246+00', 'Pride of Erin Waltz', 3071, 5, 0, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (5676, NULL, '2012-01-20 12:55:33.997021+00', 'Canadian Barn Dance', 3071, 11, 0, 16, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (5677, NULL, '2012-01-20 12:55:34.001833+00', 'Pipe Medley', 3071, 98, 0, 0, 9999, NULL, 343, 0, '');
INSERT INTO 'recording' VALUES (5678, NULL, '2012-01-20 12:55:34.006624+00', 'Eva Three-Step', 3071, 11, 0, 16, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (5679, NULL, '2012-01-20 12:55:34.011401+00', 'Wild Geese, The', 3071, 2, 4, 32, 9999, NULL, 128, 0, '');
INSERT INTO 'recording' VALUES (5680, NULL, '2012-01-20 12:55:34.016199+00', 'Military Two-Step', 3071, 11, 0, 16, 9999, NULL, 128, 0, '');
INSERT INTO 'recording' VALUES (5681, NULL, '2012-01-20 12:55:34.020978+00', 'Irish Reels', 3071, 1, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (5682, NULL, '2012-01-20 12:55:34.025766+00', 'Highland Schottische', 3071, 11, 0, 0, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (5683, NULL, '2012-01-20 12:55:34.030541+00', 'Circle Waltz', 3071, 5, 0, 32, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (5684, NULL, '2012-01-20 12:55:34.035311+00', 'Strip the Willow', 3071, 2, 8, 32, 9999, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (5685, NULL, '2012-01-20 12:55:34.040101+00', 'Party Polka', 3071, 13, 0, 0, 9999, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (5686, NULL, '2012-01-20 12:55:34.044922+00', 'Dashing White Sergeant', 3071, 1, 6, 32, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (5687, NULL, '2012-10-11 17:16:08.009278+00', 'Reels', 3418, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (5700, NULL, '2012-10-11 17:18:21.512212+00', 'Reels', 3418, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5694, NULL, '2012-10-11 17:19:28.180893+00', 'Reels', 3418, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (5692, NULL, '2012-10-11 17:20:27.837108+00', 'Reels', 3418, 1, 3, 48, 9999, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (5688, NULL, '2012-10-11 17:22:53.133479+00', 'Jigs', 3418, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5695, NULL, '2012-10-11 17:24:03.476184+00', 'Jigs', 3418, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5699, NULL, '2012-10-11 17:25:33.815619+00', 'Jigs', 3418, 2, 6, 32, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (5689, NULL, '2012-10-11 17:27:09.633832+00', 'Slow Air Strathspeys', 3418, 3, 3, 32, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (5690, NULL, '2012-10-11 17:29:18.067969+00', '6/8 Marches', 3418, 99, 0, 0, 9999, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (5693, NULL, '2012-10-11 17:31:28.337485+00', 'Slow Air & Waltz', 3418, 99, 0, 0, 9999, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (5697, NULL, '2012-10-11 17:32:24.137996+00', 'Polka', 3418, 13, 0, 0, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (5698, NULL, '2012-10-11 17:33:10.074014+00', 'Waltzes', 3418, 5, 0, 0, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (5703, NULL, '2012-01-20 12:55:34.128027+00', 'Back to the Fireside', 3002, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5704, NULL, '2012-01-20 12:55:34.132834+00', 'Robert H. Mackay', 3002, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5706, NULL, '2012-01-20 12:55:34.142424+00', 'Trip to the Drakensberg, A', 3002, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5707, NULL, '2012-01-20 12:55:34.14721+00', 'Crossing the Brook', 3002, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5708, NULL, '2012-01-20 12:55:34.152015+00', 'Sands of Forvie, The', 3002, 3, 3, 32, 9999, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (5709, NULL, '2012-01-20 12:55:34.156811+00', 'Vintage ''62', 3002, 2, 4, 32, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (5710, NULL, '2012-01-20 12:55:34.161674+00', 'Dancing On', 3002, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5711, NULL, '2012-01-20 12:55:34.166478+00', 'Susanne''s Strathspey', 3002, 3, 6, 32, 9999, NULL, 406, 0, '');
INSERT INTO 'recording' VALUES (5716, NULL, '2012-01-20 12:55:34.190916+00', 'Miss Johnstone of Ardrossan', 3002, 1, 5, 32, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (5723, NULL, '2012-01-20 12:55:34.224452+00', 'Rockside', 3002, 2, 0, 96, 9999, NULL, 118, 0, '');
INSERT INTO 'recording' VALUES (10169, '2018-03-30 09:02:40.43662+00', '2019-11-26 22:24:58.762116+00', 'Georgian Strathspey', 11613, 3, 4, 32, NULL, NULL, 259, 1, '');
INSERT INTO 'recording' VALUES (5715, NULL, '2020-05-26 19:29:41.873355+00', 'Pele Tower, The', 3002, 2, 4, 32, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (5721, NULL, '2020-06-05 18:08:40.134393+00', 'Blue and White Quilt, The', 3002, 2, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (5659, NULL, '2020-06-17 23:18:58.666487+00', 'Australian Laddie', 3403, 4, 2, 64, 17, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (5691, NULL, '2020-08-25 09:52:07.576405+00', 'Strathspeys', 3418, 3, 4, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (5667, NULL, '2021-12-21 10:36:55.161476+00', 'Quaich, The', 3399, 3, 8, 32, 9999, NULL, 536, 0, '');
INSERT INTO 'recording' VALUES (5666, NULL, '2021-12-21 10:37:54.04488+00', 'Caberfei', 3399, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5672, NULL, '2021-12-21 10:40:49.285424+00', 'Waltz', 3399, 5, 0, 0, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (5657, NULL, '2022-12-18 02:17:15.246366+00', 'Gloria''s Wee Jig', 3403, 2, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (5582, NULL, '2022-04-17 18:51:23.688082+00', 'Swithland Woods', 3006, 3, 3, 40, 9999, NULL, 238, 0, '');
INSERT INTO 'recording' VALUES (5661, NULL, '2022-08-31 16:58:17.127202+00', 'Lady in Red', 3403, 3, 8, 32, 9999, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (5668, NULL, '2022-09-01 14:55:11.835484+00', 'Haddington Assembly', 3399, 2, 8, 32, 9999, NULL, 299, 0, '');
INSERT INTO 'recording' VALUES (5656, NULL, '2022-08-31 11:21:01.425077+00', 'Rising Phoenix', 3403, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5664, NULL, '2022-08-31 22:09:05.302847+00', 'Fox In the Wood', 3403, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (5576, NULL, '2022-12-18 16:17:41.137425+00', 'Gypsy Weaver', 2162, 3, 8, 32, 9999, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (5720, NULL, '2021-06-10 09:11:08.500544+00', 'Saint Columba''s Reel', 3002, 1, 8, 40, 9999, NULL, 353, 0, '');
INSERT INTO 'recording' VALUES (5727, NULL, '2012-01-20 12:55:34.243862+00', 'Lamb Skinnet', 2586, 2, 8, 32, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (5729, NULL, '2012-01-20 12:55:34.253432+00', 'Gentleman, The', 2586, 3, 8, 32, 9999, NULL, 514, 0, '');
INSERT INTO 'recording' VALUES (5730, NULL, '2012-01-20 12:55:34.258221+00', 'Hooper''s Jig', 2586, 2, 8, 32, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (5726, NULL, '2015-04-26 01:32:32.894797+00', 'Strathglass House', 2586, 3, 8, 32, 9999, NULL, 514, 0, '');
INSERT INTO 'recording' VALUES (5653, NULL, '2016-09-04 13:57:40.259969+00', 'Pint O'' Ale', 3403, 2, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (5705, NULL, '2019-01-23 17:45:07.308606+00', 'Summer Wooing', 3002, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5732, NULL, '2012-01-20 12:55:34.267813+00', 'Lea Rig, The', 2586, 3, 8, 32, 9999, NULL, 521, 0, '');
INSERT INTO 'recording' VALUES (5733, NULL, '2012-01-20 12:55:34.272599+00', 'Miss Allie Anderson', 2586, 2, 8, 32, 9999, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (5735, NULL, '2012-01-20 12:55:34.282464+00', 'Follow Me Home', 2586, 2, 8, 32, 9999, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (5736, NULL, '2012-01-20 12:55:34.287255+00', 'Mrs MacPherson of Inveran', 2586, 1, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (5737, NULL, '2012-01-20 12:55:34.29205+00', 'Starlight', 3039, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5738, NULL, '2012-01-20 12:55:34.297501+00', 'Knotwork', 3039, 2, 8, 40, 9999, NULL, 340, 0, '');
INSERT INTO 'recording' VALUES (5739, NULL, '2012-01-20 12:55:34.302797+00', 'Silver Strathspey, The', 3039, 3, 8, 32, 9999, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (5740, NULL, '2012-01-20 12:55:34.307639+00', 'Hand in Hand', 3039, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (5741, NULL, '2012-01-20 12:55:34.312426+00', 'Cocket Hat, The', 3039, 2, 8, 40, 9999, NULL, 342, 0, '');
INSERT INTO 'recording' VALUES (5742, NULL, '2012-01-20 12:55:34.317236+00', 'Wishing Well, The', 3039, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (5725, NULL, '2012-03-23 10:16:51.95311+00', 'Rain Dancing, Da', 2586, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5701, NULL, '2012-10-11 17:35:54.352623+00', 'Slow Air', 3418, 98, 0, 0, 9999, NULL, 122, 0, '');
INSERT INTO 'recording' VALUES (5702, NULL, '2012-10-16 13:19:03.963917+00', 'My Friend Joe', 3002, 3, 8, 32, 9999, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (5718, NULL, '2013-02-05 12:36:03.442911+00', 'Findlays'' Jig, The', 3002, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5807, NULL, '2018-04-06 22:33:42.016906+00', 'One for the Millennium', 3039, 3, 3, 48, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (5712, NULL, '2014-03-19 22:46:03.289142+00', 'Inchmickery', 3002, 2, 5, 32, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (5744, NULL, '2012-01-20 12:55:34.326915+00', 'Crathes Castle', 3039, 3, 3, 48, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (5745, NULL, '2012-01-20 12:55:34.331736+00', '51st Travellers, The', 3039, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5746, NULL, '2012-01-20 12:55:34.336552+00', 'Silver Thistle, The', 3039, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5749, NULL, '2012-01-20 12:55:34.35095+00', 'Davy Nick Nack', 2586, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5750, NULL, '2012-01-20 12:55:34.356145+00', 'General Ritchie''s Reel', 2586, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (5753, NULL, '2012-01-20 12:55:34.37061+00', 'Montreal Rendezvous', 2586, 4, 8, 32, 1, NULL, 403, 0, '');
INSERT INTO 'recording' VALUES (5756, NULL, '2012-01-20 12:55:34.38501+00', 'Let''s Have a Ceilidh', 2586, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (5759, NULL, '2012-01-20 12:55:34.399457+00', 'Australian Ladies, The', 2586, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5760, NULL, '2012-01-20 12:55:34.404258+00', 'Luckenbooth Brooch, The', 3012, 2, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (5761, NULL, '2012-01-20 12:55:34.409041+00', 'Tak Tent', 3012, 1, 5, 32, 9999, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (5762, NULL, '2012-01-20 12:55:34.413841+00', 'Wind on Loch Fyne, The', 3012, 3, 3, 32, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (5763, NULL, '2012-01-20 12:55:34.418627+00', 'Chairman, The', 3012, 1, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (5764, NULL, '2012-01-20 12:55:34.423418+00', 'Cornet''s Chase', 3012, 2, 4, 40, 9999, NULL, 178, 1, '');
INSERT INTO 'recording' VALUES (5765, NULL, '2012-01-20 12:55:34.428207+00', 'Pigeon on the Gate, The', 3012, 1, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (5766, NULL, '2012-01-20 12:55:34.432999+00', 'Quern, The', 3012, 3, 3, 32, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (5767, NULL, '2012-01-20 12:55:34.437781+00', 'Pinewoods Reel', 3012, 1, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (5768, NULL, '2012-01-20 12:55:34.442564+00', 'Marie''s Farewell', 3012, 2, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (5769, NULL, '2012-01-20 12:55:34.447343+00', 'Marchmont Eightsome, The', 3012, 1, 0, 96, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (5770, NULL, '2012-01-20 12:55:34.452119+00', 'Dalry Strathspey', 3012, 3, 8, 32, 9999, NULL, 466, 0, '');
INSERT INTO 'recording' VALUES (5771, NULL, '2012-01-20 12:55:34.456913+00', 'Christina McLellan', 3012, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5772, NULL, '2012-01-20 12:55:34.4617+00', 'Cuddy, The', 3012, 2, 8, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (5773, NULL, '2012-01-20 12:55:34.466486+00', 'Bauldy Bain''s Fiddle', 3012, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (5774, NULL, '2012-01-20 12:55:34.4713+00', 'Gypsy Glen', 3012, 3, 3, 32, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (5775, NULL, '2012-01-20 12:55:34.476184+00', 'Bannockburn Reel', 3012, 1, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (5776, NULL, '2012-01-20 12:55:34.48101+00', 'Reel of the Puffins', 3012, 1, 4, 32, 9999, NULL, 143, 1, '');
INSERT INTO 'recording' VALUES (5777, NULL, '2012-01-20 12:55:34.485811+00', 'Diamond Jubilee, The', 3022, 2, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (5778, NULL, '2012-01-20 12:55:34.490612+00', 'Diamond Jubilee, The', 3022, 2, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (5779, NULL, '2012-01-20 12:55:34.495421+00', 'Clutha', 3022, 1, 4, 48, 9999, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (5780, NULL, '2012-01-20 12:55:34.500211+00', 'Margaret Parker''s Strathspey', 3022, 3, 8, 32, 9999, NULL, 499, 0, '');
INSERT INTO 'recording' VALUES (5781, NULL, '2012-01-20 12:55:34.504999+00', 'Polka Country Dance', 3022, 1, 8, 32, 9999, NULL, 280, 1, '');
INSERT INTO 'recording' VALUES (5783, NULL, '2012-01-20 12:55:34.514614+00', 'Autumn in Appin', 3022, 3, 4, 32, 9999, NULL, 252, 1, '');
INSERT INTO 'recording' VALUES (5784, NULL, '2012-01-20 12:55:34.519418+00', 'Scotland', 3022, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5785, NULL, '2012-01-20 12:55:34.524292+00', 'Sir Murdoch Macdonald''s Strathspey', 3022, 3, 4, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5786, NULL, '2012-01-20 12:55:34.529371+00', 'Cromarties Rant', 3022, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5787, NULL, '2012-01-20 12:55:34.534184+00', 'Johnnie''s Welcome Hame', 3022, 1, 8, 40, 9999, NULL, 350, 0, '');
INSERT INTO 'recording' VALUES (5790, NULL, '2012-01-20 12:55:34.548579+00', 'Grant''s Rant', 3067, 1, 8, 48, 9999, NULL, 412, 0, '');
INSERT INTO 'recording' VALUES (5791, NULL, '2012-01-20 12:55:34.553371+00', 'Green Grow the Rashes', 3067, 3, 8, 32, 9999, NULL, 510, 0, '');
INSERT INTO 'recording' VALUES (5792, NULL, '2012-01-20 12:55:34.558201+00', 'Jenny Dang the Weaver', 3067, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5793, NULL, '2012-01-20 12:55:34.562996+00', 'Laird of Dumbiedykes'' Favourite, The', 3067, 1, 8, 40, 9999, NULL, 351, 0, '');
INSERT INTO 'recording' VALUES (5794, NULL, '2012-01-20 12:55:34.567789+00', 'Fiddle Faddle', 3067, 3, 8, 32, 9999, NULL, 511, 0, '');
INSERT INTO 'recording' VALUES (5795, NULL, '2012-01-20 12:55:34.572609+00', 'Kiss me Quick, my Mither''s Coming', 3067, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5796, NULL, '2012-01-20 12:55:34.577413+00', 'Yellow-Haired Laddie, The', 3067, 5, 2, 64, 9999, NULL, 248, 0, '');
INSERT INTO 'recording' VALUES (5797, NULL, '2012-01-20 12:55:34.582212+00', 'Reel of Glamis, The', 3067, 3, 8, 32, 9999, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (5798, NULL, '2012-01-20 12:55:34.587001+00', 'Sodger Laddie', 3067, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5799, NULL, '2012-01-20 12:55:34.59192+00', 'Black Dance, The', 3067, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5800, NULL, '2012-01-20 12:55:34.596763+00', 'Earl of Home, The', 3067, 3, 8, 32, 9999, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (5801, NULL, '2012-01-20 12:55:34.601553+00', 'Machine Without Horses, The', 3067, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5802, NULL, '2012-01-20 12:55:34.606347+00', 'Dancing in 2000', 3039, 1, 4, 40, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (5803, NULL, '2012-01-20 12:55:34.611118+00', 'Julian''s Jig', 3039, 2, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (5714, NULL, '2020-01-23 10:12:09.295187+00', 'Partnership, The', 3002, 3, 0, 96, 9999, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (5752, NULL, '2020-03-08 22:25:38.405794+00', 'Shetland Fiddler, The', 2586, 1, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (5734, NULL, '2021-09-03 02:31:33.203125+00', 'Balmoral Strathspey', 2586, 3, 4, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (5728, NULL, '2021-04-05 13:14:42.771712+00', 'Catch the Wind', 2586, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5719, NULL, '2021-05-06 21:18:50.139267+00', 'In Campbell Country', 3002, 3, 4, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (5788, NULL, '2021-05-08 00:12:21.525692+00', 'Lanes of Au, The', 3022, 1, 3, 32, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (5731, NULL, '2021-06-05 09:24:15.673274+00', 'Burns'' Hornpipe', 2586, 1, 4, 32, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (5713, NULL, '2022-08-30 18:26:50.460907+00', 'Mr Hamilton''s Hornpipe', 3002, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (5789, NULL, '2022-12-18 11:04:18.687583+00', 'Miss Nancy Arnott', 3022, 3, 6, 32, 9999, NULL, 366, 0, '');
INSERT INTO 'recording' VALUES (5748, NULL, '2022-09-01 20:46:52.984695+00', 'Expert Dancer, The', 2586, 3, 8, 32, 9999, NULL, 511, 0, '');
INSERT INTO 'recording' VALUES (5804, NULL, '2012-01-20 12:55:34.615892+00', 'Ghillie Laces', 3039, 3, 8, 32, 9999, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (5805, NULL, '2012-01-20 12:55:34.620703+00', 'Bon Accord', 3039, 1, 8, 40, 9999, NULL, 349, 0, '');
INSERT INTO 'recording' VALUES (5806, NULL, '2012-01-20 12:55:34.625527+00', 'Widdershins', 3039, 2, 8, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (5757, NULL, '2017-10-22 16:06:07.7608+00', 'Traveller''s Jig, The', 2586, 2, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5782, NULL, '2018-04-15 08:06:45.157552+00', 'Autumn in Appin', 3022, 3, 4, 32, 9999, NULL, 259, 1, '');
INSERT INTO 'recording' VALUES (5743, NULL, '2019-07-24 20:31:57.052785+00', 'Festival Fling', 3039, 1, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5808, NULL, '2012-01-20 12:55:34.635154+00', 'Morpeth Rant', 3039, 1, 6, 32, 9999, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (5809, NULL, '2012-01-20 12:55:34.639937+00', 'King o'' the Rookery', 3039, 2, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (5810, NULL, '2012-01-20 12:55:34.644731+00', 'Monadh Liath', 3039, 3, 8, 32, 9999, NULL, 480, 0, '');
INSERT INTO 'recording' VALUES (5813, NULL, '2012-01-20 12:55:34.65918+00', 'Viking Ship, The', 3039, 4, 4, 64, 5, NULL, 384, 0, '');
INSERT INTO 'recording' VALUES (5814, NULL, '2012-01-20 12:55:34.663959+00', 'Bean Shea Fancy', 3039, 1, 5, 48, 9999, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (5816, NULL, '2012-01-20 12:55:34.673643+00', 'Clan Reel, The', 3039, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (5817, NULL, '2012-01-20 12:55:34.678527+00', 'Albert''s Welcome to Potten End', 3459, 2, 4, 48, 9999, NULL, 220, 0, '');
INSERT INTO 'recording' VALUES (5819, NULL, '2012-01-20 12:55:34.688194+00', 'Ard Choille', 3459, 3, 8, 32, 9999, NULL, 474, 0, '');
INSERT INTO 'recording' VALUES (5820, NULL, '2012-01-20 12:55:34.693202+00', 'Black Bear, The', 3459, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (5821, NULL, '2012-01-20 12:55:34.698026+00', 'Blenheim Gardens', 3459, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5822, NULL, '2012-01-20 12:55:34.702817+00', 'Children of the Briton', 3459, 3, 3, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (5823, NULL, '2012-01-20 12:55:34.707592+00', 'Children of the Briton', 3459, 3, 3, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (5824, NULL, '2012-01-20 12:55:34.712374+00', 'Ian Hasnae Crossed the Braes', 3459, 1, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (5825, NULL, '2012-01-20 12:55:34.717185+00', 'John''s Jig', 3459, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5818, NULL, '2012-06-12 12:14:48.004083+00', 'Anniversary Medley', 3459, 4, 0, 128, 2, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (5826, NULL, '2012-01-20 12:55:34.722014+00', 'Lady Fenella Fogarty', 3459, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5828, NULL, '2012-01-20 12:55:34.731763+00', 'Mr & Mrs Munro', 3459, 1, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (5829, NULL, '2012-01-20 12:55:34.736609+00', 'Widdershins', 3459, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (5830, NULL, '2012-01-20 12:55:34.741409+00', 'Dancing Forth', 3464, 1, 8, 32, 9999, NULL, 307, 0, '');
INSERT INTO 'recording' VALUES (5831, NULL, '2012-01-20 12:55:34.746212+00', 'Castle Wynd', 3464, 3, 8, 32, 9999, NULL, 530, 1, '');
INSERT INTO 'recording' VALUES (5832, NULL, '2012-01-20 12:55:34.75102+00', 'Eilidh MacIain', 3464, 2, 8, 40, 9999, NULL, 359, 0, '');
INSERT INTO 'recording' VALUES (5834, NULL, '2012-01-20 12:55:34.760611+00', 'Corstorphine Fair', 3464, 2, 4, 40, 9999, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (5835, NULL, '2012-01-20 12:55:34.765395+00', 'Rose of Glamis', 3464, 4, 2, 64, 5, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (5837, NULL, '2012-01-20 12:55:34.775484+00', 'Queen''s Jubilee, The', 3464, 3, 4, 40, 9999, NULL, 341, 0, '');
INSERT INTO 'recording' VALUES (5838, NULL, '2012-01-20 12:55:34.780296+00', 'Honeycomb, The', 3464, 1, 4, 40, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (5839, NULL, '2012-01-20 12:55:34.785086+00', 'Breezbay', 3464, 2, 4, 32, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (5840, NULL, '2012-01-20 12:55:34.789882+00', 'Edina''s Pride', 3464, 3, 8, 32, 9999, NULL, 549, 0, '');
INSERT INTO 'recording' VALUES (5841, NULL, '2012-01-20 12:55:34.79467+00', 'That Sinking Feeling', 3464, 1, 4, 32, 9999, NULL, 165, 1, '');
INSERT INTO 'recording' VALUES (5842, NULL, '2012-01-20 12:55:34.799461+00', 'Have a Bashie', 3464, 2, 4, 32, 9999, NULL, 157, 1, '');
INSERT INTO 'recording' VALUES (5844, NULL, '2012-01-20 12:55:34.809058+00', 'Strictly Scottish', 3464, 1, 6, 48, 9999, NULL, 344, 0, '');
INSERT INTO 'recording' VALUES (5845, NULL, '2012-01-20 12:55:34.813846+00', 'Watson''s Reel', 3006, 2, 8, 24, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (5846, NULL, '2012-01-20 12:55:34.81863+00', 'Honeymoon, The', 3006, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (5847, NULL, '2012-01-20 12:55:34.823415+00', 'Moray Reel, The', 3006, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5848, NULL, '2012-01-20 12:55:34.828237+00', 'Mrs Stewart Sinton''s Reel', 3006, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5850, NULL, '2012-01-20 12:55:34.837906+00', 'Miss Welsh''s Reel', 3006, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5851, NULL, '2012-01-20 12:55:34.842711+00', 'Isle, The', 3006, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (5852, NULL, '2012-01-20 12:55:34.847553+00', 'Miss Cholmondeley''s Reel', 3006, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (5853, NULL, '2012-01-20 12:55:34.852367+00', 'Duff''s House', 3006, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (5854, NULL, '2012-01-20 12:55:34.857155+00', 'Tarry a While', 3006, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5855, NULL, '2012-01-20 12:55:34.863157+00', 'Miss Betty Boyle', 3006, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5856, NULL, '2012-01-20 12:55:34.868145+00', 'Kendall''s Hornpipe', 3006, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5857, NULL, '2012-01-20 12:55:34.872959+00', 'Baldovan Reel', 3032, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (5858, NULL, '2012-01-20 12:55:34.877984+00', 'Nurseryman, The', 3032, 2, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (5859, NULL, '2012-01-20 12:55:34.882798+00', 'Cherrybank Gardens', 3032, 3, 3, 32, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (10170, '2018-03-30 09:05:23.547815+00', '2018-04-03 11:00:53.270523+00', 'Judie''s Farewell to Spring Creek', 11613, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (5861, NULL, '2012-01-20 12:55:34.893367+00', 'Birl Roond Forfar, A', 3032, 1, 0, 64, 9999, NULL, 78, 0, '');
INSERT INTO 'recording' VALUES (5862, NULL, '2012-01-20 12:55:34.898215+00', 'Kilkenny Castle', 3032, 3, 8, 32, 9999, NULL, 486, 0, '');
INSERT INTO 'recording' VALUES (5863, NULL, '2012-01-20 12:55:34.903484+00', 'White Heather Jig', 3032, 2, 4, 40, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (5864, NULL, '2012-01-20 12:55:34.908338+00', 'Mrs MacPherson of Inveran', 3032, 1, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5865, NULL, '2012-01-20 12:55:34.913135+00', 'Nor'' Loch, The', 3032, 4, 0, 96, 11, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (5867, NULL, '2012-01-20 12:55:34.92271+00', 'S-Locomotion', 3032, 3, 4, 32, 9999, NULL, 248, 0, '');
INSERT INTO 'recording' VALUES (5868, NULL, '2012-01-20 12:55:34.92749+00', 'Johnnie''s Welcome Hame', 3032, 1, 8, 40, 9999, NULL, 353, 0, '');
INSERT INTO 'recording' VALUES (5870, NULL, '2012-01-20 12:55:34.937494+00', 'Lady of the Lake', 3032, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (5871, NULL, '2012-01-20 12:55:34.94248+00', 'Setons Ceilidh Band', 3032, 2, 4, 64, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5872, NULL, '2012-01-20 12:55:34.947319+00', 'Australian Ladies', 3023, 1, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (5873, NULL, '2012-01-20 12:55:34.952115+00', 'Ian Powrie''s Farewell to Auchterarder', 3023, 2, 0, 128, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (5874, NULL, '2012-01-20 12:55:34.95695+00', 'Ian Powrie''s Farewell to Auchterarder', 3023, 2, 0, 128, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (5876, NULL, '2012-01-20 12:55:34.966566+00', 'Chequered Court, The', 3023, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (5877, NULL, '2012-01-20 12:55:34.97135+00', 'Piper and the Penguin, The', 3023, 1, 0, 88, 9999, NULL, 103, 0, '');
INSERT INTO 'recording' VALUES (5878, NULL, '2012-01-20 12:55:34.976127+00', 'Piper and the Penguin, The', 3023, 1, 0, 88, 9999, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (5879, NULL, '2012-01-20 12:55:34.98091+00', 'Bonnie Ann', 3023, 2, 0, 96, 9999, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (5880, NULL, '2012-01-20 12:55:34.985694+00', 'Bonnie Ann', 3023, 2, 0, 96, 9999, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (5882, NULL, '2012-01-20 12:55:34.995298+00', 'Belle of Bon Accord', 3023, 3, 4, 32, 9999, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (5883, NULL, '2012-01-20 12:55:35.000105+00', 'Flight of the Falcon, The', 3023, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5884, NULL, '2012-01-20 12:55:35.004914+00', 'Robbie Over the Waves', 3023, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5885, NULL, '2012-01-20 12:55:35.009711+00', 'Balnain House', 3023, 3, 4, 40, 9999, NULL, 310, 0, '');
INSERT INTO 'recording' VALUES (5886, NULL, '2012-01-20 12:55:35.014497+00', 'Phantom Piper, The', 3023, 2, 4, 32, 9999, NULL, 147, 1, '');
INSERT INTO 'recording' VALUES (5887, NULL, '2012-01-20 12:55:35.019333+00', 'Bonnie Stronshiray', 3023, 3, 8, 32, 9999, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (5849, NULL, '2021-06-17 00:52:35.593835+00', 'Mr Watson''s Favourite', 3006, 1, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (5811, NULL, '2021-07-14 08:17:21.374739+00', 'Folksy Fivesome, The', 3039, 1, 5, 32, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (5758, NULL, '2021-07-15 08:21:30.048415+00', 'Banks of Spey, The', 2586, 3, 4, 32, 9999, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (5843, NULL, '2021-09-04 09:58:21.461848+00', 'Melville Castle', 3464, 1, 8, 32, 9999, NULL, 306, 0, '');
INSERT INTO 'recording' VALUES (5888, NULL, '2012-01-20 12:55:35.024127+00', 'Rest and be Thankful', 3023, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5747, NULL, '2022-09-01 10:51:35.923245+00', 'On the Wings of the Morning', 2586, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (5754, NULL, '2022-09-01 19:56:37.840686+00', 'Just in Time', 2586, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (5905, NULL, '2012-01-20 12:55:35.106452+00', 'Lady Wynd', 3483, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (5906, NULL, '2012-01-20 12:55:35.111256+00', 'Culla Bay', 3483, 3, 4, 32, 9999, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (5907, NULL, '2012-01-20 12:55:35.116054+00', 'Angus MacKinnon''s Hornpipe', 3483, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5812, NULL, '2016-02-16 23:02:05.018766+00', 'Muckle Burn', 3039, 2, 5, 40, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (5827, NULL, '2017-02-25 17:18:23.937351+00', 'Mrs Litten''s Reel', 3459, 1, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (5833, NULL, '2017-02-27 17:57:13.795952+00', 'Saint Margaret, Queen of Scotland', 3464, 3, 4, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5866, NULL, '2017-11-19 18:35:35.387471+00', 'James Gray', 3032, 2, 4, 32, 9999, NULL, 146, 1, '');
INSERT INTO 'recording' VALUES (5815, NULL, '2019-06-28 14:35:38.345753+00', 'Two Furlongs', 3039, 3, 6, 32, 9999, NULL, 365, 0, '');
INSERT INTO 'recording' VALUES (5949, NULL, '2018-03-02 23:09:12.876704+00', 'Iain''s Welcome', 2566, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5890, NULL, '2014-07-30 13:54:24.379419+00', 'Duran Ranger, The', 2501, 1, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (5891, NULL, '2014-07-30 13:56:19.996983+00', 'Saint Bernard''s Waltz', 2501, 5, 0, 16, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (5881, NULL, '2014-10-04 02:32:49.31731+00', 'Reel of the 51st Division, The', 3023, 1, 0, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (5893, NULL, '2014-07-30 14:04:20.194083+00', 'Canadian Barn Dance', 2501, 11, 0, 16, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (5894, NULL, '2014-07-30 14:08:17.588238+00', 'Reels, Tricky but Catchy', 2501, 1, 4, 32, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (5895, NULL, '2014-07-30 14:12:53.432742+00', 'Gay Gordons', 2501, 11, 0, 16, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (5897, NULL, '2014-07-30 14:20:35.318966+00', 'Accordion Solo', 2501, 4, 0, 0, 9999, NULL, 185, 0, 'March, Strathspey, Reel');
INSERT INTO 'recording' VALUES (5898, NULL, '2014-07-30 14:23:29.879097+00', '6/8 Marches', 2501, 11, 0, 16, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (5899, NULL, '2014-07-30 14:25:53.318866+00', 'Barn Dance', 2501, 11, 0, 16, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (5900, NULL, '2014-07-30 14:28:08.586588+00', 'Jigs', 2501, 2, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (5901, NULL, '2014-07-30 14:30:34.133664+00', 'Dark Island, The', 2501, 5, 0, 0, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (5902, NULL, '2014-07-30 14:35:07.745005+00', 'Gay Gordons Two-Step', 2501, 11, 0, 16, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (5903, NULL, '2014-07-30 14:39:11.762139+00', 'Britannia Two-Step', 2501, 11, 0, 16, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (5904, NULL, '2014-07-30 14:42:47.277694+00', 'Reels', 2501, 1, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (5892, NULL, '2014-10-04 02:26:52.088226+00', 'River Cree, The', 2501, 2, 6, 32, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (5909, NULL, '2012-01-20 12:55:35.125656+00', 'Shiftin'' Bobbins', 3483, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (5911, NULL, '2012-01-20 12:55:35.135312+00', 'Rob Roy', 3483, 1, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (5913, NULL, '2012-01-20 12:55:35.14491+00', 'Luckenbooth Brooch', 3483, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (5914, NULL, '2012-01-20 12:55:35.149958+00', 'Breakdown, The', 3483, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (5915, NULL, '2012-01-20 12:55:35.154809+00', 'Tulloch Gorm', 3483, 3, 8, 32, 9999, NULL, 486, 0, '');
INSERT INTO 'recording' VALUES (5916, NULL, '2012-01-20 12:55:35.159649+00', 'Follow Me Home', 3483, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (5917, NULL, '2012-01-20 12:55:35.164487+00', 'General Stuart''s Reel', 3483, 1, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (5918, NULL, '2012-01-20 12:55:35.169283+00', 'Reel 8x40', 3060, 1, 8, 40, 9999, NULL, 350, 0, '');
INSERT INTO 'recording' VALUES (5919, NULL, '2012-01-20 12:55:35.17408+00', 'Jig 8x32', 3060, 2, 0, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5920, NULL, '2012-01-20 12:55:35.178863+00', 'Strathspey 3x48, Reel 3x48', 3060, 1, 0, 112, 9999, NULL, 440, 0, '');
INSERT INTO 'recording' VALUES (5921, NULL, '2012-01-20 12:55:35.183648+00', 'Reel 5x32: (Blue Grass)', 3060, 1, 5, 32, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (5922, NULL, '2012-01-20 12:55:35.18843+00', 'Jig 3x40', 3060, 2, 3, 40, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (5923, NULL, '2012-01-20 12:55:35.193802+00', 'Strathspey 8x32', 3060, 3, 8, 32, 9999, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (5924, NULL, '2012-01-20 12:55:35.198633+00', 'Reel 8x32', 3060, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5925, NULL, '2012-01-20 12:55:35.203423+00', 'Jig 8x32', 3060, 2, 3, 32, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (5926, NULL, '2012-01-20 12:55:35.208209+00', 'Strathspey - 80', 3060, 3, 0, 80, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (5927, NULL, '2012-01-20 12:55:35.212993+00', 'Reel 4x40', 3060, 1, 4, 40, 9999, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (5928, NULL, '2012-01-20 12:55:35.217782+00', 'Jig 8x32', 3060, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5929, NULL, '2012-01-20 12:55:35.222562+00', 'Strathspey 4x32', 3060, 3, 4, 32, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (5930, NULL, '2012-01-20 12:55:35.227352+00', 'Hornpipe 8x32', 3060, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5931, NULL, '2012-01-20 12:55:35.232129+00', 'Jig 4x32', 3060, 2, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (5932, NULL, '2012-01-20 12:55:35.236919+00', 'Strathspey 3x32', 3060, 3, 3, 32, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (5933, NULL, '2012-01-20 12:55:35.241703+00', 'Waltz 3x32', 3060, 5, 3, 32, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (5934, NULL, '2012-01-20 12:55:35.246487+00', 'Reel 8x32', 3060, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (5936, NULL, '2012-01-20 12:55:35.256072+00', 'Up in the Air', 3496, 3, 8, 32, 9999, NULL, 515, 0, '');
INSERT INTO 'recording' VALUES (5937, NULL, '2012-01-20 12:55:35.260856+00', 'John of Bon Accord', 3496, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (5938, NULL, '2012-01-20 12:55:35.265647+00', 'Ladies'' Fancy', 3496, 2, 8, 32, 9999, NULL, 298, 0, '');
INSERT INTO 'recording' VALUES (5939, NULL, '2012-01-20 12:55:35.270426+00', 'Gates of Edinburgh, The', 3496, 1, 8, 32, 9999, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (5940, NULL, '2012-01-20 12:55:35.275323+00', 'Gentleman, The', 3496, 3, 8, 32, 9999, NULL, 513, 0, '');
INSERT INTO 'recording' VALUES (5941, NULL, '2012-01-20 12:55:35.281818+00', 'Lady Home''s Jig', 3496, 2, 8, 32, 9999, NULL, 308, 0, '');
INSERT INTO 'recording' VALUES (5942, NULL, '2012-01-20 12:55:35.286649+00', 'Peggy''s Love', 3496, 3, 8, 32, 9999, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (5944, NULL, '2012-01-20 12:55:35.296292+00', '3x40 Jig', 3496, 2, 3, 40, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (5948, NULL, '2012-01-20 12:55:35.316718+00', '5x48 Reel', 3496, 1, 5, 48, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (5935, NULL, '2012-06-17 15:10:42.358854+00', 'Best Set in the Hall', 3496, 2, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (5910, NULL, '2012-10-21 20:30:02.236839+00', 'Jig Set (suitable for Pelorus Jack)', 3483, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5960, NULL, '2012-01-20 12:55:35.37504+00', 'Robert the Bruce', 3420, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5961, NULL, '2012-01-20 12:55:35.380689+00', 'Braveheart', 3420, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5962, NULL, '2012-01-20 12:55:35.385566+00', 'Stirling Castle', 3420, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5963, NULL, '2012-01-20 12:55:35.390368+00', 'Bannockburn', 3420, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5968, NULL, '2012-01-20 12:55:35.414392+00', 'Gay Gordons', 1836, 11, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5969, NULL, '2012-01-20 12:55:35.419191+00', 'Four of Diamonds', 1836, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5970, NULL, '2012-01-20 12:55:35.424027+00', 'Strathspey for September', 1836, 3, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5971, NULL, '2012-01-20 12:55:35.428813+00', 'Mairi''s Wedding', 1836, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5972, NULL, '2012-01-20 12:55:35.433605+00', 'Border Cities Jig', 1836, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5974, NULL, '2012-01-20 12:55:35.443201+00', 'Yamato Hornpipe', 1836, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5975, NULL, '2012-01-20 12:55:35.448082+00', 'Macpherson''s Jig', 1836, 2, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5976, NULL, '2012-01-20 12:55:35.452908+00', 'Reel of the 51st Division', 1836, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5977, NULL, '2012-01-20 12:55:35.457762+00', 'Saint Bernard''s Waltz', 1836, 5, 8, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5964, NULL, '2016-05-25 14:50:40.043757+00', 'Oliver''s Fifth', 3420, 1, 6, 32, 9999, NULL, 221, 0, '');
INSERT INTO 'recording' VALUES (5965, NULL, '2016-05-25 14:51:21.658137+00', 'Christine Miller''s Reel', 3420, 1, 4, 32, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (5966, NULL, '2016-05-25 14:53:03.820444+00', 'Lochiel Strathspey, The', 3420, 3, 4, 32, 9999, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (5967, NULL, '2016-05-25 14:53:51.681651+00', 'Howard McNally''s Favourite', 3420, 3, 4, 32, 9999, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (5950, NULL, '2018-03-02 23:09:55.360647+00', 'C''est la Vie', 2566, 3, 5, 32, 9999, NULL, 348, 0, '');
INSERT INTO 'recording' VALUES (5952, NULL, '2018-03-02 23:11:54.987649+00', 'Joe''s Strathspey', 2566, 3, 3, 32, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (5947, NULL, '2020-06-23 15:00:40.482818+00', '5x40 Jig', 3496, 2, 5, 40, 9999, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (5945, NULL, '2020-08-21 22:03:40.157813+00', '3x40 Reel', 3496, 1, 3, 40, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (5953, NULL, '2018-03-02 23:12:52.50148+00', 'Keep on Dancing', 2566, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (5954, NULL, '2018-03-02 23:13:28.272239+00', 'Baile Mor', 2566, 3, 4, 32, 9999, NULL, 282, 1, '');
INSERT INTO 'recording' VALUES (5946, NULL, '2021-12-16 20:53:15.983767+00', '5x40 Strathspey', 3496, 3, 5, 40, 9999, NULL, 398, 0, '');
INSERT INTO 'recording' VALUES (5955, NULL, '2018-03-02 23:13:59.840247+00', 'Celebration Dance', 2566, 1, 4, 32, 9999, NULL, 147, 1, '');
INSERT INTO 'recording' VALUES (5956, NULL, '2018-03-02 23:14:29.634682+00', 'Avis Harrison''s Strathspey', 2566, 3, 3, 32, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (5957, NULL, '2018-03-02 23:14:55.744844+00', 'Champion, The', 2566, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5958, NULL, '2018-03-02 23:15:22.236656+00', 'Crystal Quaich, The', 2566, 3, 4, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5959, NULL, '2018-03-02 23:15:46.830179+00', 'Solway Sailor, The', 2566, 4, 0, 128, 2, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (5943, NULL, '2019-01-23 17:16:06.419862+00', 'Mr William Brown''s Reel', 3496, 1, 8, 32, 9999, NULL, 300, 0, '');
INSERT INTO 'recording' VALUES (5978, NULL, '2012-01-20 12:55:35.46257+00', 'Set of Reels', 1836, 1, 10, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5979, NULL, '2012-01-20 12:55:35.467382+00', 'Set of Jigs', 1836, 2, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5980, NULL, '2012-01-20 12:55:35.472177+00', 'Maxwell''s Rant', 1836, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5981, NULL, '2012-01-20 12:55:35.477169+00', 'Trilliums and Cherry Blossoms', 1836, 3, 4, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5982, NULL, '2012-01-20 12:55:35.482011+00', 'Set of Hornpipes', 1836, 1, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5983, NULL, '2012-01-20 12:55:35.486817+00', 'Scottish Waltz', 1836, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5984, NULL, '2012-01-20 12:55:35.491601+00', 'Warm Up Waltz', 3019, 5, 0, 0, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (5985, NULL, '2012-01-20 12:55:35.496384+00', 'Domino 5', 3019, 1, 5, 32, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (5986, NULL, '2012-01-20 12:55:35.501168+00', 'Gilly Flower, The', 3019, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (5987, NULL, '2012-01-20 12:55:35.506024+00', 'Wind on Loch Fyne', 3019, 3, 3, 32, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (5988, NULL, '2012-01-20 12:55:35.510809+00', 'Royal Yacht Britannia, The', 3019, 1, 8, 40, 9999, NULL, 337, 0, '');
INSERT INTO 'recording' VALUES (5989, NULL, '2012-01-20 12:55:35.515595+00', 'Cuillins of Skye', 3019, 3, 8, 32, 9999, NULL, 480, 0, '');
INSERT INTO 'recording' VALUES (5990, NULL, '2012-01-20 12:55:35.520368+00', 'Ayr Promenade, The', 3019, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (5991, NULL, '2012-01-20 12:55:35.525159+00', 'Isabella''s Travels', 3019, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (5992, NULL, '2012-01-20 12:55:35.529993+00', 'Saint Columba''s Strathspey', 3019, 3, 5, 32, 9999, NULL, 302, 0, '');
INSERT INTO 'recording' VALUES (5993, NULL, '2012-01-20 12:55:35.534787+00', 'Noah''s Ark', 3019, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (5994, NULL, '2012-01-20 12:55:35.539664+00', 'Inverneill House', 3019, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (5995, NULL, '2012-01-20 12:55:35.544489+00', 'Bonnie Stronshiray', 3019, 3, 8, 32, 9999, NULL, 480, 0, '');
INSERT INTO 'recording' VALUES (5996, NULL, '2012-01-20 12:55:35.549304+00', 'Farewell to Crumlin', 3019, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (5997, NULL, '2012-01-20 12:55:35.554107+00', 'Portnacraig', 3019, 1, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (5998, NULL, '2012-01-20 12:55:35.558901+00', 'Clutha', 3530, 1, 4, 48, 9999, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (6000, NULL, '2012-01-20 12:55:35.568554+00', 'Quadrille Country Dance', 3530, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (6001, NULL, '2012-01-20 12:55:35.606544+00', 'Queen''s Quadrille, The', 3530, 1, 0, 128, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (6002, NULL, '2012-01-20 12:55:35.611527+00', 'Jubilee Quadrille, The', 3530, 1, 0, 88, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (6003, NULL, '2012-01-20 12:55:35.616322+00', 'Duke of Kent''s Waltz, The', 3530, 5, 7, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6004, NULL, '2012-01-20 12:55:35.621138+00', 'Pavilion Waltz, The', 3530, 5, 6, 32, 9999, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (6005, NULL, '2012-01-20 12:55:35.625942+00', 'Paine''s 1st set of quadrilles', 3530, 10, 0, 0, 9999, NULL, 968, 0, '');
INSERT INTO 'recording' VALUES (6006, NULL, '2012-01-20 12:55:35.630743+00', 'Paine''s 12th set of quadrilles', 3530, 10, 0, 0, 9999, NULL, 763, 0, '');
INSERT INTO 'recording' VALUES (6007, NULL, '2012-01-20 12:55:35.635527+00', 'Hart''s Lancers Quadrille', 3530, 10, 0, 0, 9999, NULL, 730, 0, '');
INSERT INTO 'recording' VALUES (6011, NULL, '2012-01-20 12:55:35.654748+00', 'Dorney Wood', 1557, 3, 1, 80, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (6013, NULL, '2012-01-20 12:55:35.664767+00', 'Betty Fitchet''s Wedding', 3010, 99, 15, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6015, NULL, '2012-01-20 12:55:35.674544+00', 'Brydie''s Polka', 3010, 13, 12, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6016, NULL, '2012-01-20 12:55:35.679387+00', 'Garry Strathspey', 3010, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6017, NULL, '2012-01-20 12:55:35.684183+00', 'Circassian Circle', 3010, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6018, NULL, '2012-01-20 12:55:35.688967+00', 'Trip to Aberdeen, A', 3010, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6019, NULL, '2012-01-20 12:55:35.694049+00', 'Double Eighty', 3040, 3, 4, 32, 9999, NULL, 247, 0, '');
INSERT INTO 'recording' VALUES (6020, NULL, '2012-01-20 12:55:35.698987+00', 'Gay Gordons', 3604, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6021, NULL, '2012-01-20 12:55:35.703798+00', 'Hooper''s Jig', 3604, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6023, NULL, '2012-01-20 12:55:35.7134+00', 'Pipes March & Reel', 3604, 4, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6024, NULL, '2012-01-20 12:55:35.718271+00', 'Britannia Two-Step', 3604, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6025, NULL, '2012-01-20 12:55:35.723065+00', 'Continental Waltz', 3604, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6026, NULL, '2012-01-20 12:55:35.727849+00', 'Eva Three-Step', 3604, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6027, NULL, '2012-01-20 12:55:35.73265+00', 'J B Milne', 3604, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6028, NULL, '2012-01-20 12:55:35.737434+00', 'Slow AIr & Hornpipe', 3604, 98, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6029, NULL, '2012-01-20 12:55:35.742225+00', 'Grandma Knight''s Mississippi Dip', 3604, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6030, NULL, '2012-01-20 12:55:35.747036+00', 'Gaelic Waltz', 3604, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6031, NULL, '2012-01-20 12:55:35.751848+00', 'Muirland Willie', 3604, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6032, NULL, '2012-01-20 12:55:35.756645+00', 'Highland Barn Dance', 3604, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6033, NULL, '2012-01-20 12:55:35.761424+00', 'Scandinavian Waltz', 3604, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6034, NULL, '2012-01-20 12:55:35.766314+00', 'Retreat Marches', 3604, 99, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6035, NULL, '2012-01-20 12:55:35.771146+00', 'Highland Schottische', 3604, 3, 0, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6037, NULL, '2012-01-20 12:55:35.780749+00', 'Bratach Bana', 3604, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6039, NULL, '2012-01-20 12:55:35.790424+00', 'Saltire Strathspey, The', 3040, 3, 4, 32, 9999, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (6040, NULL, '2012-01-20 12:55:35.795278+00', 'Catch the Wind', 3040, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (6041, NULL, '2012-01-20 12:55:35.800066+00', 'Sands of Morar', 3040, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (6042, NULL, '2012-01-20 12:55:35.804861+00', 'Preston Mill', 3040, 1, 5, 32, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (6043, NULL, '2012-01-20 12:55:35.809642+00', 'Napier''s Index', 3040, 2, 8, 40, 9999, NULL, 341, 0, '');
INSERT INTO 'recording' VALUES (6045, NULL, '2012-01-20 12:55:35.81921+00', 'Fairbridge Reel, The', 3040, 1, 3, 48, 9999, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (6046, NULL, '2012-01-20 12:55:35.823996+00', 'Preston Mill', 3040, 1, 5, 32, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (6047, NULL, '2012-01-20 12:55:35.828775+00', 'Dream Catcher, The', 3040, 3, 0, 96, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (6048, NULL, '2012-01-20 12:55:35.833596+00', 'Fairbridge Reel, The', 3040, 1, 3, 48, 9999, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (6049, NULL, '2012-01-20 12:55:35.838409+00', 'Perth Medley, The', 3018, 4, 8, 64, 22, NULL, 745, 0, '');
INSERT INTO 'recording' VALUES (6050, NULL, '2012-01-20 12:55:35.843204+00', 'Delvine Side', 3018, 3, 8, 32, 9999, NULL, 475, 0, '');
INSERT INTO 'recording' VALUES (6051, NULL, '2012-01-20 12:55:35.848012+00', 'Bob o'' Dowally, The', 3018, 3, 8, 32, 9999, NULL, 482, 0, '');
INSERT INTO 'recording' VALUES (6069, NULL, '2012-01-20 12:55:35.935339+00', 'Dancing Master, The', 3653, 2, 0, 96, 9999, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (6070, NULL, '2012-01-20 12:55:35.940117+00', 'Not I', 3653, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (6071, NULL, '2012-01-20 12:55:35.944911+00', 'Moray Rant, The', 3653, 3, 3, 48, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (6072, NULL, '2012-01-20 12:55:35.949704+00', 'Jennifer''s Jig', 3653, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (6073, NULL, '2012-01-20 12:55:35.954489+00', 'Sailor, The', 3653, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (6074, NULL, '2012-01-20 12:55:35.959312+00', 'Balquidder Strathspey', 3653, 3, 8, 32, 9999, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (6052, NULL, '2021-07-19 21:38:00.887549+00', 'Ninety-Second, The', 3011, 3, 8, 24, 9999, NULL, 360, 0, '');
INSERT INTO 'recording' VALUES (6076, NULL, '2012-01-20 12:55:35.969041+00', 'Two and Two', 3653, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (6009, NULL, '2014-09-01 15:39:23.856376+00', 'Toddlin'' Tim', 1557, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (6012, NULL, '2014-09-01 15:40:56.928313+00', 'Just For You', 1557, 1, 5, 32, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (6036, NULL, '2022-12-20 14:54:52.116287+00', 'Viennese Swing Waltz', 3604, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6075, NULL, '2022-12-19 16:36:31.627054+00', 'Set of Birlin'' Reels, A', 3653, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (6055, NULL, '2014-09-16 12:22:13.769453+00', 'Sandy O''er the Lea', 3619, 3, 6, 32, 9999, NULL, 364, 0, '');
INSERT INTO 'recording' VALUES (6054, NULL, '2014-09-16 12:10:42.270408+00', 'Kingston Jig, The', 3619, 2, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (6044, NULL, '2019-01-23 00:17:19.03665+00', 'Dream Catcher, The', 3040, 3, 0, 96, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (6058, NULL, '2014-09-16 12:22:50.993304+00', 'Indian River Strathspey', 3619, 3, 3, 32, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (6056, NULL, '2014-09-16 12:12:41.873959+00', 'Kelso Races', 3619, 1, 6, 32, 9999, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (6057, NULL, '2014-09-16 12:13:13.35245+00', 'Joe MacDiarmid''s Jig', 3619, 2, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (6014, NULL, '2014-11-08 12:55:34.736871+00', 'Call of the Pipes', 3010, 99, 16, 8, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6059, NULL, '2014-09-16 12:14:16.857497+00', 'Davy Nick Nack', 3619, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6060, NULL, '2014-09-16 12:14:48.092498+00', 'Ciamar a Tha', 3619, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (6061, NULL, '2014-09-16 12:16:03.666571+00', 'Waltz for Zoe', 3619, 5, 0, 0, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (6063, NULL, '2014-09-16 12:17:51.315472+00', 'Miss Hadden''s Reel', 3619, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (6064, NULL, '2014-09-16 12:18:15.379333+00', 'Postie''s Jig', 3619, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (6065, NULL, '2014-09-16 12:18:57.29936+00', 'Ring of Brodgar', 3619, 3, 4, 32, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (6066, NULL, '2014-09-16 12:19:45.616406+00', 'Dancing Bees, The', 3619, 1, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (6067, NULL, '2014-09-16 12:20:27.267734+00', 'Sleepy Maggie', 3619, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (6068, NULL, '2014-09-16 12:20:55.073763+00', 'Argyll''s Fancy', 3619, 2, 4, 48, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (6053, NULL, '2014-09-16 12:21:38.058032+00', 'Highlandman''s Umbrella', 3619, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (6078, NULL, '2012-01-20 12:55:35.978758+00', 'Haste to the Wedding', 3653, 2, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (6079, NULL, '2012-01-20 12:55:35.983554+00', 'College Hornpipe, The', 3653, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6080, NULL, '2012-01-20 12:55:35.988342+00', 'Mr Morrison', 3653, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (6081, NULL, '2012-01-20 12:55:35.99313+00', 'Alltshellach', 3653, 3, 8, 32, 9999, NULL, 499, 0, '');
INSERT INTO 'recording' VALUES (6082, NULL, '2012-01-20 12:55:35.997988+00', 'Mairrit Man''s Favourite, The', 3653, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (6083, NULL, '2012-01-20 12:55:36.00278+00', 'Bill''s Tadpoles', 3653, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (6084, NULL, '2012-01-20 12:55:36.007569+00', 'Let''s Have a Ceilidh', 2681, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (6085, NULL, '2012-01-20 12:55:36.012356+00', 'White Heather Jig, The', 2681, 2, 4, 40, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (6086, NULL, '2012-01-20 12:55:36.017139+00', 'Alltshellach', 2681, 3, 6, 32, 9999, NULL, 374, 0, '');
INSERT INTO 'recording' VALUES (6087, NULL, '2012-01-20 12:55:36.021925+00', 'Cadgers in the Canongate', 2681, 1, 8, 48, 9999, NULL, 429, 0, '');
INSERT INTO 'recording' VALUES (6088, NULL, '2012-01-20 12:55:36.026719+00', 'Garry Strathspey, The', 2681, 3, 4, 32, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (6089, NULL, '2012-01-20 12:55:36.031508+00', 'Australian Ladies, The', 2681, 1, 8, 32, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (6091, NULL, '2012-01-20 12:55:36.041077+00', 'Saint John River, The', 2681, 3, 4, 32, 9999, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (6092, NULL, '2012-01-20 12:55:36.045872+00', 'Celtic Dreaming', 2681, 1, 3, 40, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (6093, NULL, '2012-01-20 12:55:36.050689+00', 'Waltz Country Dance', 2681, 5, 4, 40, 9999, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (6094, NULL, '2012-01-20 12:55:36.05549+00', 'Lieutenant Zachary Hicks R.N.', 2681, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (6095, NULL, '2012-01-20 12:55:36.060438+00', 'Quaich, The', 2681, 3, 8, 32, 9999, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (6096, NULL, '2012-01-20 12:55:36.067149+00', 'Argyll''s Fancy', 2681, 2, 4, 48, 9999, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (6097, NULL, '2012-01-20 12:55:36.073387+00', 'Eightsome Reel, The', 2681, 1, 0, 464, 9999, NULL, 514, 0, '');
INSERT INTO 'recording' VALUES (6098, NULL, '2012-01-20 12:55:36.079805+00', 'Red House', 3039, 1, 8, 40, 9999, NULL, 338, 0, '');
INSERT INTO 'recording' VALUES (6099, NULL, '2012-01-20 12:55:36.086067+00', 'Linton Ploughman, The', 3039, 2, 8, 32, 9999, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (6102, NULL, '2012-01-20 12:55:36.10491+00', 'Russe, La', 3039, 1, 4, 64, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (6103, NULL, '2012-01-20 12:55:36.111227+00', 'Margaret Parker''s Strathspey', 3039, 3, 8, 32, 9999, NULL, 470, 0, '');
INSERT INTO 'recording' VALUES (6104, NULL, '2012-01-20 12:55:36.117831+00', 'Lord MacLay''s Reel', 3039, 1, 4, 40, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (6105, NULL, '2012-01-20 12:55:36.12406+00', 'Byron Strathspey, The', 3039, 3, 3, 32, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (6106, NULL, '2012-01-20 12:55:36.13113+00', 'Haunt of the Gnomes, The', 3039, 3, 0, 64, 9999, 8, 125, 0, '');
INSERT INTO 'recording' VALUES (6109, NULL, '2012-01-20 12:55:36.149869+00', 'Craigellachie Bridge', 3039, 3, 4, 32, 9999, NULL, 240, 0, '');
INSERT INTO 'recording' VALUES (6110, NULL, '2012-01-20 12:55:36.156095+00', 'Maureen''s Jig', 3039, 2, 8, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (6111, NULL, '2012-01-20 12:55:36.162365+00', 'Toast to St. Andrews, A', 3039, 1, 4, 48, 9999, NULL, 205, 1, '');
INSERT INTO 'recording' VALUES (6112, NULL, '2012-01-20 12:55:36.168589+00', 'Holyrood House', 3039, 2, 4, 48, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (6113, NULL, '2012-01-20 12:55:36.174833+00', 'Duke of Atholl''s Reel, The', 3217, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (6114, NULL, '2012-01-20 12:55:36.181088+00', 'Black Dance, The', 3217, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6116, NULL, '2012-01-20 12:55:36.193568+00', 'Round Reel of Eight', 3217, 1, 0, 88, 9999, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (6118, NULL, '2012-01-20 12:55:36.206112+00', 'Queen''s Bridge, The', 3217, 1, 4, 40, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (6119, NULL, '2012-01-20 12:55:36.212912+00', 'Baldovan Square', 3217, 3, 0, 96, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (6120, NULL, '2012-01-20 12:55:36.224965+00', 'Rakish Highlandman, The', 3217, 2, 8, 40, 9999, NULL, 338, 0, '');
INSERT INTO 'recording' VALUES (6121, NULL, '2012-01-20 12:55:36.231267+00', 'Sunlit Square', 3217, 3, 0, 64, 9999, NULL, 128, 0, '');
INSERT INTO 'recording' VALUES (6107, NULL, '2018-03-02 23:19:27.949791+00', 'John of Bon Accord', 3039, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (6123, NULL, '2012-01-20 12:55:36.24389+00', 'Lady in Red', 3217, 2, 5, 32, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (6124, NULL, '2012-01-20 12:55:36.250996+00', 'Longwise Eightsome Reel', 3217, 4, 0, 64, 5, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (6125, NULL, '2012-01-20 12:55:36.257243+00', 'Hogmanay Jig', 3217, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (6126, NULL, '2012-01-20 12:55:36.263496+00', 'Staffin Harvest', 3217, 3, 4, 32, 9999, NULL, 248, 0, '');
INSERT INTO 'recording' VALUES (6128, NULL, '2012-01-20 12:55:36.276213+00', 'Mason''s Apron, The', 3217, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6129, NULL, '2012-01-20 12:55:36.282475+00', 'My Mother''s Coming In', 3011, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6130, NULL, '2012-01-20 12:55:36.288718+00', 'I''ll Gang Nae Mair tae Yon Toon', 3011, 3, 8, 40, 9999, NULL, 615, 0, '');
INSERT INTO 'recording' VALUES (6131, NULL, '2012-01-20 12:55:36.294996+00', 'Campbell''s Frolic', 3011, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (6132, NULL, '2012-01-20 12:55:36.301247+00', 'Camp of Pleasure, The', 3011, 3, 8, 32, 9999, NULL, 500, 0, '');
INSERT INTO 'recording' VALUES (6133, NULL, '2012-01-20 12:55:36.307515+00', 'Gates of Edinburgh, The', 3011, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6134, NULL, '2012-01-20 12:55:36.313793+00', 'Lord Rosslyn''s Fancy', 3011, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (6135, NULL, '2012-01-20 12:55:36.320052+00', 'Lochiel''s Awa'' to France', 3011, 3, 8, 48, 9999, NULL, 734, 0, '');
INSERT INTO 'recording' VALUES (6136, NULL, '2012-01-20 12:55:36.326906+00', 'Middling, Thank You', 3011, 2, 8, 40, 9999, NULL, 344, 0, '');
INSERT INTO 'recording' VALUES (6137, NULL, '2012-01-20 12:55:36.333814+00', 'This is No'' My Ain Hoose', 3011, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (6138, NULL, '2012-01-20 12:55:36.340133+00', 'Argyll''s Bowling Green', 3011, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (6139, NULL, '2012-01-20 12:55:36.34639+00', 'Theekit House, The', 3011, 3, 8, 48, 9999, NULL, 740, 0, '');
INSERT INTO 'recording' VALUES (6140, NULL, '2012-01-20 12:55:36.352621+00', 'Waverley', 3011, 2, 8, 48, 9999, NULL, 406, 0, '');
INSERT INTO 'recording' VALUES (6141, NULL, '2012-01-20 12:55:36.358862+00', 'Reel for Jeannie, A', 3658, 1, 1, 32, 9999, NULL, 43, 0, '');
INSERT INTO 'recording' VALUES (6142, NULL, '2012-01-20 12:55:36.365091+00', 'Cumberland Reel', 3658, 2, 1, 32, 9999, NULL, 43, 0, '');
INSERT INTO 'recording' VALUES (6143, NULL, '2012-01-20 12:55:36.37139+00', 'Dhoon, The', 3658, 2, 1, 32, 9999, NULL, 43, 0, '');
INSERT INTO 'recording' VALUES (6101, NULL, '2019-11-18 00:52:03.526379+00', 'Dundee Reel', 3039, 2, 8, 40, 9999, NULL, 328, 0, '');
INSERT INTO 'recording' VALUES (6117, NULL, '2020-12-28 11:41:16.364485+00', 'New Ashludie Rant, The', 3217, 2, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (6090, NULL, '2019-11-19 12:47:12.605216+00', 'Scottish Reform', 2681, 2, 6, 32, 9999, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (6144, NULL, '2012-01-20 12:55:36.377612+00', 'Flying Scotsman, The', 3658, 2, 1, 32, 9999, NULL, 43, 0, '');
INSERT INTO 'recording' VALUES (6145, NULL, '2012-01-20 12:55:36.383842+00', 'Flying Scotsman, The', 3658, 2, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6146, NULL, '2012-01-20 12:55:36.390093+00', 'Jig for Mrs Dunn, A', 3658, 2, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6115, NULL, '2016-09-03 22:30:32.380907+00', 'Dance Illustrator, The', 3217, 3, 4, 32, 9999, NULL, 247, 0, '');
INSERT INTO 'recording' VALUES (8259, NULL, '2018-09-15 19:21:42.980769+00', 'Elephant''s Stampede, The', 3217, 2, 4, 48, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (6147, NULL, '2012-01-20 12:55:36.396313+00', 'Honeymoon, The', 3658, 1, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6149, NULL, '2012-01-20 12:55:36.408851+00', 'Papillon, Le', 3658, 2, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6150, NULL, '2012-01-20 12:55:36.415105+00', 'Galloway House', 3658, 1, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6151, NULL, '2012-01-20 12:55:36.42134+00', 'Kendall''s Hornpipe', 3658, 2, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6152, NULL, '2012-01-20 12:55:36.427604+00', 'Mrs Stewart''s Jig', 3658, 2, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6153, NULL, '2012-01-20 12:55:36.433847+00', 'Ways in New Hall', 3658, 1, 2, 32, 9999, NULL, 77, 0, '');
INSERT INTO 'recording' VALUES (6154, NULL, '2012-01-20 12:55:36.440088+00', 'De''il Amang the Tailors', 3658, 1, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6155, NULL, '2012-01-20 12:55:36.446337+00', 'Lady C Bruce''s Reel', 3658, 1, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6156, NULL, '2012-01-20 12:55:36.452576+00', 'Espie MacNabb', 3658, 2, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6157, NULL, '2012-01-20 12:55:36.45881+00', 'Duke of Perth, The', 3658, 1, 2, 32, 9999, NULL, 75, 0, '');
INSERT INTO 'recording' VALUES (6158, NULL, '2012-01-20 12:55:36.465045+00', 'Mrs MacLeod', 3658, 1, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6161, NULL, '2012-01-20 12:55:36.495181+00', 'Maids of Currie, The', 3658, 1, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6162, NULL, '2012-01-20 12:55:36.501369+00', 'Ladies'' Fancy', 3658, 2, 2, 32, 9999, NULL, 75, 0, '');
INSERT INTO 'recording' VALUES (6163, NULL, '2012-01-20 12:55:36.507701+00', 'Maxwell''s Rant', 3658, 1, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6164, NULL, '2012-01-20 12:55:36.51489+00', 'Express, The', 3658, 2, 2, 40, 9999, NULL, 92, 0, '');
INSERT INTO 'recording' VALUES (6165, NULL, '2012-01-20 12:55:36.527174+00', 'Flora, La', 3658, 2, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6166, NULL, '2012-01-20 12:55:36.53824+00', 'Lord Rosslyn''s Fancy', 3658, 2, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6167, NULL, '2012-01-20 12:55:36.545635+00', 'Cumbrae Reel, The', 3658, 1, 2, 32, 9999, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (6168, NULL, '2012-01-20 12:55:36.55225+00', 'Brechin Fancy', 3658, 1, 2, 32, 9999, NULL, 77, 0, '');
INSERT INTO 'recording' VALUES (6186, NULL, '2012-01-20 12:55:36.669338+00', '4x48 reel', 3185, 1, 4, 48, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (6188, NULL, '2012-01-20 12:55:36.682295+00', '48 bar strathspey/48 bar reel medley', 3185, 4, 0, 96, 11, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (6189, NULL, '2012-01-20 12:55:36.688654+00', '2x48 reel', 3185, 1, 2, 48, 9999, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (6190, NULL, '2012-01-20 12:55:36.695294+00', '88 bar jig', 3185, 2, 0, 88, 9999, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (6191, NULL, '2012-01-20 12:55:36.706617+00', 'Waltz Country Dance', 3185, 5, 0, 0, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (6192, NULL, '2012-01-20 12:55:36.713114+00', '160 bar set reel (or 5x32)', 3185, 1, 5, 32, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (6193, NULL, '2012-01-20 12:55:36.719522+00', '80 bar reel', 3185, 1, 0, 80, 9999, NULL, 96, 0, '');
INSERT INTO 'recording' VALUES (6194, NULL, '2012-01-20 12:55:36.726861+00', '80 bar strathspey', 3185, 3, 0, 80, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (6195, NULL, '2012-01-20 12:55:36.73292+00', '6x32 jig', 3185, 2, 6, 32, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (6197, NULL, '2012-01-20 12:55:36.744947+00', '120 bar set reel', 3185, 1, 0, 120, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6200, NULL, '2012-01-20 12:55:36.771319+00', '32 bar strathspey/32 bar reel', 3185, 4, 0, 64, 5, NULL, 107, 0, '');
INSERT INTO 'recording' VALUES (6201, NULL, '2012-01-20 12:55:36.77808+00', 'Selection of Reels', 3067, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (6202, NULL, '2012-01-20 12:55:36.784433+00', 'Isle, The', 3067, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6204, NULL, '2012-01-20 12:55:36.794831+00', 'Selection of Strathspeys', 3067, 3, 8, 32, 9999, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (6205, NULL, '2012-01-20 12:55:36.799623+00', 'Duke of Atholl''s Reel, The', 3067, 2, 6, 32, 9999, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (6206, NULL, '2012-01-20 12:55:36.805005+00', 'Selection of Reels', 3067, 1, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (6208, NULL, '2012-01-20 12:55:36.814637+00', 'Seann Truibhas Willichan', 3067, 3, 6, 32, 9999, NULL, 375, 0, '');
INSERT INTO 'recording' VALUES (6171, NULL, '2018-04-15 08:12:47.910573+00', 'Miss Betty Ferguson of Dumfries', 3019, 3, 4, 32, 9999, NULL, 255, 1, '');
INSERT INTO 'recording' VALUES (6211, NULL, '2012-01-20 12:55:36.829307+00', 'Betty Grant''s Strathspey', 3067, 3, 8, 32, 9999, NULL, 506, 0, '');
INSERT INTO 'recording' VALUES (6212, NULL, '2012-01-20 12:55:36.8341+00', 'Montgomeries'' Rant, The', 3067, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6214, NULL, '2012-01-20 12:55:36.843779+00', 'De''il Amang the Tailors, The', 3067, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6215, NULL, '2012-01-20 12:55:36.848742+00', 'Dancing Bells, The', 3067, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (6217, NULL, '2012-01-20 12:55:36.858418+00', 'Selection of Reels', 3067, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (6218, NULL, '2012-01-20 12:55:36.863292+00', 'Selection of Jigs', 3067, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (6220, NULL, '2012-01-20 12:55:36.872888+00', 'White Cockade, The', 3067, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (6221, NULL, '2012-01-20 12:55:36.877722+00', 'Galloping Carousel, The', 3067, 2, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (6223, NULL, '2012-01-20 12:55:36.888634+00', 'Selection of Reels/Marches', 3067, 4, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (6224, NULL, '2012-01-20 12:55:36.893577+00', 'Selection of Jigs', 3067, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6225, NULL, '2012-01-20 12:55:36.89901+00', 'Selection of Strathspeys', 3067, 3, 3, 32, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (6227, NULL, '2012-01-20 12:55:36.909079+00', 'Selection of Waltzes', 3067, 5, 6, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (6243, NULL, '2012-01-20 12:55:36.987645+00', 'Bill Jacob''s Jig', 3420, 2, 4, 32, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (6244, NULL, '2012-01-20 12:55:36.992442+00', 'Wedding Ring, The', 3420, 1, 5, 40, 9999, NULL, 231, 0, '');
INSERT INTO 'recording' VALUES (6239, NULL, '2012-10-18 12:43:31.219557+00', 'Strathspey', 3678, 3, 5, 40, 9999, NULL, 390, 0, '');
INSERT INTO 'recording' VALUES (6240, NULL, '2012-10-18 12:56:27.683259+00', 'Jig', 3678, 2, 6, 32, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (6241, NULL, '2012-10-18 13:08:16.008067+00', 'White Heather Jig, The', 3678, 2, 4, 40, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (6242, NULL, '2012-10-18 13:14:43.367175+00', 'Reel', 3678, 1, 7, 32, 9999, NULL, 247, 0, '');
INSERT INTO 'recording' VALUES (6228, NULL, '2012-10-18 13:19:05.747149+00', 'Reel', 3678, 1, 3, 32, 9999, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (6229, NULL, '2012-10-18 14:01:04.247318+00', 'Jig', 3678, 2, 3, 40, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (6231, NULL, '2012-10-18 14:29:37.735005+00', 'Reel', 3678, 1, 6, 32, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (6232, NULL, '2012-10-18 14:38:25.782783+00', 'Jig', 3678, 2, 3, 32, 9999, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (6234, NULL, '2012-10-18 14:53:30.698624+00', 'Medley', 3678, 4, 3, 64, 17, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (6235, NULL, '2012-10-18 14:56:43.080664+00', 'Barmkin, The', 3678, 1, 0, 88, 9999, NULL, 101, 0, '');
INSERT INTO 'recording' VALUES (6182, NULL, '2014-09-16 13:40:32.006393+00', 'Barton Barbecue', 3019, 1, 4, 32, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (6170, NULL, '2014-09-16 13:33:53.89663+00', 'White Rose and the Yellow Waistcoat, The', 3019, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (6172, NULL, '2014-09-16 13:34:46.025314+00', 'Horsewell''s Jig', 3019, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (6173, NULL, '2014-09-16 13:35:18.938054+00', 'Heatherbrae', 3019, 1, 0, 88, 9999, NULL, 100, 0, '');
INSERT INTO 'recording' VALUES (6209, NULL, '2019-11-19 09:33:25.655233+00', 'Selection of Reels', 3067, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (6233, NULL, '2020-01-25 23:31:05.481397+00', 'Lea Rig, The', 3678, 3, 8, 32, 9999, NULL, 522, 0, '');
INSERT INTO 'recording' VALUES (6203, NULL, '2020-02-25 07:25:52.713649+00', 'Selection of Reels', 3067, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6226, NULL, '2020-03-09 15:19:55.933136+00', 'Selection of Reels', 3067, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (6198, NULL, '2020-05-08 07:55:01.554579+00', '6x16 strathspey', 3185, 3, 6, 16, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (6199, NULL, '2020-04-28 11:45:07.395973+00', '8x40 bar jig', 3185, 2, 8, 40, 9999, NULL, 353, 0, '');
INSERT INTO 'recording' VALUES (6216, NULL, '2021-05-31 23:01:44.719494+00', 'Selection of Strathspeys', 3067, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (6222, NULL, '2021-11-05 20:26:48.417727+00', 'Selection of Strathspeys', 3067, 3, 4, 32, 9999, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (6160, NULL, '2021-11-27 10:56:06.346487+00', 'Reel of the 51st Division, The', 3658, 1, 2, 32, 9999, NULL, 81, 0, '');
INSERT INTO 'recording' VALUES (6159, NULL, '2021-11-27 10:56:43.819504+00', 'Scottish Reform', 3658, 2, 2, 32, 9999, NULL, 79, 0, '');
INSERT INTO 'recording' VALUES (6174, NULL, '2014-09-16 13:36:14.778515+00', 'We Twa Encore', 3019, 3, 8, 32, 9999, NULL, 519, 0, '');
INSERT INTO 'recording' VALUES (6175, NULL, '2014-09-16 13:36:46.827415+00', 'Renaissance', 3019, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (6196, NULL, '2017-09-26 14:41:29.035408+00', '4x16 strathspey/16 reel medley', 3185, 4, 4, 32, 1, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (6148, NULL, '2019-03-07 13:30:35.760766+00', 'Joe McDiarmid''s Jig', 3658, 2, 1, 32, 9999, NULL, 43, 0, '');
INSERT INTO 'recording' VALUES (6245, NULL, '2019-10-04 07:59:00.290418+00', 'Glenys Pearce''s Strathspey', 3420, 3, 4, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (6187, NULL, '2022-12-09 19:56:51.521808+00', '3x32 jig', 3185, 2, 3, 32, 9999, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (6176, NULL, '2014-09-16 13:37:27.987004+00', 'Dumfries Rambler', 3019, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (6178, NULL, '2014-09-16 13:38:31.817328+00', 'Sound of Cara, The', 3019, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6179, NULL, '2014-09-16 13:39:00.149898+00', 'Annan Reel, The', 3019, 1, 3, 32, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (6180, NULL, '2014-09-16 13:39:28.055481+00', 'Corstorphine Road', 3019, 3, 4, 32, 9999, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (6181, NULL, '2014-09-16 13:40:07.401252+00', 'Iain''s Obsession', 3019, 2, 8, 40, 9999, NULL, 344, 0, '');
INSERT INTO 'recording' VALUES (6183, NULL, '2014-09-16 13:40:59.81058+00', 'Rossway', 3019, 3, 3, 32, 9999, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (6185, NULL, '2014-09-16 13:41:52.651586+00', 'Slainte Mhor', 3019, 1, 0, 64, 9999, NULL, 74, 0, '');
INSERT INTO 'recording' VALUES (6207, NULL, '2014-10-04 02:31:02.094485+00', 'Linton Ploughman, The', 3067, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (6236, NULL, '2012-10-18 15:16:39.506357+00', 'Jig', 3678, 2, 7, 32, 9999, NULL, 247, 0, '');
INSERT INTO 'recording' VALUES (6237, NULL, '2012-10-18 15:24:26.448213+00', 'Reel', 3678, 1, 10, 32, 9999, NULL, 348, 0, '');
INSERT INTO 'recording' VALUES (6238, NULL, '2012-10-18 15:32:15.756153+00', 'Balcomie House', 3678, 2, 3, 48, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (6246, NULL, '2012-01-20 12:55:37.002319+00', 'Lochiel''s Farewell to Tony Szeto', 3420, 1, 8, 40, 9999, NULL, 368, 0, '');
INSERT INTO 'recording' VALUES (6247, NULL, '2012-01-20 12:55:37.008361+00', 'Miss Mary Gray''s Fancy', 3420, 3, 4, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (6248, NULL, '2012-01-20 12:55:37.013415+00', 'Rose Jacob''s Reel', 3420, 1, 8, 32, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (6249, NULL, '2012-01-20 12:55:37.018238+00', 'Simon Barbour''s Rant', 3420, 2, 8, 64, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (6250, NULL, '2012-01-20 12:55:37.023659+00', 'Candy Floss', 3420, 3, 8, 32, 9999, NULL, 514, 0, '');
INSERT INTO 'recording' VALUES (6251, NULL, '2012-01-20 12:55:37.028996+00', 'Artillery Port', 3420, 2, 6, 24, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (6252, NULL, '2012-01-20 12:55:37.033945+00', 'Dance of the Red Moon, The', 3420, 1, 4, 32, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (6253, NULL, '2012-01-20 12:55:37.038741+00', 'New Plymouth Strathspey, The', 3420, 3, 4, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (6254, NULL, '2012-01-20 12:55:37.043717+00', 'Cuddy Alang', 3420, 2, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (6255, NULL, '2012-01-20 12:55:37.048632+00', 'Odd Couple, The', 3420, 2, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (6256, NULL, '2012-01-20 12:55:37.053439+00', '4x32 Bar Reel', 3185, 1, 4, 32, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (6257, NULL, '2012-01-20 12:55:37.058242+00', '4x32 Bar Jig', 3185, 2, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (6258, NULL, '2012-01-20 12:55:37.06305+00', '8x32 Bar Reel', 3185, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6259, NULL, '2012-01-20 12:55:37.06794+00', '4x40 Bar Reel', 3185, 1, 4, 40, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (6260, NULL, '2012-01-20 12:55:37.072852+00', '3x32 Bar Strathspey', 3185, 3, 3, 32, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (6261, NULL, '2012-01-20 12:55:37.077753+00', '8x40 Bar Reel', 3185, 1, 8, 40, 9999, NULL, 350, 0, '');
INSERT INTO 'recording' VALUES (6262, NULL, '2012-01-20 12:55:37.082554+00', '5x32 Bar Reel', 3185, 1, 5, 32, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (6263, NULL, '2012-01-20 12:55:37.087445+00', '8x32 Bar Jig', 3185, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6264, NULL, '2012-01-20 12:55:37.092409+00', '4x48 Bar Reel', 3185, 1, 4, 48, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (6265, NULL, '2012-01-20 12:55:37.097222+00', '8x32 Bar Jig', 3185, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6266, NULL, '2012-01-20 12:55:37.102186+00', 'Waltz', 3185, 5, 0, 0, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (6267, NULL, '2012-01-20 12:55:37.10702+00', 'Chairman''s Strathspey, The', 3683, 3, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6268, NULL, '2012-01-20 12:55:37.111898+00', 'Old Harbour, The', 3683, 1, 0, 96, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6269, NULL, '2012-01-20 12:55:37.117558+00', 'Fiona Mackie''s Jig', 3683, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6270, NULL, '2012-01-20 12:55:37.12293+00', 'Cold Hands, Warm Heart', 3683, 3, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6271, NULL, '2012-01-20 12:55:37.12783+00', 'Fiona Paulin''s Bairns', 3683, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6272, NULL, '2012-01-20 12:55:37.132826+00', 'Jim Healy Jig, The', 3683, 2, 0, 48, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6273, NULL, '2012-01-20 12:55:37.137723+00', 'Tom McLeod''s Strathspey', 3683, 3, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6275, NULL, '2012-01-20 12:55:37.148028+00', 'V-C Jig, The', 3683, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6276, NULL, '2012-01-20 12:55:37.152881+00', 'Luke Brady''s Magical Music', 3683, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6277, NULL, '2012-01-20 12:55:37.157678+00', 'Kelloholm Jig, The', 3685, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6278, NULL, '2012-01-20 12:55:37.16247+00', 'Mrs Milne of Kinneff', 3685, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6279, NULL, '2012-01-20 12:55:37.167285+00', 'Broadford Bay', 3685, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6280, NULL, '2012-01-20 12:55:37.172189+00', 'Georgie''s Jig', 3685, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6281, NULL, '2012-01-20 12:55:37.176979+00', 'Wee Cooper o'' Fife, The', 9998, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6282, NULL, '2012-01-20 12:55:37.181772+00', 'Findlater Castle', 3023, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (6283, NULL, '2012-01-20 12:55:37.186559+00', 'Compliments to Mrs Jessie Bain', 3023, 3, 4, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (6284, NULL, '2012-01-20 12:55:37.191463+00', 'Birlin Birkie, The', 3023, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6285, NULL, '2012-01-20 12:55:37.196262+00', 'Braes of Strathlene, The', 3023, 3, 8, 32, 9999, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (6286, NULL, '2012-01-20 12:55:37.201406+00', 'Travelling to America', 3023, 1, 8, 40, 9999, NULL, 356, 0, '');
INSERT INTO 'recording' VALUES (6287, NULL, '2012-01-20 12:55:37.206471+00', 'Gourdieburn', 3023, 3, 3, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (6288, NULL, '2012-01-20 12:55:37.21138+00', 'Glenrothes, The', 3023, 2, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (6289, NULL, '2012-01-20 12:55:37.216313+00', 'Gourdieburn', 3023, 3, 3, 32, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (6292, NULL, '2012-01-20 12:55:37.231171+00', 'Glint of Gold, A', 3023, 3, 4, 32, 9999, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (6294, NULL, '2012-01-20 12:55:37.240784+00', 'Hills of Alba, The', 3023, 1, 4, 32, 9999, NULL, 150, 1, '');
INSERT INTO 'recording' VALUES (6295, NULL, '2012-01-20 12:55:37.245582+00', 'Hills of Alba, The', 3023, 1, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (6296, NULL, '2012-01-20 12:55:37.250409+00', 'Dance Set 1', 3023, 1, 4, 40, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (6297, NULL, '2012-01-20 12:55:37.256254+00', 'Dance Set 2', 3023, 3, 4, 40, 9999, NULL, 313, 0, '');
INSERT INTO 'recording' VALUES (6298, NULL, '2012-01-20 12:55:37.261109+00', 'Dance Set 3', 3023, 1, 5, 48, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (6314, NULL, '2015-03-24 12:02:28.112709+00', 'Bonnie Anne', 2566, 2, 1, 96, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (6312, NULL, '2015-03-24 11:58:49.6682+00', 'Saltire Society', 2566, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (6313, NULL, '2015-03-24 12:01:30.532063+00', 'Sauchie Haugh', 2566, 3, 8, 32, 9999, NULL, 490, 0, '');
INSERT INTO 'recording' VALUES (6315, NULL, '2015-03-24 12:03:28.813252+00', 'J.B. Milne', 2566, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (6184, NULL, '2018-04-15 08:14:29.677912+00', 'Let''s Celebrate', 3019, 2, 4, 40, 9999, NULL, 179, 1, '');
INSERT INTO 'recording' VALUES (6303, NULL, '2021-09-23 19:16:33.793233+00', 'Crieff Fair', 1396, 1, 8, 24, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (6310, NULL, '2021-09-23 19:12:50.796539+00', 'Lady Briest Knot, The', 1396, 3, 8, 16, 9999, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (6307, NULL, '2021-09-23 19:08:54.754004+00', 'Scots Bonnet, The', 1396, 2, 8, 32, 9999, 1, 276, 0, '');
INSERT INTO 'recording' VALUES (6304, NULL, '2021-09-23 18:58:08.972885+00', 'Shepherd''s Crook, The', 1396, 3, 8, 32, 9999, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (6302, NULL, '2021-09-23 19:01:45.603067+00', 'Lady Jean Murray''s Rant', 1396, 3, 8, 32, 9999, NULL, 506, 0, '');
INSERT INTO 'recording' VALUES (6301, NULL, '2021-09-23 19:03:05.526769+00', 'General Stuart''s Reel', 1396, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6300, NULL, '2021-09-23 19:04:20.565501+00', 'Infare, The', 1396, 3, 8, 16, 9999, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (6299, NULL, '2021-09-23 19:05:51.953977+00', 'Montgomeries'' Rant, The', 1396, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (6305, NULL, '2021-09-23 19:07:15.384641+00', 'Isle of Skye', 1396, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (6309, NULL, '2021-09-23 19:10:02.532237+00', 'Miss Mary Douglas', 1396, 2, 8, 48, 9999, NULL, 414, 0, '');
INSERT INTO 'recording' VALUES (6219, NULL, '2016-09-03 22:29:46.712995+00', 'George Washington Bridge, The', 3067, 3, 4, 32, 9999, NULL, 254, 0, '');
INSERT INTO 'recording' VALUES (6290, NULL, '2017-04-01 20:12:25.434318+00', 'Moranbank', 3023, 3, 8, 32, 9999, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (6291, NULL, '2019-03-19 01:35:32.488563+00', 'We''ve Nae Electric', 3023, 1, 5, 32, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (6293, NULL, '2014-10-19 15:54:54.199473+00', 'Tripitup Troupe, The', 3023, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (6339, NULL, '2012-01-20 12:55:37.467319+00', 'Luckenbooth Brooch', 3017, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (6341, NULL, '2012-01-20 12:55:37.477071+00', 'Monymusk', 3017, 3, 8, 32, 9999, NULL, 493, 0, '');
INSERT INTO 'recording' VALUES (6342, NULL, '2012-01-20 12:55:37.481879+00', 'Mrs Stewart''s Jig', 3017, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (6274, NULL, '2022-12-14 16:04:54.650722+00', 'Mary Currie''s Marryat Dances', 3683, 1, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6343, NULL, '2012-01-20 12:55:37.486656+00', 'Suitable for The Minister on the Loch', 3017, 3, 3, 32, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (6345, NULL, '2012-01-20 12:55:37.496197+00', 'Encore Duke of Perth', 3017, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (6346, NULL, '2012-01-20 12:55:37.500977+00', 'Catherine''s Waltz', 3017, 5, 0, 0, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (6347, NULL, '2012-01-20 12:55:37.505769+00', 'Pelorus Jack', 3017, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6349, NULL, '2012-01-20 12:55:37.51543+00', 'Montgomerie''s Rant', 3017, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (6351, NULL, '2012-01-20 12:55:37.525011+00', 'Suitable for the Barmkin', 3017, 1, 1, 88, 9999, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (6352, NULL, '2012-01-20 12:55:37.529784+00', 'John Hay''s Bonnie Lassie', 3017, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6353, NULL, '2012-01-20 12:55:37.534624+00', 'Gay Gordons', 3014, 11, 0, 16, 9999, NULL, 222, 0, '');
INSERT INTO 'recording' VALUES (6354, NULL, '2012-01-20 12:55:37.539421+00', 'Bell Ringer, The', 3014, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (6355, NULL, '2012-01-20 12:55:37.544204+00', 'Crossing the Tay', 3014, 3, 4, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (6356, NULL, '2012-01-20 12:55:37.548968+00', 'Wortham Manor', 3014, 1, 4, 48, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (6357, NULL, '2012-01-20 12:55:37.553767+00', 'Waltz', 3014, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6365, NULL, '2018-03-11 10:33:06.878595+00', 'Forever Friends', 3014, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (6359, NULL, '2012-01-20 12:55:37.563327+00', 'Farewell to the Highlands', 3014, 3, 4, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (6360, NULL, '2012-01-20 12:55:37.568114+00', 'Closeburn Lassies', 3014, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (6361, NULL, '2012-01-20 12:55:37.572891+00', 'Blackwater Reel, The', 3014, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (6362, NULL, '2012-01-20 12:55:37.577685+00', 'Double Top Jig, The', 3014, 2, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (6363, NULL, '2012-01-20 12:55:37.582469+00', 'Dornie Strathspey, The', 3014, 3, 8, 32, 9999, NULL, 516, 0, '');
INSERT INTO 'recording' VALUES (6364, NULL, '2012-01-20 12:55:37.587246+00', 'Two-step', 3014, 2, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (6366, NULL, '2012-01-20 12:55:37.596829+00', 'Catch the Wind', 3030, 1, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (6367, NULL, '2012-01-20 12:55:37.60163+00', 'Highland Fair/Muirland Willie', 3030, 2, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (6368, NULL, '2012-01-20 12:55:37.606414+00', 'Saint John River', 3030, 3, 4, 32, 9999, NULL, 254, 0, '');
INSERT INTO 'recording' VALUES (6369, NULL, '2012-01-20 12:55:37.611187+00', 'Dundee City Police Jig', 3030, 2, 3, 32, 9999, NULL, 103, 0, '');
INSERT INTO 'recording' VALUES (6370, NULL, '2012-01-20 12:55:37.61597+00', 'Fair Donald', 3030, 3, 8, 32, 9999, NULL, 486, 0, '');
INSERT INTO 'recording' VALUES (6371, NULL, '2012-01-20 12:55:37.620735+00', 'Piper and the Penguin', 3030, 1, 1, 88, 9999, NULL, 98, 0, '');
INSERT INTO 'recording' VALUES (6372, NULL, '2012-01-20 12:55:37.62552+00', 'Robertson Rant', 3030, 3, 1, 80, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (6373, NULL, '2012-01-20 12:55:37.630367+00', 'White Heather Jig', 3030, 2, 4, 40, 9999, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (6375, NULL, '2012-01-20 12:55:37.639955+00', 'Kangaroo Paw, The', 3217, 1, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (6377, NULL, '2012-01-20 12:55:37.649575+00', 'Christine''s Fancy', 3217, 3, 3, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (6379, NULL, '2012-01-20 12:55:37.65912+00', 'Torridon Lassies', 3217, 2, 8, 40, 9999, NULL, 348, 0, '');
INSERT INTO 'recording' VALUES (6380, NULL, '2012-01-20 12:55:37.663901+00', 'Glengarry Homestead, The', 3217, 3, 4, 32, 9999, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (6382, NULL, '2012-01-20 12:55:37.673464+00', 'Anne & Five Partners', 3217, 2, 5, 48, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (6384, NULL, '2012-01-20 12:55:37.683177+00', 'Avon Valley Strathspey, The', 3217, 3, 1, 80, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (6386, NULL, '2012-01-20 12:55:37.6928+00', 'One of a Kind', 3217, 4, 1, 120, 15, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (6387, NULL, '2012-01-20 12:55:37.697847+00', 'Flowers of the West', 3217, 3, 4, 40, 9999, NULL, 321, 0, '');
INSERT INTO 'recording' VALUES (6388, NULL, '2012-01-20 12:55:37.702678+00', 'Dancing Girls', 3217, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (6389, NULL, '2012-01-20 12:55:37.707508+00', 'Langleys Road', 3040, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (6390, NULL, '2012-01-20 12:55:37.712297+00', 'Outer Circle, The', 3040, 1, 8, 48, 9999, NULL, 423, 0, '');
INSERT INTO 'recording' VALUES (6391, NULL, '2012-01-20 12:55:37.717097+00', 'Cannadine Strathspey, The', 3040, 3, 4, 32, 9999, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (6392, NULL, '2012-01-20 12:55:37.721888+00', 'Physician''s Fancy, The', 3040, 2, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (6394, NULL, '2012-01-20 12:55:37.731471+00', 'Furth o'' Clyde', 3040, 3, 3, 32, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (6395, NULL, '2012-01-20 12:55:37.736249+00', 'Chocolate Factory, The', 3040, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (6396, NULL, '2012-01-20 12:55:37.741024+00', 'New Dixon Quadrille', 3040, 1, 4, 32, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (6397, NULL, '2012-01-20 12:55:37.745808+00', 'And Happy Meet Again', 3040, 3, 4, 32, 9999, NULL, 239, 0, '');
INSERT INTO 'recording' VALUES (6398, NULL, '2012-01-20 12:55:37.750589+00', 'Grumpy Gentleman, The', 3040, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (6399, NULL, '2012-01-20 12:55:37.755372+00', 'Floozie in the Jacuzzi, The', 3040, 1, 2, 48, 9999, NULL, 115, 0, '');
INSERT INTO 'recording' VALUES (6400, NULL, '2012-01-20 12:55:37.760141+00', 'Anita''s Dance', 3040, 3, 5, 32, 9999, NULL, 300, 0, '');
INSERT INTO 'recording' VALUES (6401, NULL, '2012-01-20 12:55:37.764912+00', 'South Street Harborne', 3040, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (6402, NULL, '2012-01-20 12:55:37.769746+00', 'Jewellery Quarter, The', 3040, 1, 4, 32, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (6403, NULL, '2012-01-20 12:55:37.774539+00', 'Second City Strathspey', 3040, 3, 8, 32, 9999, NULL, 470, 0, '');
INSERT INTO 'recording' VALUES (6404, NULL, '2012-01-20 12:55:37.779322+00', 'Red House Revisited', 3011, 1, 6, 40, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (6405, NULL, '2012-01-20 12:55:37.784116+00', 'Children of the Forest', 3011, 2, 3, 32, 9999, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (6406, NULL, '2012-01-20 12:55:37.788904+00', 'Lost in the Mist', 3011, 3, 8, 32, 9999, NULL, 526, 0, '');
INSERT INTO 'recording' VALUES (6407, NULL, '2012-01-20 12:55:37.793719+00', 'Lads and Lasses', 3011, 1, 1, 96, 9999, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (6408, NULL, '2012-01-20 12:55:37.799216+00', 'Reflections in the Lake', 3011, 2, 8, 32, 9999, 1, 282, 0, '');
INSERT INTO 'recording' VALUES (6329, NULL, '2014-09-16 09:12:18.381557+00', 'Airie Bennan', 2566, 2, 5, 32, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (6330, NULL, '2014-09-16 09:17:46.29056+00', 'Scotland''s Gardens', 2566, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6331, NULL, '2014-09-16 09:19:23.692834+00', 'Robertson Rant, The', 2566, 3, 1, 80, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (6325, NULL, '2015-03-24 12:26:22.502422+00', 'Diamond Jubilee, The', 2566, 2, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (6317, NULL, '2015-03-24 12:07:18.547591+00', 'Quarries'' Jig', 2566, 2, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (6321, NULL, '2015-03-24 12:18:59.418314+00', 'Irish Rover', 2566, 1, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (6319, NULL, '2015-03-24 12:13:06.506997+00', 'Bratach Bana', 2566, 1, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (6320, NULL, '2015-03-24 12:16:24.619415+00', 'From Scotia''s Shores', 2566, 3, 8, 32, 9999, NULL, 490, 0, '');
INSERT INTO 'recording' VALUES (6322, NULL, '2015-03-24 12:21:53.973352+00', 'Irish Rover (Reprise)', 2566, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (6323, NULL, '2015-03-24 12:23:24.589873+00', 'Seton''s Ceilidh Band', 2566, 2, 4, 64, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (6381, NULL, '2016-09-03 22:27:34.851364+00', 'Buckinghamshire Lass, The', 3217, 1, 4, 40, 9999, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (6376, NULL, '2020-12-28 11:34:11.646033+00', 'Open Road, The', 3217, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (6378, NULL, '2021-09-04 22:51:49.941342+00', 'Reeling Roy', 3217, 1, 4, 48, 9999, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (6393, NULL, '2018-01-18 13:15:03.33432+00', 'Saint Andrews Roundabout', 3040, 1, 4, 32, 9999, NULL, 152, 1, '');
INSERT INTO 'recording' VALUES (7338, NULL, '2018-09-15 23:41:14.018621+00', 'Calum''s Road (Rathad Chalum)', 3023, 3, 4, 32, NULL, NULL, 244, 0, '');
INSERT INTO 'recording' VALUES (6332, NULL, '2014-09-16 09:32:58.249685+00', 'Blooms of Bon Accord', 2566, 1, 4, 32, 9999, NULL, 146, 1, '');
INSERT INTO 'recording' VALUES (6335, NULL, '2014-09-16 08:38:25.460358+00', 'Jubilee Jig', 2566, 2, 0, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (6336, NULL, '2014-09-16 08:49:32.527253+00', 'Irish Rover', 2566, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (6337, NULL, '2014-09-16 08:51:06.651293+00', 'Any Jig', 2566, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (6338, NULL, '2014-09-16 08:51:35.923752+00', 'Summer Assembly', 2566, 1, 1, 88, 9999, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (6328, NULL, '2014-09-16 09:08:53.222747+00', 'Cadgers in the Canongate', 2566, 1, 8, 48, 9999, NULL, 410, 0, '');
INSERT INTO 'recording' VALUES (6409, NULL, '2012-01-20 12:55:37.804009+00', 'Grumpy John', 3011, 3, 4, 48, 9999, NULL, 394, 0, '');
INSERT INTO 'recording' VALUES (6350, NULL, '2022-08-19 22:03:13.399773+00', 'Set of Strathspeys', 3017, 3, 4, 32, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (6348, NULL, '2022-08-31 11:41:09.723812+00', 'Bedrule', 3017, 3, 8, 32, 9999, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (6383, NULL, '2022-12-19 16:23:48.108041+00', 'Anne & Five Partners (3 cpl encore)', 3217, 2, 3, 48, 9999, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (6318, NULL, '2022-12-12 23:06:58.039265+00', 'Jennifer''s Jig', 2566, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (6410, NULL, '2012-01-20 12:55:37.808794+00', 'Dancing on Water', 3011, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6411, NULL, '2012-01-20 12:55:37.813572+00', 'Morris Dancers, The', 3011, 2, 4, 40, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (6412, NULL, '2012-01-20 12:55:37.818339+00', 'Christmas Fling, A', 3011, 3, 5, 40, 9999, NULL, 414, 0, '');
INSERT INTO 'recording' VALUES (6413, NULL, '2012-01-20 12:55:37.823134+00', 'Quarry Bank Weavers', 3011, 1, 5, 40, 9999, NULL, 224, 0, '');
INSERT INTO 'recording' VALUES (6414, NULL, '2012-01-20 12:55:37.828024+00', 'Young Moira''s Real', 3011, 3, 8, 32, 9999, NULL, 537, 0, '');
INSERT INTO 'recording' VALUES (6415, NULL, '2012-01-20 12:55:37.832835+00', 'Return to Broadford Bay', 3011, 1, 6, 32, 9999, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (6416, NULL, '2012-01-20 12:55:37.837702+00', 'Birthday Honours', 3011, 3, 4, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (6417, NULL, '2012-01-20 12:55:37.842494+00', 'Welcome in Tokyo, A', 3011, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6420, NULL, '2012-01-20 12:55:37.856811+00', 'Gow Waltzes', 3030, 5, 0, 0, 9999, NULL, 308, 0, '');
INSERT INTO 'recording' VALUES (6421, NULL, '2012-01-20 12:55:37.861604+00', 'Purdy Pink Band Shoes', 3030, 2, 6, 32, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (6424, NULL, '2012-01-20 12:55:37.875952+00', 'Crawfords of Kerrera, The', 3040, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (6425, NULL, '2012-01-20 12:55:37.880828+00', 'Amstel Court', 3040, 3, 3, 32, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (6426, NULL, '2012-01-20 12:55:37.885643+00', 'First of September, The', 3040, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (6428, NULL, '2012-01-20 12:55:37.89522+00', 'Pawling in May', 3040, 3, 4, 32, 9999, NULL, 238, 0, '');
INSERT INTO 'recording' VALUES (6429, NULL, '2012-01-20 12:55:37.899997+00', 'Little Leigh', 3040, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6431, NULL, '2012-01-20 12:55:37.909986+00', 'Jig for Denise, A', 3040, 2, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (6432, NULL, '2012-01-20 12:55:37.914775+00', 'Nether Kellet', 3040, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (6433, NULL, '2012-01-20 12:55:37.919543+00', 'Green Ginger', 3040, 3, 8, 32, 9999, NULL, 486, 0, '');
INSERT INTO 'recording' VALUES (6435, NULL, '2012-01-20 12:55:37.929117+00', 'Rachel''s Strathspey', 3040, 3, 3, 32, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (6436, NULL, '2012-01-20 12:55:37.933996+00', 'Shinkansen (The Bullet Train)', 3040, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (6437, NULL, '2012-01-20 12:55:37.938794+00', 'Tammie Norie Jig', 3040, 2, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (6438, NULL, '2012-01-20 12:55:37.943575+00', 'Silver Halsway', 3040, 3, 4, 32, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (6439, NULL, '2012-01-20 12:55:37.948353+00', 'Committee Meeting, The', 3040, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (6440, NULL, '2012-01-20 12:55:37.953133+00', 'Argyll is my Name', 3747, 2, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (6441, NULL, '2012-01-20 12:55:37.957926+00', 'First of September, The', 1396, 1, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (6442, NULL, '2012-01-20 12:55:37.962707+00', 'White Rose of Scotland, The', 1396, 3, 8, 32, 9999, NULL, 493, 0, '');
INSERT INTO 'recording' VALUES (6443, NULL, '2012-01-20 12:55:37.96751+00', 'Nacton Hall', 1396, 1, 8, 40, 9999, NULL, 349, 0, '');
INSERT INTO 'recording' VALUES (6444, NULL, '2012-01-20 12:55:37.972299+00', 'Dancing Master, The', 2696, 2, 1, 96, 9999, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (6445, NULL, '2012-01-20 12:55:37.977077+00', 'Tom''s Friends', 2696, 3, 1, 96, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (6446, NULL, '2012-01-20 12:55:37.98186+00', 'Merry Uplanders, The', 2414, 2, 6, 32, 9999, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (6447, NULL, '2012-01-20 12:55:37.986752+00', 'Golden Harvest', 2414, 3, 4, 32, 9999, NULL, 253, 0, '');
INSERT INTO 'recording' VALUES (6448, NULL, '2012-01-20 12:55:37.991574+00', 'All for Mary', 3749, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6449, NULL, '2012-01-20 12:55:37.996418+00', 'Bydand', 3749, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (6450, NULL, '2012-01-20 12:55:38.001206+00', 'Jubilee Line, The', 3750, 1, 8, 48, 9999, NULL, 411, 0, '');
INSERT INTO 'recording' VALUES (6469, NULL, '2012-01-20 12:55:38.093201+00', 'St Andrews Welcomes Prince William', 3006, 2, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (6470, NULL, '2012-01-20 12:55:38.098006+00', 'Bejant Royal, The', 3006, 1, 8, 48, 9999, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (6488, NULL, '2012-01-20 12:55:38.179986+00', 'Yan, Tan, Tethera', 3045, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6489, NULL, '2012-01-20 12:55:38.184779+00', 'Craven Reel, The', 3045, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6490, NULL, '2012-01-20 12:55:38.189558+00', 'Ring of Brodgar, The', 3045, 3, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6491, NULL, '2012-01-20 12:55:38.194331+00', 'Domino Five', 3045, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6493, NULL, '2012-01-20 12:55:38.199125+00', 'Craven Jig, The', 3045, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6468, NULL, '2012-03-25 22:15:43.682186+00', 'Irene Bennett''s Strathspey', 3006, 3, 8, 32, 9999, NULL, 426, 0, '');
INSERT INTO 'recording' VALUES (6497, NULL, '2012-09-16 15:35:21.155638+00', 'Slow Air Strathspeys', 10659, 3, 4, 32, 9999, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (6496, NULL, '2012-09-16 15:35:21.160375+00', 'Christmas Jigs', 10659, 2, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (6495, NULL, '2012-09-16 15:35:21.164502+00', 'St Bernard Waltz', 10659, 5, 0, 16, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (6494, NULL, '2012-09-16 15:35:21.168617+00', 'Christmas Reels', 10659, 1, 5, 32, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (6453, NULL, '2014-09-16 09:51:08.689448+00', 'Marches', 1846, 11, 0, 0, 9999, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (6454, NULL, '2014-09-16 09:51:33.73729+00', 'Waltzes', 1846, 5, 0, 0, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (6456, NULL, '2014-09-16 09:52:43.847339+00', 'Set of Strathspeys', 1846, 3, 8, 32, 9999, NULL, 513, 0, '');
INSERT INTO 'recording' VALUES (6458, NULL, '2014-09-16 09:53:26.467293+00', 'Rovin'' Robin', 1846, 1, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (6459, NULL, '2014-09-16 09:53:46.585569+00', 'Sands of Morar', 1846, 3, 8, 32, 9999, NULL, 514, 0, '');
INSERT INTO 'recording' VALUES (6434, NULL, '2015-08-25 09:59:18.712745+00', 'Island Celebration', 3040, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (6418, NULL, '2016-09-03 20:32:01.203354+00', 'Lucky Pieces of Eight', 3011, 1, 3, 32, 9999, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (6422, NULL, '2018-01-22 13:31:47.965544+00', 'Miss Rowan Davies', 3030, 5, 0, 0, 9999, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (6457, NULL, '2017-01-27 18:55:37.831567+00', 'Dominie, The', 1846, 2, 4, 32, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (6451, NULL, '2017-03-10 21:30:56.708434+00', 'Miss McLean of Inverness', 3750, 3, 4, 32, 9999, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (6374, NULL, '2018-01-22 13:30:38.950438+00', 'Drunken Sailor', 3030, 1, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (6423, NULL, '2018-01-22 13:34:44.183302+00', 'Feisty Women', 3030, 1, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (6430, NULL, '2019-08-30 19:10:36.744966+00', 'Montparnasse', 3040, 3, 4, 32, 9999, NULL, 248, 0, '');
INSERT INTO 'recording' VALUES (6334, NULL, '2019-09-30 22:15:54.065955+00', 'Sailor, The', 2566, 1, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (6460, NULL, '2014-09-16 09:54:04.283949+00', 'Set of Jigs', 1846, 2, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (6461, NULL, '2014-09-16 09:54:21.041084+00', 'Arctic Circle, The', 1846, 1, 1, 64, 9999, NULL, 86, 0, '');
INSERT INTO 'recording' VALUES (6462, NULL, '2014-09-16 09:54:54.86798+00', 'Set of Strathspeys', 1846, 3, 4, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (6464, NULL, '2014-09-16 09:55:48.633172+00', 'Set of Reels', 1846, 1, 8, 32, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (6465, NULL, '2014-09-16 09:56:15.587802+00', 'Air', 1846, 98, 0, 0, 9999, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (6508, NULL, '2012-01-20 12:55:38.304003+00', 'Kathleen McAdam''s Scroll', 10000, 2, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6472, NULL, '2022-08-21 16:40:41.169786+00', 'Let''s Have a Ceilidh', 3030, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (6474, NULL, '2022-08-21 16:44:06.292779+00', 'Postie''s Jig', 3030, 2, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (6476, NULL, '2022-08-21 16:47:03.48062+00', 'Dundee Whaler, The', 3030, 3, 4, 32, 9999, NULL, 247, 0, '');
INSERT INTO 'recording' VALUES (6485, NULL, '2022-08-21 17:05:34.994446+00', 'Lass o'' Lowrie, The', 3030, 5, 0, 0, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (6484, NULL, '2022-08-21 16:50:09.136188+00', 'Gallant Forty Twa, The', 3030, 2, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (6483, NULL, '2022-08-21 16:53:41.072856+00', 'Lady Davidson', 3030, 3, 3, 40, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (6478, NULL, '2022-08-21 16:54:55.077423+00', 'Airie Bennan', 3030, 2, 5, 32, 9999, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (6477, NULL, '2022-08-21 17:01:52.462454+00', 'Australian Ladies', 3030, 1, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (6482, NULL, '2022-08-21 17:09:01.311122+00', 'Silver Spire, The', 3030, 1, 8, 40, 9999, NULL, 342, 0, '');
INSERT INTO 'recording' VALUES (6480, NULL, '2022-08-21 17:13:16.921298+00', 'Seton''s Ceilidh Band', 3030, 2, 4, 64, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (6481, NULL, '2022-08-21 17:17:56.443359+00', 'Winding Road, The', 3030, 3, 4, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (6475, NULL, '2022-08-21 17:20:17.174952+00', 'Irish Rover, The', 3030, 1, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (6486, NULL, '2022-08-21 17:22:36.909432+00', 'Marching Home', 3030, 11, 0, 0, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (6452, NULL, '2022-08-31 16:46:47.265778+00', 'London Reel', 3751, 1, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (6487, NULL, '2022-12-19 18:09:05.125597+00', 'Maureen''s Reel', 3045, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6498, NULL, '2023-02-16 13:56:08.989327+00', 'Christmas Irish Reels', 10659, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (6509, NULL, '2012-01-20 12:55:38.308066+00', 'Music Makars, The', 10000, 1, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6510, NULL, '2012-01-20 12:55:38.31215+00', 'Tulloch Gorm', 10000, 3, 8, 32, NULL, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (6511, NULL, '2012-01-20 12:55:38.316212+00', 'J.B. Milne', 10000, 1, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (6512, NULL, '2012-01-20 12:55:38.320556+00', 'MacDonald of the Isles', 10000, 3, 3, 32, NULL, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (6513, NULL, '2012-01-20 12:55:38.324673+00', 'Hamilton Rant, The', 10000, 1, 8, 48, NULL, NULL, 404, 0, '');
INSERT INTO 'recording' VALUES (6514, NULL, '2012-01-20 12:55:38.328739+00', 'Teresita Waltz', 10000, 5, 0, 0, NULL, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (6515, NULL, '2012-01-20 12:55:38.332797+00', 'White Heather Jig, The', 10000, 2, 4, 40, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (6516, NULL, '2012-01-20 12:55:38.33686+00', 'Scotch Mist', 10000, 3, 5, 32, NULL, NULL, 320, 0, '');
INSERT INTO 'recording' VALUES (6517, NULL, '2012-01-20 12:55:38.340921+00', 'Blue Moon Rendezvous', 10000, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6466, NULL, '2018-07-30 10:25:58.078752+00', 'Iona Cross', 1846, 4, 0, 192, 3, NULL, 298, 0, '');
INSERT INTO 'recording' VALUES (6519, NULL, '2012-01-20 12:55:38.349733+00', 'Asilomar Romantic', 10000, 3, 8, 32, NULL, 5, 517, 0, '');
INSERT INTO 'recording' VALUES (6520, NULL, '2012-01-20 12:55:38.353833+00', 'Reel of the Royal Scots, The', 10000, 1, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6521, NULL, '2012-01-20 12:55:38.357898+00', 'Mrs. Frances MacCullough', 10008, 1, 8, 32, NULL, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (6522, NULL, '2012-01-20 12:55:38.362004+00', 'MacDonald of the Isles', 10008, 3, 5, 32, NULL, NULL, 334, 0, '');
INSERT INTO 'recording' VALUES (6524, NULL, '2012-01-20 12:55:38.370147+00', 'Montréal Rendezvous', 10008, 1, 8, 32, NULL, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (6525, NULL, '2012-01-20 12:55:38.374279+00', 'Mòran Taing', 10008, 3, 8, 32, NULL, NULL, 523, 0, '');
INSERT INTO 'recording' VALUES (6526, NULL, '2012-01-20 12:55:38.378459+00', 'Montréal Anniversary Jig', 10008, 2, 4, 32, NULL, NULL, 150, 1, '');
INSERT INTO 'recording' VALUES (6527, NULL, '2012-01-20 12:55:38.382527+00', 'Happy To Meet You Charlie', 10008, 3, 4, 32, NULL, NULL, 269, 1, '');
INSERT INTO 'recording' VALUES (6529, NULL, '2012-01-20 12:55:38.39073+00', 'Yet Another Birthday', 10008, 3, 3, 32, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (6530, NULL, '2012-01-20 12:55:38.394799+00', 'Lydia''s Dance', 10008, 1, 8, 40, NULL, NULL, 354, 0, '');
INSERT INTO 'recording' VALUES (6531, NULL, '2012-01-20 12:55:38.398883+00', 'Waltz', 10008, 5, 0, 0, NULL, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (6532, NULL, '2012-01-20 12:55:38.402953+00', 'Deil amang the Tailors, The', 2586, 1, 8, 32, NULL, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (6534, NULL, '2012-01-20 12:55:38.411074+00', 'Deuks Dang O''er my Daddie, The', 2586, 2, 8, 40, NULL, NULL, 370, 0, '');
INSERT INTO 'recording' VALUES (6535, NULL, '2012-01-20 12:55:38.41519+00', 'John of Bon Accord', 2586, 1, 8, 32, NULL, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (6536, NULL, '2012-01-20 12:55:38.419261+00', 'Sauchie Haugh, The', 2586, 3, 8, 32, NULL, NULL, 529, 0, '');
INSERT INTO 'recording' VALUES (6537, NULL, '2012-01-20 12:55:38.423322+00', 'Ladies'' Fancy', 2586, 2, 8, 32, NULL, NULL, 300, 0, '');
INSERT INTO 'recording' VALUES (6538, NULL, '2012-01-20 12:55:38.427421+00', 'None So Pretty', 2586, 1, 8, 40, NULL, NULL, 365, 0, '');
INSERT INTO 'recording' VALUES (6539, NULL, '2012-01-20 12:55:38.431491+00', 'Miss Ogilvie''s Fancy', 2586, 3, 8, 32, NULL, NULL, 536, 0, '');
INSERT INTO 'recording' VALUES (6540, NULL, '2012-01-20 12:55:38.435547+00', 'Holyrood House', 2586, 2, 4, 48, NULL, NULL, 225, 0, '');
INSERT INTO 'recording' VALUES (6541, NULL, '2012-01-20 12:55:38.439607+00', 'Dancing Years, The', 2586, 1, 1, 88, NULL, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (6542, NULL, '2012-01-20 12:55:38.443671+00', 'Jean Martin of Aberdeen', 2586, 3, 3, 32, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (6506, NULL, '2012-09-16 15:35:21.073925+00', 'Slow Waltz', 10659, 5, 0, 0, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (6505, NULL, '2012-09-16 15:35:21.100531+00', 'Canadian Barn Dance or Polka', 10659, 13, 0, 0, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (6504, NULL, '2012-09-16 15:35:21.125766+00', 'Christmas Irish Jigs', 10659, 2, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (6503, NULL, '2012-09-16 15:35:21.130006+00', 'Gay Gordons', 10659, 11, 0, 16, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (6501, NULL, '2012-09-16 15:35:21.138902+00', 'Boston Two Step', 10659, 50, 0, 16, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (6500, NULL, '2012-09-16 15:35:21.143021+00', 'Christmas Reels', 10659, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (6499, NULL, '2012-09-16 15:35:21.147274+00', 'Waltz Country Dance', 10659, 5, 0, 40, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (6543, NULL, '2012-01-20 12:55:38.447772+00', 'Reel of the Royal Scots', 2586, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (6544, NULL, '2012-01-20 12:55:38.451918+00', 'Todlen Hame', 2586, 2, 6, 32, NULL, NULL, 228, 0, '');
INSERT INTO 'recording' VALUES (6545, NULL, '2012-01-20 12:55:38.455984+00', 'Sugar Candie', 2586, 3, 8, 32, NULL, NULL, 538, 0, '');
INSERT INTO 'recording' VALUES (6546, NULL, '2012-01-20 12:55:38.460068+00', 'Dancing Bees/More Bees A-Dancing, The', 2586, 1, 8, 32, NULL, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (6547, NULL, '2012-01-20 12:55:38.464132+00', 'Light and Airy', 2586, 2, 8, 32, NULL, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (6548, NULL, '2012-01-20 12:55:38.468193+00', 'Well Kent', 2586, 3, 3, 32, NULL, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (6549, NULL, '2012-01-20 12:55:38.472252+00', 'Red House', 2586, 1, 8, 40, NULL, NULL, 362, 0, '');
INSERT INTO 'recording' VALUES (6550, NULL, '2012-01-20 12:55:38.478121+00', 'Wisp of Thistle, A', 2586, 3, 8, 32, NULL, NULL, 525, 0, '');
INSERT INTO 'recording' VALUES (6552, NULL, '2012-01-20 12:55:38.486758+00', 'Blue Bonnets', 2586, 2, 8, 32, NULL, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (6553, NULL, '2012-01-20 12:55:38.490869+00', 'Barmkin, The', 2586, 1, 1, 88, NULL, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (6554, NULL, '2012-01-20 12:55:38.495612+00', 'Minister on the Loch, The', 2586, 3, 3, 32, NULL, 5, 206, 0, '');
INSERT INTO 'recording' VALUES (6556, NULL, '2012-01-20 12:55:38.503767+00', 'Knit the Pocky', 3049, 1, 8, 32, NULL, NULL, 302, 0, '');
INSERT INTO 'recording' VALUES (6558, NULL, '2012-01-20 12:55:38.511917+00', 'Johnny McGill', 3049, 2, 8, 40, NULL, NULL, 367, 0, '');
INSERT INTO 'recording' VALUES (6559, NULL, '2012-01-20 12:55:38.51598+00', 'Inch of Perth', 3049, 3, 8, 32, NULL, NULL, 480, 0, '');
INSERT INTO 'recording' VALUES (6560, NULL, '2012-01-20 12:55:38.520037+00', 'Sleepy Maggie', 3049, 1, 8, 32, NULL, NULL, 310, 0, '');
INSERT INTO 'recording' VALUES (6561, NULL, '2012-01-20 12:55:38.524098+00', 'Dainty Davie', 3049, 3, 8, 16, NULL, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (6562, NULL, '2012-01-20 12:55:38.528181+00', 'Moudiewort, The', 3049, 2, 8, 32, NULL, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (6563, NULL, '2012-01-20 12:55:38.532239+00', 'Long Chase, The', 3049, 1, 8, 64, NULL, NULL, 591, 0, '');
INSERT INTO 'recording' VALUES (6564, NULL, '2012-01-20 12:55:38.53629+00', 'Glasgow Flourish', 3049, 3, 8, 32, NULL, NULL, 487, 0, '');
INSERT INTO 'recording' VALUES (6565, NULL, '2012-01-20 12:55:38.540356+00', 'Invercauld''s Reel', 3049, 3, 8, 32, NULL, NULL, 490, 0, '');
INSERT INTO 'recording' VALUES (6567, NULL, '2012-01-20 12:55:38.548467+00', 'Miss Murray of Ochtertyre', 3049, 1, 8, 16, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (6568, NULL, '2012-01-20 12:55:38.552533+00', 'Jute Spinner''s Reel', 3032, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6569, NULL, '2012-01-20 12:55:38.556608+00', 'Hall Change', 3032, 2, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (6570, NULL, '2012-01-20 12:55:38.560663+00', 'Glasgow Lasses', 3032, 3, 8, 32, NULL, NULL, 477, 0, '');
INSERT INTO 'recording' VALUES (6571, NULL, '2012-01-20 12:55:38.564721+00', 'Unicef Circle, The', 3032, 1, 1, 88, NULL, NULL, 101, 0, '');
INSERT INTO 'recording' VALUES (6572, NULL, '2012-01-20 12:55:38.568784+00', 'Express, The', 3032, 2, 8, 40, NULL, NULL, 341, 0, '');
INSERT INTO 'recording' VALUES (6573, NULL, '2012-01-20 12:55:38.572844+00', 'Mrs Milne of Kinneff', 3032, 3, 4, 32, NULL, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (6574, NULL, '2012-01-20 12:55:38.576898+00', 'Stuck in the Snow', 3032, 1, 5, 32, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (6575, NULL, '2012-01-20 12:55:38.580953+00', 'Airdrie Lassies', 3032, 2, 4, 48, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (6576, NULL, '2012-01-20 12:55:38.584997+00', 'Dancing in the Street', 3032, 1, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (6578, NULL, '2012-01-20 12:55:38.593364+00', 'Lochalsh Reel, The', 3032, 1, 8, 40, NULL, NULL, 344, 0, '');
INSERT INTO 'recording' VALUES (6551, NULL, '2016-09-04 15:26:53.367933+00', 'Engine Room, The', 2586, 1, 8, 32, NULL, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (6577, NULL, '2017-10-17 00:03:33.842169+00', 'Heather Dewar''s Strathspey', 3032, 3, 4, 32, NULL, NULL, 248, 0, '');
INSERT INTO 'recording' VALUES (6507, NULL, '2018-11-08 12:16:25.870414+00', 'Christmas Reels', 10659, 1, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (6502, NULL, '2020-08-29 11:18:42.120698+00', 'Christmas Strathspeys', 10659, 3, 3, 32, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (6566, NULL, '2021-07-31 04:55:13.091022+00', 'Rakes of Glasgow', 3049, 3, 8, 32, NULL, NULL, 490, 0, '');
INSERT INTO 'recording' VALUES (6528, NULL, '2014-04-21 19:24:15.932357+00', 'Cruit Mo Chridh', 10008, 1, 8, 32, NULL, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (6580, NULL, '2014-09-16 11:45:11.921199+00', 'Major Ian Stewart', 3032, 2, 8, 32, NULL, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (6557, NULL, '2014-11-01 14:24:03.80787+00', 'Monymusk', 3049, 3, 8, 32, NULL, NULL, 474, 0, '');
INSERT INTO 'recording' VALUES (6583, NULL, '2012-01-20 12:55:38.613705+00', 'Royal Albert Country Dance', 10018, 1, 8, 32, NULL, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (6584, NULL, '2012-01-20 12:55:38.617797+00', 'Glasgow Lasses', 10018, 3, 8, 32, NULL, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (6585, NULL, '2012-01-20 12:55:38.6219+00', 'Niel Gow''s Farewell to Whisky', 10018, 1, 5, 48, NULL, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (6586, NULL, '2012-01-20 12:55:38.62597+00', 'Over The Water To Charlie', 10018, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6587, NULL, '2012-01-20 12:55:38.630116+00', 'New Scotia Quadrille', 10018, 1, 2, 48, NULL, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (6588, NULL, '2012-01-20 12:55:38.634226+00', 'Couteraller''s Rant', 10018, 3, 8, 32, NULL, NULL, 494, 0, '');
INSERT INTO 'recording' VALUES (6589, NULL, '2012-01-20 12:55:38.638284+00', 'Open The Door To Three', 10018, 2, 8, 48, NULL, NULL, 423, 0, '');
INSERT INTO 'recording' VALUES (6590, NULL, '2012-01-20 12:55:38.642345+00', 'New Scotia Quadrille (Encore)', 10018, 1, 2, 48, NULL, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (6592, NULL, '2012-01-20 12:55:38.650474+00', 'Jean Martin of Aberdeen', 10018, 3, 3, 32, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (6593, NULL, '2012-01-20 12:55:38.65456+00', 'Inimitable Derek, The', 10018, 1, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (6594, NULL, '2012-01-20 12:55:38.658786+00', 'Bromley Brae Reels', 10020, 1, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (6595, NULL, '2012-01-20 12:55:38.663617+00', 'Wise Maid Set', 10022, 4, 1, 344, 10001, NULL, 432, 0, '');
INSERT INTO 'recording' VALUES (6596, NULL, '2012-01-20 12:55:38.670021+00', 'J.B. Milne', 10023, 1, 8, 32, NULL, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (6598, NULL, '2012-01-20 12:55:38.681639+00', 'Horsbrough Set', 10022, 4, 1, 288, 10002, NULL, 376, 0, '');
INSERT INTO 'recording' VALUES (6655, NULL, '2018-03-02 23:20:27.390345+00', 'MacLeod''s Fancy', 3023, 2, 4, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (6600, NULL, '2012-01-20 12:55:38.691221+00', 'PM Donald Maclean of Lewis', 10022, 11, 0, 0, NULL, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (6601, NULL, '2012-01-20 12:55:38.695465+00', 'Mo''s Peerie Boston', 10023, 2, 8, 32, NULL, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (6602, NULL, '2012-01-20 12:55:38.69964+00', 'Dance Called Irene, A', 10023, 3, 4, 32, NULL, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (6603, NULL, '2012-01-20 12:55:38.704406+00', 'Miss Hannah''s Set', 10022, 4, 1, 288, 10003, NULL, 375, 0, '');
INSERT INTO 'recording' VALUES (6604, NULL, '2012-01-20 12:55:38.708489+00', 'Fair Donald', 10020, 3, 8, 32, NULL, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (6605, NULL, '2012-01-20 12:55:38.713263+00', 'Fosgail An Dorus Set', 10022, 4, 1, 256, 10004, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (6606, NULL, '2012-01-20 12:55:38.717384+00', 'Lachlan Dhu', 10022, 98, 0, 0, NULL, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (6607, NULL, '2012-01-20 12:55:38.722198+00', 'Ewie wi'' the Crooked Horn Set', 10022, 4, 1, 160, 10005, NULL, 234, 0, '');
INSERT INTO 'recording' VALUES (6608, NULL, '2012-01-20 12:55:38.726292+00', 'Lament for the Cut Finger', 1054, 5, 0, 0, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (6609, NULL, '2012-01-20 12:55:38.731055+00', 'Because He was a Bonnie Lad', 3015, 4, 1, 112, 19, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (6611, NULL, '2012-01-20 12:55:38.739233+00', 'Earl of Errol''s Reel, The', 3015, 2, 1, 200, NULL, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (6612, NULL, '2012-01-20 12:55:38.743293+00', 'Hebridean Weaving Lilt', 3015, 3, 1, 112, NULL, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (6613, NULL, '2012-01-20 12:55:38.747342+00', 'Kelvingrove', 3015, 3, 1, 152, NULL, NULL, 317, 0, '');
INSERT INTO 'recording' VALUES (6614, NULL, '2012-01-20 12:55:38.75142+00', 'Lamont of Inveryne', 3015, 1, 1, 208, NULL, NULL, 241, 0, '');
INSERT INTO 'recording' VALUES (6615, NULL, '2012-01-20 12:55:38.755501+00', 'MacDonald of Sleat', 3015, 2, 1, 120, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (6616, NULL, '2012-01-20 12:55:38.759565+00', 'McLaine of Lochbuie', 3015, 1, 1, 176, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (6617, NULL, '2012-01-20 12:55:38.763633+00', 'MacLeod of Harris', 3015, 1, 1, 144, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (6618, NULL, '2012-01-20 12:55:38.767699+00', 'McNichol of the Black Isle', 3015, 1, 1, 104, NULL, NULL, 126, 0, '');
INSERT INTO 'recording' VALUES (6619, NULL, '2012-01-20 12:55:38.771802+00', 'Miss Fiona Macrae of Conchra', 3015, 3, 1, 64, NULL, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (6620, NULL, '2012-01-20 12:55:38.776624+00', 'Shepherd''s Crook, The', 3015, 2, 1, 72, NULL, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (6622, NULL, '2012-01-20 12:55:38.784822+00', 'Earl of Errol''s Reel, The', 1793, 2, 1, 200, NULL, NULL, 241, 0, '');
INSERT INTO 'recording' VALUES (6623, NULL, '2012-01-20 12:55:38.788892+00', 'Bonnie Anne', 3015, 2, 1, 96, NULL, NULL, 119, 0, '');
INSERT INTO 'recording' VALUES (6624, NULL, '2012-01-20 12:55:38.792949+00', 'Brig O'' Doon', 3015, 3, 1, 96, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (6625, NULL, '2012-01-20 12:55:38.797015+00', 'Jeannie o'' the Witchin'' E''e', 3015, 2, 8, 40, NULL, NULL, 378, 0, '');
INSERT INTO 'recording' VALUES (6628, NULL, '2012-01-20 12:55:38.809181+00', 'Lerwick Reel, The', 3015, 3, 1, 128, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (6629, NULL, '2012-01-20 12:55:38.813353+00', 'Lochanside', 3015, 5, 1, 72, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (6630, NULL, '2012-01-20 12:55:38.817438+00', 'MacLeod of Dunvegan', 3015, 1, 1, 136, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (6631, NULL, '2012-01-20 12:55:38.821555+00', 'Moulin Dhu', 3015, 3, 1, 120, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (6632, NULL, '2012-01-20 12:55:38.82633+00', 'McNeil of Barra', 3015, 4, 1, 144, 18, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (6633, NULL, '2012-01-20 12:55:38.830435+00', 'Over the Dee and Over the Don', 3015, 2, 1, 152, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (6634, NULL, '2012-01-20 12:55:38.834497+00', 'Rothesay at the Fair', 3015, 1, 1, 240, NULL, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (6635, NULL, '2012-01-20 12:55:38.838561+00', 'Royal Salute, The', 3015, 1, 1, 112, NULL, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (6636, NULL, '2012-01-20 12:55:38.84263+00', 'Rouken Glen', 3015, 3, 1, 72, NULL, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (6638, NULL, '2012-01-20 12:55:38.850857+00', 'Duke of Gordon''s Welcome to Aberdeen', 1793, 1, 1, 176, NULL, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (6639, NULL, '2012-01-20 12:55:38.855349+00', 'Miss Johnstone of Ardrossan', 3023, 1, 5, 32, NULL, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (6642, NULL, '2012-01-20 12:55:38.867676+00', 'Hazel Tree, The', 3023, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (6663, NULL, '2018-03-22 16:12:37.15991+00', 'Autumn in Appin', 10034, 3, 4, 32, NULL, NULL, 264, 1, '');
INSERT INTO 'recording' VALUES (6645, NULL, '2012-01-20 12:55:38.879873+00', 'Father Connelly''s Jig', 3023, 2, 4, 64, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (6646, NULL, '2012-01-20 12:55:38.883934+00', 'Tullich Hornpipe, The', 3023, 6, 4, 32, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (6649, NULL, '2012-01-20 12:55:38.896245+00', 'Kelpie of Loch Coruisk, The', 3023, 1, 7, 32, NULL, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (6652, NULL, '2012-01-20 12:55:38.908934+00', 'Dream Catcher, The', 3023, 3, 1, 96, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (6653, NULL, '2012-01-20 12:55:38.913035+00', 'Royal Deeside Railway', 3023, 1, 8, 32, NULL, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (6654, NULL, '2012-01-20 12:55:38.917098+00', 'Set for 4x32 Strathspey', 3023, 3, 4, 32, NULL, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (6656, NULL, '2012-01-20 12:55:38.925223+00', 'Inimitable Derek, The', 3023, 1, 8, 32, NULL, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (6657, NULL, '2012-01-20 12:55:38.92931+00', 'EH3 7AF', 10034, 2, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6658, NULL, '2012-01-20 12:55:38.933377+00', 'On the Quarter-Deck', 10034, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6659, NULL, '2012-01-20 12:55:38.937447+00', 'Minister On the Loch, The', 10034, 3, 3, 32, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (6660, NULL, '2012-01-20 12:55:38.941753+00', 'Major Ian Stewart', 10034, 2, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6661, NULL, '2012-01-20 12:55:38.945828+00', 'Eileen Watt''s Reel', 10034, 1, 3, 32, NULL, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (6662, NULL, '2012-01-20 12:55:38.949895+00', 'Eileen Watt''s Reel', 10034, 1, 3, 32, NULL, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (6665, NULL, '2012-01-20 12:55:38.962143+00', 'Salute to Miss Milligan', 10034, 1, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (6641, NULL, '2018-03-22 18:14:24.421167+00', 'Autumn in Appin', 3023, 3, 4, 32, NULL, NULL, 261, 1, '');
INSERT INTO 'recording' VALUES (6610, NULL, '2018-12-11 00:16:58.2409+00', 'Braes of Balquhidder, The', 3015, 3, 1, 128, NULL, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (6647, NULL, '2019-09-01 22:12:27.725517+00', 'Orkney Reel, The', 3023, 1, 1, 96, NULL, NULL, 117, 0, '');
INSERT INTO 'recording' VALUES (6555, NULL, '2019-10-28 11:42:28.910315+00', 'Fight About the Fireside', 2586, 1, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (6666, NULL, '2012-01-20 12:55:38.966211+00', 'Up in the Air', 10034, 3, 8, 32, NULL, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (6621, NULL, '2014-03-19 15:52:55.032175+00', 'St Andrews Nicht', 3015, 2, 4, 48, NULL, NULL, 227, 0, '');
INSERT INTO 'recording' VALUES (6597, NULL, '2019-11-22 19:27:53.317421+00', 'Cate''s Conundrum', 10022, 3, 3, 32, NULL, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (6650, NULL, '2019-11-16 17:38:39.601763+00', 'Waltz Country Dance', 3023, 5, 4, 40, NULL, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (6582, NULL, '2020-06-05 17:20:45.705218+00', 'C''est L''Amour/The Flirt', 10018, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6651, NULL, '2021-05-27 19:33:33.962977+00', 'Brisk Young Lad, The', 3023, 2, 5, 48, NULL, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (6664, NULL, '2014-10-19 16:07:18.182778+00', 'Midnight Oil', 10034, 2, 5, 48, NULL, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (6667, NULL, '2012-01-20 12:55:38.970274+00', 'Reverend John Macfarlane, The', 10034, 1, 4, 32, NULL, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (6668, NULL, '2012-01-20 12:55:38.974349+00', 'Reverend John Macfarlane, The', 10034, 1, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (6669, NULL, '2012-01-20 12:55:38.978422+00', 'Dean Bridge of Edinburgh, The', 10034, 3, 8, 32, NULL, NULL, 501, 0, '');
INSERT INTO 'recording' VALUES (6670, NULL, '2012-01-20 12:55:38.982488+00', 'Saint Andrew''s Fair', 10034, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (6648, NULL, '2012-05-06 22:04:05.188816+00', 'Sands of Morar', 3023, 3, 8, 32, NULL, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (6672, NULL, '2012-01-20 12:55:38.990687+00', 'Broadford Bay', 10034, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (6673, NULL, '2012-01-20 12:55:38.994758+00', 'Mrs Stewart''s Jig', 3137, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6675, NULL, '2012-01-20 12:55:39.0029+00', 'Argyll Strathspey', 3137, 3, 8, 32, NULL, NULL, 509, 0, '');
INSERT INTO 'recording' VALUES (6676, NULL, '2012-01-20 12:55:39.006984+00', 'Major Ian Stewart', 3137, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6677, NULL, '2012-01-20 12:55:39.011051+00', 'Gentleman, The', 3137, 3, 8, 32, NULL, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (6591, NULL, '2022-12-09 19:56:15.525496+00', 'Craven Jig, The', 10018, 2, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (6626, NULL, '2022-12-21 15:00:06.790953+00', 'Laird O'' Dochart''s Reel', 3015, 2, 1, 80, NULL, NULL, 102, 0, '');
INSERT INTO 'recording' VALUES (6640, NULL, '2022-12-22 13:49:15.322758+00', 'Nurseryman, The', 3023, 2, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6679, NULL, '2012-01-20 12:55:39.019167+00', 'Saint Andrews Gardens', 3137, 2, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6680, NULL, '2012-01-20 12:55:39.023239+00', 'Summer Assembly, The', 3137, 1, 1, 88, NULL, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (6681, NULL, '2012-01-20 12:55:39.027301+00', 'Summer Assembly, The', 3137, 1, 1, 88, NULL, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (6682, NULL, '2012-01-20 12:55:39.031402+00', 'Willie With His Tartan Trews', 10037, 2, 8, 40, NULL, NULL, 348, 0, '');
INSERT INTO 'recording' VALUES (6683, NULL, '2012-01-20 12:55:39.035481+00', 'Grant''s Reel', 10037, 3, 8, 32, NULL, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (6684, NULL, '2012-01-20 12:55:39.039548+00', 'Push About The Jorum', 10037, 1, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6685, NULL, '2012-01-20 12:55:39.043618+00', 'Crooket Horned Ewie, The', 10037, 3, 8, 32, NULL, NULL, 492, 0, '');
INSERT INTO 'recording' VALUES (6686, NULL, '2012-01-20 12:55:39.047684+00', 'Miss Nancy Frowns', 10037, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (6688, NULL, '2012-01-20 12:55:39.055874+00', 'Deil Amang the Tailors, The', 10037, 1, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6690, NULL, '2012-01-20 12:55:39.064051+00', 'What a Beau My Granny Was', 10037, 1, 8, 32, NULL, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (6691, NULL, '2012-01-20 12:55:39.068201+00', 'Bonniest Lass in All the World, The', 10037, 3, 8, 40, NULL, NULL, 625, 0, '');
INSERT INTO 'recording' VALUES (6719, NULL, '2018-04-03 20:37:42.859135+00', 'Reel of the 51st Division, The', 3011, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6694, NULL, '2012-01-20 12:55:39.080494+00', 'Catch the Wind', 10034, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6695, NULL, '2012-01-20 12:55:39.084563+00', 'Muirland Willie', 10034, 2, 8, 32, NULL, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (6697, NULL, '2012-01-20 12:55:39.092842+00', 'Reel of the Royal Scots, The', 10034, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6698, NULL, '2012-01-20 12:55:39.096963+00', 'Inchmickery', 10034, 2, 5, 32, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (6699, NULL, '2012-01-20 12:55:39.101028+00', 'Jean Martin of Aberdeen', 10034, 3, 3, 32, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (6700, NULL, '2012-01-20 12:55:39.10539+00', 'Earl of Mansfield, The', 10034, 1, 4, 48, NULL, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (6701, NULL, '2012-01-20 12:55:39.109486+00', 'Streets of Milan', 10034, 2, 8, 32, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (6702, NULL, '2012-01-20 12:55:39.11358+00', 'Miss Gibson''s Strathspey', 10034, 3, 8, 32, NULL, NULL, 487, 0, '');
INSERT INTO 'recording' VALUES (6703, NULL, '2012-01-20 12:55:39.117665+00', 'Mrs Stewart''s Jig', 10034, 2, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (6705, NULL, '2012-01-20 12:55:39.125854+00', 'Gentleman, The', 10034, 3, 8, 32, NULL, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (6706, NULL, '2012-01-20 12:55:39.129921+00', 'Portnacraig', 10034, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6707, NULL, '2012-01-20 12:55:39.133981+00', 'Cabbages and Kings', 10034, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6708, NULL, '2012-01-20 12:55:39.138035+00', 'Strathmore', 10034, 3, 4, 40, NULL, NULL, 308, 0, '');
INSERT INTO 'recording' VALUES (6710, NULL, '2012-01-20 12:55:39.146163+00', 'Duran Ranger, The', 3011, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (6711, NULL, '2012-01-20 12:55:39.150233+00', 'Miss Cahoon''s Reel', 3011, 2, 8, 48, NULL, NULL, 421, 0, '');
INSERT INTO 'recording' VALUES (6712, NULL, '2012-01-20 12:55:39.154325+00', 'Mrs Stewart''s Strathspey', 3011, 3, 8, 48, NULL, NULL, 762, 0, '');
INSERT INTO 'recording' VALUES (6713, NULL, '2012-01-20 12:55:39.159158+00', 'Barley Bree', 3011, 2, 4, 40, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (6714, NULL, '2012-01-20 12:55:39.163551+00', 'Highland Reel, The', 3011, 1, 5, 32, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (6715, NULL, '2012-01-20 12:55:39.170232+00', 'Kiss for Nothing, A', 3011, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (6716, NULL, '2012-01-20 12:55:39.190921+00', 'Nether Bow Has Vanished, The', 3011, 3, 8, 48, NULL, NULL, 759, 0, '');
INSERT INTO 'recording' VALUES (6717, NULL, '2012-01-20 12:55:39.196606+00', 'Fly Not Yet', 3011, 2, 8, 48, NULL, NULL, 424, 0, '');
INSERT INTO 'recording' VALUES (6718, NULL, '2012-01-20 12:55:39.202515+00', 'Strathglass House', 3011, 3, 8, 32, NULL, NULL, 500, 0, '');
INSERT INTO 'recording' VALUES (6720, NULL, '2012-01-20 12:55:39.213386+00', 'Bridge of Nairn', 3011, 3, 8, 32, NULL, NULL, 500, 0, '');
INSERT INTO 'recording' VALUES (6721, NULL, '2012-01-20 12:55:39.219261+00', 'Ladies'' Fancy', 3011, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (6722, NULL, '2012-01-20 12:55:39.224635+00', 'White Cockade, The', 3030, 1, 8, 32, NULL, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (6723, NULL, '2012-01-20 12:55:39.230009+00', 'Napier''s Index', 3030, 2, 8, 40, NULL, NULL, 360, 0, '');
INSERT INTO 'recording' VALUES (6724, NULL, '2012-01-20 12:55:39.235358+00', 'Langholm Fair', 3030, 3, 3, 32, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (6725, NULL, '2012-01-20 12:55:39.2407+00', 'Sailor, The', 3030, 1, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (6726, NULL, '2012-01-20 12:55:39.246073+00', 'Light and Airy', 3030, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6727, NULL, '2012-01-20 12:55:39.251418+00', 'Silver Tassie, The', 3030, 3, 8, 32, NULL, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (6728, NULL, '2012-01-20 12:55:39.25677+00', 'Starry Eyed Lassie, The', 3030, 2, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6729, NULL, '2012-01-20 12:55:39.262136+00', 'Music Makars, The', 3030, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (6730, NULL, '2012-01-20 12:55:39.267483+00', 'Music Makars, The', 3030, 1, 4, 32, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (6731, NULL, '2012-01-20 12:55:39.273683+00', 'Cauld Kail in Aberdeen', 3030, 4, 8, 32, 1, NULL, 396, 0, '');
INSERT INTO 'recording' VALUES (6732, NULL, '2012-01-20 12:55:39.279049+00', 'Polharrow Burn', 3030, 1, 5, 32, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (6733, NULL, '2012-01-20 12:55:39.284396+00', 'Braes of Tulliemet, The', 3030, 3, 8, 32, NULL, NULL, 501, 0, '');
INSERT INTO 'recording' VALUES (6734, NULL, '2012-01-20 12:55:39.289759+00', 'Silver Spire, The', 3030, 1, 8, 40, NULL, NULL, 353, 0, '');
INSERT INTO 'recording' VALUES (6735, NULL, '2012-01-20 12:55:39.295327+00', 'Bobby Brown''s Canadian Breakdown', 3030, 1, 4, 32, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (6736, NULL, '2012-01-20 12:55:39.300728+00', 'Neidpath Castle', 3030, 3, 3, 32, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (6737, NULL, '2012-01-20 12:55:39.306203+00', 'Mrs Stewart''s Jig', 3030, 2, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6738, NULL, '2012-01-20 12:55:39.311558+00', 'Mairi''s Wedding', 3030, 1, 8, 40, NULL, NULL, 348, 0, '');
INSERT INTO 'recording' VALUES (6739, NULL, '2012-01-20 12:55:39.316898+00', 'Mairi''s Wedding', 3030, 1, 4, 40, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (6740, NULL, '2012-01-20 12:55:39.322326+00', 'Auld Lang Syne', 3030, 98, 0, 0, NULL, NULL, 119, 0, '');
INSERT INTO 'recording' VALUES (6741, NULL, '2012-01-20 12:55:39.328517+00', 'Bluebell Flowers', 1836, 4, 1, 112, 2, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (6743, NULL, '2012-01-20 12:55:39.339252+00', 'Canberra Bluebell, The', 1836, 3, 1, 80, NULL, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (6744, NULL, '2012-01-20 12:55:39.344596+00', 'Celebration Reel', 1836, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6745, NULL, '2012-01-20 12:55:39.349951+00', 'Cherry Blossoms', 1836, 3, 4, 32, NULL, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (6746, NULL, '2012-01-20 12:55:39.355291+00', 'Chrysanthemum', 1836, 1, 1, 96, NULL, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (6747, NULL, '2012-01-20 12:55:39.361492+00', 'Highland Games Medley', 1836, 4, 1, 96, 42, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (6748, NULL, '2012-01-20 12:55:39.366867+00', 'Jig for Yukio, A', 1836, 2, 3, 40, NULL, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (6749, NULL, '2012-01-20 12:55:39.372226+00', 'Kindred Spirits', 1836, 1, 4, 32, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (6750, NULL, '2012-01-20 12:55:39.377592+00', 'Lady of Tokai', 1836, 3, 4, 32, NULL, NULL, 244, 0, '');
INSERT INTO 'recording' VALUES (6751, NULL, '2012-01-20 12:55:39.382964+00', 'MacDonald of the Eastern Isles', 1836, 3, 3, 32, NULL, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (6687, NULL, '2014-11-01 14:54:30.185108+00', 'Keep the Country Bonnie Lassie', 10037, 3, 8, 40, NULL, NULL, 619, 0, '');
INSERT INTO 'recording' VALUES (6689, NULL, '2014-11-01 15:02:22.67262+00', 'She''s Ower Young to Marry Yet', 10037, 3, 8, 32, NULL, NULL, 493, 0, '');
INSERT INTO 'recording' VALUES (6674, NULL, '2014-11-18 00:36:04.344397+00', 'Inverneill House', 3137, 1, 8, 32, NULL, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (6678, NULL, '2014-11-18 01:02:41.391923+00', 'Trysting Place, The', 3137, 3, 8, 32, NULL, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (6752, NULL, '2012-01-20 12:55:39.38849+00', 'Mist on the Mountain', 1836, 3, 8, 32, NULL, NULL, 511, 0, '');
INSERT INTO 'recording' VALUES (6753, NULL, '2012-01-20 12:55:39.393855+00', 'Rampant Unicorn Jig, The', 1836, 2, 8, 32, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (6754, NULL, '2012-01-20 12:55:39.399217+00', 'Rampant Unicorn Strathspey, The', 1836, 3, 8, 32, NULL, NULL, 486, 0, '');
INSERT INTO 'recording' VALUES (6755, NULL, '2012-01-20 12:55:39.404562+00', 'To Be a Wind', 1836, 2, 5, 32, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (6742, NULL, '2012-03-07 12:58:39.900302+00', 'Bluebell Reel, The', 1836, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6756, NULL, '2012-01-20 12:55:39.409921+00', 'Beside the Seaside', 3420, 2, 6, 32, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (6757, NULL, '2012-01-20 12:55:39.416217+00', 'Dhoon, The', 3420, 2, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (6759, NULL, '2012-01-20 12:55:39.430035+00', 'Song of the Sea', 3420, 3, 4, 32, NULL, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (6760, NULL, '2012-01-20 12:55:39.435406+00', 'Come Ashore, Jolly Tar', 3420, 1, 4, 32, NULL, NULL, 224, 0, '');
INSERT INTO 'recording' VALUES (6761, NULL, '2012-01-20 12:55:39.44078+00', 'Fugal Fergus', 3420, 2, 8, 48, NULL, NULL, 419, 0, '');
INSERT INTO 'recording' VALUES (6762, NULL, '2012-01-20 12:55:39.448041+00', 'Beach Dancer', 3420, 2, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (6763, NULL, '2012-01-20 12:55:39.453423+00', 'Fisherman''s Reel', 3420, 1, 5, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (6764, NULL, '2012-01-20 12:55:39.458798+00', 'Sailor, The', 3420, 1, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (6693, NULL, '2022-12-09 19:58:16.961592+00', 'Lamb Skinnet', 10037, 2, 8, 32, NULL, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (6704, NULL, '2022-12-14 16:01:13.229351+00', 'Miss Johnstone of Ardrossan', 10034, 1, 5, 32, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (6766, NULL, '2012-01-20 12:55:39.469516+00', 'On the Edge of the Sand', 3420, 1, 8, 32, NULL, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (6767, NULL, '2012-01-20 12:55:39.474868+00', 'Culla Bay', 3420, 3, 4, 32, NULL, NULL, 248, 0, '');
INSERT INTO 'recording' VALUES (6768, NULL, '2012-01-20 12:55:39.480204+00', 'Pelorus Jack', 3420, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6769, NULL, '2012-01-20 12:55:39.485558+00', 'Ship O'' Grace', 3420, 3, 4, 40, NULL, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (6770, NULL, '2012-01-20 12:55:39.490922+00', 'Crossing the Ohiwa Bar', 3420, 2, 4, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (6771, NULL, '2012-01-20 12:55:39.496489+00', 'Mairi''s Wedding', 3420, 1, 8, 40, NULL, NULL, 351, 0, '');
INSERT INTO 'recording' VALUES (6772, NULL, '2012-01-20 12:55:39.501857+00', 'Collichur', 3006, 2, 8, 32, NULL, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (6773, NULL, '2012-01-20 12:55:39.507205+00', 'Hame Came Our Gudeman', 3006, 3, 8, 32, NULL, NULL, 511, 0, '');
INSERT INTO 'recording' VALUES (6774, NULL, '2012-01-20 12:55:39.512568+00', 'Highland Lass, The', 3006, 1, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6775, NULL, '2012-01-20 12:55:39.517928+00', 'Bawk, The', 3006, 2, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (6776, NULL, '2012-01-20 12:55:39.523287+00', 'Man''s a Man for A'' That, A', 3006, 3, 8, 32, NULL, NULL, 510, 0, '');
INSERT INTO 'recording' VALUES (6777, NULL, '2012-01-20 12:55:39.528661+00', 'Guidman of Balangigh, The', 3006, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (6780, NULL, '2012-01-20 12:55:39.544857+00', 'Fugal Fergus', 3006, 2, 8, 48, NULL, NULL, 418, 0, '');
INSERT INTO 'recording' VALUES (6781, NULL, '2012-01-20 12:55:39.550247+00', 'John McAlpin', 3006, 3, 8, 32, NULL, NULL, 510, 0, '');
INSERT INTO 'recording' VALUES (6783, NULL, '2012-01-20 12:55:39.560962+00', 'Miss Murray of Lintrose', 2944, 1, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6786, NULL, '2012-01-20 12:55:39.577165+00', 'Burns'' Hornpipe', 2944, 1, 4, 32, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (6787, NULL, '2012-01-20 12:55:39.58254+00', 'Tayport Beauty', 2944, 2, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6788, NULL, '2012-01-20 12:55:39.587889+00', 'Sally''s Fancy', 2944, 3, 8, 32, NULL, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (6789, NULL, '2012-01-20 12:55:39.593252+00', 'Round Reel of Eight', 2944, 1, 1, 88, NULL, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (6790, NULL, '2012-01-20 12:55:39.600353+00', 'Reel of Five', 2944, 4, 1, 64, 5, NULL, 107, 0, '');
INSERT INTO 'recording' VALUES (6791, NULL, '2012-01-20 12:55:39.605748+00', 'Seann Truibhas Willichan', 2944, 3, 8, 32, NULL, NULL, 517, 0, '');
INSERT INTO 'recording' VALUES (6792, NULL, '2012-01-20 12:55:39.611109+00', 'Flora, La', 2944, 2, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6794, NULL, '2012-01-20 12:55:39.621807+00', 'Auld Lang Syne', 2944, 3, 8, 32, NULL, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (6795, NULL, '2012-01-20 12:55:39.62717+00', 'Round Reel of Eight', 2944, 1, 1, 88, NULL, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (6796, NULL, '2012-01-20 12:55:39.633381+00', 'Reel of Five', 2944, 4, 1, 64, 5, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (6797, NULL, '2012-01-20 12:55:39.638762+00', 'Knit the Pocky', 3049, 1, 8, 32, NULL, NULL, 303, 0, '');
INSERT INTO 'recording' VALUES (6798, NULL, '2012-01-20 12:55:39.644119+00', 'Monymusk', 3049, 3, 8, 32, NULL, NULL, 474, 0, '');
INSERT INTO 'recording' VALUES (6799, NULL, '2012-01-20 12:55:39.649466+00', 'Johnny McGill', 3049, 2, 8, 40, NULL, NULL, 367, 0, '');
INSERT INTO 'recording' VALUES (6800, NULL, '2012-01-20 12:55:39.654833+00', 'Inch of Perth', 3049, 3, 8, 32, NULL, NULL, 481, 0, '');
INSERT INTO 'recording' VALUES (6801, NULL, '2012-01-20 12:55:39.66035+00', 'Sleepy Maggie', 3049, 1, 8, 32, NULL, NULL, 301, 0, '');
INSERT INTO 'recording' VALUES (6802, NULL, '2012-01-20 12:55:39.665714+00', 'Dainty Dave', 3049, 3, 8, 16, NULL, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (6803, NULL, '2012-01-20 12:55:39.671059+00', 'Moudiewort, The', 3049, 2, 8, 32, NULL, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (6804, NULL, '2012-01-20 12:55:39.676398+00', 'Long Chase, The', 3049, 1, 8, 64, NULL, NULL, 592, 0, '');
INSERT INTO 'recording' VALUES (6805, NULL, '2012-01-20 12:55:39.68208+00', 'Glasgow Flourish', 3049, 3, 8, 32, NULL, NULL, 487, 0, '');
INSERT INTO 'recording' VALUES (6806, NULL, '2012-01-20 12:55:39.687432+00', 'Invercauld''s Reel', 3049, 3, 8, 32, NULL, NULL, 491, 0, '');
INSERT INTO 'recording' VALUES (6807, NULL, '2012-01-20 12:55:39.692781+00', 'Rakes of Glasgow', 3049, 3, 8, 32, NULL, NULL, 491, 0, '');
INSERT INTO 'recording' VALUES (6808, NULL, '2012-01-20 12:55:39.698538+00', 'Miss Murray of Ochtertyre', 3049, 1, 8, 16, NULL, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (6810, NULL, '2012-01-20 12:55:39.709267+00', 'Up in the Air', 3045, 3, 8, 32, NULL, NULL, 496, 0, '');
INSERT INTO 'recording' VALUES (6812, NULL, '2012-01-20 12:55:39.71997+00', 'Village Reel', 3045, 3, 8, 32, NULL, NULL, 489, 0, '');
INSERT INTO 'recording' VALUES (6813, NULL, '2012-01-20 12:55:39.725312+00', 'Miss Burns''s Reel', 3045, 1, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (6815, NULL, '2012-01-20 12:55:39.736013+00', 'Drummer, The', 3045, 1, 8, 48, NULL, NULL, 416, 0, '');
INSERT INTO 'recording' VALUES (6816, NULL, '2012-01-20 12:55:39.741364+00', 'Miss Ogilvie''s Fancy', 3045, 3, 8, 32, NULL, NULL, 486, 0, '');
INSERT INTO 'recording' VALUES (6817, NULL, '2012-01-20 12:55:39.746744+00', 'Miss Jessie Dalrymple''s Reel', 3045, 1, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (6819, NULL, '2012-01-20 12:55:39.758557+00', 'Express, The', 3045, 2, 8, 40, NULL, NULL, 347, 0, '');
INSERT INTO 'recording' VALUES (6820, NULL, '2012-01-20 12:55:39.763994+00', 'College Hornpipe, The', 3045, 1, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (6823, NULL, '2012-09-16 15:40:26.919773+00', 'Calver Lodge', 10659, 1, 8, 24, NULL, NULL, 221, 0, '');
INSERT INTO 'recording' VALUES (6822, NULL, '2012-09-16 15:40:26.924134+00', 'Peggy''s Love', 10659, 3, 8, 32, NULL, NULL, 501, 0, '');
INSERT INTO 'recording' VALUES (6821, NULL, '2012-09-16 15:40:26.928318+00', 'Tulloch Gorm', 10659, 3, 8, 32, NULL, NULL, 483, 0, '');
INSERT INTO 'recording' VALUES (6833, NULL, '2012-01-20 12:55:39.83412+00', 'New Rigged Ship, The', 10047, 2, 8, 48, NULL, NULL, 409, 0, '');
INSERT INTO 'recording' VALUES (6835, NULL, '2012-01-20 12:55:39.844858+00', 'Madge Wildfire''s Strathspey', 10047, 3, 8, 32, NULL, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (6836, NULL, '2012-01-20 12:55:39.850274+00', 'Cadgers in the Canongate', 10047, 1, 8, 48, NULL, NULL, 422, 0, '');
INSERT INTO 'recording' VALUES (6837, NULL, '2012-01-20 12:55:39.856476+00', 'Cauld Kail', 10047, 4, 8, 32, 1, NULL, 400, 0, '');
INSERT INTO 'recording' VALUES (6839, NULL, '2012-01-20 12:55:39.867213+00', 'Eileen Watt''s Reel', 10047, 1, 3, 32, NULL, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (6840, NULL, '2012-01-20 12:55:39.87256+00', 'Eileen Watt''s Strathspey', 10047, 3, 3, 32, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (6841, NULL, '2012-01-20 12:55:39.878769+00', 'Trip to Lorient, A', 10047, 4, 1, 128, 2, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (6842, NULL, '2012-01-20 12:55:39.884149+00', 'Miss Clemy Stewart''s Reel', 10046, 1, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (6830, NULL, '2012-09-16 15:40:26.886703+00', 'Lassie wi'' the Yellow Coatie', 10659, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (6831, NULL, '2014-11-01 02:54:36.381828+00', 'Tibby Fowler o'' the Glen', 10659, 3, 8, 32, NULL, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (6784, NULL, '2014-11-17 01:05:45.304736+00', 'Nineteenth of December', 2944, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6785, NULL, '2014-11-17 02:02:47.015719+00', 'Duchess of York', 2944, 3, 8, 32, NULL, NULL, 510, 0, '');
INSERT INTO 'recording' VALUES (6778, NULL, '2014-11-17 22:12:26.590346+00', 'Cadies Lady, The', 3006, 1, 8, 40, NULL, NULL, 352, 0, '');
INSERT INTO 'recording' VALUES (6782, NULL, '2014-11-17 23:44:30.137135+00', 'Polharrow Burn', 3006, 1, 5, 32, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (6758, NULL, '2015-09-16 11:36:24.626873+00', 'Lobster in the Pot', 3420, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (7579, NULL, '2018-09-18 22:52:47.587516+00', 'Fahyda', 2696, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (6793, NULL, '2019-07-29 14:56:32.402902+00', 'Miss Nellie Wemyss', 2944, 1, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6779, NULL, '2014-11-17 22:20:28.279629+00', 'Short and Sweet', 3006, 2, 8, 40, NULL, NULL, 350, 0, '');
INSERT INTO 'recording' VALUES (6827, NULL, '2012-09-16 15:40:26.901891+00', 'Braes of Atholl', 10659, 3, 8, 40, NULL, NULL, 626, 0, '');
INSERT INTO 'recording' VALUES (6826, NULL, '2012-09-16 15:40:26.906193+00', 'Lass O'' Livingston, The', 10659, 1, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (6824, NULL, '2012-09-16 15:40:26.915578+00', 'Lovers'' Knot, The', 10659, 3, 8, 40, NULL, NULL, 623, 0, '');
INSERT INTO 'recording' VALUES (6843, NULL, '2012-01-20 12:55:39.903269+00', 'Jimp Waist, The', 10046, 3, 10, 32, NULL, NULL, 622, 0, '');
INSERT INTO 'recording' VALUES (6814, NULL, '2021-04-04 11:16:52.139042+00', 'Miss Devon''s Reel', 3045, 3, 8, 32, NULL, NULL, 484, 0, '');
INSERT INTO 'recording' VALUES (6811, NULL, '2021-05-27 16:30:35.940127+00', 'Miss Bennet''s Jig', 3045, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6844, NULL, '2012-01-20 12:55:39.922151+00', 'Duchess of Atholl''s Slipper, The', 10046, 3, 8, 32, NULL, NULL, 494, 0, '');
INSERT INTO 'recording' VALUES (6845, NULL, '2012-01-20 12:55:39.941929+00', 'My Love She''s But a Lassie Yet', 10046, 1, 6, 32, NULL, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (6846, NULL, '2012-01-20 12:55:39.947169+00', 'Mrs Grant''s Fancy', 10046, 3, 8, 32, NULL, NULL, 497, 0, '');
INSERT INTO 'recording' VALUES (6847, NULL, '2012-01-20 12:55:39.951318+00', 'Dalkeith''s Strathspey', 10046, 3, 8, 32, NULL, NULL, 493, 0, '');
INSERT INTO 'recording' VALUES (6848, NULL, '2012-01-20 12:55:39.955457+00', 'Festival Interceltique', 10046, 1, 4, 40, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (6850, NULL, '2012-01-20 12:55:39.965261+00', 'New Rigged Ship, The', 10047, 2, 8, 48, NULL, NULL, 409, 0, '');
INSERT INTO 'recording' VALUES (6852, NULL, '2012-01-20 12:55:39.97369+00', 'Madge Wildfire''s Strathspey', 10047, 3, 8, 32, NULL, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (6853, NULL, '2012-01-20 12:55:39.97777+00', 'Cadgers in the Canongate', 10047, 1, 8, 48, NULL, NULL, 422, 0, '');
INSERT INTO 'recording' VALUES (6854, NULL, '2012-01-20 12:55:39.982535+00', 'Cauld Kail', 10047, 4, 8, 32, 1, NULL, 400, 0, '');
INSERT INTO 'recording' VALUES (6860, NULL, '2018-03-23 10:02:58.1659+00', 'Jimp Waist, The', 10046, 3, 10, 32, NULL, NULL, 622, 1, '');
INSERT INTO 'recording' VALUES (6856, NULL, '2012-01-20 12:55:39.99106+00', 'Eileen Watt''s Reel', 10047, 1, 3, 32, NULL, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (6857, NULL, '2012-01-20 12:55:39.995166+00', 'Eileen Watt''s Strathspey', 10047, 3, 3, 32, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (6858, NULL, '2012-01-20 12:55:40+00', 'Trip to Lorient, A', 10047, 4, 1, 128, 2, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (6859, NULL, '2012-01-20 12:55:40.004119+00', 'Miss Clemy Stewart''s Reel', 10046, 1, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (6861, NULL, '2012-01-20 12:55:40.01242+00', 'Duchess of Atholl''s Slipper, The', 10046, 3, 8, 32, NULL, NULL, 494, 0, '');
INSERT INTO 'recording' VALUES (6862, NULL, '2012-01-20 12:55:40.016492+00', 'My Love She''s But a Lassie Yet', 10046, 1, 6, 32, NULL, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (6863, NULL, '2012-01-20 12:55:40.020559+00', 'Mrs Grant''s Fancy', 10046, 3, 8, 32, NULL, NULL, 497, 0, '');
INSERT INTO 'recording' VALUES (6864, NULL, '2012-01-20 12:55:40.024625+00', 'Dalkeith''s Strathspey', 10046, 3, 8, 32, NULL, NULL, 493, 0, '');
INSERT INTO 'recording' VALUES (6865, NULL, '2012-01-20 12:55:40.028785+00', 'Festival Interceltique', 10046, 1, 4, 40, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (6868, NULL, '2012-01-20 12:55:40.041459+00', 'New Rigged Ship, The', 10047, 2, 8, 48, NULL, NULL, 409, 0, '');
INSERT INTO 'recording' VALUES (6870, NULL, '2012-01-20 12:55:40.049803+00', 'Madge Wildfire''s Strathspey', 10047, 3, 8, 32, NULL, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (6871, NULL, '2012-01-20 12:55:40.053903+00', 'Cadgers in the Canongate', 10047, 1, 8, 48, NULL, NULL, 422, 0, '');
INSERT INTO 'recording' VALUES (6873, NULL, '2012-01-20 12:55:40.062978+00', 'Birks of Abergeldie, The', 10047, 1, 8, 48, NULL, NULL, 422, 0, '');
INSERT INTO 'recording' VALUES (6876, NULL, '2012-01-20 12:55:40.078508+00', 'Trip to Lorient, A', 10047, 4, 1, 128, 2, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (6882, NULL, '2012-01-20 12:55:40.103905+00', 'Gold and Silver', 3067, 3, 8, 32, NULL, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (10199, '2018-04-10 13:15:36.555777+00', '2018-04-10 13:15:36.555777+00', 'Sylvia Full of Grace', 11613, 3, 3, 32, NULL, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (6887, NULL, '2012-01-20 12:55:40.127714+00', 'Joanie''s Hornpipe', 3067, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (6888, NULL, '2012-01-20 12:55:40.13208+00', 'Tribute to Peter McBryde, A', 3067, 3, 3, 32, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (6889, NULL, '2012-01-20 12:55:40.136183+00', 'Source, The', 3067, 3, 8, 32, NULL, NULL, 510, 0, '');
INSERT INTO 'recording' VALUES (6891, NULL, '2012-01-20 12:55:40.140248+00', 'Thistle and the Maple Leaf, The', 3067, 2, 1, 128, NULL, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (6893, NULL, '2012-01-20 12:55:40.149717+00', 'TAC 50', 3067, 1, 1, 64, NULL, NULL, 80, 0, '');
INSERT INTO 'recording' VALUES (6894, NULL, '2012-01-20 12:55:40.154851+00', 'Fireside Lounge, The', 3067, 3, 5, 32, NULL, NULL, 324, 0, '');
INSERT INTO 'recording' VALUES (6896, NULL, '2012-01-20 12:55:40.163099+00', 'Gold and Silver', 3067, 3, 8, 32, NULL, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (6899, NULL, '2012-01-20 12:55:40.176191+00', 'Stooges'' Salute', 3067, 4, 1, 128, 2, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (6901, NULL, '2012-01-20 12:55:40.184398+00', 'Joanie''s Hornpipe', 3067, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (6902, NULL, '2012-01-20 12:55:40.188656+00', 'Tribute to Peter McBryde, A', 3067, 3, 3, 32, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (6903, NULL, '2012-01-20 12:55:40.192839+00', 'Source, The', 3067, 3, 8, 32, NULL, NULL, 510, 0, '');
INSERT INTO 'recording' VALUES (6904, NULL, '2012-01-20 12:55:40.19693+00', 'TAC''s Hospitality', 3067, 1, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (6905, NULL, '2012-01-20 12:55:40.201005+00', 'Highland Fair', 2681, 2, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6906, NULL, '2012-01-20 12:55:40.205308+00', 'Circassian Circle', 2681, 1, 3, 32, NULL, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (6908, NULL, '2012-01-20 12:55:40.213736+00', 'Meeting of the Waters, The', 2681, 1, 8, 48, NULL, NULL, 417, 0, '');
INSERT INTO 'recording' VALUES (6910, NULL, '2012-01-20 12:55:40.222127+00', 'Ladies'' Fancy', 2681, 2, 6, 32, NULL, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (6911, NULL, '2012-01-20 12:55:40.230793+00', 'Bonnie Stronshiray', 2681, 3, 8, 32, NULL, NULL, 506, 0, '');
INSERT INTO 'recording' VALUES (6912, NULL, '2012-01-20 12:55:40.235152+00', 'Seton''s Ceilidh Band', 2681, 2, 4, 64, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (6913, NULL, '2012-01-20 12:55:40.239288+00', 'Corn Rigs', 2681, 1, 6, 32, NULL, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (6914, NULL, '2012-01-20 12:55:40.243369+00', 'Tir Nan Og', 2681, 4, 4, 64, NULL, NULL, 393, 0, '');
INSERT INTO 'recording' VALUES (6915, NULL, '2012-01-20 12:55:40.249591+00', 'Express, The', 2681, 2, 8, 40, NULL, NULL, 354, 0, '');
INSERT INTO 'recording' VALUES (6916, NULL, '2012-01-20 12:55:40.253716+00', 'Dark Island, The', 2681, 98, 0, 0, NULL, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (6917, NULL, '2012-01-20 12:55:40.258113+00', 'Shiftin'' Bobbins', 2681, 1, 8, 32, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (6918, NULL, '2012-01-20 12:55:40.262265+00', 'Duchess Tree, The', 2681, 3, 8, 32, NULL, NULL, 499, 0, '');
INSERT INTO 'recording' VALUES (6919, NULL, '2012-01-20 12:55:40.269039+00', 'Frisky, The', 2681, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (6922, NULL, '2012-01-20 12:55:40.285355+00', 'Laird of Milton''s Daughter, The', 2681, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6898, NULL, '2014-03-19 14:41:19.197675+00', 'Dancing for Pleasure', 3067, 3, 3, 40, NULL, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (6900, NULL, '2014-07-16 17:07:13.422129+00', 'Summer Meeting, A', 3067, 3, 3, 32, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (6867, NULL, '2014-07-28 21:11:59.416647+00', 'Sueno''s Stone', 10046, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (6828, NULL, '2014-11-01 01:50:38.524156+00', 'Bleu Ribbon, The', 10659, 1, 8, 40, NULL, NULL, 354, 0, '');
INSERT INTO 'recording' VALUES (6825, NULL, '2014-11-01 02:37:37.182645+00', 'River Cree, The', 10659, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (6829, NULL, '2014-11-01 02:49:45.363595+00', 'Jessie''s Hornpipe', 10659, 1, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (6923, NULL, '2012-01-20 12:55:40.290751+00', 'Ship o'' Grace', 2681, 3, 4, 40, NULL, NULL, 309, 0, '');
INSERT INTO 'recording' VALUES (6866, NULL, '2017-03-24 23:47:09.976922+00', 'Minister on the Loch, The', 10046, 3, 3, 32, NULL, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (6897, NULL, '2017-09-13 15:28:45.482064+00', 'Highlander''s Farewell', 3067, 1, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (6907, NULL, '2017-11-03 22:02:34.02044+00', 'Leeze Me', 2681, 3, 4, 32, NULL, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (10194, '2018-04-10 12:53:50.305167+00', '2018-04-10 13:28:42.656755+00', 'Leaning Tower', 11613, 3, 3, 32, NULL, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (10197, '2018-04-10 13:08:46.404779+00', '2018-09-19 09:58:15.727863+00', 'Short''s Golden Strathspey', 11613, 3, 8, 32, NULL, NULL, 5002, 0, '');
INSERT INTO 'recording' VALUES (10200, '2018-04-10 13:17:25.224377+00', '2018-09-19 09:58:29.645361+00', 'Wha'' a Lass', 11613, 1, 4, 48, NULL, NULL, 221, 0, '');
INSERT INTO 'recording' VALUES (10198, '2018-04-10 13:14:04.003398+00', '2018-04-10 13:32:05.122794+00', 'Sprezzatura', 11613, 1, 4, 32, NULL, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (6875, NULL, '2019-01-22 23:24:24.840141+00', 'Eileen Watt''s Strathspey', 10047, 3, 3, 32, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (10195, '2018-04-10 13:02:21.099999+00', '2018-10-25 21:42:18.056183+00', 'Owl''s Nest', 11613, 2, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (10196, '2018-04-10 13:06:59.533118+00', '2019-09-30 22:07:59.55936+00', 'Peachtree Reel', 11613, 1, 8, 32, NULL, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (6924, NULL, '2012-01-20 12:55:40.296314+00', 'Mairi''s Wedding', 2681, 1, 8, 40, NULL, NULL, 345, 0, '');
INSERT INTO 'recording' VALUES (6925, NULL, '2012-01-20 12:55:40.301718+00', 'Langley Strathspey, The', 3006, 3, 3, 32, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (6926, NULL, '2012-01-20 12:55:40.307063+00', 'Farewell to Broadford', 3006, 1, 4, 40, NULL, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (6927, NULL, '2012-01-20 12:55:40.312413+00', 'Ammonites and Terns', 3006, 2, 5, 48, NULL, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (6928, NULL, '2012-01-20 12:55:40.317819+00', 'Clitheroe Castle', 3006, 3, 8, 32, NULL, NULL, 510, 0, '');
INSERT INTO 'recording' VALUES (6929, NULL, '2012-01-20 12:55:40.323272+00', 'Ribble Valley Revellers', 3006, 1, 4, 40, NULL, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (6934, NULL, '2012-01-20 12:55:40.351095+00', 'Stepping out with Jenny', 3006, 2, 6, 32, NULL, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (6892, NULL, '2021-05-17 14:55:42.465833+00', 'Spirit of the Dance, The', 3067, 3, 8, 32, NULL, NULL, 500, 0, '');
INSERT INTO 'recording' VALUES (6895, NULL, '2021-09-07 20:44:15.010463+00', 'Sutherland Salute', 3067, 2, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (6874, NULL, '2021-11-28 21:05:23.7745+00', 'Eileen Watt''s Reel', 10047, 1, 3, 32, NULL, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (6937, NULL, '2012-01-20 12:55:40.367407+00', 'Angela''s Jig', 3006, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (6938, NULL, '2012-01-20 12:55:40.372821+00', 'Kinnoull Ramble', 3006, 3, 5, 40, NULL, NULL, 403, 0, '');
INSERT INTO 'recording' VALUES (6939, NULL, '2012-01-20 12:55:40.378209+00', 'Party Dance Reel, The', 3006, 1, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6940, NULL, '2012-01-20 12:55:40.383573+00', 'Katie Rules, OK!', 3006, 2, 3, 32, NULL, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (6941, NULL, '2012-01-20 12:55:40.388923+00', 'Who''s Leading Who', 10018, 1, 8, 40, NULL, NULL, 353, 0, '');
INSERT INTO 'recording' VALUES (6942, NULL, '2012-01-20 12:55:40.394285+00', 'Celtic Clasp', 10018, 2, 8, 40, NULL, NULL, 346, 0, '');
INSERT INTO 'recording' VALUES (6943, NULL, '2012-01-20 12:55:40.39966+00', 'Demure Annie', 10018, 3, 4, 32, NULL, NULL, 254, 0, '');
INSERT INTO 'recording' VALUES (6944, NULL, '2012-01-20 12:55:40.405019+00', 'Niagara Swirl', 10018, 1, 8, 48, NULL, NULL, 429, 0, '');
INSERT INTO 'recording' VALUES (6945, NULL, '2012-01-20 12:55:40.410645+00', 'City of Sails', 10018, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (6946, NULL, '2012-01-20 12:55:40.41602+00', 'Fountain Strathspey, The', 10018, 3, 8, 32, NULL, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (6947, NULL, '2012-01-20 12:55:40.421366+00', 'Start as you Finish', 10018, 1, 3, 32, NULL, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (6948, NULL, '2012-01-20 12:55:40.426744+00', 'Jock''s Hill', 10018, 2, 4, 48, NULL, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (6949, NULL, '2012-01-20 12:55:40.432097+00', 'Courting Couples', 10018, 3, 5, 32, NULL, NULL, 314, 0, '');
INSERT INTO 'recording' VALUES (6950, NULL, '2012-01-20 12:55:40.437724+00', 'Atlantic - Pacific Link, The', 10018, 1, 4, 32, NULL, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (6920, NULL, '2022-12-26 20:49:27.903664+00', 'Trip to Bavaria, A', 2681, 1, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (6921, NULL, '2023-01-12 22:31:44.284406+00', 'Jimmy''s Fancy', 2681, 3, 8, 32, NULL, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (6951, NULL, '2012-01-20 12:55:40.443087+00', 'Incey Wincey Dance, The', 10018, 2, 3, 32, NULL, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (6953, NULL, '2012-01-20 12:55:40.453926+00', 'Pittsburgh Twister, The', 10018, 1, 8, 40, NULL, NULL, 355, 0, '');
INSERT INTO 'recording' VALUES (6954, NULL, '2012-01-20 12:55:40.45927+00', 'Miss Marshall of Melbourne', 10018, 2, 8, 32, NULL, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (6955, NULL, '2012-01-20 12:55:40.464641+00', 'Strathspey Shuffle, The', 10018, 3, 4, 32, NULL, NULL, 248, 0, '');
INSERT INTO 'recording' VALUES (6956, NULL, '2012-01-20 12:55:40.470001+00', 'Philip Islanders'' Dash, The', 3023, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (6957, NULL, '2012-01-20 12:55:40.475352+00', 'Keep those Feet Dancing', 3023, 2, 5, 40, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (6959, NULL, '2012-01-20 12:55:40.486066+00', 'Grundy''s Delight', 3023, 1, 4, 40, NULL, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (6960, NULL, '2012-01-20 12:55:40.491409+00', 'Happy Feet', 3023, 2, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (6961, NULL, '2012-01-20 12:55:40.496981+00', 'East of York', 3023, 3, 5, 40, NULL, NULL, 390, 0, '');
INSERT INTO 'recording' VALUES (6962, NULL, '2012-01-20 12:55:40.502337+00', 'Another Anniversary Reel', 3023, 1, 5, 32, NULL, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (6963, NULL, '2012-01-20 12:55:40.507685+00', 'Joan''s Joy', 3023, 2, 3, 32, NULL, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (6964, NULL, '2012-01-20 12:55:40.513035+00', 'In Yonder Glen', 3023, 3, 8, 32, NULL, NULL, 491, 0, '');
INSERT INTO 'recording' VALUES (6965, NULL, '2012-01-20 12:55:40.518405+00', 'Copacabana Caper', 3023, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (6966, NULL, '2012-01-20 12:55:40.523759+00', 'Irish Influence, The', 3023, 2, 8, 40, NULL, NULL, 336, 0, '');
INSERT INTO 'recording' VALUES (6967, NULL, '2012-01-20 12:55:40.529116+00', 'Monster in the Lake', 3023, 3, 5, 40, NULL, NULL, 390, 0, '');
INSERT INTO 'recording' VALUES (6968, NULL, '2012-01-20 12:55:40.534476+00', 'Hidemi''s Wedding', 3023, 1, 4, 40, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (6969, NULL, '2012-01-20 12:55:40.539836+00', 'Autumn Gold', 3023, 2, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (6971, NULL, '2012-01-20 12:55:40.552228+00', 'Royal Scot "Northward Bound"', 3023, 1, 4, 48, NULL, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (6973, NULL, '2012-01-20 12:55:40.563196+00', 'Deep Pool Reel', 3023, 1, 1, 96, NULL, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (6974, NULL, '2012-01-20 12:55:40.568539+00', 'Shetland Gathering, The', 3023, 6, 5, 48, NULL, NULL, 354, 0, '');
INSERT INTO 'recording' VALUES (6975, NULL, '2012-01-20 12:55:40.573901+00', 'Homecoming 2009, The', 3023, 1, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (6976, NULL, '2012-01-20 12:55:40.579238+00', 'Strathnairn', 3023, 3, 8, 32, NULL, NULL, 479, 0, '');
INSERT INTO 'recording' VALUES (6979, NULL, '2012-01-20 12:55:40.596168+00', 'Up the Ben wi'' Eddie', 3023, 2, 4, 32, NULL, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (6981, NULL, '2012-01-20 12:55:40.606879+00', 'Reel for Anne Chesterman of Cambuskenneth, A', 3023, 1, 4, 40, NULL, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (6982, NULL, '2012-01-20 12:55:40.612232+00', 'Cardean Strathspey', 3023, 3, 2, 40, NULL, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (6983, NULL, '2012-01-20 12:55:40.617577+00', 'Tae Gang Aboot', 3023, 1, 4, 48, NULL, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (6984, NULL, '2012-01-20 12:55:40.622937+00', 'Strathspey for the Black Watch', 3023, 3, 4, 32, NULL, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (6985, NULL, '2012-01-20 12:55:40.62829+00', 'Helen & Barclay Walker''s Reel [Sargent, Rob]', 3023, 1, 4, 40, NULL, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (6986, NULL, '2012-01-20 12:55:40.633646+00', 'Craggie Hornpipe, The', 3023, 6, 4, 32, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (6987, NULL, '2012-01-20 12:55:40.638997+00', 'Jessie Wiseman''s Reel', 3023, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (6990, NULL, '2012-01-20 12:55:40.655054+00', 'Miss Irene Whyte''s Strathspey', 3023, 3, 8, 32, NULL, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (6991, NULL, '2012-01-20 12:55:40.660395+00', 'Fireworks', 3023, 2, 8, 40, NULL, NULL, 346, 0, '');
INSERT INTO 'recording' VALUES (6992, NULL, '2012-01-20 12:55:40.665768+00', 'Royal Scot, Northward Bound, The', 3023, 1, 4, 48, NULL, NULL, 220, 0, '');
INSERT INTO 'recording' VALUES (6995, NULL, '2012-01-20 12:55:40.681923+00', 'For Old Times'' Sake', 3023, 1, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (6996, NULL, '2012-01-20 12:55:40.687277+00', 'Culloden Links', 3023, 3, 4, 32, NULL, NULL, 260, 1, '');
INSERT INTO 'recording' VALUES (6997, NULL, '2012-01-20 12:55:40.692619+00', 'Diamond Anniversary, The', 3023, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (6998, NULL, '2012-01-20 12:55:40.698232+00', 'Mrs Lilian Meiklejohn', 3023, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (6999, NULL, '2012-01-20 12:55:40.703582+00', 'Up and Down Ben Nevis', 3023, 3, 3, 32, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (7000, NULL, '2012-01-20 12:55:40.709006+00', 'Telford Hornpipe, The', 3023, 1, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (7001, NULL, '2012-01-20 12:55:40.714366+00', 'Falcon Square', 3023, 3, 4, 40, NULL, NULL, 322, 0, '');
INSERT INTO 'recording' VALUES (7002, NULL, '2012-01-20 12:55:40.719711+00', 'River Ness, The', 3023, 1, 5, 32, NULL, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (7005, NULL, '2012-01-20 12:55:40.763872+00', 'Crowcombe and Stogumber', 10070, 1, 8, 32, NULL, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (7007, NULL, '2012-01-20 12:55:40.775019+00', 'Invercauld''s Reel', 10070, 3, 8, 32, NULL, NULL, 527, 0, '');
INSERT INTO 'recording' VALUES (6936, NULL, '2014-10-19 16:04:59.901969+00', 'Acklam Reelers, The', 3006, 1, 4, 32, NULL, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (7009, NULL, '2012-01-20 12:55:40.786012+00', 'Simon Brodie', 10070, 3, 8, 32, NULL, NULL, 527, 0, '');
INSERT INTO 'recording' VALUES (7006, NULL, '2016-09-03 20:38:48.528856+00', 'My Heather Hills', 10070, 2, 3, 48, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (6935, NULL, '2016-09-03 20:30:57.424198+00', 'Carry On, Sue', 3006, 3, 3, 32, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (6932, NULL, '2018-07-29 10:06:16.155781+00', 'Drakensberg Stroll, The', 3006, 3, 8, 32, NULL, NULL, 519, 0, '');
INSERT INTO 'recording' VALUES (6952, NULL, '2017-02-08 13:57:10.314768+00', 'If at First ... Strathspey', 10018, 3, 4, 32, NULL, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (6931, NULL, '2018-07-29 10:21:10.50621+00', 'Everchanging Medley 2, The', 3006, 4, 1, 96, 21, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (6930, NULL, '2018-07-29 14:12:47.593973+00', 'Everchanging Medley 1, The', 3006, 2, 3, 32, NULL, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (9918, '2016-10-08 23:36:33.414402+00', '2018-09-19 09:56:22.09514+00', 'Bees They Are a''Drummin'', The', 3217, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (6933, NULL, '2018-07-29 14:45:39.664507+00', 'Echoes of Inverneill', 3006, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (7008, NULL, '2019-05-30 07:10:33.284487+00', 'Ferla Mor', 10070, 1, 8, 32, NULL, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (6989, NULL, '2019-10-01 13:41:03.585737+00', 'Strathconon', 3023, 1, 4, 32, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (7012, NULL, '2012-01-20 12:55:40.802123+00', 'Silver Thistle Ball, The', 10070, 3, 3, 32, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (7013, NULL, '2012-01-20 12:55:40.807468+00', 'Vale of Atholl', 10070, 2, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (7016, NULL, '2012-01-20 12:55:40.823515+00', 'Okinawa Reunion', 10070, 5, 1, 0, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (7017, NULL, '2012-01-20 12:55:40.82973+00', 'Sound of Iona, The', 10037, 4, 2, 64, 5, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (7018, NULL, '2012-01-20 12:55:40.835227+00', 'Stanley Mill, The', 10037, 1, 4, 40, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (7019, NULL, '2012-01-20 12:55:40.840581+00', 'Muirton Bank', 10037, 3, 3, 32, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (6988, NULL, '2020-02-10 10:20:04.197886+00', 'Diamond Celebration Jig, The', 3023, 2, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (6980, NULL, '2020-02-28 22:51:24.110348+00', 'Colin Dewar''s Hornpipe', 3023, 6, 8, 32, NULL, NULL, 374, 0, '');
INSERT INTO 'recording' VALUES (7014, NULL, '2021-02-21 20:25:24.842001+00', 'Sleepwalking', 10070, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (6970, NULL, '2020-09-24 08:52:42.885262+00', 'Stepping Hill', 3023, 4, 1, 160, 10, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (6993, NULL, '2021-08-17 23:11:54.721921+00', 'Belles of St Mary''s, The', 3023, 3, 8, 32, NULL, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (7020, NULL, '2012-01-20 12:55:40.845961+00', 'Oakbank''s Tribute to Christian', 10037, 2, 8, 32, NULL, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (7021, NULL, '2012-01-20 12:55:40.852179+00', 'Blooms of Perth, The', 10037, 4, 1, 128, 2, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (7023, NULL, '2012-01-20 12:55:40.862952+00', 'Miss Macpherson of Scone', 10037, 3, 4, 32, NULL, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (7025, NULL, '2012-01-20 12:55:40.873677+00', 'Silver Walk, The', 10037, 3, 1, 64, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (7003, NULL, '2012-03-23 10:16:07.788124+00', 'Rain Dancin'', Da', 10070, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7029, NULL, '2012-01-20 12:55:40.89529+00', 'Pipe Opener, The', 10076, 2, 5, 32, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (7034, NULL, '2012-01-20 12:55:40.922696+00', 'Mountain Stream, The', 10076, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (7035, NULL, '2012-01-20 12:55:40.928063+00', 'It Should be Fun', 10076, 2, 4, 32, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (7036, NULL, '2012-01-20 12:55:40.933421+00', 'Rannoch Moor', 10076, 3, 5, 32, NULL, NULL, 329, 0, '');
INSERT INTO 'recording' VALUES (7037, NULL, '2012-01-20 12:55:40.938837+00', 'Reel On', 10076, 1, 4, 32, NULL, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (7038, NULL, '2012-01-20 12:55:40.944183+00', 'Uncle Bill''s Jig', 10076, 2, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7039, NULL, '2012-01-20 12:55:40.949542+00', 'Pleasure is Mine, The', 10076, 3, 8, 32, NULL, NULL, 516, 0, '');
INSERT INTO 'recording' VALUES (7040, NULL, '2012-01-20 12:55:40.954908+00', 'Figure It Out', 10076, 1, 3, 32, NULL, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (7027, NULL, '2022-01-26 00:55:18.81786+00', 'Pitlochry Tryst, The', 10037, 3, 3, 32, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (7015, NULL, '2022-08-22 23:36:07.897119+00', 'Down on Yon Bank', 10070, 3, 8, 32, NULL, NULL, 530, 0, '');
INSERT INTO 'recording' VALUES (6972, NULL, '2022-08-30 19:40:58.801661+00', 'Wishworthy', 3023, 3, 8, 32, NULL, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (6977, NULL, '2022-12-23 14:04:59.824275+00', 'Duffus Lassie', 3023, 1, 4, 48, NULL, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (7041, NULL, '2012-01-20 12:55:40.960253+00', 'Rachel in Maryland', 10076, 2, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (7043, NULL, '2012-01-20 12:55:40.970992+00', 'Yvonne''s Lasses', 10076, 2, 1, 96, NULL, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (7044, NULL, '2012-01-20 12:55:40.976346+00', 'There and Back', 10076, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (7045, NULL, '2012-01-20 12:55:40.981713+00', 'Cherry Blossom Time', 3050, 2, 8, 32, NULL, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (7046, NULL, '2012-01-20 12:55:40.987105+00', 'Dream Maker', 3050, 3, 8, 32, NULL, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (7047, NULL, '2012-01-20 12:55:40.992448+00', 'Dragon, The', 3050, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7048, NULL, '2012-01-20 12:55:40.997925+00', 'Matsu Shima', 3050, 3, 3, 64, NULL, NULL, 381, 0, '');
INSERT INTO 'recording' VALUES (7049, NULL, '2012-01-20 12:55:41.003267+00', 'Rising Sun, The', 3050, 2, 8, 40, NULL, NULL, 344, 0, '');
INSERT INTO 'recording' VALUES (7050, NULL, '2012-01-20 12:55:41.00862+00', 'Summer in Paris', 3050, 1, 8, 40, NULL, NULL, 349, 0, '');
INSERT INTO 'recording' VALUES (7051, NULL, '2012-01-20 12:55:41.013982+00', 'Wooden Horse, The', 3050, 2, 3, 32, NULL, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (7052, NULL, '2012-01-20 12:55:41.019341+00', 'Northern Connections', 3050, 3, 4, 32, NULL, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (7054, NULL, '2012-01-20 12:55:41.030055+00', 'Spring in Shinjuku', 3050, 3, 5, 32, NULL, NULL, 315, 0, '');
INSERT INTO 'recording' VALUES (7055, NULL, '2012-01-20 12:55:41.03541+00', 'Mrs Takano''s Spirits', 3050, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (7057, NULL, '2012-01-20 12:55:41.046164+00', 'Dashing Wild Hatchan, The', 3050, 1, 6, 32, NULL, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (7058, NULL, '2012-01-20 12:55:41.05152+00', 'Great Little Lady, The', 3050, 3, 3, 40, NULL, NULL, 239, 0, '');
INSERT INTO 'recording' VALUES (7059, NULL, '2012-01-20 12:55:41.056899+00', 'Breeze Bay', 3050, 2, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (7061, NULL, '2012-01-20 12:55:41.067641+00', 'Thomas Glover''s Reel', 3050, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7063, NULL, '2012-01-20 12:55:41.078429+00', 'East Meets West', 3050, 3, 3, 24, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (7065, NULL, '2012-01-20 12:55:41.089194+00', 'Five Stars', 3050, 1, 5, 40, NULL, NULL, 223, 0, '');
INSERT INTO 'recording' VALUES (7066, NULL, '2012-01-20 12:55:41.09478+00', 'Careless Philosopher, A', 3050, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (7067, NULL, '2012-01-20 12:55:41.100155+00', 'Lady From the West, A', 3050, 3, 4, 32, NULL, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (7068, NULL, '2012-01-20 12:55:41.105797+00', 'Better Half, The', 3050, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7075, NULL, '2012-01-20 12:55:41.145237+00', 'Lagan Bridges, The', 3217, 2, 4, 48, NULL, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (7077, NULL, '2012-01-20 12:55:41.156828+00', 'Diamond for Belfast, A', 3217, 2, 3, 40, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (7078, NULL, '2012-01-20 12:55:41.162179+00', 'Glens of Antrim, The', 3217, 3, 8, 32, NULL, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (7079, NULL, '2012-01-20 12:55:41.167528+00', 'Drumlins of Down, The', 3217, 2, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (7081, NULL, '2012-01-20 12:55:41.178222+00', 'Set of Jigs', 3217, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (7083, NULL, '2012-01-20 12:55:41.188943+00', 'Port-No-Quay Jig', 2586, 2, 4, 40, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (7084, NULL, '2012-01-20 12:55:41.194305+00', 'Aye Afloat', 2586, 3, 4, 48, NULL, NULL, 410, 0, '');
INSERT INTO 'recording' VALUES (7086, NULL, '2012-01-20 12:55:41.206304+00', 'Port Hill Medley, The', 2586, 4, 1, 96, 11, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (7088, NULL, '2012-01-20 12:55:41.217071+00', 'Cadger''s Roadie, The', 2586, 2, 8, 32, NULL, NULL, 300, 0, '');
INSERT INTO 'recording' VALUES (7089, NULL, '2012-01-20 12:55:41.222426+00', 'Flagstaff and Cairn, The', 2586, 3, 4, 40, NULL, NULL, 349, 0, '');
INSERT INTO 'recording' VALUES (7091, NULL, '2012-01-20 12:55:41.233992+00', 'Bow Fiddle Shore, The', 2586, 4, 1, 96, 10007, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (7092, NULL, '2012-01-20 12:55:41.239368+00', 'Whale''s Moo, The', 2586, 1, 8, 32, NULL, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (7093, NULL, '2012-01-20 12:55:41.244724+00', 'Jenny''s Well', 2586, 3, 3, 32, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (7072, NULL, '2013-06-13 17:45:54.616453+00', 'City of Belfast', 3217, 3, 3, 32, NULL, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (7053, NULL, '2013-08-01 10:09:59.29318+00', 'Bobby & Kobby', 3050, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (7022, NULL, '2014-10-04 02:27:34.059499+00', 'Colin''s Kilts', 10037, 2, 8, 40, NULL, NULL, 337, 0, '');
INSERT INTO 'recording' VALUES (7094, NULL, '2012-01-20 12:55:41.250069+00', 'Andy Stewart Medley', 10079, 98, 0, 0, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (7095, NULL, '2012-01-20 12:55:41.255424+00', 'Cadgers in the Canongate', 2053, 1, 8, 48, NULL, NULL, 395, 0, '');
INSERT INTO 'recording' VALUES (7096, NULL, '2012-01-20 12:55:41.260769+00', 'Trumpet Polka, The', 10079, 13, 11, 8, NULL, NULL, 127, 0, '');
INSERT INTO 'recording' VALUES (7064, NULL, '2016-03-27 23:22:05.735101+00', 'Down Side Up', 3050, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (7056, NULL, '2018-03-23 10:13:32.405587+00', 'Pink Panda''s Picnic', 3050, 2, 4, 32, NULL, NULL, 144, 1, '');
INSERT INTO 'recording' VALUES (7011, NULL, '2016-09-03 20:35:26.258155+00', 'Black Mountain Reel, The', 10070, 1, 5, 32, NULL, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (7010, NULL, '2016-09-03 20:37:31.017689+00', 'Diamond Jubilee, The', 10070, 2, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7069, NULL, '2019-10-28 23:34:52.210224+00', 'Mrs Eightford', 3050, 4, 4, 64, 5, NULL, 390, 0, '');
INSERT INTO 'recording' VALUES (10202, '2018-04-10 13:24:17.336923+00', '2018-04-10 13:24:17.336923+00', 'Dawn', 11613, 5, 0, 0, NULL, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (7031, NULL, '2019-09-02 10:49:53.005362+00', 'Time to Meet', 10076, 1, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (7097, NULL, '2012-01-20 12:55:41.266149+00', 'Braes of Breadalbane, The', 2053, 3, 8, 32, NULL, NULL, 493, 0, '');
INSERT INTO 'recording' VALUES (7098, NULL, '2012-01-20 12:55:41.271496+00', 'Baldovan Jig', 2053, 2, 8, 32, NULL, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (7099, NULL, '2012-01-20 12:55:41.276837+00', 'Flying Scotsman, The', 10079, 98, 0, 0, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (7100, NULL, '2012-01-20 12:55:41.282194+00', 'Swing of the Kilt Medley, The', 10079, 98, 0, 0, NULL, NULL, 124, 0, '');
INSERT INTO 'recording' VALUES (7101, NULL, '2012-01-20 12:55:41.287555+00', 'Heart is Highland Medley, The', 10079, 98, 0, 0, NULL, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (7102, NULL, '2012-01-20 12:55:41.292904+00', 'College Hornpipe, The', 2053, 1, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (7103, NULL, '2012-01-20 12:55:41.298341+00', 'Lea Rig, The', 2053, 3, 8, 32, NULL, NULL, 481, 0, '');
INSERT INTO 'recording' VALUES (7104, NULL, '2012-01-20 12:55:41.303679+00', 'Jimmy Shand Special, The', 10079, 2, 4, 32, NULL, NULL, 125, 0, '');
INSERT INTO 'recording' VALUES (7105, NULL, '2012-01-20 12:55:41.309032+00', 'Call of the Pipes, The', 10079, 98, 0, 0, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (7033, NULL, '2019-12-12 21:03:59.391506+00', 'Caerlaverock Castle', 10076, 3, 3, 32, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (7074, NULL, '2020-03-01 16:39:53.069861+00', 'Belfast City Hall', 3217, 3, 4, 40, NULL, NULL, 356, 0, '');
INSERT INTO 'recording' VALUES (7085, NULL, '2020-06-05 17:10:04.184332+00', 'Heid o'' the Brae, The', 2586, 2, 3, 32, NULL, NULL, 122, 0, '');
INSERT INTO 'recording' VALUES (7030, NULL, '2020-07-31 19:08:14.173316+00', 'In Traditional Mode', 10076, 3, 8, 32, NULL, NULL, 519, 0, '');
INSERT INTO 'recording' VALUES (7026, NULL, '2021-07-18 20:04:37.764693+00', 'Vale of Atholl, The', 10037, 2, 8, 32, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (7060, NULL, '2021-08-20 14:15:18.030008+00', 'Mount Fuji', 3050, 3, 8, 32, NULL, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (7106, NULL, '2012-01-20 12:55:41.314393+00', 'Buchan Eightsome Reel, The', 2053, 1, 10, 40, NULL, NULL, 409, 0, '');
INSERT INTO 'recording' VALUES (7108, NULL, '2012-01-20 12:55:41.325206+00', 'Jig (The Weaver and his Wife)', 2029, 2, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (7109, NULL, '2012-01-20 12:55:41.330593+00', 'Reel (Domhnull beag an t-siucar)', 2029, 1, 4, 32, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (7110, NULL, '2012-01-20 12:55:41.335947+00', 'Reel (The Marquis of Tullibardine)', 2029, 1, 4, 32, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (7111, NULL, '2012-01-20 12:55:41.341289+00', 'Jig (Kerry Jig)', 2029, 2, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (7112, NULL, '2012-01-20 12:55:41.34664+00', 'Reel (Deveron Reel)', 2029, 1, 4, 32, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (7113, NULL, '2012-01-20 12:55:41.351976+00', 'Reel (The Mason''s Apron)', 2029, 1, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (7114, NULL, '2012-01-20 12:55:41.357339+00', 'Jig (The Glasgow Gaelic Club)', 2029, 2, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (7115, NULL, '2012-01-20 12:55:41.363009+00', 'Reel (Old Grey Cat)', 2029, 1, 4, 32, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (7116, NULL, '2012-01-20 12:55:41.36834+00', 'Jig (Tam''s Hunting Horn)', 2029, 2, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (7117, NULL, '2012-01-20 12:55:41.373715+00', 'Reel (John McNeil''s Reel)', 2029, 1, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (7118, NULL, '2012-01-20 12:55:41.37911+00', 'Jig (Anne Fraser MacKenzie)', 2029, 2, 4, 40, NULL, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (7119, NULL, '2012-01-20 12:55:41.384466+00', 'Jig (Old Rosin the Beau)', 2029, 2, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (7120, NULL, '2012-01-20 12:55:41.389823+00', 'Reel (Polka des Patroneux)', 2029, 1, 4, 32, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (7121, NULL, '2012-01-20 12:55:41.395202+00', 'Jig (Miss Stewart''s Fancy)', 2029, 2, 4, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (7090, NULL, '2022-09-01 20:42:07.968653+00', 'Three Creeks Shore, The', 2586, 2, 8, 32, NULL, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (7087, NULL, '2022-12-10 22:01:03.130182+00', 'Sheltered Cove, The', 2586, 3, 8, 32, NULL, NULL, 527, 0, '');
INSERT INTO 'recording' VALUES (7073, NULL, '2022-12-13 19:27:27.444832+00', 'City Hall Centenary', 3217, 1, 4, 32, NULL, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (7076, NULL, '2022-12-13 19:30:21.556795+00', 'Six Times S', 3217, 4, 1, 64, 5, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (7062, NULL, '2022-12-19 16:22:37.801067+00', 'Have a Bashie', 3050, 2, 4, 32, NULL, NULL, 145, 1, '');
INSERT INTO 'recording' VALUES (7122, NULL, '2012-01-20 12:55:41.400555+00', 'Jig (The Gobbie O)', 2029, 2, 4, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (7123, NULL, '2012-01-20 12:55:41.405912+00', 'Reel (Cripple Creek)', 2029, 1, 4, 32, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (7124, NULL, '2012-01-20 12:55:41.411258+00', 'Jig (Slieve Russell)', 2029, 2, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7125, NULL, '2012-01-20 12:55:41.416602+00', 'Jig (Scarce o'' Tatties)', 2029, 2, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7126, NULL, '2012-01-20 12:55:41.421953+00', 'Reel (Flirtation)', 2029, 1, 4, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (7127, NULL, '2012-01-20 12:55:41.427369+00', 'Reel (The Highlandman''s Umbrella)', 2029, 1, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (7128, NULL, '2012-01-20 12:55:41.432726+00', 'Reel (The Highlandman''s Umbrella)', 2029, 1, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7129, NULL, '2012-01-20 12:55:41.438097+00', 'Tarry A While', 3032, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (7130, NULL, '2012-01-20 12:55:41.44343+00', 'First of September, The', 3032, 1, 4, 32, NULL, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (7131, NULL, '2012-01-20 12:55:41.448784+00', 'Crathes Castle', 3032, 3, 3, 48, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (7132, NULL, '2012-01-20 12:55:41.454139+00', 'Georgie''s Jig', 3032, 2, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (7133, NULL, '2012-01-20 12:55:41.459481+00', 'Cadgers in the Canongate', 3032, 1, 8, 48, NULL, NULL, 401, 0, '');
INSERT INTO 'recording' VALUES (7134, NULL, '2012-01-20 12:55:41.464816+00', 'Culla Bay', 3032, 3, 4, 32, NULL, NULL, 244, 0, '');
INSERT INTO 'recording' VALUES (7135, NULL, '2012-01-20 12:55:41.470238+00', 'Dancing Master, The', 3032, 2, 3, 32, NULL, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (7136, NULL, '2012-01-20 12:55:41.475588+00', 'Fisherman''s Reel', 3032, 1, 5, 32, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (7137, NULL, '2012-01-20 12:55:41.480954+00', 'Sugar Candie', 3032, 3, 8, 32, NULL, NULL, 488, 0, '');
INSERT INTO 'recording' VALUES (7138, NULL, '2012-01-20 12:55:41.486308+00', 'Earl of Mansfield, The', 3032, 1, 4, 48, NULL, NULL, 220, 0, '');
INSERT INTO 'recording' VALUES (7139, NULL, '2012-01-20 12:55:41.492526+00', 'Johnnie Walker', 3032, 4, 1, 128, 13, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (7140, NULL, '2012-01-20 12:55:41.497921+00', 'Bea''s Delight', 3032, 1, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (7141, NULL, '2012-01-20 12:55:41.503264+00', 'Butterscotch and Honey', 3032, 3, 4, 32, NULL, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (7142, NULL, '2012-01-20 12:55:41.508622+00', 'New Rigged Ship, The', 3032, 2, 8, 48, NULL, NULL, 408, 0, '');
INSERT INTO 'recording' VALUES (7144, NULL, '2012-01-20 12:55:41.519309+00', 'Reels', 10095, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (7145, NULL, '2012-01-20 12:55:41.524668+00', 'Strathspeys', 10095, 3, 4, 32, NULL, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (7147, NULL, '2012-01-20 12:55:41.535365+00', 'Jigs', 10095, 2, 5, 32, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (7148, NULL, '2012-01-20 12:55:41.540695+00', 'Reels', 10095, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7150, NULL, '2012-01-20 12:55:41.551386+00', 'Waltz', 10095, 5, 0, 0, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (7151, NULL, '2012-01-20 12:55:41.556719+00', 'Fiddle Reels', 10095, 1, 5, 32, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (7153, NULL, '2012-01-20 12:55:41.567439+00', 'Jigs', 10095, 2, 4, 48, NULL, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (7155, NULL, '2012-01-20 12:55:41.579036+00', 'Jigs', 10095, 2, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7156, NULL, '2012-01-20 12:55:41.584378+00', 'Slow Air Strathspey (2bar intro)', 10095, 3, 4, 32, NULL, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (7158, NULL, '2012-01-20 12:55:41.595395+00', 'Reels', 10095, 1, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (10045, '2017-06-28 14:33:28.494909+00', '2018-09-19 09:56:30.104879+00', 'Bill And Rajeev''s Wedding Jig', 2586, 2, 3, 32, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (10190, '2018-04-10 11:54:32.360568+00', '2018-09-19 09:57:16.205305+00', 'Don''t Make Me Stop I''ll get Lost', 11613, 1, 3, 32, NULL, NULL, 119, 0, '');
INSERT INTO 'recording' VALUES (10186, '2018-04-10 11:42:12.355461+00', '2018-10-25 21:43:03.271965+00', 'Cauldron of the Plaid', 11613, 2, 8, 48, NULL, NULL, 221, 0, '');
INSERT INTO 'recording' VALUES (10224, '2018-09-15 09:46:05.519632+00', '2018-11-06 21:54:11.415186+00', 'Triple Happiness', 10659, 3, 3, 32, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (7162, NULL, '2019-01-23 00:11:25.937608+00', 'Cambusdoon', 3019, 3, 4, 32, NULL, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (10226, '2018-09-15 09:50:51.37947+00', '2019-06-06 08:14:47.4308+00', 'Trip to Timber Ridge', 10659, 1, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (7163, NULL, '2019-09-30 22:24:33.523708+00', 'Piper & the Penguin, The', 3019, 1, 1, 88, NULL, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (7143, NULL, '2014-10-04 01:36:13.614633+00', 'Jigs', 10095, 2, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7159, NULL, '2017-03-13 20:33:15.695221+00', 'Warm up Waltz', 3019, 5, 0, 0, NULL, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (7164, NULL, '2017-03-13 20:38:38.840469+00', 'Glasgow Country Dance', 3019, 4, 8, 32, 1, NULL, 385, 0, '');
INSERT INTO 'recording' VALUES (7165, NULL, '2017-03-13 20:39:40.145551+00', 'Kelloholm Jig, The', 3019, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (7166, NULL, '2017-03-13 20:40:24.116234+00', 'Kendoon Strathspey, The', 3019, 3, 8, 32, NULL, NULL, 496, 0, '');
INSERT INTO 'recording' VALUES (7168, NULL, '2017-03-13 20:41:41.123664+00', 'Napier''s Index', 3019, 2, 8, 40, NULL, NULL, 345, 0, '');
INSERT INTO 'recording' VALUES (7169, NULL, '2017-03-13 20:42:30.89649+00', 'Cherrybank Gardens', 3019, 3, 3, 32, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (7171, NULL, '2017-03-13 20:45:10.175335+00', 'Jimmy''s Fancy', 3019, 3, 8, 32, NULL, NULL, 490, 0, '');
INSERT INTO 'recording' VALUES (7167, NULL, '2017-03-13 20:47:56.17074+00', 'Preston Mill', 3019, 1, 5, 32, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (7213, NULL, '2018-03-22 17:53:00.442495+00', 'Sleeping Warrior, The', 3045, 3, 4, 32, NULL, NULL, 251, 1, '');
INSERT INTO 'recording' VALUES (7208, NULL, '2018-03-22 17:54:16.524935+00', 'Ray Milbourne', 3045, 1, 4, 32, NULL, NULL, 147, 1, '');
INSERT INTO 'recording' VALUES (10188, '2018-04-10 11:50:44.409405+00', '2018-04-10 13:26:47.084714+00', 'C2C (Canton to Cartersville)', 11613, 3, 4, 32, NULL, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (10192, '2018-04-10 12:00:03.593189+00', '2018-04-10 13:28:09.766262+00', 'Barbaron', 11613, 3, 8, 32, NULL, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (3251, NULL, '2018-04-14 08:05:17.569453+00', 'Falls of Bracklinn', 3014, 3, 4, 32, 9999, NULL, 0, 1, '');
INSERT INTO 'recording' VALUES (7375, NULL, '2018-04-15 14:15:15.626745+00', 'Weakest Link, The', 10117, 3, 4, 32, NULL, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (10203, '2018-06-23 14:38:13.962852+00', '2018-06-23 14:38:13.962852+00', 'Highland Laddie', 11651, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (10204, '2018-06-23 14:45:45.95757+00', '2018-06-23 14:45:45.95757+00', 'Royal Visit, The', 11651, 2, 8, 32, NULL, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (10207, '2018-06-23 15:53:25.191741+00', '2018-06-23 15:53:25.191741+00', 'Lady Glasgow', 11651, 3, 8, 32, NULL, NULL, 496, 0, '');
INSERT INTO 'recording' VALUES (8900, '2012-06-12 14:11:37.953078+00', '2020-01-25 22:50:52.409662+00', 'Sixtieth Celebrations', 3012, 2, 8, 32, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (10225, '2018-09-15 09:49:35.533209+00', '2020-06-12 20:29:38.972216+00', 'Bon Viveur, The', 10659, 4, 4, 32, 2, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (7202, NULL, '2012-01-20 12:55:41.8342+00', 'Yan, Tan, Tethera', 3045, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (7203, NULL, '2012-01-20 12:55:41.839574+00', 'Craven Reel, The', 3045, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7204, NULL, '2012-01-20 12:55:41.844939+00', 'Ring of Brodgar, The', 3045, 3, 4, 32, NULL, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (7205, NULL, '2012-01-20 12:55:41.850308+00', 'Domino Five', 3045, 1, 5, 32, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (7206, NULL, '2012-01-20 12:55:41.85565+00', 'Tattie Bogle, The', 3045, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (7207, NULL, '2012-01-20 12:55:41.861008+00', 'Craven Jig, The', 3045, 2, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7209, NULL, '2012-01-20 12:55:41.871725+00', 'Miss Stevenson''s Fancy', 3045, 3, 8, 32, NULL, NULL, 485, 0, '');
INSERT INTO 'recording' VALUES (7210, NULL, '2012-01-20 12:55:41.877072+00', 'Celtic Cross, The', 3045, 1, 4, 48, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (7211, NULL, '2012-01-20 12:55:41.882453+00', 'Gaelforce Wind', 3045, 2, 8, 32, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (7212, NULL, '2012-01-20 12:55:41.887796+00', 'Clansman, The', 3045, 1, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (7214, NULL, '2012-01-20 12:55:41.898601+00', 'Raven''s Dance, The', 3045, 2, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7216, NULL, '2012-01-20 12:55:41.909308+00', 'Jig for Garry, A', 3045, 2, 8, 32, NULL, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (7217, NULL, '2012-01-20 12:55:41.915093+00', 'Black Mountain Reel, The', 3045, 1, 5, 32, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (7218, NULL, '2012-01-20 12:55:41.920447+00', 'Linton Ploughman', 3069, 2, 5, 32, NULL, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (7219, NULL, '2012-01-20 12:55:41.925817+00', 'Earl of Errol''s Reel, The', 3069, 2, 1, 200, NULL, NULL, 221, 0, '');
INSERT INTO 'recording' VALUES (7220, NULL, '2012-01-20 12:55:41.931168+00', 'Boston Twostep', 3069, 50, 5, 16, NULL, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (7221, NULL, '2012-01-20 12:55:41.936525+00', 'Lochiel''s Rant', 3069, 3, 3, 32, NULL, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (7222, NULL, '2012-01-20 12:55:41.941992+00', 'Gay Gordons', 3069, 11, 8, 16, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (7161, NULL, '2022-12-12 23:06:36.848367+00', 'Wild Geese, The', 3019, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (7152, NULL, '2022-12-23 14:09:36.067766+00', 'Hornpipes (suitable for Canadian Barndance)', 10095, 6, 4, 32, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (7157, NULL, '2022-12-23 14:10:15.558588+00', 'Boston Two-Step', 10095, 50, 1, 128, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (7154, NULL, '2022-12-23 14:10:51.362901+00', 'Strathspey & Reel (suitable for Schiehallion)', 10095, 4, 1, 128, 2, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (7146, NULL, '2022-12-23 20:13:35.502704+00', '4/4 Marches (suitable for Gay Gordons)', 10095, 11, 4, 32, NULL, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (7172, NULL, '2023-02-17 21:15:21.573511+00', 'Miller of Sessnie, The', 3019, 2, 5, 32, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (9734, '2014-09-10 23:54:53.608038+00', '2023-01-10 18:24:20.255967+00', 'Dulce in Dacorum est', 3012, 1, 4, 40, NULL, NULL, 177, 1, '');
INSERT INTO 'recording' VALUES (7224, NULL, '2012-01-20 12:55:41.952695+00', 'Polish Polka, The', 3069, 50, 7, 16, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (7225, NULL, '2012-01-20 12:55:41.958051+00', 'Miss Bennet''s Jig', 3069, 2, 5, 32, NULL, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (7226, NULL, '2012-01-20 12:55:41.963396+00', 'Gaelic Waltz', 3069, 5, 8, 8, NULL, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (7227, NULL, '2012-01-20 12:55:41.969613+00', 'Foursome and Half Reel of Tulloch', 3069, 4, 1, 112, 10008, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (7228, NULL, '2012-01-20 12:55:41.975049+00', 'General Stuart''s Reel', 3069, 1, 5, 32, NULL, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (7229, NULL, '2012-01-20 12:55:41.980417+00', 'Border Polka, The', 3069, 50, 4, 32, NULL, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (7230, NULL, '2012-01-20 12:55:41.985766+00', 'Military Two-Step', 3069, 50, 8, 16, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (7234, NULL, '2012-01-20 12:55:42.007215+00', 'Barn Dance', 3069, 50, 15, 8, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (7235, NULL, '2012-01-20 12:55:42.012567+00', 'Sleepy Maggie', 3069, 1, 5, 32, NULL, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (7236, NULL, '2012-01-20 12:55:42.017933+00', 'Anniversary Two-Step', 10104, 50, 0, 0, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (7237, NULL, '2012-01-20 12:55:42.023276+00', 'Caddam Wood', 10104, 1, 5, 32, NULL, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (7238, NULL, '2012-01-20 12:55:42.028618+00', 'Harry Lime Foxtrot', 10104, 50, 0, 0, NULL, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (7239, NULL, '2012-01-20 12:55:42.03398+00', 'Hooper''s Jig', 10104, 2, 8, 32, NULL, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (7241, NULL, '2012-01-20 12:55:42.044682+00', 'Distillery Reel', 10104, 1, 4, 48, NULL, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (7242, NULL, '2012-01-20 12:55:42.050138+00', 'Edinburgh Mixture', 10104, 98, 0, 0, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (7244, NULL, '2012-01-20 12:55:42.060882+00', 'Marine Four-Step', 10104, 11, 0, 16, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (7245, NULL, '2012-01-20 12:55:42.066422+00', 'Fiddle Solo', 10104, 98, 0, 0, NULL, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (7246, NULL, '2012-01-20 12:55:42.071771+00', 'Progressive Quadrilles', 10104, 2, 6, 32, NULL, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (7247, NULL, '2012-01-20 12:55:42.077114+00', 'Jazz Twinkle', 10104, 98, 0, 0, NULL, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (7248, NULL, '2012-01-20 12:55:42.082479+00', 'Black Mountain Reel', 10104, 1, 5, 32, NULL, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (7249, NULL, '2012-01-20 12:55:42.08783+00', 'Barony Waltz', 10104, 5, 0, 0, NULL, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (7250, NULL, '2012-01-20 12:55:42.093172+00', 'Postie''s Jig', 10104, 2, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (7251, NULL, '2012-01-20 12:55:42.098566+00', 'Georgella Blues', 10104, 98, 0, 0, NULL, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (7252, NULL, '2012-01-20 12:55:42.103919+00', 'Bobby Brown''s Canadian Breakdown', 10104, 1, 4, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (7253, NULL, '2012-01-20 12:55:42.109264+00', 'Kirri March', 10104, 11, 0, 0, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (7254, NULL, '2012-01-20 12:55:42.114617+00', 'Follow Me Home', 10104, 2, 8, 32, NULL, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (7255, NULL, '2012-01-20 12:55:42.120314+00', 'Circassian Circle', 10104, 1, 6, 32, NULL, NULL, 229, 0, '');
INSERT INTO 'recording' VALUES (7256, NULL, '2012-01-20 12:55:42.125685+00', 'Fire and Ice', 1836, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (7257, NULL, '2012-01-20 12:55:42.131036+00', 'Masako', 1836, 1, 4, 40, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (7258, NULL, '2012-01-20 12:55:42.136395+00', 'Dundee Whaler, The', 1836, 3, 4, 32, NULL, NULL, 247, 0, '');
INSERT INTO 'recording' VALUES (7259, NULL, '2012-01-20 12:55:42.141764+00', 'Roaring Jelly', 1836, 2, 8, 32, NULL, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (7260, NULL, '2012-01-20 12:55:42.147106+00', 'Canadian Barn Dance', 1836, 50, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (7261, NULL, '2012-01-20 12:55:42.152535+00', 'Yukio''s Reel', 1836, 1, 4, 32, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (7262, NULL, '2012-01-20 12:55:42.157893+00', 'Letty Moodie', 1836, 3, 8, 32, NULL, NULL, 485, 0, '');
INSERT INTO 'recording' VALUES (7263, NULL, '2012-01-20 12:55:42.16324+00', 'Fergus Gathering, The', 1836, 1, 4, 40, NULL, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (7264, NULL, '2012-01-20 12:55:42.168591+00', 'Royal Wedding, The', 1836, 3, 8, 32, NULL, NULL, 483, 0, '');
INSERT INTO 'recording' VALUES (7265, NULL, '2012-01-20 12:55:42.173976+00', 'Duke of Atholl''s Reel, The', 1836, 2, 8, 32, NULL, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (7266, NULL, '2012-01-20 12:55:42.179319+00', 'Pitcarnie Hornpipe, The', 1836, 1, 5, 32, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (7267, NULL, '2012-01-20 12:55:42.18466+00', 'Seattle Landing', 1836, 3, 3, 32, NULL, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (7268, NULL, '2012-01-20 12:55:42.190001+00', 'Let''s Have a Ceilidh', 1836, 1, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (7269, NULL, '2012-01-20 12:55:42.195345+00', 'J.B. Milne', 3678, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (7233, NULL, '2018-06-26 21:54:20.740509+00', 'Argyll''s Fancy', 3069, 2, 4, 48, NULL, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (7231, NULL, '2018-06-28 08:57:50.819691+00', 'Pipe Marches for Gay Gordons', 3069, 11, 8, 16, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (10205, '2018-06-23 14:54:02.57187+00', '2018-08-17 11:54:46.16925+00', 'Lady Lucy Ramsay', 11651, 3, 8, 32, NULL, NULL, 479, 0, '');
INSERT INTO 'recording' VALUES (10187, '2018-04-10 11:44:58.140749+00', '2018-09-19 09:56:37.932015+00', 'Bonnie Bernard''s Birthday Bash', 11613, 1, 4, 32, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (10189, '2018-04-10 11:52:30.420278+00', '2018-09-19 09:57:49.098117+00', 'Lady Catherine Brodie''s Reel', 11613, 2, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (10201, '2018-04-10 13:18:30.77105+00', '2018-10-14 23:18:58.56859+00', 'Yellow Fliers, The', 11613, 2, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (7215, NULL, '2018-10-12 13:38:15.722307+00', 'Craven Twelvesome, The', 3045, 1, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7270, NULL, '2012-01-20 12:55:42.200697+00', 'Bonnie Lass o'' Bon Accord, The', 3678, 3, 1, 64, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (7271, NULL, '2012-01-20 12:55:42.206482+00', 'Hooper''s Jig', 3678, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7272, NULL, '2012-01-20 12:55:42.211849+00', 'Cramond Bridge', 3678, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (7274, NULL, '2012-01-20 12:55:42.222551+00', 'Ian Powrie''s Farewell to Auchterarder', 3678, 2, 1, 128, NULL, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (7276, NULL, '2012-01-20 12:55:42.233256+00', 'Lassie from Stirling, The', 3678, 3, 8, 32, NULL, NULL, 554, 0, '');
INSERT INTO 'recording' VALUES (7277, NULL, '2012-01-20 12:55:42.238629+00', 'Seton''s Ceilidh Band', 3678, 2, 4, 64, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7278, NULL, '2012-01-20 12:55:42.243975+00', 'Clansman, The', 3678, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (7279, NULL, '2012-01-20 12:55:42.249309+00', 'Frisky, The', 3678, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (7280, NULL, '2012-01-20 12:55:42.254674+00', 'Black Mountain Reel, The', 3678, 1, 5, 32, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (7281, NULL, '2012-01-20 12:55:42.260028+00', 'Middling, Thank You', 3678, 2, 8, 40, NULL, NULL, 345, 0, '');
INSERT INTO 'recording' VALUES (7282, NULL, '2012-01-20 12:55:42.265389+00', 'Anna Holden''s Strathspey', 3678, 3, 8, 32, NULL, NULL, 500, 0, '');
INSERT INTO 'recording' VALUES (7283, NULL, '2012-01-20 12:55:42.270753+00', 'Swiss Lassie', 3678, 1, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (7284, NULL, '2012-01-20 12:55:42.276185+00', 'Postie''s Jig', 3678, 2, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (7285, NULL, '2012-01-20 12:55:42.281534+00', 'Clutha', 3678, 1, 4, 48, NULL, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (7275, NULL, '2019-12-12 21:04:39.59662+00', 'Eightsome Reel', 3678, 1, 1, 464, NULL, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (7286, NULL, '2012-01-20 12:55:42.28689+00', 'Good Hearted Glasgow', 3678, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (7287, NULL, '2012-01-20 12:55:42.292245+00', 'Neidpath Castle', 3678, 3, 3, 32, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (7288, NULL, '2012-01-20 12:55:42.297768+00', 'Piper and the Penguin, The', 3678, 1, 1, 88, NULL, NULL, 99, 0, '');
INSERT INTO 'recording' VALUES (7289, NULL, '2012-01-20 12:55:42.303133+00', 'EH3 7AF', 3678, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (7290, NULL, '2012-01-20 12:55:42.308467+00', 'Blooms of Bon Accord', 3678, 1, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7291, NULL, '2012-01-20 12:55:42.313815+00', 'Sugar Candie', 3678, 3, 8, 32, NULL, NULL, 500, 0, '');
INSERT INTO 'recording' VALUES (7292, NULL, '2012-01-20 12:55:42.319192+00', 'Miss Hadden''s Reel', 3678, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (7293, NULL, '2012-01-20 12:55:42.324551+00', 'Punch Bowl, The', 3678, 1, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (7295, NULL, '2012-01-20 12:55:42.335253+00', 'Waltzes', 10108, 5, 0, 0, NULL, NULL, 226, 0, '');
INSERT INTO 'recording' VALUES (7296, NULL, '2012-01-20 12:55:42.340581+00', 'Polkas', 10108, 13, 6, 32, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (7297, NULL, '2012-01-20 12:55:42.345933+00', 'Reels', 10108, 1, 6, 32, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (7298, NULL, '2012-01-20 12:55:42.351342+00', 'Waltz', 10108, 5, 0, 0, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (7299, NULL, '2012-01-20 12:55:42.35668+00', 'Marches', 10108, 11, 8, 16, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (7300, NULL, '2012-01-20 12:55:42.362017+00', 'Foula Reel', 10108, 1, 4, 32, NULL, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (7301, NULL, '2012-01-20 12:55:42.367362+00', 'Marches', 10108, 11, 10, 16, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (7302, NULL, '2012-01-20 12:55:42.372694+00', 'Two-Step', 10108, 50, 8, 16, NULL, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (7303, NULL, '2012-01-20 12:55:42.378052+00', 'Waltz', 10108, 5, 0, 0, NULL, NULL, 116, 0, '');
INSERT INTO 'recording' VALUES (7304, NULL, '2012-01-20 12:55:42.383386+00', 'Reels', 10108, 1, 5, 32, NULL, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (7305, NULL, '2012-01-20 12:55:42.388728+00', 'Marches', 10108, 11, 6, 16, NULL, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (7306, NULL, '2012-01-20 12:55:42.394072+00', 'Jigs', 10108, 2, 6, 32, NULL, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (7240, NULL, '2022-12-16 21:15:55.593118+00', 'Jessie''s Waltz', 10104, 5, 0, 0, NULL, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (7232, NULL, '2023-01-12 22:30:23.241172+00', 'Lady Louisa MacDonald''s Strathspey', 3069, 3, 3, 32, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (7273, NULL, '2023-01-21 18:19:42.900981+00', 'Robertson Rant, The', 3678, 3, 1, 80, NULL, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (7307, NULL, '2012-01-20 12:55:42.399418+00', 'Two-Step', 10108, 50, 9, 16, NULL, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (7308, NULL, '2012-01-20 12:55:42.404773+00', 'Waltz', 10108, 5, 0, 0, NULL, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (7309, NULL, '2012-01-20 12:55:42.410901+00', 'Reels', 10108, 1, 5, 32, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (7310, NULL, '2012-01-20 12:55:42.416346+00', 'Ronnie Cooper''s Reels', 10114, 1, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (7311, NULL, '2012-01-20 12:55:42.421698+00', 'Cobbler, The', 10114, 2, 4, 48, NULL, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (7314, NULL, '2012-01-20 12:55:42.437753+00', 'Jenny''s Magic Touch', 10114, 3, 4, 32, NULL, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (7317, NULL, '2012-01-20 12:55:42.454719+00', 'Parnell''s Dragoons', 10114, 2, 8, 32, NULL, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (7321, NULL, '2012-01-20 12:55:42.476104+00', 'Glenbuchat Lodge', 10114, 1, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (7323, NULL, '2012-01-20 12:55:42.486823+00', 'Barmaid, The', 10114, 1, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (7324, NULL, '2012-01-20 12:55:42.492152+00', 'Windy Strath, The', 3023, 2, 8, 32, NULL, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (7325, NULL, '2012-01-20 12:55:42.497539+00', 'Montgarrie Mill', 3023, 1, 8, 40, NULL, NULL, 347, 0, '');
INSERT INTO 'recording' VALUES (7326, NULL, '2012-01-20 12:55:42.502932+00', 'Balnain House', 3023, 3, 4, 40, NULL, NULL, 309, 0, '');
INSERT INTO 'recording' VALUES (7327, NULL, '2012-01-20 12:55:42.508341+00', 'Sir J.M. Barrie of Thrums', 3023, 1, 4, 48, NULL, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (7328, NULL, '2012-01-20 12:55:42.513696+00', 'Ruthven''s Fancy', 3023, 2, 8, 32, NULL, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (7329, NULL, '2012-01-20 12:55:42.519044+00', 'Leck, The', 3023, 3, 8, 32, NULL, NULL, 490, 0, '');
INSERT INTO 'recording' VALUES (7330, NULL, '2012-01-20 12:55:42.524429+00', 'Peggy Rose', 3023, 1, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (7331, NULL, '2012-01-20 12:55:42.529779+00', 'Findhorn Bay', 3023, 6, 8, 32, NULL, NULL, 381, 0, '');
INSERT INTO 'recording' VALUES (7332, NULL, '2012-01-20 12:55:42.535247+00', 'Highland Ladies', 3023, 3, 8, 32, NULL, NULL, 493, 0, '');
INSERT INTO 'recording' VALUES (7333, NULL, '2012-01-20 12:55:42.540594+00', 'Robbie Over the Waves', 3023, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7334, NULL, '2012-01-20 12:55:42.545953+00', 'Mrs Jay Robertson''s Hornpipe', 3023, 6, 8, 32, NULL, NULL, 375, 0, '');
INSERT INTO 'recording' VALUES (7335, NULL, '2012-01-20 12:55:42.552167+00', 'Dancers Fae Auchleven, The', 3023, 4, 1, 128, 13, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (7336, NULL, '2012-01-20 12:55:42.557545+00', 'Mr McColl''s Hornpipe', 3023, 6, 4, 48, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7337, NULL, '2012-01-20 12:55:42.562904+00', 'Tribute to the Black Watch 2004', 3023, 1, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (7339, NULL, '2012-01-20 12:55:42.573614+00', 'Distillery Reel', 3023, 1, 4, 48, NULL, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (7340, NULL, '2012-01-20 12:55:42.57982+00', 'Bannercross', 10117, 4, 4, 64, 5, NULL, 417, 0, '');
INSERT INTO 'recording' VALUES (7341, NULL, '2012-01-20 12:55:42.585202+00', 'Dance for Dulcie, A', 10117, 3, 2, 32, NULL, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (7342, NULL, '2012-01-20 12:55:42.590624+00', 'Darwin Lane', 10117, 1, 4, 32, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (7343, NULL, '2012-01-20 12:55:42.595978+00', 'Don Valley Reel, The', 10117, 1, 8, 32, NULL, NULL, 306, 0, '');
INSERT INTO 'recording' VALUES (7344, NULL, '2012-01-20 12:55:42.601333+00', 'Double Eighty', 10117, 3, 4, 32, NULL, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (7345, NULL, '2012-01-20 12:55:42.606678+00', 'Inversnaid Reel', 10117, 1, 8, 32, NULL, NULL, 302, 0, '');
INSERT INTO 'recording' VALUES (7346, NULL, '2012-01-20 12:55:42.612026+00', 'Island Strathspey, The', 10117, 3, 8, 32, NULL, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (7347, NULL, '2012-01-20 12:55:42.617371+00', 'John Barleycorn', 10117, 2, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (7348, NULL, '2012-01-20 12:55:42.622732+00', 'Logan Braes', 10117, 3, 8, 32, NULL, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (7349, NULL, '2012-01-20 12:55:42.628923+00', 'Lullaby for a Baby', 10117, 4, 1, 192, 10009, NULL, 306, 0, '');
INSERT INTO 'recording' VALUES (7350, NULL, '2012-01-20 12:55:42.634299+00', 'Mix ''n'' Match', 10117, 3, 4, 32, NULL, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (7351, NULL, '2012-01-20 12:55:42.639644+00', 'Ringinglow Jig, The', 10117, 2, 4, 32, NULL, NULL, 154, 1, '');
INSERT INTO 'recording' VALUES (7322, NULL, '2014-04-11 19:23:10.176749+00', 'Appleby Horse Fair', 10114, 3, 8, 32, NULL, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (7318, NULL, '2014-04-11 19:30:25.183382+00', 'Morecambe Strathspey suitable for The Morcambe Strathspey', 10114, 3, 4, 40, NULL, NULL, 309, 0, '');
INSERT INTO 'recording' VALUES (7320, NULL, '2014-04-11 20:03:02.051202+00', 'Morland Ladies', 10114, 2, 4, 32, NULL, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (7312, NULL, '2014-04-11 20:50:26.109781+00', 'Musical Friends suitable for Wend Her Way to Bob', 10114, 3, 3, 32, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (7352, NULL, '2012-01-20 12:55:42.644976+00', 'Sheaf Strathspey, The', 10117, 3, 4, 32, NULL, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (7353, NULL, '2012-01-20 12:55:42.650325+00', 'Sheffield Secretary, The', 10117, 3, 3, 32, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (7354, NULL, '2012-01-20 12:55:42.655677+00', 'Strathaird', 10117, 3, 4, 32, NULL, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (7355, NULL, '2012-01-20 12:55:42.661022+00', 'Wheel Done', 10117, 2, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7356, NULL, '2012-01-20 12:55:42.666452+00', 'Irish Jigs', 2585, 2, 4, 32, NULL, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (7357, NULL, '2012-01-20 12:55:42.671795+00', 'Shetland Reels', 2585, 1, 4, 48, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (10193, '2018-04-10 12:52:41.96276+00', '2018-10-25 21:42:40.029798+00', 'Mr. Joseph LaFace', 11613, 2, 3, 32, NULL, NULL, 122, 0, '');
INSERT INTO 'recording' VALUES (7358, NULL, '2012-01-20 12:55:42.677136+00', 'Kerrera Polka, The', 2585, 13, 0, 0, NULL, NULL, 119, 0, '');
INSERT INTO 'recording' VALUES (7359, NULL, '2012-01-20 12:55:42.68248+00', 'Waltzes by Burns', 2585, 5, 0, 0, NULL, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (7360, NULL, '2012-01-20 12:55:42.687828+00', 'Kiss me Quick, my Mither''s Coming', 2585, 1, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (7361, NULL, '2012-01-20 12:55:42.693189+00', 'Boston Two Step', 2585, 50, 1, 16, NULL, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (7362, NULL, '2012-01-20 12:55:42.698583+00', '4/4 Marches', 2585, 11, 0, 0, NULL, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (7363, NULL, '2012-01-20 12:55:42.703946+00', 'Gaelic Waltzes', 2585, 5, 0, 0, NULL, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (7364, NULL, '2012-01-20 12:55:42.709296+00', 'Irish Reels', 2585, 1, 8, 32, NULL, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (7365, NULL, '2012-01-20 12:55:42.71466+00', 'Pipe Marches', 2585, 11, 0, 0, NULL, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (7367, NULL, '2012-01-20 12:55:42.725333+00', 'Irish Hornpipes', 2585, 1, 4, 32, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (7368, NULL, '2012-01-20 12:55:42.730699+00', '6/8 Pipe Marches', 2585, 11, 0, 0, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (7369, NULL, '2012-01-20 12:55:42.736156+00', 'Reels Fae Mull', 2585, 1, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (7370, NULL, '2012-01-20 12:55:42.741516+00', 'Pride of Erin Waltzes', 2585, 5, 0, 0, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (7371, NULL, '2012-01-20 12:55:42.746857+00', 'Pipe Jigs', 2585, 2, 8, 32, NULL, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (7372, NULL, '2012-01-20 12:55:42.752214+00', 'Rousing Reels', 2585, 1, 4, 32, NULL, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (7373, NULL, '2012-01-20 12:55:42.757568+00', 'Mrs Stuart Linnell', 10117, 1, 8, 40, NULL, NULL, 341, 0, '');
INSERT INTO 'recording' VALUES (7376, NULL, '2012-01-20 12:55:42.773788+00', 'Monday Night Reel', 10117, 1, 6, 32, NULL, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (7377, NULL, '2012-01-20 12:55:42.779145+00', 'Haddington Assembly', 10117, 2, 8, 32, NULL, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (7316, NULL, '2021-01-05 16:03:55.960344+00', 'Brecon Medley suitable for Twice Around the Beacons', 10114, 4, 1, 128, 2, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (7378, NULL, '2012-01-20 12:55:42.784499+00', 'Dream Catcher', 10117, 3, 1, 96, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (7379, NULL, '2012-01-20 12:55:42.789851+00', 'Dream Catcher', 10117, 3, 1, 96, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (7380, NULL, '2012-01-20 12:55:42.795184+00', 'Catch the Wind', 10117, 1, 8, 32, NULL, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (7381, NULL, '2012-01-20 12:55:42.801401+00', 'Iona Cross', 10117, 4, 1, 192, 3, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (7383, NULL, '2012-01-20 12:55:42.812144+00', 'Father Connelly''s Jig', 10117, 2, 4, 64, NULL, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (7384, NULL, '2012-01-20 12:55:42.817477+00', 'Conor''s Ceilidh', 10117, 1, 4, 32, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (7385, NULL, '2012-01-20 12:55:42.82285+00', 'Scottish Lilt', 10117, 2, 6, 8, NULL, NULL, 93, 0, '');
INSERT INTO 'recording' VALUES (7386, NULL, '2012-01-20 12:55:42.828175+00', 'Faculty of Actuaries, The', 10128, 2, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (7387, NULL, '2012-01-20 12:55:42.833563+00', 'Faculty of Actuaries - encore, The', 10128, 2, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (7388, NULL, '2012-01-20 12:55:42.838935+00', 'Westminster Reel, The', 10128, 1, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (7389, NULL, '2012-01-20 12:55:42.844288+00', 'Glasgow Highlanders', 10128, 3, 8, 32, NULL, NULL, 494, 1, '');
INSERT INTO 'recording' VALUES (7391, NULL, '2012-01-20 12:55:42.855023+00', 'Arkansas Traveller', 10129, 1, 8, 32, NULL, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (7392, NULL, '2012-01-20 12:55:42.860371+00', 'Saint Andrew''s Fair', 10129, 2, 8, 32, NULL, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (7393, NULL, '2012-01-20 12:55:42.865724+00', 'Corn Rigs', 10129, 1, 8, 32, NULL, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (7394, NULL, '2012-01-20 12:55:42.87107+00', 'Tulloch Gorm', 10129, 3, 8, 32, NULL, NULL, 465, 0, '');
INSERT INTO 'recording' VALUES (7395, NULL, '2012-01-20 12:55:42.876454+00', 'Light and Airy', 10129, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (7396, NULL, '2012-01-20 12:55:42.882285+00', 'Wind that Shakes the Barley, The', 10129, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7397, NULL, '2012-01-20 12:55:42.887735+00', 'Argyll Square, The', 10129, 2, 1, 96, NULL, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (7398, NULL, '2012-01-20 12:55:42.893076+00', 'Austin Silver', 10129, 3, 5, 32, NULL, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (7399, NULL, '2012-01-20 12:55:42.898438+00', 'Frog in the Middle', 10129, 2, 8, 32, NULL, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (7400, NULL, '2012-01-20 12:55:42.903785+00', 'Irish Rover', 10129, 1, 8, 32, NULL, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (7402, NULL, '2012-01-20 12:55:42.914913+00', 'Lady Catherine Bruce''s Reel', 10129, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (7404, NULL, '2012-01-20 12:55:42.925622+00', 'Macdonald of the Isles', 10129, 3, 3, 32, NULL, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (7405, NULL, '2012-01-20 12:55:42.930983+00', 'New Rigged Ship, The', 10129, 2, 8, 48, NULL, NULL, 392, 0, '');
INSERT INTO 'recording' VALUES (7406, NULL, '2012-01-20 12:55:42.936326+00', 'Black Mountain Reel', 10129, 1, 5, 32, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (7407, NULL, '2012-01-20 12:55:42.941699+00', 'Gay Gordons', 3014, 11, 0, 0, NULL, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (7408, NULL, '2012-01-20 12:55:42.947058+00', 'Set of Jigs', 3014, 2, 8, 32, NULL, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (7409, NULL, '2012-01-20 12:55:42.952401+00', 'Medley', 3014, 4, 0, 0, NULL, NULL, 319, 0, '');
INSERT INTO 'recording' VALUES (7410, NULL, '2012-01-20 12:55:42.957749+00', 'Waltz', 3014, 5, 4, 32, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (7411, NULL, '2012-01-20 12:55:42.963182+00', 'Two-Step', 3014, 50, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (7412, NULL, '2012-01-20 12:55:42.968527+00', 'Mississippi Dip', 3014, 2, 8, 32, NULL, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (7413, NULL, '2012-01-20 12:55:42.9739+00', 'Accordion Duet', 3014, 50, 0, 0, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (7414, NULL, '2012-01-20 12:55:42.979258+00', 'Slow Air', 3014, 50, 0, 0, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (7415, NULL, '2012-01-20 12:55:42.984612+00', 'Set of Reels', 3014, 1, 8, 32, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (7416, NULL, '2012-01-20 12:55:42.989961+00', 'Polka', 3014, 13, 0, 0, NULL, NULL, 126, 0, '');
INSERT INTO 'recording' VALUES (7417, NULL, '2012-01-20 12:55:42.995338+00', 'Jackdaw, The', 3014, 2, 4, 32, NULL, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (7418, NULL, '2012-01-20 12:55:43.000699+00', 'Plantation Reel, The', 3014, 1, 5, 32, NULL, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (7419, NULL, '2012-01-20 12:55:43.006232+00', 'Gammalvals', 3014, 5, 0, 0, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (7420, NULL, '2012-01-20 12:55:43.01158+00', 'Irish Hornpipes', 3014, 50, 0, 0, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (7421, NULL, '2012-01-20 12:55:43.016926+00', 'Fiddle Solo', 3014, 50, 0, 0, NULL, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (7422, NULL, '2012-01-20 12:55:43.022293+00', 'Set of Reels', 3014, 1, 8, 32, NULL, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (7423, NULL, '2012-01-20 12:55:43.027725+00', 'Dashing White Sergeant, The', 3065, 1, 5, 32, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (7425, NULL, '2012-01-20 12:55:43.045641+00', 'Canadian Barn Dance', 3065, 11, 0, 16, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (7426, NULL, '2012-01-20 12:55:43.050057+00', 'Gay Gordons', 3065, 11, 0, 16, NULL, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (7427, NULL, '2012-01-20 12:55:43.056891+00', 'Broun''s Reel', 3065, 1, 6, 32, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (7428, NULL, '2012-01-20 12:55:43.070983+00', 'Russe, La', 3065, 1, 3, 64, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (7429, NULL, '2012-01-20 12:55:43.078912+00', 'Strip the Willow', 3065, 2, 5, 32, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (7431, NULL, '2012-01-20 12:55:43.099466+00', 'Scottish Reform', 3065, 1, 5, 32, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (7432, NULL, '2012-01-20 12:55:43.105979+00', 'Gay Gordons', 3065, 11, 0, 16, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (7433, NULL, '2012-01-20 12:55:43.111501+00', 'Miss Nancy Frowns', 3065, 2, 5, 32, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (7434, NULL, '2012-01-20 12:55:43.116449+00', 'Isle of Skye', 3065, 1, 5, 32, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (7435, NULL, '2012-01-20 12:55:43.121038+00', 'Waltz Country Dance', 3065, 5, 4, 40, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (7436, NULL, '2012-01-20 12:55:43.125221+00', 'Dundee Reel', 3065, 2, 5, 32, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (7437, NULL, '2012-01-20 12:55:43.129307+00', 'Pride of Erin Waltz', 3065, 5, 0, 32, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (7438, NULL, '2012-01-20 12:55:43.133554+00', 'Glasgow Highlanders, The', 3065, 3, 3, 32, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (7439, NULL, '2012-01-20 12:55:43.137649+00', 'Hamilton House', 3065, 2, 5, 32, NULL, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (7390, NULL, '2014-03-19 22:58:01.251514+00', 'Duke and Duchess of Edinburgh, The', 10128, 1, 8, 40, NULL, NULL, 347, 0, '');
INSERT INTO 'recording' VALUES (7374, NULL, '2014-10-04 01:54:51.449872+00', 'Hotel Elsbury', 10117, 2, 8, 32, NULL, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (7440, NULL, '2012-01-20 12:55:43.141726+00', 'Linton Ploughman', 3065, 1, 5, 32, NULL, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (7441, NULL, '2012-01-20 12:55:43.145798+00', 'Scottish Waltz', 3065, 5, 0, 0, NULL, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (7442, NULL, '2012-01-20 12:55:43.149867+00', 'Lamb Skinnet', 3065, 2, 5, 32, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (7444, NULL, '2012-01-20 12:55:43.158545+00', 'Petronella', 3065, 1, 5, 32, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (7445, NULL, '2012-01-20 12:55:43.162999+00', 'Reel of the 51st Division, The', 3065, 1, 5, 32, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (7401, NULL, '2015-09-08 21:42:27.587553+00', 'Miss Baker''s Welcome', 10129, 3, 4, 40, NULL, NULL, 305, 0, '');
INSERT INTO 'recording' VALUES (10211, '2018-06-23 16:43:45.062275+00', '2018-06-23 16:43:45.062275+00', 'Seagull, The', 11651, 2, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (10191, '2018-04-10 11:56:28.476049+00', '2018-09-19 09:57:33.672057+00', 'Don''t Make Me Stop I''ll get Lost (Encore)', 11613, 1, 3, 32, NULL, NULL, 119, 0, '');
INSERT INTO 'recording' VALUES (7447, NULL, '2012-01-20 12:55:43.171408+00', 'Waltz', 3065, 5, 0, 0, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (7448, NULL, '2012-01-20 12:55:43.175616+00', 'Polka', 3065, 13, 0, 0, NULL, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (7449, NULL, '2012-01-20 12:55:43.179705+00', 'Dovecot Park', 3065, 2, 5, 32, NULL, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (7450, NULL, '2012-01-20 12:55:43.183771+00', 'Scottish Waltz', 3065, 5, 0, 0, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (7451, NULL, '2012-01-20 12:55:43.187837+00', 'Machine Without Horses', 3065, 2, 5, 32, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (7452, NULL, '2012-01-20 12:55:43.191934+00', 'Princess Margaret''s Strathspey', 3065, 3, 3, 32, NULL, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (7454, NULL, '2012-01-20 12:55:43.200204+00', 'Myosotis', 3065, 5, 0, 0, NULL, NULL, 247, 0, '');
INSERT INTO 'recording' VALUES (7455, NULL, '2012-01-20 12:55:43.204262+00', 'Jimmy''s Fancy', 3065, 3, 3, 32, NULL, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (7456, NULL, '2012-01-20 12:55:43.208766+00', 'Gay Gordons', 3065, 11, 0, 16, NULL, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (7457, NULL, '2012-01-20 12:55:43.212875+00', 'Angus Reel, The', 3065, 1, 5, 32, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (7458, NULL, '2012-01-20 12:55:43.217059+00', 'Strathglass House', 3065, 3, 3, 32, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (7459, NULL, '2012-01-20 12:55:43.2215+00', 'Ladies'' Fancy', 3065, 2, 9, 32, NULL, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (7460, NULL, '2012-01-20 12:55:43.225646+00', 'Gay Gordons', 3065, 11, 0, 16, NULL, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (7461, NULL, '2012-01-20 12:55:43.229923+00', 'Camp of Pleasure', 3065, 3, 3, 32, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (7462, NULL, '2012-01-20 12:55:43.234021+00', 'Cumberland Reel', 3065, 2, 5, 32, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (7463, NULL, '2012-01-20 12:55:43.238229+00', 'Ca'' the Ewes tae the Knowes', 3065, 3, 3, 32, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (7464, NULL, '2012-01-20 12:55:43.24239+00', 'Woo''d and married and a''', 3065, 2, 5, 32, NULL, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (7465, NULL, '2012-01-20 12:55:43.246464+00', 'Scottish Ramble', 3065, 3, 3, 32, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (7466, NULL, '2012-01-20 12:55:43.250535+00', 'River Cree, The', 3065, 2, 5, 32, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (7467, NULL, '2012-01-20 12:55:43.257405+00', 'Tibby Fowler o'' the Glen', 3065, 3, 3, 32, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (7468, NULL, '2012-01-20 12:55:43.261576+00', 'Todlen Hame', 3065, 2, 5, 32, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (7470, NULL, '2012-01-20 12:55:43.270002+00', 'Scottish Waltz', 3065, 5, 0, 16, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (7471, NULL, '2012-01-20 12:55:43.274161+00', 'Canadian Three Step', 3065, 50, 0, 16, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (7472, NULL, '2012-01-20 12:55:43.278549+00', 'Triumph, The', 3065, 1, 8, 24, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (7473, NULL, '2012-01-20 12:55:43.282644+00', 'Hesitation Waltz', 3065, 5, 0, 16, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (7474, NULL, '2012-01-20 12:55:43.286708+00', 'Boston Two Step', 3065, 2, 0, 16, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (7475, NULL, '2012-01-20 12:55:43.290833+00', 'Birks of Invermay, The', 3065, 3, 3, 32, NULL, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (7477, NULL, '2012-01-20 12:55:43.299484+00', 'Lassie wi'' the Yellow Coatie', 3065, 1, 5, 32, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (7478, NULL, '2012-01-20 12:55:43.303588+00', 'Grand March', 3065, 11, 0, 16, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (7479, NULL, '2012-01-20 12:55:43.307951+00', 'Tribute to the Borders', 2188, 2, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (7480, NULL, '2012-01-20 12:55:43.3121+00', 'Sir J.M. Barrie of Thrums', 2188, 1, 4, 48, NULL, NULL, 227, 0, '');
INSERT INTO 'recording' VALUES (7481, NULL, '2012-01-20 12:55:43.316184+00', 'Drumelzier', 2188, 3, 4, 32, NULL, NULL, 248, 0, '');
INSERT INTO 'recording' VALUES (7482, NULL, '2012-01-20 12:55:43.320728+00', 'Fiona''s Jig', 2188, 2, 1, 96, NULL, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (7483, NULL, '2012-01-20 12:55:43.32514+00', 'Baldovan Reel', 2188, 1, 4, 32, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (7484, NULL, '2012-01-20 12:55:43.329534+00', 'Moray Rant', 2188, 3, 3, 48, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7485, NULL, '2012-01-20 12:55:43.33362+00', 'Northmuir Jig', 2188, 2, 4, 32, NULL, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (7486, NULL, '2012-01-20 12:55:43.33769+00', 'Simon''s Dance', 2188, 1, 1, 128, NULL, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (7487, NULL, '2012-01-20 12:55:43.343308+00', 'Cardean Strathspey', 2188, 3, 2, 40, NULL, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (7489, NULL, '2012-01-20 12:55:43.351726+00', 'Laird of Milton''s Daughter', 2188, 2, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (7443, NULL, '2023-01-01 21:43:19.730727+00', 'Eightsome Reel, The', 3065, 1, 1, 160, NULL, NULL, 166, 0, 'Odd recording when it comes to bar count. The Eightsome Reel requires 464 bars in its standard version.');
INSERT INTO 'recording' VALUES (7490, NULL, '2012-01-20 12:55:43.355885+00', 'Belle of Bon Accord', 2188, 3, 4, 32, NULL, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (7491, NULL, '2012-01-20 12:55:43.360069+00', 'Set of Sir Jimmy Shand Jigs', 2188, 2, 4, 32, NULL, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (7492, NULL, '2012-01-20 12:55:43.364171+00', 'Montgarrie Mill', 2188, 1, 8, 40, NULL, NULL, 379, 0, '');
INSERT INTO 'recording' VALUES (7493, NULL, '2012-01-20 12:55:43.368358+00', 'Flower o'' the Quern, The', 2188, 3, 4, 32, NULL, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (7494, NULL, '2012-01-20 12:55:43.372638+00', 'J.B. Milne', 2188, 1, 8, 32, NULL, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (7495, NULL, '2012-01-20 12:55:43.377113+00', 'Duchess of Atholl''s Slipper, The', 10141, 3, 3, 32, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (7496, NULL, '2012-01-20 12:55:43.381327+00', 'Machine Without Horses, The', 10141, 2, 6, 32, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (7497, NULL, '2012-01-20 12:55:43.385458+00', 'There''s Nae Luck Aboot The Hoose', 10141, 3, 3, 32, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (7498, NULL, '2012-01-20 12:55:43.389687+00', 'River Cree', 10141, 2, 6, 32, NULL, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (7499, NULL, '2012-01-20 12:55:43.393787+00', 'Mrs Grant''s Fancy', 10141, 3, 3, 32, NULL, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (7500, NULL, '2012-01-20 12:55:43.397866+00', 'Reel of the 51st Division, The', 10141, 1, 6, 32, NULL, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (7501, NULL, '2012-01-20 12:55:43.402053+00', 'Scottish Ramble', 10141, 3, 3, 32, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (7502, NULL, '2012-01-20 12:55:43.406153+00', 'Deil amang the Tailors, The', 10141, 1, 6, 32, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (7503, NULL, '2012-01-20 12:55:43.410374+00', 'Strathglass House', 10141, 3, 3, 32, NULL, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (7504, NULL, '2012-01-20 12:55:43.438514+00', 'Grant''s Rant', 10141, 1, 4, 48, NULL, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (7505, NULL, '2012-01-20 12:55:43.444078+00', 'Monymusk', 10141, 3, 3, 32, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (7506, NULL, '2012-01-20 12:55:43.448816+00', 'Scottish Reform', 10141, 1, 6, 32, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (7507, NULL, '2012-01-20 12:55:43.45296+00', 'Braes of Tulliemet, The', 10141, 3, 3, 32, NULL, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (7508, NULL, '2012-01-20 12:55:43.45703+00', 'Triumph, The', 10141, 1, 6, 24, NULL, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (7509, NULL, '2012-01-20 12:55:43.461096+00', 'Maggie Lauder', 10141, 3, 3, 32, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (7510, NULL, '2012-01-20 12:55:43.465336+00', 'Petronella', 10141, 1, 5, 32, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (7511, NULL, '2012-01-20 12:55:43.469591+00', 'Skyeman''s Jig, The', 10142, 2, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (7512, NULL, '2012-01-20 12:55:43.473701+00', 'John McMillan of Barra', 10142, 11, 0, 0, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (7513, NULL, '2012-01-20 12:55:43.478108+00', 'Gaelic Waltz', 10142, 5, 0, 0, NULL, NULL, 227, 0, '');
INSERT INTO 'recording' VALUES (7514, NULL, '2012-01-20 12:55:43.482564+00', 'Set of Reels', 10142, 1, 4, 32, NULL, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (7515, NULL, '2012-01-20 12:55:43.486954+00', 'Fiddle Solo', 10142, 98, 0, 0, NULL, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (7517, NULL, '2012-01-20 12:55:43.495969+00', 'Jig', 10142, 2, 4, 32, NULL, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (7518, NULL, '2012-01-20 12:55:43.500895+00', 'Gaelic Waltz', 10142, 5, 0, 0, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (7519, NULL, '2012-01-20 12:55:43.505061+00', 'Reel', 10142, 1, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (7520, NULL, '2012-01-20 12:55:43.509275+00', 'Misty Isle, The', 10142, 98, 0, 0, NULL, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (7521, NULL, '2012-01-20 12:55:43.513481+00', 'Kitchener''s Army', 10142, 98, 0, 0, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (7523, NULL, '2012-01-20 12:55:43.522331+00', 'Lady Sophia Anne of Bute', 3026, 1, 4, 48, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (7524, NULL, '2012-01-20 12:55:43.527224+00', 'Deuks Dang Ow''re My Daddie, The', 2053, 2, 8, 40, 9999, NULL, 332, 0, '');
INSERT INTO 'recording' VALUES (7525, NULL, '2012-01-20 12:55:43.532079+00', 'Flowers of Edinburgh', 10147, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7526, NULL, '2012-01-20 12:55:43.536876+00', 'Waltz', 3065, 5, 0, 0, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (7528, NULL, '2012-01-20 12:55:43.546707+00', 'Highland Scottische', 10146, 3, 0, 16, 40, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (7530, NULL, '2012-01-20 12:55:43.556406+00', 'Waltz Medley', 3010, 5, 0, 0, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (7531, NULL, '2012-01-20 12:55:43.561207+00', 'Linton Ploughman, The', 2038, 2, 5, 32, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (7535, NULL, '2012-01-20 12:55:43.580454+00', 'White Heather Jig', 10144, 2, 4, 40, 9999, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (7536, NULL, '2012-01-20 12:55:43.584547+00', 'Gay Gordons', 3051, 11, 0, 16, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (7537, NULL, '2012-01-20 12:55:43.590163+00', 'Scottish Waltz', 2611, 5, 0, 0, NULL, NULL, 312, 0, '');
INSERT INTO 'recording' VALUES (7539, NULL, '2012-01-20 12:55:43.599896+00', 'Eightsome Reel, The', 10141, 1, 1, 464, 9999, NULL, 458, 0, '');
INSERT INTO 'recording' VALUES (7540, NULL, '2012-01-20 12:55:43.60476+00', 'Duke of Perth', 2053, 1, 8, 32, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (7541, NULL, '2012-01-20 12:55:43.609655+00', 'Highland Scottische', 3051, 3, 0, 16, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (7542, NULL, '2012-01-20 12:55:43.614725+00', 'Janet''s Delight Waltz', 10144, 5, 0, 0, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (7543, NULL, '2012-01-20 12:55:43.619655+00', 'Set of Jigs', 2412, 2, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (7545, NULL, '2012-01-20 12:55:43.62938+00', 'Canadian Barn Dance', 2038, 11, 0, 16, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (7546, NULL, '2012-01-20 12:55:43.634197+00', 'Petronella', 10141, 1, 8, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (7547, NULL, '2012-01-20 12:55:43.638993+00', 'Gay Gordons', 3010, 11, 0, 16, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (7548, NULL, '2012-01-20 12:55:43.643967+00', 'Saint Bernard''s Waltz', 3065, 5, 0, 16, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (7549, NULL, '2012-01-20 12:55:43.648891+00', 'Call of the Pipes, The', 10148, 11, 0, 16, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (7550, NULL, '2012-01-20 12:55:43.653825+00', 'Happy Harry Polka', 3009, 13, 0, 0, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (7551, NULL, '2012-01-20 12:55:43.658624+00', 'Boston Two Step', 10147, 2, 0, 16, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (7552, NULL, '2012-01-20 12:55:43.663409+00', 'Bonnie Lass o'' Bon Accord, The', 10145, 3, 1, 64, 9999, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (7553, NULL, '2012-01-20 12:55:43.668188+00', 'Campbell''s Frolic', 3037, 2, 4, 32, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (7554, NULL, '2012-01-20 12:55:43.673512+00', 'Harvest Home', 10146, 1, 4, 48, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (7555, NULL, '2012-01-20 12:55:43.678346+00', 'Scottish Waltz', 2611, 5, 0, 0, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (7556, NULL, '2012-01-20 12:55:43.683248+00', 'Eightsome Reel, The', 3026, 1, 1, 464, 9999, NULL, 415, 0, '');
INSERT INTO 'recording' VALUES (7557, NULL, '2012-01-20 12:55:43.687418+00', 'Star o'' Rabbie Burns, The', 3217, 98, 0, 0, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (7469, NULL, '2019-12-03 08:20:03.296567+00', 'Bluebell Polka, The', 3065, 13, 0, 16, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (7522, NULL, '2020-01-22 23:51:16.19894+00', 'March Strathspey Reel', 10142, 98, 0, 0, NULL, NULL, 234, 0, '');
INSERT INTO 'recording' VALUES (7558, NULL, '2012-01-20 12:55:43.69159+00', 'Banks and Braes', 3217, 2, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (7559, NULL, '2012-01-20 12:55:43.696355+00', 'Ha! Ha! The Wooin'' O'' It suitable for The Road to Abernyte, The Sailors Guide, St Valentine''s Day, Topsy Turvy, Wedderburn Reel', 3217, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (7560, NULL, '2012-01-20 12:55:43.700477+00', 'Red Red Rose suitable for The Seas Gang Dry, The', 3217, 3, 8, 32, NULL, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (7561, NULL, '2012-01-20 12:55:43.704555+00', 'Kenmure''s On And Awa'' suitable for Old Friends', 3217, 2, 8, 24, NULL, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (7562, NULL, '2012-01-20 12:55:43.708632+00', 'Cairney Mount', 3217, 1, 4, 40, NULL, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (7563, NULL, '2012-01-20 12:55:43.712831+00', 'Green Grow the Rashes suitable for Loralee Hyde, Trip to Tunbridge', 3217, 3, 8, 32, NULL, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (7564, NULL, '2012-01-20 12:55:43.716929+00', 'My Wife''s a Wanton Wee Thing suitable for Miss Nancy Frowns', 3217, 2, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (7527, NULL, '2012-09-01 09:30:57.360114+00', 'Petronella', 10143, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7565, NULL, '2012-01-20 12:55:43.721175+00', 'My Love She''s but a Lassie Yet suitable for Airdailly Mill', 3217, 1, 6, 32, NULL, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (7567, NULL, '2012-01-20 12:55:43.729613+00', 'Dusty Miller, The', 3217, 2, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (7569, NULL, '2012-01-20 12:55:43.737903+00', 'Ae Fond Kiss', 3217, 5, 3, 32, NULL, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (7572, NULL, '2012-01-20 12:55:43.75023+00', 'Boundary Cottage', 2696, 3, 4, 32, NULL, NULL, 264, 1, '');
INSERT INTO 'recording' VALUES (7573, NULL, '2012-01-20 12:55:43.754432+00', 'Moorlands at Hay Tor', 2696, 1, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (7576, NULL, '2012-01-20 12:55:43.766745+00', 'Wellingtonia Reel, The', 2696, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (7571, NULL, '2018-06-16 20:12:32.953887+00', 'Handsel, The', 2696, 2, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (7581, NULL, '2012-01-20 12:55:43.787203+00', 'Edinburgh''s Gain', 2696, 3, 4, 40, NULL, NULL, 323, 1, '');
INSERT INTO 'recording' VALUES (7583, NULL, '2012-01-20 12:55:43.795467+00', 'Silver Spire, The', 3012, 1, 4, 32, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (7516, NULL, '2022-12-26 18:21:14.151791+00', 'Highland Scottische', 10142, 3, 0, 0, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (7533, NULL, '2022-12-14 16:37:03.938914+00', 'Pride of Erin Waltz', 3009, 5, 0, 32, 9999, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (7575, NULL, '2022-12-18 01:39:26.768348+00', 'Naishcombe Hill', 2696, 3, 8, 32, NULL, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (7584, NULL, '2012-01-20 12:55:43.79955+00', 'Boston Two-Step', 3012, 2, 0, 16, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (7585, NULL, '2012-01-20 12:55:43.803668+00', 'Gay Gordons Two-Step', 3012, 11, 0, 16, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (7586, NULL, '2012-01-20 12:55:43.807751+00', 'Pride of Erin Waltz', 3012, 5, 0, 32, NULL, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (7587, NULL, '2012-01-20 12:55:43.811819+00', 'Last of the Lairds', 3012, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (7588, NULL, '2012-01-20 12:55:43.817818+00', 'Canadian Barn Dance', 3012, 11, 0, 16, NULL, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (7589, NULL, '2012-01-20 12:55:43.823176+00', 'Tribute to Ron Gonnella', 3012, 98, 0, 0, NULL, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (7590, NULL, '2012-01-20 12:55:43.828524+00', 'Newcastle Reel, The', 3012, 1, 4, 32, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (7591, NULL, '2012-01-20 12:55:43.833881+00', 'Eva Three Step', 3012, 2, 0, 16, NULL, NULL, 159, 0, '');
INSERT INTO 'recording' VALUES (7592, NULL, '2012-01-20 12:55:43.839221+00', 'Shetland Waltz', 3012, 5, 0, 0, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (7593, NULL, '2012-01-20 12:55:43.844572+00', 'Strip the Willow', 3012, 2, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (7594, NULL, '2012-01-20 12:55:43.849925+00', 'Gay Gordons', 3012, 11, 0, 16, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (7595, NULL, '2012-01-20 12:55:43.855279+00', 'Polkas', 3012, 13, 0, 0, NULL, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (7596, NULL, '2012-01-20 12:55:43.860794+00', 'Black Mountain Reel', 3012, 1, 5, 32, NULL, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (7597, NULL, '2012-01-20 12:55:43.866167+00', 'March, Strathspey, Reel', 3012, 4, 0, 0, NULL, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (7598, NULL, '2012-01-20 12:55:43.871513+00', 'Britannia Two-Step', 3012, 2, 0, 16, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (7599, NULL, '2012-01-20 12:55:43.876958+00', 'Scandinavian Waltz', 3012, 5, 0, 0, NULL, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (7600, NULL, '2012-01-20 12:55:43.882314+00', 'Auchtermuchty Gala March', 3012, 11, 0, 0, NULL, NULL, 119, 0, '');
INSERT INTO 'recording' VALUES (7602, NULL, '2012-01-20 12:55:43.893+00', 'Pipe Reels', 3012, 1, 6, 32, NULL, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (7603, NULL, '2012-01-20 12:55:43.898356+00', 'Waltz for Kirsty', 3012, 5, 0, 0, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (7604, NULL, '2012-01-20 12:55:43.903693+00', 'Tribute to Angus Fitchet', 3012, 2, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7605, NULL, '2012-01-20 12:55:43.909031+00', 'Clancy''s Salsa', 3012, 1, 6, 32, NULL, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (7606, NULL, '2012-01-20 12:55:43.915692+00', 'Gay Gordons, The', 2088, 50, 0, 16, 9999, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (7607, NULL, '2012-01-20 12:55:43.921919+00', 'Eva Three Step, The', 2088, 50, 0, 16, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7544, NULL, '2014-04-25 09:35:20.78412+00', 'Glasgow Highlanders, The', 10143, 3, 3, 32, 9999, NULL, 159, 1, 'played 4x24');
INSERT INTO 'recording' VALUES (7566, NULL, '2014-08-19 08:12:46.159201+00', 'Lea Rig suitable for Old Craigmore, The', 3217, 3, 8, 32, NULL, NULL, 499, 0, '');
INSERT INTO 'recording' VALUES (7529, NULL, '2014-11-15 22:47:10.944265+00', 'Tempête, La', 2246, 1, 4, 48, 9999, NULL, 241, 0, '');
INSERT INTO 'recording' VALUES (7608, NULL, '2012-01-20 12:55:43.927529+00', 'Saint Bernard''s Waltz, The', 2088, 5, 0, 16, NULL, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (7610, NULL, '2012-01-20 12:55:43.932898+00', 'Military Two Step', 2088, 50, 0, 16, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (7611, NULL, '2012-01-20 12:55:43.938253+00', 'Canadian Barn Dance, The', 2088, 50, 0, 16, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (7612, NULL, '2012-01-20 12:55:43.943596+00', 'Pride of Erin Waltz', 2088, 5, 0, 32, NULL, NULL, 226, 0, '');
INSERT INTO 'recording' VALUES (7613, NULL, '2012-01-20 12:55:43.949147+00', 'Britannia Two Step, The', 2088, 50, 0, 16, NULL, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (7615, NULL, '2012-01-20 12:55:43.95986+00', 'Highland Schottische, The', 2088, 50, 0, 8, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (7616, NULL, '2012-01-20 12:55:43.966165+00', 'Swedish Masquerade, The', 2088, 50, 0, 48, 33, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (7617, NULL, '2012-01-20 12:55:43.972375+00', 'Virginia Reel, The', 2088, 1, 4, 64, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (7578, NULL, '2015-11-04 23:13:24.622993+00', 'Old School Strathspey, The', 2696, 3, 4, 32, NULL, NULL, 262, 1, '');
INSERT INTO 'recording' VALUES (7574, NULL, '2016-09-04 13:52:06.187041+00', 'Sidney''s Reel', 2696, 2, 3, 32, NULL, NULL, 115, 0, '');
INSERT INTO 'recording' VALUES (7577, NULL, '2016-09-04 15:28:30.600508+00', 'King Edward''s Jig', 2696, 2, 4, 32, NULL, NULL, 158, 1, '');
INSERT INTO 'recording' VALUES (7614, NULL, '2017-10-17 01:21:25.751044+00', 'Cumberland Square Eight, The', 2088, 50, 0, 64, NULL, NULL, 324, 0, '');
INSERT INTO 'recording' VALUES (7580, NULL, '2018-09-18 22:53:51.174058+00', 'Birdham Pool', 2696, 2, 8, 40, NULL, NULL, 355, 0, '');
INSERT INTO 'recording' VALUES (8911, '2012-06-12 15:47:12.702895+00', '2019-01-05 12:28:11.298134+00', 'Lightning at Dawn', 3012, 2, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (7618, NULL, '2012-01-20 12:55:43.978611+00', 'Veleta, The', 2088, 5, 0, 16, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (7619, NULL, '2012-01-20 12:55:43.983986+00', 'Last Waltz', 2088, 5, 0, 0, NULL, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (7620, NULL, '2012-01-20 12:55:43.98932+00', 'Dashing White Sergeant', 10157, 1, 4, 32, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (7621, NULL, '2012-01-20 12:55:43.994677+00', 'Strip the Willow', 10157, 2, 4, 56, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (7622, NULL, '2012-01-20 12:55:44.000046+00', 'Angus Reel, The', 10157, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7623, NULL, '2012-01-20 12:55:44.005389+00', 'Saint Bernard''s Waltz', 10157, 5, 0, 16, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (7624, NULL, '2012-01-20 12:55:44.01074+00', 'Flowers of Edinburgh', 10157, 1, 6, 32, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (7625, NULL, '2012-01-20 12:55:44.016137+00', 'Tempête, La', 10157, 1, 4, 48, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (7626, NULL, '2012-01-20 12:55:44.021491+00', 'Duke of Perth', 10157, 1, 8, 32, NULL, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (7627, NULL, '2012-01-20 12:55:44.026841+00', 'Highland Schottische', 10157, 3, 0, 8, NULL, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (7628, NULL, '2012-01-20 12:55:44.032183+00', 'Circassian Circle', 10157, 1, 6, 32, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (7629, NULL, '2012-01-20 12:55:44.037546+00', 'Petronella', 10157, 1, 8, 32, NULL, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (7630, NULL, '2012-01-20 12:55:44.04289+00', 'MacDonald of Sleat', 10157, 2, 1, 120, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7631, NULL, '2012-01-20 12:55:44.048217+00', 'Hebridean Weaving Lilt', 10157, 3, 1, 88, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (7632, NULL, '2012-01-20 12:55:44.053599+00', 'Welcome to Ayr', 2566, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7633, NULL, '2012-01-20 12:55:44.058964+00', 'St Ninian''s Strathspey', 2566, 3, 4, 32, NULL, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (7634, NULL, '2012-01-20 12:55:44.064321+00', 'Isabella''s Travels', 2566, 1, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7635, NULL, '2012-01-20 12:55:44.069684+00', 'Road to Girvan, The', 2566, 3, 3, 32, NULL, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (7636, NULL, '2012-01-20 12:55:44.07506+00', 'Danderin''', 2566, 2, 6, 32, NULL, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (7637, NULL, '2012-01-20 12:55:44.080411+00', 'Gold and Silver Strathspey, The', 2566, 3, 8, 32, NULL, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (7638, NULL, '2012-01-20 12:55:44.086631+00', '8000 Miles from Home', 2566, 4, 4, 32, 1, NULL, 392, 0, '');
INSERT INTO 'recording' VALUES (7639, NULL, '2012-01-20 12:55:44.091994+00', 'McMillan Strathspey, The', 2566, 3, 4, 32, NULL, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (7640, NULL, '2012-01-20 12:55:44.097348+00', 'Newton Shore', 2566, 1, 8, 40, NULL, NULL, 346, 0, '');
INSERT INTO 'recording' VALUES (7641, NULL, '2012-01-20 12:55:44.102745+00', 'Eriskay Jig, The', 10046, 2, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (7643, NULL, '2012-01-20 12:55:44.113484+00', 'Gaelic Waltz', 10046, 5, 0, 0, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (7645, NULL, '2012-01-20 12:55:44.124536+00', 'Sleepy Maggie', 10046, 1, 5, 32, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (7646, NULL, '2012-01-20 12:55:44.129888+00', 'Highland Barn Dance', 10046, 50, 0, 16, NULL, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (7647, NULL, '2012-01-20 12:55:44.135215+00', 'Tarry a While', 10046, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (7648, NULL, '2012-01-20 12:55:44.140554+00', 'Bays of Harris', 10046, 50, 0, 0, NULL, NULL, 239, 0, '');
INSERT INTO 'recording' VALUES (7651, NULL, '2012-01-20 12:55:44.156595+00', 'Riverside Jig', 10046, 2, 5, 32, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (7652, NULL, '2012-01-20 12:55:44.162133+00', 'New Killarney Waltz', 10046, 5, 0, 0, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (7654, NULL, '2012-01-20 12:55:44.172845+00', 'Celtic Steps', 10046, 1, 5, 32, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (7655, NULL, '2012-01-20 12:55:44.178194+00', 'Buchanan Strathspey, The', 10046, 3, 3, 32, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (7657, NULL, '2012-01-20 12:55:44.188867+00', 'Blue Danube Waltz, The', 10046, 5, 0, 0, NULL, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (7658, NULL, '2012-01-20 12:55:44.194223+00', 'Orcadian Strip the Willow', 10046, 2, 8, 32, NULL, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (7659, NULL, '2012-01-20 12:55:44.199584+00', 'Highland Schottische', 10046, 3, 12, 8, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (7660, NULL, '2012-01-20 12:55:44.204932+00', 'Flying Scotsman, The', 10046, 1, 4, 32, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (7661, NULL, '2012-01-20 12:55:44.211169+00', 'Kenmuir''s up and Awa''', 2328, 4, 1, 216, 10012, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (7653, NULL, '2022-12-21 10:52:33.477597+00', 'Jackie Tar Two-Step', 10046, 50, 0, 0, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (7649, NULL, '2022-12-22 18:58:05.653392+00', 'Boston Two-Step', 10046, 50, 0, 0, NULL, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (7650, NULL, '2022-12-22 18:59:05.785062+00', 'Gay Gordons', 10046, 50, 0, 16, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (7642, NULL, '2022-12-22 18:59:58.634429+00', 'Mississippi Dip', 10046, 50, 0, 16, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (7644, NULL, '2022-12-23 00:05:31.912712+00', 'Eva Three-Step', 10046, 50, 0, 0, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (7656, NULL, '2022-12-23 00:06:29.093064+00', 'Britannia Two-Step', 10046, 50, 0, 0, NULL, NULL, 159, 0, '');
INSERT INTO 'recording' VALUES (7663, NULL, '2012-01-20 12:55:44.221894+00', 'Langshaw Lassies', 2328, 1, 6, 32, NULL, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (7665, NULL, '2012-01-20 12:55:44.232559+00', 'Marches', 2328, 11, 0, 0, NULL, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (7666, NULL, '2012-01-20 12:55:44.237908+00', 'Pride of Erin Waltz', 2328, 5, 0, 32, NULL, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (7667, NULL, '2012-01-20 12:55:44.243254+00', 'Corn Rigs', 2328, 1, 6, 32, NULL, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (7668, NULL, '2012-01-20 12:55:44.248592+00', 'Looking for a Partner', 2328, 50, 0, 0, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7669, NULL, '2012-01-20 12:55:44.253938+00', 'Keppoch''s Rant', 2328, 3, 4, 32, NULL, NULL, 236, 0, '');
INSERT INTO 'recording' VALUES (7670, NULL, '2012-01-20 12:55:44.259267+00', 'Irish Jigs', 2328, 2, 8, 32, NULL, NULL, 253, 0, '');
INSERT INTO 'recording' VALUES (7671, NULL, '2012-01-20 12:55:44.264595+00', 'Sutters of Selkirk', 2328, 1, 3, 32, NULL, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (7672, NULL, '2012-01-20 12:55:44.269948+00', 'Peter MacLeod', 2328, 11, 0, 0, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (7673, NULL, '2012-01-20 12:55:44.275277+00', 'Waltzes', 2328, 5, 0, 0, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (7674, NULL, '2012-01-20 12:55:44.280622+00', 'Rory o'' More', 2328, 2, 6, 32, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (7675, NULL, '2012-01-20 12:55:44.285964+00', 'Australian Ladies', 2328, 1, 6, 32, NULL, NULL, 236, 0, '');
INSERT INTO 'recording' VALUES (7676, NULL, '2012-01-20 12:55:44.2913+00', 'Eight Men of Moidart, The', 2328, 1, 6, 16, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (7677, NULL, '2012-01-20 12:55:44.296659+00', 'Waltz - June Clover', 2328, 5, 0, 0, NULL, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (7678, NULL, '2012-01-20 12:55:44.302051+00', 'Bonnie Kate of Aberdeen', 2328, 3, 2, 40, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (7679, NULL, '2012-01-20 12:55:44.307392+00', 'Kiss Me Quick, My Mither''s Coming', 2328, 1, 6, 32, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (7680, NULL, '2012-01-20 12:55:44.312744+00', 'Machine Without Horses', 2328, 2, 8, 32, NULL, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (7681, NULL, '2012-01-20 12:55:44.318108+00', 'Tokyo Twenty Five', 10176, 1, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (7682, NULL, '2012-01-20 12:55:44.323473+00', 'Hana Strathspey', 10176, 3, 8, 32, NULL, NULL, 527, 0, '');
INSERT INTO 'recording' VALUES (7683, NULL, '2012-01-20 12:55:44.328806+00', 'Mairi''s Wedding', 10176, 1, 8, 40, NULL, NULL, 356, 0, '');
INSERT INTO 'recording' VALUES (7684, NULL, '2012-01-20 12:55:44.334284+00', 'Waltzes', 10176, 5, 0, 0, NULL, NULL, 299, 0, '');
INSERT INTO 'recording' VALUES (7685, NULL, '2012-01-20 12:55:44.33962+00', 'Waltz', 10176, 5, 0, 0, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (7686, NULL, '2012-01-20 12:55:44.344961+00', 'March', 10176, 11, 0, 0, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (7687, NULL, '2012-01-20 12:55:44.350323+00', 'Bill Clement MBE', 10176, 2, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (7688, NULL, '2012-01-20 12:55:44.355664+00', 'New Waterloo Reel', 3026, 1, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (7689, NULL, '2012-01-20 12:55:44.361452+00', 'Alison Rose', 3026, 3, 4, 32, NULL, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (7690, NULL, '2012-01-20 12:55:44.366806+00', 'Miss Murray of Lintrose', 3026, 1, 8, 32, NULL, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (7691, NULL, '2012-01-20 12:55:44.372151+00', 'Lord Rosslyn''s Fancy', 3026, 2, 8, 32, NULL, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (7693, NULL, '2012-01-20 12:55:44.382866+00', 'Mrs Hepburn Belches', 3026, 1, 8, 48, NULL, NULL, 405, 0, '');
INSERT INTO 'recording' VALUES (7694, NULL, '2012-01-20 12:55:44.388227+00', 'Pretty Ladies', 3026, 3, 1, 80, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (7662, NULL, '2014-03-27 14:26:52.395679+00', 'Hamilton House', 2328, 2, 6, 32, NULL, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (7695, NULL, '2012-01-20 12:55:44.393576+00', 'Frisky, The', 3026, 2, 8, 32, NULL, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (7696, NULL, '2012-01-20 12:55:44.399037+00', 'Trip to Bavaria', 3026, 1, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (7697, NULL, '2012-01-20 12:55:44.404373+00', 'Duchess Tree, The', 3026, 3, 8, 32, NULL, NULL, 517, 0, '');
INSERT INTO 'recording' VALUES (7698, NULL, '2012-01-20 12:55:44.409734+00', 'Lord MacLay''s Reel', 3026, 1, 4, 40, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (7699, NULL, '2012-01-20 12:55:44.415072+00', 'Golden Pheasant', 3026, 2, 8, 40, NULL, NULL, 328, 0, '');
INSERT INTO 'recording' VALUES (7700, NULL, '2012-01-20 12:55:44.420407+00', 'Burns'' Hornpipe', 3026, 1, 4, 32, NULL, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (7701, NULL, '2012-01-20 12:55:44.425771+00', 'Miss Milligan''s Strathspey', 3026, 3, 8, 32, NULL, NULL, 480, 0, '');
INSERT INTO 'recording' VALUES (7702, NULL, '2012-01-20 12:55:44.43112+00', 'Kiss Me Quick, My Mither''s Coming', 3026, 1, 8, 32, NULL, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (7703, NULL, '2012-01-20 12:55:44.436475+00', 'Gay Gordon''s Two Step, The', 10177, 50, 0, 16, NULL, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (7704, NULL, '2012-01-20 12:55:44.441835+00', 'New Kilarney Waltz, The', 10177, 5, 0, 0, NULL, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (7705, NULL, '2012-01-20 12:55:44.447188+00', 'Campbeltown Loch', 10177, 2, 4, 48, NULL, NULL, 210, 1, '');
INSERT INTO 'recording' VALUES (7707, NULL, '2012-01-20 12:55:44.457977+00', 'Quarries'' Jig', 10177, 2, 8, 32, NULL, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (7708, NULL, '2012-01-20 12:55:44.463316+00', 'Melody Foxtrot', 10177, 50, 0, 0, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (7709, NULL, '2012-01-20 12:55:44.468654+00', 'Reel of the Puffins', 10177, 1, 4, 32, NULL, NULL, 150, 1, '');
INSERT INTO 'recording' VALUES (7710, NULL, '2012-01-20 12:55:44.474007+00', 'Southern Two Step, The', 10177, 50, 0, 0, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (7711, NULL, '2012-01-20 12:55:44.479359+00', 'Easter Reel, The', 10177, 1, 4, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (7712, NULL, '2012-01-20 12:55:44.484705+00', 'Ruby Waltz, The', 10177, 5, 0, 0, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (7714, NULL, '2012-01-20 12:55:44.495402+00', 'Catherine Waltz, The', 10177, 5, 0, 0, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (7715, NULL, '2012-01-20 12:55:44.500738+00', 'Dancing Master, The', 10177, 2, 4, 24, NULL, NULL, 107, 0, '');
INSERT INTO 'recording' VALUES (7717, NULL, '2012-01-20 12:55:44.511435+00', 'Festival Glide, The', 10177, 11, 0, 0, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (7718, NULL, '2012-01-20 12:55:44.516782+00', 'Ian Powrie''s Farewell to Auchterarder', 10177, 2, 4, 32, NULL, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (7719, NULL, '2012-01-20 12:55:44.522125+00', 'Call of the Pipes', 10177, 11, 0, 0, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (7720, NULL, '2012-01-20 12:55:44.527483+00', 'Bonny Bells of Heather, The', 10177, 1, 6, 32, NULL, NULL, 211, 1, '');
INSERT INTO 'recording' VALUES (7721, NULL, '2012-01-20 12:55:44.532839+00', 'Gay Gordon''s Two Step, The', 10177, 50, 0, 16, NULL, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (7722, NULL, '2012-01-20 12:55:44.5382+00', 'New Kilarney Waltz, The', 10177, 5, 0, 0, NULL, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (7723, NULL, '2012-01-20 12:55:44.543535+00', 'Campbeltown Loch', 10177, 2, 4, 48, NULL, NULL, 210, 1, '');
INSERT INTO 'recording' VALUES (7725, NULL, '2012-01-20 12:55:44.55423+00', 'Quarries'' Jig', 10177, 2, 8, 32, NULL, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (7726, NULL, '2012-01-20 12:55:44.559618+00', 'Melody Foxtrot', 10177, 50, 0, 0, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (7727, NULL, '2012-01-20 12:55:44.565016+00', 'Reel of the Puffins', 10177, 1, 4, 32, NULL, NULL, 150, 1, '');
INSERT INTO 'recording' VALUES (7728, NULL, '2012-01-20 12:55:44.570456+00', 'Southern Two Step, The', 10177, 50, 0, 0, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (7729, NULL, '2012-01-20 12:55:44.575791+00', 'Easter Reel', 10177, 1, 4, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (7730, NULL, '2012-01-20 12:55:44.581126+00', 'Ruby Waltz, The', 10177, 5, 0, 0, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (7732, NULL, '2012-01-20 12:55:44.591814+00', 'Catherine Waltz, The', 10177, 5, 0, 0, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (7733, NULL, '2012-01-20 12:55:44.597162+00', 'Dancing Master, The', 10177, 2, 4, 24, NULL, NULL, 107, 0, '');
INSERT INTO 'recording' VALUES (7735, NULL, '2012-01-20 12:55:44.607866+00', 'Festival Glide, The', 10177, 11, 0, 0, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (7736, NULL, '2012-01-20 12:55:44.613207+00', 'Ian Powrie''s Farewell to Auchterarder', 10177, 2, 4, 32, NULL, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (7737, NULL, '2012-01-20 12:55:44.618564+00', 'Call of the Pipes', 10177, 11, 0, 0, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (7738, NULL, '2012-01-20 12:55:44.624029+00', 'Bonny Bells of Heather, The', 10177, 1, 6, 32, NULL, NULL, 211, 1, '');
INSERT INTO 'recording' VALUES (7739, NULL, '2012-01-20 12:55:44.62939+00', 'Rock and the Wee Pickle Tow, The', 10183, 2, 5, 32, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (7740, NULL, '2012-01-20 12:55:44.634827+00', 'Medley - 4/4 and 6/8 Marches', 10183, 11, 0, 0, NULL, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (7741, NULL, '2012-01-20 12:55:44.640449+00', 'Mairrit Man''s Favourite, The', 10183, 1, 5, 32, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (7742, NULL, '2012-01-20 12:55:44.646175+00', 'Eva Tree Step, The', 10183, 2, 0, 16, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (7743, NULL, '2012-01-20 12:55:44.651689+00', 'Dunoon Barn Dance, The', 10183, 11, 0, 16, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (7744, NULL, '2012-01-20 12:55:44.657124+00', 'Reel of the 51st Division', 10183, 1, 6, 32, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (7745, NULL, '2012-01-20 12:55:44.662577+00', 'Shetland Waltzes', 10183, 5, 0, 0, NULL, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (7746, NULL, '2012-01-20 12:55:44.668056+00', 'Medley - 2/4 and 6/8 Marches', 10183, 11, 0, 0, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (7747, NULL, '2012-01-20 12:55:44.674555+00', 'Auld Reekie Schottische, The', 10183, 50, 0, 0, NULL, NULL, 115, 0, '');
INSERT INTO 'recording' VALUES (7748, NULL, '2012-01-20 12:55:44.680194+00', 'Gay Gordons', 10183, 11, 0, 16, NULL, NULL, 159, 0, '');
INSERT INTO 'recording' VALUES (7749, NULL, '2012-01-20 12:55:44.687111+00', 'Last of the Lairds, The', 10183, 2, 5, 32, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (7751, NULL, '2012-01-20 12:55:44.698957+00', 'Canadian Barn Dance', 10183, 11, 0, 16, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (7752, NULL, '2012-01-20 12:55:44.705142+00', 'Gaelic Waltz', 10183, 5, 0, 0, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (7753, NULL, '2012-01-20 12:55:44.710548+00', 'Express, The', 10183, 2, 6, 32, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (7724, NULL, '2022-12-25 19:30:39.151264+00', 'White Heather Foxtrot, The', 10177, 50, 0, 0, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (7692, NULL, '2023-01-17 11:55:33.315224+00', 'Blue Mess Jacket', 3026, 3, 4, 32, NULL, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (7754, NULL, '2012-01-20 12:55:44.715941+00', '6/8 Marches', 10183, 11, 0, 0, NULL, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (7755, NULL, '2012-01-20 12:55:44.721363+00', 'Galloway House', 10183, 1, 6, 32, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (7756, NULL, '2012-01-20 12:55:44.726774+00', 'Gaelic Waltz', 10183, 5, 0, 0, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (7757, NULL, '2012-01-20 12:55:44.732176+00', 'Gay Gordons', 10183, 11, 0, 16, NULL, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (7758, NULL, '2012-01-20 12:55:44.737583+00', 'Circassian Circle', 10183, 1, 6, 32, NULL, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (7759, NULL, '2012-01-20 12:55:44.742937+00', 'Modern Waltz', 10183, 5, 0, 0, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (7760, NULL, '2012-01-20 12:55:44.748294+00', 'Scott Skinner Marches', 10183, 11, 0, 0, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (7761, NULL, '2012-01-20 12:55:44.753651+00', 'Roxburgh Castle', 3011, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (7764, NULL, '2012-01-20 12:55:44.769728+00', 'Lennox Love to Blantyre', 3011, 3, 8, 32, NULL, NULL, 510, 0, '');
INSERT INTO 'recording' VALUES (7765, NULL, '2012-01-20 12:55:44.775072+00', 'Oxton Reel, The', 3011, 3, 6, 24, NULL, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (7766, NULL, '2012-01-20 12:55:44.781272+00', 'Threesome Reel, The', 3011, 4, 1, 96, 11, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (7767, NULL, '2012-01-20 12:55:44.786657+00', 'Bob of Fettercairn, The', 3011, 1, 8, 24, NULL, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (7768, NULL, '2012-01-20 12:55:44.792105+00', 'Prince of Orange', 3011, 2, 8, 16, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (7770, NULL, '2012-01-20 12:55:44.802816+00', 'I''ll Mak'' Ye Fain to Follow Me', 3011, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (7771, NULL, '2012-01-20 12:55:44.808162+00', 'Mrs MacLeod', 3011, 1, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (7772, NULL, '2012-01-20 12:55:44.813519+00', 'Sixteensome Reel', 3011, 1, 1, 464, NULL, NULL, 510, 0, '');
INSERT INTO 'recording' VALUES (7777, NULL, '2012-01-20 12:55:44.841147+00', 'Lady Mary Menzies'' Reel', 3006, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7778, NULL, '2012-01-20 12:55:44.847405+00', 'Menzies'' Rant, The', 3006, 1, 8, 32, 9999, NULL, 279, 1, '');
INSERT INTO 'recording' VALUES (7776, NULL, '2014-11-01 00:27:18.745922+00', 'Ye''ll Aye be Welcome Back Again', 3006, 3, 8, 32, NULL, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (7780, NULL, '2012-01-20 12:55:44.85826+00', 'Tartan Plaidie', 3006, 3, 8, 32, NULL, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (7781, NULL, '2012-01-20 12:55:44.863615+00', 'Captain MacDonald''s Fancy', 3006, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7786, NULL, '2012-01-20 12:55:44.890436+00', 'Grassmarket Reel, The', 3006, 1, 5, 32, NULL, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (7787, NULL, '2012-01-20 12:55:44.895794+00', 'Trip to Aberdeen, A', 3137, 2, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (7789, NULL, '2012-01-20 12:55:44.906515+00', 'Captain MacBean''s Reel', 3137, 1, 8, 32, NULL, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (7790, NULL, '2012-01-20 12:55:44.912395+00', 'Countess of Crawford''s Reel, The', 3137, 3, 8, 40, NULL, NULL, 634, 0, '');
INSERT INTO 'recording' VALUES (7793, NULL, '2012-01-20 12:55:44.928502+00', 'Lucy Campbell', 3137, 1, 8, 32, NULL, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (7800, NULL, '2012-01-20 12:55:44.96622+00', 'Valentine, The', 10185, 3, 8, 32, NULL, NULL, 513, 0, '');
INSERT INTO 'recording' VALUES (7802, NULL, '2012-01-20 12:55:44.976905+00', 'Christine M Phillips', 3019, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (7803, NULL, '2012-01-20 12:55:44.982266+00', 'Gardeners'' Fantasia, The', 3019, 3, 3, 32, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (7716, NULL, '2017-06-17 10:52:32.375002+00', 'Southern Rose Waltz, The', 10177, 5, 0, 0, NULL, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (7734, NULL, '2017-06-17 10:52:57.405184+00', 'Southern Rose Waltz, The', 10177, 5, 0, 0, NULL, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (7804, NULL, '2012-01-20 12:55:44.987609+00', 'Scott Meikle', 3019, 1, 4, 32, NULL, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (7805, NULL, '2012-01-20 12:55:44.992957+00', 'Barbara''s Strathspey', 3019, 3, 8, 32, NULL, NULL, 496, 0, '');
INSERT INTO 'recording' VALUES (7806, NULL, '2012-01-20 12:55:44.998336+00', 'Missing Turn, The', 3019, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7807, NULL, '2012-01-20 12:55:45.003733+00', 'Bonnie Tree, The', 3019, 3, 8, 32, NULL, NULL, 494, 0, '');
INSERT INTO 'recording' VALUES (7808, NULL, '2012-01-20 12:55:45.00908+00', 'Best Set in the Hall', 3019, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7809, NULL, '2012-01-20 12:55:45.014454+00', 'High Society', 3019, 1, 4, 40, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (7811, NULL, '2012-01-20 12:55:45.02527+00', 'Links with St Petersburg', 3019, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (7812, NULL, '2012-01-20 12:55:45.030624+00', 'Peggy Spouse MBE', 3019, 3, 8, 32, NULL, NULL, 500, 0, '');
INSERT INTO 'recording' VALUES (7813, NULL, '2012-01-20 12:55:45.035972+00', 'Zoologist, The', 3019, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7814, NULL, '2012-01-20 12:55:45.042198+00', 'President''s Quadrille, The', 3019, 4, 1, 128, 10013, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (7815, NULL, '2012-01-20 12:55:45.04757+00', 'Dashing White Sergeant, The', 3010, 1, 5, 32, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (7816, NULL, '2012-01-20 12:55:45.052919+00', 'Scottish Waltz', 3010, 5, 0, 0, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (7817, NULL, '2012-01-20 12:55:45.058292+00', 'Campbell''s Frolic', 3010, 2, 6, 32, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (7818, NULL, '2012-01-20 12:55:45.063641+00', 'Dalkeith''s Strathspey', 3010, 3, 3, 32, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (7819, NULL, '2012-01-20 12:55:45.068987+00', 'Veleta, The', 3010, 50, 0, 0, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (7820, NULL, '2012-01-20 12:55:45.074557+00', 'Miss Cahoon''s Reel', 3010, 2, 4, 48, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (7822, NULL, '2012-01-20 12:55:45.085441+00', 'Peggy O''Neill', 3010, 5, 0, 0, NULL, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (7823, NULL, '2012-01-20 12:55:45.090789+00', 'Corn Rigs', 3010, 1, 6, 32, NULL, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (7824, NULL, '2012-01-20 12:55:45.096133+00', 'Gay Gordons', 3010, 11, 0, 16, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (7731, NULL, '2020-01-22 23:52:58.645889+00', 'Pensioner''s Reel, The', 10177, 1, 8, 32, NULL, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (7769, NULL, '2020-02-05 16:15:32.595708+00', 'Lord MacDonald''s Reel', 3011, 1, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (7773, NULL, '2021-06-17 14:18:40.484632+00', 'Ye''re Welcome, Charly Stuart', 3006, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7825, NULL, '2012-01-20 12:55:45.101698+00', 'Bridge of Nairn', 3010, 3, 4, 32, NULL, NULL, 221, 0, '');
INSERT INTO 'recording' VALUES (7826, NULL, '2012-01-20 12:55:45.107128+00', 'Scottish Waltz', 3010, 5, 0, 0, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (7827, NULL, '2012-01-20 12:55:45.112468+00', 'Primrose Polka', 3010, 50, 0, 0, NULL, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (7828, NULL, '2012-01-20 12:55:45.117821+00', 'Looking for a Partner', 3010, 50, 0, 0, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (7829, NULL, '2012-01-20 12:55:45.123167+00', 'St Bernard''s Waltz', 3010, 5, 0, 0, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (7831, NULL, '2012-01-20 12:55:45.133892+00', 'Queen Mary Waltz', 3010, 5, 0, 0, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (7832, NULL, '2012-01-20 12:55:45.139236+00', 'Deil amang the Tailors, The', 3010, 1, 6, 32, NULL, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (7833, NULL, '2012-01-20 12:55:45.144658+00', 'Gay Gordons', 3010, 11, 0, 16, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (7834, NULL, '2012-01-20 12:55:45.150006+00', 'Saint Bernard''s Waltz', 3010, 5, 0, 0, NULL, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (7835, NULL, '2012-01-20 12:55:45.155368+00', 'MacDonald of Sleat', 3010, 2, 0, 120, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (7836, NULL, '2012-01-20 12:55:45.160717+00', 'Set of Strathspeys', 3010, 3, 4, 32, NULL, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (7837, NULL, '2012-01-20 12:55:45.166074+00', 'Isle of Skye', 3010, 1, 6, 32, NULL, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (7838, NULL, '2012-01-20 12:55:45.171433+00', 'My Bonnie Lies over the Ocean', 3010, 5, 0, 0, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (7839, NULL, '2012-01-20 12:55:45.177042+00', 'Middling, Thank You', 3010, 2, 4, 40, NULL, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (7840, NULL, '2012-01-20 12:55:45.194201+00', 'Peggy''s Love', 3010, 3, 4, 32, NULL, NULL, 225, 0, '');
INSERT INTO 'recording' VALUES (7841, NULL, '2012-01-20 12:55:45.199569+00', 'Ladies'' Fancy', 3010, 2, 6, 32, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (7842, NULL, '2012-01-20 12:55:45.205284+00', 'Hesitation Waltz', 3010, 5, 0, 0, NULL, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (7843, NULL, '2012-01-20 12:55:45.210741+00', 'Dashing White Sergeant', 3010, 1, 6, 32, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (7844, NULL, '2012-01-20 12:55:45.216118+00', 'Grant''s Reel', 3010, 3, 4, 32, NULL, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (7845, NULL, '2012-01-20 12:55:45.221471+00', 'Waltz', 3010, 5, 0, 0, NULL, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (7846, NULL, '2012-01-20 12:55:45.226846+00', 'Irish Jigs', 3010, 2, 5, 32, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (7847, NULL, '2012-01-20 12:55:45.232176+00', 'Barn Dance', 3010, 50, 0, 0, NULL, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (7848, NULL, '2012-01-20 12:55:45.237508+00', 'Set of Strathspeys', 3010, 3, 4, 32, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (7849, NULL, '2012-01-20 12:55:45.242843+00', 'Strathglass House', 3010, 3, 4, 32, NULL, NULL, 227, 0, '');
INSERT INTO 'recording' VALUES (7850, NULL, '2012-01-20 12:55:45.248317+00', 'Buchan Waltz', 3010, 5, 0, 0, NULL, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (7851, NULL, '2012-01-20 12:55:45.253745+00', 'Pipe Jigs', 10186, 2, 6, 32, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (7852, NULL, '2012-01-20 12:55:45.259174+00', '6/8 Marches', 10186, 11, 0, 0, NULL, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (7853, NULL, '2012-01-20 12:55:45.264501+00', 'Accordion Solo', 10186, 98, 0, 0, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (7785, NULL, '2022-05-29 10:45:30.568145+00', 'Homecoming Dance, The', 3006, 1, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7810, NULL, '2022-09-27 11:56:04.472945+00', 'Flower of Glasgow, The', 3019, 3, 3, 32, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (7763, NULL, '2022-12-22 13:49:54.045769+00', 'Rothesay Country Dance', 3011, 2, 8, 48, NULL, NULL, 405, 0, '');
INSERT INTO 'recording' VALUES (7830, NULL, '2022-12-23 23:34:22.416845+00', 'Haddo House', 3010, 2, 6, 32, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (7854, NULL, '2012-01-20 12:55:45.269857+00', 'Waltz', 10186, 5, 0, 0, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (7855, NULL, '2012-01-20 12:55:45.275177+00', 'Dumbarton Drums', 10186, 1, 6, 32, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (7856, NULL, '2012-01-20 12:55:45.280515+00', 'Fiddle Solo', 10186, 98, 0, 0, NULL, NULL, 127, 0, '');
INSERT INTO 'recording' VALUES (7857, NULL, '2012-01-20 12:55:45.285858+00', 'Gay Gordons', 10186, 11, 0, 16, NULL, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (7858, NULL, '2012-01-20 12:55:45.291201+00', 'Reel', 10186, 1, 6, 32, NULL, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (7859, NULL, '2012-01-20 12:55:45.297405+00', 'Strathspey and Reel', 10186, 4, 1, 64, 5, NULL, 97, 0, '');
INSERT INTO 'recording' VALUES (7860, NULL, '2012-01-20 12:55:45.302765+00', 'Waltz', 10186, 5, 0, 0, NULL, NULL, 120, 0, '');
INSERT INTO 'recording' VALUES (7861, NULL, '2012-01-20 12:55:45.308101+00', 'Roxburgh Castle', 10186, 1, 6, 32, NULL, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (7862, NULL, '2012-01-20 12:55:45.313435+00', 'Accordion Solo', 10186, 5, 0, 0, NULL, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (7863, NULL, '2012-01-20 12:55:45.318763+00', 'Cumberland Reel', 10186, 2, 6, 32, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (7864, NULL, '2012-01-20 12:55:45.324081+00', 'Highland Wedding', 10186, 98, 0, 0, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (7865, NULL, '2012-01-20 12:55:45.329421+00', 'Happy Hours', 3010, 50, 0, 0, NULL, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (7784, NULL, '2014-11-01 00:45:38.720247+00', 'Braes of Tulliemet, The', 3006, 3, 8, 32, NULL, NULL, 500, 0, '');
INSERT INTO 'recording' VALUES (7788, NULL, '2014-11-08 23:06:48.96027+00', 'Keppoch''s Rant', 3137, 3, 8, 32, NULL, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (7791, NULL, '2014-11-08 23:14:22.942561+00', 'Gentle Shepherd, The', 3137, 2, 4, 32, NULL, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (7792, NULL, '2014-11-08 23:16:52.918295+00', 'Miss Heyden', 3137, 3, 8, 40, NULL, NULL, 631, 0, '');
INSERT INTO 'recording' VALUES (7794, NULL, '2014-11-08 23:39:34.585258+00', 'Bonnie Kate of Aberdeen', 3137, 3, 8, 40, NULL, NULL, 628, 0, '');
INSERT INTO 'recording' VALUES (7796, NULL, '2014-11-08 23:55:50.150008+00', 'Perthshire Highlanders', 3137, 3, 8, 32, NULL, NULL, 514, 0, '');
INSERT INTO 'recording' VALUES (7797, NULL, '2014-11-08 23:59:04.429611+00', 'Twenty-First of September', 3137, 1, 8, 40, NULL, NULL, 367, 0, '');
INSERT INTO 'recording' VALUES (7799, NULL, '2014-11-09 00:10:44.222385+00', 'Capital Jig, A', 10185, 2, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (7798, NULL, '2014-11-09 00:05:14.09517+00', 'Donald Bane', 3137, 3, 8, 32, NULL, NULL, 501, 0, '');
INSERT INTO 'recording' VALUES (7801, NULL, '2014-11-09 00:15:32.232573+00', 'Forty-Five Years on', 10185, 1, 4, 40, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (7866, NULL, '2012-01-20 12:55:45.334754+00', 'Jimmy''s Fancy', 3010, 3, 4, 32, NULL, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (7867, NULL, '2012-01-20 12:55:45.340279+00', 'Yodelling Waltz', 3010, 5, 0, 0, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (7868, NULL, '2012-01-20 12:55:45.34562+00', 'Back o'' Bennachie, The', 3010, 1, 6, 32, NULL, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (7869, NULL, '2012-01-20 12:55:45.351017+00', 'Circassian Circle', 3010, 1, 6, 32, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (7870, NULL, '2012-01-20 12:55:45.357419+00', 'March, Strathspey and Reel', 3010, 4, 0, 144, 10014, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (7872, NULL, '2012-01-20 12:55:45.368351+00', 'Listening Waltz, The', 3010, 5, 0, 0, NULL, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (7873, NULL, '2012-01-20 12:55:45.373731+00', 'Athlone Jigs', 3010, 2, 6, 32, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (7874, NULL, '2012-01-20 12:55:45.379089+00', 'Borderers, The', 3010, 11, 0, 0, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (7875, NULL, '2012-01-20 12:55:45.385564+00', 'March, Strathspey and Reel', 3010, 4, 0, 144, 10014, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (7876, NULL, '2012-01-20 12:55:45.391027+00', 'Pride of Erin Waltz, The', 3010, 5, 0, 32, NULL, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (7877, NULL, '2012-01-20 12:55:45.39641+00', 'Rocky Mountain Medley', 3010, 1, 6, 32, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (7878, NULL, '2012-01-20 12:55:45.402727+00', 'March, Strathspey, Reel', 3010, 4, 0, 128, 10016, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (7879, NULL, '2012-01-20 12:55:45.408173+00', 'Crackaboot', 3010, 50, 0, 0, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (7880, NULL, '2012-01-20 12:55:45.413574+00', 'Angus Doddies, The', 3010, 98, 0, 0, NULL, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (7881, NULL, '2012-01-20 12:55:45.418936+00', 'Russe, La', 3010, 1, 3, 64, NULL, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (7882, NULL, '2012-01-20 12:55:45.424307+00', 'Saint Valery Reel, The', 3010, 1, 6, 32, NULL, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (7883, NULL, '2012-01-20 12:55:45.429711+00', 'Black Dance, The', 3010, 1, 6, 32, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (7884, NULL, '2012-01-20 12:55:45.435137+00', 'Dancing Dustman, The', 3010, 50, 0, 0, NULL, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (7885, NULL, '2012-01-20 12:55:45.440562+00', 'Shand''s Special Irish', 3010, 5, 0, 0, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (7886, NULL, '2012-01-20 12:55:45.44642+00', 'Rocky Mountain Medley', 3010, 1, 4, 40, NULL, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (7887, NULL, '2012-01-20 12:55:45.4518+00', 'Medley', 3010, 98, 0, 0, NULL, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (7889, NULL, '2012-01-20 12:55:45.463474+00', 'Strathmore Whirl', 3010, 3, 4, 32, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (7891, NULL, '2012-01-20 12:55:45.474274+00', 'Retreat Medley', 3010, 98, 0, 0, NULL, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (7892, NULL, '2012-01-20 12:55:45.480502+00', 'March, Strathspey and Reel', 3010, 4, 0, 144, 10014, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (7893, NULL, '2012-01-20 12:55:45.485885+00', 'Jiggin'', The', 3010, 2, 6, 32, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (7894, NULL, '2012-01-20 12:55:45.491228+00', 'L'' Entrainante Valse', 3010, 5, 0, 0, NULL, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (7895, NULL, '2012-01-20 12:55:45.496584+00', 'Dundee City Police Jig', 3010, 2, 6, 32, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (7896, NULL, '2012-01-20 12:55:45.501941+00', 'Highland Scottische', 3010, 3, 0, 8, NULL, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (7897, NULL, '2012-01-20 12:55:45.508138+00', 'Medley', 3010, 4, 0, 144, 10015, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (7898, NULL, '2012-01-20 12:55:45.513533+00', 'Scottish Waltzes', 3010, 5, 0, 0, NULL, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (7899, NULL, '2012-01-20 12:55:45.519733+00', 'Hills of Home, The', 3010, 4, 0, 144, 10014, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (7900, NULL, '2012-01-20 12:55:45.525095+00', 'Jacky Tar Dance Set', 3010, 1, 6, 32, NULL, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (7901, NULL, '2012-01-20 12:55:45.531302+00', 'White Clouds in an Azure Sky', 3479, 4, 0, 136, 9998, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (7902, NULL, '2012-01-20 12:55:45.537534+00', 'Acadian Medley', 3479, 4, 0, 152, 9998, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (7904, NULL, '2012-01-20 12:55:45.5491+00', 'From Scotland with Love', 3479, 4, 0, 112, 9998, NULL, 122, 0, '');
INSERT INTO 'recording' VALUES (7905, NULL, '2012-01-20 12:55:45.555323+00', 'Glamis Castle', 3479, 4, 0, 144, 9998, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (7906, NULL, '2012-01-20 12:55:45.560714+00', 'Ashokan Farewell', 3479, 98, 0, 0, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (7907, NULL, '2012-08-31 20:33:49.292303+00', 'Dannsa nan Sgoiltean Beaga {The Dance of the Small Schools}', 3479, 4, 0, 72, 9998, NULL, 87, 0, '');
INSERT INTO 'recording' VALUES (7908, NULL, '2012-01-20 12:55:45.572309+00', 'Pumpkin''s Fancy', 3479, 1, 0, 64, NULL, NULL, 90, 0, '');
INSERT INTO 'recording' VALUES (7909, NULL, '2012-01-20 12:55:45.578689+00', 'Star Swords, The', 3479, 4, 0, 120, 9998, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (7910, NULL, '2012-01-20 12:55:45.584916+00', 'Celtic Reel, The', 3479, 4, 0, 96, 9998, NULL, 107, 0, '');
INSERT INTO 'recording' VALUES (7911, NULL, '2012-01-20 12:55:45.591142+00', 'Wilkinson''s Sword Dance', 3479, 4, 0, 120, 9998, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (7912, NULL, '2012-01-20 12:55:45.597358+00', 'Muckle Wheel, The', 3479, 4, 0, 136, 9998, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (7913, NULL, '2012-01-20 12:55:45.602941+00', 'Highland Cathedral', 3479, 98, 0, 0, NULL, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (7914, NULL, '2012-01-20 12:55:45.60914+00', 'President''s Reel, The', 3479, 4, 0, 112, 9998, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (7915, NULL, '2012-01-20 12:55:45.614522+00', 'Slockit Light, Da', 3479, 98, 0, 0, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (7916, NULL, '2012-01-20 12:55:45.620736+00', 'Bonnie Anne', 3479, 4, 0, 120, 9998, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (7917, NULL, '2012-01-20 12:55:45.626964+00', 'Archers and Fair Isle Tradition, The', 3479, 4, 0, 168, 9998, NULL, 221, 0, '');
INSERT INTO 'recording' VALUES (7918, NULL, '2012-01-20 12:55:45.632329+00', 'Lochanside', 3479, 98, 0, 0, NULL, NULL, 98, 0, '');
INSERT INTO 'recording' VALUES (7919, NULL, '2012-01-20 12:55:45.638541+00', 'Wayward Roots', 3479, 4, 0, 120, 9998, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (7920, NULL, '2012-01-20 12:55:45.643903+00', 'Shilling Reel, The', 3479, 1, 3, 48, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (7921, NULL, '2012-01-20 12:55:45.649247+00', 'Pipe Intro', 10190, 98, 0, 0, NULL, NULL, 84, 0, '');
INSERT INTO 'recording' VALUES (7922, NULL, '2012-01-20 12:55:45.655457+00', 'Muckle Wheel, The', 10190, 4, 0, 136, 9998, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (7923, NULL, '2012-01-20 12:55:45.661685+00', 'Orkney Mischief', 10190, 4, 0, 144, 9998, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (7924, NULL, '2012-01-20 12:55:45.66707+00', 'Weaving of the Tartan, The', 10191, 98, 0, 0, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (7925, NULL, '2012-01-20 12:55:45.673267+00', 'Clyde Ferry Medley', 10191, 4, 0, 136, 9998, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (7926, NULL, '2012-01-20 12:55:45.679501+00', 'Glasgow Weekend', 10191, 4, 0, 80, 9998, NULL, 91, 0, '');
INSERT INTO 'recording' VALUES (7927, NULL, '2012-01-20 12:55:45.685726+00', 'Hardanger to Shetland', 10191, 4, 0, 120, 9998, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (7928, NULL, '2012-01-20 12:55:45.691098+00', 'I Wish They''d Do It Now', 10193, 98, 0, 0, NULL, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (7890, NULL, '2022-12-14 16:38:26.43108+00', 'Saint Bernard''s Waltz', 3010, 5, 0, 0, NULL, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (7888, NULL, '2023-01-12 22:30:35.316426+00', 'March, Strathspey and Reel', 3010, 4, 0, 144, 10014, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (7929, NULL, '2012-01-20 12:55:45.697316+00', 'President''s Reel, The', 10193, 4, 0, 144, 9998, NULL, 124, 0, '');
INSERT INTO 'recording' VALUES (7930, NULL, '2012-01-20 12:55:45.703639+00', 'Angus MacLeod', 10190, 4, 0, 88, 9998, NULL, 103, 0, '');
INSERT INTO 'recording' VALUES (7931, NULL, '2012-01-20 12:55:45.70901+00', 'Songs of the Isles', 10194, 98, 0, 0, NULL, NULL, 358, 0, '');
INSERT INTO 'recording' VALUES (7932, NULL, '2012-01-20 12:55:45.714375+00', 'Accordion Duet', 10194, 98, 0, 0, NULL, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (7933, NULL, '2012-01-20 12:55:45.719716+00', 'Barnyards of Delgaty, The', 10191, 98, 0, 0, NULL, NULL, 98, 0, '');
INSERT INTO 'recording' VALUES (7934, NULL, '2012-01-20 12:55:45.725921+00', 'Wayward Roots', 10191, 4, 0, 136, 9998, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (7935, NULL, '2012-01-20 12:55:45.731266+00', 'Fiddle Solo', 10191, 98, 0, 0, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (7936, NULL, '2012-01-20 12:55:45.737478+00', 'Margaret Lindsay''s Reel', 10191, 4, 0, 80, 9998, NULL, 88, 0, '');
INSERT INTO 'recording' VALUES (7937, NULL, '2012-01-20 12:55:45.742846+00', 'Pipe Solo', 10191, 98, 0, 0, NULL, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (7938, NULL, '2012-01-20 12:55:45.748172+00', 'Shilling Reel, The', 10191, 1, 3, 48, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (7939, NULL, '2012-01-20 12:55:45.753526+00', 'Northlands, The', 10200, 98, 0, 0, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (7940, NULL, '2012-01-20 12:55:45.758863+00', 'Muckin'' O'' Geordies Byre, The', 10200, 2, 4, 32, NULL, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (7941, NULL, '2012-01-20 12:55:45.764203+00', 'Jock O'' Hazeldean', 10200, 5, 0, 0, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (7942, NULL, '2012-01-20 12:55:45.769554+00', 'John MacDonald''s March', 10200, 11, 0, 0, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (7943, NULL, '2012-01-20 12:55:45.774899+00', 'Quendale Bay', 10200, 50, 0, 0, NULL, NULL, 235, 0, '');
INSERT INTO 'recording' VALUES (7944, NULL, '2012-01-20 12:55:45.780239+00', 'Hamish''s Tune', 10200, 1, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (7946, NULL, '2012-01-20 12:55:45.79094+00', 'Backshore Hornpipe, The', 10200, 1, 4, 32, NULL, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (7947, NULL, '2012-01-20 12:55:45.796293+00', 'Starry Nights of Shetland, The', 10200, 5, 0, 0, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (7948, NULL, '2012-01-20 12:55:45.801635+00', 'Tartan, The', 10200, 98, 0, 0, NULL, NULL, 70, 0, '');
INSERT INTO 'recording' VALUES (7949, NULL, '2012-01-20 12:55:45.807015+00', 'Professor Donald McIntyre', 10200, 98, 0, 0, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (7950, NULL, '2012-01-20 12:55:45.812346+00', 'Glasgow Highlanders', 10200, 3, 3, 32, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (7951, NULL, '2012-01-20 12:55:45.817708+00', 'Doune Lodge Two Step, The', 10200, 50, 0, 0, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7952, NULL, '2012-01-20 12:55:45.823187+00', 'When Irish Eyes are Smiling', 10200, 5, 0, 0, NULL, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (7953, NULL, '2012-01-20 12:55:45.828536+00', 'Jig RunRig, The', 10200, 2, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (7954, NULL, '2012-01-20 12:55:45.83387+00', 'Meeting of the Waters', 10200, 98, 0, 0, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (7955, NULL, '2012-01-20 12:55:45.839217+00', 'Haste to the Wedding', 10200, 2, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (7956, NULL, '2012-01-20 12:55:45.844551+00', 'Duke of Perth', 10200, 1, 5, 32, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (7957, NULL, '2012-01-20 12:55:45.849893+00', 'Warm-up Waltz', 10204, 5, 6, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (7959, NULL, '2012-01-20 12:55:45.860581+00', 'Selection of Reels', 10204, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7961, NULL, '2012-01-20 12:55:45.871277+00', 'Selection of Jigs', 10204, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7962, NULL, '2012-01-20 12:55:45.876614+00', 'Galloway House', 10204, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7963, NULL, '2012-01-20 12:55:45.881968+00', 'Selection of Strathspeys', 10204, 3, 8, 32, NULL, NULL, 519, 0, '');
INSERT INTO 'recording' VALUES (7964, NULL, '2012-01-20 12:55:45.887309+00', 'Selection of Jigs', 10204, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7965, NULL, '2012-01-20 12:55:45.892658+00', 'Michelle Depledge of Preston', 10204, 3, 8, 32, NULL, NULL, 519, 0, '');
INSERT INTO 'recording' VALUES (7966, NULL, '2012-01-20 12:55:45.898023+00', 'Selection of Reels', 10204, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7967, NULL, '2012-01-20 12:55:45.903367+00', 'Grand March', 10209, 11, 0, 0, NULL, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (7968, NULL, '2012-01-20 12:55:45.908711+00', 'Reel of the 51st Division', 10209, 1, 8, 32, NULL, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (7969, NULL, '2012-01-20 12:55:45.914527+00', 'Hamilton House', 10209, 2, 8, 32, NULL, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (7970, NULL, '2012-01-20 12:55:45.919865+00', 'Canadian Barn Dance', 10209, 11, 0, 16, NULL, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (7972, NULL, '2012-01-20 12:55:45.930639+00', 'Eightsome Reel, The', 10209, 1, 0, 464, NULL, NULL, 489, 0, '');
INSERT INTO 'recording' VALUES (7973, NULL, '2012-01-20 12:55:45.936899+00', 'Foursome Reel, The', 10209, 4, 0, 136, 10011, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (7974, NULL, '2012-01-20 12:55:45.942285+00', 'Saint Bernard''s Waltz', 10209, 5, 0, 16, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (7975, NULL, '2012-01-20 12:55:45.947627+00', 'Dashing White Sergeant', 10209, 1, 6, 32, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (7976, NULL, '2012-01-20 12:55:45.953115+00', 'Britannia Two Step', 10209, 11, 0, 16, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (7977, NULL, '2012-01-20 12:55:45.958472+00', 'Duke and Duchess of Edinburgh', 10209, 1, 8, 40, NULL, NULL, 337, 0, '');
INSERT INTO 'recording' VALUES (7978, NULL, '2012-01-20 12:55:45.963834+00', 'Glasgow Highlanders', 10209, 3, 8, 32, NULL, NULL, 484, 1, '');
INSERT INTO 'recording' VALUES (7979, NULL, '2012-01-20 12:55:45.969182+00', 'Duke of Perth', 10209, 1, 8, 32, NULL, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (7980, NULL, '2012-01-20 12:55:45.974539+00', 'Postie''s Jig', 10209, 2, 4, 32, NULL, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (7982, NULL, '2012-01-20 12:55:45.985231+00', 'City of Stirling Reel', 10209, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (7983, NULL, '2012-01-20 12:55:45.990579+00', 'Shetland Welcome, A', 10209, 2, 4, 32, NULL, NULL, 150, 1, '');
INSERT INTO 'recording' VALUES (7984, NULL, '2012-01-20 12:55:45.995925+00', 'New Scotland Strathspey', 10209, 3, 4, 40, NULL, NULL, 307, 0, '');
INSERT INTO 'recording' VALUES (7985, NULL, '2012-01-20 12:55:46.001273+00', 'Plantation Reel, The', 10209, 1, 5, 32, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (7960, NULL, '2021-08-16 14:19:18.861853+00', 'Selection of Strathspeys', 10204, 3, 8, 32, NULL, NULL, 519, 0, '');
INSERT INTO 'recording' VALUES (7986, NULL, '2012-01-20 12:55:46.006658+00', 'Pines of Pitlochry, The', 10209, 2, 8, 48, NULL, NULL, 415, 0, '');
INSERT INTO 'recording' VALUES (7988, NULL, '2012-01-20 12:55:46.017418+00', 'Duke of Edinburgh''s Welcome to Shetland, The', 10209, 1, 4, 32, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (7989, NULL, '2012-01-20 12:55:46.022789+00', 'Birls Allowed', 10209, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (7990, NULL, '2012-01-20 12:55:46.028132+00', 'Glenalmond Gamekeeper, The', 10209, 1, 8, 40, NULL, NULL, 355, 0, '');
INSERT INTO 'recording' VALUES (7991, NULL, '2012-01-20 12:55:46.034346+00', 'Schiehallion', 10209, 4, 0, 128, 2, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (7992, NULL, '2012-01-20 12:55:46.039709+00', 'Waggle o'' the Kilt, The', 10209, 2, 8, 40, NULL, NULL, 336, 0, '');
INSERT INTO 'recording' VALUES (7993, NULL, '2012-01-20 12:55:46.045044+00', 'Reel Archie, The', 10209, 1, 4, 32, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (7994, NULL, '2012-01-20 12:55:46.050524+00', 'Father Connelly''s Jig', 10209, 2, 4, 64, NULL, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (7032, NULL, '2018-10-13 19:31:08.808377+00', 'Starter for Ten, A', 10076, 2, 5, 32, NULL, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (7996, NULL, '2012-01-20 12:55:46.06123+00', 'Gaelforce Wind', 10209, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (7997, NULL, '2012-01-20 12:55:46.066593+00', 'Never at Sea', 10209, 1, 6, 48, NULL, NULL, 317, 0, '');
INSERT INTO 'recording' VALUES (7998, NULL, '2012-01-20 12:55:46.071924+00', 'Riverside, The', 10209, 2, 6, 32, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (8000, NULL, '2012-01-20 12:55:46.082616+00', 'Black Mountain Reel', 10209, 1, 5, 32, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (8002, NULL, '2012-01-20 12:55:46.093324+00', 'Wilma''s Waltz', 10209, 5, 0, 32, NULL, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (8003, NULL, '2012-01-20 12:55:46.098669+00', 'Eva Three Step', 10209, 11, 0, 16, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (8005, NULL, '2012-01-20 12:55:46.156945+00', 'Waltz Country Dance', 10209, 5, 4, 40, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (8007, NULL, '2012-01-20 12:55:46.165492+00', 'Circassian Circle', 10209, 1, 6, 32, NULL, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (8012, NULL, '2012-01-20 12:55:46.186063+00', 'Call of the Pipes', 10209, 11, 0, 16, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (8013, NULL, '2012-01-20 12:55:46.190133+00', 'Orcadian Strip the Willow', 10209, 2, 8, 32, NULL, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (8014, NULL, '2012-01-20 12:55:46.194418+00', 'Flying Scotsman, The', 10209, 1, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (8016, NULL, '2012-01-20 12:55:46.209636+00', 'Reels', 10233, 1, 8, 32, NULL, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (8017, NULL, '2012-01-20 12:55:46.215118+00', 'Canadian Barn Dance', 10233, 11, 0, 16, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (7958, NULL, '2022-12-12 23:06:08.992718+00', 'Selection of Jigs', 10204, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7999, NULL, '2022-12-13 22:10:32.621922+00', 'Gay Gordon Two Step, The', 10209, 11, 0, 16, NULL, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (8004, NULL, '2022-12-13 22:13:42.118805+00', 'Gypsy Tap, The', 10209, 1, 6, 32, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (8010, NULL, '2022-12-13 22:16:03.182996+00', 'Waltz of the Bells', 10209, 5, 0, 32, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (8008, NULL, '2022-12-28 12:41:14.285172+00', 'White Heather Foxtrot, The', 10209, 50, 0, 16, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (8001, NULL, '2022-12-25 21:51:01.07841+00', 'Baden-Powell, The', 10209, 11, 0, 8, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (8006, NULL, '2022-12-25 22:05:46.3109+00', 'Siege of Ennis, The', 10209, 2, 8, 32, NULL, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (8009, NULL, '2022-12-26 18:42:42.677997+00', 'Waves of Tory, The', 10209, 1, 5, 48, NULL, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (8011, NULL, '2022-12-26 18:50:44.037221+00', 'Anniversary Twostep, The', 10209, 50, 0, 16, NULL, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (8018, NULL, '2012-01-20 12:55:46.22244+00', 'Eva Three Step', 10233, 2, 8, 16, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (8019, NULL, '2012-01-20 12:55:46.227802+00', 'Gaelic Waltz', 10233, 5, 0, 0, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (8020, NULL, '2012-01-20 12:55:46.233697+00', 'Jigs', 10233, 2, 8, 32, NULL, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (8021, NULL, '2012-01-20 12:55:46.239111+00', 'Pipe Medley', 10233, 98, 0, 0, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (8022, NULL, '2012-01-20 12:55:46.244452+00', 'Reels', 10233, 1, 8, 32, NULL, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (8023, NULL, '2012-01-20 12:55:46.249814+00', '6/8 Marches', 10233, 11, 0, 0, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (8025, NULL, '2012-01-20 12:55:46.260509+00', 'Jigs', 10233, 2, 8, 32, NULL, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (8026, NULL, '2012-01-20 12:55:46.266069+00', '4/4 Marches', 10233, 11, 0, 0, NULL, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (8027, NULL, '2012-01-20 12:55:46.271422+00', 'Dunoon Barn Dance', 10233, 11, 0, 16, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (8028, NULL, '2012-01-20 12:55:46.276773+00', 'Jigs', 10233, 2, 8, 32, NULL, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (8029, NULL, '2012-01-20 12:55:46.282124+00', 'Scottish Waltz', 10233, 5, 0, 32, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (8030, NULL, '2012-01-20 12:55:46.287464+00', 'Reels', 10233, 1, 5, 32, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (8031, NULL, '2012-01-20 12:55:46.292798+00', 'Kathy Campbell''s Reel', 10237, 1, 8, 32, NULL, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (8032, NULL, '2012-01-20 12:55:46.298206+00', 'Contrary Mary', 10237, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (8033, NULL, '2012-01-20 12:55:46.303555+00', 'David Queen Strathspey, The', 10237, 3, 3, 32, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (8034, NULL, '2012-01-20 12:55:46.308927+00', 'By Invitation', 10237, 1, 4, 32, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (8035, NULL, '2012-01-20 12:55:46.314291+00', 'Ken and Lavinia''s Ruby', 10237, 3, 4, 40, NULL, NULL, 306, 0, '');
INSERT INTO 'recording' VALUES (8037, NULL, '2012-01-20 12:55:46.324985+00', 'JillwithaJ', 10237, 1, 3, 48, NULL, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (8038, NULL, '2012-01-20 12:55:46.330326+00', 'Berry Brow', 10237, 3, 4, 32, NULL, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (8039, NULL, '2012-01-20 12:55:46.335656+00', 'Far Distant Land, A', 10237, 1, 8, 48, NULL, NULL, 427, 0, '');
INSERT INTO 'recording' VALUES (8040, NULL, '2012-01-20 12:55:46.341003+00', 'Ribblesdale Strathspey, The', 10237, 3, 3, 32, NULL, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (8041, NULL, '2012-01-20 12:55:46.346364+00', 'Long Frank''s Reel', 10237, 1, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (8043, NULL, '2012-01-20 12:55:46.357084+00', 'Red Rum', 10237, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (8047, NULL, '2012-01-20 12:55:46.378712+00', 'Aird of Coigach', 10247, 2, 4, 48, NULL, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (8048, NULL, '2012-01-20 12:55:46.384138+00', 'Whigmaleeries', 10247, 1, 8, 32, NULL, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (8049, NULL, '2012-01-20 12:55:46.38967+00', 'Blue Mess Jacket', 10247, 3, 4, 32, NULL, NULL, 244, 0, '');
INSERT INTO 'recording' VALUES (8050, NULL, '2012-01-20 12:55:46.395031+00', 'Old Nick''s Lumber Room', 10247, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (8051, NULL, '2012-01-20 12:55:46.400372+00', 'Sloane Square', 10247, 3, 1, 64, NULL, NULL, 128, 0, '');
INSERT INTO 'recording' VALUES (8053, NULL, '2012-01-20 12:55:46.411066+00', 'Rothesay Rant, The', 10247, 2, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (7987, NULL, '2017-07-27 14:49:41.976016+00', 'Alison Rose', 10209, 3, 4, 32, NULL, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (8042, NULL, '2019-10-29 11:06:40.205591+00', 'Golden Birthday Strathspey', 10237, 3, 4, 32, NULL, NULL, 248, 0, '');
INSERT INTO 'recording' VALUES (8057, NULL, '2012-01-20 12:55:46.432462+00', 'Epping Hundred', 10247, 1, 8, 32, NULL, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (8059, NULL, '2012-01-20 12:55:46.443162+00', 'Spinnaker Tower, The', 10247, 2, 8, 40, NULL, NULL, 341, 0, '');
INSERT INTO 'recording' VALUES (8060, NULL, '2012-01-20 12:55:46.448523+00', 'Gavin''s Reel', 10247, 1, 5, 32, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (8061, NULL, '2012-01-20 12:55:46.453886+00', 'Birks of Invermay', 10247, 3, 8, 32, NULL, NULL, 487, 0, '');
INSERT INTO 'recording' VALUES (8062, NULL, '2012-01-20 12:55:46.459246+00', 'Startled Rabbits', 10247, 2, 5, 32, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (8064, NULL, '2012-01-20 12:55:46.470051+00', 'Charlestown Chaser', 10034, 2, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (8065, NULL, '2012-01-20 12:55:46.475397+00', 'Brudenell Jig, The', 10034, 2, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (8066, NULL, '2012-01-20 12:55:46.480745+00', 'Waratah Weaver, The', 10034, 2, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (8067, NULL, '2012-01-20 12:55:46.486088+00', 'Mr Michael Bear''s Reel', 10034, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (8068, NULL, '2012-01-20 12:55:46.491448+00', 'Barmkin, The', 10034, 1, 1, 88, NULL, NULL, 103, 0, '');
INSERT INTO 'recording' VALUES (8069, NULL, '2012-01-20 12:55:46.496783+00', 'Jig to the Music', 10034, 2, 3, 32, NULL, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (8071, NULL, '2012-01-20 12:55:46.507493+00', 'Hedwig''s Reel', 10018, 1, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (8072, NULL, '2012-01-20 12:55:46.512839+00', 'Red Nose Jig', 10018, 2, 4, 40, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (8073, NULL, '2012-01-20 12:55:46.518185+00', 'Domino Five', 10018, 1, 5, 32, NULL, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (8074, NULL, '2012-01-20 12:55:46.523542+00', 'It''s All Right', 10018, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (8075, NULL, '2012-01-20 12:55:46.528892+00', 'It''s nae Bother', 10018, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (8076, NULL, '2012-01-20 12:55:46.534278+00', 'Another Woodland Wander', 10018, 2, 4, 32, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (8077, NULL, '2012-01-20 12:55:46.539644+00', 'Mary Erskine', 10018, 1, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (8036, NULL, '2020-01-24 21:36:00.61556+00', 'Carleton Jig, The', 10237, 2, 4, 32, NULL, NULL, 149, 1, '');
INSERT INTO 'recording' VALUES (8058, NULL, '2019-11-27 06:58:29.834402+00', 'Rose of Dunure', 10247, 3, 3, 32, NULL, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (8015, NULL, '2020-01-27 09:08:10.709546+00', 'Kirrie March', 10233, 11, 0, 16, NULL, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (8055, NULL, '2021-08-17 08:52:12.833252+00', 'Bedrule', 10247, 3, 8, 32, NULL, NULL, 486, 0, '');
INSERT INTO 'recording' VALUES (8078, NULL, '2012-01-20 12:55:46.54506+00', 'Weathercock, The', 10018, 2, 4, 32, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (8079, NULL, '2012-01-20 12:55:46.550413+00', 'Longfield Reel', 10248, 1, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (8080, NULL, '2012-01-20 12:55:46.55577+00', 'Granville Market', 10248, 2, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (8081, NULL, '2012-01-20 12:55:46.561114+00', 'Provost Wynd, The', 10248, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (8082, NULL, '2012-01-20 12:55:46.566489+00', 'Golden Bracken', 10248, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (8084, NULL, '2012-01-20 12:55:46.577248+00', 'Lass of Richmond Hill, The', 10248, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (8086, NULL, '2012-01-20 12:55:46.587948+00', 'Dancing Man, The', 10248, 1, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (8087, NULL, '2012-01-20 12:55:46.593484+00', 'Warm Up March', 3023, 11, 0, 0, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (8088, NULL, '2012-01-20 12:55:46.598843+00', 'Warm Up Waltz', 3023, 5, 0, 0, NULL, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (8089, NULL, '2012-01-20 12:55:46.60426+00', 'Mrs Stuart Linnell', 3023, 1, 8, 40, NULL, NULL, 361, 0, '');
INSERT INTO 'recording' VALUES (8091, NULL, '2012-01-20 12:55:46.61495+00', 'Muirland Willie', 3023, 2, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (8092, NULL, '2012-01-20 12:55:46.620393+00', 'Midnight Ferry, The', 3023, 1, 4, 40, NULL, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (8093, NULL, '2012-01-20 12:55:46.625755+00', 'Tribute to Drummond Cook', 3023, 3, 4, 32, NULL, NULL, 263, 1, '');
INSERT INTO 'recording' VALUES (8094, NULL, '2012-01-20 12:55:46.63111+00', 'Tribute to the Borders', 3023, 2, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (8095, NULL, '2012-01-20 12:55:46.636455+00', 'Minister on the Loch, The', 3023, 3, 3, 32, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (8096, NULL, '2012-01-20 12:55:46.641814+00', 'Aird of Coigach', 3023, 2, 4, 48, NULL, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (8097, NULL, '2012-01-20 12:55:46.64715+00', 'Reel for Davina, A', 3023, 1, 4, 32, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (8098, NULL, '2012-01-20 12:55:46.652497+00', 'Anne Sheach''s Strathspey', 3023, 3, 3, 32, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (8099, NULL, '2012-01-20 12:55:46.657874+00', 'Raven''s Dance, The', 3023, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (8100, NULL, '2012-01-20 12:55:46.663224+00', 'Outer Circle, The', 3023, 1, 8, 48, NULL, NULL, 437, 0, '');
INSERT INTO 'recording' VALUES (8102, NULL, '2012-01-20 12:55:46.673933+00', 'Lochalsh Reel, The', 3023, 1, 8, 40, NULL, NULL, 362, 0, '');
INSERT INTO 'recording' VALUES (8103, NULL, '2012-01-20 12:55:46.679272+00', 'Never at Sea', 3023, 1, 3, 48, NULL, NULL, 172, 1, '');
INSERT INTO 'recording' VALUES (8104, NULL, '2012-01-20 12:55:46.684616+00', 'Eva Three Step, The', 10177, 50, 0, 16, NULL, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (8105, NULL, '2012-01-20 12:55:46.689975+00', 'Duthie Park', 10177, 2, 4, 32, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (8106, NULL, '2012-01-20 12:55:46.69542+00', 'New Hesitation Waltz, The', 10177, 5, 0, 0, NULL, NULL, 241, 0, '');
INSERT INTO 'recording' VALUES (8107, NULL, '2012-01-20 12:55:46.700765+00', 'Prince Charles of Edinburgh', 10177, 1, 4, 40, NULL, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (8108, NULL, '2012-01-20 12:55:46.706121+00', 'Silver Two Step, The', 10177, 50, 0, 0, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (8109, NULL, '2012-01-20 12:55:46.711461+00', 'Elephant''s Stampede, The', 10177, 2, 4, 48, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (8110, NULL, '2012-01-20 12:55:46.716808+00', 'Fiona''s Polka', 10177, 50, 0, 0, NULL, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (8083, NULL, '2022-12-09 19:59:16.260373+00', 'Glenrothes, The', 10248, 2, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (8070, NULL, '2022-12-10 11:14:28.43152+00', 'Easy Peasy', 10034, 1, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (8024, NULL, '2022-12-14 16:36:44.596824+00', 'Pride of Erin Waltz', 10233, 5, 0, 32, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (8044, NULL, '2022-12-22 18:57:12.58295+00', 'Don and Dee''s Reel', 10237, 1, 5, 32, NULL, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (8056, NULL, '2022-12-23 23:33:30.220833+00', 'My Heather Hills', 10247, 2, 3, 48, NULL, NULL, 164, 1, '');
INSERT INTO 'recording' VALUES (8111, NULL, '2012-01-20 12:55:46.722169+00', 'Hooper''s Jig', 10177, 2, 8, 32, NULL, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (8112, NULL, '2012-01-20 12:55:46.727524+00', 'Pride of Erin Waltz, The', 10177, 5, 0, 32, NULL, NULL, 235, 0, '');
INSERT INTO 'recording' VALUES (8113, NULL, '2012-01-20 12:55:46.732878+00', 'Blooms of Bon Accord', 10177, 1, 4, 32, NULL, NULL, 148, 1, '');
INSERT INTO 'recording' VALUES (8114, NULL, '2012-01-20 12:55:46.738399+00', 'Flirtation Two Step, The', 10177, 50, 0, 0, NULL, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (8115, NULL, '2012-01-20 12:55:46.743762+00', 'Orkney Reel, The', 10177, 1, 1, 96, NULL, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (8116, NULL, '2012-01-20 12:55:46.749107+00', 'George Ella Blues (Quickstep), The', 10177, 50, 0, 0, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (8117, NULL, '2012-01-20 12:55:46.754468+00', 'MacLeod''s Fancy', 10177, 2, 4, 32, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (8118, NULL, '2012-01-20 12:55:46.759794+00', 'Edinburgh Mixture, The', 10177, 11, 0, 0, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (8119, NULL, '2012-01-20 12:55:46.765135+00', 'Todlen Hame', 10177, 2, 8, 32, NULL, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (8120, NULL, '2012-01-20 12:55:46.770514+00', 'Dinky One Step, The', 10177, 50, 0, 0, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (8121, NULL, '2012-01-20 12:55:46.77587+00', 'Falls of Rogie, The', 10177, 1, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (8122, NULL, '2012-01-20 12:55:46.781225+00', 'Petronella', 10267, 1, 5, 32, NULL, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (8123, NULL, '2012-01-20 12:55:46.786582+00', 'Boston Two Step', 10267, 50, 0, 16, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (8054, NULL, '2014-11-15 22:50:32.715395+00', 'Tempête, La', 10247, 1, 4, 48, NULL, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (8124, NULL, '2012-01-20 12:55:46.791907+00', 'Scottish Reform', 10267, 2, 6, 32, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (8125, NULL, '2012-01-20 12:55:46.797252+00', 'Pride of Erin Waltz', 10267, 5, 0, 0, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (8126, NULL, '2012-01-20 12:55:46.802617+00', 'Highland Scottische', 10267, 3, 0, 8, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (8127, NULL, '2012-01-20 12:55:46.807959+00', 'Scottish Emigrant', 10267, 98, 0, 0, NULL, NULL, 80, 0, '');
INSERT INTO 'recording' VALUES (8129, NULL, '2012-01-20 12:55:46.818649+00', 'St Bernards Waltz', 10267, 5, 0, 0, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (8130, NULL, '2012-01-20 12:55:46.824162+00', 'Canadian Barn Dance', 10267, 50, 0, 16, NULL, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (8131, NULL, '2012-01-20 12:55:46.829522+00', 'Rory o'' More', 10267, 2, 6, 32, NULL, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (8132, NULL, '2012-01-20 12:55:46.834862+00', 'Reel', 10267, 1, 1, 176, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (8133, NULL, '2012-01-20 12:55:46.8402+00', 'Lassie Valse', 10267, 5, 0, 0, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (8134, NULL, '2012-01-20 12:55:46.845689+00', 'Haymakers', 10267, 2, 4, 48, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (8135, NULL, '2012-01-20 12:55:46.851044+00', 'Drops of Brandy', 10267, 2, 6, 32, NULL, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (8136, NULL, '2012-01-20 12:55:46.856389+00', 'Highland Scottische', 10267, 3, 0, 8, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (8137, NULL, '2012-01-20 12:55:46.86177+00', 'Inver Lasses', 10267, 1, 5, 32, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (8138, NULL, '2012-01-20 12:55:46.86713+00', 'Blaze Away', 10267, 50, 0, 0, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (8139, NULL, '2012-01-20 12:55:46.872454+00', 'Chi mi na Morbheanna', 10267, 5, 0, 0, NULL, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (8140, NULL, '2012-01-20 12:55:46.87869+00', 'Foursome Reel, The', 10267, 4, 0, 64, 5, NULL, 85, 0, '');
INSERT INTO 'recording' VALUES (8063, NULL, '2016-11-17 15:55:52.835315+00', 'Loch Ness Monster, The', 10034, 1, 5, 32, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (8141, NULL, '2012-01-20 12:55:46.884049+00', 'Russe, La', 3065, 1, 3, 64, NULL, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (8142, NULL, '2012-01-20 12:55:46.889395+00', 'Isle of Skye', 3065, 1, 5, 32, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (8143, NULL, '2012-01-20 12:55:46.894764+00', 'Tibby Fowler O'' The Glen', 3065, 3, 3, 32, NULL, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (8144, NULL, '2012-01-20 12:55:46.900116+00', 'River Cree, The', 3065, 2, 5, 32, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (8145, NULL, '2012-01-20 12:55:46.905464+00', 'Bonnie Anne', 3065, 2, 1, 96, NULL, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (8146, NULL, '2012-01-20 12:55:46.911272+00', 'Pride of Erin Waltz', 3065, 5, 5, 32, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (8147, NULL, '2012-01-20 12:55:46.916678+00', 'Duke of Perth', 3065, 1, 8, 32, NULL, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (8149, NULL, '2012-01-20 12:55:46.927409+00', 'Dundee Reel', 3065, 2, 5, 32, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (8150, NULL, '2012-01-20 12:55:46.932762+00', 'Dunoon Barn Dance', 3065, 3, 12, 16, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (8151, NULL, '2012-01-20 12:55:46.938159+00', 'Saint Bernard''s Waltz', 3065, 5, 0, 16, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (8152, NULL, '2012-01-20 12:55:46.94353+00', 'Strip the Willow', 3065, 2, 4, 32, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (8153, NULL, '2012-01-20 12:55:46.948878+00', 'Triumph, The', 3065, 1, 8, 24, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (8154, NULL, '2012-01-20 12:55:46.954245+00', 'Waltz Country Dance', 3065, 5, 4, 40, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (8155, NULL, '2012-01-20 12:55:46.9596+00', 'Grand March', 3065, 11, 0, 160, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (8156, NULL, '2012-01-20 12:55:46.965076+00', 'Gay Gordons', 10268, 11, 2, 16, NULL, NULL, 48, 0, '');
INSERT INTO 'recording' VALUES (8157, NULL, '2012-01-20 12:55:46.970455+00', 'Circassian Circle', 10268, 1, 2, 32, NULL, NULL, 78, 0, '');
INSERT INTO 'recording' VALUES (8158, NULL, '2012-01-20 12:55:46.975812+00', 'Hamilton House', 10268, 2, 2, 32, NULL, NULL, 73, 0, '');
INSERT INTO 'recording' VALUES (8159, NULL, '2012-01-20 12:55:46.981198+00', 'Duke of Perth', 10268, 1, 2, 32, NULL, NULL, 78, 0, '');
INSERT INTO 'recording' VALUES (8160, NULL, '2012-01-20 12:55:46.986558+00', 'Postie''s Jig', 10268, 2, 2, 32, NULL, NULL, 74, 0, '');
INSERT INTO 'recording' VALUES (8161, NULL, '2012-01-20 12:55:46.991919+00', 'Dashing White Sergeant, The', 10268, 1, 2, 32, NULL, NULL, 73, 0, '');
INSERT INTO 'recording' VALUES (8162, NULL, '2012-01-20 12:55:46.997272+00', 'Duke of Atholl''s Reel, The', 10268, 2, 2, 32, NULL, NULL, 74, 0, '');
INSERT INTO 'recording' VALUES (8163, NULL, '2012-01-20 12:55:47.002627+00', 'Reel of the 51st Division, The', 10268, 1, 2, 32, NULL, NULL, 66, 0, '');
INSERT INTO 'recording' VALUES (8148, NULL, '2019-12-12 21:05:54.711845+00', 'Shepherd''s Crook, The', 3065, 3, 1, 72, NULL, NULL, 127, 0, '');
INSERT INTO 'recording' VALUES (8164, NULL, '2012-01-20 12:55:47.007986+00', 'Strip the Willow', 10268, 2, 2, 40, NULL, NULL, 92, 0, '');
INSERT INTO 'recording' VALUES (8166, NULL, '2012-01-20 12:55:47.018783+00', 'Gay Gordons', 10268, 11, 8, 16, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (8167, NULL, '2012-01-20 12:55:47.02413+00', 'Circassian Circle', 10268, 1, 4, 32, NULL, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (8168, NULL, '2012-01-20 12:55:47.029496+00', 'Hamilton House', 10268, 2, 8, 32, NULL, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (8169, NULL, '2012-01-20 12:55:47.034847+00', 'Duke of Perth', 10268, 1, 8, 32, NULL, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (8170, NULL, '2012-01-20 12:55:47.040204+00', 'Postie''s Jig', 10268, 2, 4, 32, NULL, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (8171, NULL, '2012-01-20 12:55:47.045559+00', 'Dashing White Sergeant, The', 10268, 1, 6, 32, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (8172, NULL, '2012-01-20 12:55:47.050921+00', 'Duke of Atholl''s Reel, The', 10268, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (8173, NULL, '2012-01-20 12:55:47.056299+00', 'Reel of the 51st Division, The', 10268, 1, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (8174, NULL, '2012-01-20 12:55:47.061847+00', 'Strip the Willow', 10268, 2, 4, 40, NULL, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (8175, NULL, '2012-01-20 12:55:47.067261+00', 'Eightsome Reel, The', 10268, 1, 1, 464, NULL, NULL, 496, 0, '');
INSERT INTO 'recording' VALUES (8176, NULL, '2012-01-20 12:55:47.072659+00', 'Auld Lang Syne', 10268, 98, 0, 0, NULL, NULL, 98, 0, '');
INSERT INTO 'recording' VALUES (8177, NULL, '2012-01-20 12:55:47.078109+00', 'Shiftin'' Bobbins', 10037, 1, 8, 32, NULL, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (8178, NULL, '2012-01-20 12:55:47.083561+00', 'Eva Three Step', 10037, 2, 8, 16, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (8180, NULL, '2012-01-20 12:55:47.094282+00', 'Luckenbooth Brooch, The', 10037, 2, 8, 32, NULL, NULL, 254, 0, '');
INSERT INTO 'recording' VALUES (8181, NULL, '2012-01-20 12:55:47.099706+00', 'Bonnie Gallowa''', 10037, 98, 0, 0, NULL, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (8182, NULL, '2012-01-20 12:55:47.10536+00', 'Canadian Barn Dance', 10037, 11, 0, 16, NULL, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (8183, NULL, '2012-01-20 12:55:47.110721+00', 'Black Mountain Reel', 10037, 1, 5, 32, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (8184, NULL, '2012-01-20 12:55:47.116085+00', 'Square Tango', 10037, 50, 0, 0, NULL, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (8185, NULL, '2012-01-20 12:55:47.121456+00', 'Boston Two Step', 10037, 50, 0, 16, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (8186, NULL, '2012-01-20 12:55:47.126824+00', 'Wishing Well, The', 10037, 3, 4, 32, NULL, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (8188, NULL, '2012-01-20 12:55:47.137572+00', 'Reel of the 51st Division, The', 10037, 1, 8, 32, NULL, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (8189, NULL, '2012-01-20 12:55:47.142934+00', 'Man''s a Man, A', 10037, 98, 0, 0, NULL, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (8190, NULL, '2012-01-20 12:55:47.148271+00', 'Classic Pipe Marches', 10037, 11, 0, 0, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (8191, NULL, '2012-01-20 12:55:47.153703+00', 'Slow Foxtrot', 10037, 50, 0, 0, NULL, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (8192, NULL, '2012-01-20 12:55:47.159066+00', 'Gay Gordons', 10037, 11, 0, 16, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (8193, NULL, '2012-01-20 12:55:47.164422+00', 'Strip the Willow', 10037, 2, 8, 32, NULL, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (8194, NULL, '2012-01-20 12:55:47.169819+00', 'Saint Bernard''s Waltz', 10037, 5, 0, 16, NULL, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (8196, NULL, '2012-01-20 12:55:47.180543+00', 'Linton Ploughman, The', 3069, 2, 5, 32, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (8197, NULL, '2012-01-20 12:55:47.185909+00', 'Primerose Polka, The', 2301, 50, 0, 0, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (8128, NULL, '2022-12-26 18:14:00.148792+00', 'Dundee Reel', 10267, 2, 6, 32, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (8198, NULL, '2012-01-20 12:55:47.1914+00', 'Gaelic Waltz', 3057, 5, 0, 0, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (8199, NULL, '2012-01-20 12:55:47.197626+00', 'Scottish Reform', 2062, 2, 5, 32, 9999, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (8200, NULL, '2012-01-20 12:55:47.203009+00', 'Strathspey', 10141, 3, 3, 32, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (8201, NULL, '2012-01-20 12:55:47.208355+00', 'Silver Wings Polka, The', 2189, 50, 0, 0, NULL, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (8202, NULL, '2012-01-20 12:55:47.213722+00', 'Dunoon Barn Dance, The', 2328, 11, 0, 0, NULL, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (8203, NULL, '2012-01-20 12:55:47.219115+00', 'Scottish Waltz', 10272, 5, 0, 0, NULL, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (8204, NULL, '2012-01-20 12:55:47.224468+00', 'Duke of Perth', 10146, 1, 8, 32, NULL, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (8205, NULL, '2012-01-20 12:55:47.229837+00', 'Chilliwack Barn Dance, The', 10273, 11, 0, 0, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (8206, NULL, '2012-01-20 12:55:47.235194+00', 'Canadian Barn Dance', 10267, 11, 0, 16, NULL, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (8207, NULL, '2012-01-20 12:55:47.241404+00', 'Foursome and Half Reel of Tulloch', 3026, 4, 0, 128, 10017, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (8208, NULL, '2012-01-20 12:55:47.24679+00', 'Saint Bernard''s Waltz', 3065, 5, 0, 16, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (8209, NULL, '2012-01-20 12:55:47.252143+00', 'Circassian Circle', 2173, 1, 6, 32, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (8210, NULL, '2012-01-20 12:55:47.25749+00', 'Balmoral Highlanders, The', 1456, 11, 0, 0, NULL, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (8211, NULL, '2012-01-20 12:55:47.262838+00', 'Happy Harry Polka, The', 10274, 50, 0, 0, NULL, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (8212, NULL, '2012-01-20 12:55:47.268189+00', 'Gleniffer Polka, The', 3042, 50, 0, 0, NULL, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (8213, NULL, '2012-01-20 12:55:47.27354+00', 'Galloway House', 3018, 1, 4, 32, NULL, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (8214, NULL, '2012-01-20 12:55:47.278895+00', 'Highland Wedding', 10186, 11, 0, 0, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (8215, NULL, '2012-11-29 08:00:44.884108+00', 'Silver City Waltz, The', 3010, 5, 0, 0, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (8216, NULL, '2012-01-20 12:55:47.289588+00', 'Bonnie Anne', 3026, 2, 0, 96, NULL, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (8217, NULL, '2012-01-20 12:55:47.29507+00', 'Aberdeen Waltz, The', 3026, 5, 0, 0, NULL, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (8218, NULL, '2012-01-20 12:55:47.300453+00', 'Dundee Reel', 3026, 2, 8, 40, NULL, NULL, 328, 0, '');
INSERT INTO 'recording' VALUES (8219, NULL, '2012-01-20 12:55:47.305907+00', 'Scottish Waltz Medley', 3026, 5, 0, 0, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (8220, NULL, '2012-01-20 12:55:47.311258+00', 'Gay Gordons', 3026, 11, 0, 16, NULL, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (8221, NULL, '2012-01-20 12:55:47.316597+00', 'Waltz Country Dance', 3026, 5, 0, 40, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (8222, NULL, '2012-01-20 12:55:47.321961+00', 'Baldovan Reel', 3026, 1, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (8223, NULL, '2012-01-20 12:55:47.327315+00', 'Veleta, The', 3026, 5, 0, 16, NULL, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (8224, NULL, '2012-01-20 12:55:47.332675+00', 'Liberton Pipe Band, The', 3026, 50, 0, 0, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (8225, NULL, '2012-01-20 12:55:47.338029+00', 'Scottish Barn Dance', 3026, 50, 0, 0, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (8226, NULL, '2012-01-20 12:55:47.34336+00', 'Royal Exchange', 3026, 2, 8, 32, NULL, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (8227, NULL, '2012-01-20 12:55:47.349566+00', 'Strathspey and Reel', 3026, 4, 0, 64, 5, NULL, 102, 0, '');
INSERT INTO 'recording' VALUES (8179, NULL, '2017-06-17 10:55:12.891286+00', 'Southern Rose Waltz', 10037, 5, 0, 0, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (8228, NULL, '2012-01-20 12:55:47.354948+00', 'Dashing White Sergeant, The', 3026, 1, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (8229, NULL, '2012-01-20 12:55:47.360304+00', 'Hesitation Waltz', 3026, 5, 8, 16, NULL, NULL, 220, 0, '');
INSERT INTO 'recording' VALUES (8230, NULL, '2012-01-20 12:55:47.365664+00', 'Gay Gordons', 3026, 11, 6, 16, NULL, NULL, 115, 0, '');
INSERT INTO 'recording' VALUES (8231, NULL, '2012-01-20 12:55:47.371013+00', 'Gordon Waltz, The', 3026, 5, 0, 0, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (8232, NULL, '2012-01-20 12:55:47.376366+00', 'Braes of Breadalbane, The', 3026, 3, 4, 32, NULL, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (8233, NULL, '2012-01-20 12:55:47.381753+00', 'George Black Polka, The', 3026, 13, 0, 0, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (8234, NULL, '2012-01-20 12:55:47.387123+00', 'Hamilton Rant, The', 3026, 1, 4, 48, NULL, NULL, 222, 0, '');
INSERT INTO 'recording' VALUES (8235, NULL, '2012-01-20 12:55:47.392477+00', 'Last Waltz, The', 3026, 5, 0, 32, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (8236, NULL, '2012-01-20 12:55:47.397859+00', 'Hollin Buss, The', 10277, 2, 5, 32, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (8238, NULL, '2012-01-20 12:55:47.40858+00', 'Polka', 10277, 13, 0, 0, NULL, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (8239, NULL, '2012-01-20 12:55:47.413937+00', 'Scottish Waltz', 10277, 5, 0, 0, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (8240, NULL, '2012-01-20 12:55:47.419279+00', 'Roxburgh Castle', 10277, 1, 4, 32, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (8241, NULL, '2012-01-20 12:55:47.424625+00', 'Kenmure''s on and Awa''', 10277, 2, 4, 32, NULL, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (8242, NULL, '2012-01-20 12:55:47.429985+00', 'Highland Scottische', 10277, 3, 0, 8, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (8243, NULL, '2012-01-20 12:55:47.435347+00', 'Gay Gordons', 10277, 11, 0, 16, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (8244, NULL, '2012-01-20 12:55:47.440696+00', 'Mairrit Man''s Favourite, The', 10277, 1, 4, 32, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (8245, NULL, '2012-01-20 12:55:47.446077+00', 'Miss Hadden''s Reel', 10277, 2, 4, 32, NULL, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (8246, NULL, '2012-01-20 12:55:47.451438+00', 'Gay Gordons', 10277, 11, 0, 16, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (8247, NULL, '2012-01-20 12:55:47.456787+00', 'Gaelic Waltz', 10277, 5, 0, 0, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (8248, NULL, '2012-01-20 12:55:47.462159+00', 'Maxwell''s Rant', 10277, 1, 4, 32, NULL, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (8249, NULL, '2012-01-20 12:55:47.467587+00', 'Jimmy''s Fancy', 10277, 3, 3, 32, NULL, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (8250, NULL, '2012-01-20 12:55:47.472938+00', 'Hooper''s Jig', 10277, 2, 4, 32, NULL, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (8251, NULL, '2012-01-20 12:55:47.478356+00', 'Reels', 10277, 1, 6, 32, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (8255, NULL, '2012-01-20 12:55:47.499776+00', 'Florentine Waltz', 3217, 5, 0, 0, NULL, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (8256, NULL, '2012-01-20 12:55:47.505108+00', 'Bees of Maggieknockater, The', 3217, 2, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (8257, NULL, '2012-01-20 12:55:47.510474+00', 'Canadian Barn Dance', 3217, 11, 0, 16, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (8258, NULL, '2012-01-20 12:55:47.515838+00', 'Slow Air', 3217, 98, 0, 0, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (8260, NULL, '2012-01-20 12:55:47.526548+00', 'Scottish Waltz', 3217, 5, 0, 0, NULL, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (8261, NULL, '2012-01-20 12:55:47.532131+00', 'Jacqueline Cha Cha', 3217, 50, 0, 0, NULL, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (8262, NULL, '2012-01-20 12:55:47.537485+00', 'Gay Gordon''s Two Step', 3217, 11, 0, 16, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (8263, NULL, '2012-01-20 12:55:47.542871+00', 'Snake Pass', 3217, 2, 8, 32, NULL, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (8264, NULL, '2012-01-20 12:55:47.548215+00', 'New Killarney Waltz', 3217, 5, 0, 0, NULL, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (8268, NULL, '2012-01-20 12:55:47.569623+00', 'Britannia Two Step/Gay Gordons Two Step', 10104, 2, 8, 16, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (8275, NULL, '2012-01-20 12:55:47.607244+00', 'Slow Air', 10104, 50, 0, 0, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (8279, NULL, '2012-01-20 12:55:47.628796+00', 'Quickstep', 10104, 50, 0, 0, NULL, NULL, 94, 0, '');
INSERT INTO 'recording' VALUES (8280, NULL, '2012-01-20 12:55:47.634152+00', 'Shetland Reels', 10104, 1, 6, 32, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (8281, NULL, '2012-01-20 12:55:47.639503+00', 'Festival Glide/Polka', 10104, 50, 0, 0, NULL, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (8283, NULL, '2012-01-20 12:55:47.650334+00', 'Barn Dance/Highland Barn Dance', 10104, 11, 0, 16, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (8286, NULL, '2012-01-20 12:55:47.666423+00', 'New Scotland Strathspey', 3026, 3, 4, 40, NULL, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (8287, NULL, '2012-01-20 12:55:47.671773+00', 'Muirland Willie', 2317, 2, 8, 32, NULL, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (8288, NULL, '2012-01-20 12:55:47.67712+00', 'Braes of Balquhidder', 2038, 3, 1, 128, NULL, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (8278, NULL, '2022-12-22 18:42:52.493081+00', 'Jona Waltz/St Bernards Waltz', 10104, 5, 0, 16, NULL, NULL, 232, 0, '');
INSERT INTO 'recording' VALUES (8272, NULL, '2022-12-23 00:07:32.320592+00', 'Pride of Erin Waltz/New Killarney Waltz', 10104, 5, 0, 32, NULL, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (8269, NULL, '2022-12-23 00:10:01.257699+00', 'Palais Glide/White Heather Foxtrott', 10104, 50, 0, 0, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (8270, NULL, '2022-12-23 00:11:47.169961+00', 'Rory O'' More/Strip the Willow', 10104, 2, 8, 32, NULL, NULL, 265, 0, 'From the naming it''s intended for Strip the Willow (a J40), so this won''t fit.');
INSERT INTO 'recording' VALUES (8267, NULL, '2022-12-23 14:12:13.105082+00', 'Petronella/Circassian Circle', 10104, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (8274, NULL, '2022-12-23 23:45:40.645515+00', 'Canadian Barn Dance/Dunoon Barn Dance', 10104, 11, 0, 16, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (8265, NULL, '2022-12-25 19:29:58.863055+00', 'White Heather Fox Trot', 3217, 50, 0, 0, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (8282, NULL, '2022-12-25 21:47:24.481822+00', 'Captain White/Frog in the Middle', 10104, 2, 8, 32, NULL, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (8284, NULL, '2022-12-25 23:39:22.492531+00', 'Russian Ballet/Eva Three Step', 10104, 50, 0, 16, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (8277, NULL, '2022-12-25 23:40:32.544031+00', 'Mississippi Dip/Gypsy Tap', 10104, 50, 0, 0, NULL, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (8289, NULL, '2012-01-20 12:55:47.682494+00', 'Red House', 3026, 1, 8, 40, NULL, NULL, 331, 0, '');
INSERT INTO 'recording' VALUES (8290, NULL, '2012-01-20 12:55:47.687844+00', 'Kitty Campbell''s Reel', 2317, 2, 8, 32, NULL, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (8291, NULL, '2012-01-20 12:55:47.693198+00', 'Letham Ladies', 3026, 3, 4, 40, NULL, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (8292, NULL, '2012-01-20 12:55:47.698596+00', 'Duran Ranger, The', 2038, 1, 8, 32, NULL, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (8293, NULL, '2012-01-20 12:55:47.703937+00', 'River Cree, The', 2317, 2, 8, 32, NULL, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (8294, NULL, '2012-01-20 12:55:47.709292+00', 'Scotsman in America, The', 2038, 3, 4, 32, NULL, NULL, 231, 0, '');
INSERT INTO 'recording' VALUES (8295, NULL, '2012-01-20 12:55:47.714646+00', 'Angus MacLeod', 3026, 1, 2, 64, NULL, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (8252, NULL, '2013-03-31 16:36:07.007426+00', 'Pinewoods Two Step', 3217, 50, 0, 0, NULL, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (8296, NULL, '2012-01-20 12:55:47.719985+00', 'Dundee Reel', 2038, 2, 8, 40, NULL, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (8297, NULL, '2012-01-20 12:55:47.725353+00', 'Highland Reel', 2317, 1, 6, 32, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (8298, NULL, '2012-01-20 12:55:47.730716+00', 'Duke of Atholl''s Reel', 2038, 2, 5, 32, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (8299, NULL, '2012-01-20 12:55:47.736067+00', 'Glasgow Flourish', 2317, 3, 8, 32, NULL, NULL, 481, 0, '');
INSERT INTO 'recording' VALUES (8300, NULL, '2012-01-20 12:55:47.741423+00', 'Irish Rover', 3026, 1, 8, 32, NULL, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (8317, NULL, '2012-01-20 12:55:47.833896+00', 'Introduction', 3023, 98, 0, 0, NULL, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (8318, NULL, '2012-01-20 12:55:47.839249+00', 'Gus''s Reel', 3023, 1, 5, 40, NULL, NULL, 233, 0, '');
INSERT INTO 'recording' VALUES (8319, NULL, '2012-01-20 12:55:47.844588+00', 'Tribute to the Black Watch 2004', 3023, 1, 4, 32, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (8320, NULL, '2012-01-20 12:55:47.849967+00', 'Strathspey for the Black Watch', 3023, 3, 4, 32, NULL, NULL, 253, 0, '');
INSERT INTO 'recording' VALUES (8321, NULL, '2012-01-20 12:55:47.855328+00', 'Never Again!!!', 3023, 1, 6, 48, NULL, NULL, 333, 0, '');
INSERT INTO 'recording' VALUES (8324, NULL, '2012-01-20 12:55:47.871388+00', 'Reels of Dunans, The', 10330, 1, 8, 32, NULL, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (8325, NULL, '2012-01-20 12:55:47.876743+00', 'Birthday Present, The', 10330, 3, 8, 32, NULL, NULL, 484, 0, '');
INSERT INTO 'recording' VALUES (8326, NULL, '2012-01-20 12:55:47.882105+00', 'Faculty of Actuaries, The', 10330, 2, 4, 32, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (8327, NULL, '2012-01-20 12:55:47.887452+00', 'Montgomeri Strathspey, The', 10330, 3, 3, 32, NULL, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (8328, NULL, '2012-01-20 12:55:47.892809+00', 'Frimley Green Reel, The', 10330, 1, 8, 32, NULL, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (8329, NULL, '2012-01-20 12:55:47.898185+00', 'Burntisland Jig, The', 10330, 2, 5, 32, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (8330, NULL, '2012-01-20 12:55:47.904373+00', 'Gin and Tonic, A', 10330, 4, 1, 192, 3, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (8323, NULL, '2019-10-01 21:05:19.063601+00', 'Bruce Frazer''s Jig', 10330, 2, 4, 32, NULL, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (8331, NULL, '2012-01-20 12:55:47.910077+00', 'Three Shires, The', 10330, 1, 8, 32, NULL, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (8332, NULL, '2012-01-20 12:55:47.915562+00', 'Salute to the Borders', 10330, 3, 8, 32, NULL, NULL, 475, 0, '');
INSERT INTO 'recording' VALUES (8333, NULL, '2012-01-20 12:55:47.920908+00', 'Shortfield Jig, The', 10330, 2, 8, 40, NULL, NULL, 338, 0, '');
INSERT INTO 'recording' VALUES (8334, NULL, '2012-01-20 12:55:47.92626+00', 'Queen''s View, The', 10330, 1, 8, 32, NULL, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (8335, NULL, '2012-01-20 12:55:47.931605+00', 'Shetland Waltzes', 10330, 5, 7, 32, NULL, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (8336, NULL, '2012-01-20 12:55:47.936958+00', 'Sarah''s Song', 10330, 98, 0, 0, NULL, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (8338, NULL, '2012-01-20 12:55:47.947674+00', 'Jessie''s Hornpipe', 10381, 1, 8, 32, NULL, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (8340, NULL, '2012-01-20 12:55:47.959286+00', 'Maxwell''s Rant', 10381, 1, 8, 32, NULL, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (8322, NULL, '2012-09-12 23:28:43.659999+00', 'Kandahar Reel', 3023, 1, 5, 32, NULL, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (8316, NULL, '2012-09-16 15:53:44.20413+00', 'Kandahar Reel, The', 10659, 1, 10, 32, NULL, NULL, 340, 0, '');
INSERT INTO 'recording' VALUES (8315, NULL, '2012-09-16 15:53:44.238943+00', 'Kandahar Reel, The', 10659, 1, 10, 32, NULL, NULL, 349, 0, '');
INSERT INTO 'recording' VALUES (8314, NULL, '2012-09-16 15:53:44.24227+00', 'Speed the Plough', 10659, 1, 10, 32, NULL, NULL, 339, 0, '');
INSERT INTO 'recording' VALUES (8313, NULL, '2012-09-16 15:53:44.245368+00', 'Speed the Plough', 10659, 1, 10, 32, NULL, NULL, 341, 0, '');
INSERT INTO 'recording' VALUES (10212, '2018-06-23 16:55:17.468063+00', '2018-06-23 16:55:17.468063+00', 'Lady Susan Stewart''s Strathspey (as "Trinity Hall")', 11651, 3, 8, 32, NULL, NULL, 489, 0, '');
INSERT INTO 'recording' VALUES (8310, NULL, '2012-09-16 15:53:44.25508+00', 'Reel of the 51st Division', 10659, 1, 10, 32, NULL, NULL, 344, 0, '');
INSERT INTO 'recording' VALUES (8309, NULL, '2012-09-16 15:53:44.258188+00', 'Reel of the 51st Division', 10659, 1, 10, 32, NULL, NULL, 345, 0, '');
INSERT INTO 'recording' VALUES (8308, NULL, '2012-09-16 15:53:44.26128+00', 'Duke and Duchess of Edinburgh, The', 10659, 1, 10, 40, NULL, NULL, 425, 0, '');
INSERT INTO 'recording' VALUES (8306, NULL, '2012-09-16 15:53:44.267553+00', 'Foursome Reel, The', 10659, 4, 1, 144, 10018, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (8305, NULL, '2012-09-16 15:53:44.270803+00', 'Eightsome Reel, The', 10659, 1, 0, 464, NULL, NULL, 493, 0, '');
INSERT INTO 'recording' VALUES (8304, NULL, '2012-09-16 15:53:44.274566+00', 'Duke of Perth', 10659, 1, 10, 32, NULL, NULL, 341, 0, '');
INSERT INTO 'recording' VALUES (8303, NULL, '2012-09-16 15:53:44.277664+00', 'Duke of Perth', 10659, 1, 10, 32, NULL, NULL, 345, 0, '');
INSERT INTO 'recording' VALUES (8301, NULL, '2012-09-16 15:53:44.284474+00', 'Dashing White Sergeant', 10659, 1, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (8345, NULL, '2012-01-20 12:55:47.986176+00', 'Argyll''s Fancy', 10381, 2, 4, 48, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (8346, NULL, '2012-01-20 12:55:47.991628+00', 'Waltz Country Dance', 10381, 5, 4, 40, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (8312, NULL, '2020-05-08 07:52:46.250839+00', 'Hamilton House', 10659, 2, 10, 32, NULL, NULL, 334, 0, '');
INSERT INTO 'recording' VALUES (8253, NULL, '2021-08-07 18:44:28.252379+00', 'Shiftin'' Bobbins', 3217, 1, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (8347, NULL, '2012-01-20 12:55:47.996989+00', 'Bees of Maggieknockater, The', 3023, 2, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (8348, NULL, '2012-01-20 12:55:48.002355+00', 'Belle of Bon Accord, The', 3023, 3, 4, 32, NULL, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (9885, '2016-08-12 18:19:43.918234+00', '2018-10-12 14:38:25.954524+00', 'Marquis of Lorne, The', 10034, 3, 8, 32, NULL, NULL, 506, 0, '');
INSERT INTO 'recording' VALUES (8352, NULL, '2012-01-20 12:55:48.023859+00', 'Good Hearted Glasgow', 3023, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (8353, NULL, '2012-01-20 12:55:48.029211+00', 'Highland Rambler', 3023, 1, 8, 40, NULL, NULL, 366, 0, '');
INSERT INTO 'recording' VALUES (8355, NULL, '2012-01-20 12:55:48.039933+00', 'J. B. Milne', 3023, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (8357, NULL, '2012-01-20 12:55:48.050638+00', 'Lord MacLay''s Reel', 3023, 1, 4, 40, NULL, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (8358, NULL, '2012-01-20 12:55:48.056025+00', 'Mrs MacPherson of Inveran', 3023, 1, 8, 32, NULL, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (8359, NULL, '2012-01-20 12:55:48.061392+00', 'New Scotland Strathspey, The', 3023, 3, 4, 40, NULL, NULL, 322, 0, '');
INSERT INTO 'recording' VALUES (8360, NULL, '2012-01-20 12:55:48.066761+00', 'Rothesay Rant, The', 3023, 2, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (8361, NULL, '2012-01-20 12:55:48.072104+00', 'Seton''s Ceilidh Band', 3023, 2, 4, 64, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (8362, NULL, '2012-01-20 12:55:48.077517+00', 'Shiftin'' Bobbins', 3023, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (8363, NULL, '2012-01-20 12:55:48.082887+00', 'Saint John River', 3023, 3, 4, 32, NULL, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (8365, NULL, '2012-01-20 12:55:48.093608+00', 'White Heather Jig, The', 3023, 2, 4, 40, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (8379, NULL, '2012-09-16 15:34:16.525559+00', 'Reel of the Puffins', 10659, 1, 4, 32, NULL, NULL, 147, 1, '');
INSERT INTO 'recording' VALUES (8377, NULL, '2012-09-16 15:34:16.546099+00', 'Bedrule', 10659, 3, 8, 32, NULL, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (8376, NULL, '2012-09-16 15:34:16.550263+00', 'Saltire Medley, The', 10659, 4, 0, 96, 11, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (8375, NULL, '2012-09-16 15:34:16.589236+00', 'White Cockade, The', 10659, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (8374, NULL, '2012-09-16 15:34:16.59341+00', 'Seann Truibhas Willichan', 10659, 3, 8, 32, NULL, NULL, 489, 0, '');
INSERT INTO 'recording' VALUES (8373, NULL, '2012-09-16 15:34:16.59755+00', 'Mrs Stewart''s Jig', 10659, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (8337, NULL, '2013-08-19 11:56:43.44632+00', 'Cumberland Reel, The', 10381, 2, 4, 32, NULL, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (8342, NULL, '2013-08-19 11:56:43.507373+00', 'Express, The', 10381, 2, 8, 40, NULL, NULL, 323, 0, '');
INSERT INTO 'recording' VALUES (8343, NULL, '2013-08-19 11:56:44.076667+00', 'White Cockade, The', 10381, 1, 8, 32, NULL, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (8341, NULL, '2013-08-19 11:56:44.099168+00', 'White Heather Jig, The', 10381, 2, 4, 40, NULL, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (8349, NULL, '2014-09-16 14:46:17.347872+00', 'Blooms of Bon Accord', 3023, 1, 4, 32, NULL, NULL, 151, 1, '');
INSERT INTO 'recording' VALUES (8371, NULL, '2012-09-16 15:34:16.606031+00', 'Bruce''s Men', 10659, 3, 3, 32, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (8370, NULL, '2012-09-16 15:34:16.610155+00', 'Marigold', 10659, 2, 8, 40, NULL, NULL, 340, 0, '');
INSERT INTO 'recording' VALUES (8368, NULL, '2012-09-16 15:34:16.618496+00', 'Gang the Same Gate', 10659, 3, 8, 32, NULL, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (8372, NULL, '2022-12-14 16:01:50.314219+00', 'Highland Rambler, The', 10659, 1, 8, 40, NULL, NULL, 351, 0, '');
INSERT INTO 'recording' VALUES (8307, NULL, '2022-12-14 16:03:13.308423+00', 'Duke and Duchess of Edinburgh, The', 10659, 1, 10, 40, NULL, NULL, 429, 0, '');
INSERT INTO 'recording' VALUES (8378, NULL, '2022-12-19 19:36:01.899249+00', 'Kelloholm Jig, The', 10659, 2, 8, 32, NULL, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (8364, NULL, '2022-12-26 20:49:51.536472+00', 'Trip to Bavaria, A', 3023, 1, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (8367, NULL, '2012-09-16 15:34:16.622612+00', 'Let the Hackles Rise', 10659, 2, 4, 48, NULL, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (8366, NULL, '2012-09-16 15:34:16.626761+00', 'Burnieboozle', 10659, 1, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (8407, NULL, '2012-01-20 12:55:48.342818+00', 'Rest and Be Thankful', 2066, 1, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (8369, NULL, '2016-10-18 09:51:52.307367+00', 'Summer Wooing', 10659, 1, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (8339, NULL, '2017-02-12 13:14:16.079655+00', 'Strathglass House', 10381, 3, 8, 32, 9999, NULL, 456, 0, '');
INSERT INTO 'recording' VALUES (8350, NULL, '2017-02-14 17:07:49.614975+00', 'Celtic Cross, The', 3023, 1, 4, 48, NULL, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (8408, NULL, '2012-01-20 12:55:48.34816+00', 'Magic Airt o'' Gow, The', 2066, 3, 8, 32, NULL, NULL, 515, 0, '');
INSERT INTO 'recording' VALUES (8409, NULL, '2012-01-20 12:55:48.353575+00', 'Rambling Pitchfork, The', 2066, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (8410, NULL, '2012-01-20 12:55:48.358934+00', 'Campbell''s Caper', 2066, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (8411, NULL, '2012-01-20 12:55:48.364288+00', 'Lang Whang, The', 2066, 3, 8, 32, NULL, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (8412, NULL, '2012-01-20 12:55:48.369645+00', 'Clydeside Lassies', 2066, 1, 8, 32, NULL, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (8413, NULL, '2012-01-20 12:55:48.375002+00', 'Miss Stewart''s Jig', 2066, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (8414, NULL, '2012-01-20 12:55:48.380351+00', 'Shaws of Cambridge, The', 2066, 3, 4, 32, NULL, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (8416, NULL, '2012-01-20 12:55:48.391136+00', 'Old Rustic Bridge, The', 2066, 1, 4, 32, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (8417, NULL, '2012-01-20 12:55:48.396486+00', 'Shining Lights', 2066, 3, 8, 32, NULL, NULL, 494, 0, '');
INSERT INTO 'recording' VALUES (8418, NULL, '2012-01-20 12:55:48.401828+00', 'Miss Jeanetta McColl', 2066, 1, 8, 32, NULL, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (8419, NULL, '2012-01-20 12:55:48.407175+00', 'Mist on the Mountain', 2066, 5, 4, 32, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (8420, NULL, '2012-01-20 12:55:48.412526+00', 'San Francisco Branch Polka, The', 2066, 13, 2, 32, NULL, NULL, 75, 0, '');
INSERT INTO 'recording' VALUES (8421, NULL, '2012-01-20 12:55:48.417886+00', 'Auld Reekie', 2586, 7, 0, 0, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (8422, NULL, '2012-01-20 12:55:48.423234+00', 'Blue Bonnets (4/4 version)', 2586, 7, 0, 0, NULL, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (8423, NULL, '2012-01-20 12:55:48.428596+00', 'Blue Bonnets (6/8 version)', 2586, 7, 0, 0, NULL, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (8424, NULL, '2012-01-20 12:55:48.433952+00', 'Bonnie Briest Knot, The', 2586, 7, 0, 0, NULL, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (8425, NULL, '2012-01-20 12:55:48.439292+00', 'Bonnie Broom, The', 2586, 7, 0, 0, NULL, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (8426, NULL, '2012-01-20 12:55:48.444735+00', 'Come Ashore Jolly Tar', 2586, 7, 0, 0, NULL, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (8427, NULL, '2012-01-20 12:55:48.450124+00', 'Deeside Lilt (6/8 version), The', 2586, 7, 0, 0, NULL, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (8428, NULL, '2012-01-20 12:55:48.45549+00', 'Deeside Lilt (4/4 version), The', 2586, 7, 0, 0, NULL, NULL, 126, 0, '');
INSERT INTO 'recording' VALUES (8429, NULL, '2012-01-20 12:55:48.461013+00', 'Dusty Miller, The', 2586, 7, 0, 0, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (8430, NULL, '2012-01-20 12:55:48.466369+00', 'Earl of Erroll, The', 2586, 7, 0, 0, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (8431, NULL, '2012-01-20 12:55:48.47178+00', 'Flora MacDonald''s Fancy', 2586, 7, 0, 0, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (8432, NULL, '2012-01-20 12:55:48.477124+00', 'Flowers of Edinburgh, The', 2586, 7, 0, 0, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (8433, NULL, '2012-01-20 12:55:48.482485+00', 'Graces, The', 2586, 7, 0, 0, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (8434, NULL, '2012-01-20 12:55:48.487826+00', 'Highland Laddie (2/4 version)', 2586, 7, 0, 0, NULL, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (8435, NULL, '2012-01-20 12:55:48.493179+00', 'Highland Laddie (4/4 version)', 2586, 7, 0, 0, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (8436, NULL, '2012-01-20 12:55:48.498537+00', 'King of Sweden, The', 2586, 7, 0, 0, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (8437, NULL, '2012-01-20 12:55:48.503884+00', 'Dusty Miller (8 steps), The', 2586, 7, 0, 0, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (8438, NULL, '2012-01-20 12:55:48.509236+00', 'Bonnie Briest Knot (long version), The', 2586, 7, 0, 0, NULL, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (8439, NULL, '2012-01-20 12:55:48.514605+00', 'Come Ashore Jolly Tar (8 steps)', 2586, 7, 0, 0, NULL, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (8440, NULL, '2012-01-20 12:55:48.519952+00', 'Lady Louisa MacDonald of Sleat', 2586, 7, 0, 0, NULL, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (8442, NULL, '2012-01-20 12:55:48.530649+00', 'Maid of Islay, The', 2586, 7, 0, 0, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (8443, NULL, '2012-01-20 12:55:48.535989+00', 'Miss Forbes', 2586, 7, 0, 0, NULL, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (8444, NULL, '2012-01-20 12:55:48.54135+00', 'Old Scottish Lilt, The', 2586, 7, 0, 0, NULL, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (8445, NULL, '2012-01-20 12:55:48.546707+00', 'Over the Water to Charlie', 2586, 7, 0, 0, NULL, NULL, 128, 0, '');
INSERT INTO 'recording' VALUES (8446, NULL, '2012-01-20 12:55:48.552076+00', 'Pas de Deux for the Misses Grant of Monymusk', 2586, 7, 0, 0, NULL, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (8447, NULL, '2012-01-20 12:55:48.55744+00', 'Pas de Trois for the Misses Glennie', 2586, 7, 0, 0, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (8448, NULL, '2012-01-20 12:55:48.562799+00', 'Rose of Benbecula, The', 2586, 7, 0, 0, NULL, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (8449, NULL, '2012-01-20 12:55:48.568142+00', 'Rowan Tree, The', 2586, 7, 0, 0, NULL, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (8450, NULL, '2012-01-20 12:55:48.573491+00', 'Scotch Measure', 2586, 7, 0, 0, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (8451, NULL, '2012-01-20 12:55:48.578842+00', 'Scottish Lilt, The', 2586, 7, 0, 0, NULL, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (8452, NULL, '2012-01-20 12:55:48.58418+00', 'Village Maid, The', 2586, 7, 0, 0, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (8453, NULL, '2012-01-20 12:55:48.589576+00', 'Way tae Fife, The', 2586, 7, 0, 0, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (8454, NULL, '2012-01-20 12:55:48.594956+00', 'Welcome to Galloway', 2586, 7, 0, 0, NULL, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (8455, NULL, '2012-01-20 12:55:48.600321+00', 'Scottish Lilt (As taught by I. Cramb), The', 2586, 7, 0, 0, NULL, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (8457, NULL, '2012-01-20 12:55:48.611063+00', 'Hooper''s Jig', 10503, 2, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (8459, NULL, '2012-01-20 12:55:48.621766+00', 'Reel of the 51st Division, The', 10503, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (8460, NULL, '2012-01-20 12:55:48.627127+00', 'Jig Set', 10503, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (8461, NULL, '2012-01-20 12:55:48.632481+00', 'Birks of Invermay, The', 10503, 3, 8, 32, NULL, NULL, 496, 0, '');
INSERT INTO 'recording' VALUES (8462, NULL, '2012-01-20 12:55:48.637846+00', 'Left-Handed Fiddler, The', 10503, 1, 8, 32, NULL, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (8463, NULL, '2012-01-20 12:55:48.643187+00', 'Wells House', 10503, 3, 8, 32, NULL, NULL, 482, 0, '');
INSERT INTO 'recording' VALUES (8465, NULL, '2012-01-20 12:55:48.653907+00', 'Braes of Tulliemet, The', 10503, 3, 8, 32, NULL, NULL, 492, 0, '');
INSERT INTO 'recording' VALUES (8467, NULL, '2012-01-20 12:55:48.664616+00', 'Hogmanay Engagement', 10503, 5, 0, 0, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (8469, NULL, '2012-01-20 12:55:48.675418+00', 'Pipe Strathspey', 10503, 3, 0, 0, NULL, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (8470, NULL, '2012-01-20 12:55:48.680761+00', 'Saint Andrew''s Fair', 10503, 2, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (8471, NULL, '2012-01-20 12:55:48.686233+00', 'Invercauld''s Reel', 10503, 3, 8, 32, NULL, NULL, 501, 0, '');
INSERT INTO 'recording' VALUES (8472, NULL, '2012-01-20 12:55:48.691581+00', 'Hamilton Rant, The', 10503, 1, 8, 48, NULL, NULL, 416, 0, '');
INSERT INTO 'recording' VALUES (8474, NULL, '2012-01-20 12:55:49.105598+00', 'Peggy''s Love', 10503, 3, 8, 32, NULL, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (8475, NULL, '2012-01-20 12:55:49.110967+00', 'Hyperactive Reel, The', 10503, 1, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (8476, NULL, '2012-01-20 12:55:49.116305+00', 'Roaring Jelly', 10503, 2, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (8477, NULL, '2012-01-20 12:55:49.121663+00', 'Mr Pixton of Brookline', 10503, 1, 4, 32, NULL, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (8478, NULL, '2012-01-20 12:55:49.127008+00', 'Braes of Breadalbane, The', 10503, 3, 8, 32, NULL, NULL, 520, 0, '');
INSERT INTO 'recording' VALUES (8479, NULL, '2012-01-20 12:55:49.132455+00', 'Saltire Society Reel, The', 10503, 1, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (8480, NULL, '2012-01-20 12:55:49.137824+00', 'Waltz', 10503, 5, 0, 0, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (8481, NULL, '2012-01-20 12:55:49.14316+00', '3/4 Pipe Marches', 10503, 11, 0, 0, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (8482, NULL, '2012-01-20 12:55:49.148513+00', 'Postie''s Jig', 3034, 2, 4, 32, NULL, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (8483, NULL, '2012-01-20 12:55:49.153878+00', 'Dashing White Sergeant', 3034, 1, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (8484, NULL, '2012-01-20 12:55:49.159226+00', 'Waltz Country Dance', 3034, 5, 4, 40, NULL, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (8485, NULL, '2012-01-20 12:55:49.164577+00', 'Cumberland Reel', 3034, 2, 8, 32, NULL, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (8486, NULL, '2012-01-20 12:55:49.169964+00', 'Reel of the 51st Division', 3034, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (8487, NULL, '2012-01-20 12:55:49.17531+00', 'Canadian Barn Dance', 3034, 11, 0, 16, NULL, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (8488, NULL, '2012-01-20 12:55:49.18126+00', 'Duke of Perth', 3034, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (8489, NULL, '2012-01-20 12:55:49.187151+00', 'Boston Two Step', 3034, 50, 0, 16, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (8490, NULL, '2012-01-20 12:55:49.192604+00', 'Strip the Willow', 3034, 2, 8, 32, NULL, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (8491, NULL, '2012-01-20 12:55:49.198826+00', 'Johnnie Walker', 3034, 4, 0, 128, 13, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (8464, NULL, '2022-08-31 17:08:17.804138+00', 'Lady Home''s Jig', 10503, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (8492, NULL, '2012-01-20 12:55:49.204199+00', 'Mairi''s Wedding', 3034, 1, 8, 40, NULL, NULL, 331, 0, '');
INSERT INTO 'recording' VALUES (8493, NULL, '2012-01-20 12:55:49.209566+00', 'Saint Bernard''s Waltz', 3034, 5, 0, 16, NULL, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (8494, NULL, '2012-01-20 12:55:49.214985+00', 'Petronella', 3034, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (8495, NULL, '2012-01-20 12:55:49.220368+00', 'Hamilton House', 3034, 2, 8, 32, NULL, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (8496, NULL, '2012-01-20 12:55:49.225745+00', 'Flowers of Edinburgh', 3034, 1, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (8497, NULL, '2012-01-20 12:55:49.231105+00', 'Walk On', 3034, 11, 0, 24, NULL, NULL, 22, 0, '');
INSERT INTO 'recording' VALUES (8498, NULL, '2012-01-20 12:55:49.236458+00', 'Petronella', 3034, 1, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (8499, NULL, '2012-01-20 12:55:49.241812+00', 'Walk Off', 3034, 11, 0, 24, NULL, NULL, 24, 0, '');
INSERT INTO 'recording' VALUES (8500, NULL, '2012-01-20 12:55:49.247159+00', 'Last Waltz', 3034, 5, 0, 16, NULL, NULL, 120, 0, '');
INSERT INTO 'recording' VALUES (8501, NULL, '2012-01-20 12:55:49.252666+00', 'Auld Lang Syne', 3034, 98, 0, 0, NULL, NULL, 83, 0, '');
INSERT INTO 'recording' VALUES (8502, NULL, '2012-01-20 12:55:49.258213+00', 'Joe MacDiarmid''s Jig', 3217, 2, 4, 32, NULL, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (8503, NULL, '2012-01-20 12:55:49.263598+00', 'Kirrie March', 3217, 11, 0, 0, NULL, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (8504, NULL, '2012-01-20 12:55:49.269003+00', 'Saint Bernard''s Waltz', 3217, 5, 0, 16, NULL, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (8505, NULL, '2012-01-20 12:55:49.317318+00', 'Canadian Barn Dance', 3217, 11, 0, 16, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (8506, NULL, '2012-01-20 12:55:49.32158+00', 'Flirtation Two Step', 3217, 50, 0, 0, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (8507, NULL, '2012-01-20 12:55:49.325655+00', 'Sandy''s New Chanter', 3217, 1, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (8508, NULL, '2012-01-20 12:55:49.329722+00', 'Eva Three Step', 3217, 50, 0, 16, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (8509, NULL, '2012-01-20 12:55:49.333812+00', 'New Killarney Waltz', 3217, 5, 0, 0, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (8510, NULL, '2012-01-20 12:55:49.337904+00', 'Medley', 3217, 98, 0, 0, NULL, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (8511, NULL, '2012-01-20 12:55:49.341987+00', 'Edinburgh Mixture', 3217, 50, 0, 0, NULL, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (8512, NULL, '2012-01-20 12:55:49.346048+00', 'Jazz Twinkle', 3217, 13, 0, 0, NULL, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (8513, NULL, '2012-01-20 12:55:49.35011+00', 'Gypsy Tap', 3217, 2, 4, 32, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (8514, NULL, '2012-01-20 12:55:49.354221+00', 'Flowers of Edinburgh', 3217, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (8468, NULL, '2020-05-27 13:27:49.276837+00', '6/8 Pipe Marches', 10503, 11, 0, 0, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (8458, NULL, '2020-05-27 13:30:42.140518+00', 'Bob Campbell', 10503, 3, 8, 32, 9999, NULL, 491, 0, '');
INSERT INTO 'recording' VALUES (8456, NULL, '2020-05-27 14:06:41.732747+00', 'Pipe March', 10503, 11, 0, 0, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (8515, NULL, '2012-01-20 12:55:49.364511+00', 'Festival Glide', 3217, 50, 0, 0, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (8517, NULL, '2012-01-20 12:55:49.37609+00', 'Hooper''s Jig', 3217, 2, 8, 32, NULL, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (8518, NULL, '2012-01-20 12:55:49.381529+00', 'Luckenbooth Brooch', 10525, 2, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (8519, NULL, '2012-01-20 12:55:49.386954+00', 'Highland Schottische', 10525, 3, 0, 8, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (8520, NULL, '2012-01-20 12:55:49.392847+00', 'Saint Bernard''s Waltz', 10525, 5, 0, 16, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (8521, NULL, '2012-01-20 12:55:49.398816+00', 'Trip to Bavaria', 10525, 1, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (8522, NULL, '2012-01-20 12:55:49.404568+00', 'Canadian Barn Dance', 10525, 11, 0, 16, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (8523, NULL, '2012-01-20 12:55:49.41012+00', 'Medley', 10525, 98, 0, 0, NULL, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (8524, NULL, '2012-01-20 12:55:49.415873+00', 'Byron Strathspey', 10525, 3, 3, 32, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (8525, NULL, '2012-01-20 12:55:49.421799+00', 'Waltz Country Dance', 10525, 5, 4, 40, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (8526, NULL, '2012-01-20 12:55:49.427759+00', 'Boston Two Step', 10525, 50, 0, 16, NULL, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (8527, NULL, '2012-01-20 12:55:49.433435+00', 'Bagpipe Medley', 10525, 98, 0, 0, NULL, NULL, 350, 0, '');
INSERT INTO 'recording' VALUES (8528, NULL, '2012-01-20 12:55:49.439297+00', 'Happy Meeting', 10525, 2, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (8529, NULL, '2012-01-20 12:55:49.444715+00', 'Gleniffer Polka', 10525, 13, 0, 0, NULL, NULL, 120, 0, '');
INSERT INTO 'recording' VALUES (8530, NULL, '2012-01-20 12:55:49.450274+00', 'Gay Gordons', 10525, 11, 0, 16, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (8473, NULL, '2012-06-17 15:11:35.086571+00', 'Ladies'' Fancy', 10503, 2, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (8531, NULL, '2012-01-20 12:55:49.455854+00', 'Pride of Erin Waltz', 10525, 5, 0, 32, NULL, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (8532, NULL, '2012-01-20 12:55:49.461847+00', 'Drumelzier', 10525, 3, 4, 32, NULL, NULL, 233, 0, '');
INSERT INTO 'recording' VALUES (8533, NULL, '2012-01-20 12:55:49.467194+00', 'Angus MacLeod', 10525, 1, 2, 64, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (8534, NULL, '2012-01-20 12:55:49.472541+00', 'Eva Three Step', 10525, 11, 0, 16, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (8535, NULL, '2012-01-20 12:55:49.477908+00', 'Highland Barn Dance', 10525, 11, 0, 16, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (8536, NULL, '2012-01-20 12:55:49.483404+00', 'Hogmanay Jig', 10525, 2, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (8537, NULL, '2012-01-20 12:55:49.488753+00', 'Last Waltz', 10525, 5, 0, 0, NULL, NULL, 220, 0, '');
INSERT INTO 'recording' VALUES (8574, NULL, '2012-01-20 12:55:49.69176+00', 'Grand March', 10108, 50, 0, 0, NULL, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (8575, NULL, '2012-01-20 12:55:49.697803+00', 'Circassian Circle', 10108, 1, 6, 32, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (8571, NULL, '2013-01-05 14:50:21.012558+00', 'Strip The Willow', 10108, 2, 8, 32, NULL, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (8556, NULL, '2013-01-05 14:50:50.709366+00', 'Introduction', 10108, 98, 0, 0, NULL, NULL, 14, 0, '');
INSERT INTO 'recording' VALUES (8562, NULL, '2013-01-05 14:51:27.587194+00', 'Scandinavian Waltz', 10108, 5, 0, 0, NULL, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (8572, NULL, '2013-01-05 15:03:22.70193+00', 'Saint Bernard''s Waltz', 10108, 5, 0, 16, NULL, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (8565, NULL, '2013-01-05 15:03:42.97893+00', 'When You And I Were Young Maggie', 10108, 98, 0, 0, NULL, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (8564, NULL, '2013-01-05 15:04:46.220626+00', 'Reels', 10108, 1, 6, 32, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (8568, NULL, '2013-01-05 15:05:20.566655+00', 'Quickstep', 10108, 50, 6, 32, NULL, NULL, 128, 0, '');
INSERT INTO 'recording' VALUES (8558, NULL, '2013-01-05 15:06:01.54741+00', 'Reels', 10108, 1, 6, 32, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (8576, NULL, '2012-01-20 12:55:49.703366+00', 'Saint Bernard''s Waltz', 10108, 5, 0, 16, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (8577, NULL, '2012-01-20 12:55:49.708987+00', 'Boston Two Step', 10108, 50, 0, 16, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (9773, '2014-11-14 10:09:11.101682+00', '2018-10-14 23:21:53.572138+00', 'Cooper Children, The', 3011, 2, 8, 40, NULL, NULL, 352, 0, '');
INSERT INTO 'recording' VALUES (8570, NULL, '2019-10-01 14:03:02.359803+00', 'Reels', 10108, 1, 6, 32, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (8578, NULL, '2012-01-20 12:55:49.71543+00', 'Canadian Barn Dance', 10108, 11, 0, 16, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (8579, NULL, '2012-01-20 12:55:49.722476+00', 'Mississippi Dip', 10108, 50, 0, 16, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (8580, NULL, '2012-01-20 12:55:49.728707+00', 'Shetland Quadrilles Figure 1', 10108, 1, 4, 32, NULL, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (8581, NULL, '2012-01-20 12:55:49.735221+00', 'Shetland Quadrilles Figure 2', 10108, 1, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (8582, NULL, '2012-01-20 12:55:49.741148+00', 'Shetland Quadrilles Figure 3', 10108, 2, 6, 32, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (8560, NULL, '2022-12-22 19:00:46.656252+00', 'Boston Two-Step', 10108, 50, 0, 16, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (8566, NULL, '2022-12-22 22:27:37.129436+00', 'Jigs', 10108, 2, 6, 32, NULL, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (8559, NULL, '2022-12-23 00:02:19.270111+00', 'Veleta Waltz', 10108, 5, 0, 0, NULL, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (8557, NULL, '2022-12-23 00:04:31.59228+00', 'Boston Two-Step', 10108, 50, 0, 16, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (8569, NULL, '2022-12-23 00:09:05.904744+00', 'Britannia Two-Step', 10108, 2, 0, 16, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (8567, NULL, '2023-01-01 02:03:07.752166+00', 'Reels', 10108, 1, 6, 32, NULL, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (8583, NULL, '2012-01-20 12:55:49.746959+00', 'Shetland Quadrilles Figure 4', 10108, 1, 6, 32, NULL, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (8584, NULL, '2012-01-20 12:55:49.752519+00', 'Shetland Quadrilles Figure 5', 10108, 2, 8, 32, NULL, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (8585, NULL, '2012-01-20 12:55:49.757984+00', 'Shetland Quadrilles Figure 6', 10108, 1, 6, 32, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (8586, NULL, '2012-01-20 12:55:49.763339+00', 'Accordion Duet', 10108, 5, 0, 0, NULL, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (8587, NULL, '2012-01-20 12:55:49.768917+00', 'Eva Three Step', 10108, 11, 0, 16, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (8588, NULL, '2012-01-20 12:55:49.774525+00', 'Palais Glide', 10108, 50, 0, 0, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (8589, NULL, '2012-01-20 12:55:49.779869+00', 'Strip the Willow', 10108, 2, 8, 32, NULL, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (8590, NULL, '2012-01-20 12:55:49.78523+00', 'Gay Gordons', 10108, 11, 0, 16, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (8591, NULL, '2012-01-20 12:55:49.790785+00', 'Dashing White Sergeant', 10108, 1, 6, 32, NULL, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (8592, NULL, '2012-01-20 12:55:49.796134+00', 'Military Two-Step', 10108, 11, 0, 16, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (8593, NULL, '2012-01-20 12:55:49.801559+00', 'Old Time Waltz', 10108, 5, 0, 0, NULL, NULL, 220, 0, '');
INSERT INTO 'recording' VALUES (8594, NULL, '2012-01-20 12:55:49.807123+00', 'Boston Two Step', 10108, 50, 0, 16, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (8595, NULL, '2012-01-20 12:55:49.812704+00', 'Britannia Two Step', 10108, 11, 0, 16, NULL, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (8596, NULL, '2012-01-20 12:55:49.81826+00', 'Dashing White Sergeant', 10108, 1, 6, 32, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (8597, NULL, '2012-01-20 12:55:49.823621+00', 'Veleta', 10108, 5, 0, 16, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (8598, NULL, '2012-01-20 12:55:49.829188+00', 'Eva Three Step', 10108, 11, 0, 16, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (8600, NULL, '2012-01-20 12:55:49.840039+00', 'Foula Reel, Da', 10108, 2, 4, 32, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (8601, NULL, '2012-01-20 12:55:49.845713+00', 'Gay Gordons', 10108, 11, 0, 16, NULL, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (8602, NULL, '2012-01-20 12:55:49.851216+00', 'Postman Pat', 10108, 98, 0, 0, NULL, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (8603, NULL, '2012-01-20 12:55:49.856715+00', 'Shetland Reel', 10108, 1, 6, 32, NULL, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (8604, NULL, '2012-01-20 12:55:49.8628+00', 'Boston Two Step', 10108, 50, 0, 16, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (8605, NULL, '2012-01-20 12:55:49.869023+00', 'Saint Bernard''s Waltz', 10108, 5, 0, 16, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (8606, NULL, '2012-01-20 12:55:49.874468+00', 'Hornpipes', 10108, 1, 4, 32, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (8607, NULL, '2012-01-20 12:55:49.87983+00', 'Strip the Willow', 10108, 2, 8, 32, NULL, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (8608, NULL, '2012-01-20 12:55:49.885173+00', 'Canadian Barn Dance', 10108, 11, 0, 16, NULL, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (8609, NULL, '2012-01-20 12:55:49.890746+00', 'Circassian Circle', 10108, 1, 4, 32, NULL, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (8610, NULL, '2012-01-20 12:55:49.896095+00', 'Gulberwick Bay', 10108, 98, 0, 0, NULL, NULL, 243, 0, '');
INSERT INTO 'recording' VALUES (8611, NULL, '2012-01-20 12:55:49.9021+00', 'Gay Gordons', 10541, 11, 0, 16, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (8613, NULL, '2012-01-20 12:55:49.913298+00', 'Waltz', 10541, 5, 0, 0, NULL, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (8614, NULL, '2012-01-20 12:55:49.918688+00', 'Dashing White Sergeant', 10541, 1, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (8615, NULL, '2012-01-20 12:55:49.924156+00', 'Boston Two Step', 10541, 11, 0, 16, NULL, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (8616, NULL, '2012-01-20 12:55:49.929924+00', 'Canadian Barn Dance', 10541, 11, 0, 16, NULL, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (8618, NULL, '2012-01-20 12:55:49.941019+00', 'Old St Pauls', 10541, 5, 0, 0, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (8619, NULL, '2012-01-20 12:55:49.946663+00', 'Eva Three Step', 10541, 11, 0, 16, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (8620, NULL, '2012-01-20 12:55:49.952413+00', 'Mistress Delia Graham''s Polka', 10541, 13, 0, 0, NULL, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (8621, NULL, '2012-01-20 12:55:49.957797+00', 'Triste Sourire', 10541, 5, 0, 0, NULL, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (8622, NULL, '2012-01-20 12:55:49.963278+00', 'Reels', 10541, 1, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (8623, NULL, '2012-01-20 12:55:49.968708+00', 'Edinburgh Mix', 10541, 11, 0, 16, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (8624, NULL, '2012-01-20 12:55:49.974426+00', 'Strip the Willow', 10541, 2, 8, 32, NULL, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (8625, NULL, '2012-01-20 12:55:49.979978+00', 'Barn Dance', 10541, 11, 0, 16, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (8627, NULL, '2012-01-20 12:55:49.991131+00', 'Reels', 10541, 1, 8, 32, NULL, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (8628, NULL, '2012-01-20 12:55:49.997672+00', 'Britannia Two Step', 10541, 11, 0, 16, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (8629, NULL, '2012-01-20 12:55:50.003038+00', 'Final Fling Jigs', 10541, 2, 8, 32, NULL, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (8633, NULL, '2012-01-20 12:55:50.008405+00', 'Jessie''s Hornpipe', 2189, 1, 6, 32, NULL, NULL, 222, 0, '');
INSERT INTO 'recording' VALUES (8639, NULL, '2012-01-20 12:55:50.013782+00', 'Dashing White Sergeant', 10546, 1, 6, 32, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (8650, NULL, '2012-01-20 12:55:50.019302+00', 'Primrose Polka, The', 2301, 13, 0, 0, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (8652, NULL, '2012-01-20 12:55:50.03025+00', 'Hesitation Waltz', 3065, 5, 0, 16, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (8653, NULL, '2012-01-20 12:55:50.035612+00', 'Jessie''s Hornpipe', 2189, 1, 6, 32, NULL, NULL, 222, 0, '');
INSERT INTO 'recording' VALUES (8654, NULL, '2012-01-20 12:55:50.041102+00', 'Royal Scots Polka, The', 2062, 13, 0, 0, NULL, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (8655, NULL, '2012-01-20 12:55:50.046602+00', 'Russe, La', 2131, 1, 2, 64, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (8656, NULL, '2012-01-20 12:55:50.051566+00', 'Gaelic Waltz', 10142, 5, 0, 0, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (8657, NULL, '2012-01-20 12:55:50.055882+00', 'Eva Three Step', 2337, 11, 0, 16, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (8658, NULL, '2012-01-20 12:55:50.061191+00', 'Strathspey', 2173, 3, 3, 32, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (8573, NULL, '2014-10-04 01:53:12.661576+00', 'Jigs', 10108, 2, 6, 32, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (8659, NULL, '2012-01-20 12:55:50.065748+00', 'Dashing White Sergeant', 10546, 1, 6, 32, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (8660, NULL, '2012-01-20 12:55:50.069926+00', 'Waltz Country Dance', 3057, 5, 4, 40, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (8661, NULL, '2012-01-20 12:55:50.07401+00', 'Highland Barn Dance', 1670, 11, 0, 16, NULL, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (8662, NULL, '2012-01-20 12:55:50.078215+00', 'Rob Roy', 2067, 1, 4, 32, NULL, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (8663, NULL, '2012-01-20 12:55:50.082326+00', 'Canadian Barn Dance', 10547, 11, 0, 16, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (8664, NULL, '2012-01-20 12:55:50.086516+00', 'Strathspey', 2036, 3, 4, 32, NULL, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (8665, NULL, '2012-01-20 12:55:50.090601+00', 'Highland Schottische', 10146, 3, 0, 8, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (8666, NULL, '2012-01-20 12:55:50.094755+00', 'Gay Gordons', 10277, 11, 0, 16, NULL, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (8667, NULL, '2012-01-20 12:55:50.098877+00', 'Linton Ploughman, The', 3026, 2, 4, 32, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (8668, NULL, '2012-01-20 12:55:50.103232+00', 'Pride of Erin Waltz', 10548, 5, 0, 32, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (8669, NULL, '2012-01-20 12:55:50.107429+00', 'Highland Wedding', 10186, 11, 0, 16, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (8670, NULL, '2012-01-20 12:55:50.111587+00', 'Eight Men of Moidart, The', 2328, 1, 6, 16, NULL, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (8672, NULL, '2012-01-20 12:55:50.119747+00', 'Bluebell Polka', 3065, 13, 10, 16, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (8673, NULL, '2012-01-20 12:55:50.123915+00', 'Call of the Pipes, The', 2062, 11, 0, 16, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (8674, NULL, '2012-01-20 12:55:50.128077+00', 'MacDonald of Sleat', 2189, 2, 0, 120, NULL, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (8675, NULL, '2012-01-20 12:55:50.132194+00', 'Wild Geese, The', 3018, 2, 5, 32, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (8676, NULL, '2012-01-20 12:55:50.136266+00', 'Gaelic Waltz', 2337, 5, 0, 0, NULL, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (8677, NULL, '2012-01-20 12:55:50.140443+00', 'Saturday Dance, The', 10546, 2, 5, 32, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (8678, NULL, '2012-01-20 12:55:50.144531+00', 'Mistress Jameson''s Delight', 10549, 5, 0, 0, NULL, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (8679, NULL, '2012-01-20 12:55:50.148935+00', 'Happy Harry Polka', 2131, 13, 0, 0, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (8680, NULL, '2012-01-20 12:55:50.153046+00', 'Duke of Perth', 3057, 1, 6, 32, NULL, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (8681, NULL, '2012-01-20 12:55:50.157113+00', 'Misty Isle, The', 10142, 98, 0, 0, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (8682, NULL, '2012-01-20 12:55:50.16221+00', 'Strathspey and Reel', 10186, 4, 1, 64, 5, NULL, 96, 0, '');
INSERT INTO 'recording' VALUES (8683, NULL, '2012-01-20 12:55:50.16645+00', 'Circassian Circle', 2173, 1, 6, 32, NULL, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (8684, NULL, '2012-01-20 12:55:50.171356+00', 'Bonnie Lass o'' Bon Accord, The', 3041, 3, 1, 64, NULL, NULL, 127, 0, '');
INSERT INTO 'recording' VALUES (8685, NULL, '2012-01-20 12:55:50.175527+00', 'Strip the Willow', 10548, 2, 6, 32, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (8686, NULL, '2012-01-20 12:55:50.180567+00', 'Waltz', 2036, 5, 0, 96, NULL, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (8687, NULL, '2012-01-20 12:55:50.185939+00', 'Flowers of Edinburgh, The', 1456, 1, 8, 32, NULL, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (8612, NULL, '2022-12-09 19:58:00.029261+00', 'Jigs', 10541, 2, 8, 32, NULL, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (8561, NULL, '2022-12-22 18:40:29.453675+00', 'Gay Gordons', 10108, 11, 0, 16, NULL, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (8626, NULL, '2022-12-14 16:37:24.866123+00', 'Pride of Erin Waltz', 10541, 5, 0, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (8563, NULL, '2022-12-22 18:41:47.948888+00', 'Boston Two-Step', 10108, 50, 0, 16, NULL, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (8688, NULL, '2012-01-20 12:55:50.191303+00', 'Saint Bernard''s Waltz', 3026, 5, 10, 16, NULL, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (8690, NULL, '2012-01-20 12:55:50.201394+00', 'Bees of Maggieknockater', 10551, 2, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (8691, NULL, '2012-01-20 12:55:50.205503+00', 'Selection of Reels', 10551, 1, 5, 32, NULL, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (8692, NULL, '2012-01-20 12:55:50.209578+00', 'Selection of Strathspeys', 10551, 3, 4, 32, NULL, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (8693, NULL, '2012-01-20 12:55:50.213668+00', 'Hooper''s Jig', 10551, 2, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (8694, NULL, '2012-01-20 12:55:50.21786+00', 'Bratach Bana', 10551, 1, 8, 32, NULL, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (8695, NULL, '2012-01-20 12:55:50.222055+00', 'Lamb Skinnet', 10551, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (8696, NULL, '2012-01-20 12:55:50.226127+00', 'Castle Douglas', 10551, 3, 8, 32, NULL, NULL, 528, 0, '');
INSERT INTO 'recording' VALUES (8698, NULL, '2012-01-20 12:55:50.234467+00', 'Wendy of Appin', 10551, 1, 8, 32, NULL, NULL, 299, 0, '');
INSERT INTO 'recording' VALUES (8699, NULL, '2012-01-20 12:55:50.238619+00', 'Atholl Highlanders', 10551, 98, 0, 0, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (8700, NULL, '2012-01-20 12:55:50.242699+00', 'March, Strathspey & Reels Medley', 10551, 98, 0, 0, NULL, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (8701, NULL, '2012-01-20 12:55:50.246761+00', 'Air, Strathspey & Reels Medley', 10551, 98, 0, 0, NULL, NULL, 228, 0, '');
INSERT INTO 'recording' VALUES (8702, NULL, '2012-01-20 12:55:50.250821+00', 'Retreat Marches', 10551, 98, 0, 0, NULL, NULL, 243, 0, '');
INSERT INTO 'recording' VALUES (8703, NULL, '2012-01-20 12:55:50.254889+00', 'Eva Three Step', 2503, 11, 0, 16, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (8704, NULL, '2012-01-20 12:55:50.258984+00', 'Eight Men of Moidart', 2503, 1, 6, 16, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (8705, NULL, '2012-01-20 12:55:50.263046+00', 'Nae Luck aboot the Hoose', 2503, 3, 4, 32, NULL, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (8706, NULL, '2012-01-20 12:55:50.267109+00', 'Hamilton House', 2503, 2, 6, 32, NULL, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (8707, NULL, '2012-01-20 12:55:50.271218+00', 'Scottish Waltz', 2503, 5, 0, 16, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (8708, NULL, '2012-01-20 12:55:50.275323+00', 'Alasdair''s Solo', 2503, 98, 0, 0, NULL, NULL, 302, 0, '');
INSERT INTO 'recording' VALUES (8709, NULL, '2012-01-20 12:55:50.279414+00', 'Highland Barn Dance', 2503, 11, 0, 16, NULL, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (8710, NULL, '2012-01-20 12:55:50.28353+00', 'Mrs Cholmondeley''s Reel', 2503, 1, 6, 32, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (8671, NULL, '2019-12-12 21:07:20.460677+00', 'Looking for a Partner', 2301, 2, 5, 32, NULL, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (8711, NULL, '2012-01-20 12:55:50.28765+00', 'Braes of Breadalbane, The', 2503, 3, 3, 32, NULL, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (8712, NULL, '2012-01-20 12:55:50.291713+00', 'Duke of Atholl''s Reel, The', 2503, 2, 6, 32, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (8713, NULL, '2012-01-20 12:55:50.2958+00', 'Gay Gordons', 2503, 11, 8, 16, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (8714, NULL, '2012-01-20 12:55:50.29991+00', 'Tullynessle', 2503, 3, 4, 32, NULL, NULL, 248, 0, '');
INSERT INTO 'recording' VALUES (8715, NULL, '2012-01-20 12:55:50.304017+00', 'Boston Two Step', 2503, 50, 8, 16, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (8716, NULL, '2012-01-20 12:55:50.308088+00', 'Fireside Reel, The', 2503, 1, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (8717, NULL, '2012-01-20 12:55:50.312142+00', 'Gaelic Waltz', 2503, 5, 0, 16, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (8718, NULL, '2012-01-20 12:55:50.316209+00', 'Selection of Marches', 10553, 11, 0, 16, NULL, NULL, 117, 0, '');
INSERT INTO 'recording' VALUES (8719, NULL, '2012-01-20 12:55:50.320266+00', 'Selection of Jigs', 10553, 2, 4, 32, NULL, NULL, 127, 0, '');
INSERT INTO 'recording' VALUES (8720, NULL, '2012-01-20 12:55:50.324369+00', 'Margaret''s Polka', 10553, 13, 6, 16, NULL, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (8721, NULL, '2012-01-20 12:55:50.328472+00', 'Scottish Waltz', 10553, 5, 0, 16, NULL, NULL, 226, 0, '');
INSERT INTO 'recording' VALUES (8722, NULL, '2012-01-20 12:55:50.332549+00', 'Selection of Reels', 10553, 1, 4, 32, NULL, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (8723, NULL, '2012-01-20 12:55:50.336611+00', '2/4 Pipe Marches', 10553, 11, 0, 16, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (8724, NULL, '2012-01-20 12:55:50.340675+00', '6/8 Pipe Marches', 10553, 11, 0, 16, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (8725, NULL, '2012-01-20 12:55:50.344818+00', '4/4 2/4 & 6/8 Marches', 10553, 11, 0, 16, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (8726, NULL, '2012-01-20 12:55:50.349588+00', 'Hornpipe Strathspey and Reel', 10553, 4, 1, 128, 10016, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (8727, NULL, '2012-01-20 12:55:50.353678+00', 'Dantesque Polka', 10553, 13, 0, 16, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (8728, NULL, '2012-01-20 12:55:50.357735+00', 'Shetland Two Step, The', 10553, 11, 0, 16, NULL, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (8729, NULL, '2012-01-20 12:55:50.361821+00', 'Continental Waltz', 10553, 5, 6, 16, NULL, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (8730, NULL, '2012-01-20 12:55:50.365909+00', '6/8 Pipe Marches', 10553, 11, 0, 16, NULL, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (8731, NULL, '2012-01-20 12:55:50.369986+00', 'Strathspeys', 10553, 3, 3, 32, NULL, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (8732, NULL, '2012-01-20 12:55:50.37404+00', 'Bagpipe Selection', 10553, 11, 0, 16, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (8733, NULL, '2012-01-20 12:55:50.378152+00', '6/8 Pipe Marches', 10553, 11, 0, 16, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (8734, NULL, '2012-01-20 12:55:50.382323+00', 'Waltz', 10553, 5, 0, 16, NULL, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (8735, NULL, '2012-01-20 12:55:50.386378+00', 'Selection of Reels', 10553, 1, 4, 32, NULL, NULL, 125, 0, '');
INSERT INTO 'recording' VALUES (8736, NULL, '2012-01-20 12:55:50.390673+00', 'To the Games', 10148, 11, 0, 16, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (8737, NULL, '2012-01-20 12:55:50.39477+00', 'Angus MacLeod', 10148, 1, 2, 64, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (8738, NULL, '2012-01-20 12:55:50.398842+00', 'Inverness Polka', 10148, 1, 4, 32, NULL, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (8739, NULL, '2012-01-20 12:55:50.40291+00', 'Shetland Memories', 10148, 5, 0, 16, NULL, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (8740, NULL, '2012-01-20 12:55:50.406968+00', 'Call of the Pipes, The', 10148, 50, 0, 0, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (8741, NULL, '2012-01-20 12:55:50.411042+00', 'Highland Scottische', 10148, 3, 0, 8, NULL, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (8742, NULL, '2012-01-20 12:55:50.415098+00', 'Lerwick Two Step, The', 10148, 11, 0, 16, NULL, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (8743, NULL, '2012-01-20 12:55:50.419162+00', 'Mrs MacLeod', 10148, 1, 6, 32, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (8744, NULL, '2012-01-20 12:55:50.42321+00', 'Hebridean Barn Dance', 10148, 11, 0, 16, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (8745, NULL, '2012-01-20 12:55:50.427265+00', 'Duke of Perth', 10148, 1, 6, 32, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (8746, NULL, '2012-01-20 12:55:50.431348+00', 'Waltzing Through the Isles', 10148, 5, 0, 16, NULL, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (8747, NULL, '2012-01-20 12:55:50.435398+00', 'After the Games', 10148, 11, 0, 16, NULL, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (8748, NULL, '2012-01-20 12:55:50.439461+00', 'Jigs', 10555, 2, 8, 32, NULL, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (8749, NULL, '2012-01-20 12:55:50.443512+00', 'Medley', 10555, 4, 0, 128, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (8750, NULL, '2012-01-20 12:55:50.447577+00', 'Highland Schottische', 10555, 3, 0, 8, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (8751, NULL, '2012-01-20 12:55:50.451652+00', 'Slow Waltz', 10555, 5, 0, 0, NULL, NULL, 233, 0, '');
INSERT INTO 'recording' VALUES (8752, NULL, '2012-01-20 12:55:50.4557+00', 'Highland Reels', 10555, 1, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (8753, NULL, '2012-01-20 12:55:50.460102+00', 'Jigs', 10555, 2, 6, 32, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (8754, NULL, '2012-01-20 12:55:50.465602+00', 'Gaelic Waltzes', 10555, 5, 0, 0, NULL, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (8755, NULL, '2012-01-20 12:55:50.471085+00', '6/8 Marches', 10555, 11, 0, 16, NULL, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (8756, NULL, '2012-01-20 12:55:50.476453+00', 'Slow Waltz', 10555, 5, 0, 0, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (8757, NULL, '2012-01-20 12:55:50.481972+00', 'Pipe Reels', 10555, 1, 4, 32, NULL, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (8758, NULL, '2012-01-20 12:55:50.487318+00', 'Retreats', 10555, 11, 0, 16, NULL, NULL, 223, 0, '');
INSERT INTO 'recording' VALUES (8759, NULL, '2012-01-20 12:55:50.494072+00', 'Pipe Jigs', 10555, 2, 6, 32, NULL, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (8761, NULL, '2012-01-20 12:55:50.505165+00', 'Tunes to the Rhythm of The Harris Tweed Loom', 10555, 98, 0, 0, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (8762, NULL, '2012-01-20 12:55:50.510563+00', 'Medley', 10555, 4, 0, 160, NULL, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (8763, NULL, '2012-01-20 12:55:50.515994+00', 'Jigs', 10555, 2, 8, 32, NULL, NULL, 242, 0, '');
INSERT INTO 'recording' VALUES (8764, NULL, '2012-01-20 12:55:50.521388+00', 'Polka', 10555, 13, 0, 16, NULL, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (8765, NULL, '2012-01-20 12:55:50.526758+00', '6/8 Marches', 10555, 11, 0, 16, NULL, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (8766, NULL, '2012-01-20 12:55:50.532278+00', 'Pipe Reels', 10555, 1, 8, 32, NULL, NULL, 231, 0, '');
INSERT INTO 'recording' VALUES (8767, NULL, '2012-01-20 12:55:50.537784+00', 'Tribute to Roddy MacMillan', 10555, 98, 0, 0, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (8768, NULL, '2012-01-20 12:55:50.543152+00', '4/4 Marches', 10555, 11, 0, 16, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (8769, NULL, '2012-01-20 12:55:50.548502+00', '2/4 Marches', 10555, 11, 0, 16, NULL, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (8770, NULL, '2012-01-20 12:55:50.554071+00', 'Bonnie Dundee', 10555, 2, 6, 32, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (8771, NULL, '2012-01-20 12:55:50.559426+00', 'Black Mountain Reel', 10555, 1, 5, 32, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (8772, NULL, '2012-01-20 12:55:50.564902+00', 'To the Games', 2328, 11, 0, 16, NULL, NULL, 159, 0, '');
INSERT INTO 'recording' VALUES (8773, NULL, '2012-01-20 12:55:50.569422+00', 'Highland Polka', 2328, 13, 0, 16, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (8775, NULL, '2012-01-20 12:55:50.57831+00', 'Duke of Perth', 2328, 1, 10, 32, NULL, NULL, 328, 0, '');
INSERT INTO 'recording' VALUES (8776, NULL, '2012-01-20 12:55:50.582702+00', 'Eva Three Step', 2328, 11, 0, 16, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (8689, NULL, '2023-01-01 21:40:21.335424+00', 'Eightsome Reel', 10146, 1, 0, 464, NULL, NULL, 494, 0, '');
INSERT INTO 'recording' VALUES (8778, NULL, '2012-01-20 12:55:50.591299+00', 'Marches in 6/8', 2328, 11, 0, 16, NULL, NULL, 151, 0, '');
INSERT INTO 'recording' VALUES (8780, NULL, '2012-01-20 12:55:50.599468+00', 'Pride of Erin Waltz', 2328, 5, 0, 32, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (8781, NULL, '2012-01-20 12:55:50.603535+00', 'Gay Gordons', 2328, 11, 0, 16, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (8782, NULL, '2012-01-20 12:55:50.607692+00', 'Glasgow Highlanders', 2328, 3, 3, 32, NULL, NULL, 151, 1, '');
INSERT INTO 'recording' VALUES (8783, NULL, '2012-01-20 12:55:50.611773+00', 'Corn Rigs', 2328, 1, 6, 32, NULL, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (8784, NULL, '2012-01-20 12:55:50.615979+00', 'Peter MacLeod', 2328, 11, 0, 16, NULL, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (8785, NULL, '2012-01-20 12:55:50.620351+00', 'Highland Two Step', 2328, 11, 0, 16, NULL, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (8786, NULL, '2012-01-20 12:55:50.624449+00', 'Polka', 2328, 13, 0, 16, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (8787, NULL, '2012-01-20 12:55:50.628628+00', 'Gatherings, The', 2328, 11, 0, 16, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (8788, NULL, '2012-01-20 12:55:50.632696+00', 'Reel of the 51st Division', 2328, 1, 4, 32, NULL, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (8789, NULL, '2012-01-20 12:55:50.636759+00', 'After the Games', 2328, 98, 0, 0, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (8790, NULL, '2012-01-20 12:55:50.64083+00', 'Whistling Rufus', 3010, 50, 0, 0, NULL, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (8791, NULL, '2012-01-20 12:55:50.644947+00', 'Balintore Fisherman Polka', 3010, 13, 0, 16, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (8792, NULL, '2012-01-20 12:55:50.649053+00', 'Quarry Knowe Waltz', 3010, 5, 0, 32, NULL, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (8793, NULL, '2012-01-20 12:55:50.653124+00', 'Call O''the Pipes, The', 3010, 11, 0, 16, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (8795, NULL, '2012-01-20 12:55:50.661261+00', 'Gay Gordons', 3010, 11, 0, 16, NULL, NULL, 167, 0, '');
INSERT INTO 'recording' VALUES (8796, NULL, '2012-01-20 12:55:50.66533+00', 'Gaelic Waltz', 3010, 5, 0, 16, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (8797, NULL, '2012-01-20 12:55:50.669464+00', 'Angus Reel, The', 3010, 1, 4, 32, NULL, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (8798, NULL, '2012-01-20 12:55:50.673553+00', 'Happy Hours Polka', 3010, 13, 0, 16, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (8799, NULL, '2012-01-20 12:55:50.67764+00', 'Marches', 3010, 11, 0, 16, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (8800, NULL, '2012-01-20 12:55:50.681703+00', 'Military Two Step', 3010, 11, 0, 16, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (8801, NULL, '2012-01-20 12:55:50.685759+00', 'Dashing White Sergeant', 3010, 1, 5, 32, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (8802, NULL, '2012-01-20 12:55:50.689887+00', 'Ca'' The Ewes Tae The Knowes', 3010, 3, 4, 32, NULL, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (4540, NULL, '2018-10-15 16:44:14.741173+00', 'Jig 4x32', 3060, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (8805, NULL, '2012-01-20 12:55:50.703199+00', 'Gordon Waltz', 3010, 5, 0, 32, NULL, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (8806, NULL, '2012-01-20 12:55:50.707311+00', 'Bridge of Nairn', 3010, 3, 4, 32, NULL, NULL, 221, 0, '');
INSERT INTO 'recording' VALUES (8807, NULL, '2012-01-20 12:55:50.711516+00', 'Whistler and his Dog, The', 3010, 50, 0, 0, NULL, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (8808, NULL, '2012-01-20 12:55:50.715595+00', 'Strathspeys', 3010, 3, 4, 32, NULL, NULL, 227, 0, '');
INSERT INTO 'recording' VALUES (8809, NULL, '2012-01-20 12:55:50.719765+00', 'Shufflin'' Samuel', 3010, 50, 0, 0, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (8810, NULL, '2012-01-20 12:55:50.723858+00', 'Punch Bowl, The', 3010, 1, 4, 32, NULL, NULL, 134, 0, '');
INSERT INTO 'recording' VALUES (8812, NULL, '2012-01-20 12:55:50.732159+00', '12 Coates Crescent', 10569, 3, 8, 32, NULL, NULL, 518, 0, '');
INSERT INTO 'recording' VALUES (8814, NULL, '2012-01-20 12:55:50.741102+00', 'Bantam Cocks, The', 10569, 4, 0, 224, 9998, NULL, 310, 0, '');
INSERT INTO 'recording' VALUES (8815, NULL, '2012-01-20 12:55:50.745199+00', 'Magic of Merrill, The', 10569, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (8816, NULL, '2012-01-20 12:55:50.749289+00', 'Lochaber Waltzes', 10569, 5, 0, 0, NULL, NULL, 225, 0, '');
INSERT INTO 'recording' VALUES (8817, NULL, '2012-01-20 12:55:50.753546+00', 'Caller Herrin''', 2067, 1, 8, 40, NULL, NULL, 329, 0, '');
INSERT INTO 'recording' VALUES (8819, NULL, '2012-01-20 12:55:50.76178+00', 'Kendoon Strathspey, The', 2067, 3, 8, 32, NULL, NULL, 474, 0, '');
INSERT INTO 'recording' VALUES (8820, NULL, '2012-01-20 12:55:50.765914+00', 'Black Dance, The', 1456, 1, 8, 32, NULL, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (8821, NULL, '2012-01-20 12:55:50.769986+00', 'Airie Bennan', 2067, 2, 5, 32, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (8823, NULL, '2012-01-20 12:55:50.778237+00', 'J. B. Milne', 2067, 1, 8, 32, NULL, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (8824, NULL, '2012-01-20 12:55:50.782666+00', 'River Cree, The', 1456, 2, 8, 32, NULL, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (8827, NULL, '2012-01-20 12:55:50.795161+00', 'Wee Cooper o'' Fife, The', 2067, 2, 8, 40, NULL, NULL, 313, 0, '');
INSERT INTO 'recording' VALUES (8828, NULL, '2012-01-20 12:55:50.79924+00', 'Polharrow Burn', 2067, 1, 5, 32, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (8830, NULL, '2012-01-20 12:55:50.807378+00', 'Circassian Circle', 1456, 1, 8, 32, NULL, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (8832, NULL, '2012-01-20 12:55:50.817118+00', 'Newcastle Festival, The', 3039, 1, 4, 32, NULL, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (8833, NULL, '2012-01-20 12:55:50.821252+00', 'Wingrove Strathspey, The', 3039, 3, 4, 32, NULL, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (8836, NULL, '2012-01-20 12:55:50.834324+00', 'Still Buzzing', 3039, 1, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (8837, NULL, '2012-01-20 12:55:50.838403+00', 'Double Score', 3039, 3, 4, 40, NULL, NULL, 320, 0, '');
INSERT INTO 'recording' VALUES (8838, NULL, '2012-01-20 12:55:50.842468+00', 'Tyneside Ceilidh', 3039, 1, 6, 32, NULL, NULL, 223, 0, '');
INSERT INTO 'recording' VALUES (8839, NULL, '2012-01-20 12:55:50.846776+00', 'St Chad''s Strathspey', 3039, 3, 3, 32, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (8840, NULL, '2012-01-20 12:55:50.85087+00', 'Keys, The', 3039, 2, 4, 32, NULL, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (8841, NULL, '2012-01-20 12:55:50.854941+00', 'Devil''s Water, The', 3039, 3, 4, 40, NULL, NULL, 301, 0, '');
INSERT INTO 'recording' VALUES (8842, NULL, '2012-01-20 12:55:50.85901+00', 'Blagdon Hall', 3039, 1, 4, 48, NULL, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (8843, NULL, '2012-01-20 12:55:50.863311+00', 'Newcastle Half Century, The', 3039, 2, 8, 32, NULL, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (8844, NULL, '2012-01-20 12:55:50.86743+00', 'Jig for Helen, A', 3039, 2, 4, 40, NULL, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (8845, NULL, '2012-01-20 12:55:50.871498+00', 'Peter and Madeleine Quince', 3039, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (8822, NULL, '2012-05-06 22:03:46.099817+00', 'Ye''ll Aye be Welcome Back Again', 1456, 3, 8, 32, NULL, NULL, 477, 0, '');
INSERT INTO 'recording' VALUES (9322, '2013-03-19 09:30:27.265443+00', '2013-03-19 09:30:27.265449+00', 'Lamp Black Lizzie', 10330, 2, 4, 40, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (9326, '2013-03-19 20:38:57.562479+00', '2013-03-19 20:38:57.562485+00', 'Waltz', 3014, 50, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (9327, '2013-03-19 20:44:16.386203+00', '2013-03-19 20:44:16.386209+00', 'Boston Two-Step', 3014, 2, 4, 32, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (8254, NULL, '2013-03-31 16:32:42.091631+00', 'Kirrie March', 3217, 11, 0, 16, NULL, NULL, 157, 0, '');
INSERT INTO 'recording' VALUES (6994, NULL, '2013-04-07 20:42:32.522479+00', 'Bellfield Park', 3023, 2, 4, 32, NULL, NULL, 150, 1, '');
INSERT INTO 'recording' VALUES (2077, NULL, '2013-04-08 08:44:46.308635+00', 'Highlander''s Jig, The', 2048, 2, 4, 32, 9999, 1, 195, 0, '');
INSERT INTO 'recording' VALUES (9207, '2013-01-16 13:50:42.782335+00', '2013-04-08 08:45:52.217406+00', 'Strip the Willow / Macgregor''s Farewell to Whisky', 10104, 2, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (7532, NULL, '2013-04-08 18:55:55.324215+00', 'Military Two Step', 3037, 11, 0, 16, 9999, NULL, 117, 0, '');
INSERT INTO 'recording' VALUES (6213, NULL, '2013-04-10 09:11:37.806773+00', 'Selection of Waltzes', 3067, 5, 6, 32, 9999, NULL, 244, 0, '');
INSERT INTO 'recording' VALUES (8914, '2012-06-12 16:04:41.942296+00', '2019-01-05 12:30:49.700383+00', 'Lord Brownlow''s Strathspey', 3012, 3, 3, 32, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (9319, '2013-03-19 09:19:20.760359+00', '2019-04-10 22:19:09.620879+00', 'Noces d''Or, Les', 10330, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (8834, NULL, '2019-10-01 21:03:50.409723+00', 'Smiling Sally', 3039, 2, 8, 32, NULL, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (8803, NULL, '2019-10-03 18:33:22.657311+00', 'Quickstep', 3010, 50, 4, 32, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (9081, '2013-01-03 10:03:22.448364+00', '2013-04-10 10:03:48.990093+00', 'Cold Winds 6/8 Marches', 2088, 11, 8, 16, 9999, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (7315, NULL, '2013-04-28 13:11:51.180155+00', 'Quarryman''s Jig suitable for The Quarryman''s Jig, The', 10114, 2, 8, 32, NULL, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (9336, '2013-05-11 16:15:47.62469+00', '2014-03-10 07:39:39.419148+00', 'Mary Bain''s Wedding', 3420, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (9329, '2013-05-11 16:07:13.178682+00', '2014-03-10 07:35:17.138674+00', 'Seton''s Ceilidh Band', 3420, 2, 4, 64, NULL, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (9340, '2013-05-11 16:20:37.133061+00', '2014-03-10 08:02:55.4086+00', 'Bonnie Brux', 3420, 4, 1, 80, 4, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (9028, '2012-12-31 16:21:58.404025+00', '2013-05-26 19:27:55.248754+00', 'Swan and the Tay, The', 2944, 3, 3, 32, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (7024, NULL, '2013-05-28 09:44:36.305666+00', 'Two Inch Race, The', 10037, 1, 5, 32, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (2448, NULL, '2013-06-13 13:26:28.908415+00', 'Caretaker, The', 3002, 1, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (6467, NULL, '2013-07-21 13:44:31.06456+00', 'Chairman''s Chain, The', 3006, 2, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (8302, NULL, '2022-02-18 21:23:48.330078+00', 'Dashing White Sergeant', 10659, 1, 8, 32, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (8818, NULL, '2022-12-15 23:58:11.16453+00', 'Kiss For Nothing, A', 1456, 2, 8, 32, NULL, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (8779, NULL, '2023-01-01 21:40:32.582285+00', 'Eightsome Reel', 2328, 1, 0, 464, NULL, NULL, 474, 0, '');
INSERT INTO 'recording' VALUES (8794, NULL, '2023-01-21 18:20:04.941447+00', 'Robertson Rant, The', 3010, 3, 0, 80, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (7750, NULL, '2013-08-01 09:50:39.424797+00', '4/4 Marches', 10183, 11, 0, 0, NULL, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (187, NULL, '2013-08-01 09:53:09.790625+00', 'Mairi''s Wedding', 3008, 1, 8, 40, 9999, NULL, 320, 0, '');
INSERT INTO 'recording' VALUES (1628, NULL, '2013-08-01 09:54:06.7554+00', 'Irish Rover, The', 2041, 1, 8, 32, 9999, 1, 256, 0, '');
INSERT INTO 'recording' VALUES (7981, NULL, '2013-08-01 09:55:15.710238+00', 'Mairi''s Wedding', 10209, 1, 8, 40, NULL, NULL, 338, 0, '');
INSERT INTO 'recording' VALUES (8777, NULL, '2013-08-01 10:08:28.144512+00', 'Dumbarton Drums', 2328, 1, 4, 32, NULL, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (9226, '2013-02-02 14:13:29.881517+00', '2013-08-01 10:11:25.179964+00', 'Flying Scotsman, The', 10146, 1, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (8045, NULL, '2013-08-01 10:33:15.386138+00', 'Ken and Lavinia Morris', 10237, 3, 4, 32, NULL, NULL, 240, 1, '');
INSERT INTO 'recording' VALUES (1898, NULL, '2013-08-05 10:50:06.452309+00', 'Eva Three Step', 3040, 11, 12, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3601, NULL, '2013-08-05 10:50:52.755036+00', 'Eva Three Step', 3063, 11, 0, 16, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1968, NULL, '2013-08-05 10:52:57.875426+00', 'Blue Bonnets', 2246, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (4252, NULL, '2013-08-05 10:53:36.571888+00', 'Linton Ploughman', 2429, 2, 6, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9345, '2013-08-06 13:42:00.042946+00', '2013-08-06 13:42:00.042946+00', 'Mississauga Starter', 10823, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (9346, '2013-08-06 13:46:38.499016+00', '2013-08-06 13:46:38.499016+00', 'Buchan''s Country', 10823, 3, 3, 48, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (9347, '2013-08-06 13:49:31.233538+00', '2013-08-06 13:49:31.233538+00', 'Budapest Birl', 10823, 2, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (9351, '2013-08-06 14:10:44.781724+00', '2013-08-06 14:10:44.781724+00', 'Machine Without Wheels', 10823, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (9352, '2013-08-06 14:14:53.081265+00', '2013-08-06 14:14:53.081265+00', 'Hana', 10823, 3, 8, 32, 9999, NULL, 497, 0, '');
INSERT INTO 'recording' VALUES (8826, NULL, '2019-12-12 21:08:49.407838+00', 'My Love She''s but a Lassie Yet', 1456, 1, 8, 32, NULL, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (8811, NULL, '2020-07-08 14:57:56.623511+00', 'Sparkling Sixty', 10569, 1, 8, 40, NULL, NULL, 355, 0, '');
INSERT INTO 'recording' VALUES (8813, NULL, '2020-07-08 14:58:10.382767+00', 'Meeting and Greeting', 10569, 2, 6, 32, NULL, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (9354, '2013-08-06 14:22:57.966755+00', '2013-08-06 14:22:57.966755+00', 'New Approach, A', 10823, 3, 5, 32, 9999, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (9355, '2013-08-06 14:25:09.854789+00', '2013-08-06 14:25:09.854789+00', 'Mathematicians, The', 10823, 1, 5, 40, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (9356, '2013-08-06 14:30:13.62444+00', '2013-08-06 14:30:13.62444+00', 'Lys i Mørketida', 10823, 5, 0, 0, 9999, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (9324, '2013-03-19 09:43:23.890965+00', '2013-08-19 11:56:43.876215+00', 'Little Treasure, The', 3014, 3, 3, 32, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (9325, '2013-03-19 09:51:35.171899+00', '2013-08-19 11:56:43.918974+00', 'Milestone Jig, The', 3014, 2, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (9320, '2013-03-19 09:24:58.928636+00', '2013-08-19 11:56:44.017736+00', 'Saltburn Lass, The', 10330, 2, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (9331, '2013-05-11 16:09:36.169623+00', '2014-03-10 01:06:59.513586+00', 'Thistle Hall', 3420, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (9335, '2013-05-11 16:14:54.834378+00', '2014-03-10 07:33:08.650274+00', 'Five Row Reel, The', 3420, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9339, '2013-05-11 16:20:29.244818+00', '2014-03-10 07:42:17.55768+00', 'Elisabeth Hunter''s Strathspey', 3420, 3, 3, 32, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (9334, '2013-05-11 16:13:14.372157+00', '2014-03-10 07:34:03.88469+00', 'Laird of Milton''s Daughter, The', 3420, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (9338, '2013-05-11 16:18:31.473973+00', '2014-03-10 07:58:05.507983+00', 'On the Quarter-Deck', 3420, 1, 8, 32, NULL, NULL, 287, 0, 'Hornpipe');
INSERT INTO 'recording' VALUES (9337, '2013-05-11 16:17:08.970347+00', '2014-03-10 07:54:19.137491+00', 'Glenlomond Reel', 3420, 1, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (9367, '2013-09-11 21:49:57.635372+00', '2018-03-23 09:49:32.881582+00', 'It wasnae me', 3050, 3, 4, 32, 9999, NULL, 262, 1, '');
INSERT INTO 'recording' VALUES (9341, '2013-05-11 16:22:12.898037+00', '2014-03-10 08:15:13.56239+00', 'Glen Mor', 3420, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9344, '2013-05-11 16:26:06.719488+00', '2014-03-10 08:31:14.647101+00', 'Hunting Horn, The', 3420, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (9343, '2013-05-11 16:24:21.921894+00', '2014-03-10 08:26:32.370052+00', 'Cadgers in the Canongate', 3420, 1, 8, 48, NULL, NULL, 424, 0, '');
INSERT INTO 'recording' VALUES (9321, '2013-03-19 09:27:40.954456+00', '2014-10-19 16:06:07.599799+00', '"You Cannot Go Wrong"', 10330, 3, 3, 32, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (8835, NULL, '2013-11-27 17:29:47.569362+00', 'Maureen''s Medley', 3039, 4, 1, 128, 2, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (9332, '2013-05-11 16:10:47.477932+00', '2014-03-10 07:36:37.099509+00', 'Feshiebridge', 3420, 3, 6, 32, NULL, NULL, 370, 0, '');
INSERT INTO 'recording' VALUES (9328, '2013-04-10 00:15:43.225544+00', '2014-09-16 10:24:11.920873+00', 'Reel of Tulloch', 3018, 1, 4, 32, NULL, 5, 142, 0, '');
INSERT INTO 'recording' VALUES (5724, NULL, '2013-08-10 23:50:58.780787+00', 'Sgurr Alasdair', 3002, 1, 5, 32, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (5168, NULL, '2013-08-10 23:51:22.472995+00', 'Falls of Rogie', 2846, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (7403, NULL, '2013-08-10 23:51:51.077287+00', 'Mason''s Apron', 10129, 1, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (2718, NULL, '2013-08-10 23:52:21.077946+00', 'Eightsome Reel, The', 2090, 1, 1, 464, 9999, NULL, 475, 0, '');
INSERT INTO 'recording' VALUES (4899, NULL, '2013-08-10 23:52:59.284683+00', 'Duke and Duchess of Edinburgh, The', 2645, 1, 8, 40, 9999, NULL, 328, 0, '');
INSERT INTO 'recording' VALUES (8849, '2012-02-28 14:41:01.841376+00', '2013-08-19 11:56:43.727307+00', 'Hollin Buss, The', 903, 2, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (9323, '2013-03-19 09:33:28.045196+00', '2013-08-19 11:56:43.819566+00', 'Kintbury Strathspey, The', 10330, 3, 4, 32, NULL, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (8344, NULL, '2013-08-19 11:56:43.942135+00', 'New Scotland Strathspey, The', 10381, 3, 4, 40, NULL, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (9359, '2013-09-11 19:21:41.472576+00', '2013-09-11 19:21:41.472576+00', 'Linnea''s Strathspey', 3050, 3, 8, 32, 9999, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (9358, '2013-09-11 19:15:25.644615+00', '2013-09-11 19:22:04.33657+00', 'Bill Clement MBE', 3050, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (9360, '2013-09-11 19:36:12.472314+00', '2013-09-11 19:36:12.472314+00', 'Flight to Melbourne', 3050, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (9362, '2013-09-11 20:03:22.732265+00', '2013-09-11 20:03:22.732265+00', 'One o''Clock Canon, The', 3050, 1, 1, 160, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (9364, '2013-09-11 20:43:57.459985+00', '2013-09-11 20:43:57.459985+00', 'Memories of Mary Ann', 3050, 3, 3, 32, 9999, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (9365, '2013-09-11 20:48:45.840833+00', '2013-09-11 20:48:45.840833+00', 'Welcome to Ayr', 3050, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9366, '2013-09-11 21:42:28.851179+00', '2013-09-11 21:42:28.851179+00', 'Kissing Bridge, The', 3050, 1, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (9368, '2013-09-11 21:56:08.988376+00', '2013-09-11 21:56:08.988376+00', 'Glastonbury Tor', 3050, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9369, '2013-09-11 21:58:48.370483+00', '2013-09-11 21:58:48.370483+00', 'Mentor, The', 3050, 3, 1, 96, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (7476, NULL, '2013-09-29 20:53:51.972727+00', 'City of Nairobi Reel, The', 3065, 1, 4, 40, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (8901, '2012-06-12 14:18:18.859294+00', '2019-09-30 22:15:21.340334+00', 'Berkhamsted Castle', 3012, 1, 8, 32, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (9349, '2013-08-06 14:03:28.707447+00', '2015-09-06 19:06:37.006312+00', 'Carlin''s Loup', 10823, 1, 4, 32, 9999, NULL, 151, 1, '');
INSERT INTO 'recording' VALUES (9361, '2013-09-11 19:51:27.435241+00', '2017-02-12 13:27:09.286326+00', 'Aging Gracefully', 3050, 3, 8, 32, 9999, NULL, 507, 0, '');
INSERT INTO 'recording' VALUES (9348, '2013-08-06 13:58:41.961418+00', '2017-03-24 23:50:37.963735+00', 'Black Squirrel, The', 10823, 3, 8, 32, 9999, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (4124, NULL, '2018-10-19 20:49:10.862176+00', 'Bellstane', 3217, 1, 8, 32, 9999, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (9350, '2013-08-06 14:06:01.561291+00', '2019-07-24 22:12:10.221925+00', 'Cate''s Conundrum', 10823, 3, 3, 32, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (9370, '2013-10-29 01:22:38.794306+00', '2013-10-29 01:23:03.709953+00', '… And the Ladies Wore Red', 3217, 1, 4, 32, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (9372, '2013-10-29 01:36:10.43047+00', '2013-10-29 01:36:10.43047+00', 'Six Mile Road from Pitlochry', 3217, 4, 4, 64, 5, NULL, 382, 0, '');
INSERT INTO 'recording' VALUES (9373, '2013-10-29 01:38:59.195129+00', '2013-10-29 01:42:52.920933+00', 'Twins'' Delight, The', 3217, 2, 3, 32, 9999, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (9371, '2013-10-29 01:29:28.390029+00', '2013-10-29 01:43:38.273163+00', 'Anne, Duchess of Waltham', 3217, 3, 1, 80, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (9377, '2013-10-29 01:57:03.321844+00', '2013-10-29 01:57:03.321844+00', 'Salute to Lark Hill', 3217, 2, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (9378, '2013-10-29 02:03:02.667137+00', '2013-10-29 02:03:02.667137+00', 'Mrs Millar''s Strathspey', 3217, 3, 4, 32, 9999, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (9380, '2013-10-29 02:19:04.034372+00', '2013-10-29 02:20:50.84126+00', 'Hard Drive, The', 3217, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9381, '2013-10-29 02:24:36.256568+00', '2013-10-29 02:24:36.256568+00', 'Three Squared', 3217, 2, 9, 32, 9999, NULL, 321, 0, '');
INSERT INTO 'recording' VALUES (9383, '2013-10-29 02:31:52.827515+00', '2013-10-29 02:31:52.827515+00', 'Leaving Lunga', 3217, 3, 4, 32, 9999, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (9384, '2013-10-29 02:35:58.788931+00', '2013-10-29 02:35:58.788931+00', 'Tribute To Amanda', 3217, 1, 8, 32, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (9357, '2013-08-06 14:33:01.696157+00', '2022-09-01 11:28:25.312743+00', 'Jelly Roll, The', 10823, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (9353, '2013-08-06 14:19:02.09789+00', '2022-11-29 22:06:16.311659+00', 'Inveresk House', 10823, 2, 4, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (9374, '2013-10-29 01:42:14.213088+00', '2022-12-02 22:23:45.067607+00', 'Summer Sunday Strathspey', 3217, 3, 4, 32, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (9363, '2013-09-11 20:08:35.84914+00', '2022-12-19 16:23:32.397589+00', 'Vintage Simon', 3050, 2, 5, 32, 9999, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (9382, '2013-10-29 02:27:04.627743+00', '2023-01-01 02:03:22.703546+00', 'Rutland Reel, The', 3217, 1, 8, 40, 9999, NULL, 359, 0, '');
INSERT INTO 'recording' VALUES (9376, '2013-10-29 01:51:36.544193+00', '2013-11-28 00:40:05.002969+00', 'Waltham Ladies, The', 3217, 4, 1, 96, 10029, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (1465, NULL, '2013-12-07 07:27:50.590473+00', 'This is No'' My Ain Hoose', 3021, 3, 8, 32, 9999, 5, 499, 0, '');
INSERT INTO 'recording' VALUES (9330, '2013-05-11 16:08:24.792241+00', '2018-05-15 11:22:17.71348+00', 'Mr William Brown''s Reel', 3420, 1, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (9404, '2014-02-06 14:11:30.495774+00', '2014-02-06 14:11:30.495774+00', 'Waltzes', 3217, 5, 0, 0, 9999, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (7070, NULL, '2013-12-22 11:03:32.36241+00', 'Happy Rovers', 3050, 4, 1, 96, 21, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (9405, '2014-02-06 14:14:26.069947+00', '2014-02-06 14:14:26.069947+00', 'Marches 2/4', 3217, 11, 0, 0, 9999, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (8271, NULL, '2014-01-12 01:44:39.474955+00', 'Millenium March/Call of the Pipes', 10104, 11, 0, 0, NULL, NULL, 155, 0, 'The correct spelling of "Millenium" is "Millennium".');
INSERT INTO 'recording' VALUES (9402, '2014-02-06 13:58:42.301096+00', '2014-02-06 13:58:42.301096+00', 'Marches 4/4', 3217, 11, 0, 0, 9999, NULL, 228, 0, '');
INSERT INTO 'recording' VALUES (9406, '2014-02-06 14:18:32.854509+00', '2014-02-06 14:18:32.854509+00', 'Reels', 3217, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (9407, '2014-02-06 14:20:27.257344+00', '2014-02-06 14:20:27.257344+00', 'Two-Step', 3217, 50, 0, 0, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (9408, '2014-02-06 14:22:04.842536+00', '2014-02-06 14:22:04.842536+00', 'Waltz', 3217, 5, 0, 0, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (9409, '2014-02-06 14:27:58.707744+00', '2014-02-06 14:27:58.707744+00', 'Medley', 3217, 4, 0, 0, NULL, NULL, 302, 0, 'Slow Air, 9/8 March, Reel, Jig');
INSERT INTO 'recording' VALUES (9410, '2014-02-06 14:33:37.630012+00', '2014-02-06 14:33:37.630012+00', 'Strathspey', 3217, 3, 4, 32, 9999, NULL, 253, 0, '');
INSERT INTO 'recording' VALUES (9411, '2014-02-06 14:36:40.427899+00', '2014-02-06 14:36:40.427899+00', 'March', 3217, 11, 0, 0, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (9333, '2013-05-11 16:12:19.150185+00', '2021-04-05 13:10:06.694748+00', 'Catch the Wind', 3420, 1, 8, 32, NULL, NULL, 293, 0, 'Hornpipe');
INSERT INTO 'recording' VALUES (9412, '2014-02-06 14:41:28.898926+00', '2014-02-06 14:41:28.898926+00', 'Marches 6/8', 3221, 11, 0, 0, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (9413, '2014-02-06 14:46:04.856815+00', '2014-02-06 14:46:04.856815+00', 'Waltzes', 3217, 5, 0, 0, 9999, NULL, 317, 0, '');
INSERT INTO 'recording' VALUES (9414, '2014-02-06 14:49:59.653536+00', '2014-02-06 14:49:59.653536+00', 'Jigs', 3217, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9416, '2014-02-06 15:00:50.202162+00', '2014-02-06 15:00:50.202162+00', 'Reels', 3217, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (9403, '2014-02-06 14:03:57.092708+00', '2014-02-06 19:36:20.143941+00', 'Jigs', 3217, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (6581, NULL, '2014-09-16 11:46:08.708111+00', 'Auld Alliance, The', 3032, 1, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (9415, '2014-02-06 14:58:03.028102+00', '2014-02-06 15:02:25.845415+00', 'Slow Air', 3217, 98, 0, 0, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (9419, '2014-02-06 15:19:38.476117+00', '2014-02-06 15:19:38.476117+00', 'Scottish Ramble', 2681, 3, 8, 32, 9999, NULL, 485, 0, '');
INSERT INTO 'recording' VALUES (9422, '2014-02-06 15:35:28.895109+00', '2014-02-06 15:35:28.895109+00', 'Petronella', 2681, 1, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (9423, '2014-02-06 15:39:19.559283+00', '2014-02-06 15:39:19.559283+00', 'Madge Wildfire''s Strathspey', 2681, 3, 8, 32, 9999, NULL, 486, 0, '');
INSERT INTO 'recording' VALUES (9425, '2014-02-06 15:44:56.33336+00', '2014-02-06 15:44:56.33336+00', 'Set of Jigs', 2681, 2, 6, 32, 9999, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (9426, '2014-02-06 15:55:09.619993+00', '2014-02-06 15:55:09.619993+00', 'Set of Hornpipes', 2681, 4, 0, 0, 9998, NULL, 115, 0, '');
INSERT INTO 'recording' VALUES (9427, '2014-02-06 15:58:52.687445+00', '2014-02-06 15:58:52.687445+00', 'March, Strathspey & Reel', 2681, 4, 1, 128, 10016, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (9428, '2014-02-06 16:01:04.089059+00', '2014-02-06 16:01:04.089059+00', 'Set of Reels', 2681, 1, 6, 32, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (9434, '2014-02-06 18:20:53.51755+00', '2014-02-06 18:20:53.51755+00', 'Cast''n Reel, The', 10915, 1, 8, 32, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (9435, '2014-02-06 18:26:59.64597+00', '2014-02-06 18:26:59.64597+00', 'Silver Hamer, The / Dr Quarrie''s Birthday', 10915, 3, 3, 32, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (9436, '2014-02-06 18:34:42.826676+00', '2014-02-06 18:34:42.826676+00', 'Diamond Quarrie, The / The Penny Whistle Hornpipe', 10915, 1, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (9437, '2014-02-06 18:40:36.186081+00', '2014-02-06 18:40:36.186081+00', 'It''s About Time / The Falkirk Lass', 10915, 3, 8, 32, 9999, NULL, 516, 0, '');
INSERT INTO 'recording' VALUES (9395, '2013-12-19 16:55:45.299231+00', '2016-11-06 00:38:40.881031+00', 'Two Gray Cats, The', 3217, 1, 8, 40, 9999, NULL, 371, 0, '');
INSERT INTO 'recording' VALUES (9397, '2013-12-19 17:04:21.467687+00', '2016-11-06 00:49:12.389447+00', 'Christine M Phillips', 3217, 2, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (9401, '2013-12-19 17:27:42.465088+00', '2016-07-13 17:00:16.175005+00', 'Cool Down Waltz', 3217, 5, 4, 32, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (9430, '2014-02-06 17:52:04.874818+00', '2016-09-04 13:53:04.585715+00', 'Haggarty''s Brig', 10915, 3, 4, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (9387, '2013-12-19 15:59:55.154899+00', '2017-03-04 17:55:26.113288+00', 'Warm Up March (suitable for The Lion Gate)', 3217, 11, 5, 32, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (9388, '2013-12-19 16:05:09.896247+00', '2016-11-06 00:39:33.733362+00', 'Emmet''s Chase', 3217, 2, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (9389, '2013-12-19 16:09:40.380323+00', '2016-11-06 00:40:17.127629+00', 'Special Occasion, A', 3217, 1, 3, 48, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (9391, '2013-12-19 16:38:38.375697+00', '2016-11-06 00:43:36.349213+00', 'May''s 100', 3217, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (9392, '2013-12-19 16:41:48.599497+00', '2016-11-06 00:44:17.616256+00', 'Anne Archdeacon Reel, The', 3217, 1, 4, 40, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (9393, '2013-12-19 16:46:25.51736+00', '2016-11-06 00:44:57.035469+00', 'Audrey & Peter''s Jubilee', 3217, 3, 3, 48, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (9394, '2013-12-19 16:50:29.528612+00', '2016-11-06 00:45:51.984069+00', 'Torridon Cross, The', 3217, 101, 4, 48, 9999, NULL, 224, 0, '');
INSERT INTO 'recording' VALUES (9421, '2014-02-06 15:30:13.793019+00', '2018-10-14 00:09:08.898367+00', 'Montgomeries'' Rant, The', 2681, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (9398, '2013-12-19 17:08:10.350929+00', '2016-11-06 00:50:34.330885+00', 'High Society', 3217, 1, 4, 40, 9999, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (9399, '2013-12-19 17:19:35.464309+00', '2016-11-06 00:51:36.592738+00', 'Swan and the Tay, The', 3217, 3, 3, 32, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (9417, '2014-02-06 15:12:28.697958+00', '2018-10-14 23:19:40.27856+00', 'Dundee Reel, The', 2681, 2, 8, 40, 9999, NULL, 343, 0, '');
INSERT INTO 'recording' VALUES (9420, '2014-02-06 15:23:36.083582+00', '2018-10-14 23:20:16.114535+00', 'Isle of Skye, The', 2681, 1, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (9424, '2014-02-06 15:42:57.250289+00', '2018-10-14 23:21:18.215719+00', 'Flowers of Edinburgh, The', 2681, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (9418, '2014-02-06 15:15:42.140293+00', '2019-03-24 21:05:44.027993+00', 'Russe, La', 2681, 1, 4, 64, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (9442, '2014-02-06 19:07:20.270123+00', '2019-05-04 19:55:03.039448+00', 'Road to the Border, The / Four''s a Score', 10915, 1, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (9432, '2014-02-06 18:08:26.36791+00', '2019-09-02 10:57:12.195215+00', 'Union Jig, The / The Comeback Jig', 10915, 2, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (9375, '2013-10-29 01:47:34.160512+00', '2019-09-02 16:20:39.667904+00', 'History in the Making', 3217, 1, 3, 32, 9999, NULL, 117, 0, '');
INSERT INTO 'recording' VALUES (9439, '2014-02-06 18:48:30.493185+00', '2014-02-06 19:11:36.906027+00', 'Pinewoods Transitions', 10915, 1, 8, 40, 9999, NULL, 361, 0, '');
INSERT INTO 'recording' VALUES (9444, '2014-02-07 08:34:03.334+00', '2014-02-07 08:34:03.334+00', 'Golden Boy, The', 2339, 2, 8, 32, 9999, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (9445, '2014-02-07 08:40:33.59394+00', '2014-02-07 08:40:33.59394+00', 'John T', 2339, 3, 8, 32, 9999, NULL, 518, 0, '');
INSERT INTO 'recording' VALUES (9446, '2014-02-07 08:48:12.029975+00', '2014-02-07 08:48:12.029975+00', 'Forty Below', 2339, 1, 4, 40, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (9458, '2014-02-07 09:46:52.44153+00', '2018-10-25 21:41:22.456091+00', 'Selkirk Settlement, The', 2339, 1, 6, 32, 9999, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (9448, '2014-02-07 08:55:33.160618+00', '2014-02-07 08:55:33.160618+00', 'Leaving York Factory', 2339, 2, 3, 32, 9999, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (9449, '2014-02-07 08:59:28.014031+00', '2014-02-07 08:59:28.014031+00', 'Kelvin Strathspey, The', 2339, 3, 3, 32, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (9450, '2014-02-07 09:03:01.909999+00', '2014-02-07 09:03:01.909999+00', 'Trip to Sucker Bay, A', 2339, 2, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (9451, '2014-02-07 09:06:18.204634+00', '2014-02-07 09:06:18.204634+00', 'Annie Douglas', 2339, 3, 8, 32, 9999, NULL, 526, 0, '');
INSERT INTO 'recording' VALUES (9452, '2014-02-07 09:08:39.353127+00', '2014-02-07 09:08:39.353127+00', 'Cathryn''s Reel', 2339, 1, 1, 88, 9999, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (9453, '2014-02-07 09:12:25.112204+00', '2014-02-07 09:12:25.112204+00', 'Lairds'' Diamond, The', 2339, 3, 6, 32, 9999, NULL, 386, 0, '');
INSERT INTO 'recording' VALUES (9454, '2014-02-07 09:16:22.646678+00', '2014-02-07 09:16:22.646678+00', 'Red River Welcome', 2339, 2, 4, 48, 9999, NULL, 223, 0, '');
INSERT INTO 'recording' VALUES (9455, '2014-02-07 09:23:01.391834+00', '2014-02-07 09:23:01.391834+00', 'Prairie Crocus, A', 2339, 3, 3, 32, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (9456, '2014-02-07 09:40:17.757437+00', '2014-02-07 09:40:17.757437+00', 'Return of the Loons', 2339, 2, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (3925, NULL, '2014-02-07 09:48:42.950997+00', 'John T', 2339, 3, 8, 32, 9999, NULL, 518, 0, '');
INSERT INTO 'recording' VALUES (9459, '2014-02-09 17:02:54.744937+00', '2014-02-09 17:02:54.744937+00', 'Autumn Beginnings', 2566, 3, 4, 32, 9999, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (9460, '2014-02-09 17:16:04.698652+00', '2014-02-09 17:16:04.698652+00', 'Catching Helen', 2566, 1, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (9461, '2014-02-09 17:21:24.074441+00', '2014-02-09 17:21:24.074441+00', 'Fingask Castle', 2566, 2, 5, 32, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (9462, '2014-02-09 17:24:51.87245+00', '2014-02-09 17:24:51.87245+00', 'Merchant City, The', 2566, 3, 3, 32, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (6479, NULL, '2022-08-21 17:00:37.650303+00', 'Tillietudlum/He Danced Awa''', 3030, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (9438, '2014-02-06 18:43:53.679173+00', '2022-09-01 15:03:03.949646+00', 'Greenbelt Jig, The', 10915, 2, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (9463, '2014-02-09 17:30:16.395209+00', '2014-02-09 17:30:16.395209+00', 'Moulin Brae', 2566, 3, 3, 32, 9999, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (9465, '2014-02-09 17:40:15.030042+00', '2014-02-09 17:40:15.030042+00', 'Snowdrops in the Glen', 2566, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9467, '2014-02-09 17:51:51.269455+00', '2014-02-09 17:51:51.269455+00', 'Squinty Bridge, The', 2566, 2, 5, 32, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (9468, '2014-02-09 17:58:25.453704+00', '2014-02-09 17:58:25.453704+00', 'Tribute to Glasgow', 2566, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (9469, '2014-02-09 18:03:46.946988+00', '2014-02-09 18:03:46.946988+00', 'Welcome to Glasgow', 2566, 3, 8, 32, 9999, NULL, 494, 0, '');
INSERT INTO 'recording' VALUES (9464, '2014-02-09 17:36:28.979957+00', '2014-02-09 18:48:02.577359+00', 'Scotch Broth', 2566, 1, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (9471, '2014-02-14 14:51:06.672619+00', '2014-02-14 14:51:06.672619+00', 'Joie de Vivre', 1575, 2, 10, 32, 9999, NULL, 360, 0, '');
INSERT INTO 'recording' VALUES (9472, '2014-02-14 14:55:13.688002+00', '2014-02-14 14:55:13.688002+00', 'Miss Catherine Ann', 1575, 3, 3, 32, 9999, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (9473, '2014-02-14 14:58:26.918153+00', '2014-02-14 14:58:26.918153+00', 'Lancastrian Wanderer, The', 1575, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9390, '2013-12-19 16:17:03.968013+00', '2019-12-17 11:41:32.710643+00', 'Far North Queensland', 3217, 3, 5, 32, 9999, NULL, 321, 0, '');
INSERT INTO 'recording' VALUES (9379, '2013-10-29 02:09:34.194117+00', '2020-06-05 17:42:58.305762+00', 'Dalston Jig, The', 3217, 2, 4, 40, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (9429, '2014-02-06 17:45:40.750646+00', '2020-01-28 21:45:07.870861+00', 'Wee Nothin'' / More than Nothin'', A', 10915, 2, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (9396, '2013-12-19 16:59:47.243028+00', '2021-04-24 09:27:46.291092+00', 'Highlander in Glasgow, A', 3217, 3, 4, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (9433, '2014-02-06 18:14:11.315897+00', '2020-12-28 11:28:17.738415+00', 'Cardross House', 10915, 3, 8, 32, 9999, NULL, 528, 0, '');
INSERT INTO 'recording' VALUES (9470, '2014-02-09 18:06:56.620233+00', '2021-08-23 13:34:03.916854+00', 'Woodside', 2566, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9475, '2014-02-14 15:05:42.163207+00', '2014-02-14 15:05:42.163207+00', 'Culla Bay', 1575, 3, 4, 32, 9999, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (9476, '2014-02-14 15:08:44.140603+00', '2014-02-14 15:08:44.140603+00', 'Miss Hadden''s Reel', 1575, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (9477, '2014-02-14 15:15:42.905531+00', '2014-02-14 15:15:42.905531+00', 'Gaelic Waltzes', 1575, 5, 0, 0, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (9478, '2014-02-14 15:26:19.259669+00', '2014-02-14 15:26:19.259669+00', 'Mairi''s Wedding', 1575, 1, 8, 40, 9999, NULL, 438, 0, '');
INSERT INTO 'recording' VALUES (9479, '2014-02-14 15:29:36.337411+00', '2014-02-14 15:29:36.337411+00', 'Flight of the Falcon, The', 1575, 2, 10, 32, 9999, NULL, 351, 0, '');
INSERT INTO 'recording' VALUES (9480, '2014-02-14 15:34:24.987296+00', '2014-02-14 15:34:24.987296+00', 'Rambling Rose', 1575, 3, 3, 32, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (9481, '2014-02-14 15:37:49.028415+00', '2014-02-14 15:37:49.028415+00', 'Recumbent Stone, The', 1575, 1, 5, 48, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (9482, '2014-02-14 15:41:47.235222+00', '2014-02-14 15:41:47.235222+00', 'Thrums Cairn', 1575, 1, 10, 32, 9999, NULL, 351, 0, 'not the original tune');
INSERT INTO 'recording' VALUES (9483, '2014-02-14 15:46:40.60262+00', '2014-02-14 15:46:40.60262+00', 'Byron Strathspey, The', 1575, 3, 3, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (9484, '2014-02-14 16:03:34.249342+00', '2014-02-14 16:03:34.249342+00', 'Maxwell''s Rant', 1575, 1, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (9485, '2014-02-15 12:50:17.22052+00', '2014-02-15 12:50:17.22052+00', 'Highland Cathedral', 1575, 98, 0, 0, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (9486, '2014-02-15 12:52:16.206945+00', '2014-02-15 12:52:16.206945+00', 'Nottingham Lace', 1575, 1, 1, 96, 9999, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (9487, '2014-02-15 12:54:29.355544+00', '2014-02-15 12:54:29.355544+00', 'Ederline', 1575, 3, 3, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (9488, '2014-02-15 12:58:58.393864+00', '2014-02-15 12:58:58.393864+00', 'Hunting Horn, The', 1575, 2, 10, 32, 9999, NULL, 353, 0, '');
INSERT INTO 'recording' VALUES (9489, '2014-02-15 13:04:11.208588+00', '2014-02-15 13:04:11.208588+00', 'Swithland Woods', 1575, 3, 3, 40, 9999, NULL, 235, 0, '');
INSERT INTO 'recording' VALUES (9490, '2014-02-15 13:08:27.209337+00', '2014-02-15 13:08:27.209337+00', 'Plantation Reel, The', 1575, 1, 5, 32, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (9466, '2014-02-09 17:47:10.579671+00', '2014-08-21 07:18:15.988291+00', 'Speirs Wharf Hornpipe', 2566, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (9441, '2014-02-06 19:01:18.948403+00', '2014-09-16 09:27:48.70728+00', 'Tine''s Jig', 10915, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9474, '2014-02-14 15:02:29.305415+00', '2014-09-16 14:47:45.322058+00', 'Blooms of Bon Accord', 1575, 1, 4, 32, 9999, NULL, 159, 0, '');
INSERT INTO 'recording' VALUES (9491, '2014-02-15 13:10:50.796684+00', '2014-02-15 13:10:50.796684+00', 'Twa Meenit Reel, The', 1575, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (9492, '2014-02-15 13:27:51.757852+00', '2014-02-15 13:27:51.757852+00', 'Wild Geese', 1575, 2, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (9493, '2014-02-15 13:32:08.232523+00', '2014-02-15 13:32:08.232523+00', 'Spiffin''', 1575, 2, 5, 32, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (9494, '2014-02-15 13:37:34.782682+00', '2014-02-15 13:37:34.782682+00', 'Trio, The', 1575, 3, 3, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (9495, '2014-02-15 13:40:26.762432+00', '2014-02-15 13:40:26.762432+00', 'Good Hearted Glasgow', 1575, 2, 10, 32, 9999, NULL, 353, 0, '');
INSERT INTO 'recording' VALUES (9496, '2014-02-15 13:51:23.613465+00', '2014-02-15 13:51:23.613465+00', 'Middleton Moonraker', 1575, 1, 4, 32, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (9497, '2014-02-15 13:57:25.165681+00', '2014-02-15 13:57:25.165681+00', 'Welcome to Dufftown', 1575, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9498, '2014-02-15 13:59:35.397086+00', '2014-02-15 13:59:35.397086+00', 'Annan Gold', 1575, 3, 3, 32, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (2289, NULL, '2014-03-04 23:35:26.518205+00', 'Langholm Fair', 3014, 3, 3, 32, 9999, 5, 182, 0, '');
INSERT INTO 'recording' VALUES (6127, NULL, '2014-03-06 01:15:41.711204+00', 'Father Connelly''s Jig', 3217, 2, 4, 64, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (8903, '2012-06-12 14:27:11.379523+00', '2014-03-10 14:13:02.936986+00', 'Chiltern Chase', 3012, 2, 4, 40, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (9500, '2014-03-13 15:40:47.676973+00', '2014-03-13 15:40:47.676973+00', 'Whisky Galore', 10114, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (9502, '2014-03-13 15:56:21.440971+00', '2014-03-13 15:56:21.440971+00', 'Jenny''s Strathspey', 10114, 3, 8, 32, 9999, NULL, 492, 0, '');
INSERT INTO 'recording' VALUES (9504, '2014-03-13 16:10:37.072187+00', '2014-03-13 16:10:37.072187+00', 'Shetland Fiddler, The', 10114, 1, 4, 32, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (9506, '2014-03-13 17:25:09.023453+00', '2014-03-13 17:25:09.023453+00', 'Wee Cooper o'' Fife, The', 10114, 2, 8, 40, 9999, NULL, 356, 0, '');
INSERT INTO 'recording' VALUES (9507, '2014-03-13 17:30:35.796423+00', '2014-03-13 17:30:35.796423+00', 'Black, Black Oil, The', 10114, 1, 5, 32, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (9508, '2014-03-13 17:42:19.426065+00', '2014-03-13 17:42:19.426065+00', 'Margaret''s Fancy', 10114, 3, 5, 32, 9999, NULL, 310, 0, '');
INSERT INTO 'recording' VALUES (9509, '2014-03-13 17:48:41.661417+00', '2014-03-13 17:48:41.661417+00', 'Seton''s Ceilidh Band', 10114, 2, 4, 64, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (9510, '2014-03-13 17:55:06.034659+00', '2014-03-13 17:55:06.034659+00', 'Dover Ruby, The', 10114, 1, 4, 40, 9999, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (9511, '2014-03-13 17:58:47.565028+00', '2014-03-13 17:58:47.565028+00', 'Singing Sands', 10114, 3, 3, 32, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (9512, '2014-03-13 18:04:11.984925+00', '2014-03-13 18:04:11.984925+00', 'Jeannie''s Blue E''en', 10114, 2, 6, 32, 9999, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (9513, '2014-03-13 18:09:39.983813+00', '2014-03-13 18:09:39.983813+00', 'Jean Kirkpatrick''s Fancy', 10114, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (9514, '2014-03-14 15:16:19.532167+00', '2014-03-14 15:16:19.532167+00', 'Castle of Mey, The', 10034, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9515, '2014-03-14 15:18:38.807434+00', '2014-03-14 15:18:38.807434+00', 'Bill Clement MBE', 10034, 2, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (9516, '2014-03-14 15:22:16.650009+00', '2014-03-14 15:22:16.650009+00', 'Culla Bay', 10034, 3, 4, 32, 9999, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (9517, '2014-03-14 15:26:15.84726+00', '2014-03-14 15:26:15.84726+00', 'Polharrow Burn', 10034, 1, 5, 32, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (9457, '2014-02-07 09:43:44.048408+00', '2018-11-15 00:56:42.667961+00', 'Lord Selkirk', 2339, 3, 8, 32, 9999, NULL, 520, 0, '');
INSERT INTO 'recording' VALUES (9518, '2014-03-14 15:31:27.061221+00', '2014-03-14 15:31:27.061221+00', 'Napier''s Index', 10034, 2, 8, 40, 9999, NULL, 353, 0, '');
INSERT INTO 'recording' VALUES (9519, '2014-03-14 15:35:17.159625+00', '2014-03-14 15:35:17.159625+00', 'Delvine Side', 10034, 3, 8, 32, 9999, NULL, 484, 0, '');
INSERT INTO 'recording' VALUES (9520, '2014-03-14 15:38:02.986032+00', '2014-03-14 15:38:02.986032+00', 'Round Reel of Eight, The', 10034, 1, 1, 88, 9999, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (9521, '2014-03-14 15:40:52.656391+00', '2014-03-14 15:40:52.656391+00', 'Last of the Lairds, The', 10034, 2, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (9522, '2014-03-14 15:43:30.814378+00', '2014-03-14 15:43:30.814378+00', 'Neidpath Castle', 10034, 3, 3, 32, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (9523, '2014-03-14 15:46:39.182482+00', '2014-03-14 15:46:39.182482+00', 'Starlight', 10034, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9525, '2014-03-14 15:51:53.131911+00', '2014-03-14 15:51:53.131911+00', 'Valentine, The', 10034, 3, 8, 32, 9999, NULL, 492, 0, '');
INSERT INTO 'recording' VALUES (9526, '2014-03-14 15:54:59.964564+00', '2014-03-14 15:54:59.964564+00', 'Milton''s Welcome', 10034, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (9528, '2014-03-14 16:01:52.401438+00', '2014-03-14 16:01:52.401438+00', 'Balmoral Strathspey, The', 10034, 3, 4, 32, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (9529, '2014-03-14 16:08:22.136069+00', '2014-03-14 16:08:22.136069+00', 'Highland Rambler, The', 10034, 1, 8, 40, 9999, NULL, 351, 0, '');
INSERT INTO 'recording' VALUES (9532, '2014-03-16 10:17:29.402372+00', '2014-03-16 10:17:29.402372+00', 'Foursome Reel', 10920, 4, 1, 136, 10011, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (9533, '2014-03-16 10:21:40.319043+00', '2014-03-16 10:21:40.319043+00', 'Reel of the 51st Highland Division I', 10920, 1, 9, 32, 9999, NULL, 302, 0, '');
INSERT INTO 'recording' VALUES (9534, '2014-03-16 10:24:00.2311+00', '2014-03-16 10:24:00.2311+00', 'Reel of the 51st Highland Division II', 10920, 1, 15, 32, 9999, NULL, 490, 0, '');
INSERT INTO 'recording' VALUES (9535, '2014-03-16 10:26:08.466512+00', '2014-03-16 10:26:08.466512+00', 'Duke and Duchess of Edinburgh I', 10920, 1, 9, 40, 9999, NULL, 373, 0, '');
INSERT INTO 'recording' VALUES (9607, '2014-03-26 16:05:52.876295+00', '2014-03-26 16:05:52.876295+00', 'Waltz', 10936, 5, 0, 0, 9999, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (9536, '2014-03-16 10:27:27.712931+00', '2014-03-16 10:27:27.712931+00', 'Duke and Duchess of Edinburgh II', 10920, 1, 7, 40, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (9539, '2014-03-16 10:32:54.8544+00', '2014-03-16 10:32:54.8544+00', 'Duke of Perth I', 10920, 1, 11, 32, 9999, NULL, 360, 0, '');
INSERT INTO 'recording' VALUES (9540, '2014-03-16 10:34:02.027018+00', '2014-03-16 10:34:02.027018+00', 'Duke of Perth II', 10920, 1, 8, 32, 9999, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (9524, '2014-03-14 15:48:47.642485+00', '2021-05-07 13:03:27.641593+00', 'Dundee City Police Jig, The', 10034, 2, 3, 32, 9999, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (9537, '2014-03-16 10:29:30.686137+00', '2014-03-16 10:53:54.05186+00', 'Hamilton House I', 10920, 2, 15, 32, 9999, NULL, 456, 0, '');
INSERT INTO 'recording' VALUES (9538, '2014-03-16 10:30:33.036202+00', '2014-03-16 10:54:45.423071+00', 'Hamilton House II', 10920, 2, 13, 32, 9999, NULL, 399, 0, '');
INSERT INTO 'recording' VALUES (9552, '2014-03-16 11:07:44.398166+00', '2014-03-16 11:07:44.398166+00', 'Dashing White Sergeant, The', 10920, 1, 16, 32, 9999, NULL, 524, 0, '');
INSERT INTO 'recording' VALUES (9554, '2014-03-16 11:47:39.752462+00', '2014-03-16 11:47:39.752462+00', 'Reel of the 51st Highland Division', 10920, 1, 18, 32, 9999, NULL, 589, 0, '');
INSERT INTO 'recording' VALUES (9556, '2014-03-16 12:01:48.843804+00', '2014-03-16 12:01:48.843804+00', 'Mairi''s Wedding', 10920, 1, 9, 40, 9999, NULL, 369, 0, '');
INSERT INTO 'recording' VALUES (9557, '2014-03-16 12:07:41.01094+00', '2014-03-16 12:07:41.01094+00', 'Machine Without Horses, The', 10920, 2, 8, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (9558, '2014-03-16 12:16:10.42428+00', '2014-03-16 12:16:10.42428+00', 'Duke of Perth, The', 10920, 1, 19, 32, NULL, NULL, 624, 0, '');
INSERT INTO 'recording' VALUES (9559, '2014-03-16 12:23:54.053433+00', '2014-03-16 12:23:54.053433+00', 'Medley', 10920, 4, 1, 80, 10030, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (9560, '2014-03-16 12:26:47.468013+00', '2014-03-16 12:26:47.468013+00', 'Buddy Can You Spare a Dime', 10920, 50, 0, 0, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (9561, '2014-03-16 12:28:28.428616+00', '2014-03-16 12:28:28.428616+00', 'Carry Me Back to Old Virginia', 10920, 50, 0, 0, NULL, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (9562, '2014-03-16 12:29:48.429669+00', '2014-03-16 12:29:48.429669+00', 'Waltz', 10920, 5, 0, 0, 9999, NULL, 325, 0, '');
INSERT INTO 'recording' VALUES (9563, '2014-03-16 12:30:40.428165+00', '2014-03-16 12:30:40.428165+00', 'Arisaig', 10920, 50, 0, 0, NULL, NULL, 308, 0, '');
INSERT INTO 'recording' VALUES (9505, '2014-03-13 16:17:35.588747+00', '2014-04-09 21:59:58.546788+00', 'Kenneth and Fiona''s Ruby Strathspey', 10114, 3, 3, 32, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (9503, '2014-03-13 16:02:34.075847+00', '2014-04-09 22:02:06.02653+00', 'Bob Shakespeare''s Jig', 10114, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (9499, '2014-02-15 14:09:07.642926+00', '2014-09-16 08:48:10.392141+00', 'Irish Rover, The', 1575, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9564, '2014-03-16 14:39:16.004655+00', '2014-03-16 14:39:16.004655+00', 'Grand March', 3008, 11, 0, 0, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (9566, '2014-03-16 15:03:27.704435+00', '2014-03-16 15:03:27.704435+00', 'Yaezakura Strathspey', 3008, 3, 4, 32, 9999, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (9567, '2014-03-16 15:08:53.416085+00', '2014-03-16 15:08:53.416085+00', 'On the Toe', 3008, 2, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (9568, '2014-03-16 15:13:47.793344+00', '2014-03-16 15:13:47.793344+00', 'On the Toe (Repeat)', 3008, 2, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (9572, '2014-03-16 15:48:19.209177+00', '2014-03-16 15:48:19.209177+00', 'Subarashii Saitama Strathspey (Repeat)', 3008, 3, 4, 32, 9999, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (9573, '2014-03-16 15:54:27.851109+00', '2014-03-16 15:54:27.851109+00', 'Seniors Be Full Power', 3008, 2, 3, 32, 9999, NULL, 102, 0, '');
INSERT INTO 'recording' VALUES (9574, '2014-03-16 16:05:18.773687+00', '2014-03-16 16:05:18.773687+00', 'Happy Smile', 3008, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (9576, '2014-03-16 16:13:55.661727+00', '2014-03-16 16:13:55.661727+00', 'Circle Waltz and Auld Lang Syne', 3008, 5, 0, 0, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (9577, '2014-03-19 08:55:48.677544+00', '2014-03-19 08:55:48.677544+00', 'Highland Barn Dance', 10931, 11, 0, 0, 9999, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (9578, '2014-03-19 09:15:46.444293+00', '2014-03-19 09:15:46.444293+00', 'Hornpipes', 3037, 1, 4, 32, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (9580, '2014-03-19 09:59:58.976122+00', '2014-03-19 09:59:58.976122+00', 'Earl of Errol''s Reel', 2286, 2, 1, 200, 9999, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (9581, '2014-03-19 10:06:55.432249+00', '2014-03-19 10:06:55.432249+00', 'Glengarry Quickstep', 3010, 1, 4, 32, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (9582, '2014-03-19 10:09:53.693622+00', '2014-03-19 10:09:53.693622+00', 'Set of Jigs', 3037, 2, 6, 32, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (9583, '2014-03-19 10:17:11.501713+00', '2014-03-19 10:17:11.501713+00', 'Strathspey and Reel', 3063, 4, 1, 112, 18, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (9584, '2014-03-19 10:20:02.73105+00', '2014-03-19 10:20:02.73105+00', 'Light and Airy', 3010, 2, 8, 32, 9999, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (9585, '2014-03-19 10:25:26.072099+00', '2014-03-19 10:25:26.072099+00', 'Air and Shetland Reels', 1580, 98, 0, 0, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (9586, '2014-03-19 10:29:28.840657+00', '2014-03-19 10:29:28.840657+00', 'Gay Gordons, The', 10931, 11, 0, 16, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (9588, '2014-03-19 10:48:12.194761+00', '2014-03-19 10:48:12.194761+00', 'Jigs', 10931, 2, 5, 32, 9999, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (9589, '2014-03-19 10:52:38.59081+00', '2014-03-19 10:52:38.59081+00', 'Jigs from the Gow Collection', 10931, 2, 6, 32, 9999, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (9590, '2014-03-19 10:56:34.615751+00', '2014-03-19 10:56:34.615751+00', 'Saandieburn Reel', 10931, 1, 4, 32, 9999, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (9570, '2014-03-16 15:22:45.687219+00', '2018-11-20 12:42:31.602246+00', 'Rainbow of Saitama, The', 3008, 2, 8, 32, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (9569, '2014-03-16 15:18:09.556158+00', '2018-12-08 10:08:38.229124+00', 'Matsuri Strathspey, The', 3008, 3, 4, 32, 9999, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (9579, '2014-03-19 09:35:53.806176+00', '2019-03-24 21:05:24.333614+00', 'Russe, La', 10931, 1, 5, 32, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (9565, '2014-03-16 14:45:04.232294+00', '2019-09-11 08:55:20.6811+00', 'Braiding Reel, The', 3008, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (9527, '2014-03-14 15:58:50.029425+00', '2019-09-30 23:15:21.349878+00', 'Chequered Court, The', 10034, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (9591, '2014-03-19 11:04:56.170599+00', '2014-03-19 11:04:56.170599+00', 'Dashing White Sergeant', 10931, 1, 7, 32, 9999, NULL, 226, 0, '');
INSERT INTO 'recording' VALUES (9592, '2014-03-19 11:10:09.080869+00', '2014-03-19 11:10:09.080869+00', 'Auld Rants, The', 10931, 4, 2, 64, 5, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (9593, '2014-03-19 11:17:15.667549+00', '2014-03-19 11:17:15.667549+00', 'Strip the Willow', 10932, 2, 4, 32, NULL, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (9594, '2014-03-19 11:33:57.441439+00', '2014-03-19 11:33:57.441439+00', 'Virginia Reel', 10932, 1, 4, 64, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (9628, '2014-03-27 14:06:49.553688+00', '2014-03-27 14:06:49.553688+00', 'Jig Medley', 2328, 2, 8, 32, 9999, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (5320, NULL, '2014-03-19 22:25:58.71586+00', 'Founder''s Reel', 3002, 1, 4, 48, 9999, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (9595, '2014-03-26 14:19:05.667578+00', '2014-03-26 14:19:05.667578+00', 'Reel', 10936, 1, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (9596, '2014-03-26 14:22:30.619108+00', '2014-03-26 14:22:30.619108+00', 'Jigs', 10936, 2, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (9597, '2014-03-26 14:26:19.034085+00', '2014-03-26 14:26:19.034085+00', 'Waltz', 10936, 5, 0, 0, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (9598, '2014-03-26 15:04:07.900458+00', '2014-03-26 15:04:07.900458+00', '2/4 marches', 10936, 11, 0, 0, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (9599, '2014-03-26 15:09:18.996545+00', '2014-03-26 15:09:18.996545+00', 'Primrose Polka', 10936, 13, 0, 0, 9999, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (9601, '2014-03-26 15:20:34.429352+00', '2014-03-26 15:20:34.429352+00', 'Shiftin Bobbins', 10936, 1, 8, 32, 9999, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (9602, '2014-03-26 15:25:27.483535+00', '2014-03-26 15:25:27.483535+00', '6/8 Marches', 10936, 11, 0, 0, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (9603, '2014-03-26 15:30:15.14412+00', '2014-03-26 15:30:15.14412+00', 'Hornpipes', 10936, 6, 4, 32, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (9604, '2014-03-26 15:33:43.228033+00', '2014-03-26 15:33:43.228033+00', 'Waltz', 10936, 5, 0, 0, 9999, NULL, 125, 0, '');
INSERT INTO 'recording' VALUES (9605, '2014-03-26 15:43:28.164994+00', '2014-03-26 15:43:28.164994+00', 'Miss Marjory Duffields Jig', 10936, 2, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (9606, '2014-03-26 16:02:44.561883+00', '2014-03-26 16:02:44.561883+00', '4/4 Marches', 10936, 11, 0, 0, NULL, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (2424, NULL, '2022-09-01 11:20:30.149179+00', '8 x 32 Reels: 4/4 Marches', 2885, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (9555, '2014-03-16 11:56:26.09658+00', '2022-12-09 20:01:32.121187+00', 'Hamilton House', 10920, 2, 16, 32, 9999, NULL, 515, 0, '');
INSERT INTO 'recording' VALUES (9549, '2014-03-16 10:45:25.917374+00', '2022-12-20 20:30:03.545828+00', 'China Boy', 10920, 50, 0, 0, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (9545, '2014-03-16 10:41:33.549615+00', '2022-12-20 20:27:31.5823+00', 'Pinetop''s Blues', 10920, 50, 0, 0, NULL, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (9547, '2014-03-16 10:43:24.876301+00', '2022-12-20 20:26:49.522676+00', 'Gee Baby Ain''t I Good to You', 10920, 50, 0, 0, NULL, NULL, 221, 0, '');
INSERT INTO 'recording' VALUES (9551, '2014-03-16 10:48:06.287425+00', '2022-12-20 20:35:54.817149+00', 'Hobo''s Blues', 10920, 50, 0, 0, NULL, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (9541, '2014-03-16 10:36:39.307485+00', '2022-12-21 10:29:11.711085+00', 'Careless Love', 10920, 50, 0, 0, NULL, NULL, 232, 0, '');
INSERT INTO 'recording' VALUES (9587, '2014-03-19 10:41:15.769535+00', '2022-12-23 23:34:42.379445+00', 'Cumberland Reel', 10931, 4, 1, 320, 10031, NULL, 350, 0, '');
INSERT INTO 'recording' VALUES (9553, '2014-03-16 11:36:14.747211+00', '2023-01-01 21:56:20.917965+00', 'Eightsome Reel', 10920, 1, 1, 464, 9999, NULL, 479, 0, '');
INSERT INTO 'recording' VALUES (9608, '2014-03-26 16:10:11.061667+00', '2014-03-26 16:10:11.061667+00', 'Eight Men of Moidart', 10936, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (9609, '2014-03-26 16:13:03.927879+00', '2014-03-26 16:13:03.927879+00', '2/4 Marches', 10936, 11, 0, 0, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (9610, '2014-03-26 16:15:25.650158+00', '2014-03-26 16:15:25.650158+00', 'Waltz', 10936, 5, 0, 0, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (9611, '2014-03-26 16:18:31.85796+00', '2014-03-26 16:18:31.85796+00', 'Jig', 10936, 2, 4, 32, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (9612, '2014-03-26 16:21:21.98859+00', '2014-03-26 16:21:21.98859+00', 'Waltz', 10936, 5, 0, 0, 9999, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (9613, '2014-03-26 16:28:02.11909+00', '2014-03-26 16:28:02.11909+00', 'Pipe Medley', 10936, 98, 0, 0, 9999, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (9614, '2014-03-27 12:53:11.245244+00', '2014-03-27 12:53:11.245244+00', 'Dunoon Barn Dance', 2328, 11, 0, 16, 9999, NULL, 223, 0, '');
INSERT INTO 'recording' VALUES (9615, '2014-03-27 12:57:56.505986+00', '2014-03-27 12:57:56.505986+00', 'Hopeful Lover, The', 2328, 1, 8, 40, 9999, NULL, 324, 0, '');
INSERT INTO 'recording' VALUES (9616, '2014-03-27 13:02:25.253858+00', '2014-03-27 13:02:25.253858+00', 'Pipers'' Medley', 2328, 2, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (9617, '2014-03-27 13:10:44.907958+00', '2014-03-27 13:10:44.907958+00', 'Highland Waltz', 2328, 5, 0, 0, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (9618, '2014-03-27 13:14:42.147093+00', '2014-03-27 13:14:42.147093+00', 'Mrs MacLeod''s Reel', 2328, 1, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (9619, '2014-03-27 13:22:03.130268+00', '2014-03-27 13:22:03.130268+00', 'Strathspey Medley', 2328, 3, 8, 32, 9999, NULL, 478, 0, '');
INSERT INTO 'recording' VALUES (9620, '2014-03-27 13:36:29.264318+00', '2020-01-28 22:07:32.326148+00', 'Bonnie Dundee', 2328, 2, 4, 32, 9999, NULL, 155, 0, '');
INSERT INTO 'recording' VALUES (9621, '2014-03-27 13:38:37.66589+00', '2014-03-27 13:38:37.66589+00', 'Gay Gordons', 2328, 11, 0, 16, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (9622, '2014-03-27 13:42:29.664662+00', '2014-03-27 13:42:29.664662+00', 'Regimental Medley', 2328, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (9625, '2014-03-27 13:56:00.199318+00', '2014-03-27 13:56:00.199318+00', 'Hamilton House', 2328, 2, 6, 32, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (9626, '2014-03-27 14:00:16.872029+00', '2014-03-27 14:00:16.872029+00', 'Kiss Me Quick, My Mither''s Comin''', 2328, 1, 6, 32, 9999, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (9627, '2014-03-27 14:03:07.578541+00', '2014-03-27 14:03:07.578541+00', 'Scottish Waltz', 2328, 5, 0, 0, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (9631, '2014-03-27 14:17:41.990202+00', '2014-03-27 14:17:41.990202+00', 'When the Battle''s O''er Medley', 2328, 98, 0, 0, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (9624, '2014-03-27 13:48:39.913155+00', '2014-03-27 14:18:42.758684+00', 'Victoria Reel', 2328, 1, 8, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (9632, '2014-04-25 10:01:52.852513+00', '2014-04-25 10:01:52.852513+00', 'Glasgow Highlanders', 3009, 3, 3, 32, NULL, NULL, 146, 1, 'played 6x16bars');
INSERT INTO 'recording' VALUES (9633, '2014-04-25 10:08:29.753395+00', '2014-04-25 10:08:29.753395+00', 'Maxwell''s Rant', 3042, 1, 5, 32, 9999, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (9634, '2014-04-25 10:14:49.118179+00', '2014-04-25 10:14:49.118179+00', 'Scottish Soldier Medley', 2062, 11, 0, 0, 9999, NULL, 171, 0, '');
INSERT INTO 'recording' VALUES (10213, '2018-06-23 16:59:39.440629+00', '2018-06-23 17:32:45.236641+00', 'Valse Set', 11651, 5, 1, 0, NULL, NULL, 328, 0, 'Traditional Danish. Two traditional waltzes from Denmark, played and arranged in very different styles.');
INSERT INTO 'recording' VALUES (9635, '2014-04-29 13:20:31.699909+00', '2014-04-29 13:20:31.699909+00', 'Songs of the Isles Waltz', 3009, 5, 0, 0, 9999, NULL, 170, 0, '');
INSERT INTO 'recording' VALUES (9636, '2014-04-29 13:23:31.11112+00', '2014-04-29 13:23:31.11112+00', 'Angus MacLeod', 3042, 1, 2, 64, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (9637, '2014-04-29 13:25:14.902731+00', '2014-04-29 13:25:14.902731+00', 'Hebridean Polka', 3009, 13, 0, 0, 9999, NULL, 128, 0, '');
INSERT INTO 'recording' VALUES (9639, '2014-04-29 13:33:02.541043+00', '2014-04-29 13:33:02.541043+00', 'Just As I Was in the Morning', 3009, 2, 4, 40, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (9640, '2014-04-29 13:36:20.537447+00', '2014-04-29 13:36:20.537447+00', 'Kingussie Flower', 2062, 1, 4, 40, 9999, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (9638, '2014-04-29 13:27:22.155957+00', '2014-04-29 13:38:42.554376+00', 'MacDonald of Sleat', 2038, 2, 1, 120, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (9623, '2014-03-27 13:44:18.791214+00', '2018-03-01 11:12:11.313021+00', 'Balmoral Highlanders', 2328, 11, 3, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (9642, '2014-04-29 13:42:40.680993+00', '2014-04-29 13:42:40.680993+00', 'Coming Through the Rye', 2038, 5, 0, 0, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (9643, '2014-04-29 13:47:33.846027+00', '2014-04-29 13:47:33.846027+00', 'Isle of Skye, The', 3009, 1, 5, 32, 9999, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (9644, '2014-04-29 13:51:00.531105+00', '2014-04-29 13:51:00.531105+00', 'Boston Two Step, The', 3042, 11, 0, 16, 9999, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (9645, '2014-04-29 13:55:02.828792+00', '2014-04-29 13:55:02.828792+00', 'Robertson Rant, The', 3009, 3, 1, 80, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (9646, '2014-04-29 14:07:55.663418+00', '2014-04-29 14:07:55.663418+00', 'Caledonian Country Dance', 2062, 3, 4, 24, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (2314, NULL, '2014-08-05 15:26:57.683188+00', 'Bratach Bana', 3042, 1, 8, 32, 9999, 1, 266, 0, '');
INSERT INTO 'recording' VALUES (9647, '2014-04-29 14:21:24.858072+00', '2014-04-29 14:21:24.858072+00', 'Robertson Rant, The', 3009, 3, 1, 80, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (9648, '2014-04-29 14:31:13.500108+00', '2014-04-29 14:31:13.500108+00', 'Reel', 3009, 1, 5, 32, 9999, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (9649, '2014-04-29 14:34:33.222637+00', '2014-04-29 14:34:33.222637+00', 'Gaelic Waltz', 3042, 5, 0, 0, 9999, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (9650, '2014-04-29 14:38:13.494265+00', '2014-04-29 14:38:13.494265+00', 'Johnny McGill', 2062, 2, 4, 40, 9999, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (9651, '2014-04-29 14:42:04.827894+00', '2014-04-29 14:42:04.827894+00', 'Meg Merrilees Reel', 3042, 1, 6, 24, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (9652, '2014-04-29 14:59:28.265608+00', '2014-04-29 14:59:28.265608+00', 'Captain McBride''s Hornpipe', 2038, 1, 8, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (9653, '2014-04-29 15:03:26.993719+00', '2014-04-29 15:03:26.993719+00', 'Baldovan Jig, The', 2038, 2, 4, 32, 9999, NULL, 128, 0, '');
INSERT INTO 'recording' VALUES (9655, '2014-04-29 15:15:47.315693+00', '2014-04-29 15:15:47.315693+00', 'Braes of Balqhuidder, The', 2038, 3, 1, 128, 9999, NULL, 225, 0, '');
INSERT INTO 'recording' VALUES (9656, '2014-04-29 15:20:43.198833+00', '2014-04-29 15:20:43.198833+00', 'Dundee Reel, The', 2038, 2, 8, 40, 9999, NULL, 305, 0, '');
INSERT INTO 'recording' VALUES (9657, '2014-04-29 15:37:00.81807+00', '2014-04-29 15:37:00.81807+00', 'Eight Men O'' Moidart, The', 2038, 1, 8, 16, 9999, NULL, 130, 0, '');
INSERT INTO 'recording' VALUES (9658, '2014-04-29 15:41:26.971031+00', '2014-04-29 15:41:26.971031+00', 'Dalkeith''s Strathspey', 2038, 3, 8, 32, 9999, NULL, 430, 0, '');
INSERT INTO 'recording' VALUES (9659, '2014-04-29 15:48:54.402774+00', '2014-04-29 15:48:54.402774+00', 'Hamilton House', 2038, 2, 8, 32, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (9660, '2014-04-29 15:52:20.142384+00', '2014-04-29 15:52:20.142384+00', 'Bonnie Brux', 2038, 4, 1, 80, 4, NULL, 118, 0, '');
INSERT INTO 'recording' VALUES (9661, '2014-04-29 15:55:38.52523+00', '2014-04-29 15:55:38.52523+00', 'Trip to Aberdeen, A', 2038, 2, 8, 32, 9999, NULL, 241, 0, '');
INSERT INTO 'recording' VALUES (9440, '2014-02-06 18:54:55.12582+00', '2016-09-04 15:26:16.973442+00', 'Mr Gallamore''s Strathspey', 10915, 3, 4, 32, 9999, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (9662, '2014-04-29 15:59:31.349645+00', '2014-04-29 15:59:31.349645+00', 'Duran Ranger, The', 2038, 1, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (9663, '2014-04-29 16:01:13.446394+00', '2014-04-29 16:01:13.446394+00', 'MacDonald of Sleat', 2038, 2, 1, 120, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (9664, '2014-04-29 16:55:27.518475+00', '2014-04-29 16:55:27.518475+00', 'Scottish Waltz', 3009, 5, 0, 0, 9999, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (9665, '2014-04-29 17:00:33.824823+00', '2014-04-29 17:00:33.824823+00', 'Argyll''s Fancy', 3009, 2, 4, 48, 9999, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (9666, '2014-04-29 17:14:50.535841+00', '2014-04-29 17:14:50.535841+00', 'Gay Gordons', 3009, 11, 0, 16, 9999, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (9667, '2014-04-29 17:40:00.75946+00', '2014-04-29 17:40:00.75946+00', 'Pipe Marches', 3009, 11, 0, 0, 9999, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (9668, '2014-04-29 17:42:41.813305+00', '2014-04-29 17:42:41.813305+00', 'Gaelic Waltz', 3009, 5, 0, 0, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (9669, '2014-04-29 17:45:06.889064+00', '2014-04-29 17:45:06.889064+00', 'Gay Gordons', 3009, 11, 0, 16, 9999, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (3705, NULL, '2014-04-29 17:48:46.017169+00', 'Grand March', 3009, 11, 0, 0, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (3189, NULL, '2014-04-29 17:54:51.895803+00', 'Foursome and Reel of Tulloch', 3009, 4, 0, 160, 10005, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (9673, '2014-05-09 23:06:28.255036+00', '2014-05-09 23:06:28.255036+00', 'Snow Eater, The', 10955, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9675, '2014-05-09 23:51:51.391539+00', '2014-05-09 23:51:51.391539+00', 'Reel of the Pinehurst Eight, The', 10955, 1, 4, 32, 9999, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (9677, '2014-05-09 23:58:18.5339+00', '2014-05-09 23:58:18.5339+00', 'Amhuinnsuidhe Castle', 10955, 3, 8, 32, 9999, NULL, 515, 0, '');
INSERT INTO 'recording' VALUES (9678, '2014-05-10 00:01:23.320959+00', '2014-05-10 00:01:23.320959+00', 'Quinte Gathering, The', 10955, 6, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (9679, '2014-05-10 00:04:09.165003+00', '2014-05-10 00:04:09.165003+00', 'Itchy Feet', 10955, 2, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (9680, '2014-05-10 00:09:38.81343+00', '2014-05-10 00:09:38.81343+00', 'Phoenix Rising', 10955, 3, 4, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (9681, '2014-05-10 00:12:36.835935+00', '2014-05-10 00:12:36.835935+00', 'George Watson of Tipperlinn', 10955, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (9683, '2014-05-10 00:20:41.301873+00', '2014-05-10 00:20:41.301873+00', 'Lament', 10955, 50, 0, 0, 9999, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (9684, '2014-05-10 00:23:32.438287+00', '2014-05-10 00:23:32.438287+00', 'Waltz', 10955, 5, 0, 0, 9999, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (9671, '2014-05-09 22:59:04.42251+00', '2014-05-10 23:17:55.675232+00', 'New Year Wedding', 10955, 3, 3, 32, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (9682, '2014-05-10 00:18:16.982761+00', '2022-09-01 11:00:07.322248+00', 'Father to Son', 10955, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9629, '2014-03-27 14:11:29.214085+00', '2022-12-10 21:15:59.781321+00', 'Burning of Paddy''s Breeches, The', 2328, 4, 0, 128, 10044, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (9676, '2014-05-09 23:54:08.08335+00', '2022-12-19 16:22:58.992535+00', 'Trip to Crinan, A', 10955, 2, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (5617, NULL, '2014-05-24 10:49:34.228317+00', 'Summer School Peregrinations', 3019, 2, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (3010, NULL, '2014-06-12 20:24:09.699631+00', 'London Highland Club''s Farewell to Fetter Lane, The', 2057, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9092, '2013-01-04 12:24:41.432134+00', '2014-06-28 07:16:01.501789+00', 'Selection of Jigs', 3067, 2, 8, 32, 9999, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (5751, NULL, '2014-06-29 05:01:53.914364+00', 'Dear Gladys', 2586, 3, 8, 32, 9999, NULL, 511, 0, '');
INSERT INTO 'recording' VALUES (4072, NULL, '2014-06-29 12:10:00.111363+00', 'Foursome Reel', 3010, 4, 0, 0, 11, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (5889, NULL, '2014-07-30 13:49:21.787166+00', 'Eva Three-Step', 2501, 11, 0, 16, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (5896, NULL, '2014-07-30 14:14:07.919055+00', 'Military Two-Step', 2501, 11, 0, 16, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (9686, '2014-08-05 14:02:24.117901+00', '2014-08-05 20:44:18.589745+00', 'Retour des Hirondelles, Le', 3037, 98, 0, 0, 9999, NULL, 159, 0, 'accordian solo');
INSERT INTO 'recording' VALUES (9685, '2014-08-05 13:56:55.891048+00', '2014-08-05 20:48:49.074496+00', 'Shetland Waltz', 3037, 5, 0, 0, 9999, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (2952, NULL, '2021-09-11 16:37:09.696164+00', 'Dunoon Barn Dance', 2328, 11, 0, 16, 9999, NULL, 223, 0, '');
INSERT INTO 'recording' VALUES (5441, NULL, '2021-10-02 14:40:49.339144+00', 'Mercia', 1502, 1, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (9690, '2014-08-11 14:50:14.3205+00', '2014-08-11 14:50:14.3205+00', 'Newburgh Jig', 10979, 2, 8, 32, NULL, NULL, 307, 0, '');
INSERT INTO 'recording' VALUES (9689, '2014-08-05 16:46:43.421707+00', '2014-08-05 20:43:06.895153+00', 'Mrs MacLeod of Raasay', 3037, 1, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (2906, NULL, '2014-08-05 20:45:39.64878+00', 'Leith Country Dance, The', 3037, 2, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (9688, '2014-08-05 15:33:59.157187+00', '2014-08-05 20:47:53.722123+00', 'Dantesque', 3037, 13, 0, 0, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (9691, '2014-08-11 14:52:09.878919+00', '2014-08-11 14:52:09.878919+00', 'Rutland Reel, The', 10979, 1, 8, 40, NULL, NULL, 367, 0, '');
INSERT INTO 'recording' VALUES (9692, '2014-08-11 14:56:11.384796+00', '2014-08-11 14:56:11.384796+00', 'Golden Years, The', 10979, 3, 8, 32, NULL, NULL, 509, 0, '');
INSERT INTO 'recording' VALUES (9693, '2014-08-11 14:59:20.354313+00', '2014-08-11 14:59:20.354313+00', 'Monica''s Way', 10979, 2, 4, 32, NULL, NULL, 158, 1, '');
INSERT INTO 'recording' VALUES (9694, '2014-08-11 15:01:57.071116+00', '2014-08-11 15:01:57.071116+00', 'Rye Twist', 10979, 1, 5, 32, NULL, 5, 190, 0, '');
INSERT INTO 'recording' VALUES (9695, '2014-08-11 15:03:28.316877+00', '2014-08-11 15:03:28.316877+00', 'City of Belfast', 10979, 3, 3, 32, NULL, 5, 205, 0, '');
INSERT INTO 'recording' VALUES (9696, '2014-08-11 15:09:43.07291+00', '2014-08-11 15:09:43.07291+00', 'Sunshine and Sweetie''s Jig', 10979, 2, 8, 32, NULL, 21, 302, 0, '');
INSERT INTO 'recording' VALUES (9697, '2014-08-11 15:12:43.433741+00', '2014-08-11 15:12:43.433741+00', 'Tri-Mariner, The', 10979, 1, 8, 32, NULL, 5, 304, 0, '');
INSERT INTO 'recording' VALUES (9698, '2014-08-11 15:15:59.900322+00', '2014-08-11 15:15:59.900322+00', 'Summer Meeting, A', 10979, 3, 3, 32, NULL, 5, 192, 0, '');
INSERT INTO 'recording' VALUES (9699, '2014-08-11 15:18:07.376695+00', '2014-08-11 15:18:07.376695+00', 'Festival Man, The', 10979, 2, 8, 32, NULL, 1, 296, 0, '');
INSERT INTO 'recording' VALUES (9700, '2014-08-11 15:19:54.42806+00', '2014-08-11 15:19:54.42806+00', 'Fireworks Reel, The', 10979, 1, 8, 32, NULL, 5, 292, 0, '');
INSERT INTO 'recording' VALUES (9701, '2014-08-11 15:22:07.77316+00', '2014-08-11 15:22:07.77316+00', 'Rougemont Castle', 10979, 3, 3, 32, NULL, 5, 192, 0, '');
INSERT INTO 'recording' VALUES (9702, '2014-08-11 15:27:10.586833+00', '2014-08-11 15:27:10.586833+00', 'Lady in Red', 10979, 2, 5, 32, NULL, 1, 246, 0, '');
INSERT INTO 'recording' VALUES (6709, NULL, '2014-08-11 15:33:21.033715+00', 'Reel of the 51st Division, The', 10034, 1, 10, 32, NULL, NULL, 336, 0, '');
INSERT INTO 'recording' VALUES (9705, '2014-08-11 22:06:22.178644+00', '2014-08-11 22:06:22.178644+00', 'Tap the Barrel', 10981, 1, 3, 32, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (9708, '2014-08-11 22:18:54.559549+00', '2014-08-11 22:18:54.559549+00', 'Crom Allt', 10981, 1, 8, 32, NULL, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (9709, '2014-08-11 22:22:33.000029+00', '2014-08-11 22:22:33.000029+00', 'Paisley Weavers, The', 10981, 3, 3, 32, NULL, NULL, 183, 1, '');
INSERT INTO 'recording' VALUES (9710, '2014-08-11 22:23:50.118523+00', '2014-08-11 22:23:50.118523+00', 'Craigleith', 10981, 1, 1, 88, NULL, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (9711, '2014-08-11 22:26:09.795736+00', '2014-08-11 22:26:09.795736+00', 'Haar on Skye, The', 10981, 3, 8, 32, NULL, NULL, 467, 0, '');
INSERT INTO 'recording' VALUES (9712, '2014-08-11 22:27:59.756441+00', '2014-08-11 22:27:59.756441+00', 'Shetland Shepherdess, The', 10981, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9714, '2014-08-11 22:33:06.369814+00', '2014-08-11 22:33:06.369814+00', 'Captain''s House, The', 10981, 1, 8, 32, NULL, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (9715, '2014-08-11 22:34:50.060405+00', '2014-08-11 22:34:50.060405+00', 'Bill Little''s Strathspey', 10981, 3, 4, 32, NULL, NULL, 243, 0, '');
INSERT INTO 'recording' VALUES (9716, '2014-08-11 22:36:41.600113+00', '2014-08-11 22:36:41.600113+00', 'Gaelforce Wind', 10981, 2, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (9717, '2014-08-11 22:38:37.925572+00', '2014-08-11 22:38:37.925572+00', 'Out of Thin Air', 10981, 3, 3, 32, NULL, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (9718, '2014-08-11 22:40:10.074466+00', '2014-08-11 22:40:10.074466+00', 'Compleat Gardener, The', 10981, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9719, '2014-08-19 07:16:06.243241+00', '2014-08-19 07:16:06.243241+00', 'Auld Robin Gray', 10982, 3, 8, 32, NULL, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (9721, '2014-08-19 07:35:41.883145+00', '2014-08-19 07:35:41.883145+00', 'Caller Herrin''', 10982, 1, 8, 40, NULL, NULL, 363, 0, '');
INSERT INTO 'recording' VALUES (9722, '2014-08-19 07:45:13.954921+00', '2014-08-19 07:45:57.141111+00', 'Castles in the Air', 10982, 3, 8, 32, NULL, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (9724, '2014-08-19 07:59:55.297166+00', '2014-08-19 07:59:55.297166+00', 'Gallant Weaver, The', 10982, 1, 8, 32, NULL, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (9725, '2014-08-19 08:04:47.905951+00', '2014-08-19 08:04:47.905951+00', 'Hey, Johnnie Cope', 10982, 1, 8, 32, NULL, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (8868, '2012-04-29 14:26:05.422958+00', '2014-08-19 08:11:49.793106+00', 'Strathspeys (Song Airs) (with pauses between turns)', 1502, 3, 3, 32, 9999, NULL, 239, 0, '');
INSERT INTO 'recording' VALUES (9727, '2014-08-19 08:32:40.139959+00', '2014-08-19 08:32:40.139959+00', 'John Grumlie', 10982, 2, 8, 48, NULL, NULL, 420, 0, '');
INSERT INTO 'recording' VALUES (9728, '2014-08-19 08:39:03.256111+00', '2014-08-19 08:39:03.256111+00', 'John of Badenyon', 10982, 3, 4, 48, NULL, NULL, 384, 0, '');
INSERT INTO 'recording' VALUES (9707, '2014-08-11 22:16:15.106021+00', '2015-01-02 18:23:07.249369+00', 'Friendships', 10981, 3, 4, 32, NULL, NULL, 238, 0, '');
INSERT INTO 'recording' VALUES (9674, '2014-05-09 23:44:01.987115+00', '2015-09-05 21:06:24.931203+00', 'Lilibet''s Strathspey', 10955, 3, 4, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (9670, '2014-05-09 21:45:00.703314+00', '2015-09-05 21:06:49.320712+00', 'Brenda''s Jig', 10955, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (9726, '2014-08-19 08:24:32.291072+00', '2018-01-27 10:32:55.178174+00', 'In the Garb of Old Gaul', 10982, 3, 8, 32, NULL, NULL, 528, 0, '');
INSERT INTO 'recording' VALUES (9706, '2014-08-11 22:10:30.917931+00', '2019-10-01 21:06:11.689516+00', 'Bethankit', 10981, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (9729, '2014-08-19 08:43:21.507818+00', '2014-08-19 08:43:21.507818+00', 'My Mither''s Aye Glow''rin Owre Me', 10982, 2, 8, 32, NULL, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (9730, '2014-08-19 08:47:09.633653+00', '2014-08-19 08:47:09.633653+00', 'My Tocher''s the Jewel', 10982, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9731, '2014-08-19 08:51:58.408611+00', '2014-08-19 08:51:58.408611+00', 'Somebody', 10982, 3, 5, 16, NULL, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (7107, NULL, '2014-08-19 08:58:10.342844+00', 'Harry Lauder Medley', 10079, 98, 0, 0, NULL, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (9732, '2014-08-19 09:05:35.306205+00', '2014-08-19 09:05:35.306205+00', 'Wha''ll Be King But Charlie', 10982, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (9733, '2014-08-19 09:14:18.879097+00', '2014-08-19 09:14:18.879097+00', 'Wee Cooper o'' Fife, The', 10982, 2, 8, 40, NULL, NULL, 361, 0, '10-bar phrases');
INSERT INTO 'recording' VALUES (355, NULL, '2014-08-21 06:39:34.238221+00', 'Well Done Jack', 3018, 2, 8, 32, 9999, 1, 269, 0, '');
INSERT INTO 'recording' VALUES (6008, NULL, '2014-09-01 15:38:15.534754+00', 'Burnham Park', 1557, 2, 3, 40, 9999, NULL, 131, 0, '');
INSERT INTO 'recording' VALUES (9713, '2014-08-11 22:30:34.504123+00', '2014-09-06 02:36:29.700928+00', 'Karin''s Strathspey', 10981, 3, 8, 32, NULL, NULL, 468, 0, '');
INSERT INTO 'recording' VALUES (8909, '2012-06-12 15:19:33.254313+00', '2014-09-10 23:59:53.062235+00', 'Dulce in Dacorum est', 3012, 1, 4, 40, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (6326, NULL, '2014-09-16 08:58:16.531216+00', 'Mhairi''s Wedding', 2566, 1, 8, 40, 9999, NULL, 346, 0, '');
INSERT INTO 'recording' VALUES (6327, NULL, '2014-09-16 09:02:16.468562+00', 'Happy Meeting', 2566, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (6333, NULL, '2014-09-16 09:35:17.609305+00', 'Ian Powrie''s Farewell to Auchterarder', 2566, 2, 1, 128, 9999, NULL, 147, 0, 'The CD calls this “Ian Powrie''s Fairwell [sic] to Scotland” but it is clearly IPFTA – the other dance is a reel.');
INSERT INTO 'recording' VALUES (6463, NULL, '2014-09-16 09:55:11.107706+00', 'Chequered Court, The', 1846, 2, 8, 32, 9999, NULL, 300, 0, '');
INSERT INTO 'recording' VALUES (920, NULL, '2014-09-16 10:13:24.090898+00', 'Saint Patrick''s Day', 3018, 2, 8, 24, 9999, 18, 209, 0, '');
INSERT INTO 'recording' VALUES (3264, NULL, '2014-09-16 11:34:18.532163+00', 'McMarley''s Cross', 2188, 3, 3, 32, 9999, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (5951, NULL, '2018-03-02 23:10:33.162244+00', 'Trip to Blairgowrie', 2566, 2, 8, 40, 9999, NULL, 348, 0, '');
INSERT INTO 'recording' VALUES (5568, NULL, '2014-09-16 11:51:59.811988+00', 'Jubilee Jig, The', 2162, 2, 8, 32, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (6062, NULL, '2014-09-16 12:17:13.678074+00', 'Barmkin, The', 3619, 1, 0, 88, 9999, NULL, 106, 0, '');
INSERT INTO 'recording' VALUES (857, NULL, '2014-09-16 12:33:05.011859+00', 'J.B. Milne', 3039, 1, 8, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (865, NULL, '2014-09-16 12:37:04.252285+00', 'Wind on Loch Fyne, The', 3039, 3, 3, 32, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (4697, NULL, '2014-09-16 12:43:48.683203+00', 'Angus MacLeod', 3039, 1, 2, 64, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (4704, NULL, '2014-09-16 12:47:10.794437+00', 'Bees of Maggieknockater, The', 3039, 2, 4, 32, 9999, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (9704, '2014-08-11 15:35:18.099947+00', '2022-12-14 16:02:25.002439+00', 'MacLeod''s Wedding', 10979, 1, 5, 48, NULL, 5, 281, 0, '');
INSERT INTO 'recording' VALUES (9703, '2014-08-11 15:29:03.538612+00', '2023-01-30 17:42:22.268227+00', 'Farewell to Helensburgh', 10979, 3, 8, 32, NULL, 21, 513, 0, '');
INSERT INTO 'recording' VALUES (518, NULL, '2014-09-16 13:15:38.107911+00', 'Bruce & Margaret Urquhart', 3012, 3, 8, 32, 9999, NULL, 237, 0, '');
INSERT INTO 'recording' VALUES (6169, NULL, '2014-09-16 13:33:30.971843+00', 'Mideltone Silver', 3019, 2, 5, 32, 9999, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (9741, '2014-09-18 16:20:38.329502+00', '2014-09-18 16:20:38.329502+00', 'Postie''s Jig', 10034, 2, 4, 32, 9999, NULL, 139, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (9737, '2014-09-18 16:03:21.48597+00', '2014-09-18 16:03:21.48597+00', 'St Bernards Waltz', 10034, 5, 0, 0, 9999, NULL, 168, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (9736, '2014-09-18 15:59:59.373839+00', '2014-09-18 16:05:47.112435+00', 'Dashing White Sergeant, The', 11003, 50, 0, 0, 9999, NULL, 206, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (9735, '2014-09-17 10:29:38.699665+00', '2014-09-18 16:06:45.619595+00', 'Gay Gordons', 3008, 50, 0, 32, 9999, NULL, 229, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (9738, '2014-09-18 16:11:23.61007+00', '2014-09-18 16:11:23.61007+00', 'Radical Road, The', 3008, 1, 4, 32, 9999, NULL, 137, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (1345, NULL, '2021-08-18 16:56:47.996578+00', 'Crossing, The', 3018, 3, 8, 32, 9999, 5, 480, 0, '');
INSERT INTO 'recording' VALUES (9740, '2014-09-18 16:18:23.097856+00', '2014-09-18 16:18:23.097856+00', 'Military Two Step', 11003, 11, 0, 16, 9999, NULL, 166, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (9742, '2014-09-18 16:22:45.998189+00', '2014-09-18 16:22:45.998189+00', 'Granite City Reel, The', 11003, 1, 6, 32, 9999, NULL, 205, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (9743, '2014-09-18 16:25:33.321363+00', '2014-09-18 16:25:33.321363+00', 'Canadian Barn Dance', 11003, 11, 0, 16, 9999, NULL, 210, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (9744, '2014-09-18 16:27:24.346739+00', '2014-09-18 16:27:24.346739+00', 'Reel Of The 51st Division', 3008, 1, 8, 32, 9999, NULL, 273, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (9745, '2014-09-18 16:30:39.969833+00', '2014-09-18 16:31:45.221489+00', 'Britannia Two Step', 10034, 11, 0, 16, 9999, NULL, 142, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (9746, '2014-09-18 16:33:35.099784+00', '2014-09-18 16:33:35.099784+00', 'Clydeside Reel, The', 10034, 1, 4, 32, 9999, NULL, 155, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (9748, '2014-09-18 16:38:35.92788+00', '2014-09-18 16:38:35.92788+00', 'Pride Of Erin Waltz, The', 3008, 5, 0, 0, 9999, NULL, 271, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (9749, '2014-09-18 16:40:37.881934+00', '2014-09-18 16:40:37.881934+00', 'Strip The Willow', 11003, 2, 0, 0, 9999, NULL, 233, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (9750, '2014-09-18 16:42:57.405612+00', '2014-09-18 16:42:57.405612+00', 'Auld Lang Syne', 9998, 98, 0, 0, 9999, NULL, 87, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (9751, '2014-10-02 01:16:40.27893+00', '2014-10-04 01:21:57.781647+00', 'Blethering Beth', 11017, 2, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (9753, '2014-10-02 01:24:20.838765+00', '2014-10-04 01:28:42.588829+00', 'Golden Eagle, The', 11017, 3, 8, 32, 9999, NULL, 509, 0, '');
INSERT INTO 'recording' VALUES (9752, '2014-10-02 01:17:46.772243+00', '2014-10-04 01:29:22.02322+00', 'Eric''s Reel', 11017, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9754, '2014-10-02 01:26:29.869373+00', '2014-10-04 01:39:45.52522+00', 'Nickie-Tams', 11017, 2, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (9755, '2014-10-02 01:28:32.721754+00', '2014-10-04 01:41:20.568913+00', 'Athens of the North', 11017, 3, 8, 32, 9999, NULL, 500, 0, '');
INSERT INTO 'recording' VALUES (9757, '2014-10-02 01:31:43.260818+00', '2014-10-04 01:43:18.447317+00', 'Trip to Edinburgh, A', 11017, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (8187, NULL, '2014-10-04 01:55:18.451586+00', 'Houliston''s Jigs', 10037, 2, 5, 32, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (9756, '2014-10-02 01:29:53.626282+00', '2014-10-04 02:07:56.663526+00', 'About Time', 11017, 2, 8, 32, 9999, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (9758, '2014-10-02 01:33:03.022413+00', '2014-10-04 02:52:08.958545+00', 'Pink Triangle, The', 11017, 3, 3, 32, 9999, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (9759, '2014-10-02 01:34:17.720243+00', '2014-10-04 02:58:00.488867+00', 'Ravelston Rant, The', 11017, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (9760, '2014-10-02 01:35:19.019871+00', '2014-10-04 03:08:24.240354+00', 'Royal Edinburgh', 11017, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (9761, '2014-10-02 01:36:30.125699+00', '2014-10-04 03:10:55.123108+00', 'Water of Leith, The', 11017, 3, 4, 32, 9999, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (9762, '2014-10-02 01:38:02.958154+00', '2014-10-04 03:17:47.95295+00', 'Corners of Edinburgh', 11017, 1, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (9763, '2014-10-02 01:40:00.152755+00', '2014-10-04 03:22:42.249952+00', 'Ian Powrie''s Farewell to Auchterarder', 11017, 2, 1, 128, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (2959, NULL, '2014-10-08 15:09:11.315087+00', 'Glasgow Highlanders, The', 2328, 3, 3, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (2206, NULL, '2014-10-19 16:09:09.548683+00', 'Captain Whiteside', 2398, 2, 8, 32, 9999, 1, 275, 0, '');
INSERT INTO 'recording' VALUES (5138, NULL, '2014-10-19 16:10:36.216477+00', 'Ian Powrie''s Hornpipe', 3038, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (5332, NULL, '2014-10-19 20:01:56.893194+00', 'David''s Seven-O Reel', 3002, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (7782, NULL, '2014-11-01 00:38:05.622716+00', 'Hamilton House', 3006, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (9766, '2014-11-14 09:18:47.602791+00', '2014-11-14 09:18:47.602791+00', 'Shirley''s Strathspey', 3011, 3, 3, 32, NULL, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (9767, '2014-11-14 09:22:09.988627+00', '2014-11-14 09:22:09.988627+00', 'Leccamore Jig, The', 3011, 2, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (9769, '2014-11-14 09:29:03.748966+00', '2014-11-14 09:32:32.513867+00', 'Twinkle in his Eye, A', 3011, 3, 4, 32, NULL, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (6579, NULL, '2017-01-26 23:44:53.70399+00', 'Indian River Strathspey', 3032, 3, 3, 32, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (1523, NULL, '2019-10-20 23:23:56.434839+00', 'Jigs', 3067, 2, 3, 32, 9999, 1, 107, 0, '');
INSERT INTO 'recording' VALUES (10234, '2019-01-08 15:55:21.450807+00', '2019-01-25 22:49:51.926826+00', 'Susie from Penilee', 3217, 3, 8, 32, NULL, NULL, 499, 0, '');
INSERT INTO 'recording' VALUES (307, NULL, '2019-05-04 23:37:56.785097+00', 'Irish Reels', 3003, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (9768, '2014-11-14 09:25:38.137827+00', '2014-11-14 09:34:58.178315+00', 'All the Eights', 3011, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9770, '2014-11-14 09:57:18.223898+00', '2014-11-14 09:57:18.223898+00', 'Jacqui Watson''s Strathspey', 3011, 3, 3, 32, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (9771, '2014-11-14 09:59:56.021194+00', '2014-11-14 09:59:56.021194+00', 'Nifty Ninety', 3011, 1, 3, 32, NULL, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (9772, '2014-11-14 10:04:09.435993+00', '2014-11-14 10:04:09.435993+00', 'Scarborough Castle', 3011, 3, 8, 32, NULL, NULL, 520, 0, '');
INSERT INTO 'recording' VALUES (9774, '2014-11-14 10:12:17.133441+00', '2014-11-14 10:12:17.133441+00', 'Candyfloss', 3011, 3, 3, 32, NULL, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (9775, '2014-11-14 10:15:24.983842+00', '2014-11-14 10:15:24.983842+00', 'Jovial Jack', 3011, 1, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (9776, '2014-11-14 10:17:37.400013+00', '2014-11-14 10:17:37.400013+00', 'South from Oban', 3011, 2, 8, 40, NULL, NULL, 352, 0, '');
INSERT INTO 'recording' VALUES (9764, '2014-11-13 21:04:20.473499+00', '2014-11-14 10:34:32.446558+00', 'Charles Ogden''s Jig', 3011, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9765, '2014-11-13 21:56:32.750187+00', '2014-11-14 10:36:09.497384+00', 'Golden Arc', 3011, 1, 8, 32, NULL, NULL, 240, 0, '');
INSERT INTO 'recording' VALUES (4624, NULL, '2014-11-18 22:16:59.061689+00', 'Broadford Bay', 2570, 1, 8, 32, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (9720, '2014-08-19 07:22:58.106196+00', '2014-11-22 22:25:31.976629+00', 'Awa'' Whigs, Awa''', 10982, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (8804, NULL, '2014-11-26 10:34:59.533712+00', 'Flowers of Edinburgh, The', 3010, 1, 6, 32, NULL, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (7995, NULL, '2014-12-03 02:59:00.50995+00', 'Duchess Tree', 10209, 3, 8, 32, NULL, NULL, 489, 0, '');
INSERT INTO 'recording' VALUES (8090, NULL, '2014-12-03 03:01:24.406794+00', 'Duchess Tree, The', 3023, 3, 8, 32, NULL, NULL, 525, 0, '');
INSERT INTO 'recording' VALUES (7042, NULL, '2014-12-03 06:27:12.809649+00', 'Branches Together', 10076, 3, 1, 96, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (5588, NULL, '2014-12-10 07:59:28.041322+00', 'If at First', 3006, 3, 3, 32, 9999, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (7382, NULL, '2014-12-21 22:13:27.85624+00', 'Big Mac', 10117, 3, 5, 32, NULL, NULL, 306, 0, '');
INSERT INTO 'recording' VALUES (9641, '2014-04-29 13:40:45.880962+00', '2014-12-22 23:34:12.027074+00', 'Highland Wedding, The', 3042, 11, 6, 16, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (1419, NULL, '2015-01-12 14:29:09.383256+00', 'Hooper''s Jig', 2032, 2, 8, 32, 9999, 1, 277, 0, '');
INSERT INTO 'recording' VALUES (1831, NULL, '2015-02-03 00:43:58.070235+00', 'Jim Dougal of Eyemouth', 1502, 3, 3, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (6419, NULL, '2015-02-13 17:54:05.534905+00', 'Feisty Women', 3030, 1, 6, 32, 9999, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (9385, '2013-10-29 02:45:26.736872+00', '2015-02-14 03:35:33.670547+00', 'Ramadan-ce', 3217, 1, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (5589, NULL, '2015-02-15 08:52:35.634808+00', 'Chorlton Reel, The', 3006, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (1620, NULL, '2015-02-24 08:15:35.140121+00', 'Largo Bay', 2040, 3, 2, 48, 9999, 4, 192, 1, '');
INSERT INTO 'recording' VALUES (5318, NULL, '2015-02-24 08:18:41.120824+00', 'City of Angels', 3002, 3, 4, 48, 9999, NULL, 392, 0, '');
INSERT INTO 'recording' VALUES (9300, '2013-02-06 14:42:14.904783+00', '2015-02-27 15:58:36.03105+00', 'My Love She''s but a Lassie Yet', 10748, 1, 8, 32, NULL, NULL, 274, 1, '');
INSERT INTO 'recording' VALUES (9739, '2014-09-18 16:15:55.486215+00', '2022-05-24 14:10:59.282263+00', 'Virginia Reel, The', 3008, 50, 8, 40, 9999, NULL, 304, 0, '');
INSERT INTO 'recording' VALUES (9342, '2013-05-11 16:23:13.300128+00', '2022-05-29 10:41:36.362872+00', 'Wild Mountain Thyme', 3420, 3, 8, 24, NULL, NULL, 373, 0, '');
INSERT INTO 'recording' VALUES (6832, NULL, '2022-12-09 19:54:17.09687+00', 'Off She Goes or Follow Her Over The Borders', 10659, 2, 8, 16, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (6358, NULL, '2015-03-13 08:24:50.23662+00', 'Osborne Percentage, The', 3014, 2, 3, 32, 9999, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (6324, NULL, '2015-03-24 11:29:19.499092+00', 'Seton''s Ceilidh Band', 2566, 1, 4, 64, 9999, NULL, 273, 0, 'This is an encore-type track in reel time; the <<ddd:Seton''s Ceilidh Band|original dance>> is a jig.');
INSERT INTO 'recording' VALUES (6311, NULL, '2015-03-24 11:54:20.687009+00', 'Scottish Reform', 2566, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (6316, NULL, '2015-03-24 12:04:56.817195+00', 'Glens of Antrim', 2566, 3, 8, 32, 9999, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (2244, NULL, '2021-07-03 09:12:15.862511+00', 'Welcome to Queen''s Cross', 3026, 3, 4, 48, 9999, 30, 380, 0, '');
INSERT INTO 'recording' VALUES (6210, NULL, '2015-03-25 12:19:38.375106+00', 'Selection of Jigs', 3067, 2, 4, 32, 9999, NULL, 145, 0, '');
INSERT INTO 'recording' VALUES (5908, NULL, '2015-03-25 12:21:42.973883+00', 'Strathspey Set (suitable fur Bedrule)', 3483, 3, 8, 32, 9999, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (387, NULL, '2015-04-08 06:23:17.507846+00', 'Hoedown Reel Set', 3030, 1, 5, 32, 9999, 5, 174, 0, '');
INSERT INTO 'recording' VALUES (8697, NULL, '2015-04-09 21:43:12.748796+00', 'Terrace Logger''s Jig', 10551, 2, 4, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (548, NULL, '2015-04-18 19:20:01.687723+00', 'Wee Cooper of Fife, The', 3036, 2, 4, 40, 9999, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (7453, NULL, '2015-04-22 23:06:09.521996+00', 'New Rigged Ship', 3065, 2, 4, 48, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (9777, '2015-05-14 09:08:53.729372+00', '2015-05-14 09:08:53.729372+00', 'Inimitable Derek, The', 11136, 1, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (9778, '2015-05-14 09:14:13.14041+00', '2015-05-14 09:14:13.14041+00', 'Nurseryman, The', 11136, 2, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (9781, '2015-05-14 11:12:40.566588+00', '2015-05-14 11:12:40.566588+00', 'Trysting Place, The', 11136, 3, 8, 32, 9999, NULL, 531, 0, '');
INSERT INTO 'recording' VALUES (9784, '2015-05-14 11:23:09.450761+00', '2015-05-14 11:23:09.450761+00', 'Elusive Muse', 11136, 2, 3, 32, 9999, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (9785, '2015-05-14 11:28:58.310856+00', '2015-05-14 11:28:58.310856+00', 'Dr Neil S MacLeod', 11136, 3, 8, 32, 9999, NULL, 531, 0, '');
INSERT INTO 'recording' VALUES (9786, '2015-05-14 11:33:34.23202+00', '2015-05-14 11:33:34.23202+00', 'Auld Lang Syne and Polka', 11136, 13, 0, 0, 9999, NULL, 167, 0, 'Song Auld Lang Syne followed by polka');
INSERT INTO 'recording' VALUES (9782, '2015-05-14 11:16:22.160879+00', '2015-05-14 11:57:33.801865+00', 'New Rigged Ship, The', 11136, 2, 8, 48, 9999, NULL, 436, 0, '');
INSERT INTO 'recording' VALUES (4055, NULL, '2015-05-14 11:58:42.974658+00', 'New Rigged Ship, The', 3024, 2, 4, 48, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (9780, '2015-05-14 10:04:49.635225+00', '2015-08-05 02:45:09.447111+00', 'Catch the Wind', 11136, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (9779, '2015-05-14 09:17:55.985295+00', '2016-02-14 12:10:13.520898+00', 'Anna Holden''s Strathspey', 11136, 3, 6, 32, 9999, NULL, 399, 0, '');
INSERT INTO 'recording' VALUES (5438, NULL, '2016-09-04 14:02:38.666256+00', 'Jim Dougal of Eyemouth', 1502, 3, 3, 32, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (6077, NULL, '2018-07-10 11:29:52.276949+00', 'Braes of Breadalbane, The', 3653, 3, 8, 32, 9999, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (1512, NULL, '2019-08-19 08:20:18.047398+00', 'Herself', 3067, 3, 3, 32, 9999, 5, 190, 0, '');
INSERT INTO 'recording' VALUES (3244, NULL, '2015-06-13 14:44:13.760403+00', 'Come Under My Plaidie', 2137, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (9808, '2015-06-13 14:54:20.498579+00', '2015-06-13 14:54:20.498579+00', '2/4 Marches', 2137, 11, 4, 32, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (9809, '2015-06-13 14:56:00.104554+00', '2015-06-13 14:56:00.104554+00', 'Barn Dance', 2137, 11, 4, 32, NULL, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (9810, '2015-06-13 15:00:25.406493+00', '2015-06-13 15:00:25.406493+00', 'Boston Two Step', 2137, 50, 8, 16, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (9811, '2015-06-13 15:01:45.758119+00', '2015-06-13 15:01:45.758119+00', 'Apple Tree', 2137, 1, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (9812, '2015-06-13 15:04:09.95354+00', '2015-06-13 15:04:09.95354+00', 'Medley', 2137, 99, 0, 0, NULL, NULL, 220, 0, '');
INSERT INTO 'recording' VALUES (9813, '2015-06-13 15:06:57.694205+00', '2015-06-13 15:06:57.694205+00', 'Marches', 2137, 11, 0, 0, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (9814, '2015-06-13 15:08:16.666632+00', '2015-06-13 15:08:38.892388+00', 'Irish Jigs', 2137, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (9815, '2015-06-13 15:10:16.546889+00', '2015-06-13 15:10:16.546889+00', 'Waltzes', 2137, 5, 3, 32, 9999, NULL, 123, 0, '');
INSERT INTO 'recording' VALUES (9816, '2015-06-13 15:11:55.37109+00', '2015-06-13 15:11:55.37109+00', 'Marches Medley', 2137, 11, 5, 32, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (9818, '2015-06-19 10:48:55.080317+00', '2015-06-19 10:48:55.080317+00', 'John of Bon Accord', 10000, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9819, '2015-06-19 10:51:04.314267+00', '2015-06-19 10:51:04.314267+00', 'Silver Tassie, The', 10000, 3, 8, 32, NULL, NULL, 511, 0, '');
INSERT INTO 'recording' VALUES (9821, '2015-06-19 11:12:19.814277+00', '2015-06-19 11:12:19.814277+00', 'Dr. Stocker''s Hornpipe', 10000, 1, 4, 40, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (9822, '2015-06-19 11:13:58.993826+00', '2015-06-19 11:13:58.993826+00', 'Bonnie Stronshiray', 10000, 3, 8, 32, NULL, NULL, 507, 0, '');
INSERT INTO 'recording' VALUES (9857, '2015-10-06 11:06:54.807715+00', '2015-10-06 11:06:54.807715+00', 'Bonnie Lass o'' Bon Accord, The', 2414, 3, 0, 64, 9999, NULL, 120, 0, '(1x56 Strathspey with 8 bars Intro)');
INSERT INTO 'recording' VALUES (9823, '2015-06-19 11:15:52.776159+00', '2015-06-19 11:35:46.985806+00', 'Links with St Petersburg', 10000, 2, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (9825, '2015-06-19 11:45:48.804901+00', '2015-06-19 11:45:48.804901+00', 'Culla Bay', 10000, 3, 4, 32, NULL, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (9826, '2015-06-19 11:49:57.362442+00', '2015-06-19 11:49:57.362442+00', 'Granville Market', 10000, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9827, '2015-06-19 11:52:42.793865+00', '2015-06-19 11:52:42.793865+00', 'None So Pretty', 10000, 1, 8, 40, NULL, NULL, 350, 0, '');
INSERT INTO 'recording' VALUES (9828, '2015-06-19 11:54:34.62588+00', '2015-06-19 11:54:34.62588+00', 'Flower of Glasgow, The', 10000, 3, 3, 32, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (9829, '2015-06-19 11:58:05.150639+00', '2015-06-19 11:58:05.150639+00', 'Trip to Timber Ridge', 10000, 1, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (9747, '2014-09-18 16:35:51.350176+00', '2015-06-28 15:35:51.370181+00', 'Eightsome Reel, The', 10034, 1, 1, 464, 9999, NULL, 497, 0, 'No information given on the CD by the RSCDS.');
INSERT INTO 'recording' VALUES (479, NULL, '2015-07-16 18:42:10.232442+00', 'Win Thomson''s Chase', 2184, 1, 4, 40, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (4868, NULL, '2015-07-28 13:02:06.881296+00', 'Kiss for Nothing, A', 3037, 2, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (4874, NULL, '2015-07-28 13:41:51.692983+00', 'Strip the Willow', 3037, 2, 4, 32, 9999, NULL, 136, 0, 'Recording of "Strip The Willow" - Jig 4x32 bars (duration 2 mins 14

secs) by Jim Johnstone and his band is published on music cassette

"Scotland - The Dances and Dance Bands"  Lismor 1987  LICS 5163

too.');
INSERT INTO 'recording' VALUES (9830, '2015-08-19 14:34:02.233484+00', '2015-08-19 14:34:02.233484+00', 'Neil M Grant', 10659, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (9831, '2015-08-19 14:42:03.680485+00', '2015-08-19 14:42:03.680485+00', 'Orpington Caledonians', 10659, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9833, '2015-08-19 14:52:08.107919+00', '2015-08-19 14:52:08.107919+00', 'First Rain of Spring, The', 10659, 2, 3, 32, 9999, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (9834, '2015-08-19 14:54:52.78001+00', '2015-08-19 14:54:52.78001+00', 'Miss Eleanor', 10659, 3, 3, 32, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (9835, '2015-08-19 15:02:59.436376+00', '2015-08-19 15:02:59.436376+00', 'Waltz', 10659, 5, 0, 0, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (9817, '2015-06-19 10:43:24.932819+00', '2019-11-22 19:17:30.71721+00', 'On the Incoming Tide', 10000, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9788, '2015-05-14 11:46:43.602455+00', '2019-11-22 19:41:05.683244+00', 'Demonstration Set 2', 11136, 4, 1, 224, 9998, NULL, 401, 0, '');
INSERT INTO 'recording' VALUES (8904, '2012-06-12 14:31:14.236306+00', '2020-01-24 21:12:41.358521+00', 'Potten End Reel, The', 3012, 1, 8, 32, NULL, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (9783, '2015-05-14 11:20:29.087355+00', '2019-12-22 08:44:16.418892+00', 'Alasdair''s Reels', 11136, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (8902, '2012-06-12 14:21:52.057624+00', '2020-01-26 11:38:39.893874+00', 'Foundling, The', 3012, 3, 3, 32, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (8916, '2012-06-12 16:15:20.334949+00', '2020-01-28 22:07:53.926765+00', 'Other Left, The', 3012, 2, 4, 32, NULL, NULL, 141, 1, '');
INSERT INTO 'recording' VALUES (9789, '2015-05-31 08:43:56.178986+00', '2021-10-16 22:20:19.413334+00', 'Grand March', 10037, 11, 0, 0, NULL, NULL, 237, 0, '');
INSERT INTO 'recording' VALUES (9791, '2015-05-31 08:47:44.433132+00', '2022-01-12 23:08:47.110712+00', 'Inverness Country Dance', 10037, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (9792, '2015-05-31 08:48:51.331912+00', '2022-01-12 23:09:21.138402+00', 'S-Locomotion', 10037, 3, 4, 32, 9999, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (9793, '2015-05-31 08:50:06.444084+00', '2022-01-12 23:09:40.056946+00', 'Nurseryman, The', 10037, 2, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (9794, '2015-05-31 08:52:02.248155+00', '2022-01-12 23:10:08.649826+00', 'Recumbent Stone, The', 10037, 1, 5, 48, 9999, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (9795, '2015-05-31 09:22:16.900481+00', '2022-01-12 23:10:36.186144+00', 'Johnnie Walker', 10037, 4, 1, 128, 13, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (9797, '2015-05-31 09:24:26.476444+00', '2022-01-12 23:11:25.772038+00', 'Waltz Country Dance', 10037, 5, 5, 40, 9999, NULL, 239, 0, '');
INSERT INTO 'recording' VALUES (9798, '2015-05-31 09:25:37.785856+00', '2022-01-12 23:11:48.429889+00', 'Chequered Court, The', 10037, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (9799, '2015-05-31 09:26:42.743404+00', '2022-01-12 23:12:23.443626+00', 'Mrs MacLeod', 10037, 1, 8, 32, 9999, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (9800, '2015-05-31 09:27:42.389481+00', '2022-01-12 23:12:55.824306+00', 'Skyte Neuk', 10037, 3, 4, 32, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (9801, '2015-05-31 09:28:31.081747+00', '2022-01-12 23:13:20.426947+00', 'Fisherman''s Reel', 10037, 1, 5, 32, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (9802, '2015-05-31 09:30:06.964098+00', '2022-01-12 23:14:13.236895+00', 'Campbeltown Loch', 10037, 2, 4, 48, 9999, NULL, 219, 1, '');
INSERT INTO 'recording' VALUES (5717, NULL, '2022-08-31 10:18:24.263769+00', 'Chainwalk, The', 3002, 3, 3, 32, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (5662, NULL, '2022-08-31 11:29:12.728127+00', 'Miller''s Crossing', 3403, 2, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (9836, '2015-08-19 15:09:17.234887+00', '2015-08-19 15:09:17.234887+00', 'Ruby Rant, The', 10659, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9837, '2015-08-19 15:12:30.2217+00', '2015-08-19 15:12:30.2217+00', 'Round and Roundabout (Rundumadum)', 10659, 3, 3, 32, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (9838, '2015-08-19 15:15:44.678298+00', '2015-08-19 15:15:44.678298+00', 'Flora''s Fancy', 10659, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (9839, '2015-08-19 15:19:23.157307+00', '2015-08-19 15:19:23.157307+00', 'Library of Birmingham, The', 10659, 3, 4, 40, 9999, NULL, 316, 0, '');
INSERT INTO 'recording' VALUES (9840, '2015-08-19 15:31:24.623053+00', '2015-08-19 15:31:24.623053+00', 'John Cass', 10659, 2, 5, 32, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (9841, '2015-08-19 15:35:21.175405+00', '2015-08-19 15:35:21.175405+00', 'MacDonald of Keppoch', 10659, 4, 1, 128, 10034, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (9842, '2015-08-19 15:41:18.747942+00', '2015-08-19 15:41:18.747942+00', 'Countess of Dunmore''s Reel, The', 10659, 1, 8, 32, 9999, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (9843, '2015-08-19 15:44:35.112534+00', '2015-08-19 15:44:35.112534+00', 'Ragtime Pipers', 10659, 50, 0, 0, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (9844, '2015-08-19 15:51:01.676829+00', '2015-08-19 15:51:01.676829+00', 'Hooper''s Jig', 10659, 2, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (9845, '2015-08-19 16:05:05.444347+00', '2015-08-19 16:05:05.444347+00', 'British Grenadiers, The', 10659, 1, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (9846, '2015-08-19 16:13:54.694984+00', '2015-08-19 16:13:54.694984+00', 'Bonnie Geordie''s Wig', 10659, 1, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (7319, NULL, '2015-08-27 21:10:03.174603+00', 'Nautical Hornpipes', 10114, 1, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (9847, '2015-08-31 11:33:29.322676+00', '2015-08-31 11:33:29.322676+00', 'Happy Tartan', 11190, 1, 8, 32, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (9848, '2015-08-31 11:36:21.206907+00', '2015-08-31 11:36:21.206907+00', 'White Dragon, The', 11190, 2, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (9849, '2015-08-31 11:38:52.607993+00', '2015-08-31 11:38:52.607993+00', 'St Andrews Sea', 11190, 3, 8, 32, 9999, NULL, 528, 0, '');
INSERT INTO 'recording' VALUES (9850, '2015-08-31 11:41:06.883818+00', '2015-08-31 11:41:06.883818+00', 'Chasing an Elf', 11190, 2, 6, 40, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (9852, '2015-08-31 11:46:11.778939+00', '2015-08-31 11:46:11.778939+00', 'Sakura', 11190, 4, 1, 128, 2, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (9853, '2015-08-31 11:48:55.314424+00', '2015-08-31 11:48:55.314424+00', 'Renaissance Dance, A', 11190, 3, 8, 32, 9999, NULL, 520, 0, '');
INSERT INTO 'recording' VALUES (9854, '2015-08-31 11:50:43.912477+00', '2015-08-31 11:50:43.912477+00', 'Maze in the Mirror, A', 11190, 2, 3, 32, 9999, NULL, 122, 0, '');
INSERT INTO 'recording' VALUES (9856, '2015-08-31 11:56:24.82652+00', '2015-08-31 11:56:24.82652+00', 'Happy Tartan for 5 couples', 11190, 1, 5, 32, 9999, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (9851, '2015-08-31 11:44:34.754632+00', '2015-08-31 12:02:52.17227+00', 'Geometry Class, A', 11190, 3, 3, 32, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (9447, '2014-02-07 08:52:21.044605+00', '2015-09-08 11:24:45.867397+00', 'Timbit for Janis, A', 2339, 3, 4, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (5030, NULL, '2015-09-14 23:15:11.017039+00', 'Hal Robinson''s Rant', 2728, 1, 5, 40, 9999, NULL, 225, 0, '');
INSERT INTO 'recording' VALUES (11, NULL, '2015-09-16 12:19:47.188138+00', 'Back O'' Bennachie, The', 3029, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (902, NULL, '2015-10-05 12:03:53.2547+00', 'Lord McLay''s Reel', 3006, 1, 4, 40, 9999, NULL, 181, 0, '"Lord McLay''s Reel" is usually spelled "Lord MacLay''s Reel", but not on this recording.');
INSERT INTO 'recording' VALUES (9858, '2015-10-08 14:17:33.226459+00', '2015-10-08 14:17:33.226459+00', 'College Hornpipe, The', 3012, 1, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (1706, NULL, '2015-10-08 14:20:56.907967+00', 'Lamb Skinnet', 3012, 2, 4, 32, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (1707, NULL, '2015-10-08 14:22:01.658528+00', 'Shetland Waltz', 3012, 5, 4, 32, 9999, NULL, 159, 0, '');
INSERT INTO 'recording' VALUES (3618, NULL, '2015-10-08 14:35:33.247806+00', 'Schiehallion', 3012, 4, 0, 128, 2, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (4168, NULL, '2015-10-08 14:38:20.361658+00', 'Land of the Prince Bishops', 3012, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (9859, '2015-10-08 14:48:07.642835+00', '2015-10-08 14:48:07.642835+00', 'Trip to Bavaria, A', 3012, 1, 4, 32, 9999, NULL, 137, 0, '');
INSERT INTO 'recording' VALUES (1984, NULL, '2015-10-08 15:35:44.425667+00', 'Strathspeys', 3002, 3, 4, 32, 9999, 5, 262, 0, '');
INSERT INTO 'recording' VALUES (2778, NULL, '2015-10-08 15:48:52.883018+00', 'Airs', 3002, 98, 0, 0, 9999, NULL, 230, 0, 'W');
INSERT INTO 'recording' VALUES (5860, NULL, '2015-11-09 23:49:28.748749+00', 'Midnight Oil', 3032, 2, 5, 48, 9999, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (4465, NULL, '2015-11-15 15:35:51.434922+00', 'Earl of Mansfield, The', 1556, 1, 4, 48, 9999, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (9860, '2016-03-13 00:55:59.265241+00', '2016-03-13 00:55:59.265241+00', 'Anne McArthur', 2944, 3, 3, 32, NULL, 19, 188, 0, '');
INSERT INTO 'recording' VALUES (9824, '2015-06-19 11:41:06.312098+00', '2018-10-14 23:23:58.594824+00', 'Flowers of Edinburgh, The', 10000, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (9855, '2015-08-31 11:53:55.382761+00', '2018-12-02 11:35:20.314512+00', 'El Toreador', 11190, 3, 6, 32, 9999, NULL, 384, 0, '');
INSERT INTO 'recording' VALUES (9832, '2015-08-19 14:45:53.648467+00', '2016-11-02 08:01:53.684011+00', 'Midsummer Common', 10659, 3, 8, 32, 9999, NULL, 501, 0, '');
INSERT INTO 'recording' VALUES (8915, '2012-06-12 16:10:34.200559+00', '2019-01-05 12:31:54.53826+00', 'Galbraith Gold', 3012, 1, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (9890, '2016-09-12 23:03:32.684715+00', '2016-09-12 23:03:32.684715+00', 'There''s Something about Thirty', 11351, 3, 3, 32, NULL, 5, 193, 0, '');
INSERT INTO 'recording' VALUES (9891, '2016-09-12 23:11:51.966716+00', '2016-09-12 23:11:51.966716+00', '192 Miles Home', 11351, 2, 4, 48, NULL, 13, 206, 0, '');
INSERT INTO 'recording' VALUES (9861, '2016-03-13 01:09:41.230567+00', '2016-03-13 10:58:07.60636+00', 'Jollity', 2944, 2, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (9863, '2016-03-13 09:39:31.267124+00', '2018-10-14 23:25:15.286285+00', 'Falls of Feugh, The', 2944, 1, 3, 32, NULL, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (9892, '2016-09-12 23:15:03.756481+00', '2016-09-12 23:15:03.756481+00', 'Doonhamer Delight, The', 11351, 1, 6, 32, NULL, 21, 210, 0, '');
INSERT INTO 'recording' VALUES (9865, '2016-03-13 09:55:58.570636+00', '2016-03-13 11:00:33.470651+00', 'Welcome to Nerja', 2944, 2, 5, 48, NULL, NULL, 261, 0, '');
INSERT INTO 'recording' VALUES (9876, '2016-08-12 17:30:43.743423+00', '2019-03-24 21:04:25.487395+00', 'Russe, La', 10034, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (9867, '2016-03-13 10:00:54.043818+00', '2016-03-13 11:01:26.953794+00', 'Mrs Ruth Housden', 2944, 1, 4, 40, NULL, NULL, 179, 1, '');
INSERT INTO 'recording' VALUES (9868, '2016-03-13 10:02:47.875781+00', '2016-03-13 11:01:50.52744+00', 'Tullynessle & Forbes Hall', 2944, 3, 3, 32, NULL, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (9866, '2016-03-13 09:58:15.88413+00', '2018-12-07 17:28:39.460315+00', 'Toast to Aberdeen, A', 2944, 3, 3, 32, NULL, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (3441, NULL, '2016-03-17 13:57:55.484713+00', 'Culla Bay', 2236, 3, 4, 32, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (2949, NULL, '2016-05-11 00:43:51.866061+00', 'Jig Medley', 2328, 2, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3143, NULL, '2016-05-11 01:31:28.831091+00', 'Garple Burn, The', 2067, 1, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (2525, NULL, '2016-05-13 13:55:52.288281+00', 'Pinewoods Reel', 2066, 1, 8, 32, 9999, 1, 275, 0, '');
INSERT INTO 'recording' VALUES (9864, '2016-03-13 09:42:13.13192+00', '2016-05-18 00:37:30.642989+00', 'Amazing Grace Strathspey', 2944, 3, 4, 32, NULL, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (9869, '2016-03-13 10:51:10.85382+00', '2018-10-14 23:25:45.979953+00', 'Sunnyside, The', 2944, 2, 8, 32, NULL, NULL, 276, 0, 'Tune 6 is listed on the CD cover as Rock Valley (Traditional) but appears to match Rock Valley Jig (Burt)');
INSERT INTO 'recording' VALUES (6958, NULL, '2016-05-18 08:14:13.423903+00', 'Can You Repeat That', 3023, 3, 3, 40, NULL, NULL, 239, 0, '');
INSERT INTO 'recording' VALUES (2499, NULL, '2016-05-25 14:30:52.708785+00', 'Robertson Rant, The', 883, 3, 0, 80, 9999, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (242, NULL, '2016-05-29 20:48:27.348744+00', 'Bonnie Stronshiray', 3048, 3, 8, 32, 9999, 5, 529, 0, '');
INSERT INTO 'recording' VALUES (89, NULL, '2016-05-29 21:13:55.567641+00', 'Lady Susan Stewart''s Reel', 3048, 1, 8, 32, 9999, 5, 282, 0, '');
INSERT INTO 'recording' VALUES (8311, NULL, '2016-07-26 12:52:52.037297+00', 'Hamilton House', 10659, 2, 10, 32, NULL, NULL, 334, 0, '');
INSERT INTO 'recording' VALUES (9875, '2016-08-12 17:24:55.217454+00', '2016-08-12 17:24:55.217454+00', 'Banks of Allen', 10034, 2, 8, 32, NULL, 1, 283, 0, '');
INSERT INTO 'recording' VALUES (9879, '2016-08-12 17:47:11.887276+00', '2016-08-12 17:47:11.887276+00', 'Two-Step', 10034, 99, 1, 128, NULL, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (9880, '2016-08-12 17:50:39.206316+00', '2016-08-12 17:50:39.206316+00', 'Countess of Lauderdale''s Reel', 10034, 1, 8, 40, NULL, 1, 356, 0, '');
INSERT INTO 'recording' VALUES (9882, '2016-08-12 18:11:19.348294+00', '2016-08-12 18:11:19.348294+00', 'McLachlan''s Reel', 10034, 3, 8, 32, NULL, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (9883, '2016-08-12 18:13:59.332523+00', '2016-08-12 18:13:59.332523+00', 'Prince Edward', 10034, 1, 8, 40, NULL, NULL, 346, 0, '');
INSERT INTO 'recording' VALUES (9887, '2016-08-12 18:26:47.851438+00', '2016-08-12 18:26:47.851438+00', 'Set of Waltzes for Warm Up or Cool Down', 10034, 5, 4, 32, NULL, NULL, 226, 0, '');
INSERT INTO 'recording' VALUES (9804, '2015-05-31 09:32:14.581353+00', '2022-01-12 23:15:10.553073+00', 'Australian Ladies, The', 10037, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (9805, '2015-05-31 09:33:18.370059+00', '2022-01-12 23:15:50.147045+00', 'Bees of Maggieknockater, The', 10037, 2, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (9806, '2015-05-31 09:34:15.661682+00', '2022-01-12 23:16:35.803922+00', 'Belle of Bon Accord, The', 10037, 3, 4, 32, 9999, NULL, 248, 0, '');
INSERT INTO 'recording' VALUES (9807, '2015-05-31 09:35:19.909202+00', '2022-01-12 23:17:07.753173+00', 'Montgomeries'' Rant, The', 10037, 1, 8, 32, 9999, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (427, NULL, '2022-02-25 18:51:43.964885+00', 'Joe MacDiarmid''s Jig', 3026, 2, 4, 32, 9999, 1, 139, 0, '');
INSERT INTO 'recording' VALUES (9884, '2016-08-12 18:16:29.97301+00', '2022-12-10 18:05:39.457507+00', 'Polka', 10034, 13, 4, 32, NULL, NULL, 122, 0, '');
INSERT INTO 'recording' VALUES (9886, '2016-08-12 18:21:40.956023+00', '2022-12-10 18:17:35.644738+00', 'Clydeside Lassies', 10034, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (9877, '2016-08-12 17:37:52.225566+00', '2022-12-10 18:47:02.761745+00', 'Miss Corbett''s Strathspey', 10034, 3, 8, 32, NULL, 5, 507, 0, '');
INSERT INTO 'recording' VALUES (9878, '2016-08-12 17:43:12.879744+00', '2022-12-10 18:48:40.405162+00', 'Ha! Ha! The Wooin'' o'' It', 10034, 1, 8, 32, NULL, 5, 281, 0, '');
INSERT INTO 'recording' VALUES (8940, '2012-12-25 22:48:33.510077+00', '2016-09-03 20:43:58.550431+00', 'College Hornpipe', 3658, 1, 2, 32, 9999, NULL, 78, 0, '');
INSERT INTO 'recording' VALUES (6122, NULL, '2016-09-03 22:28:43.346498+00', 'Pulling Bracken', 3217, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (5217, NULL, '2016-09-04 13:56:56.722269+00', 'Duthie Park', 2944, 2, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (4974, NULL, '2016-09-04 14:00:40.397296+00', 'Leith Country Dance', 2696, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (6692, NULL, '2016-09-04 15:27:40.747735+00', 'Jimmy''s Fancy', 10037, 3, 8, 32, NULL, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (5696, NULL, '2016-09-04 15:35:10.725555+00', 'Slow Air Strathspeys', 3418, 3, 4, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (9889, '2016-09-12 22:56:17.801092+00', '2016-09-12 22:56:17.801092+00', 'Remparts de Séville, Les', 11351, 2, 8, 32, NULL, 1, 275, 0, '');
INSERT INTO 'recording' VALUES (9893, '2016-09-12 23:16:58.111352+00', '2016-09-12 23:16:58.111352+00', 'Continental Waltz', 11351, 98, 1, 128, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (9894, '2016-09-12 23:19:56.339334+00', '2016-09-12 23:19:56.339334+00', 'Mathilde is a Delight', 11351, 3, 3, 32, NULL, 21, 190, 0, '');
INSERT INTO 'recording' VALUES (9895, '2016-09-12 23:22:28.879809+00', '2016-09-12 23:22:28.879809+00', 'Wandering Wallaby, The', 11351, 2, 4, 32, NULL, 21, 140, 0, '');
INSERT INTO 'recording' VALUES (9896, '2016-09-12 23:28:29.849212+00', '2016-09-12 23:28:29.849212+00', 'Double Trouble Triangles', 11351, 1, 4, 48, NULL, 11, 210, 0, '');
INSERT INTO 'recording' VALUES (9898, '2016-09-12 23:33:07.207164+00', '2016-09-12 23:33:07.207164+00', 'Polka', 11351, 98, 1, 128, NULL, NULL, 129, 0, '');
INSERT INTO 'recording' VALUES (9899, '2016-09-12 23:35:31.296294+00', '2016-09-12 23:35:31.296294+00', 'Trip to Applecross, A', 11351, 1, 6, 32, NULL, 1, 190, 0, '');
INSERT INTO 'recording' VALUES (9900, '2016-09-12 23:39:13.588927+00', '2016-09-12 23:39:13.588927+00', 'Dancing Spirit', 11351, 2, 8, 32, NULL, 21, 275, 0, '');
INSERT INTO 'recording' VALUES (9901, '2016-09-12 23:42:12.363932+00', '2016-09-12 23:42:12.363932+00', 'Baratte Your Way Home, La', 11351, 1, 4, 40, NULL, 39, 176, 0, '');
INSERT INTO 'recording' VALUES (9903, '2016-09-12 23:49:30.922741+00', '2016-09-12 23:49:30.922741+00', 'Retreat March Medley', 11351, 98, 1, 162, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (9907, '2016-10-03 23:34:23.21574+00', '2016-10-03 23:34:23.21574+00', 'Ice on the Lake', 11376, 5, 0, 0, NULL, NULL, 234, 0, '');
INSERT INTO 'recording' VALUES (2893, NULL, '2018-07-31 13:30:34.685307+00', 'Summer in Assynt', 1701, 3, 4, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (9911, '2016-10-03 23:46:02.839135+00', '2016-10-03 23:46:02.839135+00', 'Sweet Garden', 11376, 5, 0, 0, NULL, NULL, 231, 0, '');
INSERT INTO 'recording' VALUES (9904, '2016-10-03 23:27:24.699495+00', '2016-11-07 01:06:17.874233+00', 'On the Wings of a Skorie', 11376, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (9870, '2016-07-04 08:48:33.331016+00', '2017-02-03 17:22:35.52908+00', 'Maxwell''s Rant', 3057, 1, 6, 32, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (5722, NULL, '2016-12-15 00:17:47.587744+00', 'Double Diamond Strathspey, The', 3002, 3, 4, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (9871, '2016-07-04 09:01:27.339473+00', '2017-02-03 17:52:37.104022+00', 'Berwick Johnnie', 3057, 2, 8, 32, 9999, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (9872, '2016-07-04 09:03:35.155676+00', '2017-02-03 18:05:19.69092+00', 'Eva Three Step', 3057, 50, 0, 16, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (9873, '2016-07-04 09:06:47.284489+00', '2017-02-03 18:07:41.422207+00', 'Reel Of Glamis', 3057, 1, 6, 32, 9999, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (9874, '2016-07-04 09:08:50.864089+00', '2017-02-03 18:14:53.919694+00', 'Express, The', 3057, 2, 4, 40, NULL, NULL, 169, 0, 'Number of repetitions may be wrong.');
INSERT INTO 'recording' VALUES (921, NULL, '2017-03-09 16:28:01.482979+00', 'Two of the Best', 3014, 2, 0, 96, 9999, 1, 104, 0, '');
INSERT INTO 'recording' VALUES (950, NULL, '2017-03-09 16:29:01.245182+00', 'Shene Gate', 3014, 2, 4, 32, 9999, 1, 138, 0, '');
INSERT INTO 'recording' VALUES (9905, '2016-10-03 23:29:59.169769+00', '2017-06-05 07:39:56.646349+00', 'Couple of Keepers, A', 11376, 3, 3, 32, NULL, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (9906, '2016-10-03 23:32:47.256172+00', '2017-06-05 07:40:53.431826+00', 'Jig is Up, The', 11376, 2, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (9908, '2016-10-03 23:37:31.875924+00', '2017-06-05 08:53:47.54017+00', 'Excited States', 11376, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (9881, '2016-08-12 18:05:11.415225+00', '2017-12-19 02:23:21.524398+00', 'Honeymoon, The', 10034, 2, 8, 32, NULL, 5, 281, 0, '');
INSERT INTO 'recording' VALUES (9912, '2016-10-03 23:49:34.118665+00', '2016-10-03 23:49:34.118665+00', 'City of Belfast', 11376, 3, 6, 32, NULL, NULL, 395, 0, '');
INSERT INTO 'recording' VALUES (9945, '2016-10-30 23:11:24.368607+00', '2018-10-14 23:26:39.860876+00', 'Alpine Strathspey, The', 3013, 3, 3, 32, NULL, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (9915, '2016-10-03 23:57:15.081352+00', '2017-06-05 09:03:09.672657+00', 'Dancin'' in the Rain', 11376, 3, 4, 32, NULL, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (2829, NULL, '2017-02-03 17:33:07.043348+00', 'Dunoon Barn Dance', 3057, 50, 0, 16, 9999, NULL, 216, 0, 'The download info "All Celtic Music" give these tunes:

Major David MacQueen and Captain McNeil');
INSERT INTO 'recording' VALUES (2899, NULL, '2018-07-31 13:37:32.041435+00', 'Two Bonnie Lads', 1701, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (9914, '2016-10-03 23:55:27.421823+00', '2016-10-04 00:07:50.988575+00', 'Chased Lovers', 11376, 2, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (9909, '2016-10-03 23:40:26.57556+00', '2016-10-04 00:08:59.364183+00', 'Linnea''s Strathspey', 11376, 3, 8, 32, NULL, NULL, 512, 0, '');
INSERT INTO 'recording' VALUES (9916, '2016-10-04 00:01:43.485214+00', '2016-10-07 10:45:01.97097+00', 'Kristi''s Conundrum', 11376, 2, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (9950, '2016-10-30 23:42:28.824679+00', '2016-10-30 23:42:28.824679+00', 'Freedom Reel, The', 3013, 1, 4, 48, NULL, NULL, 228, 0, '');
INSERT INTO 'recording' VALUES (9944, '2016-10-30 23:08:07.029865+00', '2016-10-31 17:37:08.525541+00', 'One for Cabarfeidh', 3013, 1, 4, 32, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (9942, '2016-10-30 23:04:15.084089+00', '2018-10-14 23:26:14.456121+00', 'Spirit of Mortlach, The', 3013, 2, 4, 48, NULL, NULL, 218, 0, '');
INSERT INTO 'recording' VALUES (9400, '2013-12-19 17:24:05.784912+00', '2016-11-06 00:54:19.532829+00', 'Perth Meets Perth', 3217, 1, 4, 32, 9999, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (10171, '2018-03-30 09:10:07.340575+00', '2018-10-25 21:43:26.620072+00', 'Swans Of Atlanta', 11613, 4, 2, 64, 5, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (9922, '2016-10-09 00:02:31.66031+00', '2016-11-17 16:15:30.027661+00', 'Marja''s Buns', 3217, 4, 1, 96, 11, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (855, NULL, '2018-11-08 12:17:21.665058+00', 'Wind that Shakes the Barley, The', 3047, 1, 8, 32, 9999, 5, 285, 0, '');
INSERT INTO 'recording' VALUES (9919, '2016-10-08 23:42:44.475909+00', '2016-10-17 14:18:29.36101+00', 'Tiaras & Teapots', 3217, 2, 8, 40, 9999, NULL, 348, 0, '');
INSERT INTO 'recording' VALUES (9920, '2016-10-08 23:50:52.51445+00', '2016-10-17 14:19:09.365492+00', 'Musical Page, The / Calm Before Storm', 3217, 3, 8, 32, 9999, NULL, 484, 0, '');
INSERT INTO 'recording' VALUES (9921, '2016-10-08 23:56:51.692352+00', '2016-10-17 14:19:58.012707+00', 'Courtship, The', 3217, 1, 8, 40, 9999, NULL, 348, 0, '');
INSERT INTO 'recording' VALUES (9967, '2017-02-12 12:15:35.395759+00', '2017-02-12 12:15:35.395759+00', 'Flowers of Edinburgh', 10034, 1, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (9923, '2016-10-09 00:06:03.208381+00', '2016-10-17 14:20:43.116688+00', 'Sunshine in Lagos', 3217, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (9924, '2016-10-09 00:10:37.403539+00', '2016-10-17 14:20:56.077485+00', 'Pat George''s Strathspey', 3217, 3, 5, 32, 9999, NULL, 303, 0, '');
INSERT INTO 'recording' VALUES (9925, '2016-10-09 00:19:31.191762+00', '2016-10-17 14:21:13.195326+00', 'Newark Castle', 3217, 2, 4, 48, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (9926, '2016-10-09 00:23:58.166202+00', '2016-10-17 14:21:23.310469+00', 'Pirongia', 3217, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (9927, '2016-10-09 00:28:59.054451+00', '2016-10-17 14:21:32.872502+00', 'Chriss Cross', 3217, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (9928, '2016-10-09 00:35:43.234227+00', '2016-10-17 14:21:44.126795+00', 'Festival Dream', 3217, 3, 1, 64, NULL, NULL, 122, 0, '');
INSERT INTO 'recording' VALUES (9930, '2016-10-09 01:49:13.836784+00', '2016-10-17 14:22:09.66023+00', 'Tipsy Vicar, The', 3217, 2, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (9931, '2016-10-09 02:04:25.773769+00', '2016-10-17 14:22:27.76177+00', 'Broadway', 3217, 3, 3, 32, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (9932, '2016-10-09 02:11:37.920341+00', '2016-10-17 14:22:39.301356+00', 'Merry St Andrews', 3217, 2, 8, 40, 9999, NULL, 346, 0, '');
INSERT INTO 'recording' VALUES (9933, '2016-10-09 02:14:56.975509+00', '2016-10-17 14:22:49.432765+00', 'Staircase in Styria', 3217, 1, 5, 40, 9999, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (9935, '2016-10-09 02:21:01.624923+00', '2016-10-17 14:23:09.277603+00', 'Auld Lang Syne', 11397, 98, 0, 0, 9999, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (9936, '2016-10-30 21:35:12.866548+00', '2016-10-30 21:35:12.866548+00', 'Freedom Reel, The', 3013, 1, 4, 48, NULL, NULL, 224, 0, '');
INSERT INTO 'recording' VALUES (9937, '2016-10-30 21:51:26.721817+00', '2016-10-30 21:51:26.721817+00', 'Jenny''s Strathspey', 3013, 3, 3, 32, NULL, NULL, 217, 0, '');
INSERT INTO 'recording' VALUES (9938, '2016-10-30 22:22:18.468415+00', '2016-10-30 22:22:18.468415+00', 'Fingal''s Cave, The Storm', 3013, 1, 4, 48, NULL, NULL, 225, 0, '');
INSERT INTO 'recording' VALUES (9939, '2016-10-30 22:27:44.513744+00', '2016-10-30 22:27:44.513744+00', 'Buchanan Street Strathspey', 3013, 3, 3, 32, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (9941, '2016-10-30 22:53:08.317933+00', '2016-10-30 22:53:08.317933+00', 'Fingal''s Cave', 3013, 3, 3, 32, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (9943, '2016-10-30 23:06:01.756446+00', '2016-10-30 23:06:01.756446+00', 'Princes Street Strathspey', 3013, 3, 3, 32, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (9946, '2016-10-30 23:14:49.026973+00', '2016-10-30 23:14:49.026973+00', 'Fraser Cailean Donaldson', 3013, 1, 4, 40, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (9947, '2016-10-30 23:20:21.626879+00', '2016-10-30 23:20:21.626879+00', 'Union Street Strathspey', 3013, 3, 3, 32, NULL, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (9948, '2016-10-30 23:22:46.561469+00', '2016-10-30 23:22:46.561469+00', 'Spinning Jenny', 3013, 1, 4, 48, NULL, NULL, 224, 0, '');
INSERT INTO 'recording' VALUES (9949, '2016-10-30 23:23:41.538297+00', '2016-10-30 23:25:25.721379+00', 'Strathspey for Kenny Thomson', 3013, 3, 3, 32, NULL, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (9897, '2016-09-12 23:31:47.252597+00', '2022-10-30 10:40:02.587758+00', 'Shadow', 11351, 2, 3, 32, NULL, 1, 106, 0, '');
INSERT INTO 'recording' VALUES (4690, NULL, '2022-09-01 15:12:52.870346+00', 'Mr Robert H. MacKay', 2586, 3, 8, 32, 9999, NULL, 514, 0, '');
INSERT INTO 'recording' VALUES (9910, '2016-10-03 23:43:34.419632+00', '2022-12-22 13:50:41.626531+00', 'Those Eyes', 11376, 2, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (9934, '2016-10-09 02:18:09.753836+00', '2022-12-25 21:37:00.432076+00', 'Polka', 3217, 13, 0, 0, 9999, NULL, 38, 0, '');
INSERT INTO 'recording' VALUES (9913, '2016-10-03 23:50:42.306068+00', '2017-12-19 00:08:03.947494+00', 'On the Boardwalk', 11376, 1, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (5109, NULL, '2020-03-31 00:03:49.923777+00', 'Thornhill Strathspey, The', 3002, 3, 3, 32, 9999, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (726, NULL, '2021-01-06 00:16:47.868601+00', 'Lanes of Au, The', 3022, 1, 3, 32, 9999, 5, 108, 0, '');
INSERT INTO 'recording' VALUES (2659, NULL, '2016-11-27 17:26:49.342406+00', 'Tipsy O''er the Glen', 2042, 3, 8, 32, 9999, NULL, 485, 0, '');
INSERT INTO 'recording' VALUES (9952, '2016-12-14 22:18:16.793454+00', '2016-12-14 22:18:16.793454+00', 'Winter Wonderland', 3045, 3, 3, 48, NULL, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (9953, '2016-12-14 22:21:56.421512+00', '2016-12-14 22:21:56.421512+00', 'Pantomime Horse', 3045, 2, 5, 32, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (9954, '2016-12-14 22:28:31.811462+00', '2016-12-14 22:28:31.811462+00', 'Silver Bells', 3045, 1, 4, 64, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (9955, '2016-12-14 22:33:22.13705+00', '2016-12-14 22:33:22.13705+00', 'Merry Little Christmas, A', 3045, 3, 4, 32, NULL, NULL, 247, 0, '');
INSERT INTO 'recording' VALUES (9956, '2016-12-14 22:37:36.422574+00', '2016-12-14 22:37:36.422574+00', 'Snowmen''s Dance, The', 3045, 2, 4, 40, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (9957, '2016-12-14 22:42:02.285795+00', '2016-12-14 22:42:02.285795+00', 'Jolly Old St. Nicholas', 3045, 1, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (9959, '2016-12-14 22:53:45.468225+00', '2016-12-14 22:53:45.468225+00', 'Hippopotamus for Christmas, A', 3045, 2, 4, 48, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (9960, '2016-12-14 23:00:06.891203+00', '2016-12-14 23:00:06.891203+00', 'See Amid the Winter''s Snow', 3045, 3, 4, 40, NULL, NULL, 308, 0, '');
INSERT INTO 'recording' VALUES (9961, '2016-12-14 23:04:52.546149+00', '2016-12-14 23:04:52.546149+00', 'Wonderful Christmas Time', 3045, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (9962, '2016-12-14 23:10:51.975436+00', '2016-12-14 23:10:51.975436+00', 'Jingle Bell Rock', 3045, 3, 5, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9964, '2016-12-14 23:17:38.450636+00', '2016-12-14 23:18:14.016913+00', 'Frosty The Snowman', 3045, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9965, '2016-12-14 23:20:05.884438+00', '2016-12-14 23:20:05.884438+00', 'We Wish You A Merry Christmas', 3045, 5, 0, 0, NULL, NULL, 235, 0, '');
INSERT INTO 'recording' VALUES (6643, NULL, '2017-10-28 00:24:41.861542+00', 'Callum Dewar''s Reel', 3023, 1, 4, 40, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (9968, '2017-02-12 12:18:23.424062+00', '2017-02-12 12:18:23.424062+00', 'Capital Jig, A', 10034, 2, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (9970, '2017-02-12 12:22:55.674565+00', '2017-02-12 12:22:55.674565+00', 'Triumph, The', 10034, 1, 4, 24, NULL, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (9971, '2017-02-12 12:24:49.73087+00', '2017-02-12 12:24:49.73087+00', 'Diamond Jubilee, The', 10034, 2, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (9972, '2017-02-12 12:36:05.979875+00', '2017-02-12 12:36:05.979875+00', 'Birks of Invermay, The', 10034, 3, 8, 32, NULL, NULL, 497, 0, '');
INSERT INTO 'recording' VALUES (9973, '2017-02-12 12:39:24.69046+00', '2017-02-12 12:39:24.69046+00', 'Music Makars, The', 10034, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (9974, '2017-02-12 13:08:38.177273+00', '2017-02-12 13:16:44.866021+00', 'Quarrie''s Jig', 10034, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9976, '2017-02-12 13:30:31.033001+00', '2017-02-12 13:30:31.033001+00', 'Swiss Lassie', 10034, 1, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (9977, '2017-02-12 13:37:20.349908+00', '2017-02-12 13:37:59.02591+00', 'Gothenburg''s Welcome', 10034, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9978, '2017-02-12 13:40:09.075509+00', '2017-02-12 13:40:09.075509+00', 'Alltshellach', 10034, 3, 8, 32, NULL, NULL, 490, 0, '');
INSERT INTO 'recording' VALUES (9979, '2017-02-12 13:45:35.874344+00', '2017-02-12 13:45:35.874344+00', 'College Hornpipe, The', 10034, 1, 8, 32, NULL, 5, 284, 0, '');
INSERT INTO 'recording' VALUES (9981, '2017-02-12 13:50:50.670141+00', '2017-02-12 13:50:50.670141+00', 'Flower of Glasgow, The', 10034, 3, 3, 32, NULL, 5, 190, 0, '');
INSERT INTO 'recording' VALUES (10031, '2017-06-28 14:06:26.835573+00', '2018-06-09 00:37:14.410471+00', 'SandBJ', 2586, 3, 3, 32, NULL, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (9992, '2017-02-13 11:51:46.566472+00', '2017-03-07 16:23:45.907667+00', 'Platinum Skies', 3217, 1, 8, 32, 9999, NULL, 301, 0, '');
INSERT INTO 'recording' VALUES (9990, '2017-02-13 11:41:02.520688+00', '2017-03-07 16:53:02.618107+00', 'Glint in the Eye, A', 3217, 2, 4, 32, 9999, NULL, 157, 1, '');
INSERT INTO 'recording' VALUES (10032, '2017-06-28 14:10:10.726743+00', '2018-06-09 00:47:46.955165+00', 'Prince Edward Assembly', 2586, 1, 1, 88, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (5497, NULL, '2017-03-10 21:07:55.500373+00', 'Airie Bennan', 3023, 2, 5, 32, 9999, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (7170, NULL, '2017-03-13 20:03:34.920262+00', 'Bratach Bana', 3019, 1, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (10033, '2017-06-28 14:12:31.771177+00', '2018-06-09 00:55:29.426797+00', 'Spark O'' Water / Sharon''s Strathspey', 2586, 3, 6, 32, NULL, NULL, 414, 0, '');
INSERT INTO 'recording' VALUES (10034, '2017-06-28 14:13:46.348946+00', '2018-06-09 01:05:30.296031+00', 'Spice It Up', 2586, 2, 3, 32, NULL, NULL, 120, 0, '');
INSERT INTO 'recording' VALUES (9983, '2017-02-13 11:01:42.254141+00', '2017-02-13 17:05:22.269532+00', 'Young at Heart', 3217, 2, 8, 32, 9999, NULL, 298, 0, '');
INSERT INTO 'recording' VALUES (10035, '2017-06-28 14:15:45.531484+00', '2018-06-09 21:13:43.88238+00', 'Jim MacLellan''s Strathspey / Sailing Days On The Penobscut', 2586, 3, 4, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (9985, '2017-02-13 11:12:43.124157+00', '2017-02-13 17:05:58.579299+00', 'Farewell to Portrush', 3217, 2, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (9986, '2017-02-13 11:14:41.034084+00', '2017-02-13 17:08:54.371373+00', 'Wardrobe, The', 3217, 1, 8, 32, 9999, NULL, 299, 0, '');
INSERT INTO 'recording' VALUES (9987, '2017-02-13 11:21:10.076939+00', '2017-02-13 17:10:05.767179+00', 'Set in Roosendaal', 3217, 4, 1, 128, 13, 8, 207, 0, 'The recording is a medley with S2x32+J2x32.');
INSERT INTO 'recording' VALUES (9988, '2017-02-13 11:25:40.397312+00', '2017-02-13 17:10:50.344932+00', 'Rainbow''s End', 3217, 1, 8, 32, 9999, NULL, 303, 0, '');
INSERT INTO 'recording' VALUES (9993, '2017-02-13 12:03:15.7132+00', '2017-11-05 10:53:50.761064+00', 'Comber Car Park', 3217, 3, 3, 32, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (10018, '2017-05-19 09:17:11.653135+00', '2017-05-22 14:06:13.885762+00', 'Davy Nick Nack', 11484, 1, 8, 32, NULL, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (10036, '2017-06-28 14:17:13.299777+00', '2018-06-09 21:19:46.059807+00', 'Olive''s Return To Old Scotia', 2586, 1, 4, 32, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (9994, '2017-02-13 12:08:18.538579+00', '2017-02-13 17:13:38.041579+00', 'Bunker Hill', 3217, 2, 4, 48, 9999, NULL, 228, 0, '');
INSERT INTO 'recording' VALUES (9995, '2017-02-13 14:21:50.835553+00', '2017-02-13 17:14:09.972345+00', 'Lonely Honeybee, The', 3217, 1, 8, 32, 9999, NULL, 304, 0, '');
INSERT INTO 'recording' VALUES (9996, '2017-02-13 14:24:17.070348+00', '2017-02-13 17:14:37.208648+00', 'Humours of California', 3217, 3, 8, 32, 9999, NULL, 469, 0, '');
INSERT INTO 'recording' VALUES (9997, '2017-02-13 14:26:25.382648+00', '2017-02-13 17:15:14.396474+00', 'Love Life to the Max', 3217, 5, 4, 32, 9999, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (8351, NULL, '2017-02-14 16:51:43.970295+00', 'Curleywee', 3023, 3, 4, 32, 9999, NULL, 260, 0, 'Differently to what one would expect from the dance, the recording is indeed only 4 times through instead of 8 times.');
INSERT INTO 'recording' VALUES (1145, NULL, '2017-02-25 13:14:47.102368+00', 'Bobby Brown''s Canadian Breakdown', 3067, 1, 4, 32, 9999, 1, 143, 1, '');
INSERT INTO 'recording' VALUES (2154, NULL, '2017-02-25 17:19:30.373723+00', 'Trip to Bavaria, A', 2058, 1, 4, 32, 9999, 1, 134, 0, '');
INSERT INTO 'recording' VALUES (9998, '2017-03-01 23:13:23.402109+00', '2017-03-01 23:13:23.402109+00', 'Shiftin'' Bobbins', 10000, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (10037, '2017-06-28 14:19:55.610114+00', '2018-06-09 21:54:23.081655+00', 'Wedding Medley', 2586, 4, 4, 32, 1, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (10000, '2017-03-01 23:23:56.071922+00', '2017-03-01 23:23:56.071922+00', 'Byron Strathspey, The', 10000, 3, 3, 32, NULL, 5, 201, 0, '');
INSERT INTO 'recording' VALUES (9999, '2017-03-01 23:22:14.860851+00', '2017-03-01 23:25:58.641605+00', 'Best Set in the Hall', 10000, 2, 8, 32, NULL, 1, 285, 0, '');
INSERT INTO 'recording' VALUES (10038, '2017-06-28 14:21:07.854447+00', '2018-06-09 22:09:59.613362+00', 'V and J''s Maggot', 2586, 2, 6, 32, NULL, NULL, 228, 0, '');
INSERT INTO 'recording' VALUES (7160, NULL, '2017-03-13 20:35:14.566554+00', 'Polharrow Burn', 3019, 1, 5, 32, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (10001, '2017-03-01 23:30:09.527978+00', '2017-03-01 23:38:04.14136+00', 'Meeting of the Waters, The', 10000, 1, 8, 48, NULL, 19, 413, 0, '');
INSERT INTO 'recording' VALUES (10003, '2017-03-01 23:39:51.07682+00', '2017-03-01 23:39:51.07682+00', 'Minister on the Loch, The', 10000, 3, 3, 32, NULL, 5, 202, 0, '');
INSERT INTO 'recording' VALUES (10002, '2017-03-01 23:35:28.617413+00', '2017-03-01 23:46:18.787738+00', 'Mrs Stewart''s Jig', 10000, 2, 8, 32, NULL, 21, 281, 0, '');
INSERT INTO 'recording' VALUES (10005, '2017-03-01 23:52:09.158765+00', '2017-03-01 23:52:09.158765+00', 'Ten Minutes Ago', 10000, 5, 0, 0, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (10040, '2017-06-28 14:24:36.15974+00', '2018-06-09 22:38:56.443421+00', 'Mayflower, The', 2586, 1, 5, 32, NULL, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (10041, '2017-06-28 14:26:18.201566+00', '2018-06-09 22:56:57.000631+00', 'Leaving Portree', 2586, 2, 4, 40, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (10007, '2017-03-02 00:01:24.880442+00', '2017-03-02 00:04:29.027163+00', 'Christine M. Phillips', 10000, 2, 8, 32, NULL, 1, 288, 0, '');
INSERT INTO 'recording' VALUES (10009, '2017-03-02 00:07:45.436145+00', '2017-03-02 00:07:45.436145+00', 'Gentleman, The', 10000, 3, 8, 32, NULL, 5, 508, 0, '');
INSERT INTO 'recording' VALUES (10042, '2017-06-28 14:29:58.226109+00', '2018-06-09 23:12:55.080766+00', 'Royal Wedding / Wisp of Thistle, The', 2586, 3, 8, 32, 9999, NULL, 540, 0, '');
INSERT INTO 'recording' VALUES (9980, '2017-02-12 13:48:03.749619+00', '2020-02-25 20:09:47.519656+00', 'Links with St Petersburg', 10034, 2, 8, 32, NULL, 1, 281, 0, '');
INSERT INTO 'recording' VALUES (9951, '2016-12-14 22:14:51.607966+00', '2021-02-20 21:36:12.418455+00', 'Santa Claus is Coming To Town', 3045, 1, 8, 40, NULL, NULL, 352, 0, '');
INSERT INTO 'recording' VALUES (9975, '2017-02-12 13:26:22.086073+00', '2022-05-03 17:22:54.732781+00', 'Cherrybank Gardens', 10034, 3, 3, 32, NULL, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (9969, '2017-02-12 12:20:23.633991+00', '2022-06-13 16:28:38.261386+00', 'Chasing the Eclipse', 10034, 3, 3, 32, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (9958, '2016-12-14 22:48:04.838461+00', '2022-09-01 11:33:01.957073+00', 'White Christmas', 3045, 3, 8, 32, NULL, NULL, 489, 0, '');
INSERT INTO 'recording' VALUES (10039, '2017-06-28 14:22:59.862777+00', '2022-08-31 22:05:57.6655+00', 'Three Fathom Harbour', 2586, 3, 8, 32, 9999, NULL, 532, 0, '');
INSERT INTO 'recording' VALUES (10008, '2017-03-02 00:05:36.162868+00', '2023-01-08 19:04:49.071751+00', 'Reel of the 51st Division, The', 10000, 1, 8, 32, NULL, 1, 294, 0, '');
INSERT INTO 'recording' VALUES (10004, '2017-03-01 23:44:47.073372+00', '2023-01-12 21:44:53.003105+00', 'Montgomeries'' Rant, The', 10000, 1, 8, 32, NULL, 5, 277, 0, '');
INSERT INTO 'recording' VALUES (9989, '2017-02-13 11:28:48.708906+00', '2021-09-04 09:57:10.071216+00', 'Orchards of Armagh, The', 3217, 3, 3, 32, 9999, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (9982, '2017-02-12 13:53:37.962689+00', '2021-08-22 10:28:17.968071+00', 'Red House', 10034, 1, 8, 40, NULL, 31, 342, 0, '');
INSERT INTO 'recording' VALUES (10011, '2017-03-02 00:29:44.463952+00', '2017-03-02 00:29:44.463952+00', 'Mairi''s Wedding', 10000, 1, 8, 40, NULL, 6, 357, 0, '');
INSERT INTO 'recording' VALUES (10012, '2017-03-02 00:31:50.343773+00', '2017-03-02 00:31:50.343773+00', 'Hunting Horn, The', 10000, 2, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (10013, '2017-03-02 00:35:43.811597+00', '2017-03-02 00:35:43.811597+00', 'City of Belfast', 10000, 3, 3, 32, NULL, 5, 205, 0, '');
INSERT INTO 'recording' VALUES (10014, '2017-03-02 00:48:11.946113+00', '2017-03-02 00:48:41.203522+00', 'Magic of Summer School, The/Fireworks Reel, The/Magic of Merrill, The', 10000, 1, 8, 32, NULL, 5, 289, 0, '');
INSERT INTO 'recording' VALUES (10028, '2017-05-19 16:57:38.659181+00', '2019-06-14 10:22:42.888386+00', 'My Love is Not Here', 11484, 5, 5, 32, NULL, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (7774, NULL, '2017-03-24 16:06:42.356056+00', 'Red House', 3006, 1, 8, 40, NULL, 39, 349, 0, '');
INSERT INTO 'recording' VALUES (10044, '2017-06-28 14:32:33.951231+00', '2018-06-09 23:20:40.147084+00', 'Rossington Strathspey, The', 2586, 3, 3, 32, 9999, NULL, 222, 0, '');
INSERT INTO 'recording' VALUES (8516, NULL, '2017-06-17 10:49:44.261693+00', 'Southern Rose Waltz', 3217, 5, 0, 0, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (10015, '2017-05-19 08:58:26.130278+00', '2019-06-14 10:13:40.730526+00', 'Wind that Shakes the Barley, The', 11484, 1, 8, 32, NULL, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (6022, NULL, '2017-06-17 10:51:42.514943+00', 'Southern Rose Waltz', 3604, 5, 0, 0, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3358, NULL, '2017-06-17 10:52:08.903447+00', 'Southern Rose Waltz, The', 2088, 5, 0, 0, 9999, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (10030, '2017-06-28 14:04:57.410247+00', '2017-06-28 17:59:45.970309+00', 'Mhairi And I', 2586, 2, 4, 40, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (10017, '2017-05-19 09:06:23.000959+00', '2017-05-22 14:09:53.708628+00', 'Braes of Tulliemet, The', 11484, 3, 8, 32, NULL, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (10016, '2017-05-19 09:00:09.916176+00', '2019-06-14 10:15:30.073802+00', 'Flights of Fancy', 11484, 2, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (10019, '2017-05-19 09:20:05.642027+00', '2018-10-25 21:44:34.651225+00', 'Saw Ye My Wee Thing', 11484, 2, 8, 32, NULL, NULL, 296, 0, '');
INSERT INTO 'recording' VALUES (10020, '2017-05-19 16:41:55.029833+00', '2017-05-22 14:11:15.858243+00', 'Sauchie Haugh, The', 11484, 3, 8, 32, NULL, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (10021, '2017-05-19 16:44:18.492012+00', '2017-05-22 14:11:58.354744+00', 'Blooms of Bon Accord, The', 11484, 1, 4, 32, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (10022, '2017-05-19 16:47:30.622374+00', '2017-05-22 14:12:52.520499+00', 'Express, The', 11484, 2, 8, 40, NULL, NULL, 362, 0, '');
INSERT INTO 'recording' VALUES (10023, '2017-05-19 16:49:00.054953+00', '2017-05-22 14:13:13.627937+00', 'Sands of Morar, The', 11484, 3, 8, 32, NULL, NULL, 518, 0, '');
INSERT INTO 'recording' VALUES (10024, '2017-05-19 16:51:01.631148+00', '2017-05-22 14:14:18.907968+00', 'De''il Amang the Tailors, The', 11484, 1, 5, 32, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (10025, '2017-05-19 16:53:25.577332+00', '2017-05-22 14:14:38.868559+00', 'Last of the Lairds, The', 11484, 2, 8, 32, NULL, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (10026, '2017-05-19 16:54:53.174345+00', '2019-06-14 10:10:04.497697+00', 'Capelthwaite', 11484, 1, 8, 32, NULL, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (10046, '2017-06-28 14:35:31.781349+00', '2018-06-09 23:29:44.353599+00', 'Rug Beater, The', 2586, 1, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (10027, '2017-05-19 16:56:32.34246+00', '2018-10-25 21:44:14.137941+00', 'Black Leather Jig', 11484, 1, 8, 32, NULL, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (10043, '2017-06-28 14:31:02.560395+00', '2017-06-28 16:05:51.864772+00', 'Tallahassee Reel, The', 2586, 1, 4, 48, NULL, NULL, 229, 0, '');
INSERT INTO 'recording' VALUES (10029, '2017-06-28 12:45:59.783554+00', '2017-06-28 17:55:48.180144+00', 'Norma''s Garden', 2586, 1, 8, 32, NULL, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (9991, '2017-02-13 11:45:42.918961+00', '2017-11-05 10:51:46.845845+00', 'Snow in Summer', 3217, 3, 8, 32, 9999, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (10067, '2017-11-08 11:31:51.967334+00', '2018-03-22 12:53:49.146707+00', 'Janet''s Cup of Tea', 10209, 3, 4, 32, 9999, NULL, 243, 1, '');
INSERT INTO 'recording' VALUES (10106, '2017-11-25 19:04:14.876667+00', '2018-06-09 22:18:53.339094+00', 'Quaker''s Daughter, The', 11568, 3, 3, 32, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (2025, NULL, '2018-01-09 14:03:44.819999+00', 'Ian Powrie''s Farewell to Scotland', 2062, 3, 1, 64, 9999, NULL, 104, 0, '');
INSERT INTO 'recording' VALUES (10047, '2017-08-26 22:37:29.15568+00', '2017-08-26 22:37:29.15568+00', 'Edinburgh Toy Shop, The', 10018, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (10048, '2017-08-26 22:45:40.59006+00', '2017-08-26 22:45:40.59006+00', 'Somerset Children''s Reel, The', 10018, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (10049, '2017-08-26 22:48:37.405067+00', '2017-08-26 22:48:37.405067+00', 'Save the Children', 10018, 3, 8, 32, 9999, NULL, 491, 0, '');
INSERT INTO 'recording' VALUES (10050, '2017-08-26 23:03:12.901113+00', '2017-08-26 23:03:12.901113+00', 'Fair Enough', 10018, 2, 4, 32, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (10051, '2017-08-26 23:08:08.617403+00', '2017-08-26 23:08:08.617403+00', 'Summer on the Beach', 10018, 1, 4, 32, 9999, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (10052, '2017-08-26 23:11:46.630659+00', '2017-08-26 23:11:46.630659+00', 'And for the Young Ones', 10018, 2, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (10053, '2017-08-26 23:14:44.848451+00', '2017-08-26 23:28:38.760131+00', 'Continental Waltz', 10018, 5, 1, 196, 9999, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (10054, '2017-08-26 23:31:56.926834+00', '2017-08-26 23:31:56.926834+00', 'Holyrood Strathspey', 10018, 3, 8, 32, 9999, NULL, 490, 0, '');
INSERT INTO 'recording' VALUES (10055, '2017-08-26 23:34:33.937684+00', '2017-08-26 23:34:33.937684+00', 'New Year Jig', 10018, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (10056, '2017-08-26 23:37:36.786076+00', '2017-08-26 23:37:36.786076+00', 'Hello-Goodbye', 10018, 3, 8, 32, 9999, NULL, 488, 0, '');
INSERT INTO 'recording' VALUES (10057, '2017-08-26 23:44:31.253343+00', '2017-08-26 23:44:31.253343+00', 'Grand March', 10018, 11, 1, 196, 9999, NULL, 220, 0, '');
INSERT INTO 'recording' VALUES (10058, '2017-08-26 23:49:57.290077+00', '2017-08-26 23:49:57.290077+00', 'Pluto''s Head', 10018, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (10060, '2017-08-27 00:02:34.595218+00', '2017-08-27 00:02:34.595218+00', 'Bohemian Reflections', 10018, 1, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (2405, NULL, '2017-09-16 11:20:04.302948+00', 'Rhinns of Kells', 2067, 1, 8, 32, 9999, 1, 264, 0, '');
INSERT INTO 'recording' VALUES (10061, '2017-08-27 00:08:12.422244+00', '2017-09-30 10:52:16.745984+00', 'Slow Air', 10018, 98, 0, 0, 9999, NULL, 241, 0, '');
INSERT INTO 'recording' VALUES (10063, '2017-11-06 18:32:58.991537+00', '2017-11-06 18:32:58.991537+00', 'Bannockburn 700', 10209, 2, 8, 40, NULL, NULL, 347, 0, '');
INSERT INTO 'recording' VALUES (10064, '2017-11-06 18:47:44.660944+00', '2017-11-06 18:47:44.660944+00', 'Miss Shearer''s Strathspey', 10209, 3, 8, 32, NULL, NULL, 491, 0, '');
INSERT INTO 'recording' VALUES (10066, '2017-11-08 11:21:49.590617+00', '2017-11-08 11:21:49.590617+00', 'Jim''s Haberdashery', 10209, 2, 8, 40, 9999, NULL, 343, 0, '');
INSERT INTO 'recording' VALUES (10068, '2017-11-08 11:43:20.905535+00', '2017-11-08 11:43:20.905535+00', 'Gowan Hill', 10209, 2, 4, 32, 9999, NULL, 146, 1, '');
INSERT INTO 'recording' VALUES (10069, '2017-11-08 12:36:24.921841+00', '2017-11-08 12:36:24.921841+00', 'Argyll''s Farewell to Stirling', 10209, 1, 4, 40, 9999, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (10072, '2017-11-08 13:28:00.901006+00', '2017-11-08 13:28:00.901006+00', 'Walkers of Avonlea, The', 10209, 3, 4, 32, 9999, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (10073, '2017-11-08 13:41:13.418847+00', '2017-11-08 13:41:13.418847+00', 'Silver Castle Reel, The', 10209, 1, 8, 40, 9999, NULL, 353, 0, '');
INSERT INTO 'recording' VALUES (10074, '2017-11-08 13:58:43.021523+00', '2017-11-08 13:58:43.021523+00', 'Mrs Milne of Kinneff', 10209, 3, 4, 32, 9999, NULL, 246, 0, '');
INSERT INTO 'recording' VALUES (10075, '2017-11-08 14:09:06.429977+00', '2017-11-08 14:09:06.429977+00', 'Reel Archie, The', 10209, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (10076, '2017-11-08 14:18:07.080537+00', '2017-11-08 14:18:07.080537+00', 'Treasurer, The', 10209, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (10077, '2017-11-08 14:23:44.034006+00', '2017-11-08 14:23:44.034006+00', 'City of Stirling Reel, The', 10209, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (10078, '2017-11-10 16:39:43.36824+00', '2017-11-10 16:39:43.36824+00', 'Mr Iain Stuart Robertson', 10955, 1, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (10080, '2017-11-10 17:04:24.071802+00', '2017-11-10 17:04:24.071802+00', 'Trip to Sorrento, A', 10955, 2, 6, 32, 9999, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (10081, '2017-11-10 17:15:03.461647+00', '2017-11-10 17:15:03.461647+00', 'Lanes of Au, The', 10955, 1, 3, 32, 9999, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (10082, '2017-11-10 17:34:31.938459+00', '2017-11-10 17:34:31.938459+00', 'White Eagle', 10955, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (10083, '2017-11-10 17:56:11.772376+00', '2017-11-10 17:56:11.772376+00', 'Charlottetown', 10955, 3, 4, 32, 9999, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (10084, '2017-11-10 18:03:02.670453+00', '2017-11-10 18:04:58.692593+00', 'Neil M Grant', 10955, 2, 8, 32, 9999, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (10085, '2017-11-10 18:16:33.811844+00', '2017-11-10 18:16:33.811844+00', 'Fiddling in the Pinewoods', 10955, 3, 8, 32, 9999, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (10086, '2017-11-10 19:10:22.201734+00', '2017-11-10 19:10:22.201734+00', 'Lass of Richmond Hill, The', 10955, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (10087, '2017-11-10 19:15:26.075352+00', '2017-11-10 19:15:26.075352+00', 'Shadow', 10955, 2, 3, 32, 9999, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (10088, '2017-11-10 19:24:38.071041+00', '2017-11-10 19:24:38.071041+00', 'Catch the Wind', 10955, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (10089, '2017-11-10 19:30:30.165339+00', '2017-11-10 19:30:30.165339+00', 'City of Belfast', 10955, 3, 3, 32, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (10090, '2017-11-10 19:35:48.110952+00', '2017-11-10 19:35:48.110952+00', 'Miss Charlotte Sandifer', 10955, 1, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (10062, '2017-11-06 18:26:28.296199+00', '2020-01-25 22:44:24.292695+00', 'Stirling at 90', 10209, 1, 5, 32, NULL, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (10071, '2017-11-08 13:09:01.091963+00', '2022-09-08 07:19:48.282691+00', 'Birls Allowed', 10209, 2, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (889, NULL, '2022-12-08 23:58:23.888105+00', 'Neidpath Castle - Encore', 3006, 3, 3, 32, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (10065, '2017-11-06 20:43:35.82241+00', '2023-01-26 21:46:51.761228+00', 'King''s Knot, The', 10209, 1, 3, 32, NULL, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (10070, '2017-11-08 12:57:48.268017+00', '2023-01-26 21:47:40.152463+00', 'Annet Burn, The', 10209, 4, 1, 128, 10034, NULL, 203, 1, '');
INSERT INTO 'recording' VALUES (10091, '2017-11-10 20:27:05.05607+00', '2017-11-10 20:27:05.05607+00', 'Cascade Jig, A', 10955, 2, 4, 32, 9999, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (10092, '2017-11-10 20:33:03.102836+00', '2017-11-10 20:33:03.102836+00', 'Waltz', 10955, 5, 2, 64, 9999, NULL, 168, 0, '');
INSERT INTO 'recording' VALUES (10093, '2017-11-17 08:59:13.556153+00', '2017-11-17 08:59:13.556153+00', 'Elma McCausland MBE', 3217, 2, 4, 40, 9999, NULL, 195, 0, 'Dances to Honour Elma McCausland MBE');
INSERT INTO 'recording' VALUES (10113, '2017-11-26 00:47:14.846337+00', '2018-01-16 14:10:49.474818+00', 'Hope Valley Reel, The', 3011, 1, 8, 40, 9999, NULL, 354, 0, '');
INSERT INTO 'recording' VALUES (10117, '2017-11-26 14:09:00.70335+00', '2018-01-16 14:11:38.712033+00', 'Swings and Roundabouts', 3011, 4, 4, 64, 17, NULL, 394, 0, '');
INSERT INTO 'recording' VALUES (10094, '2017-11-25 16:20:53.964051+00', '2018-01-16 13:59:34.856821+00', 'Reel for Alice, A', 11568, 1, 5, 32, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (10095, '2017-11-25 16:27:20.540597+00', '2018-01-16 13:59:50.455538+00', 'Bristol Fashion', 11568, 3, 3, 32, 9999, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (10097, '2017-11-25 16:39:21.43437+00', '2018-01-16 14:00:17.219189+00', 'Deeside Wanderer, The', 11568, 3, 1, 64, 9999, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (10098, '2017-11-25 16:43:19.487365+00', '2018-01-16 14:00:29.440867+00', 'Full Circle', 11568, 2, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (10099, '2017-11-25 16:47:09.846956+00', '2018-01-16 14:00:44.183437+00', 'In Balance', 11568, 1, 8, 32, 9999, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (10100, '2017-11-25 16:50:51.636303+00', '2018-01-16 14:00:54.948586+00', 'Innes Dancers, The', 11568, 1, 4, 32, 9999, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (10101, '2017-11-25 16:53:40.801393+00', '2018-01-16 14:01:03.763166+00', 'Kildonan Sands', 11568, 3, 3, 32, 9999, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (10104, '2017-11-25 17:08:21.796365+00', '2018-01-16 14:01:30.580715+00', 'Morrison Measure, The', 11568, 1, 5, 32, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (10105, '2017-11-25 17:28:26.040666+00', '2018-01-16 14:02:26.468662+00', 'One Pair of Hands', 11568, 3, 4, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (10107, '2017-11-25 19:07:45.866035+00', '2018-01-16 14:03:03.863071+00', 'Right Way Up, The', 11568, 2, 8, 32, 9999, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (10108, '2017-11-25 20:57:02.9176+00', '2018-01-16 14:03:14.840115+00', 'Well Kent', 11568, 3, 3, 32, 9999, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (10109, '2017-11-25 21:02:40.785214+00', '2018-01-16 14:03:22.076409+00', 'Yorkshire Lasses', 11568, 2, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (10111, '2017-11-25 23:59:19.577766+00', '2018-01-16 14:10:23.358086+00', 'Damflask Strathspey, The', 3011, 3, 3, 32, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (10112, '2017-11-26 00:04:55.820707+00', '2018-01-16 14:10:34.411284+00', 'Fàilte gu Alba', 3011, 1, 8, 40, 9999, NULL, 361, 0, '');
INSERT INTO 'recording' VALUES (10114, '2017-11-26 13:51:26.022776+00', '2018-01-16 14:10:58.309522+00', 'Potter''s Wheel, The', 3011, 1, 4, 32, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (10115, '2017-11-26 13:58:30.011333+00', '2018-01-16 14:11:09.999298+00', 'Sheffield Castle', 3011, 4, 1, 128, 2, NULL, 206, 0, 'The actual phasing of the medley is S2x32 + R2x32.');
INSERT INTO 'recording' VALUES (10206, '2018-06-23 15:04:20.432939+00', '2018-06-23 17:34:10.58088+00', 'Bromlan/Bohmerdans/Pirvals', 11651, 98, 1, 0, NULL, NULL, 258, 0, 'Traditional Danish. Each tune is from a different area of Denmark and specific to a certain type of dance.');
INSERT INTO 'recording' VALUES (10079, '2017-11-10 16:54:29.067287+00', '2017-12-13 21:16:40.557326+00', 'Strathspey for Stan', 10955, 3, 8, 32, 9999, NULL, 504, 0, '');
INSERT INTO 'recording' VALUES (62, NULL, '2017-12-15 23:59:08.739513+00', 'Just as I was in the Morning / The Deuks Dang Ow''er my Daddie', 3028, 2, 8, 40, 9999, NULL, 345, 0, '');
INSERT INTO 'recording' VALUES (897, NULL, '2017-12-17 22:55:56.123491+00', 'Saint Andrews of Brampton', 3006, 1, 4, 32, 9999, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (10152, '2017-12-27 16:54:50.592505+00', '2017-12-27 16:54:50.592505+00', 'Isabel Paterson''s Jig', 10018, 2, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (10153, '2017-12-27 16:56:55.11115+00', '2017-12-27 16:56:55.11115+00', 'Sandy''s Strathspey', 10018, 3, 8, 32, NULL, NULL, 494, 0, '');
INSERT INTO 'recording' VALUES (10154, '2017-12-27 16:58:35.471015+00', '2017-12-27 16:58:35.471015+00', '90th Birthday', 10018, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (10155, '2017-12-27 17:01:21.736145+00', '2017-12-27 17:01:21.736145+00', 'Wee Mary''s Strathspey', 10018, 3, 3, 32, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (10156, '2017-12-27 17:03:09.54117+00', '2017-12-27 17:03:09.54117+00', 'Scandinavian Waltz', 10018, 5, 0, 0, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (10157, '2017-12-27 17:05:16.751518+00', '2017-12-27 17:05:16.751518+00', 'Light of Hope', 10018, 3, 4, 32, NULL, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (10158, '2017-12-27 17:07:01.618+00', '2017-12-27 17:07:01.618+00', 'Galloway Lads and Lassies', 10018, 1, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (10209, '2018-06-23 16:34:04.862545+00', '2018-08-17 15:36:17.073089+00', 'AE Lam', 11651, 98, 1, 0, NULL, NULL, 335, 0, 'Traditional Danish



The official correct spelling would be "Æ Lam".



This beautiful tune from the island of Fanø is traditionally played when the meat is brought out at celebratory events and festivities.');
INSERT INTO 'recording' VALUES (10134, '2017-12-27 12:46:03.2752+00', '2017-12-27 13:28:49.227629+00', 'Canadian Barn Dance', 10037, 11, 0, 0, NULL, NULL, 209, 0, '');
INSERT INTO 'recording' VALUES (10148, '2017-12-27 16:45:00.082874+00', '2017-12-27 17:13:53.606911+00', 'Gay Gordons', 10018, 11, 0, 0, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (10151, '2017-12-27 16:52:36.470686+00', '2017-12-27 20:29:45.903311+00', 'Anne and Friends', 10018, 3, 8, 32, NULL, NULL, 492, 0, '');
INSERT INTO 'recording' VALUES (5869, NULL, '2018-01-09 14:07:44.931977+00', 'Ian Powrie''s Farewell to Scotland', 3032, 3, 1, 64, 9999, NULL, 120, 0, '');
INSERT INTO 'recording' VALUES (3039, NULL, '2018-01-13 15:13:49.066309+00', 'Larkhill Welcome, The', 3010, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10102, '2017-11-25 16:57:39.864659+00', '2018-01-16 14:01:12.791387+00', 'Maunby Reel, The', 11568, 1, 8, 32, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (10210, '2018-06-23 16:37:39.626899+00', '2018-08-17 15:46:45.766884+00', 'Schottis Set', 11651, 98, 1, 0, NULL, NULL, 268, 0, 'Traditional Norwegian. 



These two Norwegian tunes from the repertoire of Anon Egeland are played for a popular type of Scandinavian dance called ''Schottis'', which is a groovy couple dance found throughout Northern Europe.');
INSERT INTO 'recording' VALUES (10138, '2017-12-27 14:25:07.079358+00', '2017-12-27 14:25:07.079358+00', 'Kind Robin', 11351, 3, 8, 32, NULL, NULL, 510, 0, '');
INSERT INTO 'recording' VALUES (10141, '2017-12-27 14:52:49.40815+00', '2017-12-27 14:52:49.40815+00', 'Portwilliam Lass', 11351, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (10142, '2017-12-27 14:55:39.373316+00', '2017-12-27 14:55:39.373316+00', 'Bracken Wood', 11351, 3, 8, 32, NULL, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (10161, '2018-03-29 19:01:24.191405+00', '2018-10-25 21:43:52.352984+00', 'Balgeddie Reel', 11613, 1, 5, 32, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (10136, '2017-12-27 13:44:43.873662+00', '2017-12-27 14:57:53.148598+00', 'Threave Strathspey', 11351, 3, 4, 32, NULL, NULL, 256, 0, '');
INSERT INTO 'recording' VALUES (10143, '2017-12-27 15:00:14.400298+00', '2017-12-27 15:00:14.400298+00', '70 x 4 Jig', 11351, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (10144, '2017-12-27 15:04:37.306392+00', '2017-12-27 15:04:37.306392+00', 'Scottish Waltz', 11351, 5, 0, 0, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (10145, '2017-12-27 15:08:21.183069+00', '2017-12-27 15:08:21.183069+00', 'Rooftops', 11351, 3, 8, 32, NULL, NULL, 497, 0, '');
INSERT INTO 'recording' VALUES (10140, '2017-12-27 14:33:23.333896+00', '2017-12-27 15:14:06.643727+00', 'Greyfriar''s Strathspey', 11351, 3, 4, 32, NULL, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (10122, '2017-12-16 16:13:22.743707+00', '2017-12-27 16:05:25.683513+00', 'Auchengar', 10037, 2, 8, 32, NULL, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (10123, '2017-12-27 11:57:06.123951+00', '2017-12-27 16:05:46.823985+00', '75th Anniversary Reel', 10037, 1, 4, 40, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (10124, '2017-12-27 12:04:37.63935+00', '2017-12-27 16:06:05.501121+00', 'Miss Alison Veitch', 10037, 3, 8, 32, NULL, NULL, 486, 0, '');
INSERT INTO 'recording' VALUES (10125, '2017-12-27 12:12:34.093828+00', '2017-12-27 16:06:21.66815+00', 'Cilla''s Jig', 10037, 2, 8, 32, NULL, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (10126, '2017-12-27 12:16:21.701732+00', '2017-12-27 16:06:43.056115+00', 'Bonnie Gallowa''', 10037, 3, 4, 40, NULL, NULL, 314, 0, '');
INSERT INTO 'recording' VALUES (10127, '2017-12-27 12:21:02.155733+00', '2017-12-27 16:07:03.111761+00', 'Mairi''s Wedding', 10037, 1, 8, 40, NULL, NULL, 339, 0, '');
INSERT INTO 'recording' VALUES (10128, '2017-12-27 12:26:21.534791+00', '2017-12-27 16:07:27.525959+00', 'Laxey Wheel, The', 10037, 2, 8, 32, NULL, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (10130, '2017-12-27 12:32:50.544326+00', '2017-12-27 16:07:48.974583+00', 'Kirkcall Strathspey', 10037, 3, 8, 32, NULL, NULL, 477, 0, '');
INSERT INTO 'recording' VALUES (10131, '2017-12-27 12:39:12.422905+00', '2017-12-27 16:08:03.363509+00', 'Haggis, The', 10037, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (10132, '2017-12-27 12:42:18.39162+00', '2017-12-27 16:08:19.656259+00', 'Jessie Cannon''s Strathspey', 10037, 3, 3, 32, NULL, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (10133, '2017-12-27 12:44:56.970274+00', '2017-12-27 16:08:31.283915+00', 'Welcome Home', 10037, 2, 5, 32, NULL, NULL, 173, 0, '');
INSERT INTO 'recording' VALUES (10146, '2017-12-27 15:11:52.48176+00', '2017-12-27 16:10:28.262536+00', 'Fidget', 11351, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (10137, '2017-12-27 13:48:19.926662+00', '2017-12-27 16:11:00.561187+00', 'Carol''s Frolic', 11351, 1, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (10139, '2017-12-27 14:30:27.607013+00', '2017-12-27 16:12:07.265394+00', 'My Friend Jim', 11351, 2, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (10147, '2017-12-27 16:42:03.690543+00', '2017-12-27 16:42:03.690543+00', 'Carlingwark Jig', 10018, 2, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (10149, '2017-12-27 16:47:25.670384+00', '2017-12-27 16:47:25.670384+00', 'Rose of Ardwall', 10018, 3, 8, 32, NULL, NULL, 488, 0, '');
INSERT INTO 'recording' VALUES (10150, '2017-12-27 16:49:36.020082+00', '2017-12-27 16:49:36.020082+00', 'Our Friend Viv', 10018, 1, 4, 32, NULL, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (10118, '2017-11-26 14:12:32.414416+00', '2018-01-16 14:11:49.979308+00', 'Swirling and Twirling Leaves', 3011, 2, 8, 32, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (10119, '2017-11-26 14:14:49.261795+00', '2018-01-16 14:12:00.221428+00', 'Toddle wi'' Joy', 3011, 1, 8, 40, 9999, NULL, 358, 0, '');
INSERT INTO 'recording' VALUES (10110, '2017-11-25 23:56:10.290426+00', '2021-05-01 13:55:52.958864+00', 'Cream Tea', 3011, 3, 3, 32, 9999, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (10120, '2017-11-26 14:21:55.384268+00', '2018-01-16 14:12:09.300416+00', 'Wake Up Ones', 3011, 2, 5, 32, 9999, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (10116, '2017-11-26 14:00:59.772817+00', '2022-10-16 21:55:04.799646+00', 'Silverdale Strathspey', 3011, 3, 4, 32, 9999, NULL, 268, 1, '');
INSERT INTO 'recording' VALUES (10129, '2017-12-27 12:29:57.852549+00', '2022-12-20 14:54:59.830216+00', 'Viennese Waltz', 10037, 5, 0, 0, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (10121, '2017-11-26 14:25:47.593124+00', '2018-01-16 14:12:19.665166+00', 'Winter Garden, The', 3011, 3, 8, 32, 9999, NULL, 518, 0, '');
INSERT INTO 'recording' VALUES (9984, '2017-02-13 11:07:51.582321+00', '2018-02-07 10:17:36.961636+00', 'September in Skye', 3217, 3, 3, 32, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (6599, NULL, '2018-02-09 17:40:23.031405+00', 'Miss Grace Hayes'' Delight', 10020, 2, 8, 32, NULL, NULL, 271, 0, 'The dance for this recording is actually spelled "Miss Grace Hay''s Delight."');
INSERT INTO 'recording' VALUES (4893, NULL, '2018-02-18 02:25:14.4872+00', 'Mrs Milne of Kinneff', 2645, 3, 4, 32, 9999, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (2560, NULL, '2018-09-11 23:34:29.957063+00', 'Hey Johnnie Cope', 2067, 1, 8, 32, 9999, 5, 281, 0, '');
INSERT INTO 'recording' VALUES (10135, '2017-12-27 13:21:17.652011+00', '2018-10-14 23:14:44.222905+00', 'Raiders Road, The', 11351, 2, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (10222, '2018-09-15 09:43:42.188906+00', '2018-11-06 21:54:11.289565+00', 'Ysobel Stewart of Fish Hoek', 10659, 3, 8, 32, NULL, NULL, 498, 0, '');
INSERT INTO 'recording' VALUES (10221, '2018-09-15 09:41:14.477432+00', '2018-11-06 21:54:11.297922+00', 'Farewell to Balfour Road', 10659, 2, 1, 96, NULL, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (9862, '2016-03-13 09:36:18.739177+00', '2018-10-14 23:24:44.138281+00', 'Librarian''s Daughter, The', 2944, 3, 4, 40, NULL, NULL, 316, 0, 'Tune 4 is listed on the sleeve as being Manchester Caledonian Society by Jimmy Shand.  

In SCDDB, Manchester Caledonian Society (traditional) is found on only 1 recording, no audio clip is available.  Manchester Caledonians (Shand) is on 13 recordings and the available audio clip agrees with this recording by Frank Thomson.');
INSERT INTO 'recording' VALUES (8406, NULL, '2018-11-14 10:18:12.180623+00', 'Legacy, The', 2066, 2, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (10220, '2018-09-15 09:40:01.179018+00', '2018-11-06 21:54:11.314627+00', 'Ruby Wilkinson''s Farewell to Cranshaws', 10659, 3, 4, 32, NULL, NULL, 245, 1, '');
INSERT INTO 'recording' VALUES (10218, '2018-09-15 09:37:09.47017+00', '2018-11-06 21:54:11.331095+00', 'Forty and Counting', 10659, 1, 8, 40, NULL, NULL, 347, 0, '');
INSERT INTO 'recording' VALUES (10216, '2018-09-15 09:35:20.16996+00', '2018-11-06 21:54:11.355606+00', 'Ullapool Ferry, The', 10659, 1, 4, 32, NULL, NULL, 142, 0, '');
INSERT INTO 'recording' VALUES (2697, NULL, '2018-11-14 10:23:45.856918+00', 'Haymakers, The', 2088, 2, 4, 48, 9999, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (9571, '2014-03-16 15:37:17.444345+00', '2018-11-20 12:41:21.061366+00', 'Subarashii Saitama Strathspey', 3008, 3, 4, 32, 9999, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (10227, '2018-09-15 09:53:43.798677+00', '2018-11-23 23:35:54.91496+00', 'Warm-Up Waltz', 10659, 5, 12, 16, NULL, NULL, 233, 0, '');
INSERT INTO 'recording' VALUES (92, NULL, '2018-12-06 22:26:59.809898+00', 'Gaelic Waltz Selection', 3010, 5, 0, 0, 9999, NULL, 169, 0, 'List of tunes updated following issue 872 (http://my.strathspey.org/dd/issue/872/)');
INSERT INTO 'recording' VALUES (10162, '2018-03-29 19:03:37.764346+00', '2018-12-11 20:24:28.9284+00', 'Atlanta Fair', 11613, 2, 8, 32, NULL, NULL, 287, 0, 'Tunes from the soundtrack of Gone With the Wind were arranged for SCD by Dr.Peter Campbell (see http://my.strathspey.org/dd/issue/1596/).');
INSERT INTO 'recording' VALUES (10238, '2019-01-08 16:01:21.209609+00', '2019-01-25 22:53:08.245783+00', 'Easy Peasy Rights and Lefts', 3217, 2, 4, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (10241, '2019-01-08 16:06:52.781623+00', '2019-01-25 22:55:57.996196+00', 'Flowering Heather, The', 3217, 3, 3, 32, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (10242, '2019-01-08 16:10:09.986668+00', '2019-01-25 22:56:29.825497+00', 'Little Bit of Monty, A', 3217, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (10243, '2019-01-08 16:11:00.058014+00', '2019-01-25 22:57:04.607722+00', 'St Aidan''s Church Hall', 3217, 3, 4, 32, NULL, NULL, 252, 0, '');
INSERT INTO 'recording' VALUES (10240, '2019-01-08 16:05:16.866479+00', '2019-01-25 23:58:34.458293+00', 'Dancing the Baby (Medley)', 3217, 4, 1, 144, 10042, NULL, 227, 0, '');
INSERT INTO 'recording' VALUES (10246, '2019-01-08 16:23:20.340254+00', '2019-01-08 16:23:20.340254+00', 'Caledonia', 11397, 98, 0, 0, NULL, NULL, 367, 0, '');
INSERT INTO 'recording' VALUES (10245, '2019-01-08 16:22:35.841577+00', '2019-01-10 11:04:23.744336+00', 'Marches - Warm Up', 3217, 11, 0, 0, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (3462, NULL, '2019-01-22 23:53:54.220701+00', 'Let''s Meet Again', 3050, 3, 8, 32, 9999, NULL, 517, 0, '');
INSERT INTO 'recording' VALUES (116, NULL, '2019-01-23 17:15:06.279204+00', 'Happy Returns', 3002, 1, 8, 32, 9999, 1, 283, 0, '');
INSERT INTO 'recording' VALUES (809, NULL, '2019-01-23 17:21:57.370289+00', 'Punch Bowl, The', 3019, 1, 8, 32, 9999, 1, 273, 0, '');
INSERT INTO 'recording' VALUES (9097, '2013-01-04 12:33:30.122152+00', '2019-01-23 17:30:44.745421+00', 'Selection of Reels', 3067, 1, 8, 32, 9999, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (712, NULL, '2019-01-23 17:37:13.916209+00', 'Whistling Wind, The', 3038, 1, 8, 32, 9999, 5, 287, 0, '');
INSERT INTO 'recording' VALUES (3591, NULL, '2019-01-23 17:56:22.163338+00', 'Ladies of Dunse, The', 2184, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1253, NULL, '2019-01-23 18:27:16.172646+00', 'Mid Lothian', 3020, 1, 4, 40, 9999, 6, 183, 0, '');
INSERT INTO 'recording' VALUES (4219, NULL, '2019-01-23 23:30:11.1517+00', 'Mathematician, The', 2418, 1, 5, 40, 9999, NULL, 250, 0, '');
INSERT INTO 'recording' VALUES (10235, '2019-01-08 15:57:26.064611+00', '2019-01-25 22:50:23.195244+00', 'Butterfly', 3217, 1, 4, 32, NULL, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (10236, '2019-01-08 15:58:55.064658+00', '2019-01-25 22:51:36.117032+00', 'Joyce MacLeod', 3217, 2, 5, 32, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (10237, '2019-01-08 16:00:20.700458+00', '2019-01-25 22:52:33.509813+00', 'Musicians'' Wedding, The', 3217, 3, 4, 32, NULL, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (10239, '2019-01-08 16:02:45.196855+00', '2019-01-25 22:54:49.40227+00', 'Dancing the Baby', 3217, 1, 1, 72, NULL, NULL, 93, 0, '');
INSERT INTO 'recording' VALUES (10244, '2019-01-08 16:11:53.525939+00', '2019-01-25 22:57:26.794388+00', 'Chain Lynx', 3217, 1, 8, 32, NULL, NULL, 300, 0, '');
INSERT INTO 'recording' VALUES (3714, NULL, '2019-02-16 22:10:28.658108+00', 'Set of Reels', 3004, 13, 6, 32, 9999, NULL, 0, 0, 'This is a set of polkas although the track title is Set of Reels. See issue 1632 (http://my.strathspey.org/dd/issue/1632/).');
INSERT INTO 'recording' VALUES (8441, NULL, '2019-02-18 13:56:17.337044+00', 'Hirondelle, L''', 2586, 7, 0, 0, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (2444, NULL, '2019-02-25 13:03:57.025244+00', 'Barmkin, The', 3002, 1, 0, 88, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (10217, '2018-09-15 09:36:14.957711+00', '2021-10-21 18:18:11.432452+00', 'Slytherin House', 10659, 3, 8, 32, NULL, NULL, 502, 0, '');
INSERT INTO 'recording' VALUES (10262, '2019-02-27 21:50:41.659787+00', '2021-07-30 21:28:07.414609+00', 'Queensland Twosome, The', 11791, 1, 8, 32, NULL, NULL, 300, 0, '');
INSERT INTO 'recording' VALUES (9796, '2015-05-31 09:23:14.848901+00', '2021-10-16 22:53:26.121391+00', 'Irish Rover, The', 10037, 1, 8, 32, 9999, NULL, 282, 0, 'Has vocals.');
INSERT INTO 'recording' VALUES (10215, '2018-09-15 09:34:16.542378+00', '2021-10-21 18:15:13.205458+00', 'City Lights', 10659, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (10247, '2019-02-27 21:32:00.329572+00', '2022-07-27 13:25:58.728637+00', 'Ruby Rant', 11791, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (10248, '2019-02-27 21:33:06.462352+00', '2022-07-27 13:29:18.030184+00', 'Triple Happiness', 11791, 3, 3, 32, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (10249, '2019-02-27 21:34:38.388638+00', '2022-07-27 13:33:38.710785+00', 'Orpington Caledonians', 11791, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (10251, '2019-02-27 21:36:59.609637+00', '2022-07-27 17:26:53.424686+00', 'Napier''s Index', 11791, 2, 8, 40, NULL, NULL, 347, 0, '');
INSERT INTO 'recording' VALUES (10252, '2019-02-27 21:37:50.802815+00', '2022-07-27 17:31:09.503056+00', 'Emma Nixon Strathspey', 11791, 3, 8, 32, NULL, NULL, 521, 0, '');
INSERT INTO 'recording' VALUES (10253, '2019-02-27 21:39:22.910564+00', '2022-07-27 17:37:19.43286+00', 'Festival Fling', 11791, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (10254, '2019-02-27 21:40:05.655042+00', '2022-07-27 17:49:55.115263+00', 'Pelorus Jack', 11791, 2, 8, 32, NULL, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (10255, '2019-02-27 21:41:35.596332+00', '2022-07-27 17:52:21.680233+00', 'De''il Amang the Tailors', 11791, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (10256, '2019-02-27 21:42:13.704047+00', '2022-07-27 19:39:23.78836+00', 'Catch the Wind', 11791, 1, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (10265, '2019-03-13 23:57:43.920025+00', '2022-12-15 11:43:51.593817+00', 'Holden My Own', 3017, 2, 8, 32, NULL, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (10258, '2019-02-27 21:46:01.751105+00', '2022-07-27 19:48:04.470626+00', 'Everlasting Friendship, The', 11791, 3, 4, 48, NULL, NULL, 373, 0, '');
INSERT INTO 'recording' VALUES (10259, '2019-02-27 21:46:35.637632+00', '2022-07-27 19:56:56.871955+00', 'Anne Archdeacon Reel', 11791, 1, 4, 40, NULL, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (10261, '2019-02-27 21:49:46.679171+00', '2022-07-27 20:11:18.404878+00', 'Best Set in the Hall', 11791, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (10260, '2019-02-27 21:48:07.126422+00', '2022-07-27 20:07:52.020127+00', 'Quiet Achiever, The', 11791, 4, 8, 32, 1, NULL, 392, 0, '');
INSERT INTO 'recording' VALUES (10263, '2019-02-27 21:51:19.19731+00', '2022-07-27 21:04:54.584998+00', 'C''est Si Bon', 11791, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (10233, '2019-01-08 15:53:39.324895+00', '2022-08-27 10:33:11.69109+00', 'Babbling Brooke, A', 3217, 2, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (10257, '2019-02-27 21:45:07.225526+00', '2022-12-08 10:54:49.631077+00', 'Viva La Paz', 11791, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (10266, '2019-03-14 00:03:50.914766+00', '2022-12-15 11:44:35.475052+00', 'Braes of Breadalbane', 3017, 3, 8, 32, NULL, NULL, 475, 0, '');
INSERT INTO 'recording' VALUES (10267, '2019-03-14 00:07:45.206885+00', '2022-12-15 11:45:16.335679+00', 'Flowers of Edinburgh', 3017, 1, 8, 32, NULL, NULL, 269, 0, '');
INSERT INTO 'recording' VALUES (10270, '2019-03-14 00:19:31.185657+00', '2022-12-15 11:46:24.328939+00', 'Accordion Player, The', 3017, 1, 8, 32, NULL, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (10272, '2019-03-14 00:26:20.925207+00', '2022-12-15 11:47:37.736087+00', 'Fair Donald', 3017, 3, 8, 32, NULL, NULL, 488, 0, '');
INSERT INTO 'recording' VALUES (10271, '2019-03-14 00:21:42.846095+00', '2022-12-15 11:51:06.423415+00', 'Oh, to Joy!', 1763, 5, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10273, '2019-03-14 00:32:18.142215+00', '2022-12-15 11:51:52.755258+00', 'Suitable for The Maskin Rung', 3017, 1, 5, 32, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (10268, '2019-03-14 00:11:41.42845+00', '2022-12-15 11:59:00.184042+00', 'Follow Me Home', 3017, 2, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (10275, '2019-03-14 00:42:05.219926+00', '2019-03-14 00:42:05.219926+00', 'Set of Song Airs', 3017, 3, 6, 32, NULL, NULL, 345, 0, '');
INSERT INTO 'recording' VALUES (10269, '2019-03-14 00:17:19.05512+00', '2019-03-14 10:43:09.148875+00', 'Set of Strathspeys', 3017, 3, 4, 32, NULL, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (9233, '2013-02-02 14:51:53.53042+00', '2019-03-24 21:03:38.018826+00', 'Russe, La', 10146, 1, 4, 64, 9999, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (9654, '2014-04-29 15:07:00.126936+00', '2019-03-24 21:04:01.711996+00', 'Russe, La', 2038, 1, 8, 32, 9999, NULL, 255, 0, '');
INSERT INTO 'recording' VALUES (21, NULL, '2019-03-25 11:07:11.31267+00', 'Blithest Lass that Ever was Seen, The', 3002, 3, 8, 32, 9999, 5, 512, 0, 'Although Muriel Johnstone composed a tune called Miss Susan Inglis, the one used here is by Nan Main according to issue http://my.strathspey.org/dd/issue/1668/');
INSERT INTO 'recording' VALUES (8651, NULL, '2019-05-21 21:00:59.123583+00', 'Duke of Atholl''s Reel, The', 2328, 2, 6, 32, NULL, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (5481, NULL, '2019-05-29 21:31:04.539169+00', 'Captain McBride''s Hornpipe', 2696, 1, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (7004, NULL, '2019-05-30 07:07:43.643123+00', 'Forget Me Knot', 10070, 3, 3, 32, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (10280, '2019-06-14 14:45:48.824855+00', '2019-06-14 20:00:45.806933+00', 'Miss Nidra Aitken', 10659, 3, 3, 32, NULL, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (10281, '2019-06-14 14:46:52.290448+00', '2019-06-14 20:04:19.277575+00', 'Forward to Frankfurt', 10659, 1, 8, 40, NULL, NULL, 358, 0, '');
INSERT INTO 'recording' VALUES (10282, '2019-06-14 14:48:06.467815+00', '2019-06-14 20:05:43.511684+00', 'Land of the Heather Hills', 10659, 3, 4, 32, NULL, NULL, 258, 1, '');
INSERT INTO 'recording' VALUES (10283, '2019-06-14 14:49:03.188318+00', '2019-06-14 20:14:55.571647+00', 'Hungarian Bride', 10659, 1, 5, 48, NULL, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (10284, '2019-06-14 14:57:31.275706+00', '2019-06-14 20:20:59.38045+00', 'Five Penny Ness', 10659, 2, 5, 32, NULL, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (10285, '2019-06-14 14:59:03.646765+00', '2019-06-14 20:24:38.58927+00', 'Celebration at Higham', 10659, 3, 8, 32, NULL, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (5172, NULL, '2019-07-24 18:02:33.628349+00', 'Above the Clouds', 1396, 3, 8, 32, 9999, NULL, 492, 0, '');
INSERT INTO 'recording' VALUES (10288, '2019-06-14 15:03:01.82802+00', '2019-06-14 20:39:21.396933+00', 'Duddingstone Loch', 10659, 3, 5, 32, NULL, NULL, 319, 0, '');
INSERT INTO 'recording' VALUES (10289, '2019-06-14 15:04:05.076709+00', '2019-06-14 20:43:26.813462+00', 'Osgood MacKenzie of Inverewe', 10659, 1, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (10290, '2019-06-14 15:05:26.949825+00', '2019-06-14 20:52:12.18323+00', 'Stanford Swing', 10659, 2, 8, 40, NULL, NULL, 344, 0, '');
INSERT INTO 'recording' VALUES (10287, '2019-06-14 15:01:55.985289+00', '2019-06-15 14:14:11.942553+00', 'Saint Andrew''s Jig', 10659, 2, 4, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (10278, '2019-06-14 14:35:36.706953+00', '2019-06-14 19:49:03.604776+00', 'Raising the Anchor', 10659, 1, 5, 32, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (10291, '2019-06-14 15:06:43.027474+00', '2019-06-14 20:53:55.818383+00', 'Deer Friends', 10659, 3, 8, 32, NULL, NULL, 500, 0, '');
INSERT INTO 'recording' VALUES (4433, NULL, '2019-06-18 08:33:05.752699+00', 'Longways, Les', 3010, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (7424, NULL, '2019-06-24 15:38:04.093508+00', 'Monymusk', 3065, 3, 3, 32, NULL, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (408, NULL, '2019-06-28 12:29:43.287786+00', 'Auchindoun Castle', 1396, 1, 5, 32, 9999, 10, 183, 0, '');
INSERT INTO 'recording' VALUES (10307, '2019-10-29 11:31:06.080843+00', '2019-10-29 15:50:40.242283+00', 'Ballarat Bertie''s Bounce', 11898, 1, 8, 40, NULL, NULL, 369, 0, 'Recording downloadable from https://www.ballaratscd.com/audio.html');
INSERT INTO 'recording' VALUES (10306, '2019-10-29 11:18:35.98362+00', '2019-10-29 15:51:09.255133+00', 'Daylesford Reel, The', 11898, 1, 8, 32, NULL, NULL, 285, 0, 'Recording downloadable from https://www.ballaratscd.com/audio.html');
INSERT INTO 'recording' VALUES (10305, '2019-10-29 10:56:13.43373+00', '2019-10-29 15:52:17.216022+00', 'Wheels for April Fools', 11898, 2, 4, 48, NULL, NULL, 216, 0, 'Recording downloadable from https://www.ballaratscd.com/audio.html');
INSERT INTO 'recording' VALUES (10308, '2019-10-29 15:55:15.786386+00', '2019-10-29 15:55:15.786386+00', 'Wendouree Waters', 11898, 3, 8, 32, NULL, NULL, 522, 0, 'Recording downloadable from https://www.ballaratscd.com/audio.html');
INSERT INTO 'recording' VALUES (10309, '2019-10-29 15:58:02.018072+00', '2019-10-29 15:58:02.018072+00', 'Jane''s Canadian Strathspey', 11898, 3, 4, 32, NULL, NULL, 274, 0, 'Recording downloadable from https://www.ballaratscd.com/audio.html');
INSERT INTO 'recording' VALUES (10310, '2019-10-29 16:39:51.923067+00', '2019-10-29 16:44:32.741674+00', 'Reavey Roundabout, The', 11898, 3, 3, 32, NULL, NULL, 217, 0, 'Recording downloadable from https://www.ballaratscd.com/audio.html');
INSERT INTO 'recording' VALUES (10294, '2019-08-23 16:05:54.199652+00', '2019-08-26 12:27:27.356137+00', 'Spurtle King, The', 11862, 3, 8, 32, 9999, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (10293, '2019-08-23 16:05:13.282025+00', '2019-08-26 12:29:40.347853+00', 'Shy Lassie, The', 11862, 2, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (10295, '2019-08-23 16:07:10.6152+00', '2019-08-26 12:31:24.093306+00', 'Lost & Found', 11862, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (10296, '2019-08-23 16:07:59.105407+00', '2019-08-26 12:38:36.444299+00', 'Kate''s Apple Pie', 11862, 2, 8, 32, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (10297, '2019-08-23 16:08:52.356305+00', '2019-08-26 12:46:52.895518+00', 'Double Sixty', 11862, 1, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (10298, '2019-08-23 16:09:29.885694+00', '2019-08-26 12:54:12.141758+00', 'Smoky Morning, A', 11862, 3, 8, 32, 9999, NULL, 509, 0, '');
INSERT INTO 'recording' VALUES (10299, '2019-08-23 16:10:40.161313+00', '2019-08-26 12:58:30.252834+00', 'Eileen''s Hospitality / Mark & Laura''s Wedding', 11862, 5, 0, 0, 9999, NULL, 369, 0, '');
INSERT INTO 'recording' VALUES (10301, '2019-08-23 16:12:10.844092+00', '2019-08-26 14:14:00.79357+00', 'From the Don to the Dee', 11862, 3, 8, 32, 9999, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (10302, '2019-08-23 16:12:57.884589+00', '2019-08-26 14:20:04.184894+00', 'Cap''n Caplin''s Set', 11862, 6, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (10303, '2019-08-23 16:13:28.046797+00', '2019-08-26 14:35:15.871678+00', 'Second Chance', 11862, 5, 0, 0, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (5583, NULL, '2019-09-02 11:24:47.095542+00', 'Huncote Jig, The', 3006, 2, 3, 32, 9999, NULL, 108, 0, '');
INSERT INTO 'recording' VALUES (10304, '2019-09-11 21:12:10.99632+00', '2019-09-11 21:13:30.303693+00', 'Strip the Willow / Drops of Brandy', 3019, 101, 8, 40, NULL, NULL, 338, 0, '');
INSERT INTO 'recording' VALUES (3327, NULL, '2019-09-27 22:26:10.150351+00', 'Bonnie Ina Campbell', 2065, 3, 8, 32, 9999, NULL, 499, 0, '');
INSERT INTO 'recording' VALUES (10168, '2018-03-30 08:57:03.730229+00', '2019-09-30 22:07:33.873307+00', 'Happy Tenth', 11613, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (9917, '2016-10-04 00:07:25.378172+00', '2019-09-30 22:08:36.560224+00', 'Long & The Short of It, The', 11376, 4, 1, 256, 55, NULL, 403, 0, '');
INSERT INTO 'recording' VALUES (6809, NULL, '2019-10-01 13:41:44.532768+00', 'Captain McBride''s Hornpipe', 3045, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (909, NULL, '2019-10-18 00:31:14.37254+00', 'Greig''s Pipes', 3018, 3, 8, 32, 9999, 5, 490, 0, '');
INSERT INTO 'recording' VALUES (1557, NULL, '2019-10-28 11:43:56.597726+00', 'Oh Whistle and I''ll Come Tae Ye, My Lad', 3014, 2, 8, 32, 9999, 1, 276, 0, '');
INSERT INTO 'recording' VALUES (585, NULL, '2019-10-29 10:29:00.960611+00', 'Lady Dumfries', 3002, 1, 8, 32, 9999, 1, 292, 0, '');
INSERT INTO 'recording' VALUES (1255, NULL, '2019-11-01 08:05:16.27825+00', 'Sutherland Reel, The', 3018, 1, 8, 40, 9999, 6, 348, 0, '');
INSERT INTO 'recording' VALUES (1651, NULL, '2019-11-05 14:39:56.651512+00', 'Lammas Market', 2044, 3, 4, 32, 9999, 1, 248, 0, '');
INSERT INTO 'recording' VALUES (6818, NULL, '2019-11-07 09:50:37.518805+00', 'Quiet and Snug', 3045, 3, 8, 32, NULL, NULL, 487, 0, '');
INSERT INTO 'recording' VALUES (2762, NULL, '2019-11-08 10:02:55.7864+00', 'James''s Jig', 3006, 2, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (7534, NULL, '2019-11-09 11:12:12.2487+00', 'Irish Reels suitable for Irish Rover', 10145, 1, 8, 32, 9999, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (6177, NULL, '2019-11-10 00:47:04.528956+00', 'Ian and Joan McKenzie''s Strathspey', 3019, 3, 3, 40, 9999, NULL, 237, 0, '');
INSERT INTO 'recording' VALUES (9302, '2013-02-22 14:19:42.447241+00', '2019-11-21 12:41:26.864587+00', 'Russe, La', 10209, 1, 4, 64, 9999, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (5486, NULL, '2019-11-25 00:41:29.956491+00', 'Miss Ogilvie''s Fancy', 2696, 3, 8, 32, 9999, NULL, 516, 0, '');
INSERT INTO 'recording' VALUES (10059, '2017-08-26 23:55:14.4337+00', '2020-01-25 22:54:05.390189+00', 'Come What May', 10018, 2, 8, 32, 9999, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (10300, '2019-08-23 16:11:22.797807+00', '2020-01-26 17:05:17.795912+00', 'Steve''s Jigs', 11862, 2, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (10279, '2019-06-14 14:36:30.616471+00', '2020-07-08 21:33:25.005553+00', 'Globe Inn, The', 10659, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (9929, '2016-10-09 01:45:57.141488+00', '2021-05-27 17:55:50.241776+00', 'Jan Maree', 3217, 1, 3, 32, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (10286, '2019-06-14 15:00:07.930682+00', '2021-12-05 05:24:32.275007+00', 'Flitting of Lorn, The', 10659, 1, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (6230, NULL, '2019-11-14 08:53:11.259293+00', 'Jacqui Watson''s Strathspey', 3678, 3, 3, 32, 9999, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (9056, '2013-01-02 14:48:15.889445+00', '2019-11-14 09:26:55.908878+00', 'Happy Returns', 3678, 1, 8, 32, 9999, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7713, NULL, '2020-01-22 23:52:34.36184+00', 'Pensioner''s Reel, The', 10177, 1, 8, 32, NULL, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (8917, '2012-06-12 16:18:29.155613+00', '2020-01-24 21:06:55.674417+00', 'Monday Welcome', 3012, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (8913, '2012-06-12 16:00:58.138852+00', '2020-01-25 22:44:04.045303+00', 'Our Friend Robert', 3012, 1, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (2519, NULL, '2022-08-31 17:04:10.481885+00', 'Pipe Reels', 2065, 1, 8, 32, 9999, 5, 281, 0, '');
INSERT INTO 'recording' VALUES (8046, NULL, '2022-12-14 16:02:05.701007+00', 'Restless Ghost, The', 10237, 1, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (10274, '2019-03-14 00:36:35.582033+00', '2022-12-15 11:52:21.351023+00', 'Lamb Skinnet', 3017, 2, 8, 32, NULL, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (10276, '2019-03-14 00:49:42.836392+00', '2022-12-15 11:54:00.608245+00', 'Mrs MacLeod of Raasay', 3017, 1, 8, 32, NULL, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (10277, '2019-03-14 00:50:34.305934+00', '2022-12-15 12:25:12.96092+00', 'Laddie Lie Near Me', 3017, 5, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6644, NULL, '2019-11-16 08:42:37.019174+00', 'Bonnie Lass o'' Bon Accord, The', 3023, 3, 1, 64, NULL, NULL, 132, 0, 'The recording has an eight bar introduction (with no chord), followed by 56 bars for the dance. This follows the layout of the dance instructions, where the dancers stand still for four bars, bow to partners for two bars and to corners for two bars, and then commence what is really a 56 bar dance.



');
INSERT INTO 'recording' VALUES (5113, NULL, '2019-11-16 18:01:28.793896+00', 'Agnes & Bobby Crowe', 3002, 3, 0, 96, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (4585, NULL, '2019-11-17 23:57:44.173107+00', 'Mrs Clancy''s Strathspey', 3036, 3, 4, 32, 9999, NULL, 239, 0, '');
INSERT INTO 'recording' VALUES (6108, NULL, '2019-11-18 00:45:20.322714+00', 'Earl of Errol''s Reel, The', 3039, 2, 0, 200, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (8052, NULL, '2019-11-18 00:47:32.942916+00', 'Sloane Square - Encore', 10247, 3, 1, 64, NULL, NULL, 122, 0, '');
INSERT INTO 'recording' VALUES (6427, NULL, '2019-11-18 01:06:45.581872+00', 'Vive la Danse', 3040, 2, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (132, NULL, '2019-11-18 12:33:15.155916+00', 'J.B. Milne', 3011, 1, 8, 32, 9999, NULL, 273, 0, 'The original entry for this recording also mistakenly included the tune Dr Robertson.');
INSERT INTO 'recording' VALUES (254, NULL, '2019-11-18 16:39:05.865162+00', 'Pines Of Pitlochry, The', 3008, 2, 8, 48, 9999, NULL, 381, 0, 'The original entry for this recording also mistakenly included Top of Cork Road which is now removed from its list of tunes.');
INSERT INTO 'recording' VALUES (5485, NULL, '2019-11-18 18:05:43.947149+00', '3 x 32 Jigs', 2696, 2, 3, 32, 9999, NULL, 117, 0, 'The original database entry for this recording included the tune The Bingley Five Rise Locks which seems to have been a mistake so it has been removed from the list.');
INSERT INTO 'recording' VALUES (8285, NULL, '2019-11-19 09:30:10.35562+00', 'Eightsome Reel, The', 10104, 1, 0, 464, NULL, NULL, 487, 0, '');
INSERT INTO 'recording' VALUES (230, NULL, '2019-11-19 09:51:15.758531+00', 'Munro Rant, The', 3002, 3, 8, 32, 9999, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (5640, NULL, '2019-11-19 10:55:59.811502+00', 'Set of Reels', 2058, 1, 8, 32, 9999, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (9303, '2013-02-22 14:20:50.959597+00', '2019-11-21 12:43:05.488732+00', 'Joe MacDiarmid''s Jig', 10209, 2, 4, 32, 9999, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (9306, '2013-02-22 14:29:55.063871+00', '2019-11-21 17:53:01.532787+00', 'Mississippi Dip', 10209, 50, 0, 16, 9999, NULL, 182, 0, 'Described as a 32 bar "singalong" reel in the CD.');
INSERT INTO 'recording' VALUES (9313, '2013-02-22 14:54:44.738573+00', '2019-11-21 18:14:16.890119+00', 'Bees of Maggieknockater, The', 10209, 2, 4, 32, 9999, NULL, 145, 0, 'This recording does not use the recommended tune for the dance.');
INSERT INTO 'recording' VALUES (9314, '2013-02-22 14:58:32.665047+00', '2019-11-21 18:30:02.508904+00', 'Palais Glide, The', 10209, 50, 0, 0, 9999, NULL, 224, 0, '');
INSERT INTO 'recording' VALUES (9315, '2013-02-22 14:59:18.704522+00', '2019-11-21 18:31:13.687315+00', 'Irish Rover', 10209, 1, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (9317, '2013-02-22 15:03:56.116608+00', '2019-11-21 18:32:36.082912+00', 'Seton''s Ceilidh Band', 10209, 2, 4, 64, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (9318, '2013-02-22 15:05:02.808902+00', '2019-11-21 18:36:58.39544+00', 'Fisherman''s Reel', 10209, 1, 5, 32, 9999, NULL, 182, 0, 'This recording does not use the name tune, but the CD booklet references the dance.');
INSERT INTO 'recording' VALUES (9443, '2014-02-06 19:23:33.649979+00', '2019-11-22 19:10:32.146333+00', 'March', 2681, 11, 0, 0, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (9820, '2015-06-19 10:59:10.06576+00', '2019-11-22 19:13:41.723692+00', 'Carlin''s Cairn', 10000, 2, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (2171, NULL, '2019-11-22 19:19:50.323459+00', 'Strip the Willow (9/8)', 2059, 2, 4, 48, 9999, 4, 275, 0, '');
INSERT INTO 'recording' VALUES (6344, NULL, '2019-11-22 19:26:53.197577+00', 'Duke of Perth, The', 3017, 1, 8, 32, 9999, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (360, NULL, '2019-11-25 09:45:03.575292+00', 'West''s Hornpipe', 3017, 1, 4, 32, 9999, 5, 146, 0, '');
INSERT INTO 'recording' VALUES (311, NULL, '2019-11-26 22:21:35.391934+00', 'Set of Strathspeys', 3017, 3, 3, 32, 9999, 5, 192, 0, '');
INSERT INTO 'recording' VALUES (8947, '2012-12-27 12:09:47.994214+00', '2019-11-26 22:22:53.404563+00', 'MacDonald of the Isles encore', 903, 3, 3, 32, 9999, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (3362, NULL, '2019-11-26 22:23:45.190138+00', 'Cauld Kail', 2186, 4, 4, 32, 1, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (7568, NULL, '2019-12-03 22:33:55.244523+00', 'Corn Rigs suitable for Barley Riggs, Corn Dawgs, Lammas Nights, Riggs of Corn', 3217, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (10312, '2019-12-09 22:09:55.439546+00', '2020-01-20 11:02:28.284332+00', 'Set of Reels', 11568, 1, 4, 32, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (7243, NULL, '2019-12-12 21:04:17.507004+00', 'Let''s Celebrate', 10104, 2, 4, 40, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (7821, NULL, '2019-12-12 21:04:55.141324+00', 'Shepherd''s Crook, The', 3010, 3, 1, 72, NULL, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (7971, NULL, '2019-12-12 21:05:17.529134+00', 'Virginia Reel', 10209, 1, 8, 32, NULL, NULL, 272, 0, '');
INSERT INTO 'recording' VALUES (8101, NULL, '2019-12-12 21:05:37.881369+00', 'Shepherd''s Crook, The', 3023, 3, 1, 72, NULL, NULL, 146, 0, '');
INSERT INTO 'recording' VALUES (8237, NULL, '2019-12-12 21:06:11.27237+00', 'Highland Laddie', 10277, 1, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (8617, NULL, '2019-12-12 21:06:54.989203+00', 'Virginia Reel', 10541, 1, 8, 32, NULL, NULL, 264, 0, '');
INSERT INTO 'recording' VALUES (8774, NULL, '2019-12-12 21:07:52.056276+00', 'Foursome Reel, The', 2328, 4, 0, 112, 18, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (8825, NULL, '2019-12-12 21:08:27.974644+00', 'Anne', 2067, 3, 8, 32, NULL, NULL, 494, 0, '');
INSERT INTO 'recording' VALUES (2286, NULL, '2019-12-20 19:40:54.109565+00', 'Mason''s Apron, The', 3016, 1, 4, 32, 9999, 1, 142, 0, 'According to <<https://my.strathspey.org/dd/issue/1905/|issue 1905>> this is credited to members of Ed Bryde''s band, The Scottish Accent, the Bobby Frew Four, the Scotians, and The Flying Scotsmen.');
INSERT INTO 'recording' VALUES (10311, '2019-12-09 22:01:18.08652+00', '2019-12-23 21:18:02.283957+00', '6/8 Marches', 11568, 11, 0, 0, NULL, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (9963, '2016-12-14 23:14:57.636482+00', '2020-01-18 23:41:36.859399+00', 'Joy To The World', 3045, 2, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (10317, '2019-12-09 22:17:14.021736+00', '2020-01-20 11:31:32.198982+00', 'Slow Air & Slip Jig', 11568, 98, 0, 0, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (10314, '2019-12-09 22:13:28.255281+00', '2020-01-19 22:36:59.450267+00', 'When Reality Dawns', 11568, 3, 0, 0, NULL, NULL, 255, 0, 'Slow Air');
INSERT INTO 'recording' VALUES (10315, '2019-12-09 22:15:06.425128+00', '2020-01-19 22:57:32.703844+00', 'Set of Jigs', 11568, 2, 8, 32, NULL, NULL, 301, 0, '');
INSERT INTO 'recording' VALUES (10327, '2019-12-09 22:26:50.049211+00', '2020-01-19 23:10:50.650114+00', 'Set of Reels', 11568, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (10313, '2019-12-09 22:11:03.508887+00', '2020-01-19 23:27:36.431593+00', 'Salute to Ian Robertson', 11568, 3, 3, 32, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (10324, '2019-12-09 22:24:07.192007+00', '2020-01-21 10:27:56.662174+00', 'Set of Reels', 11568, 1, 5, 32, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (10319, '2019-12-09 22:19:07.144447+00', '2020-01-20 23:28:12.152692+00', 'Pipe Medley', 11568, 98, 0, 0, NULL, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (10320, '2019-12-09 22:20:23.464692+00', '2020-01-20 23:30:11.608095+00', 'Life, Love and Loss', 11568, 98, 0, 0, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (10321, '2019-12-09 22:21:18.968582+00', '2020-01-20 23:42:01.667142+00', 'Set of Jigs', 11568, 2, 5, 32, NULL, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (10328, '2019-12-09 22:27:35.966336+00', '2020-01-20 23:43:45.129003+00', 'Waltzes', 11568, 5, 0, 0, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (10323, '2019-12-09 22:23:02.68884+00', '2020-01-21 15:21:30.980518+00', 'Set of Strathspeys', 11568, 3, 4, 32, NULL, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (10325, '2019-12-09 22:24:50.841276+00', '2020-01-21 10:31:52.685181+00', 'Mathilde is a Delight', 11568, 3, 3, 32, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (10326, '2019-12-09 22:25:54.254976+00', '2020-01-21 10:43:50.230829+00', 'Pipe Jigs', 11568, 2, 6, 32, NULL, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (10322, '2019-12-09 22:22:11.551257+00', '2020-01-21 10:45:31.047712+00', 'Waltzes', 11568, 5, 0, 0, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (10365, '2020-05-21 10:10:15.981678+00', '2020-05-21 10:10:15.981678+00', 'None so Pretty', 11858, 1, 8, 40, NULL, NULL, 360, 0, '');
INSERT INTO 'recording' VALUES (10316, '2019-12-09 22:15:58.318213+00', '2020-01-21 15:25:16.338384+00', 'Set of Reels', 11568, 1, 8, 32, NULL, NULL, 299, 0, '');
INSERT INTO 'recording' VALUES (10366, '2020-05-21 10:13:05.531698+00', '2020-05-21 10:13:05.531698+00', 'Miss Hadden''s Reel', 11858, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (7366, NULL, '2020-01-22 23:51:58.39779+00', 'Band Medley', 2585, 4, 0, 0, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (10318, '2019-12-09 22:18:14.212188+00', '2022-08-06 23:05:08.726176+00', 'Set of Strathspeys', 11568, 3, 8, 32, NULL, NULL, 528, 0, '');
INSERT INTO 'recording' VALUES (8599, NULL, '2022-12-16 20:37:08.395677+00', 'Virginia Reel', 10108, 1, 8, 32, NULL, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (6869, NULL, '2022-12-18 21:53:53.882319+00', 'Braes of Busby, The', 10047, 3, 8, 32, NULL, NULL, 517, 0, '');
INSERT INTO 'recording' VALUES (10208, '2018-06-23 16:01:30.575786+00', '2022-12-10 18:43:01.707903+00', 'Monifieth Star (8R32) - as MP3 (8R48), The', 11651, 1, 8, 32, NULL, NULL, 278, 0, 'Original CD recording was wrongly 8x32, rerecorded version is available via <<http://www.rscds.org|RSCDS Homepage>>:  

RSCDS Homepage login / Media / Audio, Video / DuK MMM remastert tracks for "The Monifieth Star" and  "Newington Assembly"');
INSERT INTO 'recording' VALUES (9305, '2013-02-22 14:27:17.747087+00', '2022-12-20 11:02:25.367603+00', 'Viennese Swing', 10209, 5, 3, 32, 9999, NULL, 232, 0, 'See http://my.strathspey.org/dd/issue/1867/ for information about the associated dance.');
INSERT INTO 'recording' VALUES (6978, NULL, '2020-01-25 23:00:38.823022+00', 'Inverness Highland Ball', 3023, 4, 4, 64, 5, NULL, 398, 0, '');
INSERT INTO 'recording' VALUES (9940, '2016-10-30 22:31:32.138918+00', '2020-01-25 23:13:10.668411+00', 'Up & Doon the Doldenhorn', 3013, 2, 3, 32, NULL, NULL, 112, 0, '');
INSERT INTO 'recording' VALUES (10333, '2020-05-03 14:36:53.372344+00', '2020-05-08 18:28:00.301535+00', 'Itchy Fingers', 10114, 1, 3, 40, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (8908, '2012-06-12 15:15:48.770595+00', '2020-01-26 11:33:36.826551+00', 'Diamond Reflections', 3012, 3, 6, 32, NULL, NULL, 341, 0, '');
INSERT INTO 'recording' VALUES (1786, NULL, '2020-01-26 16:07:41.808286+00', 'Duchess Tree, The', 3026, 3, 8, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (9575, '2014-03-16 16:10:06.281428+00', '2020-01-26 22:24:31.010656+00', 'Seniors Be Full Power (Repeat)', 3008, 2, 3, 32, 9999, NULL, 101, 0, '');
INSERT INTO 'recording' VALUES (7313, NULL, '2020-01-26 22:40:41.255863+00', 'Adam Rennie''s Reels', 10114, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (8354, NULL, '2020-01-26 22:41:23.584374+00', 'Highlandman''s Umbrella, The', 3023, 1, 4, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (5875, NULL, '2020-01-27 09:20:17.033485+00', 'Braes of Breadalbane, The', 3023, 3, 8, 32, 9999, NULL, 481, 0, '');
INSERT INTO 'recording' VALUES (8928, '2012-06-17 15:01:57.004427+00', '2020-01-28 22:37:38.602444+00', 'Bauldy Bain''s Fiddle', 10000, 1, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (2822, NULL, '2020-01-28 22:38:09.678835+00', 'Strathspey and Reel Medley', 1782, 4, 0, 112, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10228, '2018-09-15 09:54:26.763052+00', '2020-01-30 22:31:58.272121+00', 'Warm-Up March', 10659, 11, 9, 16, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (9723, '2014-08-19 07:51:43.785582+00', '2020-01-30 22:32:37.465161+00', 'For Lack of Gold', 10982, 1, 8, 32, NULL, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (2675, NULL, '2020-02-01 17:15:59.405956+00', 'Postie''s Jig', 3045, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (8, NULL, '2020-02-04 02:40:08.886201+00', 'Anderson''s Rant', 3002, 1, 8, 32, 9999, 5, 283, 0, '');
INSERT INTO 'recording' VALUES (1031, NULL, '2020-02-11 09:38:23.845105+00', 'Knock of Braemoray', 2570, 2, 4, 40, 9999, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (322, NULL, '2020-02-11 11:35:22.818296+00', 'Sleepy Maggie', 3017, 1, 8, 32, 9999, 5, 278, 0, '');
INSERT INTO 'recording' VALUES (5655, NULL, '2020-02-15 16:24:13.657615+00', 'Slopes of Hlidarendi, The', 3403, 3, 3, 32, 9999, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (206, NULL, '2020-02-25 20:12:33.071826+00', 'Milltimber Jig, The', 3013, 2, 8, 32, 9999, 1, 275, 0, '');
INSERT INTO 'recording' VALUES (1410, NULL, '2020-02-26 22:08:12.908161+00', 'Lassies of Dunse', 3067, 2, 8, 32, 9999, 1, 267, 0, '');
INSERT INTO 'recording' VALUES (2515, NULL, '2020-03-11 00:43:46.457339+00', 'Shetland Reels', 2065, 1, 8, 32, 9999, 1, 279, 0, '');
INSERT INTO 'recording' VALUES (845, NULL, '2020-03-19 00:26:16.022354+00', 'Moudiewort, The', 3047, 2, 8, 32, 9999, 5, 278, 0, '');
INSERT INTO 'recording' VALUES (937, NULL, '2020-03-19 01:30:13.946851+00', 'Alder Burn, The', 3050, 2, 8, 32, 9999, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (7223, NULL, '2020-04-20 08:34:56.914309+00', 'Montgomeries'' Rant, The', 3069, 1, 4, 32, NULL, NULL, 140, 0, 'The tune <<ddt:Archie Menzies>> is apparently not mentioned in the notes accompanying the recording but is played as the 2nd tune according to Finlay Forbes in <<https://my.strathspey.org/dd/issue/2054/|issue 2054>>.');
INSERT INTO 'recording' VALUES (9501, '2014-03-13 15:50:26.982341+00', '2020-05-08 08:06:21.891289+00', 'Jack''s Jig', 10114, 1, 3, 32, 9999, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (10334, '2020-05-03 14:46:00.288652+00', '2020-05-08 18:28:25.129912+00', 'Lomond Hills', 10114, 3, 4, 32, NULL, NULL, 241, 0, '');
INSERT INTO 'recording' VALUES (3307, NULL, '2020-05-03 19:11:05.335902+00', 'Jessie''s Hornpipe', 2189, 1, 6, 32, 9999, NULL, 201, 0, 'In <<https://my.strathspey.org/dd/issue/2090/|issue 2090>> Finlay Forbes believes the 2nd tune may be The Wee Man on the Loom, but that is not confirmed.');
INSERT INTO 'recording' VALUES (10348, '2020-05-04 09:59:56.181039+00', '2020-05-08 18:37:07.433974+00', 'Tannadice', 10114, 1, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (10335, '2020-05-03 14:48:15.431542+00', '2020-05-08 18:28:46.187267+00', 'Love, Port and Sherry', 10114, 2, 6, 32, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (10349, '2020-05-04 10:01:21.727632+00', '2020-05-08 18:37:19.198875+00', 'Endearing Young Charms', 10114, 5, 4, 32, NULL, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (10336, '2020-05-03 14:50:47.693584+00', '2020-05-08 18:30:03.696403+00', '72nd''s Farewell to Aberdeen', 10114, 1, 3, 32, NULL, NULL, 110, 0, '');
INSERT INTO 'recording' VALUES (10344, '2020-05-04 09:52:59.831931+00', '2020-05-08 18:55:20.144585+00', 'Miss Gayton''s Hornpipe', 10114, 1, 3, 48, NULL, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (10351, '2020-05-21 08:56:10.17401+00', '2020-05-21 08:56:28.97143+00', 'Triumph, The', 11858, 1, 4, 24, NULL, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (2222, NULL, '2020-05-05 00:04:17.32499+00', 'Balquidder Strathspey', 2053, 3, 8, 32, 9999, 5, 486, 0, '');
INSERT INTO 'recording' VALUES (10337, '2020-05-03 14:52:27.303438+00', '2020-05-08 18:31:36.181113+00', 'Diamond in Sutton Coldfield, A', 10114, 3, 3, 32, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (10338, '2020-05-03 14:54:24.868019+00', '2020-05-08 18:31:54.6957+00', 'Piece of Cake, A', 10114, 2, 4, 32, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (10339, '2020-05-04 09:44:00.420217+00', '2020-05-08 18:32:09.868958+00', 'Jack''s Delight', 10114, 1, 6, 32, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (10347, '2020-05-04 09:58:37.849755+00', '2020-05-09 07:12:02.437333+00', 'Life in the Fast Lane', 10114, 2, 4, 40, NULL, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (182, NULL, '2020-05-09 08:03:09.597038+00', 'Macleod of Dunvegan', 3015, 1, 0, 60, 9999, NULL, 163, 0, 'The number of bars entered in the database for this recording (60) does not match the dance (136) - mistake?');
INSERT INTO 'recording' VALUES (3616, NULL, '2020-05-09 08:20:48.813821+00', 'Medley suitable for Rothesay Castle', 2247, 4, 0, 104, 36, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10330, '2020-05-02 16:54:16.176348+00', '2020-05-11 19:52:29.703923+00', 'Orcadian Jig', 10114, 2, 3, 48, NULL, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (10345, '2020-05-04 09:54:27.675693+00', '2020-05-11 21:34:36.567452+00', 'Country Dance', 10114, 2, 3, 40, NULL, NULL, 132, 0, '');
INSERT INTO 'recording' VALUES (10329, '2020-05-02 16:52:38.98126+00', '2020-05-08 18:25:52.34513+00', 'Mrs Norman McKeigan', 10114, 1, 5, 32, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (10352, '2020-05-21 08:59:21.863368+00', '2020-05-21 08:59:21.863368+00', 'Culla Bay', 11858, 3, 4, 32, NULL, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (10331, '2020-05-02 16:57:58.089692+00', '2020-05-08 18:26:29.447941+00', 'Iron Man, The', 10114, 4, 4, 32, 10034, NULL, 197, 0, '');
INSERT INTO 'recording' VALUES (10332, '2020-05-02 17:00:18.304672+00', '2020-05-08 18:27:24.829023+00', 'Miss Grace Hay''s Delight', 10114, 2, 5, 32, NULL, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (10341, '2020-05-04 09:48:09.911132+00', '2020-05-08 18:34:49.333612+00', 'Lochiel''s Welcome', 10114, 2, 3, 32, NULL, NULL, 107, 0, '');
INSERT INTO 'recording' VALUES (10342, '2020-05-04 09:50:06.232202+00', '2020-05-08 18:35:18.319124+00', 'Miss Susan Cooper', 10114, 1, 4, 48, NULL, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (10353, '2020-05-21 09:01:57.18482+00', '2020-05-21 09:01:57.18482+00', 'Mrs Stewart''s Jig', 11858, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (10346, '2020-05-04 09:56:58.803342+00', '2020-05-08 18:36:41.274309+00', 'Shetland Fiddlers'' Society, The', 10114, 3, 6, 32, NULL, NULL, 364, 0, '');
INSERT INTO 'recording' VALUES (2085, NULL, '2020-05-13 10:30:36.353248+00', 'Deuks Dang Ower my Daddie, The', 2053, 2, 8, 40, 9999, 6, 343, 0, '');
INSERT INTO 'recording' VALUES (2416, NULL, '2020-05-15 10:48:24.40612+00', 'Black Mountain Reel, The', 2068, 1, 5, 32, 9999, 5, 0, 0, '');
INSERT INTO 'recording' VALUES (10350, '2020-05-21 08:53:31.699605+00', '2020-05-21 08:53:31.699605+00', 'Tribute to the Borders', 11858, 2, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (10354, '2020-05-21 09:04:20.497102+00', '2020-05-21 09:06:08.112218+00', 'Lord MacLay''s Reel', 11858, 1, 4, 32, NULL, NULL, 184, 0, '');
INSERT INTO 'recording' VALUES (10357, '2020-05-21 09:24:33.465503+00', '2020-05-21 09:24:33.465503+00', 'Jim''s Tangents', 11858, 1, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (10358, '2020-05-21 09:28:18.357282+00', '2020-05-21 09:28:18.357282+00', 'Wind on Loch Fyne', 11858, 3, 3, 32, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (10359, '2020-05-21 09:41:50.097045+00', '2020-05-21 09:41:50.097045+00', 'Law Society of Scotland 70th Anniversary Jig', 11858, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (10360, '2020-05-21 09:48:00.606554+00', '2020-05-21 09:48:00.606554+00', 'Westminster Reel, The', 11858, 1, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (10362, '2020-05-21 10:00:32.95773+00', '2020-05-21 10:00:32.95773+00', 'John Cass', 11858, 2, 5, 32, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (10363, '2020-05-21 10:03:55.079087+00', '2020-05-21 10:03:55.079087+00', 'Stephen''s Found Baggage', 11858, 1, 4, 32, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (10364, '2020-05-21 10:08:14.379909+00', '2020-05-21 10:08:14.379909+00', 'Director Jim', 11858, 3, 4, 32, NULL, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (10355, '2020-05-21 09:08:28.492548+00', '2020-05-22 12:40:34.9515+00', 'Autumn in Appin', 11858, 3, 4, 32, NULL, NULL, 254, 1, '');
INSERT INTO 'recording' VALUES (10343, '2020-05-04 09:51:31.142198+00', '2020-05-26 21:49:47.860889+00', 'Ladylea Hill', 10114, 3, 4, 32, NULL, NULL, 241, 0, '');
INSERT INTO 'recording' VALUES (10361, '2020-05-21 09:52:27.806778+00', '2020-05-21 18:48:49.515817+00', 'Cape Town Wedding', 11858, 3, 8, 32, NULL, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (5451, NULL, '2020-05-24 09:44:59.873787+00', 'Sheena''s Buckle', 1502, 2, 8, 32, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (8466, NULL, '2020-05-27 13:39:44.784616+00', 'Highlandman Kissed His Mother, The', 10503, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (10369, '2020-05-29 10:33:45.567356+00', '2020-05-29 10:33:45.567356+00', 'Dominie, The', 11953, 3, 2, 64, NULL, NULL, 271, 0, '');
INSERT INTO 'recording' VALUES (10367, '2020-05-29 10:28:19.505841+00', '2020-05-29 15:34:00.589526+00', 'Brandons Of Los Angeles, The', 11953, 1, 8, 32, NULL, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (10372, '2020-05-29 15:42:11.127744+00', '2021-09-16 08:50:15.798768+00', 'Gleneagles Reel', 11953, 1, 8, 40, NULL, NULL, 366, 0, '');
INSERT INTO 'recording' VALUES (10373, '2020-05-29 15:58:50.369248+00', '2021-09-16 08:51:13.931052+00', 'Ladies of the Albert Hall', 11953, 4, 0, 112, 18, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (10356, '2020-05-21 09:20:26.752794+00', '2022-10-13 14:41:34.886326+00', 'Speirs Bruce - The Pole Star', 11858, 2, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (10340, '2020-05-04 09:46:01.728336+00', '2022-10-16 21:54:16.531854+00', 'Da Slockit Light', 10114, 3, 3, 32, NULL, NULL, 186, 0, '');
INSERT INTO 'recording' VALUES (10370, '2020-05-29 13:32:02.390191+00', '2022-12-19 22:59:15.636911+00', 'Falls of Clyde', 11953, 4, 2, 64, 5, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (10383, '2020-05-30 10:11:56.418482+00', '2021-09-16 09:07:57.154741+00', 'Simon Frasers Reel', 11953, 1, 8, 32, NULL, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (10371, '2020-05-29 13:34:39.964133+00', '2020-05-30 10:16:10.43219+00', 'Gassy Jack''s Eightsome', 11953, 4, 2, 64, 2, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (10398, '2020-07-04 15:07:24.164838+00', '2020-07-04 15:26:12.657736+00', 'Apple for the Teacher, An', 1042, 1, 4, 64, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10374, '2020-05-29 16:04:00.844502+00', '2021-09-16 08:51:54.029938+00', 'Lady Aberdeen Strathspey', 11953, 3, 8, 32, NULL, NULL, 520, 0, '');
INSERT INTO 'recording' VALUES (10378, '2020-05-29 16:21:35.887121+00', '2021-09-16 08:58:11.820072+00', 'Phaeton, The', 11953, 2, 1, 128, NULL, NULL, 162, 0, '');
INSERT INTO 'recording' VALUES (893, NULL, '2020-06-05 17:35:17.433162+00', 'Jig', 3006, 2, 8, 40, 9999, NULL, 345, 0, '');
INSERT INTO 'recording' VALUES (5912, NULL, '2020-06-05 18:01:08.780715+00', 'Sea Tangle of Skye', 3483, 3, 8, 32, 9999, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (7783, NULL, '2020-06-05 18:08:04.674442+00', 'Mid Lothian', 3006, 1, 8, 40, NULL, NULL, 345, 0, '');
INSERT INTO 'recording' VALUES (10385, '2020-06-11 19:12:54.864292+00', '2020-06-11 19:12:54.864292+00', 'Tin Wedding, The', 11958, 3, 8, 32, NULL, NULL, 0, 0, '1st tune given as Anne Evans (not found).');
INSERT INTO 'recording' VALUES (10386, '2020-06-11 19:15:22.579286+00', '2020-06-11 19:15:22.579286+00', 'Hebridean Weaving Lilt', 11958, 3, 0, 88, NULL, NULL, 0, 0, 'Assumed to be 88 bars.');
INSERT INTO 'recording' VALUES (10387, '2020-06-11 19:23:51.32443+00', '2020-06-11 19:23:51.32443+00', 'Edina''s Pride', 11958, 3, 8, 32, NULL, NULL, 0, 0, '3rd tune given as Memories of Aberdeen (not found on the web). 5th tune quoted as "Birthday Tribute to Susan Inglis" - assumed the same as "MIss Susan Inglis".');
INSERT INTO 'recording' VALUES (10388, '2020-06-11 19:29:20.584597+00', '2020-06-11 19:29:20.584597+00', 'Hopetoun House', 11958, 2, 4, 32, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10389, '2020-06-11 19:39:08.64749+00', '2020-06-11 19:39:08.64749+00', 'Set of Strathspeys', 11958, 3, 8, 32, NULL, NULL, 0, 0, 'Tunes 3-6 given as "The Lodge", "Marg Sherrit", "Miss Anne O Cumming", "The Fickle Lass" (none yet in SCDDB and not found on the web).');
INSERT INTO 'recording' VALUES (10390, '2020-06-11 19:42:21.402248+00', '2020-06-11 19:42:21.402248+00', 'Aird of Coigach', 11958, 2, 4, 48, NULL, NULL, 0, 0, '1st and 3rd tunes given as "Miss Menzies" and "Hugh Frazer". There are some options in SCDDB for the former but its not clear which one is used here and the latter is unknown.');
INSERT INTO 'recording' VALUES (10391, '2020-06-11 19:46:10.876843+00', '2020-06-11 19:46:10.876843+00', 'Set of Reels', 11958, 1, 6, 32, NULL, NULL, 0, 0, '1st and 3rd tunes given as "A Trip to Japan", "Avonlea" (unknown to SCDDB and not found on the web).');
INSERT INTO 'recording' VALUES (10392, '2020-06-11 19:47:59.825858+00', '2020-06-11 19:47:59.825858+00', 'Kinfauns Castle', 11958, 3, 5, 32, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10393, '2020-06-11 19:55:38.308626+00', '2020-06-11 19:55:38.308626+00', 'Iona Cross, The', 11959, 4, 0, 192, 3, NULL, 0, 0, '4th tune given as "Miss Murray" (not sure which of several possibilities).');
INSERT INTO 'recording' VALUES (10394, '2020-06-11 19:57:33.086255+00', '2020-06-11 19:57:33.086255+00', 'Thornhill Strathspey', 11959, 3, 3, 32, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10395, '2020-06-11 20:01:29.389576+00', '2020-06-11 20:01:29.389576+00', 'Rudha Dubh', 11959, 1, 4, 48, NULL, NULL, 0, 0, '1st and 2nd tunes guessed from presumed misspellings (Hamburry, Ned Kendal). 4th tune given as Pattingers Reel (unknown to SCDDB and not found on the web).');
INSERT INTO 'recording' VALUES (10396, '2020-06-11 20:06:41.422448+00', '2020-06-11 20:06:41.422448+00', 'Trip to Glasgow, A', 11959, 2, 8, 32, NULL, NULL, 0, 0, '4th tune guessed from presumed misspelling (Neil Flanertys Drake!).');
INSERT INTO 'recording' VALUES (10397, '2020-06-11 20:10:41.109649+00', '2020-06-11 20:10:41.109649+00', 'Atsuko''s Wedding', 11960, 1, 8, 32, NULL, NULL, 0, 0, '1st tune given as "24th October".');
INSERT INTO 'recording' VALUES (10384, '2020-06-11 19:10:38.704979+00', '2020-06-11 20:11:52.240552+00', 'Firth of Forth', 11958, 1, 0, 128, NULL, NULL, 0, 0, '2nd tune is quoted as "A Pipers Drone" but this was not found anywhere on the web.');
INSERT INTO 'recording' VALUES (10232, '2019-01-08 15:49:11.051211+00', '2020-06-12 13:01:58.82059+00', 'Rosss''s Reel', 3217, 1, 8, 32, NULL, NULL, 301, 0, '');
INSERT INTO 'recording' VALUES (5480, NULL, '2020-06-17 18:24:59.442291+00', 'Lady Catherine Bruce''s Reel', 2696, 2, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (5031, NULL, '2020-07-04 09:37:02.960578+00', 'Monmouth Ramble, The', 2729, 3, 4, 32, 9999, NULL, 254, 0, '');
INSERT INTO 'recording' VALUES (10399, '2020-07-04 15:08:29.690367+00', '2020-07-04 15:08:29.690367+00', 'Celebration Waltz', 1042, 5, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10401, '2020-07-04 15:14:57.966654+00', '2020-07-04 15:14:57.966654+00', 'Give Hands in Friendship', 1042, 1, 4, 64, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10402, '2020-07-04 15:15:57.627986+00', '2020-07-04 15:15:57.627986+00', 'Inspiration', 1042, 98, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10405, '2020-07-04 15:20:53.92095+00', '2020-07-04 15:20:53.92095+00', 'Seton''s Ceilidh Band', 1042, 2, 4, 64, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10404, '2020-07-04 15:19:45.611446+00', '2020-07-04 15:23:27.128859+00', 'Posthorn Gallop', 1042, 2, 4, 32, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10403, '2020-07-04 15:16:54.923651+00', '2020-07-04 15:24:08.914209+00', 'Musicians, The', 1042, 2, 4, 40, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10400, '2020-07-04 15:12:56.81904+00', '2020-07-04 15:25:30.460501+00', 'Dance for Rhoda', 1042, 2, 4, 32, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10410, '2020-07-31 16:17:51.847928+00', '2020-08-03 17:35:03.956845+00', 'Granny Kempock', 11972, 3, 8, 32, NULL, NULL, 507, 0, '');
INSERT INTO 'recording' VALUES (10411, '2020-07-31 16:29:51.35979+00', '2020-08-03 17:35:19.058719+00', 'Cloch Lighthouse, The', 11972, 2, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (10407, '2020-07-31 16:07:23.932213+00', '2020-08-03 17:33:54.897334+00', 'Cast Away', 11972, 3, 3, 32, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (10406, '2020-07-31 16:06:03.43699+00', '2020-08-03 17:33:26.25408+00', 'Abbotsford Lassies', 11972, 1, 4, 32, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (10408, '2020-07-31 16:10:12.692101+00', '2020-08-03 17:34:19.962662+00', 'Célébrations', 11972, 2, 8, 24, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (10409, '2020-07-31 16:11:14.77701+00', '2020-08-03 17:34:40.985874+00', 'Ann Banan', 11972, 1, 3, 32, NULL, NULL, 114, 0, '');
INSERT INTO 'recording' VALUES (10412, '2020-07-31 16:46:15.793053+00', '2020-08-03 17:35:51.864231+00', 'Montréal Diamond Anniversary Reel', 11972, 1, 6, 40, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (10413, '2020-07-31 16:47:34.089614+00', '2020-08-03 17:36:08.590788+00', 'Kiss the Lass Ye Like Best', 11972, 3, 6, 32, NULL, NULL, 369, 0, '');
INSERT INTO 'recording' VALUES (10414, '2020-07-31 16:52:02.202511+00', '2020-08-03 17:36:24.743793+00', 'Angus MacKinnon''s Hornpipe', 11972, 1, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (10415, '2020-07-31 16:57:13.84382+00', '2020-08-03 17:36:39.181914+00', 'Bauldy Bain''s Fiddle', 11972, 1, 8, 32, NULL, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (10416, '2020-07-31 16:58:20.903644+00', '2020-08-03 17:36:54.265874+00', 'Moonlight on Mount Royal', 11972, 5, 0, 0, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (5144, NULL, '2020-08-25 10:03:06.869503+00', 'Balgeddie Reel', 3002, 1, 5, 32, 9999, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (7538, NULL, '2020-08-26 23:58:06.70064+00', 'Roxburgh Castle Reel', 2412, 1, 8, 32, 9999, NULL, 291, 0, 'The name of the recording should probably have been "Roxburgh Caste", as that is the name of both the dance and or the lead tune');
INSERT INTO 'recording' VALUES (10382, '2020-05-30 10:09:57.598469+00', '2021-09-16 08:47:32.863096+00', 'Shoolbraids Jig', 11953, 2, 4, 40, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (10368, '2020-05-29 10:30:20.163853+00', '2021-09-16 08:48:32.902765+00', 'Dear David', 11953, 3, 8, 32, NULL, NULL, 509, 0, '');
INSERT INTO 'recording' VALUES (10375, '2020-05-29 16:08:25.143925+00', '2021-09-16 08:52:49.753525+00', 'Lions Gate', 11953, 1, 4, 40, NULL, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (10376, '2020-05-29 16:15:19.312639+00', '2021-09-16 08:53:37.252196+00', 'Mary Isdale''s Highland Schottische', 11953, 4, 3, 64, 5, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (10377, '2020-05-29 16:19:09.021399+00', '2021-09-16 08:57:27.845019+00', 'Mormaer Of Moray, The', 11953, 4, 0, 96, 11, NULL, 160, 0, '');
INSERT INTO 'recording' VALUES (10379, '2020-05-29 16:26:13.135055+00', '2021-09-16 09:04:16.70353+00', 'Piper Frap', 11953, 3, 2, 48, NULL, NULL, 205, 0, '');
INSERT INTO 'recording' VALUES (10380, '2020-05-30 09:54:21.307525+00', '2021-09-16 09:06:00.278537+00', 'Reel Of The 88th', 11953, 1, 3, 40, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (10381, '2020-05-30 09:57:26.634358+00', '2021-09-16 09:06:42.464732+00', 'Sandy Butterly', 11953, 2, 4, 48, NULL, NULL, 231, 0, '');
INSERT INTO 'recording' VALUES (10418, '2020-12-07 22:50:21.235103+00', '2022-03-01 23:44:15.383312+00', 'Petronella (3 couple set)', 709, 1, 6, 32, NULL, NULL, 210, 0, '');
INSERT INTO 'recording' VALUES (10417, '2020-12-07 22:49:19.511641+00', '2022-03-01 23:42:34.417656+00', 'Bonnie Lassie, A', 709, 2, 8, 32, NULL, NULL, 291, 0, 'Subtitle: Any Good Jig');
INSERT INTO 'recording' VALUES (10419, '2020-12-07 22:51:25.937297+00', '2022-03-01 23:48:33.836126+00', 'Miss Ogilvie''s Fancy', 709, 3, 8, 32, NULL, NULL, 515, 0, '');
INSERT INTO 'recording' VALUES (10420, '2020-12-07 22:55:09.668392+00', '2022-03-01 23:52:07.243992+00', 'Express, The', 709, 2, 8, 40, NULL, NULL, 359, 0, '');
INSERT INTO 'recording' VALUES (10423, '2020-12-07 23:08:41.655581+00', '2022-03-02 00:04:45.854066+00', 'Ruth''s Return to Glen Ravine', 709, 2, 8, 32, NULL, NULL, 291, 0, 'Subtitle: Any Good Jig');
INSERT INTO 'recording' VALUES (10424, '2020-12-07 23:18:20.212984+00', '2022-03-02 00:06:45.766971+00', 'Friday Night Musician, The', 709, 1, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (10425, '2020-12-07 23:20:24.003138+00', '2022-03-02 00:12:52.436723+00', 'Stuttgart Strathspey', 709, 3, 6, 32, NULL, NULL, 395, 0, 'For a 3 couple set.');
INSERT INTO 'recording' VALUES (10426, '2020-12-07 23:22:48.836473+00', '2022-03-02 00:16:51.675787+00', 'Links with St Petersburg', 709, 2, 8, 32, NULL, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (10427, '2020-12-07 23:23:46.113776+00', '2022-03-02 00:19:00.469439+00', 'Tri-Mariner, The', 709, 1, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (10428, '2020-12-07 23:24:53.152472+00', '2022-03-02 00:25:30.994468+00', 'Any Good Strathspey', 709, 3, 8, 32, NULL, NULL, 509, 0, 'Subtitle: St Anne''s Cathedral');
INSERT INTO 'recording' VALUES (10429, '2020-12-07 23:25:44.089549+00', '2022-03-02 00:28:45.6628+00', 'Any Good Jig', 709, 2, 8, 32, NULL, NULL, 291, 0, 'Subtitle: Miss Ali Bartlett');
INSERT INTO 'recording' VALUES (10430, '2020-12-07 23:26:50.294235+00', '2022-03-02 00:30:47.342437+00', 'Smiling Lila', 709, 1, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (5229, NULL, '2021-01-06 00:05:11.550543+00', 'Selection of Strathspeys', 3067, 3, 8, 32, 9999, NULL, 503, 0, '');
INSERT INTO 'recording' VALUES (10432, '2021-03-18 22:06:49.287477+00', '2021-03-18 22:06:49.287477+00', 'Miss Hadden''s Reel', 2039, 2, 5, 32, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10433, '2021-03-18 22:14:14.276511+00', '2021-03-18 22:14:14.276511+00', 'Schiehallion', 2039, 4, 1, 128, 2, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10434, '2021-03-18 22:19:06.609204+00', '2021-03-18 22:19:06.609204+00', 'Petronella', 2039, 1, 5, 32, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10435, '2021-03-18 22:25:08.597691+00', '2021-03-18 22:25:08.597691+00', 'Foursome Reel', 2039, 4, 1, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3046, NULL, '2021-03-20 19:54:29.224366+00', 'Queen''s Bridge, The', 2038, 1, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5218, NULL, '2021-03-23 21:34:14.240922+00', 'Durrisdear', 2944, 3, 4, 32, 9999, NULL, 259, 0, 'NB the spelling of this recording in SCDDB (Durrisdear) differs from that of the dance and tune (Durisdeer). A web search suggests the name of village also has a variable spelling.');
INSERT INTO 'recording' VALUES (1349, NULL, '2021-03-27 11:26:01.277664+00', 'Hame Came Our Gudeman', 3018, 3, 8, 32, 9999, 5, 470, 0, '');
INSERT INTO 'recording' VALUES (2037, NULL, '2021-03-29 19:27:47.436212+00', 'Bonnie Beauly Blooms, The', 3217, 1, 8, 32, 9999, NULL, 294, 0, '');
INSERT INTO 'recording' VALUES (722, NULL, '2021-04-03 00:02:02.681723+00', 'Oriel Strathspey', 3022, 3, 4, 32, 9999, 5, 252, 0, '');
INSERT INTO 'recording' VALUES (10436, '2021-04-03 15:33:01.737773+00', '2021-04-03 15:35:17.46892+00', 'Last of the Lairds, The', 2062, 2, 5, 32, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1969, NULL, '2021-04-04 21:35:49.967419+00', 'Bratach Bana', 3014, 1, 8, 32, 9999, 1, 265, 0, '');
INSERT INTO 'recording' VALUES (2873, NULL, '2021-04-05 13:07:19.462353+00', 'Medley-Flirtation Hornpipes', 2124, 1, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (4909, NULL, '2021-04-06 01:29:40.999152+00', 'Frisky, The', 3036, 2, 8, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (3098, NULL, '2021-04-07 09:46:40.147384+00', 'Lord MacLay''s Reel', 3010, 1, 4, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (4912, NULL, '2021-04-20 20:03:51.930037+00', 'Reel for Jeannie, A', 2137, 1, 4, 32, 9999, NULL, 148, 0, 'SCDDB originally listed tune 3 as <<ddt:Pat Donald#2752>> and tune 4 as <<ddt:The Rev. Peter Davidson#7554>>. However in <<https://my.strathspey.org/dd/issue/2438/|issue 2438>> Finlay Forbes reports that tune 3 is actually <<ddt:Bill Sutherland#1926>> and the 4th tune is a repeat of the first. This entry has been updated accordingly. It is not clear if the Book 40 CD has this correct or not.');
INSERT INTO 'recording' VALUES (10103, '2017-11-25 17:02:03.939189+00', '2021-04-24 10:50:18.333403+00', 'Memories', 11568, 3, 3, 32, 9999, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (7795, NULL, '2021-04-30 10:06:25.278112+00', 'Bob Sanders', 3137, 2, 8, 40, NULL, NULL, 354, 0, 'The RSCDS as uploaded the whole album to youtube as a playlist <<https://www.youtube.com/playlist?list=OLAK5uy_l4GSZ84YFy5Un22hyNLbSXOziMKmKUYFQ>>. However as reported in <<https://my.strathspey.org/dd/issue/2447/|issue 2447>> the "video" for Bob Sanders was uploaded incorrectly.');
INSERT INTO 'recording' VALUES (4804, NULL, '2021-05-03 09:18:58.858134+00', 'Jigs', 2185, 2, 6, 32, 9999, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (7775, NULL, '2021-05-12 18:49:25.345256+00', 'Priest and his Books, The', 3006, 2, 8, 24, NULL, NULL, 212, 0, 'SCDDB originally listed the 3rd tune as The Humors of California. However <<https://my.strathspey.org/dd/issue/2452/|issue 2452>> corrected this to Donnybrook Boy.');
INSERT INTO 'recording' VALUES (337, NULL, '2021-05-16 09:57:15.159411+00', 'Teviot Bridge', 3019, 2, 8, 24, 9999, 18, 203, 0, 'SCCDB originally had the 4th tune as <<ddt:Haymakers, The#2249>>. This was corrected to <<ddt:Harvest Time#652>> in accordance with <<https://my.strathspey.org/dd/issue/2449/|issue 2449>>.');
INSERT INTO 'recording' VALUES (10437, '2021-05-22 08:00:57.022935+00', '2021-05-22 08:00:57.022935+00', 'Strip The Willow', 3037, 101, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10438, '2021-05-22 08:01:39.534324+00', '2021-05-22 08:01:39.534324+00', 'Scottish Waltz', 3037, 5, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10439, '2021-05-22 08:03:12.867269+00', '2021-05-22 08:03:12.867269+00', 'Pea Strae Reel', 3037, 1, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10441, '2021-05-22 08:05:51.049304+00', '2021-05-22 08:05:51.049304+00', 'Barn Dance', 3037, 1, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10440, '2021-05-22 08:04:54.1502+00', '2021-05-22 08:10:16.875289+00', 'Dashing White Sergeant', 3037, 1, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10442, '2021-05-22 19:04:22.353219+00', '2021-05-22 19:04:22.353219+00', 'Paul Jones', 3037, 99, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10444, '2021-05-22 19:05:27.867931+00', '2021-05-22 19:05:27.867931+00', 'St. Bernard''s Waltz', 3037, 5, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5331, NULL, '2021-06-06 19:35:51.832404+00', 'McDonald Saunter, The', 3002, 11, 5, 32, 9999, NULL, 178, 0, '');
INSERT INTO 'recording' VALUES (10443, '2021-05-22 19:05:01.838611+00', '2021-05-22 19:08:47.48906+00', 'Gay Gordons', 3037, 11, 0, 16, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10445, '2021-05-23 11:55:19.317606+00', '2021-05-23 11:55:19.317606+00', 'Bothy Ballads', 3009, 1, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (2338, NULL, '2021-05-25 11:59:24.20356+00', 'Silver Wedding, The', 3069, 2, 6, 32, 9999, 1, 199, 0, '');
INSERT INTO 'recording' VALUES (2145, NULL, '2021-06-13 10:37:29.29704+00', 'Nottingham Lace', 3040, 1, 0, 96, 9999, 18, 0, 0, '');
INSERT INTO 'recording' VALUES (1346, NULL, '2021-06-13 13:09:48.519684+00', 'Braw Sir John', 3018, 1, 8, 32, 9999, 5, 278, 0, '');
INSERT INTO 'recording' VALUES (2029, NULL, '2021-06-15 07:43:17.926131+00', 'None so Pretty', 3056, 1, 4, 32, 9999, NULL, 0, 0, 'Entered in SCDDB as 32 bars, but the dance None So Pretty is 40 bars so this might be a mistake.');
INSERT INTO 'recording' VALUES (1857, NULL, '2021-06-20 22:14:39.499972+00', 'From the Broomielaw', 2047, 3, 4, 32, 9999, 5, 252, 0, '');
INSERT INTO 'recording' VALUES (1914, NULL, '2021-06-20 23:01:50.390824+00', 'Fairy Bridge, The', 3040, 2, 8, 32, 9999, 1, 274, 0, '');
INSERT INTO 'recording' VALUES (2645, NULL, '2021-06-21 21:32:02.678656+00', 'Miss Johnstone of Dumfries', 3067, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (682, NULL, '2021-06-21 21:33:29.995414+00', 'Windmills are Turning', 3039, 2, 4, 32, 9999, NULL, 128, 0, '');
INSERT INTO 'recording' VALUES (10449, '2021-08-13 21:21:35.436456+00', '2021-08-13 21:21:35.436456+00', 'Dunfermline to Sarasota', 12028, 3, 3, 32, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (2463, NULL, '2021-07-03 08:51:43.472448+00', 'New Scotland Strathspey, The', 3042, 3, 4, 40, 9999, 39, 296, 0, '');
INSERT INTO 'recording' VALUES (614, NULL, '2021-07-03 09:13:57.83596+00', 'Nether Bow has Vanished, The', 3018, 3, 4, 48, 9999, NULL, 380, 0, '');
INSERT INTO 'recording' VALUES (10446, '2021-06-30 11:18:05.508352+00', '2021-07-28 18:07:14.911303+00', 'Cranberry Tart, The', 10037, 2, 8, 32, NULL, NULL, 273, 0, '');
INSERT INTO 'recording' VALUES (10447, '2021-07-03 15:21:10.036918+00', '2021-07-04 09:57:04.784934+00', 'Ho! Tom Bombadil', 11521, 1, 3, 32, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (10448, '2021-08-13 21:19:05.761109+00', '2021-08-13 21:19:05.761109+00', 'Mrs Milne of Kinneff', 12028, 3, 4, 32, NULL, NULL, 258, 0, '');
INSERT INTO 'recording' VALUES (10450, '2021-08-13 21:26:20.514443+00', '2021-08-13 21:26:20.514443+00', 'Drummond Castle', 12028, 2, 4, 32, NULL, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (10451, '2021-08-13 21:28:46.948735+00', '2021-08-13 21:30:52.955379+00', 'We''ve Nae Electric', 12028, 1, 5, 32, NULL, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (1096, NULL, '2021-08-15 23:39:20.719351+00', 'Jimmy Shankland''s Reel', 3038, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3193, NULL, '2021-08-17 08:21:24.841101+00', 'Aileen''s Reel (Bonnie Geordie''s Wig)', 1556, 1, 8, 32, 9999, NULL, 274, 0, 'This track was also assigned to "Bonnie Geordie''s Wig" (see <<https://my.strathspey.org/dd/issue/2611/|issue 2611>>).');
INSERT INTO 'recording' VALUES (3194, NULL, '2021-08-17 08:22:17.048904+00', 'East of Yeadon (Kiss under the Stairs)', 1556, 2, 8, 32, 9999, NULL, 278, 0, 'This track was also assigned to "Kiss under the Stairs" (see <<https://my.strathspey.org/dd/issue/2611/|issue 2611>>).');
INSERT INTO 'recording' VALUES (3196, NULL, '2021-08-17 08:23:08.749329+00', 'Piper''s Glen (Lady Charlotte Bruce), The', 1556, 3, 8, 32, 9999, NULL, 519, 0, 'This track was also assigned to "Lady Charlotte Bruce" (see <<https://my.strathspey.org/dd/issue/2611/|issue 2611>>).');
INSERT INTO 'recording' VALUES (10452, '2021-08-20 14:25:26.621333+00', '2021-08-20 14:25:26.621333+00', 'Welcome to the Stagger Inn', 11858, 1, 6, 32, NULL, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (10453, '2021-08-20 14:28:12.055579+00', '2021-08-20 14:28:12.055579+00', '''Inn'' Strathspey, The', 11858, 3, 3, 32, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (10454, '2021-08-20 14:30:47.613513+00', '2021-08-20 14:30:47.613513+00', 'Barmaid''s Jig, The', 11858, 2, 5, 32, NULL, NULL, 180, 0, '');
INSERT INTO 'recording' VALUES (10455, '2021-08-20 14:33:15.355603+00', '2021-08-20 14:33:15.355603+00', 'Young Accordian Man, The', 11858, 1, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (10456, '2021-08-20 14:51:56.01614+00', '2021-08-20 14:51:56.01614+00', 'Tiger Two Step', 11858, 2, 4, 32, NULL, NULL, 143, 0, '');
INSERT INTO 'recording' VALUES (10457, '2021-08-20 14:59:31.025458+00', '2021-08-20 14:59:31.025458+00', 'Ewan''s Midnight Medley', 11858, 4, 1, 128, 10034, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (10458, '2021-08-20 15:02:10.169742+00', '2021-08-20 15:02:10.169742+00', 'Demo Dandy Dancers', 11858, 1, 4, 32, NULL, NULL, 150, 1, '');
INSERT INTO 'recording' VALUES (10459, '2021-08-20 15:06:10.970369+00', '2021-08-20 15:06:10.970369+00', 'Da Trowie Reel', 11858, 4, 3, 32, 1, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (10460, '2021-08-20 15:08:31.371735+00', '2021-08-20 15:08:31.371735+00', 'Stagger Dream', 11858, 3, 3, 40, NULL, NULL, 236, 0, '');
INSERT INTO 'recording' VALUES (10431, '2020-12-07 23:27:53.71297+00', '2022-03-02 00:31:46.632261+00', 'Jappy Farewell Waltz, The', 709, 5, 1, 144, NULL, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (464, NULL, '2022-12-09 19:55:02.611394+00', 'Cumberland Reel', 3018, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (10461, '2021-08-20 15:10:32.972242+00', '2021-08-20 15:10:32.972242+00', '2am Jig, The', 11858, 2, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (10462, '2021-08-20 15:13:36.242858+00', '2021-08-20 15:13:36.242858+00', 'Last Orders', 11858, 3, 8, 32, NULL, NULL, 495, 0, '');
INSERT INTO 'recording' VALUES (10463, '2021-08-20 15:18:11.036774+00', '2021-08-20 15:18:11.036774+00', 'Staggering Hame', 11858, 2, 3, 32, NULL, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (6696, NULL, '2021-09-03 02:29:12.918297+00', 'George Scroggie''s Strathspey', 10034, 3, 4, 32, NULL, NULL, 245, 0, '');
INSERT INTO 'recording' VALUES (6308, NULL, '2021-09-23 19:09:31.129598+00', 'There''s Nae Luck Aboot the Hoose', 1396, 3, 8, 32, 9999, NULL, 505, 0, '');
INSERT INTO 'recording' VALUES (6306, NULL, '2021-09-23 19:23:34.567288+00', 'Maggie Lauder', 1396, 3, 8, 32, 9999, NULL, 491, 0, 'The 3rd tune is listed as "Dr Hardie" in the insert for the Book 10 CD. The usual searches did not turn up any information about it.');
INSERT INTO 'recording' VALUES (10464, '2021-09-30 20:18:01.312905+00', '2021-09-30 20:18:43.183054+00', 'Joanna''s Jig', 12069, 2, 6, 32, NULL, NULL, 212, 0, '');
INSERT INTO 'recording' VALUES (10465, '2021-09-30 20:27:14.884805+00', '2021-09-30 20:27:14.884805+00', 'John McLean''s Reel', 12069, 1, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (10466, '2021-09-30 20:31:19.63516+00', '2021-09-30 20:31:19.63516+00', 'Speyside Way, The', 12069, 3, 3, 32, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (10467, '2021-09-30 20:39:17.158376+00', '2021-09-30 20:39:17.158376+00', 'Fond Farewell, A', 12069, 2, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (10468, '2021-09-30 20:42:28.647471+00', '2021-09-30 20:42:28.647471+00', 'Millbank Reel, The', 12069, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (10469, '2021-09-30 20:44:43.392908+00', '2021-09-30 20:44:43.392908+00', 'Portsoy Links', 12069, 3, 3, 32, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (10470, '2021-09-30 20:50:29.001349+00', '2021-09-30 20:50:29.001349+00', 'Behind the Scenes', 12069, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (10471, '2021-09-30 20:54:29.588039+00', '2021-09-30 20:54:29.588039+00', 'Moray Rambler, The', 12069, 1, 8, 32, NULL, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (10472, '2021-09-30 20:57:38.128058+00', '2021-09-30 20:57:38.128058+00', 'Banffshire Centenarian, The', 12069, 3, 5, 32, NULL, NULL, 312, 0, '');
INSERT INTO 'recording' VALUES (10473, '2021-09-30 21:05:01.489556+00', '2021-09-30 21:05:01.489556+00', 'Haudagain Roundabout, The', 12069, 2, 4, 32, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (10474, '2021-09-30 21:08:04.788193+00', '2021-09-30 21:08:04.788193+00', 'Bouquet of Flowers, A', 12069, 1, 8, 48, NULL, NULL, 426, 0, '');
INSERT INTO 'recording' VALUES (10475, '2021-09-30 21:17:07.009332+00', '2021-09-30 21:17:07.009332+00', 'Ladies of Banffshire, The', 12069, 3, 4, 32, NULL, NULL, 251, 0, '');
INSERT INTO 'recording' VALUES (10476, '2021-09-30 21:20:07.650071+00', '2021-09-30 21:20:07.650071+00', 'Ladies of Banffshire, The', 12069, 3, 3, 32, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (97, NULL, '2021-10-21 18:10:40.506449+00', 'Gathering, The', 3002, 1, 8, 32, 9999, 5, 277, 0, '');
INSERT INTO 'recording' VALUES (406, NULL, '2021-11-05 19:19:55.60081+00', 'Fete Champetre', 1396, 2, 1, 128, 9999, 1, 148, 0, '128 bars plus 8 bars Intro');
INSERT INTO 'recording' VALUES (2962, NULL, '2021-11-24 23:09:08.242444+00', 'Cadgers in the Canongate', 2328, 1, 4, 48, 9999, NULL, 191, 0, 'According to <<https://my.strathspey.org/dd/issue/2664/|issue 2664>> the lead tune is <<ddt:John McNeil''s Reel>> and not <<ddt:Cadgers in the Canongate>> as originally entered in SCDDB for this recording.');
INSERT INTO 'recording' VALUES (9630, '2014-03-27 14:14:36.087937+00', '2021-11-24 23:12:20.574982+00', 'Cadgers in the Canongate', 2328, 1, 4, 48, 9999, NULL, 200, 0, 'According to <<https://my.strathspey.org/dd/issue/2664/|issue 2664>> the lead tune is <<ddt:John McNeil''s Reel>> which was previously not listed in SCDDB for this recording.');
INSERT INTO 'recording' VALUES (10481, '2021-11-26 11:49:32.944332+00', '2021-11-26 11:49:32.944332+00', 'Provost Wynd, The', 3658, 1, 2, 32, NULL, NULL, 79, 0, '');
INSERT INTO 'recording' VALUES (10482, '2021-11-26 11:54:59.996672+00', '2021-11-26 11:54:59.996672+00', 'It''s All Right', 3658, 2, 2, 32, NULL, NULL, 79, 0, '');
INSERT INTO 'recording' VALUES (10483, '2021-11-26 11:58:19.619924+00', '2021-11-26 11:58:19.619924+00', 'Braes of Balluder, The', 3658, 1, 2, 32, NULL, NULL, 79, 0, '');
INSERT INTO 'recording' VALUES (10484, '2021-11-26 12:06:46.236502+00', '2021-11-26 12:06:46.236502+00', 'Inverneill House', 3658, 1, 2, 32, NULL, NULL, 81, 0, '');
INSERT INTO 'recording' VALUES (10485, '2021-11-26 12:36:11.638258+00', '2021-11-26 12:36:11.638258+00', 'Tribute to the Borders', 3658, 2, 2, 32, NULL, NULL, 78, 0, '');
INSERT INTO 'recording' VALUES (10486, '2021-11-26 12:39:08.225926+00', '2021-11-26 12:39:08.225926+00', 'Silver Tassie, The', 3658, 3, 2, 32, NULL, NULL, 133, 0, '');
INSERT INTO 'recording' VALUES (10489, '2021-11-26 16:33:08.151455+00', '2021-11-26 16:33:08.151455+00', 'Swiss Lassie', 3658, 1, 2, 32, NULL, NULL, 81, 0, '');
INSERT INTO 'recording' VALUES (10479, '2021-11-26 11:43:20.257322+00', '2021-11-27 09:31:45.684602+00', 'Waratah Weaver, The', 3658, 2, 1, 32, NULL, NULL, 43, 0, '');
INSERT INTO 'recording' VALUES (10478, '2021-11-25 22:25:21.908411+00', '2021-11-27 10:53:52.7414+00', 'Mr Michael Bear''s Reel', 3658, 1, 2, 32, NULL, NULL, 80, 0, '');
INSERT INTO 'recording' VALUES (10488, '2021-11-26 16:31:08.951662+00', '2021-11-27 10:54:21.079093+00', 'Brudenell Jig, The', 3658, 2, 2, 32, NULL, NULL, 76, 0, '');
INSERT INTO 'recording' VALUES (10480, '2021-11-26 11:47:31.240195+00', '2021-11-27 10:54:57.561315+00', 'Hedwig''s Reel', 3658, 1, 2, 32, NULL, NULL, 80, 0, '');
INSERT INTO 'recording' VALUES (10487, '2021-11-26 12:40:35.51115+00', '2021-11-27 10:57:18.192615+00', 'Capital Jig, A', 3658, 2, 2, 32, NULL, NULL, 78, 0, '');
INSERT INTO 'recording' VALUES (10477, '2021-11-25 22:19:19.989438+00', '2021-11-28 20:45:53.346697+00', 'Merry Reapers, The', 3658, 2, 2, 24, NULL, NULL, 60, 0, '');
INSERT INTO 'recording' VALUES (10490, '2021-12-02 11:57:22.74509+00', '2021-12-02 11:58:55.153823+00', 'Between Yews and Willows', 3179, 3, 3, 32, 9999, NULL, 0, 0, 'The recording is accessible as MP3 from https://drive.google.com/drive/folders/1hWXHwuPxXlBa8F94hKA7i3255_coPtD9');
INSERT INTO 'recording' VALUES (6455, NULL, '2021-12-08 23:49:49.426338+00', 'Ms Katy B.', 1846, 1, 4, 32, 9999, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (6518, NULL, '2021-12-12 21:17:19.99263+00', 'Magic of Merrill, The', 10000, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (779, NULL, '2021-12-21 10:33:48.372634+00', 'Many Happy Returns', 3399, 3, 8, 32, 9999, NULL, 525, 0, '');
INSERT INTO 'recording' VALUES (781, NULL, '2021-12-21 10:34:18.433746+00', 'Arthur''s Seat', 3399, 1, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (4505, NULL, '2021-12-21 10:37:30.478621+00', 'Saint John River, The', 3399, 3, 4, 32, 9999, NULL, 278, 0, '');
INSERT INTO 'recording' VALUES (776, NULL, '2022-08-31 21:47:22.813953+00', 'On the Morning Tide', 3399, 1, 8, 32, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (5671, NULL, '2021-12-21 10:40:27.07612+00', 'Laird of Milton''s Daughter', 3399, 2, 8, 32, 9999, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (4692, NULL, '2022-01-09 23:53:18.498635+00', 'It''s Just For Fun', 2586, 2, 8, 32, 9999, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (9790, '2015-05-31 08:45:57.14455+00', '2022-01-12 23:07:26.970002+00', 'Ian Powrie''s Farewell to Auchterarder', 10037, 2, 1, 128, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (9803, '2015-05-31 09:31:12.262212+00', '2022-01-12 23:14:41.133211+00', 'Cherrybank Gardens', 10037, 3, 3, 32, 9999, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (10494, '2022-01-13 14:13:58.427588+00', '2022-01-13 14:13:58.427588+00', 'Trip to Orlova', 2944, 1, 8, 32, NULL, NULL, 279, 0, '');
INSERT INTO 'recording' VALUES (10495, '2022-01-13 14:16:12.197197+00', '2022-01-13 14:21:05.428941+00', 'Ninety Years On', 2944, 3, 4, 40, NULL, NULL, 320, 0, '');
INSERT INTO 'recording' VALUES (10491, '2022-01-13 14:03:06.53625+00', '2022-01-13 17:21:26.386397+00', 'Reel or Two for Sheila, A', 2944, 1, 4, 40, NULL, NULL, 177, 0, '');
INSERT INTO 'recording' VALUES (10492, '2022-01-13 14:04:45.825744+00', '2022-01-13 17:25:45.323531+00', 'Skeely Skipper, The', 2944, 2, 3, 40, NULL, NULL, 136, 0, '');
INSERT INTO 'recording' VALUES (10493, '2022-01-13 14:08:51.558355+00', '2022-01-13 17:26:17.309595+00', 'Red Rose, The', 2944, 3, 4, 32, NULL, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (10496, '2022-01-13 17:31:40.952437+00', '2022-01-13 17:31:40.952437+00', 'Jig for John Philip, A', 2944, 2, 5, 40, NULL, NULL, 224, 0, '');
INSERT INTO 'recording' VALUES (10497, '2022-01-13 17:36:33.915313+00', '2022-01-13 17:36:33.915313+00', 'Louise Carnegie Gates, The', 2944, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (10498, '2022-01-13 17:41:14.344209+00', '2022-01-13 17:41:14.344209+00', 'Linktown Strathspey', 2944, 3, 6, 32, NULL, NULL, 399, 0, '');
INSERT INTO 'recording' VALUES (10499, '2022-01-13 17:50:20.81238+00', '2022-01-13 17:50:20.81238+00', 'Peacocks in the Glen', 2944, 1, 4, 32, NULL, NULL, 204, 0, '');
INSERT INTO 'recording' VALUES (10500, '2022-01-13 18:18:32.488582+00', '2022-01-13 18:18:32.488582+00', 'Dunfermline to Sarasota', 2944, 3, 3, 32, NULL, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (10501, '2022-01-13 18:43:54.141774+00', '2022-01-13 18:43:54.141774+00', 'Queen Margaret''s Crown', 2944, 1, 1, 96, NULL, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (10502, '2022-01-13 19:43:03.147212+00', '2022-01-13 19:43:03.147212+00', 'Nethertown Nights', 2944, 3, 3, 32, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (10503, '2022-01-13 19:46:36.422288+00', '2022-01-13 19:46:36.422288+00', 'Queensferry Crossing, The', 2944, 2, 4, 32, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (10504, '2022-01-13 19:49:15.528452+00', '2022-01-13 19:49:15.528452+00', 'Countess of Elgin, The', 2944, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (10505, '2022-01-13 19:51:51.81049+00', '2022-01-13 19:51:51.81049+00', 'Glen Pavilion, The', 2944, 3, 4, 32, NULL, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (10506, '2022-01-13 19:55:04.606935+00', '2022-01-13 19:55:04.606935+00', 'Abbot House', 2944, 1, 1, 80, NULL, NULL, 94, 0, '');
INSERT INTO 'recording' VALUES (1475, NULL, '2022-01-16 21:30:34.570141+00', 'Winding Road, The', 2033, 3, 4, 32, 9999, 1, 239, 0, '');
INSERT INTO 'recording' VALUES (895, NULL, '2022-01-17 23:32:00.730063+00', 'Seaton''s Ceilidh Band', 3006, 2, 4, 64, 9999, NULL, 278, 0, 'Checking a few online music websites it seems the title on the CD is "Seaton" whereas the spelling of the dance and tune are both "Seton". See also <<https://my.strathspey.org/dd/issue/2701/|issue 2701>>.');
INSERT INTO 'recording' VALUES (2985, NULL, '2022-01-21 23:13:18.670518+00', 'MacDonald of the Isles', 3008, 3, 3, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (8879, '2012-05-09 15:52:41.677599+00', '2022-01-23 12:10:35.995504+00', 'Dilemma, The', 1502, 4, 3, 96, 54, NULL, 508, 0, '');
INSERT INTO 'recording' VALUES (7149, NULL, '2022-07-24 23:19:58.88824+00', 'Strathspeys', 10095, 3, 3, 32, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (5670, NULL, '2022-09-01 15:25:24.930779+00', 'Irongray', 3399, 3, 8, 32, 9999, NULL, 533, 0, '');
INSERT INTO 'recording' VALUES (7028, NULL, '2022-12-19 16:29:47.734037+00', 'St Johnstoun Reel, The', 10037, 1, 8, 32, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (7903, NULL, '2022-01-24 09:54:42.511559+00', 'Chasing Shadows', 3479, 1, 0, 64, NULL, NULL, 103, 0, '');
INSERT INTO 'recording' VALUES (411, NULL, '2022-01-26 01:40:27.043654+00', 'Silver Star, The', 3026, 3, 3, 32, 9999, 1, 201, 0, '');
INSERT INTO 'recording' VALUES (5999, NULL, '2022-01-28 10:51:30.125192+00', 'New Scotia Quadrille', 3530, 1, 2, 48, 9999, NULL, 113, 0, '');
INSERT INTO 'recording' VALUES (3253, NULL, '2022-02-03 23:53:00.11768+00', 'London Highland Club''s Farewell to Fetter Lane, The', 3014, 1, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (8831, NULL, '2022-02-10 20:26:20.2747+00', 'Geordie Diamond, The', 3039, 3, 3, 40, NULL, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (10421, '2020-12-07 22:56:33.772295+00', '2022-03-02 00:01:07.953232+00', 'Links o'' Forth', 709, 1, 8, 32, NULL, NULL, 284, 0, 'Subtitle: Any Good Hornpipe');
INSERT INTO 'recording' VALUES (10422, '2020-12-07 22:57:42.319857+00', '2022-03-02 00:02:56.547124+00', 'Delta Borderers'' 25th, The', 709, 3, 3, 32, NULL, NULL, 198, 0, '');
INSERT INTO 'recording' VALUES (5179, NULL, '2022-03-28 22:01:38.075309+00', 'King''s Croft', 1396, 1, 3, 32, 9999, NULL, 109, 0, '');
INSERT INTO 'recording' VALUES (9600, '2014-03-26 15:15:50.630465+00', '2022-04-07 19:00:27.511196+00', 'Old St Pauls', 10936, 5, 0, 0, 9999, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (8356, NULL, '2022-04-18 09:03:34.894517+00', 'Letham Ladies', 3023, 3, 4, 40, NULL, NULL, 316, 0, '');
INSERT INTO 'recording' VALUES (5498, NULL, '2022-04-22 23:32:57.676701+00', 'Secret Garden, The', 3023, 3, 3, 40, 9999, NULL, 238, 0, 'The back cover of the CD incorrectly states that the recording is 3x48S, this database has the correct number of bars (3x40S),');
INSERT INTO 'recording' VALUES (5216, NULL, '2022-04-24 09:01:32.577411+00', 'Lochindorb Strathspey', 2944, 3, 6, 32, 9999, NULL, 382, 0, '');
INSERT INTO 'recording' VALUES (8266, NULL, '2022-04-26 12:14:34.174148+00', 'Fisherman''s Reel', 3217, 1, 5, 32, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (10507, '2022-04-29 20:43:26.625969+00', '2022-04-29 20:43:26.625969+00', 'Welcome to Argentina', 12122, 2, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (10508, '2022-04-29 20:50:01.498951+00', '2022-04-29 20:50:01.498951+00', 'Florida Street "Cambio Cambio"', 12122, 3, 8, 32, NULL, NULL, 516, 0, '');
INSERT INTO 'recording' VALUES (10509, '2022-04-29 20:55:49.167847+00', '2022-04-29 20:55:49.167847+00', 'Salinas Grandes', 12122, 1, 8, 32, NULL, NULL, 301, 0, '');
INSERT INTO 'recording' VALUES (10510, '2022-04-29 21:14:41.228197+00', '2022-04-29 21:14:41.228197+00', 'Siete Colores', 12122, 3, 4, 32, NULL, NULL, 257, 0, '');
INSERT INTO 'recording' VALUES (10511, '2022-04-29 21:29:03.361616+00', '2022-04-29 21:29:03.361616+00', 'Barolo Palace Tower', 12122, 4, 2, 64, 5, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (10512, '2022-04-29 21:33:01.384207+00', '2022-04-29 21:33:01.384207+00', 'Charly''s Strathspey', 12122, 3, 3, 32, NULL, NULL, 196, 0, '');
INSERT INTO 'recording' VALUES (10514, '2022-04-29 21:45:17.493801+00', '2022-04-29 21:45:17.493801+00', 'Jacarandas of Buenos Aires, The', 12122, 3, 8, 32, NULL, NULL, 496, 0, '');
INSERT INTO 'recording' VALUES (10515, '2022-04-29 21:51:24.505591+00', '2022-04-29 21:51:24.505591+00', 'Insurance Man from BA, The', 12122, 1, 8, 32, NULL, NULL, 298, 0, '');
INSERT INTO 'recording' VALUES (10516, '2022-04-29 21:54:20.59299+00', '2022-04-29 21:54:20.59299+00', 'Aberdeenshire Meets Argentina', 12122, 3, 3, 32, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (10517, '2022-04-29 22:04:36.762815+00', '2022-04-29 22:04:36.762815+00', 'On the Tropic of Capricorn', 12122, 2, 8, 32, NULL, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (10519, '2022-04-29 22:17:22.576468+00', '2022-04-29 22:17:22.576468+00', 'Purmamarca Market', 12122, 3, 4, 32, NULL, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (10518, '2022-04-29 22:13:41.470885+00', '2022-04-29 22:35:11.850603+00', 'Four Spoons, The', 12122, 3, 4, 32, NULL, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (10521, '2022-05-03 21:14:51.268539+00', '2022-05-03 21:14:51.268539+00', 'Claverhouse Rant', 11858, 1, 4, 32, NULL, NULL, 154, 0, '');
INSERT INTO 'recording' VALUES (10522, '2022-05-03 21:23:57.480438+00', '2022-05-03 21:23:57.480438+00', 'Get Knotted', 11858, 2, 3, 32, NULL, NULL, 117, 0, '');
INSERT INTO 'recording' VALUES (10524, '2022-05-03 21:39:22.766289+00', '2022-05-03 21:39:22.766289+00', 'Across the Waves', 11858, 1, 4, 32, NULL, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (10525, '2022-05-03 21:47:11.513686+00', '2022-05-03 21:47:11.513686+00', 'Ready Aye Ready', 11858, 1, 5, 32, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (10537, '2022-06-25 18:31:29.43009+00', '2022-06-25 18:33:38.669656+00', 'Jesmond Saunter', 3008, 3, 8, 32, NULL, NULL, 490, 0, '');
INSERT INTO 'recording' VALUES (1675, NULL, '2022-05-06 01:42:36.834517+00', 'Bonnie Flowers O''er the Muir', 2035, 3, 8, 32, 9999, 5, 512, 0, '');
INSERT INTO 'recording' VALUES (10523, '2022-05-03 21:35:35.789712+00', '2022-05-07 09:12:18.825583+00', 'Trinity Launch', 11858, 3, 4, 32, NULL, NULL, 266, 0, '');
INSERT INTO 'recording' VALUES (1469, NULL, '2022-05-07 21:43:29.655242+00', 'Muirland Willie', 2033, 2, 8, 32, 9999, 1, 262, 0, '');
INSERT INTO 'recording' VALUES (7082, NULL, '2022-05-16 23:06:20.478945+00', 'Moray Firth Hornpipe, The', 2586, 1, 8, 32, NULL, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (1268, NULL, '2022-05-17 07:15:11.498475+00', 'Charmer, The', 3018, 2, 8, 32, 9999, 1, 269, 0, '');
INSERT INTO 'recording' VALUES (10513, '2022-04-29 21:40:03.422208+00', '2022-05-27 19:02:53.101381+00', 'Road to Cafayate, The', 12122, 2, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (7762, NULL, '2022-05-29 10:40:43.459677+00', 'Edinburgh Volunteers, The', 3011, 3, 8, 24, NULL, NULL, 369, 0, '');
INSERT INTO 'recording' VALUES (5355, NULL, '2022-05-29 10:42:11.52359+00', 'Sugar Spoon, The', 3139, 3, 3, 48, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (6010, NULL, '2022-05-31 11:37:58.542217+00', 'Chippy''s Rant', 1557, 2, 3, 32, 9999, NULL, 107, 0, '');
INSERT INTO 'recording' VALUES (110, NULL, '2022-05-31 13:46:15.346838+00', 'Golden Wedding Strathspey, The', 3019, 3, 4, 40, 9999, 6, 313, 0, '');
INSERT INTO 'recording' VALUES (6671, NULL, '2022-05-31 13:46:43.006288+00', 'Golden Wedding Strathspey, The', 10034, 3, 4, 40, NULL, NULL, 314, 0, '');
INSERT INTO 'recording' VALUES (6872, NULL, '2022-05-31 13:51:35.170645+00', 'Cauld Kail', 10047, 4, 8, 32, 1, NULL, 400, 0, '');
INSERT INTO 'recording' VALUES (6385, NULL, '2022-06-18 05:33:16.369524+00', 'Lauraine''s Delight', 3217, 1, 3, 48, 9999, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (5068, NULL, '2022-06-20 08:30:31.962913+00', 'Polharrow Burn', 3009, 1, 5, 32, 9999, NULL, 173, 0, 'According to <<https://my.strathspey.org/dd/issue/2817/|issue 2817>> this recording was lifted from the Jim MacLeod LP "Lassie Come and Dance with Me" (presumably track B3).');
INSERT INTO 'recording' VALUES (10520, '2022-04-29 22:21:02.545493+00', '2022-06-21 15:47:25.125394+00', 'Iguazú Falls, The', 12122, 1, 8, 32, NULL, NULL, 302, 0, '');
INSERT INTO 'recording' VALUES (10527, '2022-06-25 17:44:45.663598+00', '2022-06-25 17:47:37.907171+00', 'Sheila of Morpeth', 3217, 3, 4, 40, NULL, NULL, 320, 1, '');
INSERT INTO 'recording' VALUES (10528, '2022-06-25 17:50:49.17481+00', '2022-06-25 17:50:49.17481+00', 'Jig for Jean, A', 3217, 2, 8, 32, NULL, NULL, 293, 0, '');
INSERT INTO 'recording' VALUES (10529, '2022-06-25 17:53:44.205312+00', '2022-06-25 17:53:44.205312+00', 'Robert''s Rant', 3217, 1, 8, 32, NULL, NULL, 298, 0, '');
INSERT INTO 'recording' VALUES (10530, '2022-06-25 17:58:05.417416+00', '2022-06-25 18:04:26.757845+00', 'Gill''s Jig', 3217, 2, 4, 32, NULL, NULL, 152, 0, 'Tune 4 (The Speed Bump) is the same as The Speed Hump');
INSERT INTO 'recording' VALUES (10531, '2022-06-25 18:07:43.42631+00', '2022-06-25 18:07:43.42631+00', 'Bird Man, The', 3217, 2, 8, 32, NULL, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (10532, '2022-06-25 18:10:05.039538+00', '2022-06-25 18:10:05.039538+00', 'Time to Spare', 3217, 3, 3, 32, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (10533, '2022-06-25 18:11:52.703529+00', '2022-06-25 18:11:52.703529+00', 'Shadows', 3217, 3, 3, 32, NULL, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (10536, '2022-06-25 18:29:03.961856+00', '2022-06-27 21:30:48.991755+00', 'Quince Jelly', 3008, 4, 4, 32, 10020, NULL, 202, 0, 'The tune "David John Robertson" is in the book, but not used in this recording.');
INSERT INTO 'recording' VALUES (10538, '2022-06-25 18:35:20.537256+00', '2022-06-25 18:35:56.611543+00', 'Cathie Smith''s Reel', 3008, 1, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (10539, '2022-06-25 18:39:59.919978+00', '2022-06-25 18:39:59.919978+00', 'Golden Wishes', 3008, 1, 5, 32, NULL, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (10540, '2022-06-25 18:46:50.029918+00', '2022-06-25 18:46:50.029918+00', 'Tyne Bridge, The', 3008, 2, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (10541, '2022-06-25 18:53:02.181353+00', '2022-06-25 18:53:02.181353+00', '70 is Fun', 3008, 1, 7, 32, NULL, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (5478, NULL, '2022-06-29 04:13:43.460936+00', '6 x 32 Reels', 2696, 1, 6, 32, 9999, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (6523, NULL, '2022-06-29 17:52:28.144036+00', 'Charlie''s Birthday', 10008, 2, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (10292, '2019-06-14 15:08:06.135699+00', '2022-07-12 16:16:50.586021+00', 'New York Hornpipe, The', 10659, 1, 8, 48, NULL, NULL, 426, 0, '');
INSERT INTO 'recording' VALUES (7071, NULL, '2022-07-21 10:04:37.544896+00', 'Kurazukuri', 3050, 3, 3, 40, NULL, NULL, 242, 0, 'This recording appears on both <<Cherry Blossom Time#912>> and <<dda:Cherry Blossom Time Volume 1#1143>>. It is assumed to be the identical recording. According to <<https://my.strathspey.org/dd/issue/2837/|issue 2837>> hte tune order was wrong in the original album.');
INSERT INTO 'recording' VALUES (7488, NULL, '2022-07-23 14:24:50.742724+00', 'Fifty Sixty-Five Strathspey', 2188, 3, 4, 40, NULL, NULL, 312, 0, '');
INSERT INTO 'recording' VALUES (3127, NULL, '2022-07-23 14:55:43.312648+00', 'None so Pretty', 3010, 1, 8, 40, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (5028, NULL, '2022-12-18 01:30:06.122474+00', 'Flights of Fancy', 2123, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (981, NULL, '2022-08-31 16:09:54.87925+00', 'Broadford Bay', 3002, 1, 8, 32, 9999, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (9672, '2014-05-09 23:02:51.488013+00', '2022-09-01 20:00:26.132256+00', 'Promise of Spring', 10955, 1, 8, 32, 9999, NULL, 283, 0, '');
INSERT INTO 'recording' VALUES (9386, '2013-10-29 02:52:36.216894+00', '2022-08-31 22:02:09.788776+00', 'Barry & Doreen''s Continental Capers', 3217, 1, 4, 32, 9999, NULL, 156, 1, '');
INSERT INTO 'recording' VALUES (9431, '2014-02-06 18:00:02.823419+00', '2022-09-01 20:04:24.837438+00', 'Pawling Porch, The / A Double Measure', 10915, 1, 8, 32, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (10526, '2022-06-25 17:39:42.794692+00', '2023-01-30 18:03:50.085728+00', 'Newcastle''s 70th Celebration', 3217, 3, 4, 32, NULL, NULL, 260, 0, '');
INSERT INTO 'recording' VALUES (10534, '2022-06-25 18:15:10.78661+00', '2023-01-30 18:09:39.195484+00', 'Busy Fingers', 3008, 1, 8, 32, NULL, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (10535, '2022-06-25 18:19:23.044769+00', '2023-01-30 18:12:10.251285+00', 'Freda''s Frolic', 3008, 2, 4, 32, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (3132, NULL, '2022-07-23 14:57:54.424898+00', 'Cadgers in the Canongate', 3010, 1, 8, 48, 9999, NULL, 0, 0, 'This is really a generic medley of “hornpipe” tunes and does not feature the official music for Cadgers.');
INSERT INTO 'recording' VALUES (4989, NULL, '2022-07-24 17:43:29.577129+00', 'Saltire Society Reel, The', 3049, 1, 8, 32, 9999, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (95, NULL, '2022-07-24 17:47:26.792177+00', 'Celtic Cross, The', 3049, 1, 4, 48, 9999, NULL, 213, 0, '');
INSERT INTO 'recording' VALUES (263, NULL, '2022-07-24 17:48:24.60903+00', 'Irish Jigs', 3049, 2, 8, 32, 9999, NULL, 267, 0, '');
INSERT INTO 'recording' VALUES (10542, '2022-07-24 18:27:29.557449+00', '2022-07-24 18:27:29.557449+00', 'Pride of Erin Waltz', 3049, 5, 0, 32, NULL, NULL, 243, 0, '');
INSERT INTO 'recording' VALUES (7080, NULL, '2022-07-24 23:28:05.670597+00', 'Set of Reels', 3217, 1, 8, 32, NULL, NULL, 291, 0, '');
INSERT INTO 'recording' VALUES (9787, '2015-05-14 11:44:24.140973+00', '2022-08-02 09:18:01.730439+00', 'Demonstration Set 1', 11136, 4, 1, 592, 9998, NULL, 883, 0, 'Starlight Reel 3x32, Waverly 3x48, Mrs Milne of Kineff 2x32, Sleepy Maggie 3x32, MacDonald of the Isles 3x32, Petronella 3x32.



The above list was presumably entered by Meinhard. Subsequently issue http://my.strathspey.org/dd/issue/1894/ suggested a full set of tunes which have now been added.



Another issue https://my.strathspey.org/dd/issue/2843/ provides even more tunes for track 10.');
INSERT INTO 'recording' VALUES (923, NULL, '2022-08-03 18:31:53.222423+00', 'Duke is Welcome to Inverness, The', 3018, 3, 8, 32, 9999, 5, 494, 1, '');
INSERT INTO 'recording' VALUES (10544, '2022-08-06 14:37:14.347905+00', '2022-08-06 14:37:14.347905+00', 'Reels 8x32 Bars', 3039, 1, 8, 32, NULL, NULL, 288, 0, 'Described as suitable for Shiftin Bobbins etc');
INSERT INTO 'recording' VALUES (10545, '2022-08-06 14:39:27.946334+00', '2022-08-06 14:39:27.946334+00', 'Southern Rose Waltz', 3039, 5, 0, 0, NULL, NULL, 166, 0, '');
INSERT INTO 'recording' VALUES (10546, '2022-08-06 14:41:55.481406+00', '2022-08-06 14:41:55.481406+00', 'Polka', 3039, 13, 0, 0, NULL, NULL, 164, 0, '');
INSERT INTO 'recording' VALUES (10547, '2022-08-06 14:46:07.427764+00', '2022-08-06 14:46:07.427764+00', 'Jigs 5x32 Bars', 3039, 2, 5, 32, NULL, NULL, 179, 0, '');
INSERT INTO 'recording' VALUES (10549, '2022-08-06 14:55:57.284996+00', '2022-08-06 14:55:57.284996+00', 'St Bernard''s Waltz', 3039, 5, 0, 0, NULL, NULL, 159, 0, '');
INSERT INTO 'recording' VALUES (10550, '2022-08-06 14:58:17.983625+00', '2022-08-06 15:03:00.718582+00', 'Hornpipes', 3039, 1, 8, 32, NULL, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (10551, '2022-08-06 15:16:33.351269+00', '2022-08-06 15:16:33.351269+00', 'Reel 5x32 Bars', 3039, 1, 5, 32, NULL, NULL, 193, 0, 'Described as suitable for Black Mountain Reel etc.');
INSERT INTO 'recording' VALUES (10552, '2022-08-06 15:18:05.195337+00', '2022-08-06 15:18:05.195337+00', 'Flirtation Twostep', 3039, 50, 0, 0, NULL, NULL, 175, 0, '');
INSERT INTO 'recording' VALUES (10554, '2022-08-06 15:26:08.617419+00', '2022-08-06 15:26:08.617419+00', 'Jigs 4x32 Bars', 3039, 2, 4, 32, NULL, NULL, 143, 0, 'Described as suitable for Postie''s Jig or Joe MacDiarmid''s Jig.');
INSERT INTO 'recording' VALUES (10556, '2022-08-06 15:46:52.206929+00', '2022-08-06 15:46:52.206929+00', 'Boston Two Step', 3039, 50, 0, 0, NULL, NULL, 144, 0, '');
INSERT INTO 'recording' VALUES (10557, '2022-08-06 15:50:28.940959+00', '2022-08-06 15:50:28.940959+00', 'Lomond Waltz, The', 3039, 5, 0, 0, NULL, NULL, 238, 0, '');
INSERT INTO 'recording' VALUES (10559, '2022-08-06 15:52:31.583934+00', '2022-08-06 15:53:31.41908+00', 'Waltz of the Bells, The', 3039, 5, 0, 0, NULL, NULL, 231, 0, '');
INSERT INTO 'recording' VALUES (10560, '2022-08-06 15:57:46.657797+00', '2022-08-06 15:57:46.657797+00', 'Reels 8x32 Bars', 3039, 1, 8, 32, NULL, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (10561, '2022-08-06 16:00:03.722058+00', '2022-08-06 16:00:03.722058+00', 'Novelty Polka', 3039, 13, 0, 0, NULL, NULL, 182, 0, '');
INSERT INTO 'recording' VALUES (10562, '2022-08-06 16:03:49.834933+00', '2022-08-06 16:05:06.452915+00', 'Reels 8x32 Bars', 3039, 1, 8, 32, NULL, NULL, 290, 0, '');
INSERT INTO 'recording' VALUES (10558, '2022-08-06 15:51:19.10556+00', '2022-08-06 16:09:43.958944+00', 'Jigs 8x32 Bars', 3039, 2, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (10543, '2022-08-06 14:35:40.261581+00', '2022-08-06 16:10:54.384816+00', 'Eva Three Step', 3039, 2, 0, 16, NULL, NULL, 158, 0, '');
INSERT INTO 'recording' VALUES (10548, '2022-08-06 14:48:04.059995+00', '2022-08-06 16:12:42.37324+00', 'Gay Gordons Two-Step', 3039, 11, 0, 16, NULL, NULL, 239, 0, '');
INSERT INTO 'recording' VALUES (7294, NULL, '2022-08-14 15:01:20.677858+00', 'Reels', 10108, 1, 6, 32, NULL, NULL, 207, 0, '');
INSERT INTO 'recording' VALUES (8415, NULL, '2022-08-15 08:50:33.052088+00', 'Abernethy Jig, The', 2066, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (1064, NULL, '2022-08-20 14:29:16.238022+00', 'Jessie''s Hornpipe', 3037, 1, 4, 32, 9999, NULL, 138, 0, '');
INSERT INTO 'recording' VALUES (3772, NULL, '2022-08-20 14:30:55.179255+00', 'Dumbarton''s Drums', 3037, 1, 4, 32, 9999, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (3777, NULL, '2022-08-20 14:33:35.900589+00', 'Swilcan, The', 3037, 2, 8, 32, 9999, NULL, 270, 0, '');
INSERT INTO 'recording' VALUES (1805, NULL, '2022-08-20 15:49:28.698405+00', 'Hooper''s Jig', 3037, 2, 8, 32, 9999, 1, 263, 0, '');
INSERT INTO 'recording' VALUES (2849, NULL, '2022-08-20 17:09:25.820286+00', 'Dashing White Sergeant, The', 3026, 1, 4, 32, 9999, NULL, 141, 0, '');
INSERT INTO 'recording' VALUES (2854, NULL, '2022-08-20 17:12:28.744837+00', 'Scottish Waltz Medley', 3026, 5, 0, 0, 9999, NULL, 174, 0, '');
INSERT INTO 'recording' VALUES (1766, NULL, '2022-08-20 22:08:52.376379+00', 'Mr Wilson''s Hornpipe', 2252, 1, 8, 32, 9999, 1, 275, 0, '');
INSERT INTO 'recording' VALUES (1864, NULL, '2022-08-20 22:34:57.786889+00', 'Mantua Makers, The', 2231, 1, 8, 32, 9999, 1, 288, 0, '');
INSERT INTO 'recording' VALUES (4835, NULL, '2022-08-20 23:08:29.709057+00', 'Lord MacDonald''s Reel', 3064, 1, 5, 32, 9999, NULL, 172, 0, '');
INSERT INTO 'recording' VALUES (4840, NULL, '2022-08-20 23:11:20.823429+00', 'Gay Gordons', 3064, 11, 0, 16, 9999, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (4134, NULL, '2022-08-21 16:16:50.64636+00', 'Reel of the 51st Division, The', 2090, 1, 8, 32, 9999, NULL, 276, 0, '');
INSERT INTO 'recording' VALUES (2713, NULL, '2022-08-21 16:18:11.678055+00', 'Dashing White Sergeant (encore), The', 2090, 1, 8, 32, 9999, NULL, 263, 0, '');
INSERT INTO 'recording' VALUES (6473, NULL, '2022-08-21 16:57:16.66059+00', 'Mairi''s Wedding', 3030, 1, 8, 40, 9999, NULL, 336, 0, '');
INSERT INTO 'recording' VALUES (2054, NULL, '2022-08-21 22:01:15.567778+00', 'Russe, La', 3065, 1, 3, 64, 9999, 1, 183, 0, '');
INSERT INTO 'recording' VALUES (1039, NULL, '2022-08-21 22:06:50.934051+00', 'Glasgow Highlanders, The', 3065, 3, 4, 32, 9999, 5, 210, 0, '');
INSERT INTO 'recording' VALUES (2055, NULL, '2022-08-21 22:16:47.831157+00', 'Strip the Willow', 3065, 2, 5, 32, 9999, 1, 167, 0, '');
INSERT INTO 'recording' VALUES (2471, NULL, '2022-08-22 21:52:13.312364+00', 'Sailor (Encore), The', 2414, 1, 4, 32, 9999, 1, 139, 0, '');
INSERT INTO 'recording' VALUES (10563, '2022-08-22 23:03:32.113463+00', '2022-08-22 23:03:32.113463+00', 'Reels – Set 22', 12196, 1, 10, 32, NULL, NULL, 325, 0, '');
INSERT INTO 'recording' VALUES (10564, '2022-08-22 23:07:48.268629+00', '2022-08-22 23:07:48.268629+00', 'Jigs – St Nicholas Boat', 12196, 2, 8, 32, NULL, NULL, 259, 0, '');
INSERT INTO 'recording' VALUES (10565, '2022-08-22 23:09:44.73135+00', '2022-08-22 23:09:44.73135+00', 'Medley No. 1 – Rustic Bridge', 12196, 11, 6, 32, NULL, NULL, 229, 0, '');
INSERT INTO 'recording' VALUES (10566, '2022-08-22 23:11:24.862867+00', '2022-08-22 23:11:24.862867+00', 'Canadian Barn Dance', 12196, 50, 0, 16, NULL, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (10567, '2022-08-22 23:15:38.10176+00', '2022-08-22 23:15:38.10176+00', 'Gaelic Waltz – Sine Bhan', 12196, 5, 0, 0, NULL, NULL, 219, 0, '');
INSERT INTO 'recording' VALUES (10568, '2022-08-22 23:19:17.475497+00', '2022-08-22 23:19:17.475497+00', 'Reels – Set 24', 12196, 1, 6, 48, NULL, NULL, 387, 0, '');
INSERT INTO 'recording' VALUES (10569, '2022-08-22 23:23:23.214033+00', '2022-08-22 23:23:23.214033+00', 'Jigs – Miss Bennet', 12196, 2, 8, 32, NULL, NULL, 322, 0, '');
INSERT INTO 'recording' VALUES (10570, '2022-08-22 23:26:39.686876+00', '2022-08-22 23:26:39.686876+00', 'Waltz – I Feel Pretty', 12196, 5, 0, 0, NULL, NULL, 220, 0, '');
INSERT INTO 'recording' VALUES (10571, '2022-08-22 23:31:36.397972+00', '2022-08-22 23:31:36.397972+00', 'Foursome Reel', 12196, 4, 0, 0, 3, NULL, 236, 0, '');
INSERT INTO 'recording' VALUES (10572, '2022-08-22 23:40:24.92155+00', '2022-08-22 23:40:24.92155+00', 'Medley', 12196, 4, 0, 0, NULL, NULL, 169, 0, '');
INSERT INTO 'recording' VALUES (10573, '2022-08-22 23:44:30.070532+00', '2022-08-22 23:44:30.070532+00', 'Duke and Duchess of Edinburgh', 12196, 1, 9, 40, NULL, NULL, 365, 0, '');
INSERT INTO 'recording' VALUES (1729, NULL, '2022-08-28 22:48:15.474737+00', 'Cumberland Reel', 3018, 2, 4, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (9902, '2016-09-12 23:45:21.987125+00', '2022-08-30 19:28:52.59932+00', 'Odd Thoughts', 11351, 3, 8, 32, NULL, 5, 500, 0, '');
INSERT INTO 'recording' VALUES (7570, NULL, '2022-08-30 19:34:01.835587+00', 'Burn''s Hornpipe suitable for Flower Pot Rocks', 3217, 1, 4, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (6100, NULL, '2022-08-30 19:48:28.102047+00', 'Sleeping Warrior, The', 3039, 3, 4, 32, 9999, NULL, 257, 1, '');
INSERT INTO 'recording' VALUES (172, NULL, '2022-08-31 10:13:33.888969+00', 'Long Pond Reel', 3017, 1, 8, 32, 9999, 5, 288, 0, '');
INSERT INTO 'recording' VALUES (5477, NULL, '2022-08-31 10:46:50.959034+00', '5 x 32 Strathspeys', 2696, 3, 5, 32, 9999, NULL, 324, 0, '');
INSERT INTO 'recording' VALUES (6340, NULL, '2022-08-31 11:03:49.217925+00', 'Fireside Reel', 3017, 1, 8, 32, 9999, NULL, 289, 0, '');
INSERT INTO 'recording' VALUES (8085, NULL, '2022-08-31 16:21:52.779599+00', 'Hyperactive Reel, The', 10248, 1, 8, 32, NULL, NULL, 285, 0, '');
INSERT INTO 'recording' VALUES (4455, NULL, '2022-08-31 16:41:18.096814+00', 'Selection of Reels', 3067, 1, 6, 32, 9999, NULL, 215, 0, '');
INSERT INTO 'recording' VALUES (10250, '2019-02-27 21:36:11.758136+00', '2022-12-08 10:49:30.543976+00', 'Miss Mary Stirling''s Hornpipe', 11791, 1, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (10553, '2022-08-06 15:19:27.032685+00', '2022-12-20 14:54:32.231313+00', 'Viennese Swing', 3039, 5, 0, 0, NULL, NULL, 192, 0, '');
INSERT INTO 'recording' VALUES (10555, '2022-08-06 15:43:40.662967+00', '2022-12-25 19:29:41.64444+00', 'White Heather Foxtrot', 3039, 50, 0, 0, NULL, NULL, 229, 0, '');
INSERT INTO 'recording' VALUES (5669, NULL, '2022-09-01 11:16:17.854895+00', 'McGregor''s Leap', 3399, 1, 8, 32, 9999, NULL, 295, 0, '');
INSERT INTO 'recording' VALUES (4114, NULL, '2022-09-01 11:23:23.782768+00', '8 x 32 Jigs', 2885, 2, 8, 32, 9999, NULL, 280, 0, '');
INSERT INTO 'recording' VALUES (10096, '2017-11-25 16:33:37.248795+00', '2022-09-01 11:58:28.515388+00', 'Bruce That Was, The', 11568, 2, 8, 32, 9999, NULL, 297, 0, '');
INSERT INTO 'recording' VALUES (6038, NULL, '2022-09-01 12:10:43.72783+00', 'Alan J Smith', 3040, 2, 8, 32, 9999, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (5755, NULL, '2022-09-01 20:38:09.232812+00', 'Spirit of the Dance, The', 2586, 3, 8, 32, 9999, NULL, 506, 0, '');
INSERT INTO 'recording' VALUES (2576, NULL, '2022-11-27 16:29:19.93327+00', 'London Highland Club''s Farewell to Fetter Lane', 2414, 1, 4, 32, 9999, 3, 140, 0, '');
INSERT INTO 'recording' VALUES (5492, NULL, '2022-12-04 13:04:15.106418+00', 'Hamilton Welcome', 3023, 3, 5, 32, 9999, NULL, 321, 0, '');
INSERT INTO 'recording' VALUES (8888, '2012-05-31 07:22:05.791761+00', '2022-12-06 20:26:55.060564+00', 'Dhoon, The', 10034, 2, 4, 32, 9999, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (10574, '2022-12-07 22:04:16.855982+00', '2022-12-07 22:04:16.855982+00', 'Wirral in Gladenbach', 11858, 1, 4, 32, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (10575, '2022-12-07 22:05:07.501245+00', '2022-12-07 22:05:07.501245+00', 'Tattie Bogle', 11858, 2, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (10576, '2022-12-07 22:06:16.86592+00', '2022-12-07 22:06:16.86592+00', 'Invercauld''s Reel', 11858, 3, 8, 32, NULL, NULL, 496, 0, '');
INSERT INTO 'recording' VALUES (10577, '2022-12-07 22:07:57.374815+00', '2022-12-07 22:07:57.374815+00', 'Jill''s Purple Party', 11858, 1, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (10578, '2022-12-07 22:08:45.066258+00', '2022-12-07 22:08:45.066258+00', 'Weathercock, The', 11858, 2, 4, 32, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (10579, '2022-12-07 22:09:37.863561+00', '2022-12-07 22:09:37.863561+00', 'Peter Knight''s Strathspey', 11858, 3, 3, 32, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (10580, '2022-12-07 22:13:06.321676+00', '2022-12-07 22:13:06.321676+00', 'Rest and Be Thankful', 11858, 1, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (10581, '2022-12-07 22:14:15.425963+00', '2022-12-07 22:14:15.425963+00', 'Vintage Simon', 11858, 2, 5, 32, NULL, NULL, 181, 0, '');
INSERT INTO 'recording' VALUES (10582, '2022-12-07 22:16:00.421186+00', '2022-12-07 22:16:00.421186+00', 'Magic of Mary Ross', 11858, 3, 3, 32, NULL, NULL, 190, 0, '');
INSERT INTO 'recording' VALUES (10584, '2022-12-07 22:18:17.217168+00', '2022-12-07 22:18:17.217168+00', 'Elusive Muse, The', 11858, 2, 3, 32, NULL, NULL, 111, 0, '');
INSERT INTO 'recording' VALUES (10586, '2022-12-07 22:20:56.846854+00', '2022-12-07 22:20:56.846854+00', 'Kyleside Belvedere', 11858, 3, 3, 40, NULL, NULL, 237, 0, '');
INSERT INTO 'recording' VALUES (10587, '2022-12-07 22:24:00.713912+00', '2022-12-07 22:24:00.713912+00', 'Angus Macleod', 11858, 1, 2, 64, NULL, NULL, 147, 0, '');
INSERT INTO 'recording' VALUES (10588, '2022-12-07 22:25:23.857764+00', '2022-12-07 22:25:23.857764+00', 'Welcome to Dufftown', 11858, 2, 8, 32, NULL, NULL, 227, 0, '');
INSERT INTO 'recording' VALUES (10589, '2022-12-07 22:26:29.371279+00', '2022-12-07 22:26:29.371279+00', 'Bonnie Stronshiray', 11858, 3, 8, 32, NULL, NULL, 496, 0, '');
INSERT INTO 'recording' VALUES (10590, '2022-12-07 22:27:27.322632+00', '2022-12-07 22:27:27.322632+00', 'Across the Waves', 11858, 1, 4, 32, NULL, NULL, 208, 0, '');
INSERT INTO 'recording' VALUES (10591, '2022-12-07 22:31:43.071191+00', '2022-12-07 22:31:43.071191+00', 'Warm Up/Cool Down March', 11858, 11, 0, 0, NULL, NULL, 148, 0, '');
INSERT INTO 'recording' VALUES (10583, '2022-12-07 22:16:53.018696+00', '2022-12-07 22:35:22.043279+00', 'Burnieboozle', 11858, 1, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (10585, '2022-12-07 22:20:08.216909+00', '2022-12-07 22:41:35.733463+00', 'Haggis Hunters, The', 11858, 4, 0, 128, 2, NULL, 200, 0, '');
INSERT INTO 'recording' VALUES (10264, '2019-02-27 21:52:04.028829+00', '2022-12-08 15:47:09.946029+00', 'Waltz for Peter Ellis', 11791, 5, 6, 32, NULL, NULL, 241, 0, 'Called "Waltz for Peter Ellis” on the disc sleeve but "Peter Ellis Waltz" on disc insert (https://my.strathspey.org/dd/issue/2849/).



Tunes: Take Your Partners, Collector''s Choice, Castlemaine all by Bob McInnes.');
INSERT INTO 'recording' VALUES (6765, NULL, '2022-12-08 16:43:29.297397+00', 'Ferryboat, The', 3420, 2, 4, 32, NULL, NULL, 149, 0, '');
INSERT INTO 'recording' VALUES (4321, NULL, '2022-12-08 19:44:12.388896+00', 'Wild Geese, The', 3018, 2, 0, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (7945, NULL, '2022-12-08 22:20:05.527823+00', 'Loch Ruan', 10200, 98, 0, 0, NULL, NULL, 183, 0, '');
INSERT INTO 'recording' VALUES (2465, NULL, '2022-12-09 19:52:44.298457+00', 'Blacksmith of Elgin, The', 2414, 2, 8, 48, 9999, 11, 387, 0, '');
INSERT INTO 'recording' VALUES (2207, NULL, '2022-12-09 19:53:33.675363+00', 'Hooper''s Jig', 2053, 2, 8, 32, 9999, 1, 280, 0, '');
INSERT INTO 'recording' VALUES (2388, NULL, '2022-12-09 19:57:25.341765+00', 'Hamilton House', 2069, 2, 8, 32, 9999, 1, 259, 0, '');
INSERT INTO 'recording' VALUES (298, NULL, '2022-12-09 19:58:48.736012+00', 'Cumberland Reel', 3001, 2, 8, 32, 9999, 1, 283, 0, '');
INSERT INTO 'recording' VALUES (7601, NULL, '2022-12-09 19:59:02.817525+00', 'Farewell to the Tay', 3012, 2, 4, 32, NULL, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (2925, NULL, '2022-12-09 19:59:34.79023+00', 'Jig Medley', 3037, 2, 8, 24, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (1376, NULL, '2022-12-09 19:59:50.199147+00', 'Joe MacDiarmid''s Jig', 3044, 2, 8, 32, 9999, 1, 270, 0, '');
INSERT INTO 'recording' VALUES (641, NULL, '2022-12-09 21:05:58.200986+00', 'Medley', 1502, 98, 0, 0, 9999, NULL, 232, 0, '');
INSERT INTO 'recording' VALUES (10214, '2018-06-23 17:07:23.226236+00', '2022-12-10 18:43:36.707916+00', 'Newington Assembly (8R48) - as MP3 (8R32)', 11651, 1, 8, 48, NULL, NULL, 530, 0, 'Original CD recording was wrongly 8x48, rerecorded version is available via <<http://www.rscds.org|RSCDS Homepage>>:  

RSCDS Homepage login / Media / Audio, Video / DuK MMM remastert tracks for "The Monifieth Star" and  "Newington Assembly"');
INSERT INTO 'recording' VALUES (7664, NULL, '2022-12-10 21:17:58.160542+00', 'Burning of Paddy''s Breeches, The', 2328, 4, 0, 128, 10044, NULL, 153, 0, '');
INSERT INTO 'recording' VALUES (6627, NULL, '2022-12-11 20:22:08.306249+00', 'Laird O'' Dochart''s Reel', 3015, 2, 2, 80, NULL, NULL, 195, 0, 'As reported in <<https://my.strathspey.org/dd/issue/2924/|issue 2924>> this is incorrectly listed on the CD as being a Reel, but they''re playing in 6/8 time, which is a Jig.');
INSERT INTO 'recording' VALUES (10595, '2022-12-11 21:00:31.011057+00', '2022-12-11 21:34:57.956253+00', 'St. Bernard''s Waltz, The', 1580, 5, 0, 0, NULL, NULL, 235, 0, '');
INSERT INTO 'recording' VALUES (10593, '2022-12-11 20:56:58.091455+00', '2022-12-11 20:56:58.091455+00', 'Waltz Camay', 1580, 5, 0, 32, NULL, NULL, 328, 0, '');
INSERT INTO 'recording' VALUES (10594, '2022-12-11 20:58:22.178561+00', '2022-12-11 20:58:22.178561+00', 'Mabel Besant''s Two Step', 1580, 11, 0, 16, NULL, NULL, 189, 0, '');
INSERT INTO 'recording' VALUES (10598, '2022-12-11 21:05:11.544545+00', '2022-12-11 21:05:11.544545+00', 'Sindy Swing', 1580, 99, 0, 0, NULL, NULL, 187, 0, '');
INSERT INTO 'recording' VALUES (10602, '2022-12-11 21:14:47.266075+00', '2022-12-11 21:14:47.266075+00', 'Strip the Willow Square', 1580, 2, 4, 48, NULL, NULL, 198, 0, 'Online tune list states: Shredded Breeks / The Lion''s Haunch / St. Lawrence / The Rankins Welcome to Glasgow');
INSERT INTO 'recording' VALUES (10605, '2022-12-11 21:16:57.243052+00', '2022-12-11 21:16:57.243052+00', 'White Heather Parade', 1580, 99, 0, 0, NULL, NULL, 149, 0, 'Online tune list states: Sunset Trail');
INSERT INTO 'recording' VALUES (10596, '2022-12-11 21:02:35.568835+00', '2022-12-11 21:35:11.726526+00', 'Raw Recruit (Two Step), The', 1580, 50, 0, 0, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (10597, '2022-12-11 21:03:49.254952+00', '2022-12-11 21:35:26.97424+00', 'Oriental Mazurka, The', 1580, 50, 0, 0, NULL, NULL, 165, 0, '');
INSERT INTO 'recording' VALUES (10600, '2022-12-11 21:12:37.853841+00', '2022-12-11 21:35:55.624762+00', 'Party Polka, The', 1580, 13, 0, 0, NULL, NULL, 161, 0, '');
INSERT INTO 'recording' VALUES (10601, '2022-12-11 21:13:22.685124+00', '2022-12-11 21:36:07.358495+00', 'Glenburn Waltz, The', 1580, 5, 0, 0, NULL, NULL, 274, 0, '');
INSERT INTO 'recording' VALUES (10603, '2022-12-11 21:15:18.398744+00', '2022-12-11 21:36:20.309274+00', 'Phyllis Waltz, The', 1580, 5, 0, 0, NULL, NULL, 194, 0, '');
INSERT INTO 'recording' VALUES (10604, '2022-12-11 21:16:03.121026+00', '2022-12-11 21:36:33.94247+00', 'Victorian Gavotte, The', 1580, 50, 0, 0, NULL, NULL, 304, 0, '');
INSERT INTO 'recording' VALUES (10606, '2022-12-11 21:17:47.267467+00', '2022-12-11 21:36:52.099501+00', 'Guaracha Waltz, The', 1580, 5, 0, 0, NULL, NULL, 379, 0, 'Online tune list states: The Guaracha Waltz / The Merry Masons');
INSERT INTO 'recording' VALUES (10608, '2022-12-11 21:21:04.627361+00', '2022-12-11 21:37:18.07085+00', 'Queen Elizabeth Waltz, The', 1580, 5, 0, 0, NULL, NULL, 198, 0, 'Online tune list: The Golden Jubilee');
INSERT INTO 'recording' VALUES (10609, '2022-12-11 21:22:07.786558+00', '2022-12-11 21:37:32.636296+00', 'Square Tango, The', 1580, 50, 0, 0, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (10610, '2022-12-11 21:22:57.410966+00', '2022-12-11 21:37:48.335223+00', 'Marine Four Step (Two Step), The', 1580, 50, 0, 0, NULL, NULL, 152, 0, 'Online tune list states: The Malt and Barley Two Step');
INSERT INTO 'recording' VALUES (10611, '2022-12-11 21:23:44.956313+00', '2022-12-11 21:38:00.826104+00', 'Marie Mazurka, The', 1580, 50, 0, 0, NULL, NULL, 83, 0, 'Online tune list states: Dunbar''s Mazurka');
INSERT INTO 'recording' VALUES (10612, '2022-12-11 21:24:40.020018+00', '2022-12-11 21:38:16.574877+00', 'Alsatian Polka, The', 1580, 13, 0, 0, NULL, NULL, 130, 0, 'Online tune list states: The Jenny Lind Polka / The Swedish Nightingale');
INSERT INTO 'recording' VALUES (10613, '2022-12-11 21:25:44.904776+00', '2022-12-11 21:39:33.15955+00', 'Blue Danube, The', 1580, 5, 0, 0, NULL, NULL, 185, 0, '');
INSERT INTO 'recording' VALUES (10614, '2022-12-11 21:26:46.811751+00', '2022-12-11 21:39:46.467865+00', 'Jacky Tar Two Step (Schottische), The', 1580, 50, 0, 0, NULL, NULL, 106, 0, 'Online tune list states: Keswick''s Bonny Lasses / The Calgarth');
INSERT INTO 'recording' VALUES (10615, '2022-12-11 21:27:42.432647+00', '2022-12-11 21:40:02.151458+00', 'Hesitation Waltz, The', 1580, 5, 0, 0, NULL, NULL, 191, 0, 'Online tune list states: Memories of Willie Smith');
INSERT INTO 'recording' VALUES (10592, '2022-12-11 20:54:27.397002+00', '2022-12-11 21:34:40.474891+00', 'Bradford Barn Dance, The', 1580, 99, 0, 0, NULL, NULL, 150, 0, '');
INSERT INTO 'recording' VALUES (10599, '2022-12-11 21:11:41.059769+00', '2022-12-11 21:35:43.502072+00', 'Lammermuir Waltz, The', 1580, 5, 0, 0, NULL, NULL, 247, 0, 'Online tune list states: The Lammermuir Hills / Meikle Law / Kelphope');
INSERT INTO 'recording' VALUES (10607, '2022-12-11 21:20:11.097591+00', '2022-12-11 21:42:29.066406+00', 'North Walls Quadrille, The', 1580, 1, 4, 48, NULL, NULL, 219, 0, 'Online tune list states: The Steamboat / Proudlock''s Hornpipe / Enrico / St. George''s Polka

"The Steamboat": unclear as to which of our database tunes this would apply to.');
INSERT INTO 'recording' VALUES (282, NULL, '2022-12-13 17:19:43.326687+00', 'Saint Andrew''s Cross', 3015, 1, 1, 136, 9999, NULL, 156, 0, '');
INSERT INTO 'recording' VALUES (75, NULL, '2022-12-13 19:18:21.975069+00', 'Earl of Errol''s Reel, The', 3062, 2, 0, 200, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (7582, NULL, '2022-12-14 16:06:09.189989+00', 'Architect, The', 2696, 1, 8, 32, NULL, NULL, 282, 0, '');
INSERT INTO 'recording' VALUES (9206, '2013-01-16 13:45:56.337579+00', '2022-12-14 16:36:31.736229+00', 'Pride of Erin Waltz', 10709, 5, 6, 32, 9999, NULL, 201, 0, '');
INSERT INTO 'recording' VALUES (10616, '2022-12-16 09:28:48.363111+00', '2022-12-16 09:28:48.363111+00', 'Devil Among the Tailors', 2058, 1, 8, 32, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10617, '2022-12-16 09:30:39.696151+00', '2022-12-16 09:30:39.696151+00', 'Aikendrum', 2058, 1, 8, 32, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10618, '2022-12-16 09:32:51.480608+00', '2022-12-16 09:32:51.480608+00', 'Annie Laurie', 2058, 99, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10619, '2022-12-16 09:33:55.757217+00', '2022-12-16 09:33:55.757217+00', 'Monymusk Lads', 2058, 99, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10620, '2022-12-16 09:36:40.72001+00', '2022-12-16 09:36:40.72001+00', 'West Country Barn Dance', 2058, 99, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10621, '2022-12-16 09:38:06.460752+00', '2022-12-16 09:38:06.460752+00', 'Piper O'' Dundee', 2058, 99, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10622, '2022-12-16 09:39:44.809914+00', '2022-12-16 09:39:44.809914+00', 'Glasgow Peggy', 2058, 99, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10623, '2022-12-16 09:41:22.560963+00', '2022-12-16 09:41:22.560963+00', 'Trooper and the Maid', 2058, 99, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10624, '2022-12-16 09:42:45.36715+00', '2022-12-16 09:42:45.36715+00', 'Mairi''s Wedding', 2058, 1, 0, 40, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (6909, NULL, '2022-12-16 11:25:48.178529+00', 'Inverness Sixsome, The', 2681, 1, 0, 128, NULL, NULL, 144, 0, 'This recording is 128 bars. Some versions of the dance <<ddd:Inverness Reel, The#3110>> (also known as The Inverness Sixsome) are 144 bars. See the extra info for the dance.');
INSERT INTO 'recording' VALUES (5408, NULL, '2022-12-16 21:15:33.990296+00', 'Circle Waltz', 3008, 5, 0, 184, 9999, NULL, 249, 0, '');
INSERT INTO 'recording' VALUES (8195, NULL, '2022-12-19 16:36:52.509885+00', 'Duke of Perth', 10037, 1, 8, 32, NULL, NULL, 262, 0, '');
INSERT INTO 'recording' VALUES (828, NULL, '2022-12-19 16:37:12.748869+00', 'Whistlin'' In the Kitchen', 3045, 1, 8, 32, 9999, NULL, 268, 0, '');
INSERT INTO 'recording' VALUES (7446, NULL, '2022-12-19 17:25:39.435756+00', 'Campbell''s Frolic', 3065, 2, 5, 32, NULL, NULL, 163, 0, 'The recording could be found on spotify and is 5x through only.');
INSERT INTO 'recording' VALUES (7201, NULL, '2022-12-19 18:08:56.028473+00', 'Maureen''s Reel', 3045, 1, 8, 32, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (9542, '2014-03-16 10:38:03.015058+00', '2022-12-20 10:56:27.814072+00', 'Christopher Columbus', 10920, 50, 0, 0, NULL, NULL, 214, 0, '');
INSERT INTO 'recording' VALUES (1223, NULL, '2022-12-20 11:05:24.271104+00', 'Morpeth Rant', 3010, 1, 5, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (3338, NULL, '2022-12-20 14:54:16.633526+00', 'Viennese Swing', 2188, 50, 0, 0, 9999, NULL, 139, 0, '');
INSERT INTO 'recording' VALUES (9543, '2014-03-16 10:39:18.719055+00', '2022-12-20 15:15:49.620938+00', 'It Don''t Mean a Thing', 10920, 50, 0, 0, NULL, NULL, 238, 0, '');
INSERT INTO 'recording' VALUES (9544, '2014-03-16 10:40:14.756581+00', '2022-12-20 19:53:37.714052+00', 'Makin'' Whoopee', 10920, 50, 0, 0, NULL, NULL, 216, 0, '');
INSERT INTO 'recording' VALUES (10636, '2022-12-20 23:08:49.310391+00', '2022-12-20 23:08:49.310391+00', 'Reel De Montreal', 11376, 99, 0, 0, NULL, NULL, 348, 0, '');
INSERT INTO 'recording' VALUES (10637, '2022-12-20 23:09:42.586303+00', '2022-12-20 23:09:42.586303+00', 'Grandpa''s Mint Chip', 11376, 99, 0, 0, NULL, NULL, 229, 0, '');
INSERT INTO 'recording' VALUES (9548, '2014-03-16 10:44:50.35235+00', '2022-12-20 20:26:38.250783+00', 'Nobody Knows You When You''re Down and Out', 10920, 50, 0, 0, NULL, NULL, 405, 0, '');
INSERT INTO 'recording' VALUES (9546, '2014-03-16 10:42:26.312728+00', '2022-12-20 20:27:16.211438+00', 'I''ve Found a New Baby', 10920, 50, 0, 0, NULL, NULL, 188, 0, '');
INSERT INTO 'recording' VALUES (9550, '2014-03-16 10:46:59.027612+00', '2022-12-20 20:34:22.160636+00', 'Honky-Tonk Château', 10920, 50, 0, 0, NULL, NULL, 469, 0, '');
INSERT INTO 'recording' VALUES (9311, '2013-02-22 14:51:43.12652+00', '2022-12-20 21:31:37.224188+00', 'Student Lancers, The', 10209, 4, 1, 604, 9998, NULL, 690, 0, 'This 604 bars recording for a display dance is rather uncommon in structure.  

J104+R104+J72+R104+J224.  

  

The individual figures are then:  

Fig. 1 [J8+J4×24)]  

Fig. 2 [R8+R4×24)]  

Fig. 3 [J8+J2×32)]  

Fig. 4 [R8+R4×24)]  

Fig. 5 [J4×48+J16+J16)]');
INSERT INTO 'recording' VALUES (10625, '2022-12-20 22:53:09.894342+00', '2022-12-20 22:53:09.894342+00', 'Grand Teton', 11376, 99, 0, 0, NULL, NULL, 337, 0, '');
INSERT INTO 'recording' VALUES (10626, '2022-12-20 22:54:22.958446+00', '2022-12-20 22:54:22.958446+00', 'Lady Elizabeth Cole', 11376, 99, 0, 0, NULL, NULL, 312, 0, '');
INSERT INTO 'recording' VALUES (10627, '2022-12-20 22:55:05.410711+00', '2022-12-20 22:55:05.410711+00', 'Footprint in Time', 11376, 99, 0, 0, NULL, NULL, 265, 0, '');
INSERT INTO 'recording' VALUES (10628, '2022-12-20 22:57:15.602267+00', '2022-12-20 22:57:15.602267+00', 'Grandpa''s Shrine', 11376, 99, 0, 0, NULL, NULL, 341, 0, '');
INSERT INTO 'recording' VALUES (10629, '2022-12-20 22:58:34.699313+00', '2022-12-20 22:58:34.699313+00', 'Evit Gabriel', 11376, 99, 0, 0, NULL, NULL, 311, 0, '');
INSERT INTO 'recording' VALUES (10630, '2022-12-20 23:00:42.123486+00', '2022-12-20 23:00:42.123486+00', 'Return to the Stewartry', 11376, 99, 0, 0, NULL, NULL, 322, 0, '');
INSERT INTO 'recording' VALUES (10631, '2022-12-20 23:02:16.943296+00', '2022-12-20 23:02:16.943296+00', 'Oddville Cupola', 11376, 99, 0, 0, NULL, NULL, 281, 0, '');
INSERT INTO 'recording' VALUES (10632, '2022-12-20 23:03:19.111394+00', '2022-12-20 23:03:19.111394+00', 'Trout Transmigration', 11376, 99, 0, 0, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (10633, '2022-12-20 23:05:06.949319+00', '2022-12-20 23:05:06.949319+00', 'Hiking to High Point', 11376, 99, 0, 0, NULL, NULL, 311, 0, '');
INSERT INTO 'recording' VALUES (10634, '2022-12-20 23:06:12.214475+00', '2022-12-20 23:06:12.214475+00', 'Julia Delaney', 11376, 99, 0, 0, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (10635, '2022-12-20 23:06:47.536837+00', '2022-12-20 23:06:47.536837+00', 'Solstice Wedding', 11376, 99, 0, 0, NULL, NULL, 199, 0, '');
INSERT INTO 'recording' VALUES (10638, '2022-12-20 23:21:42.836938+00', '2022-12-20 23:21:42.836938+00', 'Ice Palace', 11376, 99, 0, 0, NULL, NULL, 312, 0, '');
INSERT INTO 'recording' VALUES (10639, '2022-12-20 23:23:11.825356+00', '2022-12-20 23:23:11.825356+00', 'Round the Horn', 11376, 99, 0, 0, NULL, NULL, 312, 0, '');
INSERT INTO 'recording' VALUES (10640, '2022-12-20 23:24:29.464471+00', '2022-12-20 23:24:29.464471+00', 'Far Away', 11376, 99, 0, 0, NULL, NULL, 376, 0, '');
INSERT INTO 'recording' VALUES (10641, '2022-12-20 23:26:18.450485+00', '2022-12-20 23:26:18.450485+00', 'Magician''s Hornpipe', 11376, 99, 0, 0, NULL, NULL, 292, 0, '');
INSERT INTO 'recording' VALUES (10642, '2022-12-20 23:28:04.412886+00', '2022-12-20 23:28:04.412886+00', 'Reel De Gasp', 11376, 99, 0, 0, NULL, NULL, 315, 0, '');
INSERT INTO 'recording' VALUES (10643, '2022-12-20 23:29:18.816304+00', '2022-12-20 23:29:18.816304+00', 'Kitty in the High Grass', 11376, 99, 0, 0, NULL, NULL, 313, 0, '');
INSERT INTO 'recording' VALUES (10645, '2022-12-20 23:32:40.08039+00', '2022-12-20 23:32:40.08039+00', 'Vladi On the Trans Siberian', 11376, 99, 0, 0, NULL, NULL, 311, 0, '');
INSERT INTO 'recording' VALUES (10646, '2022-12-20 23:34:25.80219+00', '2022-12-20 23:34:25.80219+00', 'Hughie Shortys Reel', 11376, 99, 0, 0, NULL, NULL, 324, 0, '');
INSERT INTO 'recording' VALUES (10647, '2022-12-20 23:34:51.506903+00', '2022-12-20 23:34:51.506903+00', 'Over the Lake', 11376, 99, 0, 0, NULL, NULL, 230, 0, '');
INSERT INTO 'recording' VALUES (10648, '2022-12-20 23:36:42.207239+00', '2022-12-20 23:36:42.207239+00', 'Whiskey Before Breakfast', 11376, 99, 0, 0, NULL, NULL, 304, 0, '');
INSERT INTO 'recording' VALUES (10654, '2022-12-22 22:11:14.400606+00', '2022-12-22 22:11:14.400606+00', 'Accordion Solo', 3009, 98, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10644, '2022-12-20 23:31:00.266452+00', '2022-12-21 11:24:58.074162+00', 'Maison De Glace, La', 11376, 99, 0, 0, NULL, NULL, 365, 0, '');
INSERT INTO 'recording' VALUES (1327, NULL, '2022-12-22 13:49:32.87109+00', 'Nineteenth of December, The', 3024, 2, 8, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (10649, '2022-12-22 22:07:28.441356+00', '2022-12-22 22:07:56.446057+00', 'Gallant Forty-Twa, The', 3009, 2, 0, 32, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10650, '2022-12-22 22:08:54.022927+00', '2022-12-22 22:08:54.022927+00', 'Melodies Of The West', 3009, 5, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10651, '2022-12-22 22:09:45.537886+00', '2022-12-22 22:09:45.537886+00', 'Tap Wood Polka, The', 3009, 13, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10652, '2022-12-22 22:10:09.744706+00', '2022-12-22 22:10:09.744706+00', 'Come Out Of This World', 3009, 5, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10653, '2022-12-22 22:10:48.940505+00', '2022-12-22 22:10:48.940505+00', 'Pipe Marches', 3009, 11, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10655, '2022-12-22 22:11:40.772232+00', '2022-12-22 22:11:40.772232+00', 'Coulter''s Candy', 3009, 99, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10656, '2022-12-22 22:12:25.543938+00', '2022-12-22 22:12:25.543938+00', 'Where The River Shannon Flows', 3009, 99, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10657, '2022-12-22 22:12:49.241296+00', '2022-12-22 22:12:49.241296+00', 'Tin-Whistle Feature', 3009, 98, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10661, '2022-12-22 22:49:42.27967+00', '2022-12-26 19:11:21.332358+00', 'Whistler And His Dog', 3009, 99, 0, 0, NULL, NULL, 0, 0, 'The LP back states: "Jimmy MacFarlane''s solo as he whistles his way through this well known melody."');
INSERT INTO 'recording' VALUES (10663, '2022-12-22 22:51:06.204748+00', '2022-12-26 19:16:29.891732+00', 'Accordion Solo', 3009, 98, 0, 0, NULL, NULL, 0, 0, 'Played by Tommy Ford.');
INSERT INTO 'recording' VALUES (2147, NULL, '2023-01-10 11:50:36.444197+00', 'Dark Mile, The', 3040, 3, 3, 32, 9999, 1, 0, 0, '');
INSERT INTO 'recording' VALUES (10662, '2022-12-22 22:50:09.398751+00', '2022-12-26 19:15:32.867855+00', 'Lights On Lochindaal, The', 3009, 99, 0, 0, NULL, NULL, 0, 0, 'The LP back states: "While the band was on the BBC''s ''ON TOUR'' series, Jim MacLeod hard this song for the first time in Bowmore, Isle of Islay."');
INSERT INTO 'recording' VALUES (10664, '2022-12-22 22:52:35.409691+00', '2022-12-26 19:20:49.76524+00', 'Hooper''s Jig', 3009, 2, 0, 32, NULL, NULL, 0, 0, 'Full title on the Cover of "Scotland Swings With The Great Jim MacLeod Band": "Hooper''s Jig With A Trip To Tomintoul And Midlothian Pipe Band"');
INSERT INTO 'recording' VALUES (2706, NULL, '2023-01-10 18:19:26.315368+00', 'Waves of Tory, The', 2089, 1, 8, 32, 9999, NULL, 0, 0, 'This recording with 32 bars only won''t fit most common dance descriptions for the SCD version of "Waves of Tory" (48 bars).');
INSERT INTO 'recording' VALUES (8273, NULL, '2022-12-23 00:03:40.208701+00', 'Mrs MacLeod/Dashing White Sergeant', 10104, 1, 8, 32, NULL, NULL, 275, 0, '');
INSERT INTO 'recording' VALUES (9530, '2014-03-16 10:09:45.659304+00', '2022-12-23 00:13:52.281373+00', 'Inverness Country Dance', 10920, 1, 9, 32, 9999, NULL, 303, 0, '');
INSERT INTO 'recording' VALUES (10665, '2022-12-22 22:53:15.687708+00', '2022-12-26 19:21:48.271659+00', 'Caledonian Schottische & Reel', 3009, 99, 0, 0, NULL, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (10676, '2022-12-23 12:14:43.113653+00', '2022-12-23 12:14:43.113653+00', 'Grand March & Reels', 3009, 99, 0, 0, NULL, NULL, 202, 0, 'The tune list is not complete.');
INSERT INTO 'recording' VALUES (10677, '2022-12-23 12:15:58.262027+00', '2022-12-23 12:15:58.262027+00', 'Hebridean Polka, The', 3009, 13, 0, 0, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (10678, '2022-12-23 12:17:34.118086+00', '2022-12-23 12:17:34.118086+00', 'Gay Gordon', 3009, 11, 0, 16, NULL, NULL, 193, 0, 'The tune list is not complete.');
INSERT INTO 'recording' VALUES (10679, '2022-12-23 12:18:57.74189+00', '2022-12-23 12:18:57.74189+00', 'Gay Gordons Encore', 3009, 11, 0, 16, NULL, NULL, 189, 0, 'The tune list is not complete.');
INSERT INTO 'recording' VALUES (10681, '2022-12-23 12:21:29.840031+00', '2022-12-23 12:21:29.840031+00', 'Scottish Waltz', 3009, 5, 0, 0, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (10682, '2022-12-23 12:23:51.028547+00', '2022-12-23 12:23:51.028547+00', 'Barn Dance', 3009, 99, 0, 0, NULL, NULL, 152, 0, '');
INSERT INTO 'recording' VALUES (10685, '2022-12-23 12:27:43.366677+00', '2022-12-23 12:27:43.366677+00', 'Highland Scottishe', 3009, 3, 0, 0, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (10686, '2022-12-23 12:30:35.298653+00', '2022-12-23 12:30:35.298653+00', 'Round Reel of Eight', 3009, 1, 1, 88, NULL, NULL, 105, 0, '');
INSERT INTO 'recording' VALUES (10687, '2022-12-23 12:32:23.855382+00', '2022-12-23 12:32:23.855382+00', 'Canadian Barn Dance', 3009, 11, 0, 16, NULL, NULL, 191, 0, '');
INSERT INTO 'recording' VALUES (10688, '2022-12-23 12:34:22.796338+00', '2022-12-23 12:34:22.796338+00', 'Strip the Willow', 3009, 2, 0, 0, NULL, NULL, 280, 0, 'The tune list might not be complete.');
INSERT INTO 'recording' VALUES (10670, '2022-12-23 12:03:23.753604+00', '2022-12-23 12:46:14.972007+00', 'Dashing White Sergeant', 3009, 1, 0, 32, NULL, NULL, 183, 0, 'The tune list might not be complete.');
INSERT INTO 'recording' VALUES (10671, '2022-12-23 12:05:35.716687+00', '2022-12-23 12:46:30.190921+00', 'Dashing White Sergeant Encore', 3009, 1, 0, 32, NULL, NULL, 148, 0, 'The tune list is not complete.');
INSERT INTO 'recording' VALUES (10672, '2022-12-23 12:06:48.63673+00', '2022-12-23 12:46:42.824928+00', 'Military Two-Step', 3009, 11, 0, 16, NULL, NULL, 163, 0, '');
INSERT INTO 'recording' VALUES (10673, '2022-12-23 12:08:17.91225+00', '2022-12-23 12:46:54.467592+00', 'Military Two-Step Encore', 3009, 11, 0, 16, NULL, NULL, 128, 0, '');
INSERT INTO 'recording' VALUES (7430, NULL, '2023-01-10 22:09:28.653022+00', 'Saint Bernard''s Waltz', 3065, 5, 0, 0, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (10666, '2022-12-22 22:53:42.00083+00', '2022-12-26 19:26:48.637959+00', 'Close The Door Gently', 3009, 99, 0, 0, NULL, NULL, 0, 0, 'The LP back states: "A complete change of style: Jim sings a waltz written by two of Scotland''s foremost songwriters, David Silver and Ian Gourlay."');
INSERT INTO 'recording' VALUES (10683, '2022-12-23 12:25:19.388567+00', '2022-12-23 12:48:12.818463+00', 'Circassian Circle', 3009, 1, 0, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (10684, '2022-12-23 12:26:25.871611+00', '2022-12-23 12:48:37.28258+00', 'Duke of Perth', 3009, 1, 0, 32, NULL, NULL, 211, 0, '');
INSERT INTO 'recording' VALUES (10667, '2022-12-22 22:54:04.899834+00', '2022-12-26 19:27:35.4324+00', 'Scottish Waltz', 3009, 5, 0, 0, NULL, NULL, 176, 0, '');
INSERT INTO 'recording' VALUES (6533, NULL, '2023-01-12 22:30:10.954227+00', 'Silver Tassie, The', 2586, 3, 8, 32, NULL, NULL, 531, 0, '');
INSERT INTO 'recording' VALUES (9003, '2012-12-28 16:43:43.986781+00', '2022-12-25 19:29:31.963697+00', 'White Heather Foxtrot', 2583, 50, 0, 0, 9999, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (7706, NULL, '2022-12-25 19:30:09.849807+00', 'White Heather Foxtrot, The', 10177, 50, 0, 0, NULL, NULL, 135, 0, '');
INSERT INTO 'recording' VALUES (3353, NULL, '2022-12-25 21:50:40.876615+00', 'Baden Powell, The', 2088, 11, 0, 8, 9999, NULL, 195, 0, '');
INSERT INTO 'recording' VALUES (9307, '2013-02-22 14:38:17.783525+00', '2022-12-25 23:03:13.014174+00', 'Lion Standard Quadrilles', 10209, 10, 1, 728, 9998, NULL, 811, 0, '');
INSERT INTO 'recording' VALUES (10674, '2022-12-23 12:09:55.720811+00', '2022-12-26 09:14:59.165635+00', 'Pride of Erin / St. Bernard''s Waltz', 3009, 5, 0, 32, NULL, NULL, 173, 0, 'The tune list is not complete.');
INSERT INTO 'recording' VALUES (10675, '2022-12-23 12:12:22.363085+00', '2022-12-26 09:15:19.481965+00', 'Pride of Erin / St. Bernard''s Waltz Encore', 3009, 5, 0, 32, NULL, NULL, 171, 0, 'The tune list might not be complete.');
INSERT INTO 'recording' VALUES (3227, NULL, '2022-12-26 18:12:51.444899+00', 'Eight Men of Moidart, The', 2173, 1, 8, 32, 9999, NULL, 0, 0, '');
INSERT INTO 'recording' VALUES (8276, NULL, '2022-12-26 18:20:20.150346+00', 'Military Two Step/Boston Two Step', 10104, 50, 0, 16, NULL, NULL, 140, 0, '');
INSERT INTO 'recording' VALUES (10669, '2022-12-22 22:55:14.058987+00', '2022-12-26 18:33:54.893469+00', 'Eightsome Reel', 3009, 1, 0, 0, NULL, NULL, 534, 0, '');
INSERT INTO 'recording' VALUES (10658, '2022-12-22 22:47:28.123742+00', '2022-12-26 19:07:50.462694+00', 'Gay Gordons', 3009, 11, 0, 16, NULL, NULL, 193, 0, '');
INSERT INTO 'recording' VALUES (10659, '2022-12-22 22:48:37.100354+00', '2022-12-26 19:08:45.54693+00', 'Whiskey On A Sunday', 3009, 99, 0, 0, NULL, NULL, 0, 0, 'The LP back states: "A song which Jim first heard on a ''Cairngorm Ski-Night'' TV show and thought would suit the band''s style.');
INSERT INTO 'recording' VALUES (10660, '2022-12-22 22:49:07.887654+00', '2022-12-26 19:10:44.255148+00', 'Highland Patrol, The', 3009, 99, 0, 0, NULL, NULL, 0, 0, 'The LP back states: "A novelty item with Jimmy MacFarlane playing his now famous ''penny whistle''."');
INSERT INTO 'recording' VALUES (10668, '2022-12-22 22:54:32.361778+00', '2022-12-26 19:28:33.087205+00', 'Trottin'' To The Fair', 3009, 99, 0, 0, NULL, NULL, 0, 0, 'The LP back states: "An Irish song, with percussions work bei Alex Mullan, George Hill and ''whistling'' Jimmy MacFarlane."');
INSERT INTO 'recording' VALUES (8760, NULL, '2022-12-26 21:50:22.593226+00', '2/4 Marches', 10555, 11, 0, 16, NULL, NULL, 203, 0, '');
INSERT INTO 'recording' VALUES (10167, '2018-03-30 08:53:34.616955+00', '2023-01-12 22:31:33.236436+00', 'Montgomeries'' Rant', 11613, 4, 4, 64, 5, NULL, 392, 0, '');
INSERT INTO 'recording' VALUES (9888, '2016-09-12 22:52:52.056425+00', '2023-01-01 02:03:39.966276+00', 'Spring Fling Reel, The', 11351, 1, 8, 40, NULL, 14, 346, 0, '');
INSERT INTO 'recording' VALUES (8165, NULL, '2023-01-01 21:43:35.831036+00', 'Eightsome Reel, The', 10268, 1, 1, 88, NULL, NULL, 102, 0, 'Odd recording when it comes to bar count. The Eightsome Reel requires 464 bars in its standard version.');
INSERT INTO 'recording' VALUES (7871, NULL, '2023-01-01 21:43:44.132604+00', 'Eightsome Reel, The', 3010, 1, 1, 176, NULL, NULL, 187, 0, 'Odd recording when it comes to bar count. The Eightsome Reel requires 464 bars in its standard version.');
INSERT INTO 'recording' VALUES (2686, NULL, '2023-01-01 21:43:51.244076+00', 'Eightsome Reel, The', 3010, 1, 0, 232, 9999, NULL, 230, 0, 'Odd recording when it comes to bar count. The Eightsome Reel requires 464 bars in its standard version.');
INSERT INTO 'recording' VALUES (3881, NULL, '2023-01-01 21:44:48.78086+00', 'Half Eightsome Reel', 2069, 1, 0, 272, 9999, NULL, 271, 0, 'Odd recording when it comes to bar count. The Eightsome Reel requires 464 bars in its standard version and due to its structure, a recording cannot be played twice.');
INSERT INTO 'recording' VALUES (4881, NULL, '2023-01-09 23:57:45.898864+00', 'Waves of Tory, The', 3037, 1, 4, 32, 9999, NULL, 142, 0, 'This recording with 32 bars only won''t fit most common dance descriptions for the SCD version of "Waves of Tory" (48 bars).');
INSERT INTO 'recording' VALUES (5836, NULL, '2023-01-18 17:31:14.003798+00', 'Brian''s Bairns', 3464, 2, 4, 32, 9999, NULL, 151, 0, 'All online sources for this recording state it is a "R4x32". Yet, it can''t be, as the dance and all tunes coming with it are jigs. ');
INSERT INTO 'recording' VALUES (2113, NULL, '2023-01-20 22:14:04.108696+00', 'Solway Reel, The', 3051, 1, 4, 48, 9999, 13, 0, 0, '');
INSERT INTO 'recording' VALUES (5973, NULL, '2023-01-21 13:00:10.132885+00', 'Braes of Balquhidder', 1836, 3, 8, 32, 9999, NULL, 0, 0, 'Other than its title suggest, this recording fits none of the two dances of the same name (one is a reel, the other one has a different bar count). The editors decided to connect this recording to "Balquidder Strathspey" instead.');
INSERT INTO 'recording' VALUES (10694, '2023-02-26 22:28:17.632117+00', '2023-02-27 00:06:47.52228+00', 'Frisky Ten Years', 11953, 1, 4, 32, NULL, NULL, 152, 1, '');
INSERT INTO 'recording' VALUES (10690, '2023-02-26 21:59:17.636311+00', '2023-02-26 23:19:39.980229+00', 'Dancing on West Sands', 11953, 1, 8, 32, NULL, NULL, 287, 0, '');
INSERT INTO 'recording' VALUES (10693, '2023-02-26 22:26:41.250563+00', '2023-02-26 23:18:14.123744+00', 'Bouquets', 11953, 3, 3, 32, NULL, NULL, 202, 0, '');
INSERT INTO 'recording' VALUES (10692, '2023-02-26 22:25:57.663407+00', '2023-02-26 23:18:43.076276+00', 'Sweetfish of Neo River', 11953, 2, 8, 32, NULL, NULL, 288, 0, '');
INSERT INTO 'recording' VALUES (10691, '2023-02-26 22:02:55.923794+00', '2023-02-26 23:19:13.116035+00', 'Leisurely Stroll, A', 11953, 3, 8, 32, NULL, NULL, 553, 0, '');
INSERT INTO 'recording' VALUES (10689, '2023-02-26 21:57:04.852162+00', '2023-02-26 23:20:00.530498+00', 'Happy Dancing', 11953, 2, 8, 32, NULL, NULL, 284, 0, '');
INSERT INTO 'recording' VALUES (10699, '2023-02-26 23:09:03.740017+00', '2023-02-26 23:09:03.740017+00', 'Yamashita Park', 11953, 3, 8, 32, NULL, NULL, 518, 0, '');
INSERT INTO 'recording' VALUES (10700, '2023-02-26 23:14:11.747752+00', '2023-02-26 23:15:05.73857+00', 'Always on My Mind', 11953, 1, 8, 32, NULL, NULL, 286, 0, '');
INSERT INTO 'recording' VALUES (10698, '2023-02-26 22:45:54.031246+00', '2023-02-26 23:15:23.197139+00', 'Peatys Jig', 11953, 2, 8, 32, NULL, NULL, 277, 0, '');
INSERT INTO 'recording' VALUES (10697, '2023-02-26 22:39:32.799454+00', '2023-02-26 23:15:39.660921+00', 'Celebrate Ten and Twenty Years', 11953, 3, 3, 32, NULL, NULL, 206, 0, '');
INSERT INTO 'recording' VALUES (10696, '2023-02-26 22:37:55.526355+00', '2023-02-26 23:16:03.151516+00', 'Happy Anniversary', 11953, 2, 8, 40, NULL, NULL, 352, 0, '');
INSERT INTO 'recording' VALUES (10695, '2023-02-26 22:35:46.57013+00', '2023-02-26 23:16:32.463757+00', 'Gate of Daffodil Garden, The', 11953, 3, 8, 32, NULL, NULL, 514, 0, '');


--
INSERT INTO 'shape' VALUES (103, 'Longwise - any', 'L-any');
INSERT INTO 'shape' VALUES (104, 'Longwise - 2', 'L2');
INSERT INTO 'shape' VALUES (105, 'Lines', 'ln');
INSERT INTO 'shape' VALUES (1, 'Longwise - 4', 'L4');
INSERT INTO 'shape' VALUES (2, 'Longwise - 3', 'L3');
INSERT INTO 'shape' VALUES (3, 'Longwise - 5', 'L5');
INSERT INTO 'shape' VALUES (4, 'Square', 'Square');
INSERT INTO 'shape' VALUES (5, 'Round the room', 'RtR');
INSERT INTO 'shape' VALUES (6, 'Triangular', 'Tri');
INSERT INTO 'shape' VALUES (7, 'Circle', 'Circle');
INSERT INTO 'shape' VALUES (8, 'Longwise - 6', 'L6');
INSERT INTO 'shape' VALUES (9, 'Longwise - 7', 'L7');
INSERT INTO 'shape' VALUES (10, 'Longwise - 8', 'L8');
INSERT INTO 'shape' VALUES (99, 'Unknown', '?');
INSERT INTO 'shape' VALUES (101, 'Hexagonal', 'Hex');
INSERT INTO 'shape' VALUES (102, 'Pentagonal', 'Pent');
INSERT INTO 'shape' VALUES (100, 'Longwise & Square', 'L&S');
INSERT INTO 'shape' VALUES (107, 'Other', 'Other');
INSERT INTO 'shape' VALUES (11, 'Other ?', 'Other ?');


--
INSERT INTO 'shapeprogressionsmap' VALUES (1, 1, 1, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (2, 1, 2, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (3, 1, 5, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (4, 1, 11, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (5, 3, 3, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (6, 3, 4, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (7, 3, 6, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (8, 3, 7, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (9, 3, 8, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (10, 3, 10, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (11, 4, 1, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (12, 4, 3, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (13, 8, 9, 6);
INSERT INTO 'shapeprogressionsmap' VALUES (14, 8, 12, 6);
INSERT INTO 'shapeprogressionsmap' VALUES (15, 3, 7, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (16, 1, 13, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (17, 1, 14, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (18, 1, 15, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (19, 3, 16, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (20, 2, 17, 3);
INSERT INTO 'shapeprogressionsmap' VALUES (21, 2, 17, 2);
INSERT INTO 'shapeprogressionsmap' VALUES (22, 2, 18, 3);
INSERT INTO 'shapeprogressionsmap' VALUES (23, 2, 3, 3);
INSERT INTO 'shapeprogressionsmap' VALUES (24, 2, 4, 3);
INSERT INTO 'shapeprogressionsmap' VALUES (25, 3, 19, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (26, 6, 17, 3);
INSERT INTO 'shapeprogressionsmap' VALUES (27, 6, 18, 3);
INSERT INTO 'shapeprogressionsmap' VALUES (28, 3, 20, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (29, 3, 21, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (30, 11, 17, 53);
INSERT INTO 'shapeprogressionsmap' VALUES (31, 4, 21, 55);
INSERT INTO 'shapeprogressionsmap' VALUES (32, 4, 6, 55);
INSERT INTO 'shapeprogressionsmap' VALUES (33, 1, 22, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (34, 1, 4, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (35, 1, 8, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (37, 1, 18, 3);
INSERT INTO 'shapeprogressionsmap' VALUES (38, 8, 25, 6);
INSERT INTO 'shapeprogressionsmap' VALUES (39, 4, 13, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (40, 3, 26, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (42, 4, 14, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (43, 4, 16, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (44, 4, 6, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (45, 4, 28, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (47, 1, 1, 2);
INSERT INTO 'shapeprogressionsmap' VALUES (48, 7, 17, 3);
INSERT INTO 'shapeprogressionsmap' VALUES (49, 1, 30, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (50, 3, 31, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (51, 8, 32, 6);
INSERT INTO 'shapeprogressionsmap' VALUES (52, 3, 33, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (53, 8, 34, 6);
INSERT INTO 'shapeprogressionsmap' VALUES (54, 1, 1, 3);
INSERT INTO 'shapeprogressionsmap' VALUES (55, 4, 35, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (56, 9, 36, 7);
INSERT INTO 'shapeprogressionsmap' VALUES (57, 3, 37, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (58, 3, 35, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (59, 4, 1, 54);
INSERT INTO 'shapeprogressionsmap' VALUES (60, 11, 2, 54);
INSERT INTO 'shapeprogressionsmap' VALUES (61, 4, 4, 4);
INSERT INTO 'shapeprogressionsmap' VALUES (62, 3, 38, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (63, 8, 39, 6);
INSERT INTO 'shapeprogressionsmap' VALUES (64, 3, 40, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (65, 6, 4, 3);
INSERT INTO 'shapeprogressionsmap' VALUES (66, 3, 41, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (67, 6, 18, 53);
INSERT INTO 'shapeprogressionsmap' VALUES (68, 4, 21, 5);
INSERT INTO 'shapeprogressionsmap' VALUES (69, 11, 13, 54);


--
INSERT INTO 'step' VALUES (1, 'Skip-Change', 'SkCh');
INSERT INTO 'step' VALUES (2, 'Pas-de-Basque', 'Pdb');
INSERT INTO 'step' VALUES (3, 'Slip-Step', 'Slip');
INSERT INTO 'step' VALUES (4, 'Strathspey travel', 'S-Trv');
INSERT INTO 'step' VALUES (5, 'Strathspey setting', 'S-Set');
INSERT INTO 'step' VALUES (6, 'Highland Schottische', 'HS');
INSERT INTO 'step' VALUES (7, 'Running', 'Run');
INSERT INTO 'step' VALUES (8, 'Tulloch turn', 'Tulloch');
INSERT INTO 'step' VALUES (9, 'Glasgow Highlanders', 'GHSet');
INSERT INTO 'step' VALUES (10, 'Highland', 'HLSet');
INSERT INTO 'step' VALUES (99, 'other', 'Other');
INSERT INTO 'step' VALUES (101, 'Minuet PdB/Pas de Valse', 'Min/PdV');
INSERT INTO 'step' VALUES (103, 'Spring Points', 'Points');
INSERT INTO 'step' VALUES (102, 'Coupé / Balance', 'Coupé');


--
INSERT INTO 'tune' VALUES (22, NULL, '2012-01-20 12:54:20.32135+00', 'Alec''s Baldy Pow', 1725, '');
INSERT INTO 'tune' VALUES (1, NULL, '2012-01-20 12:54:20.252172+00', '1066 and all that', 9998, '');
INSERT INTO 'tune' VALUES (3725, NULL, '2012-01-20 12:54:32.386972+00', 'R. D. Hunter''s Reel', 1437, '');
INSERT INTO 'tune' VALUES (2, NULL, '2012-01-20 12:54:20.255936+00', 'Jig for Joy', 1510, '');
INSERT INTO 'tune' VALUES (23, NULL, '2012-01-20 12:54:20.324346+00', 'Alewife and her Barrel, The', 9999, '');
INSERT INTO 'tune' VALUES (3, NULL, '2012-01-20 12:54:20.258949+00', '21st of October, The', 9999, '');
INSERT INTO 'tune' VALUES (3726, NULL, '2012-01-20 12:54:32.390014+00', 'Enchanted Isle, The', 1607, '');
INSERT INTO 'tune' VALUES (4, NULL, '2012-01-20 12:54:20.261939+00', 'Twopenny Jig', 2156, '');
INSERT INTO 'tune' VALUES (24, NULL, '2012-01-20 12:54:20.327283+00', 'Alex. McGlashan''s Farewell', 1587, '');
INSERT INTO 'tune' VALUES (5, NULL, '2012-01-20 12:54:20.264875+00', '60th Summer School, The', 1502, '');
INSERT INTO 'tune' VALUES (3727, NULL, '2012-01-20 12:54:32.392934+00', 'Turnpike Rant, The', 1839, '');
INSERT INTO 'tune' VALUES (6, NULL, '2012-01-20 12:54:20.267829+00', '74th Highlanders'' Quickstep, The', 9999, '');
INSERT INTO 'tune' VALUES (25, NULL, '2012-01-20 12:54:20.330218+00', 'Alison Laing', 9998, '');
INSERT INTO 'tune' VALUES (7, NULL, '2012-01-20 12:54:20.273286+00', 'Mrs Forbes Leith', 1512, '');
INSERT INTO 'tune' VALUES (3728, NULL, '2012-01-20 12:54:32.395849+00', 'Dale and Janet''s Strathspey', 1745, '');
INSERT INTO 'tune' VALUES (8, NULL, '2012-01-20 12:54:20.276923+00', 'A M Shinnie', 1554, '');
INSERT INTO 'tune' VALUES (26, NULL, '2012-01-20 12:54:20.333134+00', 'Alison Rose', 9998, '');
INSERT INTO 'tune' VALUES (9, NULL, '2012-01-20 12:54:20.279957+00', 'Aberlour House', 1487, '');
INSERT INTO 'tune' VALUES (3729, NULL, '2012-01-20 12:54:32.398956+00', 'Bill Hamilton', 1502, '');
INSERT INTO 'tune' VALUES (10, NULL, '2012-01-20 12:54:20.282961+00', 'Saint Connal''s Well', 9998, '');
INSERT INTO 'tune' VALUES (27, NULL, '2012-01-20 12:54:20.336053+00', 'Alister McAlister', 9999, '');
INSERT INTO 'tune' VALUES (11, NULL, '2012-01-20 12:54:20.285885+00', 'Gordon''s Jig', 1501, '');
INSERT INTO 'tune' VALUES (3730, NULL, '2012-01-20 12:54:32.401868+00', 'Epsom Caledonian, The', 1840, '');
INSERT INTO 'tune' VALUES (12, NULL, '2012-01-20 12:54:20.288831+00', 'Admiral Nelson', 1518, '');
INSERT INTO 'tune' VALUES (28, NULL, '2012-01-20 12:54:20.341012+00', 'Ms Arlene Baxter', 1780, '');
INSERT INTO 'tune' VALUES (13, NULL, '2012-01-20 12:54:20.293862+00', 'Aiken Drum', 9999, '');
INSERT INTO 'tune' VALUES (3731, NULL, '2012-01-20 12:54:32.404764+00', 'Lynley''s Lilt', 1986, '');
INSERT INTO 'tune' VALUES (14, NULL, '2012-01-20 12:54:20.296812+00', 'Airdrie Lassies', 9999, '');
INSERT INTO 'tune' VALUES (29, NULL, '2012-01-20 12:54:20.345043+00', 'Alloa Kirk', 9999, '');
INSERT INTO 'tune' VALUES (15, NULL, '2012-01-20 12:54:20.300239+00', 'Stonehave March, The', 9999, '');
INSERT INTO 'tune' VALUES (16, NULL, '2012-01-20 12:54:20.303297+00', 'Alan Grant', 1586, '');
INSERT INTO 'tune' VALUES (30, NULL, '2012-01-20 12:54:20.34801+00', 'Alltreoch', 1410, '');
INSERT INTO 'tune' VALUES (3733, NULL, '2012-01-20 12:54:32.410561+00', 'Eriskay Boat, The', 9998, '');
INSERT INTO 'tune' VALUES (18, NULL, '2012-01-20 12:54:20.309182+00', 'Loch Assipol', 1608, '');
INSERT INTO 'tune' VALUES (31, NULL, '2012-01-20 12:54:20.350945+00', 'Alltshellach', 1617, '');
INSERT INTO 'tune' VALUES (19, NULL, '2012-01-20 12:54:20.312113+00', 'Ale is Dear, The', 9999, '');
INSERT INTO 'tune' VALUES (3734, NULL, '2012-01-20 12:54:32.41346+00', 'Ewan Telford', 1502, '');
INSERT INTO 'tune' VALUES (32, NULL, '2012-01-20 12:54:20.353881+00', 'Always Welcome', 2135, '');
INSERT INTO 'tune' VALUES (21, NULL, '2012-01-20 12:54:20.317954+00', 'Alec Heard', 1797, '');
INSERT INTO 'tune' VALUES (3735, NULL, '2012-01-20 12:54:32.416356+00', 'Exposition Reel, The', 1764, '');
INSERT INTO 'tune' VALUES (33, NULL, '2012-01-20 12:54:20.357192+00', 'Chrissie Forsyth', 1555, '');
INSERT INTO 'tune' VALUES (34, NULL, '2012-01-20 12:54:20.360136+00', 'Alyth Burn', 1558, '');
INSERT INTO 'tune' VALUES (35, NULL, '2012-01-20 12:54:20.363068+00', 'An'' thou wert my only Dear', 9999, '');
INSERT INTO 'tune' VALUES (36, NULL, '2012-01-20 12:54:20.365992+00', 'Anderson''s Rant', 1516, '');
INSERT INTO 'tune' VALUES (38, NULL, '2012-01-20 12:54:20.371848+00', 'Andrew''s Reel', 1501, '');
INSERT INTO 'tune' VALUES (3737, NULL, '2012-01-20 12:54:32.422247+00', 'Gipsy Laddie, The', 9998, '');
INSERT INTO 'tune' VALUES (39, NULL, '2012-01-20 12:54:20.374758+00', 'Angus Campbell', 1512, '');
INSERT INTO 'tune' VALUES (40, NULL, '2012-01-20 12:54:20.377669+00', 'Angus MacKinnon''s Hornpipe', 1414, '');
INSERT INTO 'tune' VALUES (3738, NULL, '2012-01-20 12:54:32.425158+00', 'Faery Lullaby, A', 9999, '');
INSERT INTO 'tune' VALUES (41, NULL, '2012-01-20 12:54:20.380868+00', 'Angus MacLeod', 1533, '');
INSERT INTO 'tune' VALUES (42, NULL, '2012-01-20 12:54:20.383796+00', 'Angus Reel, The', 9998, '');
INSERT INTO 'tune' VALUES (3739, NULL, '2012-01-20 12:54:32.428058+00', 'Failte Do''nla', 1707, '');
INSERT INTO 'tune' VALUES (44, NULL, '2012-01-20 12:54:20.389652+00', 'Ann Nisbet', 1836, '');
INSERT INTO 'tune' VALUES (45, NULL, '2012-01-20 12:54:20.392641+00', 'Anna Campbell Holden', 1502, '');
INSERT INTO 'tune' VALUES (3740, NULL, '2012-01-20 12:54:32.430962+00', 'Lonach Gathering, The', 1473, '');
INSERT INTO 'tune' VALUES (46, NULL, '2012-01-20 12:54:20.395567+00', 'Annandale Strathspey, The', 1443, '');
INSERT INTO 'tune' VALUES (47, NULL, '2012-01-20 12:54:20.398491+00', 'Anne', 1607, '');
INSERT INTO 'tune' VALUES (48, NULL, '2012-01-20 12:54:20.401426+00', 'Aon Da Tri', 1582, '');
INSERT INTO 'tune' VALUES (49, NULL, '2012-01-20 12:54:20.405174+00', 'Apple Tree, The', 1424, '');
INSERT INTO 'tune' VALUES (50, NULL, '2012-01-20 12:54:20.408473+00', 'Archie Buchanan', 1797, '');
INSERT INTO 'tune' VALUES (51, NULL, '2012-01-20 12:54:20.411428+00', 'Archie Menzies', 445, '');
INSERT INTO 'tune' VALUES (52, NULL, '2012-01-20 12:54:20.414361+00', 'Archivist, The', 1502, '');
INSERT INTO 'tune' VALUES (53, NULL, '2012-01-20 12:54:20.417284+00', 'Argyll Assembly, The', 1502, '');
INSERT INTO 'tune' VALUES (3743, NULL, '2012-01-20 12:54:32.439936+00', 'Donald MacLeod''s Farewell to Fort George', 9998, '');
INSERT INTO 'tune' VALUES (3744, NULL, '2012-01-20 12:54:32.442854+00', '79th''s Farewell to Gibraltar, The', 1549, '');
INSERT INTO 'tune' VALUES (3745, NULL, '2012-01-20 12:54:32.445758+00', 'Earl of Epsom', 1590, '');
INSERT INTO 'tune' VALUES (3746, NULL, '2012-01-20 12:54:32.449388+00', 'Ian Muir''s Compliments to John Browne', 1590, '');
INSERT INTO 'tune' VALUES (3747, NULL, '2012-01-20 12:54:32.452295+00', 'Miss Jane Purves''s Delight', 1576, '');
INSERT INTO 'tune' VALUES (3748, NULL, '2012-01-20 12:54:32.455199+00', 'Tartan Andy''s Half Pint Shandy', 1846, '');
INSERT INTO 'tune' VALUES (3749, NULL, '2012-01-20 12:54:32.458087+00', 'Golden Slippers, Dem', 1957, '');
INSERT INTO 'tune' VALUES (3732, NULL, '2012-01-22 19:04:09.19471+00', 'H.I.S.C.D.', 2054, '');
INSERT INTO 'tune' VALUES (12001, '2012-02-06 11:09:02.540255+00', '2012-02-06 12:16:44.742499+00', 'Queen of the South Polka, The', 1668, '');
INSERT INTO 'tune' VALUES (12024, '2012-02-07 10:21:37.512749+00', '2012-02-07 10:21:37.512759+00', 'Waltz For Jessie Stuart, A', 1591, '');
INSERT INTO 'tune' VALUES (12038, '2012-02-09 00:47:46.824051+00', '2012-02-09 00:47:46.824061+00', 'Robert and Patsy Rennie', 10604, '');
INSERT INTO 'tune' VALUES (12040, '2012-04-23 10:22:54.800686+00', '2012-04-23 10:22:54.800697+00', 'Port Ui Fhaolain', 9999, '');
INSERT INTO 'tune' VALUES (12041, '2012-04-29 12:58:30.766288+00', '2012-04-29 12:58:30.766299+00', 'On Top of Ben Lomond', 9999, '');
INSERT INTO 'tune' VALUES (12042, '2012-04-29 13:40:46.152102+00', '2012-04-29 13:40:46.152114+00', 'Wi'' a Hundred Pipers', 9999, '');
INSERT INTO 'tune' VALUES (12043, '2012-04-29 14:09:48.404401+00', '2012-04-29 14:09:48.404412+00', 'Julia Place', 1502, '');
INSERT INTO 'tune' VALUES (12044, '2012-05-04 18:52:03.548092+00', '2012-05-04 18:52:03.548103+00', 'Mr Houston of Robert''s Wharf', 1502, '');
INSERT INTO 'tune' VALUES (12082, '2012-05-06 21:59:04.966026+00', '2012-05-06 22:01:06.885598+00', 'Campsie Glen', 9999, '');
INSERT INTO 'tune' VALUES (12083, '2012-05-07 20:38:45.105447+00', '2012-05-07 20:38:45.105458+00', 'May and John McAllister', 1981, '');
INSERT INTO 'tune' VALUES (12084, '2012-05-31 07:10:22.237426+00', '2012-05-31 07:10:22.237437+00', 'Jim Dougal of Eyemouth', 1502, '');
INSERT INTO 'tune' VALUES (12161, '2012-06-12 22:17:00.447332+00', '2012-06-12 22:17:00.447342+00', 'Derek Haynes', 1502, '');
INSERT INTO 'tune' VALUES (12168, '2012-06-13 08:16:12.861338+00', '2012-06-13 08:16:12.861349+00', 'Bonnie Glenisla', 1480, '');
INSERT INTO 'tune' VALUES (12179, '2012-06-17 14:23:26.649833+00', '2012-06-17 14:23:26.649845+00', 'Betsy Hooper''s Jig', 10635, '');
INSERT INTO 'tune' VALUES (12193, '2012-07-22 13:20:34.05179+00', '2012-07-22 13:20:34.051801+00', 'Thousand Oaks Jig', 1582, '');
INSERT INTO 'tune' VALUES (12198, '2012-08-15 09:09:11.077065+00', '2012-08-15 09:09:11.077076+00', 'Jane''s Thirtieth', 3452, '');
INSERT INTO 'tune' VALUES (12199, '2012-08-19 19:45:48.944915+00', '2012-08-19 19:45:48.944926+00', 'Snow on the Roof', 1508, '');
INSERT INTO 'tune' VALUES (12200, '2012-08-23 16:22:48.668699+00', '2012-08-23 16:22:48.66871+00', 'Lady Julia Griffin', 1173, '');
INSERT INTO 'tune' VALUES (12201, '2012-09-08 12:10:19.399712+00', '2012-09-08 12:10:19.399723+00', 'William John Beatty', 1607, 'Source: "Corstorphine Fair" leaflet, Mozart Allan, Glasgow (no date)');
INSERT INTO 'tune' VALUES (54, NULL, '2012-01-20 12:54:20.420322+00', 'Argyll Ludging, The', 1837, '');
INSERT INTO 'tune' VALUES (12195, '2012-07-22 13:47:14.271238+00', '2018-04-07 23:36:59.672226+00', 'Strathspey Decadence', 3179, '');
INSERT INTO 'tune' VALUES (3750, NULL, '2012-01-20 12:54:32.461073+00', 'Ginette', 1203, '');
INSERT INTO 'tune' VALUES (55, NULL, '2012-01-20 12:54:20.423291+00', 'Argyll is my Name', 9999, '');
INSERT INTO 'tune' VALUES (43, NULL, '2013-11-16 20:58:16.001526+00', 'Ann Caithness', 10896, 'Douglas Henderson wrote "The Tartan Waistcoat" and published it in Scottish Dance Archives (September 1972, No. 2). He said: "Recommended tune:- Ann Caithness (composed Bert Brown, arranged Nan Main)."

We have no other information yet on Bert Brown');
INSERT INTO 'tune' VALUES (20, NULL, '2014-11-18 00:52:38.943659+00', 'Mrs Fordyce of Ayton''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (56, NULL, '2012-01-20 12:54:20.426219+00', 'Argyll''s Bowling Green', 1518, '');
INSERT INTO 'tune' VALUES (76, NULL, '2012-01-20 12:54:20.485762+00', 'Babes in the Wood', 9999, '');
INSERT INTO 'tune' VALUES (3741, NULL, '2018-04-10 12:52:26.609608+00', 'Fanny Power', 1882, '');
INSERT INTO 'tune' VALUES (12098, '2012-06-12 14:07:42.971579+00', '2018-11-14 14:43:31.302245+00', 'Anne Newton''s Jig', 1596, '');
INSERT INTO 'tune' VALUES (3736, NULL, '2019-04-22 12:07:30.088657+00', 'Driving Force, The', 1842, '');
INSERT INTO 'tune' VALUES (3751, NULL, '2012-01-20 12:54:32.463991+00', 'Gair''s Rant', 9998, '');
INSERT INTO 'tune' VALUES (57, NULL, '2012-01-20 12:54:20.429151+00', 'Arrival at Paris, The', 9999, '');
INSERT INTO 'tune' VALUES (58, NULL, '2012-01-20 12:54:20.432089+00', 'Arthur''s Seat', 1512, '');
INSERT INTO 'tune' VALUES (77, NULL, '2012-01-20 12:54:20.488677+00', 'Back o'' Bennachie', 9999, '');
INSERT INTO 'tune' VALUES (3752, NULL, '2012-01-20 12:54:32.47082+00', 'Farmer''s Jamboree', 9999, '');
INSERT INTO 'tune' VALUES (59, NULL, '2012-01-20 12:54:20.434998+00', 'Ashfield', 9998, '');
INSERT INTO 'tune' VALUES (12002, '2012-02-06 11:10:44.645743+00', '2012-02-06 11:10:44.645753+00', 'Paddy Neary', 1554, '');
INSERT INTO 'tune' VALUES (60, NULL, '2012-01-20 12:54:20.437911+00', 'At the Edge of the Clear Running Burn', 1816, '');
INSERT INTO 'tune' VALUES (78, NULL, '2012-01-20 12:54:20.49161+00', 'Balcomie House', 9999, '');
INSERT INTO 'tune' VALUES (12025, '2012-02-07 10:24:33.015939+00', '2012-02-07 10:24:33.015949+00', 'Bert Murray''s Reel', 1591, '');
INSERT INTO 'tune' VALUES (61, NULL, '2012-01-20 12:54:20.440828+00', 'At the Fair', 9999, '');
INSERT INTO 'tune' VALUES (12039, '2012-02-09 00:49:12.939083+00', '2012-02-09 00:49:12.939094+00', 'Echline Green', 2668, '');
INSERT INTO 'tune' VALUES (86, NULL, '2012-03-14 11:14:13.885379+00', 'Banjo Breakdown', 1910, '');
INSERT INTO 'tune' VALUES (79, NULL, '2012-01-20 12:54:20.494547+00', 'Baldooser, The', 9999, '');
INSERT INTO 'tune' VALUES (12045, '2012-05-04 18:52:35.364243+00', '2012-05-04 18:52:35.364254+00', 'Bungee Jump', 1502, '');
INSERT INTO 'tune' VALUES (12085, '2012-05-31 07:21:19.286782+00', '2012-05-31 07:21:19.286793+00', 'Margo''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (80, NULL, '2012-01-20 12:54:20.497462+00', 'Baldovan Jig', 1624, '');
INSERT INTO 'tune' VALUES (12099, '2012-06-12 14:09:11.144537+00', '2012-06-12 14:09:11.144548+00', 'Rock Valley Jig', 9998, '');
INSERT INTO 'tune' VALUES (12169, '2012-06-13 08:23:19.838141+00', '2012-06-13 08:23:19.838152+00', 'Tillytweedle Cat Army, The', 1506, '');
INSERT INTO 'tune' VALUES (81, NULL, '2012-01-20 12:54:20.500389+00', 'Baldovan Reel', 1624, '');
INSERT INTO 'tune' VALUES (12180, '2012-06-17 14:23:53.558933+00', '2012-06-17 14:23:53.558944+00', 'Trip to Ottawa', 2395, '');
INSERT INTO 'tune' VALUES (82, NULL, '2012-01-20 12:54:20.503308+00', 'Baldovan Strathspey', 1624, '');
INSERT INTO 'tune' VALUES (12194, '2012-07-22 13:21:48.353447+00', '2012-07-22 13:21:48.353459+00', 'Mr Robb Quint', 1582, '');
INSERT INTO 'tune' VALUES (64, NULL, '2012-01-20 12:54:20.449649+00', 'Atholl House', 1781, '');
INSERT INTO 'tune' VALUES (83, NULL, '2012-01-20 12:54:20.506224+00', 'Ballemuir Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (12202, '2012-09-28 13:36:37.545122+00', '2012-09-28 13:36:37.545132+00', 'Ewie Dubh', 2961, '');
INSERT INTO 'tune' VALUES (65, NULL, '2012-01-20 12:54:20.45258+00', 'Auld Cliff Hoose, The', 1955, '');
INSERT INTO 'tune' VALUES (84, NULL, '2012-01-20 12:54:20.509145+00', 'Balmoral', 1797, '');
INSERT INTO 'tune' VALUES (85, NULL, '2012-01-20 12:54:20.512078+00', 'Bamberg March', 1718, '');
INSERT INTO 'tune' VALUES (66, NULL, '2012-01-20 12:54:20.4555+00', 'Auld Inn, The', 9999, '');
INSERT INTO 'tune' VALUES (67, NULL, '2012-01-20 12:54:20.458407+00', 'Auld Jock the Tinker', 1725, '');
INSERT INTO 'tune' VALUES (87, NULL, '2012-01-20 12:54:20.517948+00', 'Bank Street Reel', 9998, '');
INSERT INTO 'tune' VALUES (88, NULL, '2012-01-20 12:54:20.520904+00', 'Banks Hornpipe', 1767, '');
INSERT INTO 'tune' VALUES (68, NULL, '2012-01-20 12:54:20.461334+00', 'Auld Luckie', 9999, '');
INSERT INTO 'tune' VALUES (89, NULL, '2012-01-20 12:54:20.52386+00', 'Pied Wagtail, The', 1502, '');
INSERT INTO 'tune' VALUES (69, NULL, '2012-01-20 12:54:20.464275+00', 'Auld Road to Towie, The', 9998, '');
INSERT INTO 'tune' VALUES (90, NULL, '2012-01-20 12:54:20.526777+00', 'Banks of the Allan, The', 9999, '');
INSERT INTO 'tune' VALUES (70, NULL, '2012-01-20 12:54:20.467207+00', 'Auld Robin Gray', 1433, '');
INSERT INTO 'tune' VALUES (71, NULL, '2012-01-20 12:54:20.470124+00', 'Auld Toon o'' Ayr, The', 9999, '');
INSERT INTO 'tune' VALUES (93, NULL, '2012-01-20 12:54:20.535529+00', 'Banks of Spey, The', 1516, '');
INSERT INTO 'tune' VALUES (72, NULL, '2012-01-20 12:54:20.473854+00', 'Auprez de ma blonde', 9998, '');
INSERT INTO 'tune' VALUES (73, NULL, '2012-01-20 12:54:20.476836+00', 'Australian Ladies, The', 1434, '');
INSERT INTO 'tune' VALUES (94, NULL, '2012-01-20 12:54:20.538444+00', 'Bannockburn', 1701, '');
INSERT INTO 'tune' VALUES (74, NULL, '2012-01-20 12:54:20.479895+00', 'Avril Jones', 1725, '');
INSERT INTO 'tune' VALUES (95, NULL, '2012-01-20 12:54:20.541426+00', 'Bannocks and Brose', 1701, '');
INSERT INTO 'tune' VALUES (96, NULL, '2012-01-20 12:54:20.544345+00', 'Barbara McOwen''s Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (97, NULL, '2012-01-20 12:54:20.547263+00', 'Barley Cakes', 9999, '');
INSERT INTO 'tune' VALUES (99, NULL, '2012-01-20 12:54:20.553105+00', 'Barras Bridge', 1533, '');
INSERT INTO 'tune' VALUES (100, NULL, '2012-01-20 12:54:20.556027+00', 'Barren Rocks of Aden, The', 1440, '');
INSERT INTO 'tune' VALUES (101, NULL, '2012-01-20 12:54:20.558944+00', 'Beamsley Hall', 1607, '');
INSERT INTO 'tune' VALUES (102, NULL, '2012-01-20 12:54:20.561857+00', 'Bean na bainnse', 9998, '');
INSERT INTO 'tune' VALUES (103, NULL, '2012-01-20 12:54:20.564791+00', 'Beauty of the North, The', 2142, '');
INSERT INTO 'tune' VALUES (104, NULL, '2012-01-20 12:54:20.567721+00', 'Because he was a Bonnie Lad', 9999, '');
INSERT INTO 'tune' VALUES (105, NULL, '2012-01-20 12:54:20.570643+00', 'Bel Fiore', 2346, '');
INSERT INTO 'tune' VALUES (106, NULL, '2012-01-20 12:54:20.573573+00', 'Belfast Almanac, The', 9999, '');
INSERT INTO 'tune' VALUES (107, NULL, '2012-01-20 12:54:20.576483+00', 'Galloway Holiday, A', 1504, '');
INSERT INTO 'tune' VALUES (129, NULL, '2012-01-20 12:54:20.64128+00', 'Blue Bonnets', 9999, '');
INSERT INTO 'tune' VALUES (108, NULL, '2012-01-20 12:54:20.579418+00', 'Bell Tower, The', 1502, '');
INSERT INTO 'tune' VALUES (3753, NULL, '2012-01-20 12:54:32.486127+00', 'Far Up the Glen', 9998, '');
INSERT INTO 'tune' VALUES (130, NULL, '2012-01-20 12:54:20.644294+00', 'George Stirrat''s Rant', 1505, '');
INSERT INTO 'tune' VALUES (110, NULL, '2012-01-20 12:54:20.585377+00', 'Belle of Bon Accord, The', 9998, '');
INSERT INTO 'tune' VALUES (3754, NULL, '2012-01-20 12:54:32.490649+00', 'Father Kelly', 9999, '');
INSERT INTO 'tune' VALUES (111, NULL, '2012-01-20 12:54:20.58833+00', 'Bert McCroskie', 1796, '');
INSERT INTO 'tune' VALUES (3755, NULL, '2012-01-20 12:54:32.494476+00', 'Approach to Grantown on Spey', 3505, '');
INSERT INTO 'tune' VALUES (113, NULL, '2012-01-20 12:54:20.594193+00', 'Bett Nairn', 1520, '');
INSERT INTO 'tune' VALUES (132, NULL, '2012-01-20 12:54:20.650144+00', 'Bluebell Polka, The', 2004, '');
INSERT INTO 'tune' VALUES (114, NULL, '2012-01-20 12:54:20.597128+00', 'Bide Ye Yet', 9999, '');
INSERT INTO 'tune' VALUES (3756, NULL, '2012-01-20 12:54:32.49828+00', 'Female Saylor, The', 9998, '');
INSERT INTO 'tune' VALUES (115, NULL, '2012-01-20 12:54:20.600045+00', 'Bill Hendry of Downfield', 1576, '');
INSERT INTO 'tune' VALUES (133, NULL, '2012-01-20 12:54:20.653086+00', 'Boatie Rows, The', 9999, '');
INSERT INTO 'tune' VALUES (116, NULL, '2012-01-20 12:54:20.602998+00', 'Bill Powrie', 1551, '');
INSERT INTO 'tune' VALUES (3757, NULL, '2012-01-20 12:54:32.503318+00', 'Feshiebridge', 275, '');
INSERT INTO 'tune' VALUES (117, NULL, '2012-01-20 12:54:20.605911+00', 'Bill Zobel', 1502, '');
INSERT INTO 'tune' VALUES (134, NULL, '2012-01-20 12:54:20.656201+00', 'Mrs Blair', 9999, '');
INSERT INTO 'tune' VALUES (13813, '2018-02-24 03:03:23.158466+00', '2018-02-24 03:03:23.158466+00', 'Angus Campbell''s Farewell to Stirling', 9998, '');
INSERT INTO 'tune' VALUES (3758, NULL, '2012-01-20 12:54:32.506323+00', 'Fete Champetre', 9998, '');
INSERT INTO 'tune' VALUES (119, NULL, '2012-01-20 12:54:20.611888+00', 'Glengarry March', 9999, '');
INSERT INTO 'tune' VALUES (135, NULL, '2012-01-20 12:54:20.65939+00', 'Bob Campbell', 1502, '');
INSERT INTO 'tune' VALUES (120, NULL, '2012-01-20 12:54:20.614808+00', 'Birkhall', 1654, '');
INSERT INTO 'tune' VALUES (3759, NULL, '2012-01-20 12:54:32.509244+00', 'Agnes Martin', 1679, '');
INSERT INTO 'tune' VALUES (121, NULL, '2012-01-20 12:54:20.617777+00', 'Birks of Invermay, The', 2271, '');
INSERT INTO 'tune' VALUES (136, NULL, '2012-01-20 12:54:20.662507+00', 'Bob McMath''s Reel', 1576, '');
INSERT INTO 'tune' VALUES (122, NULL, '2012-01-20 12:54:20.620721+00', 'Black Bear, The', 9999, '');
INSERT INTO 'tune' VALUES (3760, NULL, '2012-01-20 12:54:32.512139+00', 'Bert Gonnella''s Jig', 1615, '');
INSERT INTO 'tune' VALUES (123, NULL, '2012-01-20 12:54:20.623651+00', 'Black Boy, The', 9999, '');
INSERT INTO 'tune' VALUES (137, NULL, '2012-01-20 12:54:20.665456+00', 'Bob o'' Dowally, The', 9999, '');
INSERT INTO 'tune' VALUES (124, NULL, '2012-01-20 12:54:20.626568+00', 'Black Dance, The', 453, '');
INSERT INTO 'tune' VALUES (3761, NULL, '2012-01-20 12:54:32.515052+00', 'Fife Hunt', 1747, '');
INSERT INTO 'tune' VALUES (125, NULL, '2012-01-20 12:54:20.629513+00', 'Black Douglas, The', 696, '');
INSERT INTO 'tune' VALUES (138, NULL, '2012-01-20 12:54:20.668376+00', 'Bob of Fettercairn, The', 9999, '');
INSERT INTO 'tune' VALUES (126, NULL, '2012-01-20 12:54:20.632491+00', 'Bleu Ribbon, The', 9998, '');
INSERT INTO 'tune' VALUES (3762, NULL, '2012-01-20 12:54:32.518003+00', 'Trossachs Strathspey, The', 1461, '');
INSERT INTO 'tune' VALUES (127, NULL, '2012-01-20 12:54:20.635433+00', 'Blithe and Cheerie', 1607, '');
INSERT INTO 'tune' VALUES (139, NULL, '2012-01-20 12:54:20.671314+00', 'Bob''s Fancy', 1836, '');
INSERT INTO 'tune' VALUES (3763, NULL, '2012-01-20 12:54:32.521111+00', 'Fiery Cross, The', 1607, '');
INSERT INTO 'tune' VALUES (63, NULL, '2019-06-23 09:14:37.394048+00', 'Atholl and Breadalbane Gathering, The', 1434, '');
INSERT INTO 'tune' VALUES (98, NULL, '2014-08-19 07:19:04.19909+00', 'Barnyards of Delgaty, The', 9999, '');
INSERT INTO 'tune' VALUES (109, NULL, '2014-08-25 11:12:39.134022+00', 'Belladrum House', 9999, '');
INSERT INTO 'tune' VALUES (91, NULL, '2014-11-01 00:44:25.526771+00', 'Banks of Clyde, The', 9999, '');
INSERT INTO 'tune' VALUES (3764, NULL, '2012-01-20 12:54:32.524548+00', 'Aberdeen Town Council, The', 1607, '');
INSERT INTO 'tune' VALUES (144, NULL, '2012-01-20 12:54:20.686833+00', 'Bon Accord', 1454, '');
INSERT INTO 'tune' VALUES (145, NULL, '2012-01-20 12:54:20.689745+00', 'Bonnets o'' Blue', 9999, '');
INSERT INTO 'tune' VALUES (3765, NULL, '2012-01-20 12:54:32.52774+00', 'Rebel War Song, The', 9999, '');
INSERT INTO 'tune' VALUES (112, NULL, '2015-06-19 11:51:59.60989+00', 'Bessie''s Haggies', 1921, '');
INSERT INTO 'tune' VALUES (142, NULL, '2017-07-07 12:56:52.931069+00', 'Bog a''nuadh', 9999, '');
INSERT INTO 'tune' VALUES (146, NULL, '2012-01-20 12:54:20.692667+00', 'Bonnie Banchory', 1512, '');
INSERT INTO 'tune' VALUES (147, NULL, '2012-01-20 12:54:20.695585+00', 'Jefferson and Liberty', 9998, '');
INSERT INTO 'tune' VALUES (149, NULL, '2012-01-20 12:54:20.701522+00', 'Bingley Five Rise Locks, The', 1506, '');
INSERT INTO 'tune' VALUES (151, NULL, '2012-01-20 12:54:20.707429+00', 'Bonnie Cherlie''s noo awa''', 9998, '');
INSERT INTO 'tune' VALUES (152, NULL, '2012-01-20 12:54:20.710343+00', 'Bonnie Dundee', 9999, '');
INSERT INTO 'tune' VALUES (92, NULL, '2023-02-26 22:34:58.808838+00', 'Banks of Loch Ness, The', 9998, '');
INSERT INTO 'tune' VALUES (3767, NULL, '2012-01-20 12:54:32.53384+00', 'Finnan Haddies', 1424, '');
INSERT INTO 'tune' VALUES (153, NULL, '2012-01-20 12:54:20.713265+00', 'Road to Muchty, The', 1558, '');
INSERT INTO 'tune' VALUES (154, NULL, '2012-01-20 12:54:20.716194+00', 'Bonnie Flowers O''er the Muir', 9998, '');
INSERT INTO 'tune' VALUES (155, NULL, '2012-01-20 12:54:20.719119+00', 'Bonnie Kate', 2145, '');
INSERT INTO 'tune' VALUES (3768, NULL, '2012-01-20 12:54:32.536752+00', 'Fiona''s Wedding', 9998, '');
INSERT INTO 'tune' VALUES (156, NULL, '2012-01-20 12:54:20.722035+00', 'Bonnie Lass o'' Bon Accord, The', 1512, '');
INSERT INTO 'tune' VALUES (157, NULL, '2012-01-20 12:54:20.724958+00', 'Mr Murray', 9999, '');
INSERT INTO 'tune' VALUES (158, NULL, '2012-01-20 12:54:20.728065+00', 'Bonnie Links, The', 9998, '');
INSERT INTO 'tune' VALUES (3769, NULL, '2012-01-20 12:54:32.539659+00', 'Firecross Song, The', 9998, '');
INSERT INTO 'tune' VALUES (159, NULL, '2012-01-20 12:54:20.730983+00', 'Bonnie Lossie', 1512, '');
INSERT INTO 'tune' VALUES (3770, NULL, '2012-01-20 12:54:32.542676+00', 'Firehose Reel, The', 1817, '');
INSERT INTO 'tune' VALUES (3771, NULL, '2012-01-20 12:54:32.545939+00', 'Firth Jig, The', 9998, '');
INSERT INTO 'tune' VALUES (3772, NULL, '2012-01-20 12:54:32.548998+00', 'Ships are Sailing, The', 9999, '');
INSERT INTO 'tune' VALUES (3773, NULL, '2012-01-20 12:54:32.55198+00', 'Five Row Reel, The', 1643, '');
INSERT INTO 'tune' VALUES (3774, NULL, '2012-01-20 12:54:32.554892+00', 'Heather Donald of Saint Andrews', 559, '');
INSERT INTO 'tune' VALUES (3775, NULL, '2012-01-20 12:54:32.557939+00', 'Duncan Donald''s Strathspey', 559, '');
INSERT INTO 'tune' VALUES (3776, NULL, '2012-01-20 12:54:32.560862+00', 'Fleece, The', 9998, '');
INSERT INTO 'tune' VALUES (3777, NULL, '2012-01-20 12:54:32.563845+00', 'Mrs Phillip''s Jig', 1537, '');
INSERT INTO 'tune' VALUES (12003, '2012-02-06 11:14:22.956446+00', '2012-02-06 11:14:22.956456+00', 'Sarah', 1606, '');
INSERT INTO 'tune' VALUES (12086, '2012-05-31 07:25:56.60777+00', '2012-05-31 07:25:56.60778+00', 'Smiles Galore', 3683, '');
INSERT INTO 'tune' VALUES (12046, '2012-05-04 18:53:01.111876+00', '2012-06-04 23:57:16.279585+00', 'Jim Scott, Petty Officer First Class', 1502, '');
INSERT INTO 'tune' VALUES (12163, '2012-06-12 22:25:10.82378+00', '2012-06-12 22:25:10.823793+00', 'Scots Came O''er the Border, The', 9999, '');
INSERT INTO 'tune' VALUES (12170, '2012-06-13 08:26:44.030935+00', '2012-06-13 08:26:44.030946+00', 'Venskaben', 1502, '');
INSERT INTO 'tune' VALUES (12181, '2012-06-17 14:28:22.926593+00', '2012-06-17 14:28:22.926605+00', 'Celtic Thunder', 10636, '');
INSERT INTO 'tune' VALUES (12197, '2012-07-22 13:57:04.116768+00', '2012-07-22 13:57:04.116778+00', 'Rumgally', 1465, '');
INSERT INTO 'tune' VALUES (12207, '2012-10-18 12:39:38.529473+00', '2012-10-18 12:39:38.529484+00', 'Ballater', 9999, '');
INSERT INTO 'tune' VALUES (12210, '2012-10-18 13:11:20.136357+00', '2012-10-18 13:11:20.136368+00', 'Pit Hame da Borrowed Claes', 9999, '');
INSERT INTO 'tune' VALUES (12214, '2012-10-18 14:00:45.657297+00', '2012-10-18 14:00:45.657309+00', 'Billy Barlow', 9999, '');
INSERT INTO 'tune' VALUES (12215, '2012-10-18 14:18:19.474554+00', '2012-10-18 14:18:19.474564+00', 'Jacqui Watson''s Strathspey', 1596, '');
INSERT INTO 'tune' VALUES (12219, '2012-10-18 14:46:54.53182+00', '2012-10-18 14:46:54.531831+00', 'Carlisle Races', 9999, '');
INSERT INTO 'tune' VALUES (12222, '2012-10-18 15:16:31.159975+00', '2012-10-18 15:16:31.159985+00', 'Andrew''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (12227, '2012-10-21 12:15:47.579931+00', '2012-10-21 12:49:14.126411+00', 'Giradet House', 316, 'Written on a paper napkin in the Irish pub in Giradet House.  Giradet House is a disused printing works in Essen, Germany, which has now been turned into a shopping centre.  As well as boutiques and an old people''s home, there is an Irish pub where the EMO dancers go after their training sessions.  



');
INSERT INTO 'tune' VALUES (12228, '2012-10-23 22:44:25.326704+00', '2012-10-23 22:44:25.326714+00', 'Bloom is on the Rye, The', 9999, '');
INSERT INTO 'tune' VALUES (180, NULL, '2012-01-20 12:54:20.792958+00', 'Braes of Busby, The', 1462, '');
INSERT INTO 'tune' VALUES (160, NULL, '2012-01-20 12:54:20.733899+00', 'Bonnie Stronshiray', 1607, '');
INSERT INTO 'tune' VALUES (3778, NULL, '2012-01-20 12:54:32.566757+00', 'Angus McAulay of Newbury', 1590, '');
INSERT INTO 'tune' VALUES (161, NULL, '2012-01-20 12:54:20.736824+00', 'Bonnie lass that widna marry me, The', 1883, '');
INSERT INTO 'tune' VALUES (162, NULL, '2012-01-20 12:54:20.739752+00', 'Bonnie wee Jeannie McColl', 2229, '');
INSERT INTO 'tune' VALUES (3779, NULL, '2012-01-20 12:54:32.569656+00', 'Sister Elder''s Reel', 1558, '');
INSERT INTO 'tune' VALUES (163, NULL, '2012-01-20 12:54:20.742667+00', 'Bonny Annie', 9998, '');
INSERT INTO 'tune' VALUES (182, NULL, '2012-01-20 12:54:20.798839+00', 'Braes of Mar, The', 2624, '');
INSERT INTO 'tune' VALUES (164, NULL, '2012-01-20 12:54:20.745582+00', 'Bonny Bridge', 1512, '');
INSERT INTO 'tune' VALUES (3780, NULL, '2012-01-20 12:54:32.572571+00', 'Jock Tamson''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (165, NULL, '2012-01-20 12:54:20.748729+00', 'Cliff Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (166, NULL, '2012-01-20 12:54:20.751661+00', 'Bonnie Mally Lee', 9999, '');
INSERT INTO 'tune' VALUES (3781, NULL, '2012-01-20 12:54:32.57548+00', 'Stockholmslaaten', 9998, '');
INSERT INTO 'tune' VALUES (167, NULL, '2012-01-20 12:54:20.754592+00', 'Bookworm, The', 1828, '');
INSERT INTO 'tune' VALUES (184, NULL, '2012-01-20 12:54:20.804718+00', 'Old Woman Tossed in a Blanket, The', 9999, '');
INSERT INTO 'tune' VALUES (3782, NULL, '2012-01-20 12:54:32.578376+00', 'Flower of Auchattie, The', 1512, '');
INSERT INTO 'tune' VALUES (169, NULL, '2012-01-20 12:54:20.760431+00', 'Borowlaski''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (185, NULL, '2012-01-20 12:54:20.807657+00', 'Bramhall', 810, '');
INSERT INTO 'tune' VALUES (170, NULL, '2012-01-20 12:54:20.763351+00', 'Bothkennar', 9998, '');
INSERT INTO 'tune' VALUES (3783, NULL, '2012-01-20 12:54:32.581273+00', 'Flowers of Craigie', 3119, '');
INSERT INTO 'tune' VALUES (186, NULL, '2012-01-20 12:54:20.810575+00', 'Bratach Bana', 9999, '');
INSERT INTO 'tune' VALUES (172, NULL, '2012-01-20 12:54:20.769282+00', 'Bovaglie''s Plaid', 1512, '');
INSERT INTO 'tune' VALUES (3784, NULL, '2012-01-20 12:54:32.584283+00', 'Emily Gordon', 1473, '');
INSERT INTO 'tune' VALUES (173, NULL, '2012-01-20 12:54:20.772219+00', 'Bow-Legged Bosun, The', 1488, '');
INSERT INTO 'tune' VALUES (187, NULL, '2012-01-20 12:54:20.813477+00', 'Breadalbane Reel', 1558, '');
INSERT INTO 'tune' VALUES (174, NULL, '2012-01-20 12:54:20.775145+00', 'Knotted Piece of String, The', 1508, '');
INSERT INTO 'tune' VALUES (3785, NULL, '2012-01-20 12:54:32.58721+00', 'Florence Lesslie''s Farewell to Edinburgh', 1609, '');
INSERT INTO 'tune' VALUES (175, NULL, '2012-01-20 12:54:20.778059+00', 'Braes o'' Lochaber', 9998, '');
INSERT INTO 'tune' VALUES (176, NULL, '2012-01-20 12:54:20.780977+00', 'Braes of Atholl', 9999, '');
INSERT INTO 'tune' VALUES (3786, NULL, '2012-01-20 12:54:32.590102+00', 'Northumbrian Reel', 9998, '');
INSERT INTO 'tune' VALUES (177, NULL, '2012-01-20 12:54:20.783894+00', 'Braes of Auchtertyre, The', 2144, '');
INSERT INTO 'tune' VALUES (189, NULL, '2012-01-20 12:54:20.819351+00', 'Brian Borouhme', 9999, '');
INSERT INTO 'tune' VALUES (178, NULL, '2012-01-20 12:54:20.786809+00', 'Braes of Balquhidder, The', 9998, '');
INSERT INTO 'tune' VALUES (3787, NULL, '2012-01-20 12:54:32.593096+00', 'Bibonka''s Reel', 1745, '');
INSERT INTO 'tune' VALUES (179, NULL, '2012-01-20 12:54:20.789718+00', 'Braes of Breadalbane, The', 9999, '');
INSERT INTO 'tune' VALUES (190, NULL, '2012-01-20 12:54:20.822259+00', 'Bride, The', 9998, '');
INSERT INTO 'tune' VALUES (3788, NULL, '2012-01-20 12:54:32.596799+00', 'Forest Prince, The', 1607, '');
INSERT INTO 'tune' VALUES (192, NULL, '2012-01-20 12:54:20.8281+00', 'Brig o'' Aboyne', 1818, '');
INSERT INTO 'tune' VALUES (193, NULL, '2012-01-20 12:54:20.831014+00', 'Brig o'' Dee', 1466, '');
INSERT INTO 'tune' VALUES (194, NULL, '2012-01-20 12:54:20.833936+00', 'Brig of Perth', 1781, '');
INSERT INTO 'tune' VALUES (3789, NULL, '2012-01-20 12:54:32.599715+00', 'Forgan Bank', 1658, '');
INSERT INTO 'tune' VALUES (183, NULL, '2018-08-17 16:03:25.116265+00', 'Braes of Tulliemet, The', 9999, '');
INSERT INTO 'tune' VALUES (196, NULL, '2012-01-20 12:54:20.840042+00', 'Brisk Young Lad, The', 9999, '');
INSERT INTO 'tune' VALUES (197, NULL, '2012-01-20 12:54:20.842962+00', 'Britches Maker, The', 9999, '');
INSERT INTO 'tune' VALUES (3790, NULL, '2012-01-20 12:54:32.602671+00', 'For Lack of Silver', 1607, '');
INSERT INTO 'tune' VALUES (188, NULL, '2014-03-10 08:01:37.519343+00', 'Breakdown, The', 9999, '');
INSERT INTO 'tune' VALUES (143, NULL, '2014-08-11 15:14:33.207613+00', 'Bog of Gight, The', 1516, '');
INSERT INTO 'tune' VALUES (168, NULL, '2014-08-05 15:05:29.811233+00', 'Bore Stone, The', 1525, '');
INSERT INTO 'tune' VALUES (171, NULL, '2014-09-16 09:07:29.975397+00', 'Bottom of the Punch Bowl, The', 1859, '');
INSERT INTO 'tune' VALUES (141, NULL, '2014-11-08 23:55:11.619032+00', 'Bobby Harvey Strathspey, The', 1554, '');
INSERT INTO 'tune' VALUES (198, NULL, '2012-01-20 12:54:20.845872+00', 'British Grenadiers, The', 9999, '');
INSERT INTO 'tune' VALUES (199, NULL, '2012-01-20 12:54:20.848791+00', 'Broachan Laoimh', 9999, '');
INSERT INTO 'tune' VALUES (3791, NULL, '2012-01-20 12:54:32.605601+00', 'Forth Railway Bridge Centenary Reel, The', 1585, '');
INSERT INTO 'tune' VALUES (3792, NULL, '2012-01-20 12:54:32.608502+00', 'Four Counts, The', 9998, '');
INSERT INTO 'tune' VALUES (200, NULL, '2012-01-20 12:54:20.851707+00', 'Brolum, The', 1686, '');
INSERT INTO 'tune' VALUES (201, NULL, '2012-01-20 12:54:20.854644+00', 'Broomhill', 1640, '');
INSERT INTO 'tune' VALUES (3766, NULL, '2016-09-12 23:10:59.517485+00', 'Duncan MacDonald''s Fiddle', 1615, '');
INSERT INTO 'tune' VALUES (191, NULL, '2017-07-07 12:43:07.475518+00', 'Bridge of Ballater, The', 9998, '');
INSERT INTO 'tune' VALUES (181, NULL, '2017-07-07 13:42:59.083129+00', 'Braes of Elchies, The', 1807, '');
INSERT INTO 'tune' VALUES (202, NULL, '2012-01-20 12:54:20.857558+00', 'Broun''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (203, NULL, '2012-01-20 12:54:20.861007+00', 'Brown Trout, The', 1502, '');
INSERT INTO 'tune' VALUES (3793, NULL, '2012-01-20 12:54:32.611518+00', 'Fox Went Out One Starry Night, A', 9999, '');
INSERT INTO 'tune' VALUES (204, NULL, '2012-01-20 12:54:20.863936+00', 'Bruce and Margaret Urquhart', 1578, '');
INSERT INTO 'tune' VALUES (205, NULL, '2012-01-20 12:54:20.866857+00', 'Bruce, The', 1701, '');
INSERT INTO 'tune' VALUES (206, NULL, '2012-01-20 12:54:20.869758+00', 'Brumley Brae', 1541, '');
INSERT INTO 'tune' VALUES (3794, NULL, '2012-01-20 12:54:32.614424+00', 'Opening Chorus, The', 9999, '');
INSERT INTO 'tune' VALUES (207, NULL, '2012-01-20 12:54:20.873183+00', 'Buccleuch''s Favourite', 9998, '');
INSERT INTO 'tune' VALUES (208, NULL, '2012-01-20 12:54:20.876139+00', 'Buckingham House', 1512, '');
INSERT INTO 'tune' VALUES (209, NULL, '2012-01-20 12:54:20.879669+00', 'Bugle Horn, The', 9999, '');
INSERT INTO 'tune' VALUES (3795, NULL, '2012-01-20 12:54:32.617313+00', 'Foxhunter''s Jig, The', 9999, '');
INSERT INTO 'tune' VALUES (210, NULL, '2012-01-20 12:54:20.882716+00', 'Bumpkin, The', 9999, '');
INSERT INTO 'tune' VALUES (211, NULL, '2012-01-20 12:54:20.885662+00', 'Burnfoot House', 1502, '');
INSERT INTO 'tune' VALUES (3796, NULL, '2012-01-20 12:54:32.620342+00', 'From Aberdeen', 9998, '');
INSERT INTO 'tune' VALUES (3797, NULL, '2012-01-20 12:54:32.623384+00', 'Francis Sitwell''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (3798, NULL, '2012-01-20 12:54:32.626331+00', 'Dunlain Bridge', 1590, '');
INSERT INTO 'tune' VALUES (3799, NULL, '2012-01-20 12:54:32.62924+00', 'Freemason''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (3800, NULL, '2012-01-20 12:54:32.63213+00', 'French Ambassador, The', 9998, '');
INSERT INTO 'tune' VALUES (3801, NULL, '2012-01-20 12:54:32.635025+00', 'Alexander Hay', 1607, '');
INSERT INTO 'tune' VALUES (3803, NULL, '2012-01-20 12:54:32.640813+00', 'Miss Emilie Simpson', 1582, '');
INSERT INTO 'tune' VALUES (12004, '2012-02-06 11:21:35.485779+00', '2012-02-06 11:21:35.48579+00', 'Patricia''s Fancy', 2208, '');
INSERT INTO 'tune' VALUES (12027, '2012-02-07 10:27:38.107554+00', '2012-02-07 10:27:38.107565+00', 'John Crawford''s March', 1591, '');
INSERT INTO 'tune' VALUES (12087, '2012-05-31 07:27:35.577272+00', '2012-05-31 07:27:35.577283+00', 'Luke Brady''s Compliments to Bruce Frazer', 3683, '');
INSERT INTO 'tune' VALUES (12101, '2012-06-12 14:15:23.852877+00', '2012-06-12 14:15:23.852888+00', 'Berkhamsted Castle', 1576, '');
INSERT INTO 'tune' VALUES (12164, '2012-06-12 22:33:53.218592+00', '2012-06-12 22:33:53.218602+00', 'Susan''s Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (12171, '2012-06-13 08:32:45.129827+00', '2012-06-13 08:32:45.129838+00', 'Mr Purves, the Tailor', 1502, '');
INSERT INTO 'tune' VALUES (12182, '2012-06-17 14:36:00.457305+00', '2012-06-17 14:36:00.457316+00', 'King George IV', 9999, '');
INSERT INTO 'tune' VALUES (12208, '2012-10-18 12:41:53.832504+00', '2012-10-18 12:41:53.832515+00', 'Bridge o'' Calley', 9999, '');
INSERT INTO 'tune' VALUES (12211, '2012-10-18 13:14:06.50268+00', '2012-10-18 13:14:06.502691+00', 'Laurel''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (12220, '2012-10-18 14:49:03.320137+00', '2012-10-18 14:49:03.320148+00', 'Mist Over Tenessee', 9999, '');
INSERT INTO 'tune' VALUES (12223, '2012-10-18 15:20:33.038543+00', '2012-10-18 15:20:33.038554+00', 'Wilafiord', 9999, '');
INSERT INTO 'tune' VALUES (12229, '2012-10-23 22:51:07.983348+00', '2012-10-23 22:51:07.983359+00', 'Banks of Sicily, The', 10665, '');
INSERT INTO 'tune' VALUES (12234, '2012-12-18 08:34:29.442727+00', '2012-12-18 08:34:29.442738+00', 'Country Gallop, A', 10673, 'April 2012');
INSERT INTO 'tune' VALUES (12240, '2012-12-19 07:44:23.87977+00', '2012-12-19 18:29:42.114647+00', 'David Vandegrift - The Grand Marshall', 1502, '"Lmae (Linda Mae)" <lmae@imaginationprocessing.com> can send an MP3 wit this tune.');
INSERT INTO 'tune' VALUES (212, NULL, '2012-01-20 12:54:20.888587+00', 'Burnham Park', 9998, '');
INSERT INTO 'tune' VALUES (234, NULL, '2012-01-20 12:54:20.953697+00', 'Cameron''s Got his Wife Again', 9999, '');
INSERT INTO 'tune' VALUES (13814, '2018-02-24 03:04:23.449852+00', '2018-02-24 03:04:23.449852+00', 'Athole Cummers', 9998, '');
INSERT INTO 'tune' VALUES (3804, NULL, '2012-01-20 12:54:32.643833+00', 'Furth o'' Clyde', 1502, '');
INSERT INTO 'tune' VALUES (235, NULL, '2012-01-20 12:54:20.956644+00', 'Bonavista Hornpipe, The', 345, '');
INSERT INTO 'tune' VALUES (215, NULL, '2012-01-20 12:54:20.897424+00', 'Button Boy, The', 1502, '');
INSERT INTO 'tune' VALUES (216, NULL, '2012-01-20 12:54:20.900394+00', 'Byron Strathspey, The', 1533, '');
INSERT INTO 'tune' VALUES (3805, NULL, '2012-01-20 12:54:32.647781+00', 'Wooden Whale, The', 1782, '');
INSERT INTO 'tune' VALUES (236, NULL, '2012-01-20 12:54:20.959547+00', 'Campbell''s Frolic', 9999, '');
INSERT INTO 'tune' VALUES (217, NULL, '2012-01-20 12:54:20.903328+00', 'C J''s Reel', 1508, '');
INSERT INTO 'tune' VALUES (218, NULL, '2012-01-20 12:54:20.906248+00', 'Ca'' Hawkie through the Water', 9999, '');
INSERT INTO 'tune' VALUES (237, NULL, '2012-01-20 12:54:20.962476+00', 'Campbell''s Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (219, NULL, '2012-01-20 12:54:20.909175+00', 'Syd Chalmers', 1558, '');
INSERT INTO 'tune' VALUES (220, NULL, '2012-01-20 12:54:20.912085+00', 'Caddam Wood', 1598, '');
INSERT INTO 'tune' VALUES (3807, NULL, '2012-01-20 12:54:32.653658+00', 'Gainsborough', 9998, '');
INSERT INTO 'tune' VALUES (238, NULL, '2012-01-20 12:54:20.965402+00', 'Campbells are coming, The', 9999, '');
INSERT INTO 'tune' VALUES (221, NULL, '2012-01-20 12:54:20.915312+00', 'Cadger of Crief', 9998, '');
INSERT INTO 'tune' VALUES (222, NULL, '2012-01-20 12:54:20.918419+00', 'Cadger''s Ford, The', 1794, '');
INSERT INTO 'tune' VALUES (3808, NULL, '2012-01-20 12:54:32.656549+00', 'Abbotsford Gardens', 1502, '');
INSERT INTO 'tune' VALUES (223, NULL, '2012-01-20 12:54:20.921351+00', 'Cadgers in the Canongate', 9999, '');
INSERT INTO 'tune' VALUES (224, NULL, '2012-01-20 12:54:20.924337+00', 'Caerketton', 326, '');
INSERT INTO 'tune' VALUES (3809, NULL, '2012-01-20 12:54:32.65983+00', 'Prince Frederick''s Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (240, NULL, '2012-01-20 12:54:20.971242+00', 'Campden Jig, The', 1701, '');
INSERT INTO 'tune' VALUES (225, NULL, '2012-01-20 12:54:20.927304+00', 'Cairn Strathspey, The', 9998, '');
INSERT INTO 'tune' VALUES (226, NULL, '2012-01-20 12:54:20.930224+00', 'Cairney Mount', 9999, '');
INSERT INTO 'tune' VALUES (3810, NULL, '2012-01-20 12:54:32.6629+00', 'Gallaton', 1512, '');
INSERT INTO 'tune' VALUES (241, NULL, '2012-01-20 12:54:20.974145+00', 'Campsie Glen', 1557, '');
INSERT INTO 'tune' VALUES (227, NULL, '2012-01-20 12:54:20.933219+00', 'Caithness Reel, The', 9998, '');
INSERT INTO 'tune' VALUES (228, NULL, '2012-01-20 12:54:20.936148+00', 'Calabria', 9999, '');
INSERT INTO 'tune' VALUES (3811, NULL, '2012-01-20 12:54:32.665913+00', 'May MacDougall', 613, '');
INSERT INTO 'tune' VALUES (242, NULL, '2012-01-20 12:54:20.977063+00', 'Canty Auld Man, The', 9999, '');
INSERT INTO 'tune' VALUES (229, NULL, '2012-01-20 12:54:20.939058+00', 'Caldercruix', 9998, '');
INSERT INTO 'tune' VALUES (230, NULL, '2012-01-20 12:54:20.941968+00', 'Caledonian Society of London, The', 9999, '');
INSERT INTO 'tune' VALUES (3812, NULL, '2012-01-20 12:54:32.668828+00', 'Domhnull beag an t-siucar', 9998, '');
INSERT INTO 'tune' VALUES (243, NULL, '2012-01-20 12:54:20.980212+00', 'Canty Jeanie Munro', 1512, '');
INSERT INTO 'tune' VALUES (231, NULL, '2012-01-20 12:54:20.944892+00', 'Caller Herrin''', 1517, '');
INSERT INTO 'tune' VALUES (232, NULL, '2012-01-20 12:54:20.947816+00', 'Callum Beag', 9999, '');
INSERT INTO 'tune' VALUES (3813, NULL, '2012-01-20 12:54:32.671895+00', 'Galtee Rangers, The', 9999, '');
INSERT INTO 'tune' VALUES (244, NULL, '2012-01-20 12:54:20.983143+00', 'Captain Young''s Quickstep', 9998, '');
INSERT INTO 'tune' VALUES (233, NULL, '2012-01-20 12:54:20.950728+00', 'Calluna', 1594, '');
INSERT INTO 'tune' VALUES (245, NULL, '2012-01-20 12:54:20.986058+00', 'Robert Crawford', 1555, '');
INSERT INTO 'tune' VALUES (3814, NULL, '2012-01-20 12:54:32.674818+00', 'Lesley Ann Barr', 1831, '');
INSERT INTO 'tune' VALUES (246, NULL, '2012-01-20 12:54:20.988981+00', 'Captain Bain''s Tribute', 1547, '');
INSERT INTO 'tune' VALUES (247, NULL, '2012-01-20 12:54:20.9919+00', 'Captain Campbell (of Lochnell''s) Reel', 1519, '');
INSERT INTO 'tune' VALUES (248, NULL, '2012-01-20 12:54:20.99482+00', 'Captain Charles Stewart''s Jigg', 1486, '');
INSERT INTO 'tune' VALUES (3815, NULL, '2012-01-20 12:54:32.677715+00', 'Flipping the Pancake', 1445, '');
INSERT INTO 'tune' VALUES (249, NULL, '2012-01-20 12:54:20.997727+00', 'Captain Gillan''s Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (250, NULL, '2012-01-20 12:54:21.000952+00', 'Captain Lockhart', 9998, '');
INSERT INTO 'tune' VALUES (251, NULL, '2012-01-20 12:54:21.003867+00', 'Captain MacBean''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (3816, NULL, '2012-01-20 12:54:32.680611+00', 'Miss Barbara Manning of Bramfield', 1590, '');
INSERT INTO 'tune' VALUES (252, NULL, '2012-01-20 12:54:21.006787+00', 'Captain MacDuff', 9998, '');
INSERT INTO 'tune' VALUES (3817, NULL, '2012-01-20 12:54:32.68352+00', 'General Abercrombie''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (253, NULL, '2012-01-20 12:54:21.009719+00', 'Captain Macdonald''s Fancy', 9998, '');
INSERT INTO 'tune' VALUES (254, NULL, '2012-01-20 12:54:21.012668+00', 'Captain Pringle of Yair', 9998, '');
INSERT INTO 'tune' VALUES (255, NULL, '2012-01-20 12:54:21.01561+00', 'Captain Ross', 9998, '');
INSERT INTO 'tune' VALUES (3818, NULL, '2012-01-20 12:54:32.686484+00', 'Ann Lindsey', 1862, '');
INSERT INTO 'tune' VALUES (256, NULL, '2012-01-20 12:54:21.018521+00', 'Captain White', 9999, '');
INSERT INTO 'tune' VALUES (257, NULL, '2012-01-20 12:54:21.021435+00', 'Caribou, The', 1812, '');
INSERT INTO 'tune' VALUES (3806, NULL, '2013-11-26 17:09:03.834358+00', 'Leaving Lerwick Harbour', 1677, '');
INSERT INTO 'tune' VALUES (258, NULL, '2012-01-20 12:54:21.024433+00', 'Carolside Jig, The', 1475, '');
INSERT INTO 'tune' VALUES (3819, NULL, '2012-01-20 12:54:32.689402+00', 'John Lockhart', 1862, '');
INSERT INTO 'tune' VALUES (259, NULL, '2012-01-20 12:54:21.027371+00', 'Carse o'' Gowrie, The', 1525, '');
INSERT INTO 'tune' VALUES (260, NULL, '2012-01-20 12:54:21.030284+00', 'Casbah, The', 1407, '');
INSERT INTO 'tune' VALUES (261, NULL, '2012-01-20 12:54:21.033199+00', 'Cashmere Shawl, The', 1478, '');
INSERT INTO 'tune' VALUES (3820, NULL, '2012-01-20 12:54:32.692302+00', 'Cessnock Gardens', 1696, '');
INSERT INTO 'tune' VALUES (262, NULL, '2012-01-20 12:54:21.036114+00', 'Castle Grant', 9998, '');
INSERT INTO 'tune' VALUES (214, NULL, '2016-03-19 11:44:47.273126+00', 'Brian & Eleanor Rutherford', 353, '');
INSERT INTO 'tune' VALUES (263, NULL, '2012-01-20 12:54:21.039041+00', 'Castle Park Jig', 1702, '');
INSERT INTO 'tune' VALUES (264, NULL, '2012-01-20 12:54:21.041991+00', 'Castle Stuart', 9999, '');
INSERT INTO 'tune' VALUES (3821, NULL, '2012-01-20 12:54:32.69544+00', 'Pretty Maiden', 1537, '');
INSERT INTO 'tune' VALUES (3822, NULL, '2012-01-20 12:54:32.69838+00', 'George MacDonald''s Reel', 948, '');
INSERT INTO 'tune' VALUES (3823, NULL, '2012-01-20 12:54:32.70128+00', 'Duke of Atholl''s Jig, The', 1615, '');
INSERT INTO 'tune' VALUES (3824, NULL, '2012-01-20 12:54:32.704172+00', 'George Square of Edinburgh', 1864, '');
INSERT INTO 'tune' VALUES (3825, NULL, '2012-01-20 12:54:32.70718+00', 'Four Potatoes', 1765, '');
INSERT INTO 'tune' VALUES (3826, NULL, '2012-01-20 12:54:32.710081+00', 'Ghillie Laces', 1718, '');
INSERT INTO 'tune' VALUES (3827, NULL, '2012-01-20 12:54:32.712971+00', 'Girl with the Deep Brown Eyes, The', 1865, '');
INSERT INTO 'tune' VALUES (3828, NULL, '2012-01-20 12:54:32.715877+00', 'Robert Forsyth Crowe', 1502, '');
INSERT INTO 'tune' VALUES (12005, '2012-02-06 11:30:45.016277+00', '2012-02-06 11:30:45.016288+00', 'Morris Grant''s Button Box', 10601, '');
INSERT INTO 'tune' VALUES (12028, '2012-02-07 10:29:14.496349+00', '2012-02-07 10:29:14.496359+00', 'Jim and Finngerd''s Wedding', 1591, '');
INSERT INTO 'tune' VALUES (12088, '2012-05-31 07:29:34.55884+00', '2012-05-31 07:29:34.558851+00', 'Val Frazer: Good for the Soul', 3683, '');
INSERT INTO 'tune' VALUES (12172, '2012-06-13 08:37:29.631637+00', '2012-06-13 08:37:29.631647+00', 'Sharper''s Point', 1502, '');
INSERT INTO 'tune' VALUES (12183, '2012-06-17 14:41:43.50671+00', '2012-06-17 14:41:43.506721+00', 'Waltz for Atsuko and Bill', 2395, '');
INSERT INTO 'tune' VALUES (12209, '2012-10-18 12:54:23.909147+00', '2012-10-18 12:54:23.909158+00', 'Jim & Jane Ruxton of Aberdeen', 10664, '');
INSERT INTO 'tune' VALUES (12212, '2012-10-18 13:18:05.481052+00', '2012-10-18 13:18:05.481063+00', 'Ben Hill', 9999, '');
INSERT INTO 'tune' VALUES (12218, '2012-10-18 14:37:41.167959+00', '2012-10-18 14:37:41.16797+00', 'Miss Watt of Nether Cluny', 9999, '');
INSERT INTO 'tune' VALUES (12221, '2012-10-18 15:01:50.320908+00', '2012-10-18 15:01:50.320919+00', 'Miss Grant of Tombreakachy', 9999, '');
INSERT INTO 'tune' VALUES (12224, '2012-10-18 15:22:59.989499+00', '2012-10-18 15:22:59.98951+00', 'Da Underhill', 9999, '');
INSERT INTO 'tune' VALUES (13815, '2018-02-24 03:05:44.846941+00', '2018-02-24 03:05:44.846941+00', 'Blair Drummond', 9998, '');
INSERT INTO 'tune' VALUES (12233, '2012-12-18 08:33:30.3999+00', '2012-12-18 08:35:11.416431+00', 'Carriage to Schiehallion', 10669, 'composed February 2012');
INSERT INTO 'tune' VALUES (12241, '2012-12-27 11:02:29.623989+00', '2012-12-27 11:02:29.624+00', 'Rob Fraser''s Welcome to San Francisco', 2294, '');
INSERT INTO 'tune' VALUES (12242, '2012-12-27 11:12:34.243945+00', '2012-12-27 11:12:34.243955+00', 'Dinky Dorrian''s', 2940, '');
INSERT INTO 'tune' VALUES (12243, '2012-12-27 11:58:20.504236+00', '2012-12-27 11:58:20.504247+00', 'Galen''s Arrival', 2294, '');
INSERT INTO 'tune' VALUES (12244, '2012-12-27 12:31:13.669691+00', '2012-12-27 12:31:13.669702+00', 'Reavey''s No. 9', 9999, '');
INSERT INTO 'tune' VALUES (12247, '2012-12-27 13:12:13.913034+00', '2012-12-27 13:12:13.913045+00', 'Gha Mi Sgith', 9999, '');
INSERT INTO 'tune' VALUES (12248, '2012-12-27 13:24:47.413112+00', '2012-12-27 13:24:47.413124+00', 'Niel Gow''s Lamentation for James Moray of Abercairny', 1518, '');
INSERT INTO 'tune' VALUES (265, NULL, '2012-01-20 12:54:21.045158+00', 'Castle Wynd', 1402, '');
INSERT INTO 'tune' VALUES (286, NULL, '2012-01-20 12:54:21.110413+00', 'Stan & Nancy Peacock''s Strathspey', 1555, '');
INSERT INTO 'tune' VALUES (3829, NULL, '2012-01-20 12:54:32.719111+00', 'Girl in a Blue Dream, The', 9998, '');
INSERT INTO 'tune' VALUES (266, NULL, '2012-01-20 12:54:21.048099+00', 'Castlecraigs', 1502, '');
INSERT INTO 'tune' VALUES (267, NULL, '2012-01-20 12:54:21.051064+00', 'Castles in the Air', 9999, '');
INSERT INTO 'tune' VALUES (287, NULL, '2012-01-20 12:54:21.113342+00', 'Clarence House', 1588, '');
INSERT INTO 'tune' VALUES (3830, NULL, '2012-01-20 12:54:32.722227+00', 'Elizabeth', 1437, '');
INSERT INTO 'tune' VALUES (268, NULL, '2012-01-20 12:54:21.054046+00', 'Cathie''s Reel', 1607, '');
INSERT INTO 'tune' VALUES (288, NULL, '2012-01-20 12:54:21.116531+00', 'Claymore Strathspey', 1646, '');
INSERT INTO 'tune' VALUES (3831, NULL, '2012-01-20 12:54:32.72515+00', 'Annie M. Davidson''s Jig', 1866, '');
INSERT INTO 'tune' VALUES (270, NULL, '2012-01-20 12:54:21.059939+00', 'Cease Not to Row, Brave Boys', 9998, '');
INSERT INTO 'tune' VALUES (271, NULL, '2012-01-20 12:54:21.062868+00', 'Ceilidh Umbrella, The', 1502, '');
INSERT INTO 'tune' VALUES (289, NULL, '2012-01-20 12:54:21.119492+00', 'Clean Pease Strae', 9999, '');
INSERT INTO 'tune' VALUES (3832, NULL, '2012-01-20 12:54:32.728154+00', 'Lady Binning', 9999, '');
INSERT INTO 'tune' VALUES (272, NULL, '2012-01-20 12:54:21.065782+00', 'Ceres Green', 9999, '');
INSERT INTO 'tune' VALUES (273, NULL, '2012-01-20 12:54:21.068879+00', 'Chantreuse, The', 9999, '');
INSERT INTO 'tune' VALUES (290, NULL, '2012-01-20 12:54:21.122403+00', 'Clydeside Lassies', 9999, '');
INSERT INTO 'tune' VALUES (3833, NULL, '2012-01-20 12:54:32.731221+00', 'Glasgow Jubilee', 9998, '');
INSERT INTO 'tune' VALUES (274, NULL, '2012-01-20 12:54:21.071803+00', 'Charles Leslie of Findassie''s Strathspey', 1470, '');
INSERT INTO 'tune' VALUES (275, NULL, '2012-01-20 12:54:21.074712+00', 'Charlie is my Darling', 2704, '');
INSERT INTO 'tune' VALUES (291, NULL, '2012-01-20 12:54:21.12532+00', 'Banks of Newfoundland, The', 1509, '');
INSERT INTO 'tune' VALUES (3834, NULL, '2012-01-20 12:54:32.734484+00', 'Doris Robertson', 1607, '');
INSERT INTO 'tune' VALUES (276, NULL, '2012-01-20 12:54:21.077629+00', 'Charlotte Square', 1502, '');
INSERT INTO 'tune' VALUES (277, NULL, '2012-01-20 12:54:21.080624+00', 'Chase, The', 9999, '');
INSERT INTO 'tune' VALUES (292, NULL, '2012-01-20 12:54:21.128235+00', 'Cobbler, The', 9999, '');
INSERT INTO 'tune' VALUES (3835, NULL, '2012-01-20 12:54:32.73739+00', 'Glen Affric', 1868, '');
INSERT INTO 'tune' VALUES (278, NULL, '2012-01-20 12:54:21.084131+00', 'Cherish the Ladies', 2287, '');
INSERT INTO 'tune' VALUES (279, NULL, '2012-01-20 12:54:21.087226+00', 'Hussars'' Quadrille', 9999, '');
INSERT INTO 'tune' VALUES (293, NULL, '2012-01-20 12:54:21.131144+00', 'Cobblers, The', 9998, '');
INSERT INTO 'tune' VALUES (3836, NULL, '2012-01-20 12:54:32.740284+00', 'Hugh Foss''s Strathspey', 1437, '');
INSERT INTO 'tune' VALUES (280, NULL, '2012-01-20 12:54:21.090151+00', 'Chris Worrall', 1508, '');
INSERT INTO 'tune' VALUES (281, NULL, '2012-01-20 12:54:21.095468+00', 'Christian Catto', 1520, '');
INSERT INTO 'tune' VALUES (294, NULL, '2012-01-20 12:54:21.134048+00', 'Cock a Bendie', 9999, '');
INSERT INTO 'tune' VALUES (3837, NULL, '2012-01-20 12:54:32.743711+00', 'Glendarroch Gathering', 9998, '');
INSERT INTO 'tune' VALUES (282, NULL, '2012-01-20 12:54:21.098417+00', 'Christine McWilliam', 1586, '');
INSERT INTO 'tune' VALUES (283, NULL, '2012-01-20 12:54:21.101465+00', 'Circassian Circle', 9999, '');
INSERT INTO 'tune' VALUES (295, NULL, '2012-01-20 12:54:21.136998+00', 'Cock o'' the North, The', 9999, '');
INSERT INTO 'tune' VALUES (3838, NULL, '2012-01-20 12:54:32.746786+00', 'Simon Scott', 1457, '');
INSERT INTO 'tune' VALUES (296, NULL, '2012-01-20 12:54:21.140076+00', 'Dandy Denny Cronin', 2150, '');
INSERT INTO 'tune' VALUES (3839, NULL, '2012-01-20 12:54:32.749711+00', 'I Will Not Go to my Bed Till I Should Die', 9998, '');
INSERT INTO 'tune' VALUES (297, NULL, '2012-01-20 12:54:21.142992+00', 'Cockle Gatherers, The', 9999, '');
INSERT INTO 'tune' VALUES (298, NULL, '2012-01-20 12:54:21.145894+00', 'Bag of Praties', 9999, '');
INSERT INTO 'tune' VALUES (3840, NULL, '2012-01-20 12:54:32.752607+00', 'Glenkiln Jig, The', 1668, '');
INSERT INTO 'tune' VALUES (299, NULL, '2012-01-20 12:54:21.148803+00', 'Colonel Ridley''s Quickstep', 1401, '');
INSERT INTO 'tune' VALUES (300, NULL, '2012-01-20 12:54:21.151709+00', 'Cold and Raw', 9999, '');
INSERT INTO 'tune' VALUES (301, NULL, '2012-01-20 12:54:21.154611+00', 'Pig Town Fling, The', 9999, '');
INSERT INTO 'tune' VALUES (3841, NULL, '2012-01-20 12:54:32.755506+00', 'Glenmazeran', 9998, '');
INSERT INTO 'tune' VALUES (302, NULL, '2012-01-20 12:54:21.157651+00', 'Coldside Jig', 1554, '');
INSERT INTO 'tune' VALUES (3842, NULL, '2012-01-20 12:54:32.758404+00', 'Glenmoor, The', 1502, '');
INSERT INTO 'tune' VALUES (303, NULL, '2012-01-20 12:54:21.162419+00', 'Colonel Alex. Grant''s Strathspey', 1470, '');
INSERT INTO 'tune' VALUES (304, NULL, '2012-01-20 12:54:21.165801+00', 'Colonel Baird', 2427, '');
INSERT INTO 'tune' VALUES (3843, NULL, '2012-01-20 12:54:32.761298+00', 'Lord Ramsay', 1448, '');
INSERT INTO 'tune' VALUES (306, NULL, '2012-01-20 12:54:21.171655+00', 'Colonel H.F. Campbell''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (307, NULL, '2012-01-20 12:54:21.174562+00', 'Colonel L. Stewart''s Reel', 1516, '');
INSERT INTO 'tune' VALUES (308, NULL, '2012-01-20 12:54:21.178015+00', 'Colonel MacBean', 9998, '');
INSERT INTO 'tune' VALUES (3844, NULL, '2012-01-20 12:54:32.764217+00', 'Marie-Anne', 1203, '');
INSERT INTO 'tune' VALUES (309, NULL, '2012-01-20 12:54:21.180934+00', 'Coltbridge', 1542, '');
INSERT INTO 'tune' VALUES (310, NULL, '2012-01-20 12:54:21.183848+00', 'Come Ashore Jolly Tar', 9999, '');
INSERT INTO 'tune' VALUES (311, NULL, '2012-01-20 12:54:21.186748+00', 'Professor Blackie', 1512, '');
INSERT INTO 'tune' VALUES (3845, NULL, '2012-01-20 12:54:32.767178+00', 'Click Go the Shears, Boys', 9999, '');
INSERT INTO 'tune' VALUES (13816, '2018-02-24 03:06:54.757807+00', '2018-02-24 03:06:54.757807+00', 'Bridge of Perth', 9998, '');
INSERT INTO 'tune' VALUES (313, NULL, '2012-01-20 12:54:21.192562+00', 'Come o''er the stream, Charlie', 9999, '');
INSERT INTO 'tune' VALUES (314, NULL, '2012-01-20 12:54:21.195477+00', 'Comely Bank', 1813, '');
INSERT INTO 'tune' VALUES (3846, NULL, '2012-01-20 12:54:32.770081+00', 'Golden Harvest', 1554, '');
INSERT INTO 'tune' VALUES (315, NULL, '2012-01-20 12:54:21.198375+00', 'Coniston Capers', 1577, '');
INSERT INTO 'tune' VALUES (316, NULL, '2012-01-20 12:54:21.201847+00', 'Conundrum, The', 2138, '');
INSERT INTO 'tune' VALUES (3848, NULL, '2012-01-20 12:54:32.775869+00', 'Mrs Scott Skinner', 1512, '');
INSERT INTO 'tune' VALUES (3849, NULL, '2012-01-20 12:54:32.779571+00', 'Jimmy Noble''s Reel', 1796, '');
INSERT INTO 'tune' VALUES (3850, NULL, '2012-01-20 12:54:32.782554+00', 'Good Humour', 9999, '');
INSERT INTO 'tune' VALUES (3851, NULL, '2012-01-20 12:54:32.78545+00', 'I Winna Gang tae Bed', 1512, '');
INSERT INTO 'tune' VALUES (3852, NULL, '2012-01-20 12:54:32.788983+00', 'Glentana', 1512, '');
INSERT INTO 'tune' VALUES (12165, '2012-06-12 22:42:10.058988+00', '2017-11-26 14:21:04.316967+00', 'Doreen & Roy Goldring''s Jig', 1501, '');
INSERT INTO 'tune' VALUES (3853, NULL, '2012-01-20 12:54:32.791902+00', 'Directors, The', 1505, '');
INSERT INTO 'tune' VALUES (3854, NULL, '2012-01-20 12:54:32.794813+00', 'Kanikani', 1872, '');
INSERT INTO 'tune' VALUES (3855, NULL, '2012-01-20 12:54:32.797805+00', 'Miss Margaret Church', 1502, '');
INSERT INTO 'tune' VALUES (12006, '2012-02-06 11:35:19.848625+00', '2012-02-06 11:35:19.848635+00', 'Big Tam Jamieson', 1811, '');
INSERT INTO 'tune' VALUES (12029, '2012-02-07 10:30:36.027327+00', '2012-02-07 10:30:36.027338+00', 'Veda Jane', 1591, '');
INSERT INTO 'tune' VALUES (12049, '2012-05-04 18:55:46.686142+00', '2012-05-04 18:55:46.686153+00', 'Muriel Johnstone''s Compliments to Ruth Jappy', 1502, '');
INSERT INTO 'tune' VALUES (12089, '2012-05-31 07:49:40.400808+00', '2012-05-31 07:49:40.400819+00', 'Dick Webster''s Farewell to Middleton', 1777, '');
INSERT INTO 'tune' VALUES (12103, '2012-06-12 14:17:21.950645+00', '2012-06-12 14:17:21.950656+00', 'Max Houliston''s Compliments to Bobby MacLeod', 1606, '');
INSERT INTO 'tune' VALUES (12166, '2012-06-12 22:44:24.489266+00', '2012-06-12 22:44:24.489277+00', 'Hill o'' Fare, The', 1506, '');
INSERT INTO 'tune' VALUES (3847, NULL, '2020-01-15 17:10:21.254188+00', 'Mountain Gold', 1631, '');
INSERT INTO 'tune' VALUES (12173, '2012-06-13 08:40:15.585453+00', '2012-06-13 08:40:15.585464+00', 'Noble''s', 9999, '');
INSERT INTO 'tune' VALUES (12184, '2012-06-17 14:47:29.909338+00', '2012-06-17 14:47:29.909349+00', 'Hamish the Carpenter', 9999, '');
INSERT INTO 'tune' VALUES (12206, '2012-10-02 09:53:43.437196+00', '2012-10-02 09:53:43.437206+00', 'Johnnie Steele', 10662, '');
INSERT INTO 'tune' VALUES (12213, '2012-10-18 13:18:45.466081+00', '2012-10-18 13:18:45.466092+00', 'Lakeland', 9999, '');
INSERT INTO 'tune' VALUES (12225, '2012-10-18 15:24:10.563395+00', '2012-10-18 15:24:10.563406+00', 'Yank''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (12232, '2012-11-07 10:53:01.569907+00', '2012-11-07 10:53:01.569918+00', 'Maguy Paillet', 2197, '');
INSERT INTO 'tune' VALUES (12235, '2012-12-18 08:35:59.247574+00', '2012-12-18 08:35:59.247585+00', 'Crewkerne 2012', 10673, 'composed April 2012');
INSERT INTO 'tune' VALUES (269, NULL, '2022-07-27 17:34:01.821382+00', 'Cauld Kail in Aberdeen', 9999, '');
INSERT INTO 'tune' VALUES (12245, '2012-12-27 12:32:21.891073+00', '2012-12-27 12:32:21.891084+00', 'Dooley''s', 9999, '');
INSERT INTO 'tune' VALUES (12249, '2012-12-27 20:32:34.386958+00', '2012-12-27 20:32:34.386969+00', 'Niel Gow''s Lament for the Death of his Second Wife', 1518, '');
INSERT INTO 'tune' VALUES (317, NULL, '2012-01-20 12:54:21.204758+00', 'Cork Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (337, NULL, '2012-01-20 12:54:21.269996+00', 'Craighall', 2054, '');
INSERT INTO 'tune' VALUES (3856, NULL, '2012-01-20 12:54:32.800721+00', 'Graelynda Strathspey, The', 1873, '');
INSERT INTO 'tune' VALUES (318, NULL, '2012-01-20 12:54:21.207672+00', 'Corn Rigs', 9999, '');
INSERT INTO 'tune' VALUES (319, NULL, '2012-01-20 12:54:21.210572+00', 'Fair Quaker of Deal', 9998, '');
INSERT INTO 'tune' VALUES (338, NULL, '2012-01-20 12:54:21.27297+00', 'Craigieburn Wood', 9999, '');
INSERT INTO 'tune' VALUES (3857, NULL, '2012-01-20 12:54:32.803643+00', 'Graham Warren Hamilton', 1653, '');
INSERT INTO 'tune' VALUES (320, NULL, '2012-01-20 12:54:21.213475+00', 'Corner House Jig, The', 1533, '');
INSERT INTO 'tune' VALUES (321, NULL, '2012-01-20 12:54:21.216383+00', 'Cornet''s Lass, The', 9998, '');
INSERT INTO 'tune' VALUES (339, NULL, '2012-01-20 12:54:21.27588+00', 'Craigside Royal', 9998, '');
INSERT INTO 'tune' VALUES (3858, NULL, '2012-01-20 12:54:32.806538+00', 'Katherine''s Welcome', 1502, '');
INSERT INTO 'tune' VALUES (322, NULL, '2012-01-20 12:54:21.219359+00', 'Corstorphine Fair', 1607, '');
INSERT INTO 'tune' VALUES (323, NULL, '2012-01-20 12:54:21.222638+00', 'Coulter''s Candy', 9998, '');
INSERT INTO 'tune' VALUES (340, NULL, '2012-01-20 12:54:21.278783+00', 'Creag Mhor', 1502, '');
INSERT INTO 'tune' VALUES (3859, NULL, '2012-01-20 12:54:32.810452+00', 'Five Barred Gate, The', 9999, '');
INSERT INTO 'tune' VALUES (324, NULL, '2012-01-20 12:54:21.226767+00', 'Countess of Cassilis Strathspey, The', 9999, '');
INSERT INTO 'tune' VALUES (341, NULL, '2012-01-20 12:54:21.281684+00', 'Crieff Fair', 9999, '');
INSERT INTO 'tune' VALUES (3860, NULL, '2012-01-20 12:54:32.813392+00', 'Warrior''s Return, The', 1512, '');
INSERT INTO 'tune' VALUES (326, NULL, '2012-01-20 12:54:21.234507+00', 'Countess of Loudoun''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (327, NULL, '2012-01-20 12:54:21.238337+00', 'Countess of Sutherland''s Reel, The', 1495, '');
INSERT INTO 'tune' VALUES (342, NULL, '2012-01-20 12:54:21.284602+00', 'Cromartie''s Rant', 9999, '');
INSERT INTO 'tune' VALUES (3861, NULL, '2012-01-20 12:54:32.816305+00', 'Wicker Man, The', 2392, '');
INSERT INTO 'tune' VALUES (328, NULL, '2012-01-20 12:54:21.242166+00', 'Country Dance', 1518, '');
INSERT INTO 'tune' VALUES (329, NULL, '2012-01-20 12:54:21.245982+00', 'Country Lasses', 9999, '');
INSERT INTO 'tune' VALUES (343, NULL, '2012-01-20 12:54:21.287516+00', 'Cromdel Hill', 9998, '');
INSERT INTO 'tune' VALUES (3862, NULL, '2012-01-20 12:54:32.819207+00', 'Green Jerseys, The', 9998, '');
INSERT INTO 'tune' VALUES (331, NULL, '2012-01-20 12:54:21.252447+00', 'Cousin Jim', 1554, '');
INSERT INTO 'tune' VALUES (344, NULL, '2012-01-20 12:54:21.290422+00', 'Crooket Horned Ewie, The', 1518, '');
INSERT INTO 'tune' VALUES (3863, NULL, '2012-01-20 12:54:32.822095+00', 'Green Oak Tree, The', 9999, '');
INSERT INTO 'tune' VALUES (332, NULL, '2012-01-20 12:54:21.255377+00', 'Coutt''s Concert Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (333, NULL, '2012-01-20 12:54:21.258277+00', 'Cradle Song, The', 1512, '');
INSERT INTO 'tune' VALUES (345, NULL, '2012-01-20 12:54:21.293362+00', 'Crookit Bawbee, The', 9998, '');
INSERT INTO 'tune' VALUES (3864, NULL, '2012-01-20 12:54:32.824988+00', 'Green Sleeves', 9998, '');
INSERT INTO 'tune' VALUES (334, NULL, '2012-01-20 12:54:21.261225+00', 'Craigdarroch''s Whistle', 1822, '');
INSERT INTO 'tune' VALUES (335, NULL, '2012-01-20 12:54:21.264139+00', 'Craigellachie', 1701, '');
INSERT INTO 'tune' VALUES (12277, '2012-12-28 16:25:22.888132+00', '2012-12-28 16:25:22.888144+00', 'Miss Helen Goodfellow', 10082, '');
INSERT INTO 'tune' VALUES (3865, NULL, '2012-01-20 12:54:32.828751+00', 'Greenwich Hill', 1518, '');
INSERT INTO 'tune' VALUES (336, NULL, '2012-01-20 12:54:21.267087+00', 'Craigendoran', 9999, '');
INSERT INTO 'tune' VALUES (347, NULL, '2012-01-20 12:54:21.2998+00', 'Cross of Inverness, The', 2142, 'Capt. Fraser''s authorship of this tune isn''t quite certain.');
INSERT INTO 'tune' VALUES (3866, NULL, '2012-01-20 12:54:32.831718+00', 'Greenwich Park', 9998, '');
INSERT INTO 'tune' VALUES (348, NULL, '2012-01-20 12:54:21.302714+00', 'Cuckoo''s Nest, The', 9999, '');
INSERT INTO 'tune' VALUES (349, NULL, '2012-01-20 12:54:21.305606+00', 'Culloden''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (350, NULL, '2012-01-20 12:54:21.3085+00', 'Cumberland Reel', 9999, '');
INSERT INTO 'tune' VALUES (3867, NULL, '2012-01-20 12:54:32.834716+00', 'Betts, The', 1465, '');
INSERT INTO 'tune' VALUES (352, NULL, '2012-01-20 12:54:21.314289+00', 'Cupar Barn Dance', 1566, '');
INSERT INTO 'tune' VALUES (353, NULL, '2012-01-20 12:54:21.317184+00', 'Cushion Dance, The', 9999, '');
INSERT INTO 'tune' VALUES (3868, NULL, '2012-01-20 12:54:32.83768+00', 'Miss Brown of Kingo', 1815, '');
INSERT INTO 'tune' VALUES (354, NULL, '2012-01-20 12:54:21.320147+00', 'Cutty Sark', 9998, '');
INSERT INTO 'tune' VALUES (355, NULL, '2012-01-20 12:54:21.323063+00', 'Cutty''s Wedding', 9999, '');
INSERT INTO 'tune' VALUES (356, NULL, '2012-01-20 12:54:21.325951+00', 'D''ye ken John Peel', 9998, '');
INSERT INTO 'tune' VALUES (3869, '2006-09-03 22:00:00+00', '2012-01-20 12:54:32.840592+00', 'Sailor Hector', 3383, '');
INSERT INTO 'tune' VALUES (358, NULL, '2012-01-20 12:54:21.331761+00', 'Heids o'' Vigon, Da', 9999, '');
INSERT INTO 'tune' VALUES (360, NULL, '2012-01-20 12:54:21.337553+00', 'Daggs of Craighouse, The', 1402, '');
INSERT INTO 'tune' VALUES (3870, NULL, '2012-01-20 12:54:32.843611+00', 'Grocer, Da', 1710, '');
INSERT INTO 'tune' VALUES (362, NULL, '2012-01-20 12:54:21.343605+00', 'Dainty Davie', 9999, '');
INSERT INTO 'tune' VALUES (363, NULL, '2012-01-20 12:54:21.346501+00', 'Dalkeith House', 1950, '');
INSERT INTO 'tune' VALUES (3871, NULL, '2012-01-20 12:54:32.846541+00', 'Miss Harriet Forbes', 1759, '');
INSERT INTO 'tune' VALUES (365, NULL, '2012-01-20 12:54:21.35234+00', 'Dalrymple Jig', 1558, '');
INSERT INTO 'tune' VALUES (366, NULL, '2012-01-20 12:54:21.355244+00', 'Dame Diana''s Delight', 326, '');
INSERT INTO 'tune' VALUES (3872, NULL, '2012-01-20 12:54:32.858052+00', 'Gunn of Killearnan', 1865, '');
INSERT INTO 'tune' VALUES (367, NULL, '2012-01-20 12:54:21.35813+00', 'Dance of Diamonds, The', 9998, '');
INSERT INTO 'tune' VALUES (3874, NULL, '2012-01-20 12:54:32.865686+00', 'Mrs David Gordon of Haddo', 1409, '');
INSERT INTO 'tune' VALUES (3875, NULL, '2012-01-20 12:54:32.869628+00', 'Hadrian''s Reel', 1815, '');
INSERT INTO 'tune' VALUES (3876, NULL, '2012-01-20 12:54:32.873478+00', 'Hagg''s Castle', 1424, '');
INSERT INTO 'tune' VALUES (3877, NULL, '2012-01-20 12:54:32.877277+00', 'Flower of Dunblane, The', 1854, '');
INSERT INTO 'tune' VALUES (3878, NULL, '2012-01-20 12:54:32.881119+00', 'Halsway Manor', 1439, '');
INSERT INTO 'tune' VALUES (3879, NULL, '2012-01-20 12:54:32.884923+00', 'Hambleton''s Round O', 9998, '');
INSERT INTO 'tune' VALUES (3880, NULL, '2012-01-20 12:54:32.888732+00', 'Hamiltonian', 9998, '');
INSERT INTO 'tune' VALUES (3881, NULL, '2012-01-20 12:54:32.892681+00', 'Hamilton''s Strathspey', 1512, '');
INSERT INTO 'tune' VALUES (3882, NULL, '2012-01-20 12:54:32.896503+00', 'Ron Wallace', 1764, '');
INSERT INTO 'tune' VALUES (3883, NULL, '2012-01-20 12:54:32.900535+00', 'Uncle Buck', 1329, '');
INSERT INTO 'tune' VALUES (12007, '2012-02-06 11:36:21.23503+00', '2012-02-06 11:36:21.235041+00', 'Nan Adam', 1605, '');
INSERT INTO 'tune' VALUES (12030, '2012-02-07 10:32:15.419803+00', '2012-02-07 10:32:15.419814+00', 'Glenda''s 30th!', 1591, '');
INSERT INTO 'tune' VALUES (12050, '2012-05-04 18:56:45.642089+00', '2012-05-04 18:56:45.6421+00', 'Denise''s Delight', 1502, '');
INSERT INTO 'tune' VALUES (12090, '2012-05-31 07:50:43.06623+00', '2012-05-31 07:50:43.066242+00', 'Mr Huband''s Hornpipe', 1777, '');
INSERT INTO 'tune' VALUES (12167, '2012-06-12 22:47:17.806919+00', '2012-06-12 22:47:17.80693+00', 'Greenside', 1502, '');
INSERT INTO 'tune' VALUES (12174, '2012-06-13 08:41:46.098059+00', '2012-06-13 08:41:46.098069+00', 'Lady Hamilton', 9999, '');
INSERT INTO 'tune' VALUES (346, NULL, '2012-06-17 14:36:42.16298+00', 'Cropie''s Strathspey', 1818, '');
INSERT INTO 'tune' VALUES (12185, '2012-06-17 14:48:45.937711+00', '2012-06-17 14:48:45.937722+00', 'Longford Collector, The', 9999, '');
INSERT INTO 'tune' VALUES (12226, '2012-10-18 15:31:00.019606+00', '2012-10-18 15:31:00.019617+00', 'Marchioness of Normanby', 10138, '');
INSERT INTO 'tune' VALUES (351, NULL, '2017-11-14 10:02:05.576592+00', 'Cumernad Hoose', 1859, '"Cumernad Hoose" is also known as "Cumbernould House", "My Lord Aboyne''s Air" and "My Lord Aboyne''s welcome".');
INSERT INTO 'tune' VALUES (12236, '2012-12-18 08:36:35.350602+00', '2012-12-18 08:36:35.350613+00', 'Double Diamond, A', 10673, 'composed April 2012');
INSERT INTO 'tune' VALUES (12246, '2012-12-27 12:33:31.532172+00', '2012-12-27 12:33:31.532183+00', 'Perrie Werrie, The', 9999, '');
INSERT INTO 'tune' VALUES (12250, '2012-12-28 13:32:39.26944+00', '2012-12-28 13:32:39.269451+00', 'Pharmacist, The', 10680, '');
INSERT INTO 'tune' VALUES (12276, '2012-12-28 16:04:46.663398+00', '2012-12-28 16:04:46.663409+00', 'We''re Off to the Isles', 9999, '');
INSERT INTO 'tune' VALUES (12279, '2012-12-28 16:43:14.74059+00', '2012-12-28 16:43:14.740602+00', 'Irene Meldrum''s Welcome to Bon Accord', 10686, '');
INSERT INTO 'tune' VALUES (12280, '2012-12-28 16:56:13.397676+00', '2012-12-28 16:56:13.397687+00', 'Milrig House', 2776, '');
INSERT INTO 'tune' VALUES (12281, '2012-12-31 15:05:05.283213+00', '2012-12-31 15:05:05.283225+00', 'Reel for Nick', 2856, '');
INSERT INTO 'tune' VALUES (12282, '2012-12-31 15:17:24.554192+00', '2012-12-31 15:17:24.554203+00', 'Ailsa''s Memories O'' Yell', 10086, '');
INSERT INTO 'tune' VALUES (12283, '2012-12-31 15:35:22.636399+00', '2012-12-31 15:35:22.63641+00', 'Troubled Oceans', 10634, '');
INSERT INTO 'tune' VALUES (12290, '2012-12-31 16:26:19.806107+00', '2012-12-31 16:26:19.806118+00', 'Poo''in o'' the Cork, The', 2856, '');
INSERT INTO 'tune' VALUES (427, NULL, '2012-01-20 12:54:21.537655+00', 'Drumtochty Glen', 1607, '');
INSERT INTO 'tune' VALUES (330, NULL, '2020-12-03 21:34:06.882006+00', 'Coupar Angus Jigg', 12006, '');
INSERT INTO 'tune' VALUES (12291, '2012-12-31 16:38:39.754171+00', '2012-12-31 16:38:39.754182+00', 'William Glen''s Favourite', 10690, '');
INSERT INTO 'tune' VALUES (12292, '2013-01-02 14:32:18.254872+00', '2013-01-02 17:02:29.719357+00', 'Cover the Well', 3798, '');
INSERT INTO 'tune' VALUES (12327, '2013-01-03 07:59:08.608332+00', '2013-01-03 07:59:08.608343+00', 'Freeland Barbour''s Compliments to Sandy and Angela Horne', 1580, '');
INSERT INTO 'tune' VALUES (368, NULL, '2012-01-20 12:54:21.361081+00', 'Dancing Feet', 1699, '');
INSERT INTO 'tune' VALUES (369, NULL, '2012-01-20 12:54:21.364002+00', 'Dancing the Baby', 9999, '');
INSERT INTO 'tune' VALUES (3884, NULL, '2012-01-20 12:54:32.904362+00', 'Hamish Henderson''s Refusal', 1857, '');
INSERT INTO 'tune' VALUES (370, NULL, '2012-01-20 12:54:21.366923+00', 'Mary Walker', 1512, '');
INSERT INTO 'tune' VALUES (390, NULL, '2012-01-20 12:54:21.427396+00', 'Devil in Dublin, The', 1516, '');
INSERT INTO 'tune' VALUES (371, NULL, '2012-01-20 12:54:21.369817+00', 'Dancingmaster, The', 9999, '');
INSERT INTO 'tune' VALUES (3885, NULL, '2012-01-20 12:54:32.90874+00', 'Ada Johnstone''s Fancy', 1525, '');
INSERT INTO 'tune' VALUES (372, NULL, '2012-01-20 12:54:21.372717+00', 'Dark Lochnagar', 9999, '');
INSERT INTO 'tune' VALUES (391, NULL, '2012-01-20 12:54:21.430288+00', 'Diane''s Dilemma', 1456, '');
INSERT INTO 'tune' VALUES (3886, NULL, '2012-01-20 12:54:32.912738+00', 'Joe Killeen''s Fancy', 1593, '');
INSERT INTO 'tune' VALUES (374, NULL, '2012-01-20 12:54:21.378528+00', 'Dashing White Sergeant, The', 2876, '');
INSERT INTO 'tune' VALUES (392, NULL, '2012-01-20 12:54:21.433257+00', 'Dinnet House', 9999, '');
INSERT INTO 'tune' VALUES (375, NULL, '2012-01-20 12:54:21.381434+00', 'Davie Work', 1512, '');
INSERT INTO 'tune' VALUES (3887, NULL, '2012-01-20 12:54:32.916454+00', 'Ian Muir''s Compliments to Jon Olive', 1590, '');
INSERT INTO 'tune' VALUES (376, NULL, '2012-01-20 12:54:21.384372+00', 'Davie''s Brae', 1525, '');
INSERT INTO 'tune' VALUES (377, NULL, '2012-01-20 12:54:21.387274+00', 'Davy Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (3888, NULL, '2012-01-20 12:54:32.920248+00', 'Happy Marriage, The', 9998, '');
INSERT INTO 'tune' VALUES (378, NULL, '2012-01-20 12:54:21.390187+00', 'Davy Nick Nack', 9999, '');
INSERT INTO 'tune' VALUES (394, NULL, '2012-01-20 12:54:21.439125+00', 'Dodo''s Reel', 1502, '');
INSERT INTO 'tune' VALUES (379, NULL, '2012-01-20 12:54:21.393094+00', 'Mrs Grant', 1516, '');
INSERT INTO 'tune' VALUES (3889, NULL, '2012-01-20 12:54:32.923251+00', 'Ben''s Reel', 1582, '');
INSERT INTO 'tune' VALUES (380, NULL, '2012-01-20 12:54:21.396001+00', 'Deil among the Mantua-Makers, The', 1516, '');
INSERT INTO 'tune' VALUES (395, NULL, '2012-01-20 12:54:21.442062+00', 'Domhnall Dubh', 9998, '');
INSERT INTO 'tune' VALUES (381, NULL, '2012-01-20 12:54:21.398899+00', 'Dean Brig of Edinburgh, The', 2170, '');
INSERT INTO 'tune' VALUES (3890, NULL, '2012-01-20 12:54:32.926146+00', 'When We Go to the Dance', 1643, '');
INSERT INTO 'tune' VALUES (382, NULL, '2012-01-20 12:54:21.401804+00', 'Deil Amang the Tailors', 2658, '');
INSERT INTO 'tune' VALUES (396, NULL, '2012-01-20 12:54:21.444964+00', 'Donald Bane', 9999, '');
INSERT INTO 'tune' VALUES (383, NULL, '2012-01-20 12:54:21.406793+00', 'Susan''s Jig', 1510, '');
INSERT INTO 'tune' VALUES (3891, NULL, '2012-01-20 12:54:32.92923+00', 'Iain Boyd', 1607, '');
INSERT INTO 'tune' VALUES (384, NULL, '2012-01-20 12:54:21.409938+00', 'Deil''s awa'' wi'' the Exciseman, The', 9999, '');
INSERT INTO 'tune' VALUES (397, NULL, '2012-01-20 12:54:21.447867+00', 'Donald Bathgate', 1609, '');
INSERT INTO 'tune' VALUES (385, NULL, '2012-01-20 12:54:21.41285+00', 'Delvine Side', 1781, '');
INSERT INTO 'tune' VALUES (3892, NULL, '2012-01-20 12:54:32.93236+00', 'Music Makers, The', 1643, '');
INSERT INTO 'tune' VALUES (386, NULL, '2012-01-20 12:54:21.415758+00', 'Sarah Muirhead''s Reel', 1527, '');
INSERT INTO 'tune' VALUES (398, NULL, '2012-01-20 12:54:21.45077+00', 'Donald Iain Rankine', 1533, '');
INSERT INTO 'tune' VALUES (387, NULL, '2012-01-20 12:54:21.418671+00', 'Derek and Maureen Haynes', 1582, '');
INSERT INTO 'tune' VALUES (3893, NULL, '2012-01-20 12:54:32.935299+00', 'Hardy Annual Jig, The', 1590, '');
INSERT INTO 'tune' VALUES (388, NULL, '2012-01-20 12:54:21.421581+00', 'Deuks dang ow''er my Daddie, The', 9999, '');
INSERT INTO 'tune' VALUES (399, NULL, '2012-01-20 12:54:21.453669+00', 'Donald MacDonald''s Fancy', 9998, '');
INSERT INTO 'tune' VALUES (400, NULL, '2012-01-20 12:54:21.457042+00', 'Donald Maclean''s Farewell to Oban', 1755, '');
INSERT INTO 'tune' VALUES (3894, NULL, '2012-01-20 12:54:32.938197+00', 'Hare Amang the Corn, The', 9999, '');
INSERT INTO 'tune' VALUES (401, NULL, '2012-01-20 12:54:21.45998+00', 'Donald Ridley''s Compliments to Colin Dewar', 1593, '');
INSERT INTO 'tune' VALUES (402, NULL, '2012-01-20 12:54:21.462905+00', 'Donnie Muirhead''s Reel', 1527, '');
INSERT INTO 'tune' VALUES (3895, NULL, '2012-01-20 12:54:32.941566+00', 'Hare''s Maggot, The', 9998, '');
INSERT INTO 'tune' VALUES (404, NULL, '2012-01-20 12:54:21.468748+00', 'Doon the Water', 9998, '');
INSERT INTO 'tune' VALUES (405, NULL, '2012-01-20 12:54:21.471653+00', 'Dornoch Links', 1950, '');
INSERT INTO 'tune' VALUES (406, NULL, '2012-01-20 12:54:21.474551+00', 'Douglas Keiller of Carnoustie', 1692, '');
INSERT INTO 'tune' VALUES (13817, '2018-02-24 03:08:00.362067+00', '2018-02-24 03:08:00.362067+00', 'Brig Gen Lorne Campbell VC of Akarit', 9998, '');
INSERT INTO 'tune' VALUES (408, NULL, '2012-01-20 12:54:21.481357+00', 'Dovecote Park', 1568, '');
INSERT INTO 'tune' VALUES (409, NULL, '2012-01-20 12:54:21.484306+00', 'Down on Yon Bank', 9998, '');
INSERT INTO 'tune' VALUES (410, NULL, '2012-01-20 12:54:21.487241+00', 'Dr Alastair MacFadyen', 1502, '');
INSERT INTO 'tune' VALUES (3897, NULL, '2012-01-20 12:54:32.947429+00', 'Hawthorn Tree of Cawdor, The', 9998, '');
INSERT INTO 'tune' VALUES (411, NULL, '2012-01-20 12:54:21.490161+00', 'Dr Bob Smith', 2054, '');
INSERT INTO 'tune' VALUES (412, NULL, '2012-01-20 12:54:21.493109+00', 'Pipe Major Thomson''s Welcome to Paisley', 2383, '');
INSERT INTO 'tune' VALUES (12293, '2013-01-02 14:33:05.128629+00', '2013-01-02 17:02:59.962012+00', 'Little Black Fly', 3798, '');
INSERT INTO 'tune' VALUES (3898, NULL, '2012-01-20 12:54:32.950328+00', 'Julia''s Jig', 326, '');
INSERT INTO 'tune' VALUES (414, NULL, '2012-01-20 12:54:21.499293+00', 'Draw the Sword, Scotland', 9999, '');
INSERT INTO 'tune' VALUES (415, NULL, '2012-01-20 12:54:21.502196+00', 'Drops of Brandy', 9999, '');
INSERT INTO 'tune' VALUES (416, NULL, '2012-01-20 12:54:21.5051+00', 'Drowsy Maggie', 2145, '');
INSERT INTO 'tune' VALUES (3899, NULL, '2012-01-20 12:54:32.953327+00', 'Miss Laura Gracie', 1582, '');
INSERT INTO 'tune' VALUES (417, NULL, '2012-01-20 12:54:21.508007+00', 'Drumdelgie', 1517, '');
INSERT INTO 'tune' VALUES (413, NULL, '2018-07-31 20:27:35.488541+00', 'Dr & Mrs Green', 1800, '');
INSERT INTO 'tune' VALUES (419, NULL, '2012-01-20 12:54:21.514352+00', 'Drumelzier', 1533, '');
INSERT INTO 'tune' VALUES (3900, NULL, '2012-01-20 12:54:32.956239+00', 'Tramping Through the Heather', 9998, '');
INSERT INTO 'tune' VALUES (420, NULL, '2012-01-20 12:54:21.517266+00', 'Drumin', 1512, '');
INSERT INTO 'tune' VALUES (3901, NULL, '2012-01-20 12:54:32.959147+00', 'Old Barn Jig, The', 1422, '');
INSERT INTO 'tune' VALUES (3902, NULL, '2012-01-20 12:54:32.962044+00', 'He-Ho-Hiram', 9998, '');
INSERT INTO 'tune' VALUES (3903, NULL, '2012-01-20 12:54:32.964994+00', 'New Market House', 2347, '');
INSERT INTO 'tune' VALUES (3904, NULL, '2012-01-20 12:54:32.967909+00', 'Murray and Patricia Henderson''s Welcome to Nelson', 1877, '');
INSERT INTO 'tune' VALUES (3905, NULL, '2012-01-20 12:54:32.970809+00', 'Herbie MacLeod''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (3906, NULL, '2012-01-20 12:54:32.973786+00', 'Give and Take', 1872, '');
INSERT INTO 'tune' VALUES (3907, NULL, '2012-01-20 12:54:32.976701+00', 'Hereford Rant, The', 1624, '');
INSERT INTO 'tune' VALUES (12008, '2012-02-06 11:38:25.157419+00', '2012-02-06 11:38:25.15743+00', 'Bobby Coghill Two-Step, The', 1543, '');
INSERT INTO 'tune' VALUES (12031, '2012-02-07 10:34:18.014656+00', '2012-02-07 10:34:18.014667+00', 'Broom, The', 1591, '');
INSERT INTO 'tune' VALUES (12051, '2012-05-04 18:57:14.88543+00', '2012-05-04 18:57:14.885441+00', 'Jiggin'' Aboot', 1502, '');
INSERT INTO 'tune' VALUES (12091, '2012-05-31 07:51:48.211861+00', '2012-05-31 07:51:48.211871+00', 'Doadie the Roadie', 1777, '');
INSERT INTO 'tune' VALUES (12105, '2012-06-12 14:19:52.828311+00', '2012-06-12 14:19:52.828322+00', 'Minstrel Boy, The', 9998, '');
INSERT INTO 'tune' VALUES (538, NULL, '2012-01-20 12:54:21.891424+00', 'Forteviot Jig', 1554, '');
INSERT INTO 'tune' VALUES (389, NULL, '2014-11-01 00:31:28.836412+00', 'Deveron Reel, The', 1523, '');
INSERT INTO 'tune' VALUES (12175, '2012-06-13 08:43:53.042786+00', '2012-06-13 08:43:53.042797+00', 'Lord John Campbell''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (12237, '2012-12-18 08:37:09.359221+00', '2012-12-18 08:37:09.359232+00', 'Haphazard', 10669, 'composed December 2011');
INSERT INTO 'tune' VALUES (12251, '2012-12-28 13:39:03.027996+00', '2012-12-28 13:39:03.028007+00', 'Grand Slam, The', 1539, '');
INSERT INTO 'tune' VALUES (12278, '2012-12-28 16:28:35.697909+00', '2012-12-28 16:28:35.69792+00', 'Mr & Mrs J Hendrie''s Ruby Anniversary Polka', 2693, '');
INSERT INTO 'tune' VALUES (12284, '2012-12-31 15:39:30.863501+00', '2012-12-31 15:39:30.863512+00', 'Millhills', 1512, '');
INSERT INTO 'tune' VALUES (12288, '2012-12-31 16:12:34.682088+00', '2012-12-31 16:12:34.6821+00', 'Mo Rutherford''s Compliments to Frank Thomson', 1626, '');
INSERT INTO 'tune' VALUES (12328, '2013-01-03 08:00:32.615459+00', '2013-01-03 08:00:32.615471+00', 'Jimmy Horne of Clochkan', 1580, '');
INSERT INTO 'tune' VALUES (12338, '2013-01-03 09:14:16.331156+00', '2013-01-03 09:14:16.331167+00', 'Fàgail Lismor', 9999, '');
INSERT INTO 'tune' VALUES (421, NULL, '2012-01-20 12:54:21.520175+00', 'Drumlanrig Castle', 1518, '');
INSERT INTO 'tune' VALUES (437, NULL, '2012-01-20 12:54:21.570086+00', 'Duchess of Gordon''s New Strathspey, The', 1519, '');
INSERT INTO 'tune' VALUES (3908, NULL, '2012-01-20 12:54:32.979603+00', 'Wee Willie''s Strathspey', 2422, '');
INSERT INTO 'tune' VALUES (422, NULL, '2012-01-20 12:54:21.523113+00', 'Sheena''s Buckle', 1502, '');
INSERT INTO 'tune' VALUES (423, NULL, '2012-01-20 12:54:21.526018+00', 'Drumleys', 9999, '');
INSERT INTO 'tune' VALUES (438, NULL, '2012-01-20 12:54:21.573046+00', 'Rector''s Day Off, The', 1511, '');
INSERT INTO 'tune' VALUES (3909, NULL, '2012-01-20 12:54:32.982509+00', 'Duke of Leinster''s Wife, The', 9999, '');
INSERT INTO 'tune' VALUES (424, NULL, '2012-01-20 12:54:21.52893+00', 'Drummer, The', 9999, '');
INSERT INTO 'tune' VALUES (425, NULL, '2012-01-20 12:54:21.531836+00', 'Drummond Castle', 1518, '');
INSERT INTO 'tune' VALUES (439, NULL, '2012-01-20 12:54:21.575949+00', 'Duchess of Gordon, The', 1587, '');
INSERT INTO 'tune' VALUES (3910, NULL, '2012-01-20 12:54:32.9854+00', 'Mr & Mrs Joe Killeen', 1593, '');
INSERT INTO 'tune' VALUES (426, NULL, '2012-01-20 12:54:21.534745+00', 'Drummond Castle Laundry', 2270, '');
INSERT INTO 'tune' VALUES (440, NULL, '2012-01-20 12:54:21.578862+00', 'Duchess of Roxburghe', 1516, '');
INSERT INTO 'tune' VALUES (3911, NULL, '2012-01-20 12:54:32.988549+00', 'Hey-Boys Up We Go', 9998, '');
INSERT INTO 'tune' VALUES (428, NULL, '2012-01-20 12:54:21.541091+00', 'Drunken Meg Young', 9998, '');
INSERT INTO 'tune' VALUES (429, NULL, '2012-01-20 12:54:21.544021+00', 'Drunken Parson, The', 9999, '');
INSERT INTO 'tune' VALUES (430, NULL, '2012-01-20 12:54:21.546934+00', 'Drunken Piper, The', 1421, '');
INSERT INTO 'tune' VALUES (431, NULL, '2012-01-20 12:54:21.551906+00', 'Duchess Tree, The', 1512, '');
INSERT INTO 'tune' VALUES (442, NULL, '2012-01-20 12:54:21.585033+00', 'Duke is welcome to Inverness, The', 9999, '');
INSERT INTO 'tune' VALUES (3913, NULL, '2012-01-20 12:54:32.994432+00', 'Hide Park', 9998, '');
INSERT INTO 'tune' VALUES (502, NULL, '2012-01-20 12:54:21.777607+00', 'Fancy Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (432, NULL, '2012-01-20 12:54:21.55482+00', 'Duchess of Atholl''s Slipper, The', 1518, '');
INSERT INTO 'tune' VALUES (443, NULL, '2012-01-20 12:54:21.587998+00', 'Rising Moon Reel, The', 2394, '');
INSERT INTO 'tune' VALUES (434, NULL, '2012-01-20 12:54:21.560619+00', 'Bannetstane, The', 1555, '');
INSERT INTO 'tune' VALUES (12238, '2012-12-18 08:38:06.257966+00', '2012-12-18 08:38:06.257977+00', 'Torquay Gathering, The', 1582, 'composed February 2012');
INSERT INTO 'tune' VALUES (436, NULL, '2012-01-20 12:54:21.567159+00', 'Duchess of Campbellville, The', 1836, '');
INSERT INTO 'tune' VALUES (445, NULL, '2012-01-20 12:54:21.593803+00', 'Duke of Gordon, The', 1516, '');
INSERT INTO 'tune' VALUES (3916, NULL, '2012-01-20 12:54:33.005413+00', 'Highland Jigg', 9998, '');
INSERT INTO 'tune' VALUES (446, NULL, '2012-01-20 12:54:21.596706+00', 'Duke of Hamilton''s Reel, The', 9998, '');
INSERT INTO 'tune' VALUES (447, NULL, '2012-01-20 12:54:21.59961+00', 'Duke of Kent', 1306, '');
INSERT INTO 'tune' VALUES (448, NULL, '2012-01-20 12:54:21.602499+00', 'Duke of Perth', 9999, '');
INSERT INTO 'tune' VALUES (3917, NULL, '2012-01-20 12:54:33.009222+00', 'N'' Troopa Ghaelach', 9998, '');
INSERT INTO 'tune' VALUES (449, NULL, '2012-01-20 12:54:21.605974+00', 'Duke of Roxburghe, The', 9998, '');
INSERT INTO 'tune' VALUES (450, NULL, '2012-01-20 12:54:21.608898+00', 'Dumbarton Castle', 1424, '');
INSERT INTO 'tune' VALUES (451, NULL, '2012-01-20 12:54:21.611826+00', 'Dumbarton''s Drums', 9999, '');
INSERT INTO 'tune' VALUES (3918, NULL, '2012-01-20 12:54:33.014237+00', 'Hilary''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (452, NULL, '2012-01-20 12:54:21.614763+00', 'Dumfries House', 1762, '');
INSERT INTO 'tune' VALUES (453, NULL, '2012-01-20 12:54:21.617682+00', 'Dumfries Lasses', 9999, '');
INSERT INTO 'tune' VALUES (454, NULL, '2012-01-20 12:54:21.620588+00', 'Dumgoyne', 1876, '');
INSERT INTO 'tune' VALUES (3919, NULL, '2012-01-20 12:54:33.033066+00', 'Nut Brown Maiden, The', 9999, '');
INSERT INTO 'tune' VALUES (455, NULL, '2012-01-20 12:54:21.623491+00', 'Dun Telve', 1413, '');
INSERT INTO 'tune' VALUES (456, NULL, '2012-01-20 12:54:21.626386+00', 'Duncan Davidson', 1587, '');
INSERT INTO 'tune' VALUES (457, NULL, '2012-01-20 12:54:21.629281+00', 'Duncan Gray', 9999, '');
INSERT INTO 'tune' VALUES (3920, NULL, '2012-01-20 12:54:33.037018+00', 'Hoist the Flag', 2257, '');
INSERT INTO 'tune' VALUES (458, NULL, '2012-01-20 12:54:21.632764+00', 'Duncan MacCalman', 1607, '');
INSERT INTO 'tune' VALUES (459, NULL, '2012-01-20 12:54:21.635704+00', 'Duncan Mackay', 9998, '');
INSERT INTO 'tune' VALUES (460, NULL, '2012-01-20 12:54:21.638607+00', 'Duncan''s Reel', 1701, '');
INSERT INTO 'tune' VALUES (461, NULL, '2012-01-20 12:54:21.641522+00', 'Dundee Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (3921, NULL, '2012-01-20 12:54:33.039978+00', 'Holborn March', 9998, '');
INSERT INTO 'tune' VALUES (462, NULL, '2012-01-20 12:54:21.644424+00', 'Dunedin', 1701, '');
INSERT INTO 'tune' VALUES (463, NULL, '2012-01-20 12:54:21.647331+00', 'Dunie Mains', 1790, '');
INSERT INTO 'tune' VALUES (464, NULL, '2012-01-20 12:54:21.650231+00', 'Dunire Lodge', 1518, '');
INSERT INTO 'tune' VALUES (3922, NULL, '2012-01-20 12:54:33.042903+00', 'Reel Derek, The', 1880, '');
INSERT INTO 'tune' VALUES (465, NULL, '2012-01-20 12:54:21.65314+00', 'Dunkeld Bridge', 1518, '');
INSERT INTO 'tune' VALUES (466, NULL, '2012-01-20 12:54:21.656069+00', 'Dunkeld House', 1518, '');
INSERT INTO 'tune' VALUES (467, NULL, '2012-01-20 12:54:21.659867+00', 'Dunkeld Steeple', 1518, '');
INSERT INTO 'tune' VALUES (3923, NULL, '2012-01-20 12:54:33.045788+00', 'Air VIII Hornpipe', 1881, '');
INSERT INTO 'tune' VALUES (468, NULL, '2012-01-20 12:54:21.662905+00', 'Dunnechan', 9999, '');
INSERT INTO 'tune' VALUES (3924, NULL, '2012-01-20 12:54:33.04896+00', 'Hollyburn Jig, The', 1457, '');
INSERT INTO 'tune' VALUES (3925, NULL, '2012-01-20 12:54:33.051867+00', 'Honeypot, The', 1815, '');
INSERT INTO 'tune' VALUES (3926, NULL, '2012-01-20 12:54:33.054774+00', 'Miss Claire Hamilton Goodman', 1701, '');
INSERT INTO 'tune' VALUES (3927, NULL, '2012-01-20 12:54:33.057668+00', 'Dandie Dinmont', 1632, '');
INSERT INTO 'tune' VALUES (3928, NULL, '2012-01-20 12:54:33.060596+00', 'Tom the Barman', 1679, '');
INSERT INTO 'tune' VALUES (3929, NULL, '2012-01-20 12:54:33.063615+00', 'Hugh''s Welcome', 1872, '');
INSERT INTO 'tune' VALUES (3930, NULL, '2012-01-20 12:54:33.066538+00', 'Humberstone''s Magic Piano', 1590, '');
INSERT INTO 'tune' VALUES (3931, NULL, '2012-01-20 12:54:33.070214+00', 'Humours of Castle Bernard', 9999, '');
INSERT INTO 'tune' VALUES (3932, NULL, '2012-01-20 12:54:33.074325+00', 'Cuttyman and Treladle', 9999, '');
INSERT INTO 'tune' VALUES (3933, NULL, '2012-01-20 12:54:33.077357+00', 'Hunter''s Rant', 1329, '');
INSERT INTO 'tune' VALUES (3934, NULL, '2012-01-20 12:54:33.080268+00', 'Hunter Valley Strathspey', 609, '');
INSERT INTO 'tune' VALUES (12009, '2012-02-06 11:47:05.0429+00', '2012-02-06 11:47:05.042911+00', 'Mrs Jamieson of Newlands', 1456, '');
INSERT INTO 'tune' VALUES (12032, '2012-02-07 10:36:30.336351+00', '2012-02-07 10:36:30.336362+00', 'John Renton', 1591, '');
INSERT INTO 'tune' VALUES (12052, '2012-05-04 18:57:53.009095+00', '2012-05-04 18:57:53.009106+00', 'Cream of the Strawberries', 1502, '');
INSERT INTO 'tune' VALUES (12092, '2012-05-31 08:08:03.295496+00', '2012-05-31 08:08:03.295507+00', 'Andrew Nolan''s Reel', 3683, '');
INSERT INTO 'tune' VALUES (13819, '2018-02-24 03:09:32.045025+00', '2018-02-24 03:09:32.045025+00', 'Cannich Bridge', 9998, '');
INSERT INTO 'tune' VALUES (12176, '2012-06-13 08:46:11.330828+00', '2012-06-13 08:46:11.330838+00', 'Old Salt Strathspey, the', 146, '');
INSERT INTO 'tune' VALUES (12187, '2012-06-17 14:55:31.26842+00', '2012-06-17 14:55:31.268431+00', 'Peerie Weerie', 9999, '');
INSERT INTO 'tune' VALUES (12285, '2012-12-31 15:44:48.577319+00', '2012-12-31 15:44:48.57733+00', 'Frank''s Favourite', 1836, '');
INSERT INTO 'tune' VALUES (12289, '2012-12-31 16:16:17.168797+00', '2012-12-31 16:16:17.168808+00', 'Pitgaveny', 1541, '');
INSERT INTO 'tune' VALUES (12294, '2013-01-02 14:38:13.059378+00', '2013-01-02 14:38:13.05939+00', 'David Finlay''s Hornpipe', 1607, '');
INSERT INTO 'tune' VALUES (12329, '2013-01-03 08:04:26.212183+00', '2013-01-03 08:04:26.212194+00', 'Kevin McLeod''s', 1580, '');
INSERT INTO 'tune' VALUES (12339, '2013-01-03 09:16:31.277593+00', '2013-01-03 09:16:31.277605+00', 'Loch Maruibhe', 9999, '');
INSERT INTO 'tune' VALUES (482, NULL, '2012-01-20 12:54:21.704439+00', 'East Neuk o'' Fife, The', 1859, '');
INSERT INTO 'tune' VALUES (3935, NULL, '2012-01-20 12:54:33.083935+00', 'Tekeli', 9998, '');
INSERT INTO 'tune' VALUES (483, NULL, '2012-01-20 12:54:21.707811+00', 'Traditional Jig', 9999, '');
INSERT INTO 'tune' VALUES (472, NULL, '2012-01-20 12:54:21.674554+00', 'Dusty Miller, The', 9999, '');
INSERT INTO 'tune' VALUES (3936, NULL, '2012-01-20 12:54:33.087039+00', 'Iain D. MacPhail', 1527, '');
INSERT INTO 'tune' VALUES (484, NULL, '2012-01-20 12:54:21.710786+00', 'Eccles'' Rant', 9998, '');
INSERT INTO 'tune' VALUES (474, NULL, '2012-01-20 12:54:21.68099+00', 'Eagle Hall', 1502, '');
INSERT INTO 'tune' VALUES (3937, NULL, '2012-01-20 12:54:33.089974+00', 'Ian Duncan', 9998, '');
INSERT INTO 'tune' VALUES (475, NULL, '2012-01-20 12:54:21.683923+00', 'Earl Marshall''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (476, NULL, '2012-01-20 12:54:21.686825+00', 'Earl of Angus and Arran, The', 1516, '');
INSERT INTO 'tune' VALUES (3938, NULL, '2012-01-20 12:54:33.092882+00', 'Ian Powrie''s Farewell to Scotland', 1640, '');
INSERT INTO 'tune' VALUES (477, NULL, '2012-01-20 12:54:21.689722+00', 'Earl of Fife', 1516, '');
INSERT INTO 'tune' VALUES (486, NULL, '2012-01-20 12:54:21.716592+00', 'Edinburgh Volunteers, The', 9998, '');
INSERT INTO 'tune' VALUES (478, NULL, '2012-01-20 12:54:21.69262+00', 'Earl of Fife''s Fireside, The', 1695, '');
INSERT INTO 'tune' VALUES (3912, NULL, '2017-03-02 00:20:45.693067+00', 'Hey, Johnnie Cope', 9999, '');
INSERT INTO 'tune' VALUES (433, NULL, '2017-07-07 13:28:31.652812+00', 'Duchess of Buccleuch''s Favourite, The', 1518, '');
INSERT INTO 'tune' VALUES (3939, NULL, '2012-01-20 12:54:33.095775+00', 'Christina McNair Caskie', 1551, '');
INSERT INTO 'tune' VALUES (479, NULL, '2012-01-20 12:54:21.695519+00', 'Earl of Home''s Country Dance, The', 1517, '');
INSERT INTO 'tune' VALUES (487, NULL, '2012-01-20 12:54:21.719488+00', 'Eight Men of Moidart, The', 9999, '');
INSERT INTO 'tune' VALUES (480, NULL, '2012-01-20 12:54:21.69842+00', 'Earl of Mansfield''s March, The', 1741, '');
INSERT INTO 'tune' VALUES (3940, NULL, '2012-01-20 12:54:33.098687+00', 'I Daurna Say No', 1512, '');
INSERT INTO 'tune' VALUES (481, NULL, '2012-01-20 12:54:21.701537+00', 'Earl of Seaforth''s Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (488, NULL, '2012-01-20 12:54:21.722376+00', 'Elizabeth Adair', 1554, '');
INSERT INTO 'tune' VALUES (3941, NULL, '2012-01-20 12:54:33.101583+00', 'I Love to Wear the Kilt', 1883, '');
INSERT INTO 'tune' VALUES (489, NULL, '2012-01-20 12:54:21.725292+00', 'Ellen Mackay', 2841, '');
INSERT INTO 'tune' VALUES (490, NULL, '2012-01-20 12:54:21.728819+00', 'Ellie''s Jig', 1764, '');
INSERT INTO 'tune' VALUES (491, NULL, '2012-01-20 12:54:21.731788+00', 'Elspeth Andrew''s Fancy', 1555, '');
INSERT INTO 'tune' VALUES (3942, NULL, '2012-01-20 12:54:33.105974+00', 'I''m Doun for Lack o'' Johnnie', 9999, '');
INSERT INTO 'tune' VALUES (492, NULL, '2012-01-20 12:54:21.734702+00', 'Emslie Twins, The', 1607, '');
INSERT INTO 'tune' VALUES (493, NULL, '2012-01-20 12:54:21.737604+00', 'Endrick Water', 1815, '');
INSERT INTO 'tune' VALUES (494, NULL, '2012-01-20 12:54:21.740508+00', 'European, The', 1718, '');
INSERT INTO 'tune' VALUES (441, NULL, '2021-06-03 21:12:34.155501+00', 'Duke and Duchess of Edinburgh, The', 1588, '');
INSERT INTO 'tune' VALUES (469, NULL, '2021-06-03 21:12:01.313001+00', 'Dunnottar Castle', 9999, '');
INSERT INTO 'tune' VALUES (3943, NULL, '2012-01-20 12:54:33.10888+00', 'Indian Queen, The', 9998, '');
INSERT INTO 'tune' VALUES (495, NULL, '2012-01-20 12:54:21.743445+00', 'Expert Dancer, The', 2142, '');
INSERT INTO 'tune' VALUES (496, NULL, '2012-01-20 12:54:21.746342+00', 'Fairhaven Jig', 9998, '');
INSERT INTO 'tune' VALUES (497, NULL, '2012-01-20 12:54:21.750621+00', 'Fairy Dance, The', 1517, '');
INSERT INTO 'tune' VALUES (3944, NULL, '2012-01-20 12:54:33.111773+00', 'Oban Bay Strathspey', 1846, '');
INSERT INTO 'tune' VALUES (498, NULL, '2012-01-20 12:54:21.753543+00', 'Fairy Hillock, The', 9999, '');
INSERT INTO 'tune' VALUES (499, NULL, '2012-01-20 12:54:21.757186+00', 'Faithful Friend', 2743, '');
INSERT INTO 'tune' VALUES (3945, NULL, '2012-01-20 12:54:33.114708+00', 'Installation, The', 9998, '');
INSERT INTO 'tune' VALUES (500, NULL, '2012-01-20 12:54:21.760117+00', 'Falkland Beauty, The', 9999, '');
INSERT INTO 'tune' VALUES (501, NULL, '2012-01-20 12:54:21.77455+00', 'Falls o'' Dochart, The', 1719, '');
INSERT INTO 'tune' VALUES (3947, NULL, '2012-01-20 12:54:33.121352+00', 'Woodbridge Strathspey', 1615, '');
INSERT INTO 'tune' VALUES (504, NULL, '2012-01-20 12:54:21.783427+00', 'Mi''m Shuidh''an Deireach Bata', 1513, '');
INSERT INTO 'tune' VALUES (3948, NULL, '2012-01-20 12:54:33.126141+00', 'Intrigue, The', 9998, '');
INSERT INTO 'tune' VALUES (505, NULL, '2012-01-20 12:54:21.786327+00', 'Farewell to Auchterarder', 9998, '');
INSERT INTO 'tune' VALUES (3949, NULL, '2012-01-20 12:54:33.129281+00', 'Inverclyde', 1537, '');
INSERT INTO 'tune' VALUES (506, NULL, '2012-01-20 12:54:21.789709+00', 'Farewell to Cramond', 1502, '');
INSERT INTO 'tune' VALUES (3950, NULL, '2012-01-20 12:54:33.132348+00', 'Invereshie', 1516, '');
INSERT INTO 'tune' VALUES (507, NULL, '2012-01-20 12:54:21.79263+00', 'Farewell to Fetter Lane', 9998, '');
INSERT INTO 'tune' VALUES (3951, NULL, '2012-01-20 12:54:33.135295+00', 'Pat''s Jig', 948, '');
INSERT INTO 'tune' VALUES (509, NULL, '2012-01-20 12:54:21.798428+00', 'Farewell to Strathardle', 1410, '');
INSERT INTO 'tune' VALUES (510, NULL, '2012-01-20 12:54:21.80133+00', 'Farewell to the Creeks', 1515, '');
INSERT INTO 'tune' VALUES (3952, NULL, '2012-01-20 12:54:33.138215+00', 'Honour the Piper', 1607, '');
INSERT INTO 'tune' VALUES (511, NULL, '2012-01-20 12:54:21.804247+00', 'Tom & Madge Sharp', 1555, '');
INSERT INTO 'tune' VALUES (12010, '2012-02-06 11:48:14.255678+00', '2012-02-06 11:48:14.255689+00', 'John Huband of Muirhead', 1550, '');
INSERT INTO 'tune' VALUES (512, NULL, '2012-01-20 12:54:21.807467+00', 'Farewell to the Tay', 9999, '');
INSERT INTO 'tune' VALUES (513, NULL, '2012-01-20 12:54:21.810483+00', 'Farewell, my Fancy', 1836, '');
INSERT INTO 'tune' VALUES (12033, '2012-02-07 10:37:58.498696+00', '2012-02-07 10:37:58.498706+00', 'B''s Two-Step, The', 1591, '');
INSERT INTO 'tune' VALUES (514, NULL, '2012-01-20 12:54:21.81342+00', 'Father Connelly''s Jig', 1817, '');
INSERT INTO 'tune' VALUES (515, NULL, '2012-01-20 12:54:21.816329+00', 'Feet Washing, The', 9998, '');
INSERT INTO 'tune' VALUES (516, NULL, '2012-01-20 12:54:21.819248+00', 'Fell End', 810, '');
INSERT INTO 'tune' VALUES (12093, '2012-05-31 08:11:24.434113+00', '2012-05-31 08:11:24.434123+00', 'Angel Without Wings', 3683, '');
INSERT INTO 'tune' VALUES (517, NULL, '2012-01-20 12:54:21.822142+00', 'Ferguson''s Rant', 9999, '');
INSERT INTO 'tune' VALUES (518, NULL, '2012-01-20 12:54:21.825233+00', 'Ferintosh', 2142, '');
INSERT INTO 'tune' VALUES (519, NULL, '2012-01-20 12:54:21.828795+00', 'Ferry to the Islands, The', 9999, '');
INSERT INTO 'tune' VALUES (12177, '2012-06-13 08:55:15.049713+00', '2012-06-13 08:55:15.049724+00', 'Vancouver Island Reel, the', 1502, '');
INSERT INTO 'tune' VALUES (520, NULL, '2012-01-20 12:54:21.831852+00', 'Ferry, The', 9999, '');
INSERT INTO 'tune' VALUES (12188, '2012-06-17 15:01:19.386629+00', '2012-06-17 15:01:19.38664+00', 'Trip to the Market', 10013, '');
INSERT INTO 'tune' VALUES (521, NULL, '2012-01-20 12:54:21.834816+00', 'Fiddlehead Reel, The', 1452, '');
INSERT INTO 'tune' VALUES (522, NULL, '2012-01-20 12:54:21.83775+00', 'Fiddles and Boxes', 1815, '');
INSERT INTO 'tune' VALUES (12239, '2012-12-18 08:38:45.474812+00', '2012-12-18 08:38:45.474822+00', 'Willow Bank, The', 10673, 'composed April 2012');
INSERT INTO 'tune' VALUES (523, NULL, '2012-01-20 12:54:21.84069+00', 'Fidget', 9999, '');
INSERT INTO 'tune' VALUES (12253, '2012-12-28 13:43:50.326275+00', '2012-12-28 13:43:50.326286+00', 'Kol Kalison''s March', 10681, '');
INSERT INTO 'tune' VALUES (524, NULL, '2012-01-20 12:54:21.843653+00', 'Fife and Forfar Hunt''s Favourite, The', 1519, '');
INSERT INTO 'tune' VALUES (525, NULL, '2012-01-20 12:54:21.847196+00', 'Finlay Stewart Skinner', 1502, '');
INSERT INTO 'tune' VALUES (12286, '2012-12-31 15:48:53.627329+00', '2012-12-31 15:48:53.62734+00', 'Octocentenary, The', 10252, '');
INSERT INTO 'tune' VALUES (526, NULL, '2012-01-20 12:54:21.850437+00', 'Fiona Bruce', 9999, '');
INSERT INTO 'tune' VALUES (527, NULL, '2012-01-20 12:54:21.853555+00', 'Fiona''s Fancy', 1464, '');
INSERT INTO 'tune' VALUES (528, NULL, '2012-01-20 12:54:21.856604+00', 'Fireside Reel, The', 9998, '');
INSERT INTO 'tune' VALUES (12295, '2013-01-02 14:39:06.318904+00', '2013-01-02 17:05:10.932504+00', 'Snowy Morning, The', 3798, '');
INSERT INTO 'tune' VALUES (529, NULL, '2012-01-20 12:54:21.859881+00', 'Auchmague', 1555, '');
INSERT INTO 'tune' VALUES (12330, '2013-01-03 08:05:24.237456+00', '2013-01-03 08:05:24.237467+00', 'Millar Man, The', 1580, '');
INSERT INTO 'tune' VALUES (530, NULL, '2012-01-20 12:54:21.863423+00', 'Fishers'' Reel o'' Buckie, The', 1860, '');
INSERT INTO 'tune' VALUES (531, NULL, '2012-01-20 12:54:21.867302+00', 'Lansdowne', 1560, '');
INSERT INTO 'tune' VALUES (12340, '2013-01-03 09:18:38.263353+00', '2013-01-03 09:18:38.263364+00', 'Cuthag nan Craobh', 9999, '');
INSERT INTO 'tune' VALUES (12343, '2013-01-03 09:54:08.617997+00', '2013-01-03 09:54:08.618008+00', 'Drouthie Crony', 9999, '');
INSERT INTO 'tune' VALUES (533, NULL, '2012-01-20 12:54:21.875085+00', 'Flower o'' the Quern, The', 1512, '');
INSERT INTO 'tune' VALUES (534, NULL, '2012-01-20 12:54:21.878603+00', 'Flowers of Edinburgh, The', 9999, '');
INSERT INTO 'tune' VALUES (12344, '2013-01-03 10:00:49.179143+00', '2013-01-03 10:00:49.179155+00', 'Cold Winds from Wyvis', 9999, '');
INSERT INTO 'tune' VALUES (535, NULL, '2012-01-20 12:54:21.881795+00', 'For Lack of Gold', 9998, '');
INSERT INTO 'tune' VALUES (12350, '2013-01-03 11:02:17.206665+00', '2013-01-03 11:02:17.206676+00', 'Drumcolliher', 1961, '');
INSERT INTO 'tune' VALUES (536, NULL, '2012-01-20 12:54:21.884845+00', 'Forbes Morrison', 1512, '');
INSERT INTO 'tune' VALUES (558, NULL, '2012-01-20 12:54:21.970567+00', 'Gardener, The', 1815, '');
INSERT INTO 'tune' VALUES (537, NULL, '2012-01-20 12:54:21.887953+00', 'Forres Country Dance', 1797, '');
INSERT INTO 'tune' VALUES (473, NULL, '2013-10-05 11:02:59.525232+00', 'Dyster Laddie', 1587, '');
INSERT INTO 'tune' VALUES (559, NULL, '2012-01-20 12:54:21.974592+00', 'Garple Burn, The', 1437, '');
INSERT INTO 'tune' VALUES (3954, NULL, '2012-01-20 12:54:33.144023+00', 'Iona Black', 1884, '');
INSERT INTO 'tune' VALUES (508, NULL, '2018-06-09 21:24:09.284885+00', 'Farewell to Nova Scotia', 9999, '');
INSERT INTO 'tune' VALUES (540, NULL, '2012-01-20 12:54:21.898648+00', 'Four Stringer, The', 1554, '');
INSERT INTO 'tune' VALUES (560, NULL, '2012-01-20 12:54:21.978411+00', 'Garry Owen', 9999, '');
INSERT INTO 'tune' VALUES (3955, NULL, '2012-01-20 12:54:33.146922+00', 'Iona Reel, The', 1872, '');
INSERT INTO 'tune' VALUES (541, NULL, '2012-01-20 12:54:21.902581+00', 'Fox Chase, The', 9999, '');
INSERT INTO 'tune' VALUES (542, NULL, '2012-01-20 12:54:21.906397+00', 'Fraser Patrick''s Reel', 1442, '');
INSERT INTO 'tune' VALUES (561, NULL, '2012-01-20 12:54:21.983109+00', 'Lad o'' Kyle', 9999, '');
INSERT INTO 'tune' VALUES (3956, NULL, '2012-01-20 12:54:33.149807+00', 'Laoidh an t''Slanuidhfear', 9999, '');
INSERT INTO 'tune' VALUES (543, NULL, '2012-01-20 12:54:21.910245+00', 'Frasers of Oban, The', 1586, '');
INSERT INTO 'tune' VALUES (544, NULL, '2012-01-20 12:54:21.914113+00', 'French Air', 9999, '');
INSERT INTO 'tune' VALUES (562, NULL, '2012-01-20 12:54:21.986963+00', 'Gaspe Reel', 9999, '');
INSERT INTO 'tune' VALUES (3957, NULL, '2012-01-20 12:54:33.152836+00', 'Islay Hoose', 9999, '');
INSERT INTO 'tune' VALUES (545, NULL, '2012-01-20 12:54:21.918923+00', 'Friday Evening', 1557, '');
INSERT INTO 'tune' VALUES (546, NULL, '2012-01-20 12:54:21.922765+00', 'Friends Forever', 9998, '');
INSERT INTO 'tune' VALUES (563, NULL, '2012-01-20 12:54:21.990945+00', 'Gates of Edinburgh, The', 9999, '');
INSERT INTO 'tune' VALUES (3958, NULL, '2012-01-20 12:54:33.155739+00', 'Mr Edward Simpson of Edinburgh''s Fancy', 1516, '');
INSERT INTO 'tune' VALUES (547, NULL, '2012-01-20 12:54:21.926597+00', 'Frolicksome Paddy', 9999, '');
INSERT INTO 'tune' VALUES (548, NULL, '2012-01-20 12:54:21.930424+00', 'From Scotia''s Shores We''re Noo Awa''', 2054, '');
INSERT INTO 'tune' VALUES (3959, NULL, '2012-01-20 12:54:33.158682+00', 'Whistling Rufus', 1885, '');
INSERT INTO 'tune' VALUES (3946, NULL, '2018-01-27 10:32:31.937673+00', 'In the Garb of Old Gaul', 9999, '');
INSERT INTO 'tune' VALUES (549, NULL, '2012-01-20 12:54:21.934279+00', 'From the Broomielaw', 1701, '');
INSERT INTO 'tune' VALUES (550, NULL, '2012-01-20 12:54:21.938296+00', 'Fullarton Reel, The', 1508, '');
INSERT INTO 'tune' VALUES (565, NULL, '2012-01-20 12:54:21.999027+00', 'Geese in the Bog, The', 2261, '');
INSERT INTO 'tune' VALUES (3960, NULL, '2012-01-20 12:54:33.161618+00', 'Ball o'' Kirriemuir', 9998, '');
INSERT INTO 'tune' VALUES (551, NULL, '2012-01-20 12:54:21.942757+00', 'Fyket, The', 9999, '');
INSERT INTO 'tune' VALUES (552, NULL, '2012-01-20 12:54:21.94659+00', 'Gadie Water, The', 1487, '');
INSERT INTO 'tune' VALUES (566, NULL, '2012-01-20 12:54:22.005646+00', 'General Campbell', 1519, '');
INSERT INTO 'tune' VALUES (3961, NULL, '2012-01-20 12:54:33.164525+00', 'Jack''s Maggot', 9998, '');
INSERT INTO 'tune' VALUES (553, NULL, '2012-01-20 12:54:21.950415+00', 'Gallant Weaver, The', 9999, '');
INSERT INTO 'tune' VALUES (554, NULL, '2012-01-20 12:54:21.954438+00', 'Rosedale', 9999, '');
INSERT INTO 'tune' VALUES (567, NULL, '2012-01-20 12:54:22.00971+00', 'General Wemyss of Wemyss', 9998, '');
INSERT INTO 'tune' VALUES (3962, NULL, '2012-01-20 12:54:33.168299+00', 'Jacob Hall''s Jigg', 9998, '');
INSERT INTO 'tune' VALUES (555, NULL, '2012-01-20 12:54:21.958317+00', 'Galway Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (556, NULL, '2012-01-20 12:54:21.962857+00', 'John Anderson, my Jo', 9999, '');
INSERT INTO 'tune' VALUES (568, NULL, '2012-01-20 12:54:22.013552+00', 'Gentle Shepherd, The', 1493, '');
INSERT INTO 'tune' VALUES (3963, NULL, '2012-01-20 12:54:33.171221+00', 'Jakie Stewart''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (12053, '2012-05-04 18:59:41.891855+00', '2021-11-25 01:02:37.121621+00', 'My Beautiful Landrieau', 1502, '');
INSERT INTO 'tune' VALUES (557, NULL, '2012-01-20 12:54:21.966704+00', 'Garden Wall, The', 9998, '');
INSERT INTO 'tune' VALUES (569, NULL, '2012-01-20 12:54:22.01747+00', 'Ann Dix''s Reel', 1527, '');
INSERT INTO 'tune' VALUES (570, NULL, '2012-01-20 12:54:22.022749+00', 'Geordie MacLeish', 9999, '');
INSERT INTO 'tune' VALUES (3964, NULL, '2012-01-20 12:54:33.174119+00', 'Mile-Dyke Two-Step, The', 1531, '');
INSERT INTO 'tune' VALUES (571, NULL, '2012-01-20 12:54:22.026749+00', 'Geordie the Roadman', 9999, '');
INSERT INTO 'tune' VALUES (12094, '2012-05-31 08:15:55.593211+00', '2019-06-14 19:58:28.352064+00', 'Anne Riley''s Whimsey', 1502, '');
INSERT INTO 'tune' VALUES (573, NULL, '2012-01-20 12:54:22.034455+00', 'George Darling''s Reel', 1501, '');
INSERT INTO 'tune' VALUES (3965, NULL, '2012-01-20 12:54:33.177662+00', 'Jar of Honey, A', 1607, '');
INSERT INTO 'tune' VALUES (574, NULL, '2012-01-20 12:54:22.040905+00', 'George Skene Duff of Milton', 1516, '');
INSERT INTO 'tune' VALUES (575, NULL, '2012-01-20 12:54:22.044851+00', 'George Swirles of Arbroath', 1653, '');
INSERT INTO 'tune' VALUES (3966, NULL, '2012-01-20 12:54:33.180604+00', 'Bridge of Athlone', 2145, '');
INSERT INTO 'tune' VALUES (577, NULL, '2012-01-20 12:54:22.053502+00', 'Money in Both Pockets', 9999, '');
INSERT INTO 'tune' VALUES (578, NULL, '2012-01-20 12:54:22.057357+00', 'Gin I was a bonny lad', 9999, '');
INSERT INTO 'tune' VALUES (579, NULL, '2012-01-20 12:54:22.061353+00', 'Gin Worth Living', 1469, '');
INSERT INTO 'tune' VALUES (3967, NULL, '2012-01-20 12:54:33.183501+00', 'Silver City, The', 1886, '');
INSERT INTO 'tune' VALUES (580, NULL, '2012-01-20 12:54:22.06532+00', 'Gipsy Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (581, NULL, '2012-01-20 12:54:22.069204+00', 'Girl in Green', 9999, '');
INSERT INTO 'tune' VALUES (582, NULL, '2012-01-20 12:54:22.073386+00', 'Girnel, The', 1725, '');
INSERT INTO 'tune' VALUES (3968, NULL, '2012-01-20 12:54:33.186394+00', 'Jeannie Campbell of Edinburgh', 1725, '');
INSERT INTO 'tune' VALUES (584, NULL, '2012-01-20 12:54:22.081259+00', 'Gladstone', 1512, '');
INSERT INTO 'tune' VALUES (585, NULL, '2012-01-20 12:54:22.085279+00', 'Glasgow Caledonian Strathspey and Reel Society', 1554, '');
INSERT INTO 'tune' VALUES (3969, NULL, '2012-01-20 12:54:33.189288+00', 'Logie Park', 1594, '');
INSERT INTO 'tune' VALUES (586, NULL, '2012-01-20 12:54:22.089494+00', 'Glasgow Gaelic Club, The', 9999, '');
INSERT INTO 'tune' VALUES (12351, '2013-01-03 11:02:49.961456+00', '2013-01-03 11:02:49.961468+00', 'Emigrant''s Letter, The', 1961, '');
INSERT INTO 'tune' VALUES (588, NULL, '2012-01-20 12:54:22.098193+00', 'Glasgow Highlanders, The', 9999, '');
INSERT INTO 'tune' VALUES (3970, NULL, '2012-01-20 12:54:33.192177+00', 'Jeanie''s Strathspey', 1887, '');
INSERT INTO 'tune' VALUES (3971, NULL, '2012-01-20 12:54:33.195072+00', 'Jean Sim''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (3972, NULL, '2012-01-20 12:54:33.198003+00', 'Alesund Strathspey, The', 467, '');
INSERT INTO 'tune' VALUES (3973, NULL, '2012-01-20 12:54:33.20095+00', 'Don''t Go Below F', 848, '');
INSERT INTO 'tune' VALUES (3974, NULL, '2012-01-20 12:54:33.203884+00', 'Silver Wedding Jig, The', 9998, '');
INSERT INTO 'tune' VALUES (3975, NULL, '2012-01-20 12:54:33.20682+00', 'Miss Karen Pilcher', 1582, '');
INSERT INTO 'tune' VALUES (3976, NULL, '2012-01-20 12:54:33.209774+00', 'Captain Ridley''s Quickstep', 9999, '');
INSERT INTO 'tune' VALUES (3977, NULL, '2012-01-20 12:54:33.212708+00', 'Jim Bruce', 9998, '');
INSERT INTO 'tune' VALUES (3978, NULL, '2012-01-20 12:54:33.215666+00', 'Jim McKenzie''s Rant', 1607, '');
INSERT INTO 'tune' VALUES (12011, '2012-02-06 11:49:31.32777+00', '2012-02-06 11:49:31.327781+00', 'Ancrum Brig', 1580, '');
INSERT INTO 'tune' VALUES (12034, '2012-02-07 10:39:18.580432+00', '2012-02-07 10:39:18.580443+00', 'Ann and Alex Smith''s Ruby Wedding', 1591, '');
INSERT INTO 'tune' VALUES (12108, '2012-06-12 14:25:03.830656+00', '2012-06-12 14:25:03.830667+00', 'Chiltern Chase', 3220, '');
INSERT INTO 'tune' VALUES (12178, '2012-06-13 08:59:24.499252+00', '2012-06-13 08:59:24.499263+00', 'Silver Threepenny, The', 1502, '');
INSERT INTO 'tune' VALUES (12189, '2012-06-17 15:14:02.846165+00', '2012-06-17 15:14:02.846175+00', 'Little Donald in the Pigpen', 9999, '');
INSERT INTO 'tune' VALUES (587, NULL, '2012-11-29 07:59:45.775024+00', 'Silver City, The', 1561, '');
INSERT INTO 'tune' VALUES (12254, '2012-12-28 13:47:20.891902+00', '2012-12-28 13:47:20.891913+00', 'Lucy Sumsion', 1596, '');
INSERT INTO 'tune' VALUES (12296, '2013-01-02 14:40:03.551088+00', '2013-01-02 17:00:58.376935+00', 'Beaver Lake Breakdown', 3798, '');
INSERT INTO 'tune' VALUES (12331, '2013-01-03 08:06:53.583614+00', '2013-01-03 08:06:53.583625+00', 'Conal an dranndain', 9999, '');
INSERT INTO 'tune' VALUES (12341, '2013-01-03 09:38:03.588829+00', '2013-01-03 09:38:03.58884+00', 'Jimmy Allan', 9999, '');
INSERT INTO 'tune' VALUES (12345, '2013-01-03 10:02:21.901676+00', '2013-01-03 10:02:21.901687+00', 'John Hunt''s Welcome to Skipness', 1580, '');
INSERT INTO 'tune' VALUES (589, NULL, '2012-01-20 12:54:22.102207+00', 'Glasgow Hornpipe', 2145, '');
INSERT INTO 'tune' VALUES (610, NULL, '2012-01-20 12:54:22.185413+00', 'Golden Pheasant, The', 9999, '');
INSERT INTO 'tune' VALUES (3979, NULL, '2012-01-20 12:54:33.218595+00', 'Mrs Orlandi''s Jig', 1558, '');
INSERT INTO 'tune' VALUES (590, NULL, '2012-01-20 12:54:22.106202+00', 'Glasgow Peggy', 9999, '');
INSERT INTO 'tune' VALUES (591, NULL, '2012-01-20 12:54:22.110195+00', 'Glasgow Week in Hamburg', 1819, '');
INSERT INTO 'tune' VALUES (3980, NULL, '2012-01-20 12:54:33.22159+00', 'Jimmy Shankland', 1619, '');
INSERT INTO 'tune' VALUES (592, NULL, '2012-01-20 12:54:22.114165+00', 'Glen Brae', 9998, '');
INSERT INTO 'tune' VALUES (593, NULL, '2012-01-20 12:54:22.1182+00', 'Glen Cottage', 1512, '');
INSERT INTO 'tune' VALUES (612, NULL, '2012-01-20 12:54:22.193998+00', 'Etta Gibson', 9998, '');
INSERT INTO 'tune' VALUES (3981, NULL, '2012-01-20 12:54:33.224838+00', 'Jimmy Fyfe''s Medley', 1463, '');
INSERT INTO 'tune' VALUES (594, NULL, '2012-01-20 12:54:22.122515+00', 'Glen Grant', 1807, '');
INSERT INTO 'tune' VALUES (595, NULL, '2012-01-20 12:54:22.126535+00', 'Glen Lyon''s Rant', 9998, '');
INSERT INTO 'tune' VALUES (613, NULL, '2012-01-20 12:54:22.197837+00', 'Goodnight and Joy be With You', 9999, '');
INSERT INTO 'tune' VALUES (3982, NULL, '2012-01-20 12:54:33.227798+00', 'Country Ayr', 249, '');
INSERT INTO 'tune' VALUES (596, NULL, '2012-01-20 12:54:22.13058+00', 'Glen Nevis Barn Dance', 1550, '');
INSERT INTO 'tune' VALUES (597, NULL, '2012-01-20 12:54:22.13462+00', 'Glen Ogle', 9999, '');
INSERT INTO 'tune' VALUES (614, NULL, '2012-01-20 12:54:22.201669+00', 'Gordon B. Cosh', 1573, '');
INSERT INTO 'tune' VALUES (3983, NULL, '2012-01-20 12:54:33.230751+00', 'J. McInnes Esq.', 9999, '');
INSERT INTO 'tune' VALUES (598, NULL, '2012-01-20 12:54:22.13862+00', 'Glenburnie Rant, The', 1518, '');
INSERT INTO 'tune' VALUES (12054, '2012-05-04 19:00:18.964874+00', '2013-08-19 12:00:20.497952+00', 'Magnum Hornpipe, The', 1502, '');
INSERT INTO 'tune' VALUES (599, NULL, '2012-01-20 12:54:22.142493+00', 'Glencoe', 1512, '');
INSERT INTO 'tune' VALUES (615, NULL, '2012-01-20 12:54:22.205497+00', 'Gordon Young', 1576, '');
INSERT INTO 'tune' VALUES (3984, NULL, '2012-01-20 12:54:33.233682+00', 'Joe MacKenzie', 2406, '');
INSERT INTO 'tune' VALUES (600, NULL, '2012-01-20 12:54:22.14667+00', 'Glendarroch', 1647, '');
INSERT INTO 'tune' VALUES (601, NULL, '2012-01-20 12:54:22.150523+00', 'Glendaruel Highlanders, The', 1666, '');
INSERT INTO 'tune' VALUES (616, NULL, '2012-01-20 12:54:22.209328+00', 'Gowan Strathspey, The', 1464, '');
INSERT INTO 'tune' VALUES (3985, NULL, '2012-01-20 12:54:33.236626+00', 'Jock Caskie''s Reel', 1558, '');
INSERT INTO 'tune' VALUES (602, NULL, '2012-01-20 12:54:22.154337+00', 'Glenfiddich', 1516, '');
INSERT INTO 'tune' VALUES (603, NULL, '2012-01-20 12:54:22.158237+00', 'Glengary', 2142, '');
INSERT INTO 'tune' VALUES (617, NULL, '2012-01-20 12:54:22.213187+00', 'P/M William Gray''s Farewell to the City of Glasgow Police', 2332, '');
INSERT INTO 'tune' VALUES (3986, NULL, '2012-01-20 12:54:33.239604+00', 'Jog On', 9998, '');
INSERT INTO 'tune' VALUES (604, NULL, '2012-01-20 12:54:22.162044+00', 'Glengrant', 1512, '');
INSERT INTO 'tune' VALUES (605, NULL, '2012-01-20 12:54:22.165866+00', 'Glenhurst Reel, The', 1869, '');
INSERT INTO 'tune' VALUES (618, NULL, '2012-01-20 12:54:22.217483+00', 'Grace Brown''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (3987, NULL, '2012-01-20 12:54:33.242589+00', 'Johnny MacLeod''s Reel', 1890, '');
INSERT INTO 'tune' VALUES (606, NULL, '2012-01-20 12:54:22.170102+00', 'Go to the Devil and Shake Yourself', 9998, '');
INSERT INTO 'tune' VALUES (607, NULL, '2012-01-20 12:54:22.17393+00', 'Mirrie Boys O Greenland, Da', 1623, '');
INSERT INTO 'tune' VALUES (619, NULL, '2012-01-20 12:54:22.221316+00', 'Graeme''s Reel', 1709, '');
INSERT INTO 'tune' VALUES (3988, NULL, '2012-01-20 12:54:33.245541+00', 'John''s Delight', 1538, '');
INSERT INTO 'tune' VALUES (609, NULL, '2012-01-20 12:54:22.181588+00', 'Golden Jubilee Reel, The', 1502, '');
INSERT INTO 'tune' VALUES (620, NULL, '2012-01-20 12:54:22.225137+00', 'Graham Hamilton of Glenwood', 1653, '');
INSERT INTO 'tune' VALUES (3989, NULL, '2012-01-20 12:54:33.248699+00', 'Jackie Johnstone', 1668, '');
INSERT INTO 'tune' VALUES (583, NULL, '2016-06-03 13:56:31.263351+00', 'Gisela Koehne''s Welcome to Frankfurt', 228, '');
INSERT INTO 'tune' VALUES (611, NULL, '2017-10-20 15:21:03.572122+00', 'Good Hearted Glasgow', 1871, '');
INSERT INTO 'tune' VALUES (622, NULL, '2012-01-20 12:54:22.232852+00', 'Grant''s Rant, The', 9999, '');
INSERT INTO 'tune' VALUES (3990, NULL, '2012-01-20 12:54:33.25165+00', 'Borden', 210, '');
INSERT INTO 'tune' VALUES (623, NULL, '2012-01-20 12:54:22.236707+00', 'Grant''s Reel', 453, '');
INSERT INTO 'tune' VALUES (3991, NULL, '2012-01-20 12:54:33.254584+00', 'Jo''s Reel', 1754, '');
INSERT INTO 'tune' VALUES (626, NULL, '2012-01-20 12:54:22.248635+00', 'Greenholm', 9999, '');
INSERT INTO 'tune' VALUES (627, NULL, '2012-01-20 12:54:22.252623+00', 'Greig''s Pipes', 1732, '');
INSERT INTO 'tune' VALUES (3992, NULL, '2012-01-20 12:54:33.257524+00', 'My Ain Lassie', 9999, '');
INSERT INTO 'tune' VALUES (628, NULL, '2012-01-20 12:54:22.256446+00', 'Grinder''s Hornpipe, The', 1799, '');
INSERT INTO 'tune' VALUES (629, NULL, '2012-01-20 12:54:22.260368+00', 'Growling Old Woman, The', 9999, '');
INSERT INTO 'tune' VALUES (630, NULL, '2012-01-20 12:54:22.264612+00', 'Guid Luck Go wi'' Ye', 1558, '');
INSERT INTO 'tune' VALUES (631, NULL, '2012-01-20 12:54:22.268455+00', 'Guidman of Balangigh, The', 9999, '');
INSERT INTO 'tune' VALUES (3993, NULL, '2012-01-20 12:54:33.26047+00', 'Solomon Levi', 9998, '');
INSERT INTO 'tune' VALUES (632, NULL, '2012-01-20 12:54:22.272316+00', 'Guisborough Lassies', 536, '');
INSERT INTO 'tune' VALUES (3997, NULL, '2013-02-15 13:01:33.355183+00', 'Beattys, The', 1607, '');
INSERT INTO 'tune' VALUES (634, NULL, '2012-01-20 12:54:22.279972+00', 'Gypsy Laddie, The', 9998, '');
INSERT INTO 'tune' VALUES (3994, NULL, '2012-01-20 12:54:33.263384+00', 'Jovial Beggars, The', 9998, '');
INSERT INTO 'tune' VALUES (635, NULL, '2012-01-20 12:54:22.283804+00', 'H.L.I. Crossing the Line', 9998, '');
INSERT INTO 'tune' VALUES (636, NULL, '2012-01-20 12:54:22.287997+00', 'Haddo House', 1607, '');
INSERT INTO 'tune' VALUES (637, NULL, '2012-01-20 12:54:22.291885+00', 'Haig of Bemersyde', 1502, '');
INSERT INTO 'tune' VALUES (3995, NULL, '2012-01-20 12:54:33.266285+00', 'Joy After Sorrow', 9998, '');
INSERT INTO 'tune' VALUES (638, NULL, '2012-01-20 12:54:22.295717+00', 'Half and Half', 1329, '');
INSERT INTO 'tune' VALUES (639, NULL, '2012-01-20 12:54:22.299556+00', 'Halloween', 1587, '');
INSERT INTO 'tune' VALUES (640, NULL, '2012-01-20 12:54:22.303504+00', 'Hame Came Our Gudeman', 9999, '');
INSERT INTO 'tune' VALUES (3996, NULL, '2012-01-20 12:54:33.269701+00', 'Three Sea Captains', 9999, '');
INSERT INTO 'tune' VALUES (3998, NULL, '2012-01-20 12:54:33.275556+00', 'Kelsterne Gardens', 9998, '');
INSERT INTO 'tune' VALUES (3999, NULL, '2012-01-20 12:54:33.278457+00', 'Kendall House', 9998, '');
INSERT INTO 'tune' VALUES (4000, NULL, '2012-01-20 12:54:33.281362+00', 'James Oliver of Howgill Cottage', 1593, '');
INSERT INTO 'tune' VALUES (4001, NULL, '2012-01-20 12:54:33.284273+00', 'Kensington Court', 9998, '');
INSERT INTO 'tune' VALUES (4002, NULL, '2012-01-20 12:54:33.301149+00', 'Chester Castle', 1587, '');
INSERT INTO 'tune' VALUES (4003, NULL, '2012-01-20 12:54:33.30426+00', 'Kincaldrun''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (4004, NULL, '2012-01-20 12:54:33.307225+00', 'King of the Fairies, The', 9999, '');
INSERT INTO 'tune' VALUES (4005, NULL, '2012-01-20 12:54:33.310142+00', 'Bridge of Garry, The', 1810, '');
INSERT INTO 'tune' VALUES (4006, NULL, '2012-01-20 12:54:33.313059+00', 'Bed o'' Flowers', 9998, '');
INSERT INTO 'tune' VALUES (4007, NULL, '2012-01-20 12:54:33.316007+00', 'Kinnegad Jig, The', 9999, '');
INSERT INTO 'tune' VALUES (4008, NULL, '2012-01-20 12:54:33.319045+00', 'Kitchen Maid, The', 9998, '');
INSERT INTO 'tune' VALUES (4009, NULL, '2012-01-20 12:54:33.322028+00', 'Isobel Murray', 1764, '');
INSERT INTO 'tune' VALUES (4010, NULL, '2012-01-20 12:54:33.32496+00', 'Knockendarroch', 1607, '');
INSERT INTO 'tune' VALUES (4011, NULL, '2012-01-20 12:54:33.32813+00', 'Knowles Park', 9998, '');
INSERT INTO 'tune' VALUES (4012, NULL, '2012-01-20 12:54:33.331094+00', 'Quiet Man, The', 1878, '');
INSERT INTO 'tune' VALUES (4013, NULL, '2012-01-20 12:54:33.334007+00', 'Maggie''s Jigg', 1780, '');
INSERT INTO 'tune' VALUES (4014, NULL, '2012-01-20 12:54:33.336948+00', 'Lady Belhaven''s Delight', 1518, '');
INSERT INTO 'tune' VALUES (4015, NULL, '2012-01-20 12:54:33.340063+00', 'Lady C. Bruce''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (4016, NULL, '2012-01-20 12:54:33.343047+00', 'Lady Friend', 837, '');
INSERT INTO 'tune' VALUES (12012, '2012-02-06 11:50:22.343584+00', '2012-02-06 11:50:22.343595+00', 'Moggy, The', 1580, '');
INSERT INTO 'tune' VALUES (12035, '2012-02-07 10:40:16.443619+00', '2012-02-07 10:40:16.443629+00', 'Miss Veda Jane Stephen''s Reel', 1591, '');
INSERT INTO 'tune' VALUES (12055, '2012-05-04 19:00:50.495308+00', '2012-05-04 19:00:50.495319+00', 'Hall of Mirrors', 1502, '');
INSERT INTO 'tune' VALUES (12095, '2012-05-31 08:19:36.060708+00', '2012-05-31 08:19:36.060719+00', 'Marian Anderson''s Reel', 3683, '');
INSERT INTO 'tune' VALUES (12190, '2012-06-17 15:14:47.12301+00', '2012-06-17 15:14:47.123022+00', 'Good Morning to Your Nightcap', 9999, '');
INSERT INTO 'tune' VALUES (12255, '2012-12-28 13:51:20.887661+00', '2012-12-28 13:51:20.887672+00', 'Willie Hunter of Lerwick', 2912, '');
INSERT INTO 'tune' VALUES (12297, '2013-01-02 14:41:24.588206+00', '2013-01-02 17:04:27.452296+00', 'Snowman''s Breakdown, The', 3798, '');
INSERT INTO 'tune' VALUES (12332, '2013-01-03 08:07:52.882249+00', '2013-01-03 08:07:52.88226+00', 'Hardie''s Triumph', 1580, '');
INSERT INTO 'tune' VALUES (12342, '2013-01-03 09:43:27.997633+00', '2013-01-03 09:43:27.997644+00', 'Whittingham Rant, The', 1580, '');
INSERT INTO 'tune' VALUES (12346, '2013-01-03 10:06:10.379435+00', '2013-01-03 10:06:10.379446+00', 'New Hebridean Waltz, The', 3058, '');
INSERT INTO 'tune' VALUES (12352, '2013-01-03 11:03:37.201781+00', '2013-01-03 11:03:37.201793+00', 'Night That Miss Cooney Eloped, The', 1961, '');
INSERT INTO 'tune' VALUES (12359, '2013-01-04 14:53:20.839556+00', '2013-01-04 14:53:20.839568+00', 'Cargil', 1714, 'Mentioned as tune 2 on the original leaflet for "The Queen''s Jubilee".');
INSERT INTO 'tune' VALUES (641, NULL, '2012-01-20 12:54:22.307343+00', 'Hame o'' Mine', 9998, '');
INSERT INTO 'tune' VALUES (663, NULL, '2012-01-20 12:54:22.39357+00', 'Heart''s Desire', 1985, '');
INSERT INTO 'tune' VALUES (4017, NULL, '2012-01-20 12:54:33.345975+00', 'Lady George Murray''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (642, NULL, '2012-01-20 12:54:22.311668+00', '42nds March to Kerbeckan', 1570, '');
INSERT INTO 'tune' VALUES (643, NULL, '2012-01-20 12:54:22.315626+00', 'Hamilton Races', 1518, '');
INSERT INTO 'tune' VALUES (664, NULL, '2012-01-20 12:54:22.397577+00', 'Heather Hills', 1554, '');
INSERT INTO 'tune' VALUES (4018, NULL, '2012-01-20 12:54:33.349002+00', 'My Ain Folk', 9999, '');
INSERT INTO 'tune' VALUES (644, NULL, '2012-01-20 12:54:22.319453+00', 'Wade''s Welcome to Inverness', 2270, '');
INSERT INTO 'tune' VALUES (645, NULL, '2012-01-20 12:54:22.323276+00', 'Hamish Smith', 1576, '');
INSERT INTO 'tune' VALUES (665, NULL, '2012-01-20 12:54:22.401894+00', 'Heather Mixture Jig, The', 1558, '');
INSERT INTO 'tune' VALUES (4019, NULL, '2012-01-20 12:54:33.356642+00', 'One Spare Kiss', 1834, '');
INSERT INTO 'tune' VALUES (646, NULL, '2012-01-20 12:54:22.327105+00', 'Happy Returns', 9998, '');
INSERT INTO 'tune' VALUES (647, NULL, '2012-01-20 12:54:22.330923+00', 'Happy We''ll Be', 9999, '');
INSERT INTO 'tune' VALUES (666, NULL, '2012-01-20 12:54:22.405826+00', 'Heather Mixture Rant', 9998, '');
INSERT INTO 'tune' VALUES (4020, NULL, '2012-01-20 12:54:33.360034+00', 'Reel of Corse, The', 9998, '');
INSERT INTO 'tune' VALUES (648, NULL, '2012-01-20 12:54:22.335048+00', 'Happy We''ve Been A'' Thegither', 9999, '');
INSERT INTO 'tune' VALUES (649, NULL, '2012-01-20 12:54:22.33898+00', 'Harmonica, The', 9999, '');
INSERT INTO 'tune' VALUES (667, NULL, '2012-01-20 12:54:22.410446+00', 'Heather Mixture Two-Step, The', 1558, '');
INSERT INTO 'tune' VALUES (4021, NULL, '2012-01-20 12:54:33.363337+00', 'Lady Pentweazle', 9998, '');
INSERT INTO 'tune' VALUES (650, NULL, '2012-01-20 12:54:22.342794+00', 'Harvest Home', 9999, '');
INSERT INTO 'tune' VALUES (651, NULL, '2012-01-20 12:54:22.346632+00', 'Calton Hill', 1558, '');
INSERT INTO 'tune' VALUES (668, NULL, '2012-01-20 12:54:22.414486+00', 'Heather on the Mountain', 1816, '');
INSERT INTO 'tune' VALUES (4022, NULL, '2012-01-20 12:54:33.366518+00', 'MacPherson''s Rant', 2139, '');
INSERT INTO 'tune' VALUES (652, NULL, '2012-01-20 12:54:22.350434+00', 'Harvest Time', 9999, '');
INSERT INTO 'tune' VALUES (653, NULL, '2012-01-20 12:54:22.354271+00', 'Haste ye back', 1575, '');
INSERT INTO 'tune' VALUES (841, NULL, '2012-01-20 12:54:22.96124+00', 'Kay''s Delight', 1720, '');
INSERT INTO 'tune' VALUES (669, NULL, '2012-01-20 12:54:22.418763+00', 'Hebridean Milking Song', 9999, '');
INSERT INTO 'tune' VALUES (654, NULL, '2012-01-20 12:54:22.358098+00', 'Haughs o'' Cromdale', 9999, '');
INSERT INTO 'tune' VALUES (655, NULL, '2012-01-20 12:54:22.362345+00', 'Quarryman, The', 1538, '');
INSERT INTO 'tune' VALUES (670, NULL, '2012-01-20 12:54:22.422659+00', 'Heights of Alma, The', 9999, '');
INSERT INTO 'tune' VALUES (656, NULL, '2012-01-20 12:54:22.366176+00', 'Haunt of the Gnomes, The', 1512, '');
INSERT INTO 'tune' VALUES (657, NULL, '2012-01-20 12:54:22.370022+00', 'Hayfield House', 1623, '');
INSERT INTO 'tune' VALUES (671, NULL, '2012-01-20 12:54:22.426543+00', 'Helen Black of Inveran', 1550, '');
INSERT INTO 'tune' VALUES (658, NULL, '2012-01-20 12:54:22.373875+00', 'Sally Alison Taylor', 1502, '');
INSERT INTO 'tune' VALUES (659, NULL, '2012-01-20 12:54:22.377708+00', 'Hazelbank', 1607, '');
INSERT INTO 'tune' VALUES (672, NULL, '2012-01-20 12:54:22.430818+00', 'Hen''s March over the Midden, The', 9998, '');
INSERT INTO 'tune' VALUES (4026, NULL, '2012-01-20 12:54:33.37962+00', 'Dr Alexander of Balmerino', 9999, '');
INSERT INTO 'tune' VALUES (660, NULL, '2012-01-20 12:54:22.381587+00', 'He''s aye a kissin'' me', 2642, '');
INSERT INTO 'tune' VALUES (661, NULL, '2012-01-20 12:54:22.385829+00', 'He''s o''er the hills that I lo''e dear', 9999, '');
INSERT INTO 'tune' VALUES (673, NULL, '2012-01-20 12:54:22.435335+00', 'Here''s a Health to ane I lo''e dear', 9999, '');
INSERT INTO 'tune' VALUES (4027, NULL, '2012-01-20 12:54:33.383135+00', 'Laird of Oxgangs, The', 9998, '');
INSERT INTO 'tune' VALUES (662, NULL, '2012-01-20 12:54:22.389732+00', 'Health and Joy be with You', 9999, '');
INSERT INTO 'tune' VALUES (4028, NULL, '2012-01-20 12:54:33.386389+00', 'George''s Reel', 1329, '');
INSERT INTO 'tune' VALUES (674, NULL, '2012-01-20 12:54:22.439243+00', 'Juniper Jig', 1538, '');
INSERT INTO 'tune' VALUES (675, NULL, '2012-01-20 12:54:22.443135+00', 'Here''s to the Health', 2292, '');
INSERT INTO 'tune' VALUES (4029, NULL, '2012-01-20 12:54:33.3896+00', 'Mrs MacLeod of MacLeod''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (676, NULL, '2012-01-20 12:54:22.447183+00', 'Loch Carron', 564, '');
INSERT INTO 'tune' VALUES (4030, NULL, '2012-01-20 12:54:33.392785+00', 'Charlie Todd''s Strathspey', 1595, '');
INSERT INTO 'tune' VALUES (677, NULL, '2012-01-20 12:54:22.451318+00', 'Hereford Hornpipe, The', 1815, '');
INSERT INTO 'tune' VALUES (4024, NULL, '2015-10-30 15:43:24.214418+00', 'Primrose Bay', 93, '');
INSERT INTO 'tune' VALUES (4031, NULL, '2012-01-20 12:54:33.396053+00', 'Lancaster Lasses', 9998, '');
INSERT INTO 'tune' VALUES (678, NULL, '2012-01-20 12:54:22.455572+00', 'Birsay Beach', 9998, '');
INSERT INTO 'tune' VALUES (679, NULL, '2012-01-20 12:54:22.459732+00', 'Hey to Cupar', 1518, '');
INSERT INTO 'tune' VALUES (680, NULL, '2012-01-20 12:54:22.46381+00', 'Hi Kiwi !', 1836, '');
INSERT INTO 'tune' VALUES (681, NULL, '2012-01-20 12:54:22.467876+00', 'High Bridge, The', 1766, '');
INSERT INTO 'tune' VALUES (4032, NULL, '2012-01-20 12:54:33.399422+00', 'Anchor Hornpipe, The', 1505, '');
INSERT INTO 'tune' VALUES (682, NULL, '2012-01-20 12:54:22.471959+00', 'High Level Hornpipe, The', 1625, '');
INSERT INTO 'tune' VALUES (683, NULL, '2012-01-20 12:54:22.476061+00', 'High Lodge, The', 1502, '');
INSERT INTO 'tune' VALUES (684, NULL, '2012-01-20 12:54:22.48057+00', 'High Peak', 1725, '');
INSERT INTO 'tune' VALUES (4033, NULL, '2012-01-20 12:54:33.402776+00', 'Land O'' MacLeod, The', 9998, '');
INSERT INTO 'tune' VALUES (685, NULL, '2012-01-20 12:54:22.48465+00', 'High Road to Linton, The', 1517, '');
INSERT INTO 'tune' VALUES (686, NULL, '2012-01-20 12:54:22.488731+00', 'Highland Donald', 9999, '');
INSERT INTO 'tune' VALUES (687, NULL, '2012-01-20 12:54:22.492823+00', 'Highland Laddie', 9999, '');
INSERT INTO 'tune' VALUES (688, NULL, '2012-01-20 12:54:22.496882+00', 'Highland Lassie', 1525, '');
INSERT INTO 'tune' VALUES (689, NULL, '2012-01-20 12:54:22.500934+00', 'Highland Piper''s Fancy, The', 9998, '');
INSERT INTO 'tune' VALUES (690, NULL, '2012-01-20 12:54:22.505501+00', 'Highland Reel', 9998, '');
INSERT INTO 'tune' VALUES (4035, NULL, '2012-01-20 12:54:33.409398+00', 'Melita', 9998, '');
INSERT INTO 'tune' VALUES (691, NULL, '2012-01-20 12:54:22.509572+00', 'Believe Me, If All those Enduring Young Charms', 9999, '');
INSERT INTO 'tune' VALUES (4036, NULL, '2012-01-20 12:54:33.412671+00', '10,000 Miles Away', 9998, '');
INSERT INTO 'tune' VALUES (4037, NULL, '2012-01-20 12:54:33.415819+00', 'Wee Glasgow Waltz, The', 1773, '');
INSERT INTO 'tune' VALUES (4038, NULL, '2012-01-20 12:54:33.419088+00', 'Miss Pat Chalmers', 9998, '');
INSERT INTO 'tune' VALUES (4039, NULL, '2012-01-20 12:54:33.42229+00', 'Mormond Braes', 9999, '');
INSERT INTO 'tune' VALUES (4040, NULL, '2012-01-20 12:54:33.425619+00', 'Mrs Hay', 9998, '');
INSERT INTO 'tune' VALUES (4041, NULL, '2012-01-20 12:54:33.429001+00', 'Tom''s Reel', 275, '');
INSERT INTO 'tune' VALUES (4042, NULL, '2012-01-20 12:54:33.432353+00', 'Queenie of Larkhill', 1558, '');
INSERT INTO 'tune' VALUES (4043, NULL, '2012-01-20 12:54:33.435535+00', 'Belfast Linen', 9999, '');
INSERT INTO 'tune' VALUES (12013, '2012-02-06 11:51:11.830419+00', '2012-02-06 11:51:11.830429+00', 'Bessie Ross', 1543, '');
INSERT INTO 'tune' VALUES (12036, '2012-02-07 10:44:53.936212+00', '2012-02-07 10:44:53.936223+00', 'Granny Nicol', 1591, '');
INSERT INTO 'tune' VALUES (12096, '2012-05-31 08:21:26.924847+00', '2012-05-31 08:21:26.924858+00', 'John Huband''s Reel', 1605, '');
INSERT INTO 'tune' VALUES (692, NULL, '2012-06-17 14:37:18.313859+00', 'Highland Whisky', 1518, '');
INSERT INTO 'tune' VALUES (12191, '2012-06-17 15:16:07.168708+00', '2012-06-17 15:16:07.168719+00', 'Mutt''s Favorite', 1633, '');
INSERT INTO 'tune' VALUES (4023, NULL, '2012-10-10 21:48:53.748739+00', 'Laggan Burn, The', 9998, '');
INSERT INTO 'tune' VALUES (12256, '2012-12-28 14:08:18.141879+00', '2012-12-28 14:08:18.141889+00', 'Sir John A MacDonald', 1602, '');
INSERT INTO 'tune' VALUES (12298, '2013-01-02 14:51:46.501981+00', '2013-01-02 14:51:46.501992+00', 'Mrs McLeod of Blareoch', 9999, '');
INSERT INTO 'tune' VALUES (4129, NULL, '2012-01-20 12:54:33.757136+00', 'Chorus Jig, The', 9999, '');
INSERT INTO 'tune' VALUES (12333, '2013-01-03 08:26:21.938853+00', '2013-01-03 08:26:21.938864+00', 'Carn Gorm to Blue Ridge', 1539, '');
INSERT INTO 'tune' VALUES (12347, '2013-01-03 10:17:56.481656+00', '2013-01-03 10:17:56.481668+00', 'Duncan and Jean Shaw of Skipness', 1580, '');
INSERT INTO 'tune' VALUES (12353, '2013-01-03 11:11:20.766999+00', '2013-01-03 11:11:20.767011+00', 'Howes of Bucksburn', 10693, '');
INSERT INTO 'tune' VALUES (12360, '2013-01-04 15:44:50.725963+00', '2013-01-04 15:44:50.725974+00', 'Sweet Caroliney', 3484, '');
INSERT INTO 'tune' VALUES (693, NULL, '2012-01-20 12:54:22.517275+00', 'Highlandman Kissed his Mother, The', 1701, '');
INSERT INTO 'tune' VALUES (714, NULL, '2012-01-20 12:54:22.58498+00', 'House of Cairnfield, The', 1516, '');
INSERT INTO 'tune' VALUES (4044, NULL, '2012-01-20 12:54:33.438938+00', 'Lassies of Belfast', 1898, '');
INSERT INTO 'tune' VALUES (694, NULL, '2012-01-20 12:54:22.521118+00', 'Highlandman''s Umbrella, The', 1701, '');
INSERT INTO 'tune' VALUES (695, NULL, '2012-01-20 12:54:22.524951+00', 'Hiking Song, The', 1620, '');
INSERT INTO 'tune' VALUES (715, NULL, '2012-01-20 12:54:22.587914+00', 'House of Cluny, The', 1516, '');
INSERT INTO 'tune' VALUES (4045, NULL, '2012-01-20 12:54:33.442291+00', 'Lass of Richmond Hill, The', 9999, '');
INSERT INTO 'tune' VALUES (696, NULL, '2012-01-20 12:54:22.528979+00', 'Hill o'' Nigg, The', 1512, '');
INSERT INTO 'tune' VALUES (697, NULL, '2012-01-20 12:54:22.531972+00', 'Hills of Glenorchy, The', 9999, '');
INSERT INTO 'tune' VALUES (716, NULL, '2012-01-20 12:54:22.590801+00', 'House of Gray', 9999, '');
INSERT INTO 'tune' VALUES (4046, NULL, '2012-01-20 12:54:33.44565+00', 'Girl at the Ballyclare Fair, The', 9999, '');
INSERT INTO 'tune' VALUES (698, NULL, '2012-01-20 12:54:22.534868+00', 'Hills of Lorne, The', 1722, '');
INSERT INTO 'tune' VALUES (699, NULL, '2012-01-20 12:54:22.540615+00', 'Hoddam Castle', 9999, '');
INSERT INTO 'tune' VALUES (717, NULL, '2012-01-20 12:54:22.59368+00', 'Household Brigade', 1567, '');
INSERT INTO 'tune' VALUES (4047, NULL, '2012-01-20 12:54:33.449173+00', 'Left Handed Tushker, The', 1623, '');
INSERT INTO 'tune' VALUES (700, NULL, '2012-01-20 12:54:22.543586+00', 'Hogmanay Jig', 1533, '');
INSERT INTO 'tune' VALUES (701, NULL, '2012-01-20 12:54:22.546471+00', 'Holly Bush, The', 9999, '');
INSERT INTO 'tune' VALUES (718, NULL, '2012-01-20 12:54:22.596565+00', 'How Lovely are thy Dwellings', 1431, '');
INSERT INTO 'tune' VALUES (4048, NULL, '2012-01-20 12:54:33.452808+00', 'Leg of a Duck, The', 1910, '');
INSERT INTO 'tune' VALUES (702, NULL, '2012-01-20 12:54:22.549411+00', 'Holyrood House', 1797, '');
INSERT INTO 'tune' VALUES (703, NULL, '2012-01-20 12:54:22.552704+00', 'Holystone, The', 1709, '');
INSERT INTO 'tune' VALUES (719, NULL, '2012-01-20 12:54:22.599924+00', 'Howard Steventon''s Strathspey', 1407, '');
INSERT INTO 'tune' VALUES (4049, NULL, '2012-01-20 12:54:33.456371+00', 'Leprechaun, The', 1872, '');
INSERT INTO 'tune' VALUES (704, NULL, '2012-01-20 12:54:22.555637+00', 'Hon Mrs Campbell (of Lochnell)', 1519, '');
INSERT INTO 'tune' VALUES (705, NULL, '2012-01-20 12:54:22.558538+00', 'Hon Mrs Fraser', 1519, '');
INSERT INTO 'tune' VALUES (720, NULL, '2012-01-20 12:54:22.602902+00', 'Howard''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (4050, NULL, '2012-01-20 12:54:33.459331+00', 'Hon Captain Maitland''s Strathspey', 1518, '');
INSERT INTO 'tune' VALUES (706, NULL, '2012-01-20 12:54:22.561417+00', 'Hon Mrs Maule''s Favourite', 1518, '');
INSERT INTO 'tune' VALUES (707, NULL, '2012-01-20 12:54:22.564315+00', 'Jane of Pintalia Strathspey', 1419, '');
INSERT INTO 'tune' VALUES (721, NULL, '2012-01-20 12:54:22.605803+00', 'Hugh Foss''s Reel', 1607, '');
INSERT INTO 'tune' VALUES (4051, NULL, '2012-01-20 12:54:33.462284+00', 'Paul Wallace', 9998, '');
INSERT INTO 'tune' VALUES (708, NULL, '2012-01-20 12:54:22.567202+00', 'Hoop Her and Gird Her', 9999, '');
INSERT INTO 'tune' VALUES (709, NULL, '2012-01-20 12:54:22.570118+00', 'Hopeful Lover, The', 9999, '');
INSERT INTO 'tune' VALUES (722, NULL, '2012-01-20 12:54:22.608694+00', 'Humber Jumber', 9999, '');
INSERT INTO 'tune' VALUES (4052, NULL, '2012-01-20 12:54:33.46522+00', 'Let''s Meet Again', 1865, '');
INSERT INTO 'tune' VALUES (710, NULL, '2012-01-20 12:54:22.573004+00', 'Hopeless Lover, The', 9998, '');
INSERT INTO 'tune' VALUES (711, NULL, '2012-01-20 12:54:22.576268+00', 'Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (723, NULL, '2012-01-20 12:54:22.611587+00', 'Miss Flora McDonald''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (4053, NULL, '2012-01-20 12:54:33.468398+00', 'Debut', 609, '');
INSERT INTO 'tune' VALUES (712, NULL, '2012-01-20 12:54:22.579193+00', 'Hornpipe Medley', 9998, '');
INSERT INTO 'tune' VALUES (724, NULL, '2012-01-20 12:54:22.614488+00', 'Hundred Pipers, The', 2704, '');
INSERT INTO 'tune' VALUES (4054, NULL, '2012-01-20 12:54:33.471426+00', 'Liberty for the Sailors', 9999, '');
INSERT INTO 'tune' VALUES (725, NULL, '2012-01-20 12:54:22.617386+00', 'Huntsman''s Chorus', 9999, '');
INSERT INTO 'tune' VALUES (726, NULL, '2012-01-20 12:54:22.620276+00', 'Hurdle Race, The', 2154, '');
INSERT INTO 'tune' VALUES (12361, '2013-01-04 15:50:12.962897+00', '2013-01-04 15:50:12.962908+00', 'Dolly Sods', 2977, '');
INSERT INTO 'tune' VALUES (727, NULL, '2012-01-20 12:54:22.623224+00', 'I Love a Lassie', 1663, '');
INSERT INTO 'tune' VALUES (728, NULL, '2012-01-20 12:54:22.626131+00', 'I ha''e laid a Herring in Salt', 1447, '');
INSERT INTO 'tune' VALUES (729, NULL, '2012-01-20 12:54:22.629031+00', 'I left my dearie lying here', 9998, '');
INSERT INTO 'tune' VALUES (4056, NULL, '2012-01-20 12:54:33.477325+00', 'Rosebrook Road', 1329, '');
INSERT INTO 'tune' VALUES (731, NULL, '2012-01-20 12:54:22.634827+00', 'I''ll Never Leave Thee', 9998, '');
INSERT INTO 'tune' VALUES (4057, NULL, '2012-01-20 12:54:33.480248+00', 'Lt. Zachary Hicks R.N.', 1899, '');
INSERT INTO 'tune' VALUES (732, NULL, '2012-01-20 12:54:22.637709+00', 'I''ll mak'' ye fain to follow me', 9999, '');
INSERT INTO 'tune' VALUES (4058, NULL, '2012-01-20 12:54:33.483212+00', 'Hornpipe from Ruddigore', 1900, '');
INSERT INTO 'tune' VALUES (733, NULL, '2012-01-20 12:54:22.640602+00', 'Nut, The', 9998, '');
INSERT INTO 'tune' VALUES (734, NULL, '2012-01-20 12:54:22.643487+00', 'Iain Alexander Nixon', 1576, '');
INSERT INTO 'tune' VALUES (735, NULL, '2012-01-20 12:54:22.64637+00', 'Ian Charles Hamilton', 1653, '');
INSERT INTO 'tune' VALUES (4059, NULL, '2012-01-20 12:54:33.48614+00', 'Peer of Leith, The', 9998, '');
INSERT INTO 'tune' VALUES (736, NULL, '2012-01-20 12:54:22.64959+00', 'Ian Murray''s Reel', 1648, '');
INSERT INTO 'tune' VALUES (737, NULL, '2012-01-20 12:54:22.652534+00', 'Ian Powrie''s Compliments to Willie Hunter', 1551, '');
INSERT INTO 'tune' VALUES (738, NULL, '2012-01-20 12:54:22.655429+00', 'Ian''s Reel', 810, '');
INSERT INTO 'tune' VALUES (12368, '2013-01-04 16:33:29.271546+00', '2013-01-04 16:33:29.271558+00', 'August 19', 10697, '');
INSERT INTO 'tune' VALUES (739, NULL, '2012-01-20 12:54:22.658317+00', 'Scapa Flow', 1525, '');
INSERT INTO 'tune' VALUES (740, NULL, '2012-01-20 12:54:22.66186+00', 'Inchkeith Island', 1501, '');
INSERT INTO 'tune' VALUES (741, NULL, '2012-01-20 12:54:22.664791+00', 'Innes Russell of Perth', 1598, '');
INSERT INTO 'tune' VALUES (4061, NULL, '2012-01-20 12:54:33.492109+00', 'Lilli Burlero', 9998, '');
INSERT INTO 'tune' VALUES (742, NULL, '2012-01-20 12:54:22.667694+00', 'Innes''s Jig', 1458, '');
INSERT INTO 'tune' VALUES (743, NULL, '2012-01-20 12:54:22.670598+00', 'Inverary', 1424, '');
INSERT INTO 'tune' VALUES (744, NULL, '2012-01-20 12:54:22.673494+00', 'Champion, The', 1575, '');
INSERT INTO 'tune' VALUES (4062, NULL, '2012-01-20 12:54:33.495066+00', 'Trip to Bournemouth, A', 1582, '');
INSERT INTO 'tune' VALUES (4063, NULL, '2012-01-20 12:54:33.497984+00', 'Bonnie Lass of Head Lake', 9998, '');
INSERT INTO 'tune' VALUES (4064, NULL, '2012-01-20 12:54:33.500926+00', 'Lincoln', 9998, '');
INSERT INTO 'tune' VALUES (4065, NULL, '2012-01-20 12:54:33.503894+00', 'Linen Cap, The', 9999, '');
INSERT INTO 'tune' VALUES (4066, NULL, '2012-01-20 12:54:33.506823+00', 'MacVicar''s', 1518, '');
INSERT INTO 'tune' VALUES (4067, NULL, '2012-01-20 12:54:33.509751+00', 'Lions International', 1547, '');
INSERT INTO 'tune' VALUES (4068, NULL, '2012-01-20 12:54:33.512704+00', 'Little Dither on the Marsh', 2392, '');
INSERT INTO 'tune' VALUES (4069, NULL, '2012-01-20 12:54:33.516065+00', 'Liverpool Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (12014, '2012-02-06 11:52:13.164141+00', '2012-02-06 11:52:13.164151+00', 'Topsy', 1668, '');
INSERT INTO 'tune' VALUES (12037, '2012-02-07 10:46:35.725777+00', '2012-02-07 10:46:35.725788+00', 'Colin Dewar''s Compliments To Gordon Simpson', 1591, '');
INSERT INTO 'tune' VALUES (12057, '2012-05-04 19:01:51.716468+00', '2012-05-04 19:01:51.716481+00', 'Au Revoir Marie Solange', 1502, '');
INSERT INTO 'tune' VALUES (12111, '2012-06-12 14:26:52.724417+00', '2012-06-12 14:26:52.724428+00', 'Laird o'' MacNab', 9998, '');
INSERT INTO 'tune' VALUES (12192, '2012-06-17 15:16:34.631315+00', '2012-06-17 15:16:34.631326+00', 'Ramnee Ceilidh', 3129, '');
INSERT INTO 'tune' VALUES (4060, NULL, '2012-11-29 07:21:41.906786+00', 'Lights on Lochindaal, The', 10666, '');
INSERT INTO 'tune' VALUES (12257, '2012-12-28 14:09:32.08051+00', '2012-12-28 14:09:32.080521+00', 'Trail Blazers Two Step', 1602, '');
INSERT INTO 'tune' VALUES (12299, '2013-01-02 14:59:24.25421+00', '2013-01-02 14:59:24.254222+00', 'Art Wooton''s Quadrille', 9999, '');
INSERT INTO 'tune' VALUES (12334, '2013-01-03 08:27:12.792247+00', '2013-01-03 08:27:12.792258+00', 'Banjo Branch Fiddle', 1539, '');
INSERT INTO 'tune' VALUES (12348, '2013-01-03 10:18:46.203458+00', '2013-01-03 10:18:46.203469+00', 'Celebration Reel, The', 1580, '');
INSERT INTO 'tune' VALUES (12354, '2013-01-03 11:14:23.009657+00', '2013-01-03 11:14:23.009668+00', 'Duchess of Hamilton''s Quickstep, The', 10694, '');
INSERT INTO 'tune' VALUES (12369, '2013-01-05 16:07:56.133026+00', '2013-01-05 16:07:56.133037+00', 'Blaze Away', 10700, '');
INSERT INTO 'tune' VALUES (12372, '2013-01-05 16:36:42.689843+00', '2013-01-05 16:36:42.689854+00', 'Peerie Alex O Setter', 2253, '');
INSERT INTO 'tune' VALUES (12399, '2013-01-06 14:01:37.277368+00', '2013-01-06 14:01:37.277379+00', 'Miann Cridhe', 9999, '');
INSERT INTO 'tune' VALUES (12400, '2013-01-06 16:46:10.602116+00', '2013-01-06 16:46:10.602128+00', 'Feller From Fortune', 9999, '');
INSERT INTO 'tune' VALUES (12408, '2013-01-06 17:52:15.032088+00', '2013-01-06 17:52:15.032099+00', 'Ellon Castle', 1512, '');
INSERT INTO 'tune' VALUES (12409, '2013-01-06 18:05:39.591551+00', '2013-01-06 18:05:39.591563+00', 'Lark Rising', 210, '');
INSERT INTO 'tune' VALUES (12410, '2013-01-13 00:24:35.243668+00', '2013-01-13 00:24:35.243679+00', 'Combined Effort', 1633, '');
INSERT INTO 'tune' VALUES (12411, '2013-01-16 13:07:52.206829+00', '2013-01-16 13:07:52.206841+00', 'Following in Father''s Footsteps', 10710, '');
INSERT INTO 'tune' VALUES (12415, '2013-01-16 14:13:48.382669+00', '2013-01-16 14:13:48.38268+00', 'Keep Right onto the End of the Road', 1663, '');
INSERT INTO 'tune' VALUES (745, NULL, '2012-01-20 12:54:22.676425+00', 'Inverness Lassies', 9998, '');
INSERT INTO 'tune' VALUES (766, NULL, '2012-01-20 12:54:22.737957+00', 'Jamie Gow, Crathie Bellman', 1632, '');
INSERT INTO 'tune' VALUES (746, NULL, '2012-01-20 12:54:22.679329+00', 'Iona Strathspey, The', 1502, '');
INSERT INTO 'tune' VALUES (4070, NULL, '2012-01-20 12:54:33.519005+00', 'Catherine''s Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (747, NULL, '2012-01-20 12:54:22.682221+00', 'Irish Girls', 9999, '');
INSERT INTO 'tune' VALUES (767, NULL, '2012-01-20 12:54:22.740875+00', 'Janet Robb''s Fancy', 1841, '');
INSERT INTO 'tune' VALUES (748, NULL, '2012-01-20 12:54:22.685124+00', 'Irish Miss', 1457, '');
INSERT INTO 'tune' VALUES (13820, '2018-02-24 03:10:16.212851+00', '2018-02-24 03:10:16.212851+00', 'Capt Jack Murray', 9998, '');
INSERT INTO 'tune' VALUES (749, NULL, '2012-01-20 12:54:22.68802+00', 'Irish Rover, The', 9999, '');
INSERT INTO 'tune' VALUES (768, NULL, '2012-01-20 12:54:22.743769+00', 'Jeannie o'' the Witchin'' E''e', 9999, '');
INSERT INTO 'tune' VALUES (750, NULL, '2012-01-20 12:54:22.690913+00', 'Irish Washerwoman, The', 9999, '');
INSERT INTO 'tune' VALUES (4072, NULL, '2012-01-20 12:54:33.525755+00', 'Lord Byron''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (751, NULL, '2012-01-20 12:54:22.693802+00', 'Irish Wedding, The', 9998, '');
INSERT INTO 'tune' VALUES (769, NULL, '2012-01-20 12:54:22.746749+00', 'Jennifer''s Jig', 1586, '');
INSERT INTO 'tune' VALUES (13821, '2018-02-24 03:13:18.536988+00', '2018-02-24 03:13:18.536988+00', 'Capt P D Wallace', 9998, '');
INSERT INTO 'tune' VALUES (4073, NULL, '2012-01-20 12:54:33.529682+00', 'Rocket Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (753, NULL, '2012-01-20 12:54:22.699996+00', 'Island of Mull, The', 1774, '');
INSERT INTO 'tune' VALUES (770, NULL, '2012-01-20 12:54:22.749768+00', 'Jenny Dang the Weaver', 9999, '');
INSERT INTO 'tune' VALUES (754, NULL, '2012-01-20 12:54:22.702945+00', 'Jack is Yet Alive', 9999, '');
INSERT INTO 'tune' VALUES (4074, NULL, '2012-01-20 12:54:33.533504+00', 'Earl of Eglinton''s Strathspey', 1517, '');
INSERT INTO 'tune' VALUES (755, NULL, '2012-01-20 12:54:22.705838+00', 'Isle of Skye, The', 1518, '');
INSERT INTO 'tune' VALUES (771, NULL, '2012-01-20 12:54:22.752671+00', 'Jenny''s Bawbee', 9999, '');
INSERT INTO 'tune' VALUES (756, NULL, '2012-01-20 12:54:22.708738+00', 'It''s nice to get up in the morning', 1663, '');
INSERT INTO 'tune' VALUES (4075, NULL, '2012-01-20 12:54:33.537313+00', 'Lord Huntly''s Cave', 1512, '');
INSERT INTO 'tune' VALUES (757, NULL, '2012-01-20 12:54:22.711641+00', 'J.B. Milne', 1554, '');
INSERT INTO 'tune' VALUES (772, NULL, '2012-01-20 12:54:22.755559+00', 'Jessie Cruickshank', 1722, '');
INSERT INTO 'tune' VALUES (758, NULL, '2012-01-20 12:54:22.714532+00', 'J.M.Duthie', 1446, '');
INSERT INTO 'tune' VALUES (4076, NULL, '2012-01-20 12:54:33.542608+00', 'March to Aberfoyle', 1610, '');
INSERT INTO 'tune' VALUES (759, NULL, '2012-01-20 12:54:22.717442+00', 'Jack''s Alive', 9999, '');
INSERT INTO 'tune' VALUES (773, NULL, '2012-01-20 12:54:22.758481+00', 'Jessie Smith', 9999, '');
INSERT INTO 'tune' VALUES (760, NULL, '2012-01-20 12:54:22.720337+00', 'Jack''s Delight', 9999, '');
INSERT INTO 'tune' VALUES (4077, NULL, '2012-01-20 12:54:33.546407+00', 'Lord Macpherson of Drumochter', 1616, '');
INSERT INTO 'tune' VALUES (761, NULL, '2012-01-20 12:54:22.723416+00', 'Jackson''s Bottle of Claret', 9999, '');
INSERT INTO 'tune' VALUES (774, NULL, '2012-01-20 12:54:22.761403+00', 'Jig for Joyce, A', 1796, '');
INSERT INTO 'tune' VALUES (762, NULL, '2012-01-20 12:54:22.726325+00', 'Jacky''s Return', 9999, '');
INSERT INTO 'tune' VALUES (4078, NULL, '2012-01-20 12:54:33.550416+00', 'Lord Phoppington', 9998, '');
INSERT INTO 'tune' VALUES (763, NULL, '2012-01-20 12:54:22.729224+00', 'James Forrester Rankine', 1533, '');
INSERT INTO 'tune' VALUES (775, NULL, '2012-01-20 12:54:22.764294+00', 'Jig for Liz, A', 1607, '');
INSERT INTO 'tune' VALUES (764, NULL, '2012-01-20 12:54:22.732134+00', 'James O. Forbes of Corse', 1818, '');
INSERT INTO 'tune' VALUES (4079, NULL, '2012-01-20 12:54:33.554237+00', 'Lord Stormont', 885, '');
INSERT INTO 'tune' VALUES (765, NULL, '2012-01-20 12:54:22.735033+00', 'James Stephen', 1554, '');
INSERT INTO 'tune' VALUES (776, NULL, '2012-01-20 12:54:22.767194+00', 'Jig for Mhairi, A', 9998, '');
INSERT INTO 'tune' VALUES (777, NULL, '2012-01-20 12:54:22.77008+00', 'Jig in G', 9998, '');
INSERT INTO 'tune' VALUES (4080, NULL, '2012-01-20 12:54:33.558038+00', 'Where Hath Scotland Found Her Lance', 9998, '');
INSERT INTO 'tune' VALUES (778, NULL, '2012-01-20 12:54:22.773052+00', 'Jig of Slurs, The', 1699, '');
INSERT INTO 'tune' VALUES (842, NULL, '2012-01-20 12:54:22.964141+00', 'Keel Row, The', 9999, '');
INSERT INTO 'tune' VALUES (779, NULL, '2012-01-20 12:54:22.775967+00', 'Jig wi'' the Snap', 1554, '');
INSERT INTO 'tune' VALUES (780, NULL, '2012-01-20 12:54:22.779413+00', 'Jiggin'' in the Kitchen', 1836, '');
INSERT INTO 'tune' VALUES (4081, NULL, '2012-01-20 12:54:33.561851+00', 'Ena''s Tune', 1901, '');
INSERT INTO 'tune' VALUES (781, NULL, '2012-01-20 12:54:22.782335+00', 'Jigtime Polka, The', 2920, '');
INSERT INTO 'tune' VALUES (782, NULL, '2012-01-20 12:54:22.785231+00', 'Jim Baine', 9999, '');
INSERT INTO 'tune' VALUES (783, NULL, '2012-01-20 12:54:22.788127+00', 'Jim Barrie', 1558, '');
INSERT INTO 'tune' VALUES (4082, NULL, '2012-01-20 12:54:33.566451+00', 'Love''s Triumph', 9998, '');
INSERT INTO 'tune' VALUES (784, NULL, '2012-01-20 12:54:22.79102+00', 'Jim Douglas', 1555, '');
INSERT INTO 'tune' VALUES (4083, NULL, '2012-01-20 12:54:33.570407+00', 'Cripple Creek', 9998, '');
INSERT INTO 'tune' VALUES (785, NULL, '2012-01-20 12:54:22.793911+00', 'Deil Stick Da Minister', 9999, '');
INSERT INTO 'tune' VALUES (786, NULL, '2012-01-20 12:54:22.799094+00', 'Jim McCabe''s Strathspey', 1555, '');
INSERT INTO 'tune' VALUES (787, NULL, '2012-01-20 12:54:22.801995+00', 'Jimmy Harris Jig, The', 1554, '');
INSERT INTO 'tune' VALUES (4084, NULL, '2012-01-20 12:54:33.574241+00', 'Ault na Vournoch', 2191, '');
INSERT INTO 'tune' VALUES (788, NULL, '2012-01-20 12:54:22.804921+00', 'Jimmy Shand''s Delight', 9998, '');
INSERT INTO 'tune' VALUES (789, NULL, '2012-01-20 12:54:22.80782+00', 'Jock Wilson''s Ball', 1889, '');
INSERT INTO 'tune' VALUES (790, NULL, '2012-01-20 12:54:22.810712+00', 'Jock o'' Hazeldean', 9999, '');
INSERT INTO 'tune' VALUES (4085, NULL, '2012-01-20 12:54:33.578039+00', 'Lucky Scaup', 1558, '');
INSERT INTO 'tune' VALUES (791, NULL, '2012-01-20 12:54:22.813606+00', 'Jockey''s Dance', 9999, '');
INSERT INTO 'tune' VALUES (792, NULL, '2012-01-20 12:54:22.816497+00', 'Joe Foster''s Jig', 1522, '');
INSERT INTO 'tune' VALUES (793, NULL, '2012-01-20 12:54:22.819415+00', 'Joe Hunter''s Jig', 1558, '');
INSERT INTO 'tune' VALUES (4086, NULL, '2012-01-20 12:54:33.582288+00', 'Lucy''s Flittin''', 9998, '');
INSERT INTO 'tune' VALUES (794, NULL, '2012-01-20 12:54:22.822329+00', 'Joe MacDiarmid''s Jig', 1569, '');
INSERT INTO 'tune' VALUES (795, NULL, '2012-01-20 12:54:22.825234+00', 'Joe Murphy', 1456, '');
INSERT INTO 'tune' VALUES (4087, NULL, '2012-01-20 12:54:33.586876+00', 'Lum Hat Wantin'' the Croon', 1902, '');
INSERT INTO 'tune' VALUES (4088, NULL, '2012-01-20 12:54:33.591089+00', 'Stewart Smith', 1773, '');
INSERT INTO 'tune' VALUES (4089, NULL, '2012-01-20 12:54:33.594911+00', 'Mrs Marilyn Watson', 1582, '');
INSERT INTO 'tune' VALUES (4090, NULL, '2012-01-20 12:54:33.598878+00', 'Cyril and Jean', 1646, '');
INSERT INTO 'tune' VALUES (4091, NULL, '2012-01-20 12:54:33.602676+00', 'MacGregor''s Jig', 1904, '');
INSERT INTO 'tune' VALUES (4092, NULL, '2012-01-20 12:54:33.606489+00', 'MacGregor''s Wail', 9998, '');
INSERT INTO 'tune' VALUES (796, NULL, '2018-01-18 21:02:18.71063+00', 'Joe and Evelyn Ramwell', 1456, '');
INSERT INTO 'tune' VALUES (4093, NULL, '2012-01-20 12:54:33.61051+00', 'Val Mitchell''s Reel', 1502, '');
INSERT INTO 'tune' VALUES (4094, NULL, '2012-01-20 12:54:33.614437+00', 'Shin Falls', 1502, '');
INSERT INTO 'tune' VALUES (4095, NULL, '2012-01-20 12:54:33.618239+00', 'O''er the Hills', 9999, '');
INSERT INTO 'tune' VALUES (12015, '2012-02-06 11:53:28.200549+00', '2012-02-06 11:53:28.20056+00', 'Turner''s Rant', 2208, '');
INSERT INTO 'tune' VALUES (12058, '2012-05-04 19:02:29.619384+00', '2012-05-04 19:02:29.619394+00', 'Quel Fromage', 1502, '');
INSERT INTO 'tune' VALUES (12112, '2012-06-12 14:28:50.121115+00', '2012-06-12 14:28:50.121125+00', 'Stuart Anderson''s Reel', 2197, '');
INSERT INTO 'tune' VALUES (12258, '2012-12-28 14:10:37.919084+00', '2012-12-28 14:10:37.919094+00', 'Swinging with the Eighties', 1602, '');
INSERT INTO 'tune' VALUES (12300, '2013-01-02 15:06:04.084926+00', '2013-01-02 17:02:08.792855+00', 'Blueberry Pickers Clog', 3798, '');
INSERT INTO 'tune' VALUES (12335, '2013-01-03 08:28:10.9602+00', '2013-01-03 08:28:10.960211+00', 'French Broad Lightning', 1539, '');
INSERT INTO 'tune' VALUES (12349, '2013-01-03 10:26:31.119651+00', '2013-01-03 10:26:31.119662+00', 'Muck Ceilidh, The', 1580, '');
INSERT INTO 'tune' VALUES (12355, '2013-01-03 11:18:30.05048+00', '2013-01-03 11:18:30.050491+00', 'High Road to Wigton, The', 1580, '');
INSERT INTO 'tune' VALUES (12362, '2013-01-04 15:53:29.169489+00', '2013-01-04 15:53:29.169501+00', 'McOwens'' Farewell', 3484, '');
INSERT INTO 'tune' VALUES (12370, '2013-01-05 16:14:27.712079+00', '2013-01-05 16:14:27.712089+00', 'Over the Waves', 10701, '');
INSERT INTO 'tune' VALUES (12373, '2013-01-05 16:41:45.603095+00', '2013-01-05 18:03:18.226803+00', 'Fustra''s Compliments to Robert Whitehead & the Danelaw Country Dance Band, Da', 2253, '');
INSERT INTO 'tune' VALUES (12401, '2013-01-06 16:47:49.178499+00', '2013-01-06 16:47:49.178512+00', 'I''se the B''y', 9999, '');
INSERT INTO 'tune' VALUES (12412, '2013-01-16 13:14:10.230611+00', '2013-01-16 13:14:10.230623+00', 'Me and My Gal', 10711, '');
INSERT INTO 'tune' VALUES (12417, '2013-01-17 15:06:09.003931+00', '2013-01-17 15:06:09.003943+00', 'Alan Bell', 1579, '');
INSERT INTO 'tune' VALUES (12418, '2013-01-17 15:55:36.259854+00', '2013-01-17 15:55:36.259865+00', 'Evelyn Kerr', 1579, '');
INSERT INTO 'tune' VALUES (797, NULL, '2012-01-20 12:54:22.831086+00', 'John Anderson''s Reel', 1796, '');
INSERT INTO 'tune' VALUES (817, NULL, '2012-01-20 12:54:22.890132+00', 'Johnnie Lad', 9999, '');
INSERT INTO 'tune' VALUES (4096, NULL, '2012-01-20 12:54:33.62269+00', 'Flora''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (798, NULL, '2012-01-20 12:54:22.833988+00', 'John Brown or the Faithful Friend', 1844, '');
INSERT INTO 'tune' VALUES (799, NULL, '2012-01-20 12:54:22.836921+00', 'John D. Wallace', 1606, '');
INSERT INTO 'tune' VALUES (818, NULL, '2012-01-20 12:54:22.893044+00', 'Johnnie come kiss me now', 9998, '');
INSERT INTO 'tune' VALUES (4097, NULL, '2012-01-20 12:54:33.626517+00', 'Seven of Hearts, The', 1607, '');
INSERT INTO 'tune' VALUES (800, NULL, '2012-01-20 12:54:22.839822+00', 'John David Robertson', 9998, '');
INSERT INTO 'tune' VALUES (801, NULL, '2012-01-20 12:54:22.842739+00', 'John Drewry', 1502, '');
INSERT INTO 'tune' VALUES (819, NULL, '2012-01-20 12:54:22.895987+00', 'Johnnie in Nether Mains', 1518, '');
INSERT INTO 'tune' VALUES (4098, NULL, '2012-01-20 12:54:33.630311+00', 'McKenzie River Strathspey, The', 1906, '');
INSERT INTO 'tune' VALUES (803, NULL, '2012-01-20 12:54:22.848792+00', 'John Grumlie', 9999, '');
INSERT INTO 'tune' VALUES (820, NULL, '2012-01-20 12:54:22.89942+00', 'Johnnie''s Friends Are Never Pleased', 9999, '');
INSERT INTO 'tune' VALUES (4099, NULL, '2012-01-20 12:54:33.634267+00', 'Caroline''s Concerto', 1907, '');
INSERT INTO 'tune' VALUES (804, NULL, '2012-01-20 12:54:22.851694+00', 'John Illingsworth', 1502, '');
INSERT INTO 'tune' VALUES (805, NULL, '2012-01-20 12:54:22.854589+00', 'John Macfadyen of Melfort', 1889, '');
INSERT INTO 'tune' VALUES (821, NULL, '2012-01-20 12:54:22.902369+00', 'Elaine Wallace Brunken', 1502, '');
INSERT INTO 'tune' VALUES (4100, NULL, '2012-01-20 12:54:33.638073+00', 'McLachlan''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (806, NULL, '2012-01-20 12:54:22.857481+00', 'John McAlpine', 9999, '');
INSERT INTO 'tune' VALUES (807, NULL, '2012-01-20 12:54:22.860432+00', 'John McNeil''s Reel', 1818, '');
INSERT INTO 'tune' VALUES (822, NULL, '2012-01-20 12:54:22.905269+00', 'Dancing Dustman, The', 1567, '');
INSERT INTO 'tune' VALUES (4101, NULL, '2012-01-20 12:54:33.642067+00', 'MacLeod of Mull', 1910, '');
INSERT INTO 'tune' VALUES (808, NULL, '2012-01-20 12:54:22.86339+00', 'John Mortimer', 1586, '');
INSERT INTO 'tune' VALUES (809, NULL, '2012-01-20 12:54:22.866342+00', 'John Roy Lyall', 1601, '');
INSERT INTO 'tune' VALUES (823, NULL, '2012-01-20 12:54:22.908251+00', 'Johnny Groat''s House', 1518, '');
INSERT INTO 'tune' VALUES (4102, NULL, '2012-01-20 12:54:33.646616+00', 'McKinnon of Dunakin', 9999, '');
INSERT INTO 'tune' VALUES (810, NULL, '2012-01-20 12:54:22.869262+00', 'John Roy Stewart', 1587, '');
INSERT INTO 'tune' VALUES (811, NULL, '2012-01-20 12:54:22.872615+00', 'John Sinton''s Strathspey', 1531, '');
INSERT INTO 'tune' VALUES (824, NULL, '2012-01-20 12:54:22.911156+00', 'Johnny McGill', 1891, '');
INSERT INTO 'tune' VALUES (4103, NULL, '2012-01-20 12:54:33.650422+00', 'Mr Duncan''s Delight', 1519, '');
INSERT INTO 'tune' VALUES (812, NULL, '2012-01-20 12:54:22.87556+00', 'John Stephen of Chance Inn', 1554, '');
INSERT INTO 'tune' VALUES (813, NULL, '2012-01-20 12:54:22.878465+00', 'John W. Smith''s Compliments to Annie Shand Scott', 1417, '');
INSERT INTO 'tune' VALUES (825, NULL, '2012-01-20 12:54:22.914065+00', 'Jolly Tars', 9999, '');
INSERT INTO 'tune' VALUES (814, NULL, '2012-01-20 12:54:22.881366+00', 'John of Badenyon', 2155, '');
INSERT INTO 'tune' VALUES (815, NULL, '2012-01-20 12:54:22.884308+00', 'John of Bon Accord', 1508, '');
INSERT INTO 'tune' VALUES (826, NULL, '2012-01-20 12:54:22.917513+00', 'Joyce''s Jig', 810, '');
INSERT INTO 'tune' VALUES (4105, NULL, '2012-01-20 12:54:33.658138+00', 'Anvil, The', 1623, '');
INSERT INTO 'tune' VALUES (816, NULL, '2012-01-20 12:54:22.887226+00', 'Johnnie Cope', 9999, '');
INSERT INTO 'tune' VALUES (827, '2006-08-27 22:00:00+00', '2012-01-20 12:54:22.920449+00', 'Expo Reel, The', 3692, '');
INSERT INTO 'tune' VALUES (4106, NULL, '2012-01-20 12:54:33.66248+00', 'Glen Tromie Strathspey, The', 1516, '');
INSERT INTO 'tune' VALUES (828, NULL, '2012-01-20 12:54:22.923377+00', 'Julian''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (829, NULL, '2012-01-20 12:54:22.926266+00', 'Jumping Geordie', 9999, '');
INSERT INTO 'tune' VALUES (830, NULL, '2012-01-20 12:54:22.929257+00', 'June Scott', 9998, '');
INSERT INTO 'tune' VALUES (4107, NULL, '2012-01-20 12:54:33.667324+00', 'Miss MacPherson''s Rant', 9998, '');
INSERT INTO 'tune' VALUES (831, NULL, '2012-01-20 12:54:22.932154+00', 'Just as I was in the Morning', 9998, '');
INSERT INTO 'tune' VALUES (832, NULL, '2012-01-20 12:54:22.935055+00', 'Just for You', 9998, '');
INSERT INTO 'tune' VALUES (4108, NULL, '2012-01-20 12:54:33.671272+00', 'New Bridge to Skye, The', 1502, '');
INSERT INTO 'tune' VALUES (834, NULL, '2012-01-20 12:54:22.940835+00', 'Kail Pot, The', 9999, '');
INSERT INTO 'tune' VALUES (835, NULL, '2012-01-20 12:54:22.943721+00', 'Kate Dalrymple', 9999, '');
INSERT INTO 'tune' VALUES (836, NULL, '2012-01-20 12:54:22.946609+00', 'Kate McFarlan', 9998, '');
INSERT INTO 'tune' VALUES (4109, NULL, '2012-01-20 12:54:33.675425+00', 'Strathcare', 1502, '');
INSERT INTO 'tune' VALUES (837, NULL, '2012-01-20 12:54:22.949616+00', 'Kate''s Jig', 1607, '');
INSERT INTO 'tune' VALUES (4110, NULL, '2012-01-20 12:54:33.679303+00', 'Donald MacLeod of Kyle', 1502, '');
INSERT INTO 'tune' VALUES (838, NULL, '2012-01-20 12:54:22.952518+00', 'Katherine''s Welcome', 1472, '');
INSERT INTO 'tune' VALUES (839, NULL, '2012-01-20 12:54:22.955411+00', 'Kathleen''s Reel', 1533, '');
INSERT INTO 'tune' VALUES (4111, NULL, '2012-01-20 12:54:33.683111+00', 'MacLeod''s Tables', 1912, '');
INSERT INTO 'tune' VALUES (840, NULL, '2012-01-20 12:54:22.958294+00', 'Katie Bairdie', 9999, '');
INSERT INTO 'tune' VALUES (4112, NULL, '2012-01-20 12:54:33.686906+00', 'Portree Men Quickstep', 1913, '');
INSERT INTO 'tune' VALUES (843, NULL, '2012-01-20 12:54:22.967036+00', 'Keep the Country Bonnie Lassie', 9998, '');
INSERT INTO 'tune' VALUES (844, NULL, '2012-01-20 12:54:22.969928+00', 'Keithmore', 1516, '');
INSERT INTO 'tune' VALUES (845, NULL, '2012-01-20 12:54:22.972884+00', 'Kelly''s Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (4113, NULL, '2012-01-20 12:54:33.691402+00', 'Duntulm', 9999, '');
INSERT INTO 'tune' VALUES (846, NULL, '2012-01-20 12:54:22.975784+00', 'Kelso Races', 9998, '');
INSERT INTO 'tune' VALUES (847, NULL, '2012-01-20 12:54:22.978674+00', 'Kelvin Bridge', 1454, '');
INSERT INTO 'tune' VALUES (848, NULL, '2012-01-20 12:54:22.981586+00', 'Kelvingrove', 9999, '');
INSERT INTO 'tune' VALUES (4114, NULL, '2012-01-20 12:54:33.695469+00', 'Mrs Charles Graham''s Welcome Home', 9999, '');
INSERT INTO 'tune' VALUES (849, NULL, '2012-01-20 12:54:22.984481+00', 'Kendoon Strathspey, The', 1437, '');
INSERT INTO 'tune' VALUES (4115, NULL, '2012-01-20 12:54:33.699333+00', 'Daft Donald', 9999, '');
INSERT INTO 'tune' VALUES (4116, NULL, '2012-01-20 12:54:33.70315+00', 'Muscovy Ducks, The', 1914, '');
INSERT INTO 'tune' VALUES (4117, NULL, '2012-01-20 12:54:33.70715+00', 'Tullochard', 1915, '');
INSERT INTO 'tune' VALUES (4118, NULL, '2012-01-20 12:54:33.711912+00', 'Laphroaig', 1564, '');
INSERT INTO 'tune' VALUES (4119, NULL, '2012-01-20 12:54:33.715938+00', 'Sud Mar Chuir Mi''n Geamhradh', 9999, '');
INSERT INTO 'tune' VALUES (4120, NULL, '2012-01-20 12:54:33.719865+00', 'Mrs MacDonald of Skeabost', 9999, '');
INSERT INTO 'tune' VALUES (4121, NULL, '2012-01-20 12:54:33.723698+00', 'D.C. MacLeod of Stormyhill', 1915, '');
INSERT INTO 'tune' VALUES (12016, '2012-02-06 11:57:45.458278+00', '2012-02-06 11:57:45.458289+00', 'Fosten House', 1656, '');
INSERT INTO 'tune' VALUES (12059, '2012-05-04 19:04:08.618484+00', '2012-05-04 19:04:08.618495+00', 'Vive La Danse', 1502, '');
INSERT INTO 'tune' VALUES (12113, '2012-06-12 14:29:11.925932+00', '2012-06-12 14:29:11.925944+00', 'Plough and the Stars', 9998, '');
INSERT INTO 'tune' VALUES (12259, '2012-12-28 14:19:22.971274+00', '2012-12-28 14:19:22.971285+00', 'Margaret & Alison''s Ruby Wedding', 3155, '');
INSERT INTO 'tune' VALUES (12301, '2013-01-02 15:07:16.982963+00', '2013-01-02 15:07:16.982975+00', 'Celtic Sessions Breakdown', 9999, '');
INSERT INTO 'tune' VALUES (12336, '2013-01-03 08:29:13.793362+00', '2013-01-03 08:29:13.793373+00', 'Late Night at Kincraigie', 1539, '');
INSERT INTO 'tune' VALUES (12356, '2013-01-03 11:21:30.86702+00', '2013-01-03 11:21:30.867032+00', 'Rhinns of Kells', 1580, '');
INSERT INTO 'tune' VALUES (12363, '2013-01-04 15:54:25.923289+00', '2013-01-04 15:54:25.923301+00', 'Farewell Mary Ann', 9999, '');
INSERT INTO 'tune' VALUES (12374, '2013-01-05 16:43:14.225931+00', '2013-01-05 16:43:14.225943+00', 'Black Maria', 1567, '');
INSERT INTO 'tune' VALUES (12402, '2013-01-06 16:53:08.16888+00', '2013-01-06 16:53:08.168891+00', 'Golden Rod Jig', 10057, '');
INSERT INTO 'tune' VALUES (12413, '2013-01-16 13:14:57.790663+00', '2013-01-16 13:14:57.790674+00', 'Mary', 3366, '');
INSERT INTO 'tune' VALUES (12419, '2013-01-17 16:00:45.39972+00', '2013-01-17 16:00:45.399732+00', 'Jimmy Leighton', 1579, '');
INSERT INTO 'tune' VALUES (12422, '2013-01-23 10:07:15.860213+00', '2013-01-23 10:07:15.860224+00', 'New Fowlis Hall, The', 10658, '');
INSERT INTO 'tune' VALUES (12423, '2013-01-23 13:06:42.681804+00', '2013-01-23 13:42:29.571157+00', 'Mary B Skippin', 10729, 'information came from Iain Gent');
INSERT INTO 'tune' VALUES (12430, '2013-01-24 14:19:03.053287+00', '2013-01-24 14:19:03.053298+00', 'Hornpipe (Allan''s Reels Strathspeys and General Dance Music p. 27, second tune)', 9998, '');
INSERT INTO 'tune' VALUES (12431, '2013-01-24 15:28:58.25258+00', '2013-01-24 15:28:58.252591+00', 'Tribe of Galen, The', 1902, 'This is a variant of <<ddt:Maggie Lauder>>.');
INSERT INTO 'tune' VALUES (13822, '2018-02-24 03:14:28.147778+00', '2018-02-24 03:14:28.147778+00', 'Charles Edward Hope Vere', 9998, '');
INSERT INTO 'tune' VALUES (12438, '2013-02-02 15:23:32.247792+00', '2013-02-02 15:23:32.247804+00', 'June Carr', 1579, '');
INSERT INTO 'tune' VALUES (12451, '2013-02-02 17:06:35.688189+00', '2013-02-02 17:06:35.6882+00', 'Alex Taylor of Perth', 1579, '');
INSERT INTO 'tune' VALUES (850, NULL, '2012-01-20 12:54:22.987384+00', 'Kenmure''s on and awa''', 9999, '');
INSERT INTO 'tune' VALUES (871, NULL, '2012-01-20 12:54:23.048817+00', 'Kiss for a Ha''pennie, A', 9998, '');
INSERT INTO 'tune' VALUES (851, NULL, '2012-01-20 12:54:22.990304+00', 'Kenneth Campbell Holden', 1502, '');
INSERT INTO 'tune' VALUES (4122, NULL, '2012-01-20 12:54:33.727613+00', 'Padlock, The', 1915, '');
INSERT INTO 'tune' VALUES (852, NULL, '2012-01-20 12:54:22.993203+00', 'Kenneth MacGregor Holden', 1502, '');
INSERT INTO 'tune' VALUES (872, NULL, '2012-01-20 12:54:23.052012+00', 'Kiss me quick, my Mither''s coming', 9999, '');
INSERT INTO 'tune' VALUES (853, NULL, '2012-01-20 12:54:22.996102+00', 'Sir Reginald Macdonald', 9999, '');
INSERT INTO 'tune' VALUES (4123, NULL, '2012-01-20 12:54:33.732466+00', 'Gearrchaile Shligigh', 9999, '');
INSERT INTO 'tune' VALUES (854, NULL, '2012-01-20 12:54:22.999214+00', 'Kilkenny Castle', 1557, '');
INSERT INTO 'tune' VALUES (873, NULL, '2012-01-20 12:54:23.054916+00', 'Knit the Pocky', 9999, '');
INSERT INTO 'tune' VALUES (855, NULL, '2012-01-20 12:54:23.002128+00', 'Killearn', 2849, '');
INSERT INTO 'tune' VALUES (4124, NULL, '2012-01-20 12:54:33.736445+00', 'Murdo Lamont''s Spree', 1915, '');
INSERT INTO 'tune' VALUES (856, NULL, '2012-01-20 12:54:23.005044+00', 'Kilravock''s Strathspey', 1518, '');
INSERT INTO 'tune' VALUES (874, NULL, '2012-01-20 12:54:23.057859+00', 'Knock of Braemoray, The', 1586, '');
INSERT INTO 'tune' VALUES (857, NULL, '2012-01-20 12:54:23.007952+00', 'Kilt is my Delight, The', 9999, '');
INSERT INTO 'tune' VALUES (4125, NULL, '2012-01-20 12:54:33.741265+00', 'West Highland Line, The', 1502, '');
INSERT INTO 'tune' VALUES (858, NULL, '2012-01-20 12:54:23.010863+00', 'Sleep Soond I''da Moarnin''', 9999, '');
INSERT INTO 'tune' VALUES (4126, NULL, '2012-01-20 12:54:33.745083+00', 'Gillean an Drobhair', 9999, '');
INSERT INTO 'tune' VALUES (860, NULL, '2012-01-20 12:54:23.016681+00', 'Kilwinning Archers', 9999, '');
INSERT INTO 'tune' VALUES (4127, NULL, '2012-01-20 12:54:33.749039+00', 'Bride is a Bonny Thing, The', 9999, '');
INSERT INTO 'tune' VALUES (862, NULL, '2012-01-20 12:54:23.022531+00', 'Kinderdijk Jig, The', 1725, '');
INSERT INTO 'tune' VALUES (877, NULL, '2012-01-20 12:54:23.066694+00', 'Valletta, La', 2281, '');
INSERT INTO 'tune' VALUES (863, NULL, '2012-01-20 12:54:23.025424+00', 'Kings X', 1502, '');
INSERT INTO 'tune' VALUES (4128, NULL, '2012-01-20 12:54:33.753183+00', 'Lady Douglas of Bothwell', 1781, '');
INSERT INTO 'tune' VALUES (864, NULL, '2012-01-20 12:54:23.028399+00', 'Kingussie Flower', 9999, '');
INSERT INTO 'tune' VALUES (878, NULL, '2012-01-20 12:54:23.069588+00', 'Lad''s Awa'', The', 1701, '');
INSERT INTO 'tune' VALUES (865, NULL, '2012-01-20 12:54:23.031395+00', 'Kinlochewe', 1512, '');
INSERT INTO 'tune' VALUES (866, NULL, '2012-01-20 12:54:23.034316+00', 'Kirkstall Road', 1582, '');
INSERT INTO 'tune' VALUES (879, NULL, '2012-01-20 12:54:23.07248+00', 'Laddies o'' Dunse, The', 9999, '');
INSERT INTO 'tune' VALUES (867, NULL, '2012-01-20 12:54:23.037217+00', 'Kirrie Kebbuck, The', 1512, '');
INSERT INTO 'tune' VALUES (868, NULL, '2012-01-20 12:54:23.040124+00', 'Tame Her When Da Snaw Comes', 9999, '');
INSERT INTO 'tune' VALUES (880, NULL, '2012-01-20 12:54:23.075395+00', 'Ladies of Dingwall, The', 2981, '');
INSERT INTO 'tune' VALUES (869, NULL, '2012-01-20 12:54:23.043024+00', 'Kirriemuir', 9998, '');
INSERT INTO 'tune' VALUES (4131, NULL, '2012-01-20 12:54:33.765773+00', 'David Meek''s Welcome to Skye', 1915, '');
INSERT INTO 'tune' VALUES (870, NULL, '2012-01-20 12:54:23.045916+00', 'Kishmul''s Galley', 9998, '');
INSERT INTO 'tune' VALUES (881, NULL, '2012-01-20 12:54:23.078294+00', 'Lads of Air (Ayr), The', 9998, '');
INSERT INTO 'tune' VALUES (882, NULL, '2012-01-20 12:54:23.08123+00', 'Lads of Leith, The', 9999, '');
INSERT INTO 'tune' VALUES (4132, NULL, '2012-01-20 12:54:33.769577+00', 'Burnt Leg, The', 9999, '');
INSERT INTO 'tune' VALUES (883, NULL, '2012-01-20 12:54:23.084413+00', 'Lads of Saltcoats, The', 453, '');
INSERT INTO 'tune' VALUES (884, NULL, '2012-01-20 12:54:23.087339+00', 'So Merry As We Have Been', 9998, '');
INSERT INTO 'tune' VALUES (885, NULL, '2012-01-20 12:54:23.090232+00', 'Lady Ann Maitland', 9998, '');
INSERT INTO 'tune' VALUES (4133, NULL, '2012-01-20 12:54:33.773376+00', 'Thearlaich! Nan Tigeadh Tu', 9999, '');
INSERT INTO 'tune' VALUES (886, NULL, '2012-01-20 12:54:23.093127+00', 'Lady Auckland''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (887, NULL, '2012-01-20 12:54:23.096022+00', 'Lady Baird''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (888, NULL, '2012-01-20 12:54:23.099176+00', 'Lady Baird''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (4134, NULL, '2012-01-20 12:54:33.77728+00', 'Skye Boat Song', 9999, '');
INSERT INTO 'tune' VALUES (889, NULL, '2012-01-20 12:54:23.102089+00', 'Lady Carmichael of Castle Craig''s Strathspey', 1974, '');
INSERT INTO 'tune' VALUES (890, NULL, '2012-01-20 12:54:23.122518+00', 'Lady Charlotte Campbell (strathspey)', 1519, '');
INSERT INTO 'tune' VALUES (891, NULL, '2012-01-20 12:54:23.125502+00', 'Lady Charlotte Campbell (reel)', 1519, '');
INSERT INTO 'tune' VALUES (4135, NULL, '2012-01-20 12:54:33.781632+00', 'Chi Mi Na Mor-Bheanna', 9999, '');
INSERT INTO 'tune' VALUES (892, NULL, '2012-01-20 12:54:23.128396+00', 'Lady Charlotte Campbell''s Strathspey', 1517, '');
INSERT INTO 'tune' VALUES (893, NULL, '2012-01-20 12:54:23.131298+00', 'Lady Coventry''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (894, NULL, '2012-01-20 12:54:23.134183+00', 'Lady Dick Lauder''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (4136, NULL, '2012-01-20 12:54:33.785441+00', 'Donegal Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (895, NULL, '2012-01-20 12:54:23.137154+00', 'Lady Doune', 1517, '');
INSERT INTO 'tune' VALUES (896, NULL, '2012-01-20 12:54:23.140056+00', 'Lady Dumfries', 9999, '');
INSERT INTO 'tune' VALUES (4137, NULL, '2012-01-20 12:54:33.789237+00', 'Red Haired Girl of Tulloch', 9999, '');
INSERT INTO 'tune' VALUES (898, NULL, '2012-01-20 12:54:23.145825+00', 'Lady Elizabeth Lindsay', 1447, '');
INSERT INTO 'tune' VALUES (899, NULL, '2012-01-20 12:54:23.148796+00', 'Lady Erskine', 1973, '');
INSERT INTO 'tune' VALUES (900, NULL, '2012-01-20 12:54:23.151709+00', 'Lady Georgina Gordon''s Reel', 1516, '');
INSERT INTO 'tune' VALUES (861, NULL, '2014-08-19 08:23:50.1666+00', 'Kind Robin', 9999, 'Lyrics by Carolina, Lady Nairne.');
INSERT INTO 'tune' VALUES (897, NULL, '2014-11-09 00:34:19.108591+00', 'Lady Eliza Lindsay', 9999, '');
INSERT INTO 'tune' VALUES (876, NULL, '2014-11-15 22:54:27.938177+00', 'Tempête, La', 9999, '');
INSERT INTO 'tune' VALUES (4138, NULL, '2012-01-20 12:54:33.793061+00', 'Answering Machine, The', 1445, '');
INSERT INTO 'tune' VALUES (901, NULL, '2012-01-20 12:54:23.154619+00', 'Lady Glasgow', 1774, '');
INSERT INTO 'tune' VALUES (4139, NULL, '2012-01-20 12:54:33.796964+00', 'Springtime in Cambridge', 1445, '');
INSERT INTO 'tune' VALUES (4140, NULL, '2012-01-20 12:54:33.80081+00', 'Dutch Skipper, The', 1445, '');
INSERT INTO 'tune' VALUES (4141, NULL, '2012-01-20 12:54:33.804621+00', 'Pipe Major William McVean', 1445, '');
INSERT INTO 'tune' VALUES (4142, NULL, '2012-01-20 12:54:33.80842+00', 'Man from Pennsylvania, The', 1445, '');
INSERT INTO 'tune' VALUES (4143, NULL, '2012-01-20 12:54:33.812878+00', 'Pinocchio''s Jig', 1445, '');
INSERT INTO 'tune' VALUES (4144, NULL, '2012-01-20 12:54:33.816689+00', 'Wilhelm Tell Strathspey, The', 1445, '');
INSERT INTO 'tune' VALUES (4145, NULL, '2012-01-20 12:54:33.820601+00', 'Ins and Outs', 1445, '');
INSERT INTO 'tune' VALUES (4146, NULL, '2012-01-20 12:54:33.824397+00', 'Bells and Tooters', 1445, '');
INSERT INTO 'tune' VALUES (12017, '2012-02-06 11:58:52.228956+00', '2012-02-06 11:58:52.228967+00', 'Margaret Wilson', 1456, '');
INSERT INTO 'tune' VALUES (12060, '2012-05-04 19:04:41.416065+00', '2012-05-04 19:04:41.416076+00', 'Fran''s Fancy', 1502, '');
INSERT INTO 'tune' VALUES (12260, '2012-12-28 14:21:06.956529+00', '2012-12-28 14:21:06.95654+00', 'Davie & Margaret''s Ruby Wedding', 2912, '');
INSERT INTO 'tune' VALUES (12302, '2013-01-02 15:09:03.547856+00', '2013-01-02 15:09:03.547867+00', 'House on the Hill Clog', 9999, '');
INSERT INTO 'tune' VALUES (12337, '2013-01-03 08:47:27.748984+00', '2013-01-03 08:47:27.748995+00', 'Heave a Pawl', 1580, '');
INSERT INTO 'tune' VALUES (12357, '2013-01-03 11:22:17.56237+00', '2013-01-03 11:22:17.562381+00', 'Fosters Reel', 1580, '');
INSERT INTO 'tune' VALUES (12364, '2013-01-04 15:59:02.634877+00', '2013-01-04 15:59:02.634888+00', 'Lorraine Fraser Gets Jiggy', 10570, '');
INSERT INTO 'tune' VALUES (12375, '2013-01-05 16:47:41.252621+00', '2013-01-05 16:47:41.252633+00', 'Senga''s Walking Stick Waltz', 2253, '');
INSERT INTO 'tune' VALUES (12403, '2013-01-06 16:55:17.242832+00', '2013-01-06 16:55:17.242843+00', 'Capers', 2243, '');
INSERT INTO 'tune' VALUES (12420, '2013-01-17 16:01:47.667807+00', '2013-01-17 16:01:47.667818+00', 'Jim Campbell', 1579, '');
INSERT INTO 'tune' VALUES (12424, '2013-01-23 13:08:38.732733+00', '2013-01-23 13:08:38.732744+00', 'Dougie Mcleod', 1981, '');
INSERT INTO 'tune' VALUES (12432, '2013-01-24 15:31:10.65874+00', '2013-01-24 15:31:10.658752+00', 'Miss May Thomson', 1902, '');
INSERT INTO 'tune' VALUES (12439, '2013-02-02 15:24:21.65279+00', '2013-02-02 15:24:21.652801+00', 'Carry', 1579, '');
INSERT INTO 'tune' VALUES (12452, '2013-02-02 17:10:41.859277+00', '2013-02-02 17:10:41.859289+00', 'Angela Fullerton', 1579, '');
INSERT INTO 'tune' VALUES (902, NULL, '2012-01-20 12:54:23.157517+00', 'Lady Graham''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (922, NULL, '2012-01-20 12:54:23.216036+00', 'Lady Maxwell''s Rant', 9998, '');
INSERT INTO 'tune' VALUES (903, NULL, '2012-01-20 12:54:23.160416+00', 'Lady Harriet Hope', 9998, '');
INSERT INTO 'tune' VALUES (4147, NULL, '2012-01-20 12:54:33.828196+00', 'Young Wille McSproot', 1445, '');
INSERT INTO 'tune' VALUES (13892, '2018-06-09 00:52:52.330448+00', '2018-06-09 00:52:52.330448+00', 'Iceberg, The', 1502, '');
INSERT INTO 'tune' VALUES (13907, '2018-06-09 22:23:30.095156+00', '2018-06-09 22:23:30.095156+00', 'Muriel Johnstone''s Compliments to Peter Shand', 1502, '');
INSERT INTO 'tune' VALUES (904, NULL, '2012-01-20 12:54:23.163312+00', 'Lady Harriet Hope''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (923, NULL, '2012-01-20 12:54:23.218961+00', 'Lady Montgomerie', 1774, '');
INSERT INTO 'tune' VALUES (905, NULL, '2012-01-20 12:54:23.166196+00', 'Lady Heathcote''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (4148, NULL, '2012-01-20 12:54:33.832008+00', 'Johnnie comes Marching Home', 9999, '');
INSERT INTO 'tune' VALUES (906, NULL, '2012-01-20 12:54:23.169131+00', 'Lady Home''s Jig', 1518, '');
INSERT INTO 'tune' VALUES (924, NULL, '2012-01-20 12:54:23.221846+00', 'Lady Shaftesbury', 9999, '');
INSERT INTO 'tune' VALUES (907, NULL, '2012-01-20 12:54:23.172028+00', 'Lady Hope of Pinkie', 1517, '');
INSERT INTO 'tune' VALUES (4149, NULL, '2012-01-20 12:54:33.836502+00', 'Peter Elmes', 41, '');
INSERT INTO 'tune' VALUES (908, NULL, '2012-01-20 12:54:23.174917+00', 'Lady Horne''s Jig', 1518, '');
INSERT INTO 'tune' VALUES (925, NULL, '2012-01-20 12:54:23.224745+00', 'Lady Stormont''s Strathspey', 1801, '');
INSERT INTO 'tune' VALUES (909, NULL, '2012-01-20 12:54:23.177841+00', 'Lady Hunter Blair''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (4150, NULL, '2012-01-20 12:54:33.840459+00', 'Sprightly Girl, The', 1445, '');
INSERT INTO 'tune' VALUES (910, NULL, '2012-01-20 12:54:23.180734+00', 'Lady Huntly', 9999, '');
INSERT INTO 'tune' VALUES (12425, '2013-01-23 13:12:55.97042+00', '2013-01-23 13:15:39.361938+00', 'Wednesday Night Strathspey, The', 10727, 'Information came from iain Gent');
INSERT INTO 'tune' VALUES (911, NULL, '2012-01-20 12:54:23.183622+00', 'Lady Kinloch of Gilmerton''s Strathspey', 1695, '');
INSERT INTO 'tune' VALUES (4151, NULL, '2012-01-20 12:54:33.84427+00', 'Samson''s Strathspey', 1445, '');
INSERT INTO 'tune' VALUES (912, NULL, '2012-01-20 12:54:23.186509+00', 'Lady Louisa Macdonald''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (927, NULL, '2012-01-20 12:54:23.230941+00', 'Lady of the Lake, The', 9999, '');
INSERT INTO 'tune' VALUES (913, NULL, '2012-01-20 12:54:23.189604+00', 'Lady Lucy Ramsay', 1517, '');
INSERT INTO 'tune' VALUES (4152, NULL, '2012-01-20 12:54:33.848083+00', 'Hobby Horse, The', 1445, '');
INSERT INTO 'tune' VALUES (928, NULL, '2012-01-20 12:54:23.233843+00', 'Lady''s Breist Knot, The', 1895, '');
INSERT INTO 'tune' VALUES (915, NULL, '2012-01-20 12:54:23.195386+00', 'Lady Madeline Sinclair', 1486, '');
INSERT INTO 'tune' VALUES (4153, NULL, '2012-01-20 12:54:33.85188+00', 'Visit to Eindhoven, A', 1445, '');
INSERT INTO 'tune' VALUES (916, NULL, '2012-01-20 12:54:23.198289+00', 'Lady Marie Parker', 1518, '');
INSERT INTO 'tune' VALUES (929, NULL, '2012-01-20 12:54:23.236737+00', 'Ladykirk Bridge', 1502, '');
INSERT INTO 'tune' VALUES (917, NULL, '2012-01-20 12:54:23.201188+00', 'Lady Mary Hay''s Scotch Measure', 1517, '');
INSERT INTO 'tune' VALUES (4154, NULL, '2012-01-20 12:54:33.855677+00', 'Far Islands, The', 1445, '');
INSERT INTO 'tune' VALUES (918, NULL, '2012-01-20 12:54:23.204099+00', 'Lady Mary Menzies'' Reel', 9999, '');
INSERT INTO 'tune' VALUES (930, NULL, '2012-01-20 12:54:23.239632+00', 'Lager Beer', 1859, '');
INSERT INTO 'tune' VALUES (919, NULL, '2012-01-20 12:54:23.207329+00', 'Lady Mary Murray', 1517, '');
INSERT INTO 'tune' VALUES (4155, NULL, '2012-01-20 12:54:33.860312+00', 'Bird-Clad Rocks, The', 1445, '');
INSERT INTO 'tune' VALUES (920, NULL, '2012-01-20 12:54:23.210237+00', 'Lady Mary Ramsay', 1517, '');
INSERT INTO 'tune' VALUES (931, NULL, '2012-01-20 12:54:23.242522+00', 'Laird and his Lass, The', 1701, '');
INSERT INTO 'tune' VALUES (921, NULL, '2012-01-20 12:54:23.213138+00', 'Lady Mary Stopford', 9999, '');
INSERT INTO 'tune' VALUES (4156, NULL, '2012-01-20 12:54:33.864201+00', 'Little Isle of Taransay, The', 1445, '');
INSERT INTO 'tune' VALUES (932, NULL, '2012-01-20 12:54:23.245406+00', 'Laird of Cockpen, The', 9999, '');
INSERT INTO 'tune' VALUES (933, NULL, '2012-01-20 12:54:23.248578+00', 'Laird o'' Dochart''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (1308, NULL, '2012-01-20 12:54:24.393+00', 'Mrs Fanny Kyd', 1607, '');
INSERT INTO 'tune' VALUES (13823, '2018-02-24 03:16:23.41343+00', '2018-02-24 03:16:23.41343+00', 'Charlie''s Welcome', 9998, '');
INSERT INTO 'tune' VALUES (4157, NULL, '2012-01-20 12:54:33.868009+00', 'Joe Cumming''s Favourite', 1445, '');
INSERT INTO 'tune' VALUES (936, NULL, '2012-01-20 12:54:23.257299+00', 'Parson in Boots, The', 9998, '');
INSERT INTO 'tune' VALUES (937, NULL, '2012-01-20 12:54:23.260285+00', 'Laird of Milton''s Daughter, The', 1619, '');
INSERT INTO 'tune' VALUES (4158, NULL, '2012-01-20 12:54:33.871887+00', 'Level Crossing, The', 1445, '');
INSERT INTO 'tune' VALUES (938, NULL, '2012-01-20 12:54:23.263192+00', 'Contrapas', 9999, '');
INSERT INTO 'tune' VALUES (4159, NULL, '2012-01-20 12:54:33.8757+00', 'Lady Sophia Amelia Elphinstone', 1445, '');
INSERT INTO 'tune' VALUES (940, NULL, '2012-01-20 12:54:23.268974+00', 'Lament for the Death of the Rev. Archie Beaton', 1817, '');
INSERT INTO 'tune' VALUES (941, NULL, '2012-01-20 12:54:23.272056+00', 'Lamont of Inveryne', 9998, '');
INSERT INTO 'tune' VALUES (942, NULL, '2012-01-20 12:54:23.274964+00', 'Lamplighter''s Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (943, NULL, '2012-01-20 12:54:23.277854+00', 'Landlady of the Inver Inn, The', 1518, '');
INSERT INTO 'tune' VALUES (4160, NULL, '2012-01-20 12:54:33.879656+00', 'Prelim Hornpipe, The', 1445, '');
INSERT INTO 'tune' VALUES (944, NULL, '2012-01-20 12:54:23.280749+00', 'Langford Ceilidh, The', 1439, '');
INSERT INTO 'tune' VALUES (945, NULL, '2012-01-20 12:54:23.283645+00', 'Lango Lee', 9998, '');
INSERT INTO 'tune' VALUES (946, NULL, '2012-01-20 12:54:23.286536+00', 'Langside Ladies', 9998, '');
INSERT INTO 'tune' VALUES (4161, NULL, '2012-01-20 12:54:33.884359+00', 'Dundee Sailor, The', 1445, '');
INSERT INTO 'tune' VALUES (947, NULL, '2012-01-20 12:54:23.28944+00', 'Lantern of the North, The', 9998, '');
INSERT INTO 'tune' VALUES (948, NULL, '2012-01-20 12:54:23.292421+00', 'Larach do Thacaidean', 9999, '');
INSERT INTO 'tune' VALUES (949, NULL, '2012-01-20 12:54:23.295332+00', 'Largo Law', 9999, '');
INSERT INTO 'tune' VALUES (4162, NULL, '2012-01-20 12:54:33.888182+00', 'Russell Court', 1782, '');
INSERT INTO 'tune' VALUES (950, NULL, '2012-01-20 12:54:23.298249+00', 'Larkhill Welcome', 9998, '');
INSERT INTO 'tune' VALUES (951, NULL, '2012-01-20 12:54:23.301149+00', 'Lass o'' Corrie Mill, The', 9999, '');
INSERT INTO 'tune' VALUES (4163, NULL, '2012-01-20 12:54:33.891988+00', 'Landsdowne', 1776, '');
INSERT INTO 'tune' VALUES (4164, NULL, '2012-01-20 12:54:33.895789+00', 'Hamilton Hall', 1886, '');
INSERT INTO 'tune' VALUES (4165, NULL, '2012-01-20 12:54:33.899697+00', 'Garry Blair', 9998, '');
INSERT INTO 'tune' VALUES (4166, NULL, '2012-01-20 12:54:33.903514+00', 'Mad Robin', 9998, '');
INSERT INTO 'tune' VALUES (4167, NULL, '2012-01-20 12:54:33.907857+00', 'Maggie Cameron', 1644, '');
INSERT INTO 'tune' VALUES (4168, NULL, '2012-01-20 12:54:33.911681+00', 'Trip to Tomintoul, A', 1531, '');
INSERT INTO 'tune' VALUES (4169, NULL, '2012-01-20 12:54:33.915479+00', 'Dunollie', 1840, '');
INSERT INTO 'tune' VALUES (4170, NULL, '2012-01-20 12:54:33.919415+00', 'Trim the Velvet', 2141, '');
INSERT INTO 'tune' VALUES (4171, NULL, '2012-01-20 12:54:33.923235+00', 'Mairead Nicol of Drumossie', 1623, '');
INSERT INTO 'tune' VALUES (4172, NULL, '2012-01-20 12:54:33.927706+00', 'Mrs Mary Gudger', 316, '');
INSERT INTO 'tune' VALUES (12018, '2012-02-06 12:01:16.31573+00', '2012-02-06 12:01:16.315741+00', 'Sgt. John McIntee''s Farewell to Mull', 1777, '');
INSERT INTO 'tune' VALUES (12115, '2012-06-12 14:30:51.255463+00', '2012-06-12 14:30:51.255474+00', 'Allan MacKillop of Lochmady', 9998, '');
INSERT INTO 'tune' VALUES (914, NULL, '2014-09-06 02:49:21.299454+00', 'Lady Mackenzie of Coull', 9999, '');
INSERT INTO 'tune' VALUES (926, NULL, '2012-06-17 14:54:31.572433+00', 'Lady Susan Stewart''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (12303, '2013-01-02 15:10:14.067461+00', '2013-01-02 15:10:14.067472+00', 'Myer''s Cavern', 9999, '');
INSERT INTO 'tune' VALUES (12358, '2013-01-03 11:22:52.494394+00', '2013-01-03 11:22:52.494406+00', 'Teviot Crossing, The', 1580, '');
INSERT INTO 'tune' VALUES (12365, '2013-01-04 16:06:58.83879+00', '2013-01-04 16:06:58.838801+00', 'Stella''s Trip to Kamloops', 10696, '');
INSERT INTO 'tune' VALUES (12376, '2013-01-05 16:48:38.390456+00', '2013-01-05 16:48:38.390469+00', 'Grinda Geo Waltz, The', 2253, '');
INSERT INTO 'tune' VALUES (12404, '2013-01-06 17:08:23.783953+00', '2013-01-06 17:08:23.783965+00', 'JFK''s Double Eight Reel', 210, '');
INSERT INTO 'tune' VALUES (12421, '2013-01-17 16:02:40.326712+00', '2013-01-17 16:02:40.326723+00', 'Dawn Turner of Airlie', 1579, '');
INSERT INTO 'tune' VALUES (12440, '2013-02-02 15:25:16.699972+00', '2013-02-02 15:25:16.699984+00', 'Mary Duncan', 1579, '');
INSERT INTO 'tune' VALUES (13824, '2018-02-24 03:17:00.685113+00', '2018-02-24 03:17:00.685113+00', 'Craig-n-darroch', 9998, '');
INSERT INTO 'tune' VALUES (12453, '2013-02-02 17:12:18.045024+00', '2013-02-02 17:12:18.045035+00', 'Donald C. Campbell', 1579, '');
INSERT INTO 'tune' VALUES (952, NULL, '2012-01-20 12:54:23.304041+00', 'Lass o'' Gowrie, The', 9999, '');
INSERT INTO 'tune' VALUES (960, NULL, '2012-01-20 12:54:23.32758+00', 'Lassie wi'' the Yellow Coatie, The', 453, '');
INSERT INTO 'tune' VALUES (4173, NULL, '2012-01-20 12:54:33.931544+00', 'Major Mole', 9999, '');
INSERT INTO 'tune' VALUES (953, NULL, '2012-01-20 12:54:23.306998+00', 'Lass o'' Livingston, The', 1451, '');
INSERT INTO 'tune' VALUES (954, '2006-08-27 22:00:00+00', '2012-01-20 12:54:23.309914+00', 'Loft, The', 2591, '');
INSERT INTO 'tune' VALUES (961, NULL, '2012-01-20 12:54:23.330478+00', 'Lassies o'' Melrose, The', 9999, '');
INSERT INTO 'tune' VALUES (4174, NULL, '2012-01-20 12:54:33.935389+00', 'Make up the Quarrel', 1917, '');
INSERT INTO 'tune' VALUES (955, NULL, '2012-01-20 12:54:23.31289+00', 'Lass o'' Patie''s Mill, The', 9999, '');
INSERT INTO 'tune' VALUES (956, NULL, '2012-01-20 12:54:23.315807+00', 'Bush Below Da Gairden', 9999, '');
INSERT INTO 'tune' VALUES (962, NULL, '2012-01-20 12:54:23.333706+00', 'Lassies of Dunse, The', 9999, '');
INSERT INTO 'tune' VALUES (4175, NULL, '2012-01-20 12:54:33.940999+00', 'Malcolm of the Glen', 9998, '');
INSERT INTO 'tune' VALUES (957, NULL, '2012-01-20 12:54:23.318704+00', 'Lass of Levendale, The', 2006, '');
INSERT INTO 'tune' VALUES (958, NULL, '2012-01-20 12:54:23.321611+00', 'Lassie Come and Dance with Me', 1523, '');
INSERT INTO 'tune' VALUES (963, NULL, '2012-01-20 12:54:23.336602+00', 'Last May a Braw Wooer', 9999, '');
INSERT INTO 'tune' VALUES (4176, NULL, '2012-01-20 12:54:33.945+00', 'Man From North Connel, The', 1605, '');
INSERT INTO 'tune' VALUES (959, NULL, '2012-01-20 12:54:23.324682+00', 'Lassie Look Before Ye', 1516, '');
INSERT INTO 'tune' VALUES (965, NULL, '2012-01-20 12:54:23.342376+00', 'My Aunt Jane', 9999, '');
INSERT INTO 'tune' VALUES (4177, NULL, '2012-01-20 12:54:33.948813+00', 'Man From Uist, The', 9998, '');
INSERT INTO 'tune' VALUES (966, NULL, '2012-01-20 12:54:23.345269+00', 'Pretty Marion', 9998, '');
INSERT INTO 'tune' VALUES (967, NULL, '2012-01-20 12:54:23.348158+00', 'Lea Rig, The', 9999, '');
INSERT INTO 'tune' VALUES (1216, NULL, '2012-01-20 12:54:24.096615+00', 'Brig o'' Dee', 1466, '');
INSERT INTO 'tune' VALUES (968, NULL, '2012-01-20 12:54:23.351064+00', 'Leaving Port Askaig', 1635, '');
INSERT INTO 'tune' VALUES (4178, NULL, '2012-01-20 12:54:33.953177+00', 'Mantua Makers'' Frolic', 9998, '');
INSERT INTO 'tune' VALUES (969, NULL, '2012-01-20 12:54:23.353959+00', 'Lee Mills', 1516, '');
INSERT INTO 'tune' VALUES (970, NULL, '2012-01-20 12:54:23.35685+00', 'Leeds Branch RSCDS, The', 1607, '');
INSERT INTO 'tune' VALUES (971, NULL, '2012-01-20 12:54:23.360081+00', 'Left Handed Fiddler, The', 1512, '');
INSERT INTO 'tune' VALUES (4179, NULL, '2012-01-20 12:54:33.957088+00', 'Many-a-Mickle', 948, '');
INSERT INTO 'tune' VALUES (972, NULL, '2012-01-20 12:54:23.363003+00', 'Legacy, The', 1811, '');
INSERT INTO 'tune' VALUES (973, NULL, '2012-01-20 12:54:23.36589+00', 'Lemonville Jig, The', 2257, '');
INSERT INTO 'tune' VALUES (974, NULL, '2012-01-20 12:54:23.36878+00', 'Lennox love to Blantyre', 9999, '');
INSERT INTO 'tune' VALUES (4180, NULL, '2012-01-20 12:54:33.961077+00', 'Silver Leaf, The', 709, '');
INSERT INTO 'tune' VALUES (975, NULL, '2012-01-20 12:54:23.371674+00', 'Trois Grande Luthiers, Les', 1512, '');
INSERT INTO 'tune' VALUES (976, NULL, '2012-01-20 12:54:23.374564+00', 'Lesley''s Reel', 1576, '');
INSERT INTO 'tune' VALUES (4181, NULL, '2012-01-20 12:54:33.96497+00', 'Maple Leaf Rant', 1692, '');
INSERT INTO 'tune' VALUES (977, NULL, '2012-01-20 12:54:23.377448+00', 'Let the Hackles Rise', 1533, '');
INSERT INTO 'tune' VALUES (4182, NULL, '2012-01-20 12:54:33.968764+00', 'Robbie Dickson', 1679, '');
INSERT INTO 'tune' VALUES (978, NULL, '2012-01-20 12:54:23.380336+00', 'Let us Dance and Sing', 9998, '');
INSERT INTO 'tune' VALUES (979, NULL, '2012-01-20 12:54:23.383233+00', 'Leveneep Head', 1535, '');
INSERT INTO 'tune' VALUES (4183, NULL, '2012-01-20 12:54:33.972567+00', 'Margaret Cook''s Fancy', 1558, '');
INSERT INTO 'tune' VALUES (980, NULL, '2012-01-20 12:54:23.386116+00', 'Lewis Ricardo, M.P.', 1516, '');
INSERT INTO 'tune' VALUES (1065, NULL, '2012-01-20 12:54:23.645657+00', 'Major Spicer', 1750, '');
INSERT INTO 'tune' VALUES (4184, NULL, '2012-01-20 12:54:33.976828+00', 'Miss Claire Pomeroy', 1582, '');
INSERT INTO 'tune' VALUES (981, NULL, '2012-01-20 12:54:23.389001+00', 'Liberton Pipe Band', 1975, '');
INSERT INTO 'tune' VALUES (982, NULL, '2012-01-20 12:54:23.392133+00', 'Light and Airy', 2156, '');
INSERT INTO 'tune' VALUES (4185, NULL, '2012-01-20 12:54:33.980724+00', 'Margo Bourne''s Strathspey', 1920, '');
INSERT INTO 'tune' VALUES (983, NULL, '2012-01-20 12:54:23.395037+00', 'Lilleshall''s Fancy', 1701, '');
INSERT INTO 'tune' VALUES (4186, NULL, '2012-01-20 12:54:33.984567+00', 'Margravine''s Waltz', 9998, '');
INSERT INTO 'tune' VALUES (984, NULL, '2012-01-20 12:54:23.397924+00', 'Lily of the Vale is Sweet, The', 9998, '');
INSERT INTO 'tune' VALUES (12019, '2012-02-06 12:02:48.36547+00', '2012-02-06 12:02:48.36548+00', 'Jimmy & Amy Henderson''s Silver Wedding', 1550, '');
INSERT INTO 'tune' VALUES (985, NULL, '2012-01-20 12:54:23.400813+00', 'Linda Gaul', 1502, '');
INSERT INTO 'tune' VALUES (12116, '2012-06-12 14:39:45.473981+00', '2012-06-12 14:39:45.473992+00', 'Jane''s Dream', 2197, '');
INSERT INTO 'tune' VALUES (12262, '2012-12-28 14:30:55.028972+00', '2012-12-28 14:30:55.028984+00', 'Ross''s Reel', 10086, '');
INSERT INTO 'tune' VALUES (12304, '2013-01-02 15:14:18.494005+00', '2013-01-02 15:14:18.494015+00', 'Ann''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (988, NULL, '2012-01-20 12:54:23.409473+00', 'Little Cascade, The', 1643, '');
INSERT INTO 'tune' VALUES (12366, '2013-01-04 16:08:27.154808+00', '2013-01-04 16:08:27.154819+00', 'Memories of Winston', 1633, '');
INSERT INTO 'tune' VALUES (989, NULL, '2012-01-20 12:54:23.41237+00', 'Little Peggy''s Love', 1516, '');
INSERT INTO 'tune' VALUES (12377, '2013-01-05 16:57:46.472807+00', '2013-01-05 16:57:46.472819+00', 'John Ryan''s Polka', 9999, '');
INSERT INTO 'tune' VALUES (13825, '2018-02-24 03:17:37.493945+00', '2018-02-24 03:17:37.493945+00', 'Delvinside', 9998, '');
INSERT INTO 'tune' VALUES (12405, '2013-01-06 17:14:59.647244+00', '2013-01-06 17:14:59.647255+00', 'Loch Kinord', 1538, '');
INSERT INTO 'tune' VALUES (991, NULL, '2012-01-20 12:54:23.418137+00', 'Loch Erichtside', 9998, '');
INSERT INTO 'tune' VALUES (12426, '2013-01-23 13:14:32.355493+00', '2013-01-23 13:14:32.355504+00', 'Jig for Joy, A', 1679, 'Information came from iain Gent');
INSERT INTO 'tune' VALUES (992, NULL, '2012-01-20 12:54:23.421109+00', 'Loch Leven Castle', 9999, '');
INSERT INTO 'tune' VALUES (12441, '2013-02-02 15:26:09.636354+00', '2013-02-02 15:26:09.636364+00', 'Hazel Hamilton', 1579, '');
INSERT INTO 'tune' VALUES (993, NULL, '2012-01-20 12:54:23.424006+00', 'Loch Lomond', 9999, '');
INSERT INTO 'tune' VALUES (995, NULL, '2012-01-20 12:54:23.426904+00', 'Loch Rynach', 9999, '');
INSERT INTO 'tune' VALUES (996, NULL, '2012-01-20 12:54:23.429787+00', 'Loch Torridon', 9999, '');
INSERT INTO 'tune' VALUES (997, NULL, '2012-01-20 12:54:23.432732+00', 'Lochaber', 1617, '');
INSERT INTO 'tune' VALUES (998, NULL, '2012-01-20 12:54:23.435676+00', 'Lochanside', 1700, '');
INSERT INTO 'tune' VALUES (999, NULL, '2012-01-20 12:54:23.438601+00', 'Clan MacLeod Dancers', 9998, '');
INSERT INTO 'tune' VALUES (1000, NULL, '2012-01-20 12:54:23.441524+00', 'Lochiel''s Rant', 1897, '');
INSERT INTO 'tune' VALUES (1002, NULL, '2012-01-20 12:54:23.459224+00', 'Lochleven Side', 1749, '');
INSERT INTO 'tune' VALUES (1003, NULL, '2012-01-20 12:54:23.462283+00', 'Lochmaben Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (1004, NULL, '2012-01-20 12:54:23.465196+00', 'Look Across the Water', 1857, '');
INSERT INTO 'tune' VALUES (1005, NULL, '2012-01-20 12:54:23.468098+00', 'Looking for a Partner', 1568, '');
INSERT INTO 'tune' VALUES (1006, NULL, '2012-01-20 12:54:23.470998+00', 'Lord Cathcart', 9999, '');
INSERT INTO 'tune' VALUES (1007, NULL, '2012-01-20 12:54:23.47388+00', 'Otterburn Towers', 9998, '');
INSERT INTO 'tune' VALUES (1009, NULL, '2012-01-20 12:54:23.479984+00', 'Lord Eglintoune', 9999, '');
INSERT INTO 'tune' VALUES (1010, NULL, '2012-01-20 12:54:23.482893+00', 'Lord Elgin''s Fancy', 1518, '');
INSERT INTO 'tune' VALUES (1011, NULL, '2012-01-20 12:54:23.485787+00', 'Lord Elgin''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (1012, NULL, '2012-01-20 12:54:23.488693+00', 'Lord Hume''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (1014, NULL, '2012-01-20 12:54:23.494469+00', 'Lord Macdonald', 9999, '');
INSERT INTO 'tune' VALUES (1015, NULL, '2012-01-20 12:54:23.497386+00', 'Lord Macdonald''s Reel', 263, '');
INSERT INTO 'tune' VALUES (1016, NULL, '2012-01-20 12:54:23.500277+00', 'Boland''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (1017, NULL, '2012-01-20 12:54:23.503219+00', 'Lord Moira', 1518, '');
INSERT INTO 'tune' VALUES (1018, NULL, '2012-01-20 12:54:23.506128+00', 'Lord Ramsay', 1517, '');
INSERT INTO 'tune' VALUES (1019, NULL, '2012-01-20 12:54:23.509026+00', 'Lord Rosslyn''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (1020, NULL, '2012-01-20 12:54:23.511936+00', 'Lord Saltoun', 9999, '');
INSERT INTO 'tune' VALUES (1021, NULL, '2012-01-20 12:54:23.514834+00', 'Lord Seaforth', 1447, '');
INSERT INTO 'tune' VALUES (1022, NULL, '2012-01-20 12:54:23.517724+00', 'Lord Wellington', 9999, '');
INSERT INTO 'tune' VALUES (1023, NULL, '2012-01-20 12:54:23.520618+00', 'Lord of the Dance', 9999, '');
INSERT INTO 'tune' VALUES (1024, NULL, '2012-01-20 12:54:23.523556+00', 'Lord of the Isles', 9999, '');
INSERT INTO 'tune' VALUES (12062, '2012-05-04 19:06:24.476216+00', '2013-08-19 12:00:21.121223+00', 'Misses Orgeret, The', 1502, '');
INSERT INTO 'tune' VALUES (986, NULL, '2014-11-01 02:33:17.556458+00', 'Link him Dodie', 1518, '');
INSERT INTO 'tune' VALUES (1025, NULL, '2012-01-20 12:54:23.526489+00', 'Lothian Lads', 1508, '');
INSERT INTO 'tune' VALUES (1026, NULL, '2012-01-20 12:54:23.529703+00', 'Loudon''s Bonnie Woods', 9999, '');
INSERT INTO 'tune' VALUES (1027, NULL, '2012-01-20 12:54:23.53357+00', 'Lovat Scouts, The', 1512, '');
INSERT INTO 'tune' VALUES (1028, NULL, '2012-01-20 12:54:23.536493+00', 'Lt. Murray''s Welcome to the 79th', 9998, '');
INSERT INTO 'tune' VALUES (1049, NULL, '2012-01-20 12:54:23.598307+00', 'Maid of Bellevue', 1558, '');
INSERT INTO 'tune' VALUES (1029, NULL, '2012-01-20 12:54:23.539408+00', 'Lt. Ray''s Quick Step', 9999, '');
INSERT INTO 'tune' VALUES (4187, NULL, '2012-01-20 12:54:33.988379+00', 'Cooley''s', 9999, '');
INSERT INTO 'tune' VALUES (1050, NULL, '2012-01-20 12:54:23.601222+00', 'Maid of Islay, The', 9998, '');
INSERT INTO 'tune' VALUES (1031, NULL, '2012-01-20 12:54:23.545211+00', 'Lugging the Box', 1501, '');
INSERT INTO 'tune' VALUES (4188, NULL, '2012-01-20 12:54:33.992184+00', 'Peter Straughan', 1555, '');
INSERT INTO 'tune' VALUES (1032, NULL, '2012-01-20 12:54:23.548159+00', 'MacDonald''s Rant', 9998, '');
INSERT INTO 'tune' VALUES (1051, NULL, '2012-01-20 12:54:23.604111+00', 'Maid of the Mill, The', 9999, '');
INSERT INTO 'tune' VALUES (1033, NULL, '2012-01-20 12:54:23.551077+00', 'Mr & Mrs Don Machen', 1745, '');
INSERT INTO 'tune' VALUES (4189, NULL, '2012-01-20 12:54:33.995987+00', 'Market Town Jig', 2145, '');
INSERT INTO 'tune' VALUES (1034, NULL, '2012-01-20 12:54:23.553975+00', 'Jock and Dolly Leiper', 1533, '');
INSERT INTO 'tune' VALUES (1052, NULL, '2012-01-20 12:54:23.607007+00', 'Maid on the Green, The', 9999, '');
INSERT INTO 'tune' VALUES (1035, NULL, '2012-01-20 12:54:23.556867+00', 'Ann Skipper', 9998, '');
INSERT INTO 'tune' VALUES (4190, NULL, '2012-01-20 12:54:34.00031+00', 'Marquis of Hastings'' Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (1036, NULL, '2012-01-20 12:54:23.559787+00', 'MacLeod and MacKay', 1512, '');
INSERT INTO 'tune' VALUES (1053, NULL, '2012-01-20 12:54:23.609895+00', 'Maidie Logie Robertson', 326, '');
INSERT INTO 'tune' VALUES (1037, NULL, '2012-01-20 12:54:23.562693+00', 'MacLeod of Dunvegan', 9998, '');
INSERT INTO 'tune' VALUES (4191, NULL, '2012-01-20 12:54:34.004274+00', 'Marquis of Huntly''s Strathspey', 1516, '');
INSERT INTO 'tune' VALUES (1038, NULL, '2012-01-20 12:54:23.565584+00', 'MacDonald of the Isles', 9999, '');
INSERT INTO 'tune' VALUES (1054, NULL, '2012-01-20 12:54:23.613306+00', 'Maids of Currie, The', 1909, '');
INSERT INTO 'tune' VALUES (1039, NULL, '2012-01-20 12:54:23.568477+00', 'Macfarlane''s Strathspey', 1518, '');
INSERT INTO 'tune' VALUES (4192, NULL, '2012-01-20 12:54:34.008074+00', 'Marquis of Lorn''s Strathspey', 1518, '');
INSERT INTO 'tune' VALUES (1040, NULL, '2012-01-20 12:54:23.57141+00', 'Macgregors Gathering', 9999, '');
INSERT INTO 'tune' VALUES (1041, NULL, '2012-01-20 12:54:23.574377+00', 'Machine without Horses, The', 9999, '');
INSERT INTO 'tune' VALUES (4193, NULL, '2012-01-20 12:54:34.011878+00', 'Kiltmaker''s Reel, The', 1782, '');
INSERT INTO 'tune' VALUES (1042, NULL, '2012-01-20 12:54:23.577283+00', 'Mackenzie Hay', 1512, '');
INSERT INTO 'tune' VALUES (1056, NULL, '2012-01-20 12:54:23.619099+00', 'Mairi Allan', 1740, '');
INSERT INTO 'tune' VALUES (1013, NULL, '2015-10-04 22:57:23.109964+00', 'Lord MacLay''s Reel', 1841, '');
INSERT INTO 'tune' VALUES (990, NULL, '2016-06-03 13:55:13.382814+00', 'Local Exchange, The', 228, '');
INSERT INTO 'tune' VALUES (1055, NULL, '2016-06-03 13:57:01.468857+00', 'Mainhattan Jig, The', 228, '');
INSERT INTO 'tune' VALUES (1001, NULL, '2016-10-03 23:26:58.442814+00', 'Lochiel''s awa'' to France', 1518, '');
INSERT INTO 'tune' VALUES (1030, NULL, '2017-07-07 13:23:30.608903+00', 'Lt. Col. Baillie of Leys', 1447, '');
INSERT INTO 'tune' VALUES (1043, NULL, '2012-01-20 12:54:23.580432+00', 'Madge Wildfire''s Strathspey', 1517, '');
INSERT INTO 'tune' VALUES (4194, NULL, '2012-01-20 12:54:34.015714+00', 'Souris', 210, '');
INSERT INTO 'tune' VALUES (1044, NULL, '2012-01-20 12:54:23.583349+00', 'Maggie', 9999, '');
INSERT INTO 'tune' VALUES (1057, NULL, '2012-01-20 12:54:23.622007+00', 'Mairi Bhan', 9998, '');
INSERT INTO 'tune' VALUES (1045, NULL, '2012-01-20 12:54:23.586288+00', 'Maggie Hamilton''s Jig', 1651, '');
INSERT INTO 'tune' VALUES (4195, NULL, '2012-01-20 12:54:34.02014+00', 'Miss Mary Macgregor', 1923, '');
INSERT INTO 'tune' VALUES (1046, NULL, '2012-01-20 12:54:23.589245+00', 'Maggie Lauder', 9999, '');
INSERT INTO 'tune' VALUES (1058, NULL, '2012-01-20 12:54:23.624904+00', 'Mairi Dhu', 9998, '');
INSERT INTO 'tune' VALUES (1047, NULL, '2012-01-20 12:54:23.592502+00', 'Magnum Strathspey, The', 9998, '');
INSERT INTO 'tune' VALUES (4196, NULL, '2012-01-20 12:54:34.024098+00', 'College Delight, The', 1923, '');
INSERT INTO 'tune' VALUES (1048, NULL, '2012-01-20 12:54:23.595413+00', 'Maid Behind the Bar, The', 9999, '');
INSERT INTO 'tune' VALUES (1059, NULL, '2012-01-20 12:54:23.627799+00', 'Mairi''s Wedding', 9999, '');
INSERT INTO 'tune' VALUES (1060, NULL, '2012-01-20 12:54:23.630694+00', 'Mist on the Bog', 9999, '');
INSERT INTO 'tune' VALUES (4197, NULL, '2012-01-20 12:54:34.02791+00', 'Westerness', 1473, '');
INSERT INTO 'tune' VALUES (1061, NULL, '2012-01-20 12:54:23.634035+00', 'Mairrit Man''s Favourite, The', 9998, '');
INSERT INTO 'tune' VALUES (1062, NULL, '2012-01-20 12:54:23.636947+00', 'Major Graham', 1518, '');
INSERT INTO 'tune' VALUES (1063, NULL, '2012-01-20 12:54:23.639849+00', 'Major Hamish Robertson', 326, '');
INSERT INTO 'tune' VALUES (4198, NULL, '2012-01-20 12:54:34.031745+00', 'Mary Brandon Strathspey', 1584, '');
INSERT INTO 'tune' VALUES (1064, NULL, '2012-01-20 12:54:23.642746+00', 'Major Manson', 9999, '');
INSERT INTO 'tune' VALUES (4199, NULL, '2012-01-20 12:54:34.035568+00', 'Master Frazer Johnstone', 9998, '');
INSERT INTO 'tune' VALUES (1067, NULL, '2012-01-20 12:54:23.653615+00', 'Marchioness of Huntly', 1516, '');
INSERT INTO 'tune' VALUES (4200, NULL, '2012-01-20 12:54:34.039389+00', 'Mattara Strathspey', 848, '');
INSERT INTO 'tune' VALUES (1068, NULL, '2012-01-20 12:54:23.656543+00', 'Marchioness of Huntly''s Jig, The', 1516, '');
INSERT INTO 'tune' VALUES (1070, NULL, '2012-01-20 12:54:23.662901+00', 'Margaret Anne', 1407, '');
INSERT INTO 'tune' VALUES (4201, NULL, '2012-01-20 12:54:34.04384+00', 'Winter in Tarbert', 9998, '');
INSERT INTO 'tune' VALUES (1071, NULL, '2012-01-20 12:54:23.665818+00', 'Margaret Ogilvie', 1918, '');
INSERT INTO 'tune' VALUES (1072, NULL, '2012-01-20 12:54:23.66874+00', 'Margaret''s Strathspey', 1668, '');
INSERT INTO 'tune' VALUES (1073, NULL, '2012-01-20 12:54:23.671808+00', 'Marion Barrie', 1586, '');
INSERT INTO 'tune' VALUES (4202, NULL, '2012-01-20 12:54:34.047681+00', 'Major David Manson', 1597, '');
INSERT INTO 'tune' VALUES (1074, NULL, '2012-01-20 12:54:23.674743+00', 'Marischal College', 1607, '');
INSERT INTO 'tune' VALUES (1075, NULL, '2012-01-20 12:54:23.677643+00', 'Marquess of Hartington''s Strathspey, The', 1870, '');
INSERT INTO 'tune' VALUES (1076, NULL, '2012-01-20 12:54:23.680548+00', 'Mrs Netta Gibb', 1607, '');
INSERT INTO 'tune' VALUES (4203, NULL, '2012-01-20 12:54:34.051505+00', 'Miss May Dick', 1430, '');
INSERT INTO 'tune' VALUES (1077, NULL, '2012-01-20 12:54:23.684468+00', 'Marquis of Huntly''s Farewell, The', 1516, '');
INSERT INTO 'tune' VALUES (1078, NULL, '2012-01-20 12:54:23.687537+00', 'Marquis of Huntly''s Highlanders, The', 1516, '');
INSERT INTO 'tune' VALUES (1079, NULL, '2012-01-20 12:54:23.690443+00', 'Marquis of Huntly''s Reel', 1470, '');
INSERT INTO 'tune' VALUES (4204, NULL, '2012-01-20 12:54:34.055413+00', 'Southbourne Strathspey', 1582, '');
INSERT INTO 'tune' VALUES (4205, NULL, '2012-01-20 12:54:34.059238+00', 'Carbery Reel', 1582, '');
INSERT INTO 'tune' VALUES (4206, NULL, '2012-01-20 12:54:34.063058+00', 'Gallovidian, The', 210, '');
INSERT INTO 'tune' VALUES (4207, NULL, '2012-01-20 12:54:34.067625+00', 'Kenilworth Court', 1843, '');
INSERT INTO 'tune' VALUES (4208, NULL, '2012-01-20 12:54:34.071515+00', 'Ena Smith''s Reel', 2085, '');
INSERT INTO 'tune' VALUES (4209, NULL, '2012-01-20 12:54:34.075345+00', 'Lord Boyd Orr''s March', 1558, '');
INSERT INTO 'tune' VALUES (4210, NULL, '2012-01-20 12:54:34.079174+00', 'Duchess of Athole', 9999, '');
INSERT INTO 'tune' VALUES (4211, NULL, '2012-01-20 12:54:34.082985+00', 'Ing Head', 1203, '');
INSERT INTO 'tune' VALUES (4212, NULL, '2012-01-20 12:54:34.086939+00', 'Merrylea Anniversary Reel', 1608, '');
INSERT INTO 'tune' VALUES (12020, '2012-02-06 12:04:10.838247+00', '2012-02-06 12:04:10.838258+00', 'Ladies of Lockerbie', 1656, '');
INSERT INTO 'tune' VALUES (12063, '2012-05-04 19:06:55.080048+00', '2012-05-04 19:06:55.080059+00', 'Duke Point', 1502, '');
INSERT INTO 'tune' VALUES (12263, '2012-12-28 14:33:17.000935+00', '2012-12-28 14:33:17.000946+00', 'Youngs Shetland Wedding Polka, The', 2912, '');
INSERT INTO 'tune' VALUES (12305, '2013-01-02 15:15:12.813861+00', '2013-01-02 15:15:12.813872+00', 'Casually Yours', 9999, '');
INSERT INTO 'tune' VALUES (13826, '2018-02-24 03:19:16.73207+00', '2018-02-24 03:19:16.73207+00', 'Flaggon, The', 9998, '');
INSERT INTO 'tune' VALUES (12378, '2013-01-05 16:59:13.036693+00', '2013-01-05 16:59:13.036705+00', 'Dennis Murphy''s Polka', 9999, '');
INSERT INTO 'tune' VALUES (12406, '2013-01-06 17:17:09.813013+00', '2013-01-06 17:17:09.813023+00', 'Scurdie Ness', 1538, '');
INSERT INTO 'tune' VALUES (12435, '2013-01-24 15:33:00.766677+00', '2013-01-24 15:33:00.766688+00', 'Moira Hunter', 1902, '');
INSERT INTO 'tune' VALUES (12442, '2013-02-02 15:30:17.203265+00', '2013-02-02 15:30:17.203277+00', 'Mabel Campbell', 1579, '');
INSERT INTO 'tune' VALUES (12454, '2013-02-02 17:16:47.480507+00', '2013-02-02 17:16:47.480518+00', 'Frances McDonald Waltz, The', 1579, '');
INSERT INTO 'tune' VALUES (1100, NULL, '2012-01-20 12:54:23.751737+00', 'McVicar''s Strathspey', 1518, '');
INSERT INTO 'tune' VALUES (1081, NULL, '2012-01-20 12:54:23.696313+00', 'Marquis of Tweeddale''s Favourite, The', 1438, '');
INSERT INTO 'tune' VALUES (4213, NULL, '2012-01-20 12:54:34.091309+00', 'Boatman''s Dance, The', 9999, '');
INSERT INTO 'tune' VALUES (1082, NULL, '2012-01-20 12:54:23.699252+00', 'Mr Marshall''s Compliments to Niel Gow', 1516, '');
INSERT INTO 'tune' VALUES (1101, NULL, '2012-01-20 12:54:23.754645+00', 'Meeting of the Waters, The', 1910, '');
INSERT INTO 'tune' VALUES (1083, NULL, '2012-01-20 12:54:23.702169+00', 'Martin''s Tin Whistle', 2413, '');
INSERT INTO 'tune' VALUES (4214, NULL, '2012-01-20 12:54:34.095739+00', 'Merry Uplanders, The', 1407, '');
INSERT INTO 'tune' VALUES (1084, NULL, '2012-01-20 12:54:23.70512+00', 'Mary Bain''s Wedding', 9999, '');
INSERT INTO 'tune' VALUES (1102, NULL, '2012-01-20 12:54:23.757554+00', 'Bonnie Isle O Whalsay', 9999, '');
INSERT INTO 'tune' VALUES (1085, NULL, '2012-01-20 12:54:23.708018+00', 'Mary Currie', 1576, '');
INSERT INTO 'tune' VALUES (4215, NULL, '2012-01-20 12:54:34.112177+00', 'Christine''s Air', 2100, '');
INSERT INTO 'tune' VALUES (1103, NULL, '2012-01-20 12:54:23.760486+00', 'Meg Merrilees', 9999, '');
INSERT INTO 'tune' VALUES (4216, NULL, '2012-01-20 12:54:34.116151+00', 'Sara Elizabeth', 1966, '');
INSERT INTO 'tune' VALUES (1088, NULL, '2012-01-20 12:54:23.716806+00', 'Mary Prentice''s Jig', 1821, '');
INSERT INTO 'tune' VALUES (1104, NULL, '2012-01-20 12:54:23.763388+00', 'Melville Castle', 1502, '');
INSERT INTO 'tune' VALUES (1089, NULL, '2012-01-20 12:54:23.7197+00', 'Mary and Maurice Cooper', 1533, '');
INSERT INTO 'tune' VALUES (4217, NULL, '2012-01-20 12:54:34.120709+00', 'Neil Dawson''s Strathspey', 1404, '');
INSERT INTO 'tune' VALUES (1090, NULL, '2012-01-20 12:54:23.722596+00', 'Maskelia', 1836, '');
INSERT INTO 'tune' VALUES (1105, NULL, '2012-01-20 12:54:23.766279+00', 'Menzies'' Rant, The', 1790, '');
INSERT INTO 'tune' VALUES (1091, NULL, '2012-01-20 12:54:23.725536+00', 'Mason''s Apron, The', 9999, '');
INSERT INTO 'tune' VALUES (4218, NULL, '2012-01-20 12:54:34.125197+00', 'George Wilson', 1679, '');
INSERT INTO 'tune' VALUES (1092, NULL, '2012-01-20 12:54:23.728441+00', 'Master Colin MacLeod', 9998, '');
INSERT INTO 'tune' VALUES (1106, NULL, '2012-01-20 12:54:23.769175+00', 'Merrily Danced the Quaker''s Wife', 9999, '');
INSERT INTO 'tune' VALUES (1093, NULL, '2012-01-20 12:54:23.731345+00', 'Master Erskine', 1518, '');
INSERT INTO 'tune' VALUES (4219, NULL, '2012-01-20 12:54:34.129762+00', 'Tignish', 210, '');
INSERT INTO 'tune' VALUES (1094, NULL, '2012-01-20 12:54:23.734263+00', 'Master Reginald MacDonald', 1662, '');
INSERT INTO 'tune' VALUES (1107, NULL, '2012-01-20 12:54:23.77207+00', 'Merry Dancers, The', 9999, '');
INSERT INTO 'tune' VALUES (1095, NULL, '2012-01-20 12:54:23.73718+00', 'Maxwell''s Rant', 9999, '');
INSERT INTO 'tune' VALUES (4220, NULL, '2012-01-20 12:54:34.133579+00', 'Captain Elphinstoun', 9999, '');
INSERT INTO 'tune' VALUES (1096, NULL, '2012-01-20 12:54:23.740081+00', 'McGinty''s Meal and Ale', 1532, '');
INSERT INTO 'tune' VALUES (1108, NULL, '2012-01-20 12:54:23.774965+00', 'Merry Lads of Ayr, The', 1762, '');
INSERT INTO 'tune' VALUES (1097, NULL, '2012-01-20 12:54:23.742973+00', 'Otterburn Club', 9998, '');
INSERT INTO 'tune' VALUES (4221, NULL, '2012-01-20 12:54:34.137397+00', 'Willie Miller', 1502, '');
INSERT INTO 'tune' VALUES (1098, NULL, '2012-01-20 12:54:23.745871+00', 'McIntosh Hall', 1502, '');
INSERT INTO 'tune' VALUES (1109, NULL, '2012-01-20 12:54:23.777868+00', 'Jordan''s Reel', 2989, '');
INSERT INTO 'tune' VALUES (1099, NULL, '2012-01-20 12:54:23.74882+00', 'McPhedran''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (4222, NULL, '2012-01-20 12:54:34.193751+00', 'Old Mill, The', 1408, '');
INSERT INTO 'tune' VALUES (1110, NULL, '2012-01-20 12:54:23.780771+00', 'Mid Lothian', 263, '');
INSERT INTO 'tune' VALUES (1111, NULL, '2012-01-20 12:54:23.783705+00', 'Middling, Thank You', 9999, '');
INSERT INTO 'tune' VALUES (1112, NULL, '2012-01-20 12:54:23.786766+00', 'Midlothian Pipe Band', 1879, '');
INSERT INTO 'tune' VALUES (4223, NULL, '2012-01-20 12:54:34.19758+00', 'Min-Man Dance, The', 2392, '');
INSERT INTO 'tune' VALUES (1113, NULL, '2012-01-20 12:54:23.789748+00', 'Midnight Oil', 1508, '');
INSERT INTO 'tune' VALUES (1114, NULL, '2012-01-20 12:54:23.792672+00', 'Mike Hardie', 1576, '');
INSERT INTO 'tune' VALUES (1115, NULL, '2012-01-20 12:54:23.795569+00', 'Milk Maid, The', 9999, '');
INSERT INTO 'tune' VALUES (4224, NULL, '2012-01-20 12:54:34.201382+00', 'Mirth''s Welcome', 689, '');
INSERT INTO 'tune' VALUES (1116, NULL, '2012-01-20 12:54:23.79846+00', 'Mill Burn, The', 2154, '');
INSERT INTO 'tune' VALUES (1117, NULL, '2012-01-20 12:54:23.801361+00', 'Milladen', 1512, '');
INSERT INTO 'tune' VALUES (1080, NULL, '2017-07-07 13:04:16.723174+00', 'Marquis of Huntly''s Snuff-mill, The', 1518, '');
INSERT INTO 'tune' VALUES (1069, NULL, '2017-07-07 13:15:50.351885+00', 'Marchioness of Huntly''s Strathspey, The', 1470, '');
INSERT INTO 'tune' VALUES (1118, NULL, '2012-01-20 12:54:23.804284+00', 'Miller o'' Hirn, The', 1512, '');
INSERT INTO 'tune' VALUES (4225, NULL, '2012-01-20 12:54:34.20519+00', 'Crosbie Hornpipe, The', 1582, '');
INSERT INTO 'tune' VALUES (1119, NULL, '2012-01-20 12:54:23.807221+00', 'Miller of Camserney, The', 1941, '');
INSERT INTO 'tune' VALUES (1120, NULL, '2012-01-20 12:54:23.810208+00', 'Miller of Dee, The', 9999, '');
INSERT INTO 'tune' VALUES (1121, NULL, '2012-01-20 12:54:23.813111+00', 'Tony & Olive Lansdown', 1555, '');
INSERT INTO 'tune' VALUES (4226, NULL, '2012-01-20 12:54:34.20899+00', 'Miss Anderson''s Bouquet', 1926, '');
INSERT INTO 'tune' VALUES (13827, '2018-02-24 03:20:23.537826+00', '2018-02-24 03:20:23.537826+00', 'Glengarry Gathering', 9998, '');
INSERT INTO 'tune' VALUES (1123, NULL, '2012-01-20 12:54:23.818909+00', 'Millicent''s Favourite', 9998, '');
INSERT INTO 'tune' VALUES (1124, NULL, '2012-01-20 12:54:23.821805+00', 'Millport Harbour', 1718, '');
INSERT INTO 'tune' VALUES (13893, '2018-06-09 00:54:07.789623+00', '2018-06-09 00:54:07.789623+00', 'Anne Carter''s Fancy', 1502, '');
INSERT INTO 'tune' VALUES (1125, NULL, '2012-01-20 12:54:23.824696+00', 'Mingulay Boat Song, The', 9999, '');
INSERT INTO 'tune' VALUES (1126, NULL, '2012-01-20 12:54:23.827593+00', 'Minister o'' Birse, The', 9999, '');
INSERT INTO 'tune' VALUES (1127, NULL, '2012-01-20 12:54:23.830473+00', 'Barley Crop, The', 1506, '');
INSERT INTO 'tune' VALUES (4228, NULL, '2012-01-20 12:54:34.216608+00', 'Miss Barbara Campbell', 2392, '');
INSERT INTO 'tune' VALUES (1128, NULL, '2012-01-20 12:54:23.833462+00', 'Miss Andy Campbell''s Scotch Measure', 9999, '');
INSERT INTO 'tune' VALUES (1130, NULL, '2012-01-20 12:54:23.839285+00', 'Miss Ann Edwards', 1631, '');
INSERT INTO 'tune' VALUES (4229, NULL, '2012-01-20 12:54:34.220408+00', 'Jessie''s Dream', 9998, '');
INSERT INTO 'tune' VALUES (4230, NULL, '2012-01-20 12:54:34.224215+00', 'Miss Bowie''s Delight', 1837, '');
INSERT INTO 'tune' VALUES (4231, NULL, '2012-01-20 12:54:34.228017+00', 'Miss Campbell of Menzies', 1518, '');
INSERT INTO 'tune' VALUES (4232, NULL, '2012-01-20 12:54:34.231819+00', 'Miss Clementina Stewart of Garth''s Jig', 2839, '');
INSERT INTO 'tune' VALUES (4233, NULL, '2012-01-20 12:54:34.235631+00', 'Miss Dalgleish''s Fancy', 1846, '');
INSERT INTO 'tune' VALUES (4234, NULL, '2012-01-20 12:54:34.239443+00', 'Miss Brown''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (4235, NULL, '2012-01-20 12:54:34.243239+00', 'Miss Dolland''s Delight', 9998, '');
INSERT INTO 'tune' VALUES (4236, NULL, '2012-01-20 12:54:34.247049+00', 'Miss E. Lyall', 9999, 'Often wrongly attributed to Lindsay Ross.');
INSERT INTO 'tune' VALUES (4237, NULL, '2012-01-20 12:54:34.250862+00', 'Miss E. Purcell', 1557, '');
INSERT INTO 'tune' VALUES (4238, NULL, '2012-01-20 12:54:34.254659+00', 'Mar Castle', 1512, '');
INSERT INTO 'tune' VALUES (12021, '2012-02-06 12:05:16.838648+00', '2012-02-06 12:05:16.838659+00', 'Rhona''s Wedding', 3684, '');
INSERT INTO 'tune' VALUES (12118, '2012-06-12 14:40:56.699272+00', '2012-06-12 14:40:56.699283+00', 'Rab Gray''s Bus', 1898, '');
INSERT INTO 'tune' VALUES (12264, '2012-12-28 14:38:32.93754+00', '2012-12-28 14:38:32.937551+00', 'Faded Love', 10682, '');
INSERT INTO 'tune' VALUES (12306, '2013-01-02 15:16:32.43391+00', '2013-01-02 15:16:32.433921+00', 'Gary Richard''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (12379, '2013-01-05 17:03:14.136378+00', '2013-01-05 17:03:14.136388+00', 'Kevana', 10702, '');
INSERT INTO 'tune' VALUES (12407, '2013-01-06 17:21:59.891033+00', '2013-01-06 17:21:59.891044+00', 'Magician', 1502, '');
INSERT INTO 'tune' VALUES (12436, '2013-01-24 15:33:23.032487+00', '2013-01-24 15:33:23.032498+00', 'Adviser, Charles King, The', 1902, '');
INSERT INTO 'tune' VALUES (12443, '2013-02-02 15:34:35.156798+00', '2013-02-02 15:34:35.15681+00', 'Miss Bennett''s Jig', 1454, '');
INSERT INTO 'tune' VALUES (12457, '2013-02-03 15:02:36.088393+00', '2013-02-03 15:02:36.088403+00', 'Hi Leannan', 9998, '');
INSERT INTO 'tune' VALUES (12461, '2013-02-03 15:51:05.461521+00', '2013-02-03 15:51:05.461532+00', 'Traditional Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (12464, '2013-02-03 16:22:34.911778+00', '2013-02-03 16:22:34.91179+00', 'Kris'' Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (12466, '2013-02-03 16:41:41.114524+00', '2013-02-03 16:41:41.114536+00', 'Uibhist Mo Ghraidh', 9999, '');
INSERT INTO 'tune' VALUES (1008, NULL, '2013-02-04 15:40:56.373607+00', 'Lord Eglinton''s Auld Man', 9999, '');
INSERT INTO 'tune' VALUES (12468, '2013-02-05 14:29:58.602778+00', '2013-02-05 14:29:58.602789+00', 'Lucy Cassidy', 10201, '');
INSERT INTO 'tune' VALUES (12469, '2013-02-05 14:43:38.111672+00', '2013-02-05 14:43:38.111683+00', 'Fiddler''s Rally, The', 10738, '');
INSERT INTO 'tune' VALUES (12470, '2013-02-05 15:15:03.891149+00', '2013-02-05 15:15:03.89116+00', 'Charlie''s March', 10739, '');
INSERT INTO 'tune' VALUES (12471, '2013-02-05 15:26:59.322491+00', '2013-02-05 15:26:59.322502+00', 'Shores of Loch Bee, The', 1549, '');
INSERT INTO 'tune' VALUES (12473, '2013-02-05 15:39:38.469524+00', '2013-02-05 15:39:38.469536+00', 'Hut on Staffin Island, The', 1761, '');
INSERT INTO 'tune' VALUES (12476, '2013-02-05 16:09:58.968848+00', '2013-02-05 16:09:58.968859+00', 'Hell Bound Train, The', 2656, '');
INSERT INTO 'tune' VALUES (12477, '2013-02-06 11:28:24.394832+00', '2013-02-06 11:28:24.394844+00', 'Highland Piper''s Society of Glasgow', 9998, '');
INSERT INTO 'tune' VALUES (12479, '2013-02-06 12:47:35.420003+00', '2013-02-06 12:47:35.420015+00', 'Jeannie Gray', 9998, '');
INSERT INTO 'tune' VALUES (1131, NULL, '2012-01-20 12:54:23.842176+00', 'Miss Ann Lothian''s Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (1151, NULL, '2012-01-20 12:54:23.901042+00', 'Miss Caroline Thomson''s Reel', 1967, '');
INSERT INTO 'tune' VALUES (4239, NULL, '2012-01-20 12:54:34.25847+00', 'Miss French of Tayside', 1931, '');
INSERT INTO 'tune' VALUES (1133, NULL, '2012-01-20 12:54:23.848037+00', 'Jackie and Lawson Thomson', 1527, '');
INSERT INTO 'tune' VALUES (1152, NULL, '2012-01-20 12:54:23.904108+00', 'Miss Catherine Maxwell''s Scots Measure', 1401, '');
INSERT INTO 'tune' VALUES (4240, NULL, '2012-01-20 12:54:34.262286+00', 'Miss Girdle', 9999, '');
INSERT INTO 'tune' VALUES (1134, NULL, '2012-01-20 12:54:23.850938+00', 'Miss Anne Mechie', 1823, '');
INSERT INTO 'tune' VALUES (1135, NULL, '2012-01-20 12:54:23.853858+00', 'Miss Audrey Hinchcliffe''s Strathspey', 1558, '');
INSERT INTO 'tune' VALUES (1153, NULL, '2012-01-20 12:54:23.907036+00', 'Miss Catherine Stewart', 1516, '');
INSERT INTO 'tune' VALUES (4241, NULL, '2012-01-20 12:54:34.266098+00', 'Octogenarian, The', 1586, '');
INSERT INTO 'tune' VALUES (1137, NULL, '2012-01-20 12:54:23.859814+00', 'Miss Barbara Cunningham', 1519, '');
INSERT INTO 'tune' VALUES (1154, NULL, '2012-01-20 12:54:23.909935+00', 'Miss Catherine Stewart, Pettyvaich', 1516, '');
INSERT INTO 'tune' VALUES (1138, NULL, '2012-01-20 12:54:23.86273+00', 'Miss Barstow''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (1139, NULL, '2012-01-20 12:54:23.865625+00', 'Miss Begg of Benton', 9998, '');
INSERT INTO 'tune' VALUES (12455, '2013-02-03 14:33:39.467698+00', '2013-11-26 17:06:17.465824+00', 'Alan and Helen Mann', 10165, '');
INSERT INTO 'tune' VALUES (1087, NULL, '2014-08-19 08:11:02.208215+00', 'Mary Morison', 9999, '');
INSERT INTO 'tune' VALUES (4242, NULL, '2014-11-08 23:13:50.087929+00', 'Miss Isaac Forsyth-Elgin', 1516, '');
INSERT INTO 'tune' VALUES (1155, NULL, '2012-01-20 12:54:23.912833+00', 'Miss Charlotte Bruce', 9999, '');
INSERT INTO 'tune' VALUES (4243, NULL, '2012-01-20 12:54:34.273692+00', 'Andrew Rankine''s Compliments to Lindsay Ross', 1533, '');
INSERT INTO 'tune' VALUES (1140, NULL, '2012-01-20 12:54:23.86852+00', 'Miss Betsy Robertson', 9999, '');
INSERT INTO 'tune' VALUES (1156, NULL, '2012-01-20 12:54:23.915741+00', 'Miss Christie of Durrie', 1939, '');
INSERT INTO 'tune' VALUES (4244, NULL, '2012-01-20 12:54:34.27749+00', 'Miss Jane Wright''s Jig', 1607, '');
INSERT INTO 'tune' VALUES (1142, NULL, '2012-01-20 12:54:23.874898+00', 'Bruce Trail, The', 249, '');
INSERT INTO 'tune' VALUES (1143, NULL, '2012-01-20 12:54:23.877804+00', 'Twenty-fifth Anniversary of Peterhead Scottish Week', 467, '');
INSERT INTO 'tune' VALUES (12428, '2013-01-23 13:21:30.719418+00', '2018-10-30 17:20:53.37786+00', 'Reel O'' Deans', 10728, '');
INSERT INTO 'tune' VALUES (4245, NULL, '2012-01-20 12:54:34.281285+00', 'Miss Jarvis''s Reel', 1607, '');
INSERT INTO 'tune' VALUES (1144, NULL, '2012-01-20 12:54:23.880747+00', 'Miss Brooke', 1512, '');
INSERT INTO 'tune' VALUES (1145, NULL, '2012-01-20 12:54:23.883657+00', 'Miss Burns''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (4246, NULL, '2012-01-20 12:54:34.285084+00', 'Miss Jean Matheson', 2054, '');
INSERT INTO 'tune' VALUES (1147, NULL, '2012-01-20 12:54:23.889451+00', 'Miss Cahoon''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (1159, NULL, '2012-01-20 12:54:23.924478+00', 'Miss Clementina Stewart''s Reel', 1486, '');
INSERT INTO 'tune' VALUES (4247, NULL, '2012-01-20 12:54:34.288895+00', 'James Hamilton of Auchencruive', 2054, '');
INSERT INTO 'tune' VALUES (1148, NULL, '2012-01-20 12:54:23.892349+00', 'Miss Campbell', 1598, '');
INSERT INTO 'tune' VALUES (1149, NULL, '2012-01-20 12:54:23.895246+00', 'Gordon, The', 9998, '');
INSERT INTO 'tune' VALUES (1160, NULL, '2012-01-20 12:54:23.927418+00', 'Miss Condie''s Reel', 1801, '');
INSERT INTO 'tune' VALUES (4248, NULL, '2012-01-20 12:54:34.292728+00', 'Miss Jean R Hood', 885, '');
INSERT INTO 'tune' VALUES (1150, NULL, '2012-01-20 12:54:23.898138+00', 'When The Battle Is Over', 1514, '');
INSERT INTO 'tune' VALUES (1161, NULL, '2012-01-20 12:54:23.930331+00', 'Miss Corbett''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (1162, NULL, '2012-01-20 12:54:23.933254+00', 'Jimmy Ritchie of Penicuik', 1679, '');
INSERT INTO 'tune' VALUES (4249, NULL, '2012-01-20 12:54:34.296525+00', 'Bonnie Jean', 9999, '');
INSERT INTO 'tune' VALUES (1163, NULL, '2012-01-20 12:54:23.936151+00', 'Miss Coxe''s Strathspey', 1388, '');
INSERT INTO 'tune' VALUES (1164, NULL, '2012-01-20 12:54:23.939042+00', 'Miss Dickson''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (1165, NULL, '2012-01-20 12:54:23.941924+00', 'Miss Dorothy Shaw', 1843, '');
INSERT INTO 'tune' VALUES (4250, NULL, '2012-01-20 12:54:34.300329+00', 'You''re Sitting in my Chair', 1932, '');
INSERT INTO 'tune' VALUES (1217, NULL, '2012-01-20 12:54:24.099548+00', 'Miss Marion Ferguson', 1439, '');
INSERT INTO 'tune' VALUES (1218, NULL, '2012-01-20 12:54:24.102444+00', 'Miss Marston''s Strathspey', 1867, '');
INSERT INTO 'tune' VALUES (4278, NULL, '2012-01-20 12:54:34.407933+00', 'Mol-a-Deas', 3615, '');
INSERT INTO 'tune' VALUES (1219, NULL, '2012-01-20 12:54:24.10535+00', 'Miss Mary Douglas', 1518, '');
INSERT INTO 'tune' VALUES (1220, NULL, '2012-01-20 12:54:24.108306+00', 'Miss Mary Milne', 165, '');
INSERT INTO 'tune' VALUES (1221, NULL, '2012-01-20 12:54:24.1112+00', 'Miss Maule''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (1157, NULL, '2017-03-03 13:43:55.94683+00', 'Miss Chirsty Stewart', 10507, '');
INSERT INTO 'tune' VALUES (1166, NULL, '2012-01-20 12:54:23.944848+00', 'Miss Dow''s Fancy', 1512, 'Alan Macpherson (amdmac [at] blueyonder.co.uk), devier of Miss Dow''s Strathspey, writes: 



"The composer of the tune ''Miss Dow''s Fancy'' was John Reid (1869-1942), a famous Angus "Dancie" from Newtyle. He taught step dancing at the early Summer Schools and his Newtyle Orchestra provided the music for the Younger Hall dances. ''Miss Dow''s Fancy'' was first played by John Reid''s orchestra at a Dundee Branch dance in the Training College Hall on the 14th December, 1934"



Could this be another tune of the same name?');
INSERT INTO 'tune' VALUES (1167, NULL, '2012-01-20 12:54:23.947777+00', 'Miss Dumbreck', 1518, '');
INSERT INTO 'tune' VALUES (1168, NULL, '2012-01-20 12:54:23.950676+00', 'Miss Edwina Angus', 1607, '');
INSERT INTO 'tune' VALUES (4251, NULL, '2012-01-20 12:54:34.304134+00', 'Miss Johnston of Hilton''s Fancy', 1517, '');
INSERT INTO 'tune' VALUES (1169, NULL, '2012-01-20 12:54:23.953622+00', 'Miss Eileen Stuart''s Jig', 1754, '');
INSERT INTO 'tune' VALUES (1170, NULL, '2012-01-20 12:54:23.956529+00', 'Miss Elizabeth Anne Hale', 1590, '');
INSERT INTO 'tune' VALUES (1171, NULL, '2012-01-20 12:54:23.959426+00', 'Miss Elizabeth Ferguson''s Favourite', 1695, '');
INSERT INTO 'tune' VALUES (4252, NULL, '2012-01-20 12:54:34.307962+00', 'Miss Judith Baillie of Dochfour', 1933, '');
INSERT INTO 'tune' VALUES (1172, NULL, '2012-01-20 12:54:23.962324+00', 'Miss Elizabeth Magd. Fordyce Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (1173, NULL, '2012-01-20 12:54:23.965231+00', 'Miss Erskine of Torry', 1939, '');
INSERT INTO 'tune' VALUES (4253, NULL, '2012-01-20 12:54:34.311746+00', 'Goodbe Mrs Durkin', 9999, '');
INSERT INTO 'tune' VALUES (4254, NULL, '2012-01-20 12:54:34.315541+00', 'Miss Knowles', 9998, '');
INSERT INTO 'tune' VALUES (4255, NULL, '2012-01-20 12:54:34.319428+00', 'Miss Urquart of Meldrum', 1934, '');
INSERT INTO 'tune' VALUES (4256, NULL, '2012-01-20 12:54:34.323226+00', 'Miss MacDonald''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (4257, NULL, '2012-01-20 12:54:34.327774+00', 'Miss Macintosh', 9999, '');
INSERT INTO 'tune' VALUES (4258, NULL, '2012-01-20 12:54:34.331624+00', 'Miss MacLachlan''s March', 9999, '');
INSERT INTO 'tune' VALUES (4259, NULL, '2012-01-20 12:54:34.335425+00', 'Miss Margaret Donaldson''s Welcome to Allestree', 1463, '');
INSERT INTO 'tune' VALUES (4260, NULL, '2012-01-20 12:54:34.339231+00', 'Miss L Montgomery of Skelmorie''s Strathspey', 1458, '');
INSERT INTO 'tune' VALUES (4261, NULL, '2012-01-20 12:54:34.343038+00', 'Peat Moss', 9998, '');
INSERT INTO 'tune' VALUES (4262, NULL, '2012-01-20 12:54:34.34688+00', 'Miss Rosy Powell', 1137, '');
INSERT INTO 'tune' VALUES (4263, NULL, '2012-01-20 12:54:34.350675+00', 'Wandering Willie', 1517, '');
INSERT INTO 'tune' VALUES (12022, '2012-02-06 12:06:37.111137+00', '2012-02-06 12:06:37.111147+00', 'John Huband''s Dancing Fingers', 10601, '');
INSERT INTO 'tune' VALUES (12065, '2012-05-04 19:08:20.47225+00', '2012-05-04 19:08:20.472261+00', 'Fiddling Frank', 1502, '');
INSERT INTO 'tune' VALUES (12265, '2012-12-28 14:40:15.752468+00', '2012-12-28 14:40:15.75248+00', 'Lily Dale', 10683, '');
INSERT INTO 'tune' VALUES (12307, '2013-01-02 15:17:48.765174+00', '2013-01-02 15:17:48.765186+00', 'Fiddlin'' Jam Session Reel', 9999, '');
INSERT INTO 'tune' VALUES (12380, '2013-01-05 17:04:31.968782+00', '2013-01-05 17:04:31.968793+00', 'Isle of Capri, The', 2544, '');
INSERT INTO 'tune' VALUES (12429, '2013-01-23 13:22:38.608933+00', '2013-01-23 13:22:38.608944+00', 'Three Score and Ten', 10728, 'Information came from Iain Gent');
INSERT INTO 'tune' VALUES (633, NULL, '2013-01-24 15:41:22.77687+00', 'Gushet Neuk', 1902, '');
INSERT INTO 'tune' VALUES (12444, '2013-02-02 15:37:42.13164+00', '2013-02-02 15:37:42.131651+00', 'Ann & Jim Patterson of Abernethy', 1579, '');
INSERT INTO 'tune' VALUES (12456, '2013-02-03 14:39:19.435249+00', '2013-02-03 14:39:19.43526+00', 'Little Brown Island, The', 9998, '');
INSERT INTO 'tune' VALUES (12458, '2013-02-03 15:04:53.6845+00', '2013-02-03 15:04:53.684512+00', 'By the Shores of Loch Etive', 9998, '');
INSERT INTO 'tune' VALUES (12462, '2013-02-03 15:52:33.941431+00', '2013-02-03 15:52:33.941442+00', 'Allan H Cameron', 10165, '');
INSERT INTO 'tune' VALUES (12465, '2013-02-03 16:27:24.7261+00', '2013-02-03 16:27:24.726111+00', 'John Whyte''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (12472, '2013-02-05 15:28:12.491261+00', '2013-02-05 15:28:12.491272+00', 'Dark Waters of Loch Shiel, The', 3052, '');
INSERT INTO 'tune' VALUES (12474, '2013-02-05 15:45:31.073893+00', '2013-02-05 15:45:31.073905+00', 'Dawning of the Day', 10745, '');
INSERT INTO 'tune' VALUES (12478, '2013-02-06 11:30:54.365126+00', '2013-02-06 11:30:54.365138+00', 'Lorna Ann Stirrat''s Waltz', 1456, '');
INSERT INTO 'tune' VALUES (1503, NULL, '2012-01-20 12:54:25.049647+00', 'Rachel Rae', 445, '');
INSERT INTO 'tune' VALUES (1141, NULL, '2022-08-22 23:22:57.920872+00', 'Miss Betty Hunter', 1928, '');
INSERT INTO 'tune' VALUES (1146, NULL, '2023-01-01 02:05:55.751263+00', 'Miss C. M. Barbour', 1527, '');
INSERT INTO 'tune' VALUES (12480, '2013-02-06 13:07:36.28653+00', '2013-02-06 13:07:36.286541+00', 'Eriskay Ferryman, The', 9998, '');
INSERT INTO 'tune' VALUES (1194, NULL, '2012-01-20 12:54:24.026637+00', 'Miss J. Rose''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (1175, NULL, '2012-01-20 12:54:23.971066+00', 'Miss Falconer', 9999, '');
INSERT INTO 'tune' VALUES (4264, NULL, '2012-01-20 12:54:34.354472+00', '93rd''s Farewell to Edinburgh, The', 9999, '');
INSERT INTO 'tune' VALUES (1176, NULL, '2012-01-20 12:54:23.974021+00', 'Miss Maule of Panmure', 1517, '');
INSERT INTO 'tune' VALUES (1177, NULL, '2012-01-20 12:54:23.976984+00', 'Miss Fiona MacRae of Conchra', 9998, '');
INSERT INTO 'tune' VALUES (4265, NULL, '2012-01-20 12:54:34.358356+00', 'Miss Sayers'' Allemande', 9998, '');
INSERT INTO 'tune' VALUES (1196, NULL, '2012-01-20 12:54:24.033931+00', 'Miss Jane Stewart', 1516, '');
INSERT INTO 'tune' VALUES (1178, NULL, '2012-01-20 12:54:23.979898+00', 'Miss Flora''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (1179, NULL, '2012-01-20 12:54:23.982795+00', 'Miss Forbes'' Farewell to Banff', 1934, '');
INSERT INTO 'tune' VALUES (4266, NULL, '2012-01-20 12:54:34.362155+00', 'Miss Scales'' Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (1197, NULL, '2012-01-20 12:54:24.037352+00', 'Miss Janet Laing''s Strathspey', 1607, '');
INSERT INTO 'tune' VALUES (1180, '2006-08-27 22:00:00+00', '2012-01-20 12:54:23.985703+00', 'Tea Lady, The', 1590, '');
INSERT INTO 'tune' VALUES (1181, NULL, '2012-01-20 12:54:23.988629+00', 'Miss Gayton''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (1198, NULL, '2012-01-20 12:54:24.041309+00', 'Miss Jean Milligan', 1560, '');
INSERT INTO 'tune' VALUES (1182, NULL, '2012-01-20 12:54:23.991532+00', 'Miss Geddes', 9998, '');
INSERT INTO 'tune' VALUES (1183, NULL, '2012-01-20 12:54:23.994427+00', 'Miss Gill Henderson', 9998, '');
INSERT INTO 'tune' VALUES (4268, NULL, '2012-01-20 12:54:34.369763+00', 'Miss Spark''s Maggot', 9998, '');
INSERT INTO 'tune' VALUES (1199, NULL, '2012-01-20 12:54:24.044877+00', 'Miss Jean Raeburn', 274, '');
INSERT INTO 'tune' VALUES (1184, NULL, '2012-01-20 12:54:23.997328+00', 'Miss Graham of Inchbrakie', 1517, '');
INSERT INTO 'tune' VALUES (1185, NULL, '2012-01-20 12:54:24.000258+00', 'Miss Grant of Elchies', 1516, '');
INSERT INTO 'tune' VALUES (4269, NULL, '2012-01-20 12:54:34.373569+00', 'Miss Susan Campbell Menzies', 9999, '');
INSERT INTO 'tune' VALUES (1200, NULL, '2012-01-20 12:54:24.048083+00', 'Miss Jean Stewart', 1784, '');
INSERT INTO 'tune' VALUES (1186, NULL, '2012-01-20 12:54:24.003181+00', 'Miss Grant of Grant', 1519, '');
INSERT INTO 'tune' VALUES (1174, NULL, '2014-11-08 23:16:21.78793+00', 'Miss Esther Oswald of Auchencruive', 1519, '');
INSERT INTO 'tune' VALUES (1158, NULL, '2014-11-17 23:35:59.197302+00', 'Miss Clementina Loughnan', 1518, '');
INSERT INTO 'tune' VALUES (1187, NULL, '2012-01-20 12:54:24.006089+00', 'Miss Hamilton of Bangowrie', 9998, '');
INSERT INTO 'tune' VALUES (4270, NULL, '2012-01-20 12:54:34.377378+00', 'Miss Taylor', 1516, '');
INSERT INTO 'tune' VALUES (1201, NULL, '2012-01-20 12:54:24.051191+00', 'Miss Jeanie S. Grant''s Favourite', 1807, '');
INSERT INTO 'tune' VALUES (1188, NULL, '2012-01-20 12:54:24.008994+00', 'Miss Hanbury''s Fancy', 10504, '');
INSERT INTO 'tune' VALUES (1189, NULL, '2012-01-20 12:54:24.011918+00', 'John Hay''s Bonny Lassie', 9999, '');
INSERT INTO 'tune' VALUES (4271, NULL, '2012-01-20 12:54:34.38118+00', 'Miss Vyvian Wells', 783, '');
INSERT INTO 'tune' VALUES (1202, NULL, '2012-01-20 12:54:24.054256+00', 'Miss Jeany Abernethie', 1934, '');
INSERT INTO 'tune' VALUES (1191, NULL, '2012-01-20 12:54:24.017719+00', 'Miss Hope''s Strathspey', 1476, '');
INSERT INTO 'tune' VALUES (4272, NULL, '2012-01-20 12:54:34.384978+00', 'Old Scotch Measure, An', 9998, '');
INSERT INTO 'tune' VALUES (1203, NULL, '2012-01-20 12:54:24.057347+00', 'Miss Jenny Elliot''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (1192, NULL, '2012-01-20 12:54:24.020624+00', 'Miss Hutton', 1749, '');
INSERT INTO 'tune' VALUES (1193, NULL, '2012-01-20 12:54:24.023608+00', 'Miss Irene Fidler''s Strathspey', 33, '');
INSERT INTO 'tune' VALUES (4273, NULL, '2012-01-20 12:54:34.388786+00', 'Miss Allison Brown', 1814, '');
INSERT INTO 'tune' VALUES (13828, '2018-02-24 03:21:19.79002+00', '2018-02-24 03:21:19.79002+00', 'Highland Wedding', 9998, '');
INSERT INTO 'tune' VALUES (1205, NULL, '2012-01-20 12:54:24.06411+00', 'Miss Jessie Smith', 9999, '');
INSERT INTO 'tune' VALUES (1206, NULL, '2012-01-20 12:54:24.067072+00', 'Miss Lesley Lowe', 1576, '');
INSERT INTO 'tune' VALUES (4274, NULL, '2012-01-20 12:54:34.3926+00', 'Bonnie Sheila''s Hornpipe', 1582, '');
INSERT INTO 'tune' VALUES (1207, NULL, '2012-01-20 12:54:24.069993+00', 'Miss Leslie Campbell''s Strathspey', 1607, '');
INSERT INTO 'tune' VALUES (1208, NULL, '2012-01-20 12:54:24.072906+00', 'Miss Lyall (strathspey)', 9999, '');
INSERT INTO 'tune' VALUES (1209, NULL, '2012-01-20 12:54:24.075811+00', 'Miss Mackenzie''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (4275, NULL, '2012-01-20 12:54:34.396517+00', 'Neil''s Hornpipe', 1329, '');
INSERT INTO 'tune' VALUES (1210, NULL, '2012-01-20 12:54:24.078707+00', 'Miss Macpherson of Giliston', 9999, '');
INSERT INTO 'tune' VALUES (1211, NULL, '2012-01-20 12:54:24.081601+00', 'Miss Macpherson''s Reel', 1516, '');
INSERT INTO 'tune' VALUES (1212, NULL, '2012-01-20 12:54:24.084502+00', 'Miss Margaret Anderson', 1502, '');
INSERT INTO 'tune' VALUES (4276, NULL, '2012-01-20 12:54:34.40033+00', 'Kaim Park', 1538, '');
INSERT INTO 'tune' VALUES (1213, NULL, '2012-01-20 12:54:24.087403+00', 'Miss Margaret Brander, J.P.', 1658, '');
INSERT INTO 'tune' VALUES (1214, NULL, '2012-01-20 12:54:24.090293+00', 'Miss Margaret Gordon', 1519, '');
INSERT INTO 'tune' VALUES (1215, NULL, '2012-01-20 12:54:24.09335+00', 'Miss Margaret McLaren', 1502, '');
INSERT INTO 'tune' VALUES (4277, NULL, '2012-01-20 12:54:34.404138+00', 'Sherwood Rangers, The', 9999, '');
INSERT INTO 'tune' VALUES (4267, NULL, '2015-06-19 11:17:19.747156+00', 'Miss Sophia Campbell of Saddell''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (4279, NULL, '2012-01-20 12:54:34.411959+00', 'Scotia', 210, '');
INSERT INTO 'tune' VALUES (1222, NULL, '2012-01-20 12:54:24.114094+00', 'Sooth End, Da', 1677, '');
INSERT INTO 'tune' VALUES (1223, NULL, '2012-01-20 12:54:24.117491+00', 'Miss Milligan', 9999, '');
INSERT INTO 'tune' VALUES (4280, NULL, '2012-01-20 12:54:34.415831+00', 'Jan''s Jig', 1938, '');
INSERT INTO 'tune' VALUES (4281, NULL, '2012-01-20 12:54:34.419632+00', 'Jimmy Stewart', 1614, '');
INSERT INTO 'tune' VALUES (4282, NULL, '2012-01-20 12:54:34.423451+00', 'Montrose Races', 9998, '');
INSERT INTO 'tune' VALUES (4283, NULL, '2012-01-20 12:54:34.427249+00', 'Alices Dollie', 1512, '');
INSERT INTO 'tune' VALUES (4284, NULL, '2012-01-20 12:54:34.43105+00', 'Phoenix, The', 9998, '');
INSERT INTO 'tune' VALUES (4285, NULL, '2012-01-20 12:54:34.434849+00', 'More Toast for the Boys', 9998, '');
INSERT INTO 'tune' VALUES (4286, NULL, '2012-01-20 12:54:34.438657+00', 'Moray''s Jig', 1776, '');
INSERT INTO 'tune' VALUES (4287, NULL, '2012-01-20 12:54:34.442454+00', 'Morison''s Bush', 1872, '');
INSERT INTO 'tune' VALUES (4288, NULL, '2012-01-20 12:54:34.446247+00', 'Nancy', 1940, '');
INSERT INTO 'tune' VALUES (4289, NULL, '2012-01-20 12:54:34.450039+00', 'Mother Brown''s Cat', 9998, '');
INSERT INTO 'tune' VALUES (4290, NULL, '2012-01-20 12:54:34.453836+00', 'Mr & Mrs Victor Jamieson', 1527, '');
INSERT INTO 'tune' VALUES (12023, '2012-02-06 12:09:59.018904+00', '2012-02-06 12:09:59.018914+00', 'John & Ann Neave''s Silver Wedding March', 1777, '');
INSERT INTO 'tune' VALUES (12120, '2012-06-12 14:41:59.500856+00', '2012-06-12 14:41:59.500866+00', 'Water Aid', 1576, '');
INSERT INTO 'tune' VALUES (12266, '2012-12-28 14:43:49.245107+00', '2012-12-28 14:43:49.245118+00', 'Miss Adrianne Farnan', 10270, '');
INSERT INTO 'tune' VALUES (12308, '2013-01-02 15:24:24.586803+00', '2013-01-02 15:24:24.586813+00', 'Gigue du Forgeron', 9999, '');
INSERT INTO 'tune' VALUES (12381, '2013-01-05 17:09:14.965169+00', '2013-01-05 17:09:14.965181+00', 'Over Balgray', 10703, '');
INSERT INTO 'tune' VALUES (12445, '2013-02-02 15:49:50.273945+00', '2013-02-02 15:49:50.273957+00', 'Hatton Hill', 2275, '');
INSERT INTO 'tune' VALUES (12463, '2013-02-03 15:55:07.261615+00', '2013-02-03 15:55:07.261627+00', 'Alex C MacGregor', 10165, '');
INSERT INTO 'tune' VALUES (12475, '2013-02-05 15:51:07.235891+00', '2013-02-05 15:51:07.235902+00', 'Cameron Quickstep, The', 1512, '');
INSERT INTO 'tune' VALUES (12482, '2013-02-06 14:12:48.696934+00', '2013-02-06 14:12:48.696945+00', 'Nach Aghmhor', 9999, '');
INSERT INTO 'tune' VALUES (12481, '2013-02-06 14:02:31.640592+00', '2013-02-06 14:21:11.009969+00', 'Will You Go with Me My Fair One', 9998, '');
INSERT INTO 'tune' VALUES (12483, '2013-02-15 18:48:13.960703+00', '2013-02-15 18:48:13.960714+00', 'Mrs Elder', 9998, '');
INSERT INTO 'tune' VALUES (12486, '2013-02-22 15:35:22.695496+00', '2013-02-22 15:35:22.695507+00', 'President Garfield', 10752, '');
INSERT INTO 'tune' VALUES (12495, '2013-02-27 12:32:40.15964+00', '2013-02-27 12:32:40.159651+00', 'L.S.Q. Figure 1', 9999, '');
INSERT INTO 'tune' VALUES (1224, '2005-03-02 23:00:00+00', '2012-01-20 12:54:24.120433+00', 'Liquid Assets', 1508, '');
INSERT INTO 'tune' VALUES (1244, NULL, '2012-01-20 12:54:24.192348+00', 'Miss Taylor''s Mince Pies', 9998, '');
INSERT INTO 'tune' VALUES (1225, NULL, '2012-01-20 12:54:24.123384+00', 'Miss Monaghan', 2141, '');
INSERT INTO 'tune' VALUES (1226, NULL, '2012-01-20 12:54:24.126343+00', 'Miss Murray of Lintrose', 1749, '');
INSERT INTO 'tune' VALUES (4291, NULL, '2012-01-20 12:54:34.457643+00', 'Mr Beveridge''s Maggot', 9998, '');
INSERT INTO 'tune' VALUES (1227, NULL, '2012-01-20 12:54:24.134401+00', 'Miss Murray of Ochtertyre', 1749, '');
INSERT INTO 'tune' VALUES (1228, NULL, '2012-01-20 12:54:24.138254+00', 'Miss Nancy Arnott', 1585, '');
INSERT INTO 'tune' VALUES (4292, NULL, '2012-01-20 12:54:34.461448+00', 'Mr Compton of Compton Hall', 9998, '');
INSERT INTO 'tune' VALUES (1246, NULL, '2012-01-20 12:54:24.198224+00', 'Miss Watson''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (1229, NULL, '2012-01-20 12:54:24.142097+00', 'Miss Nancy Frowns', 9999, '');
INSERT INTO 'tune' VALUES (1230, NULL, '2012-01-20 12:54:24.145972+00', 'Miss Ogilvie''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (1247, NULL, '2012-01-20 12:54:24.201134+00', 'Miss Watt''s Jig', 1516, '');
INSERT INTO 'tune' VALUES (13829, '2018-02-24 03:22:27.196777+00', '2018-02-24 03:22:27.196777+00', 'Hills of South Uist', 9998, '');
INSERT INTO 'tune' VALUES (1232, NULL, '2012-01-20 12:54:24.154322+00', 'Miss Rae of Eskgrove', 1517, '');
INSERT INTO 'tune' VALUES (4294, NULL, '2012-01-20 12:54:34.469051+00', 'Mr Isaac''s Maggot', 9998, '');
INSERT INTO 'tune' VALUES (1233, NULL, '2012-01-20 12:54:24.158147+00', 'Miss Rae''s Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (1234, NULL, '2012-01-20 12:54:24.161971+00', 'Miss Reay of Killingworth''s Favourite', 1401, '');
INSERT INTO 'tune' VALUES (4295, NULL, '2012-01-20 12:54:34.472857+00', 'Mr Lane''s Maggot', 9998, '');
INSERT INTO 'tune' VALUES (1249, NULL, '2012-01-20 12:54:24.206925+00', 'Miss Wilma Miller', 1502, '');
INSERT INTO 'tune' VALUES (1235, NULL, '2012-01-20 12:54:24.165463+00', 'Miss Robertson''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (1236, NULL, '2012-01-20 12:54:24.168571+00', 'Miss Rose''s Fancy', 1449, '');
INSERT INTO 'tune' VALUES (4296, NULL, '2012-01-20 12:54:34.476677+00', 'Mr Sharp''s Favourite', 9998, '');
INSERT INTO 'tune' VALUES (1250, NULL, '2012-01-20 12:54:24.209819+00', 'Misses Cramb of Linlithgow, The', 1607, '');
INSERT INTO 'tune' VALUES (1237, NULL, '2012-01-20 12:54:24.171479+00', 'Miss Rose''s Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (1238, NULL, '2012-01-20 12:54:24.174372+00', 'Miss Sally Hunter', 1517, '');
INSERT INTO 'tune' VALUES (4297, NULL, '2012-01-20 12:54:34.480478+00', 'Mr William Brown''s Reel', 1425, '');
INSERT INTO 'tune' VALUES (1239, NULL, '2012-01-20 12:54:24.177262+00', 'Miss Scott of Usan', 9998, '');
INSERT INTO 'tune' VALUES (1240, NULL, '2012-01-20 12:54:24.180159+00', 'Miss Spens Munro''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (4298, NULL, '2012-01-20 12:54:34.484286+00', 'Mrs Bingham''s Fancy', 1943, '');
INSERT INTO 'tune' VALUES (1252, NULL, '2012-01-20 12:54:24.215769+00', 'Moness Falls', 1836, '');
INSERT INTO 'tune' VALUES (1242, NULL, '2012-01-20 12:54:24.18594+00', 'Top of Cork Road', 9999, '');
INSERT INTO 'tune' VALUES (4299, NULL, '2012-01-20 12:54:34.488092+00', 'Mrs Booth''s Minuet', 9998, '');
INSERT INTO 'tune' VALUES (1243, NULL, '2012-01-20 12:54:24.188836+00', 'Miss Susan Inglis', 1502, '');
INSERT INTO 'tune' VALUES (1254, NULL, '2012-01-20 12:54:24.221619+00', 'Monro''s Rant', 9998, '');
INSERT INTO 'tune' VALUES (4300, NULL, '2012-01-20 12:54:34.491903+00', 'Mrs Catherine Sherrit', 1538, '');
INSERT INTO 'tune' VALUES (12459, '2013-02-03 15:17:45.627014+00', '2014-11-06 15:35:05.12321+00', 'Clan MacColl, The', 1694, '');
INSERT INTO 'tune' VALUES (1248, NULL, '2014-11-17 22:14:49.016422+00', 'Miss William''s Fancy', 263, '');
INSERT INTO 'tune' VALUES (1241, NULL, '2014-11-17 22:17:16.4196+00', 'Miss Stewart of Bombay', 1516, '');
INSERT INTO 'tune' VALUES (1255, NULL, '2012-01-20 12:54:24.229838+00', 'Montreal Rendezvous', 1836, '');
INSERT INTO 'tune' VALUES (1256, NULL, '2012-01-20 12:54:24.232808+00', 'Montrose Reel', 1607, '');
INSERT INTO 'tune' VALUES (1257, NULL, '2012-01-20 12:54:24.235714+00', 'Sir Archibald Grant of Monymusk', 1781, '');
INSERT INTO 'tune' VALUES (4301, NULL, '2012-01-20 12:54:34.495701+00', 'Mrs Double''s Farewell to Aberdeen', 1945, '');
INSERT INTO 'tune' VALUES (1258, NULL, '2012-01-20 12:54:24.238615+00', 'Morag & Brian Wilkinson', 1593, '');
INSERT INTO 'tune' VALUES (13894, '2018-06-09 00:58:23.125778+00', '2018-06-09 00:58:23.125778+00', 'Nova Scotia, The', 9999, '');
INSERT INTO 'tune' VALUES (1260, NULL, '2012-01-20 12:54:24.244449+00', 'Morayshire Farmers', 9998, '');
INSERT INTO 'tune' VALUES (4302, NULL, '2012-01-20 12:54:34.499523+00', 'Mrs Douglas of Invergloy', 1527, '');
INSERT INTO 'tune' VALUES (1261, NULL, '2012-01-20 12:54:24.247339+00', 'Morpeth Rant', 9999, '');
INSERT INTO 'tune' VALUES (1262, NULL, '2012-01-20 12:54:24.250229+00', 'Moudiewort, The', 1859, '');
INSERT INTO 'tune' VALUES (4303, NULL, '2012-01-20 12:54:34.503334+00', 'Mrs Ena Meikle''s Strathspey', 1508, '');
INSERT INTO 'tune' VALUES (1263, NULL, '2012-01-20 12:54:24.253192+00', 'Mount Stewart House', 9999, '');
INSERT INTO 'tune' VALUES (1264, NULL, '2012-01-20 12:54:24.256107+00', 'Moving Cloud, The', 1726, '');
INSERT INTO 'tune' VALUES (4304, NULL, '2012-01-20 12:54:34.507135+00', 'Mrs Gordon of Troop''s Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (1265, NULL, '2012-01-20 12:54:24.259041+00', 'Mr & Mrs Alex Ross', 1547, '');
INSERT INTO 'tune' VALUES (1266, NULL, '2012-01-20 12:54:24.261978+00', 'Mr & Mrs Little of Castle Douglas', 1502, '');
INSERT INTO 'tune' VALUES (1267, NULL, '2012-01-20 12:54:24.264928+00', 'Mr Alex Menzies', 1928, '');
INSERT INTO 'tune' VALUES (4305, NULL, '2012-01-20 12:54:34.510931+00', 'Graeme''s Fancy', 1776, '');
INSERT INTO 'tune' VALUES (1268, NULL, '2012-01-20 12:54:24.267837+00', 'Mr Alexander Laing''s Hornpipe', 1516, '');
INSERT INTO 'tune' VALUES (1269, NULL, '2012-01-20 12:54:24.270732+00', 'Mr Charles Graham', 9999, '');
INSERT INTO 'tune' VALUES (1270, NULL, '2012-01-20 12:54:24.273623+00', 'Mr Dolph Morris'' Strathspey', 1584, '');
INSERT INTO 'tune' VALUES (4306, NULL, '2012-01-20 12:54:34.514733+00', 'Mrs Haswell', 1946, '');
INSERT INTO 'tune' VALUES (1271, NULL, '2012-01-20 12:54:24.276519+00', 'Mr Edward Wagstaff''s Fancy', 1516, '');
INSERT INTO 'tune' VALUES (1272, NULL, '2012-01-20 12:54:24.279415+00', 'Mr Fletcher''s Delight', 9998, '');
INSERT INTO 'tune' VALUES (1273, NULL, '2012-01-20 12:54:24.282307+00', 'Mr George A. Young', 1516, '');
INSERT INTO 'tune' VALUES (4307, NULL, '2012-01-20 12:54:34.518546+00', 'Mrs Hay of Angus', 1607, '');
INSERT INTO 'tune' VALUES (1274, NULL, '2012-01-20 12:54:24.285256+00', 'Mr Grant of Pitnacree''s Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (4308, NULL, '2012-01-20 12:54:34.522368+00', 'Jackson''s Frieze Coat', 2135, '');
INSERT INTO 'tune' VALUES (4309, NULL, '2012-01-20 12:54:34.52617+00', 'Mrs Herries Forbes', 9998, '');
INSERT INTO 'tune' VALUES (4311, NULL, '2012-01-20 12:54:34.534692+00', 'Mrs Jessie Blair''s Strathspey', 1558, '');
INSERT INTO 'tune' VALUES (4312, NULL, '2012-01-20 12:54:34.538497+00', 'Mrs Jimmy Shand''s Strathspey', 1558, '');
INSERT INTO 'tune' VALUES (4313, NULL, '2012-01-20 12:54:34.542287+00', 'Mrs John Clark''s Delight', 2613, '');
INSERT INTO 'tune' VALUES (4314, NULL, '2012-01-20 12:54:34.546093+00', 'Mrs Joseph Lowe', 9998, '');
INSERT INTO 'tune' VALUES (4315, NULL, '2012-01-20 12:54:34.549917+00', 'Mrs Low''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (12121, '2012-06-12 14:42:44.793962+00', '2012-06-12 14:42:44.793972+00', 'Mrs Morag Hopkins of Kennet', 1898, '');
INSERT INTO 'tune' VALUES (12267, '2012-12-28 14:45:36.578154+00', '2012-12-28 14:45:36.578165+00', 'For the Record', 2567, '');
INSERT INTO 'tune' VALUES (12309, '2013-01-02 15:26:03.004618+00', '2013-01-02 17:03:51.11954+00', 'Harwey Jig, The', 3798, '');
INSERT INTO 'tune' VALUES (12382, '2013-01-05 17:12:26.494178+00', '2013-01-05 17:12:26.494189+00', 'Cumliewick Crofter, The', 2253, '');
INSERT INTO 'tune' VALUES (1245, NULL, '2013-01-28 20:17:19.427339+00', 'Tally Ho Two-Step', 1728, 'Composer mentioned in Strathspey message 63607 by Helen McGinley on 27 jan 2013

');
INSERT INTO 'tune' VALUES (12446, '2013-02-02 15:50:47.350131+00', '2013-02-02 15:50:47.350143+00', 'Shona Cameron', 1579, '');
INSERT INTO 'tune' VALUES (12460, '2013-02-03 15:22:44.268543+00', '2013-02-03 15:22:44.268555+00', 'Glenprosen Ghillies Ball', 9998, '');
INSERT INTO 'tune' VALUES (12487, '2013-02-22 15:38:57.644151+00', '2013-02-22 15:38:57.644162+00', 'Steamboat Jig, The', 3186, '');
INSERT INTO 'tune' VALUES (12496, '2013-02-27 12:33:03.146476+00', '2013-02-27 12:33:03.146487+00', 'L.S.Q. Figure 2', 9999, '');
INSERT INTO 'tune' VALUES (1275, NULL, '2012-01-20 12:54:24.288214+00', 'Mr Hamilton of Pencaitland', 9998, '');
INSERT INTO 'tune' VALUES (1276, NULL, '2012-01-20 12:54:24.291145+00', 'Mr John Stewart', 9998, '');
INSERT INTO 'tune' VALUES (4316, NULL, '2012-01-20 12:54:34.553725+00', 'Ennis Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (1277, NULL, '2012-01-20 12:54:24.294051+00', 'Mr Macintyre of Glencoe', 9998, '');
INSERT INTO 'tune' VALUES (1296, NULL, '2012-01-20 12:54:24.353691+00', 'Mrs Blair''s Jig', 1944, '');
INSERT INTO 'tune' VALUES (1278, NULL, '2012-01-20 12:54:24.298703+00', 'Mr Masson, Manse of Botriphnie', 1516, '');
INSERT INTO 'tune' VALUES (4317, NULL, '2012-01-20 12:54:34.557514+00', 'Mrs Mary McManus', 1659, '');
INSERT INTO 'tune' VALUES (1279, NULL, '2012-01-20 12:54:24.301657+00', 'Mr Michie', 1554, '');
INSERT INTO 'tune' VALUES (1280, NULL, '2012-01-20 12:54:24.30457+00', 'Mr Michie''s', 1512, '');
INSERT INTO 'tune' VALUES (4318, '2006-09-03 22:00:00+00', '2012-01-20 12:54:34.56132+00', 'Fiddler from Dooney', 3705, '');
INSERT INTO 'tune' VALUES (1281, NULL, '2012-01-20 12:54:24.307477+00', 'Mr Moore''s Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (1298, NULL, '2012-01-20 12:54:24.3596+00', 'Mrs Captain Skene''s Strathspey of Carreston', 1516, '');
INSERT INTO 'tune' VALUES (1282, NULL, '2012-01-20 12:54:24.310371+00', 'Mr Morison of Bognie', 1516, '');
INSERT INTO 'tune' VALUES (4319, NULL, '2012-01-20 12:54:34.565137+00', 'Isabel Muir''s Strathspey', 1404, '');
INSERT INTO 'tune' VALUES (1283, NULL, '2012-01-20 12:54:24.314015+00', 'Mr Muir MacKenzie''s Favourite', 1731, '');
INSERT INTO 'tune' VALUES (1299, NULL, '2012-01-20 12:54:24.362563+00', 'Mrs Chisholm of Chisholm', 9998, '');
INSERT INTO 'tune' VALUES (1284, NULL, '2012-01-20 12:54:24.316997+00', 'Mr Oswald (of Auchencruive)', 1519, '');
INSERT INTO 'tune' VALUES (4320, NULL, '2012-01-20 12:54:34.568946+00', 'Andy Muir''s Reel', 1404, '');
INSERT INTO 'tune' VALUES (1285, NULL, '2012-01-20 12:54:24.319902+00', 'Mr Patrick Duff Junior''s Strathspey', 1470, '');
INSERT INTO 'tune' VALUES (1300, NULL, '2012-01-20 12:54:24.36593+00', 'Mrs Christine Brown''s Jig', 1558, '');
INSERT INTO 'tune' VALUES (1286, NULL, '2012-01-20 12:54:24.3229+00', 'Mr Richardson''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (4321, NULL, '2012-01-20 12:54:34.572825+00', 'Mrs. Magee''s Reel', 1762, '');
INSERT INTO 'tune' VALUES (1287, NULL, '2012-01-20 12:54:24.326754+00', 'Mr Robert Mackay of Edinburgh', 1502, '');
INSERT INTO 'tune' VALUES (1301, NULL, '2012-01-20 12:54:24.37006+00', 'Mrs Colonel Sinclair of Forss', 1470, '');
INSERT INTO 'tune' VALUES (1288, NULL, '2012-01-20 12:54:24.329753+00', 'Mr Tierney''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (4322, NULL, '2012-01-20 12:54:34.576637+00', 'Mrs Stirling of Keir', 9998, '');
INSERT INTO 'tune' VALUES (1289, NULL, '2012-01-20 12:54:24.333057+00', 'Mr William Davidson', 1632, '');
INSERT INTO 'tune' VALUES (1302, NULL, '2012-01-20 12:54:24.373043+00', 'Mrs Compton of Carham Hall', 1447, '');
INSERT INTO 'tune' VALUES (1290, NULL, '2012-01-20 12:54:24.336243+00', 'Mr Wilson''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (4323, NULL, '2012-01-20 12:54:34.58044+00', 'Captain Campbell', 9999, '');
INSERT INTO 'tune' VALUES (1291, NULL, '2012-01-20 12:54:24.339163+00', 'Mrs Adie', 1942, '');
INSERT INTO 'tune' VALUES (1303, NULL, '2012-01-20 12:54:24.375956+00', 'Mrs Dalzell', 1517, '');
INSERT INTO 'tune' VALUES (1292, NULL, '2012-01-20 12:54:24.342063+00', 'Old French (Rambler''s Hornpipe)', 9999, '');
INSERT INTO 'tune' VALUES (4324, NULL, '2012-01-20 12:54:34.584249+00', 'Ms Gillian McMullen of Cambridge', 1461, '');
INSERT INTO 'tune' VALUES (1293, NULL, '2012-01-20 12:54:24.34497+00', 'Mrs Anderson''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (1304, NULL, '2012-01-20 12:54:24.379515+00', 'Dancing on the Lawn', 1643, '');
INSERT INTO 'tune' VALUES (4325, NULL, '2012-01-20 12:54:34.5881+00', 'Carlisle Branch of the RSCDS, The', 1593, '');
INSERT INTO 'tune' VALUES (1305, NULL, '2012-01-20 12:54:24.383721+00', 'Ace at Windermere, An', 1360, '');
INSERT INTO 'tune' VALUES (1306, NULL, '2012-01-20 12:54:24.386677+00', 'Mrs Eleanora Robertson''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (1307, NULL, '2012-01-20 12:54:24.389587+00', 'Mrs Ella Wilson', 1502, '');
INSERT INTO 'tune' VALUES (4326, NULL, '2012-01-20 12:54:34.591902+00', 'Muirhead Bobbie', 9998, '');
INSERT INTO 'tune' VALUES (4310, NULL, '2022-12-26 21:47:45.168658+00', 'Mrs. H. L. MacDonald of Dunach', 12248, '');
INSERT INTO 'tune' VALUES (1309, NULL, '2012-01-20 12:54:24.395929+00', 'Mrs Findlay of Haywood', 1416, '');
INSERT INTO 'tune' VALUES (1310, NULL, '2012-01-20 12:54:24.39885+00', 'Mrs Fitchet', 1554, '');
INSERT INTO 'tune' VALUES (4327, NULL, '2012-01-20 12:54:34.59574+00', 'Muir O'' Logie, The', 1512, '');
INSERT INTO 'tune' VALUES (1311, NULL, '2012-01-20 12:54:24.401743+00', 'Mrs Garden of Troup', 1695, '');
INSERT INTO 'tune' VALUES (1312, NULL, '2012-01-20 12:54:24.404876+00', 'Mrs Garthland''s Strathspey', 1517, '');
INSERT INTO 'tune' VALUES (1313, NULL, '2012-01-20 12:54:24.407891+00', 'Mrs Grace Bowie', 1598, '');
INSERT INTO 'tune' VALUES (4328, NULL, '2012-01-20 12:54:34.599543+00', 'Muriel Crawshaw''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (1314, NULL, '2012-01-20 12:54:24.411006+00', 'Trip to Paradise', 401, '');
INSERT INTO 'tune' VALUES (1315, NULL, '2012-01-20 12:54:24.413924+00', 'Mrs Grant of Laggan''s Favourite', 1470, '');
INSERT INTO 'tune' VALUES (4329, NULL, '2012-01-20 12:54:34.603349+00', 'Mrs Reid of Kilcalmkill''s Strathspey', 1470, '');
INSERT INTO 'tune' VALUES (1316, NULL, '2012-01-20 12:54:24.416829+00', 'Mrs Grieve of Howdan', 1447, '');
INSERT INTO 'tune' VALUES (1317, NULL, '2012-01-20 12:54:24.419732+00', 'Mrs Hamilton of Wishaw', 1518, '');
INSERT INTO 'tune' VALUES (12484, '2013-02-15 18:55:04.236267+00', '2014-08-25 15:06:52.754064+00', 'Woods o'' Stirkoe', 2636, '');
INSERT INTO 'tune' VALUES (1295, NULL, '2014-11-08 23:06:01.266658+00', 'Mrs Blair (of Blair)', 1519, '');
INSERT INTO 'tune' VALUES (4330, NULL, '2012-01-20 12:54:34.607161+00', 'Music in the Glen', 1607, '');
INSERT INTO 'tune' VALUES (1319, NULL, '2012-01-20 12:54:24.42553+00', 'Mrs Hepburn Belches of Invermay', 1749, '');
INSERT INTO 'tune' VALUES (1320, NULL, '2012-01-20 12:54:24.428429+00', 'Mrs Hill''s Delight', 9998, '');
INSERT INTO 'tune' VALUES (1321, NULL, '2012-01-20 12:54:24.431323+00', 'Mrs Hood''s Strathspey', 1401, '');
INSERT INTO 'tune' VALUES (1322, NULL, '2012-01-20 12:54:24.434217+00', 'Mrs Jamieson''s Favourite', 1807, '');
INSERT INTO 'tune' VALUES (1323, NULL, '2012-01-20 12:54:24.437224+00', 'Under the Double Eagle', 2881, '');
INSERT INTO 'tune' VALUES (1324, NULL, '2012-01-20 12:54:24.440909+00', 'Long Island, The', 1834, '');
INSERT INTO 'tune' VALUES (4332, NULL, '2012-01-20 12:54:34.614782+00', 'My Brown Haired Maiden', 9998, '');
INSERT INTO 'tune' VALUES (1325, NULL, '2012-01-20 12:54:24.444112+00', 'Mrs Johnston''s Reel', 1470, '');
INSERT INTO 'tune' VALUES (4333, NULL, '2012-01-20 12:54:34.618596+00', 'My Lady Winwood''s Maggot', 9998, '');
INSERT INTO 'tune' VALUES (4335, NULL, '2012-01-20 12:54:34.626196+00', 'Miss Biddy Fawdry', 1843, '');
INSERT INTO 'tune' VALUES (4336, NULL, '2012-01-20 12:54:34.629996+00', 'Piccadilly', 9998, '');
INSERT INTO 'tune' VALUES (4337, NULL, '2012-01-20 12:54:34.633816+00', 'Kelligrew''s Soiree', 9998, '');
INSERT INTO 'tune' VALUES (4338, NULL, '2012-01-20 12:54:34.637618+00', 'New Howford Bridge, The', 1437, '');
INSERT INTO 'tune' VALUES (4339, NULL, '2012-01-20 12:54:34.641514+00', 'Newington Assembly', 9998, '');
INSERT INTO 'tune' VALUES (4340, NULL, '2012-01-20 12:54:34.645357+00', 'New New Nothing', 9998, '');
INSERT INTO 'tune' VALUES (12068, '2012-05-04 19:10:22.855723+00', '2012-05-04 19:10:22.855734+00', 'Sandy D''s Major', 1502, '');
INSERT INTO 'tune' VALUES (12122, '2012-06-12 14:43:14.220184+00', '2012-06-12 14:43:14.220195+00', 'Bill Cook', 9998, '');
INSERT INTO 'tune' VALUES (12268, '2012-12-28 14:48:18.502701+00', '2012-12-28 14:48:18.502712+00', 'Bodvar Bjarkis Boys', 10675, '');
INSERT INTO 'tune' VALUES (12310, '2013-01-02 15:31:02.486728+00', '2013-01-02 15:31:02.486739+00', 'Jennifer''s Reel', 10692, '');
INSERT INTO 'tune' VALUES (12383, '2013-01-05 17:16:14.112074+00', '2013-01-05 17:16:14.112085+00', 'Lisa L'' Allegro', 10684, '');
INSERT INTO 'tune' VALUES (12447, '2013-02-02 15:52:10.750168+00', '2013-02-02 15:52:10.75018+00', 'Jean and Bob Turner', 1579, '');
INSERT INTO 'tune' VALUES (12485, '2013-02-15 19:02:34.478296+00', '2013-02-15 19:02:34.478307+00', 'Gordon''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (12488, '2013-02-22 15:41:25.872979+00', '2013-02-22 15:41:25.87299+00', 'Dog''s Paws, The', 1621, '');
INSERT INTO 'tune' VALUES (12497, '2013-02-27 12:33:21.42474+00', '2013-02-27 12:33:21.424751+00', 'L.S.Q. Figure 3', 9999, '');
INSERT INTO 'tune' VALUES (1346, NULL, '2012-01-20 12:54:24.50781+00', 'Mrs Nancy Taylor', 1585, '');
INSERT INTO 'tune' VALUES (1326, NULL, '2012-01-20 12:54:24.447029+00', 'Mrs L. Stewart of Java', 1516, '');
INSERT INTO 'tune' VALUES (1327, NULL, '2012-01-20 12:54:24.449935+00', 'Mrs Lumsden of Achindores', 1516, '');
INSERT INTO 'tune' VALUES (1347, NULL, '2012-01-20 12:54:24.512217+00', 'Mrs Ramsay', 9999, '');
INSERT INTO 'tune' VALUES (1328, NULL, '2012-01-20 12:54:24.452842+00', 'Mrs MacDouall Grant', 1517, '');
INSERT INTO 'tune' VALUES (1329, NULL, '2012-01-20 12:54:24.455799+00', 'Mrs MacLeod of Raasay', 1518, '');
INSERT INTO 'tune' VALUES (4342, NULL, '2012-01-20 12:54:34.652972+00', 'New York Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (1348, NULL, '2012-01-20 12:54:24.516089+00', 'Mrs Ramsay of Barnton', 9999, '');
INSERT INTO 'tune' VALUES (1330, NULL, '2012-01-20 12:54:24.458759+00', 'Mrs Macdougall''s Rant', 9998, '');
INSERT INTO 'tune' VALUES (1331, NULL, '2012-01-20 12:54:24.461713+00', 'Mrs Macpherson of Inveran', 1699, '');
INSERT INTO 'tune' VALUES (4343, NULL, '2012-01-20 12:54:34.656774+00', 'Animals Went in Two by Two, The', 9998, '');
INSERT INTO 'tune' VALUES (1540, NULL, '2012-01-20 12:54:25.175688+00', 'Rory O''More', 9999, '');
INSERT INTO 'tune' VALUES (1349, NULL, '2012-01-20 12:54:24.519916+00', 'Mrs Russel of Blackhall', 1519, '');
INSERT INTO 'tune' VALUES (1332, NULL, '2012-01-20 12:54:24.464795+00', 'Turkey in the Straw', 9999, '');
INSERT INTO 'tune' VALUES (1333, NULL, '2012-01-20 12:54:24.467704+00', 'Mrs Marshall''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (4344, NULL, '2012-01-20 12:54:34.661085+00', 'No Churchman am I', 9999, '');
INSERT INTO 'tune' VALUES (1350, NULL, '2012-01-20 12:54:24.523768+00', 'Mrs Scott of Bellevue', 9998, '');
INSERT INTO 'tune' VALUES (1335, NULL, '2012-01-20 12:54:24.473485+00', 'Chicken Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (4345, NULL, '2012-01-20 12:54:34.664903+00', 'Noel Park', 9998, '');
INSERT INTO 'tune' VALUES (1351, NULL, '2012-01-20 12:54:24.527592+00', 'Mrs Seller''s Favourite', 1807, '');
INSERT INTO 'tune' VALUES (1336, NULL, '2012-01-20 12:54:24.476428+00', 'Mrs Mary Stoker', 1502, '');
INSERT INTO 'tune' VALUES (1337, NULL, '2012-01-20 12:54:24.47934+00', 'Kirsty Aitken Rae', 2991, '');
INSERT INTO 'tune' VALUES (4346, NULL, '2012-01-20 12:54:34.668716+00', 'Back o'' Moss', 1981, '');
INSERT INTO 'tune' VALUES (1338, NULL, '2012-01-20 12:54:24.48223+00', 'Mrs McLennan of Brora', 9998, '');
INSERT INTO 'tune' VALUES (1353, NULL, '2012-01-20 12:54:24.535004+00', 'Geordie Hinny', 1502, '');
INSERT INTO 'tune' VALUES (1340, NULL, '2012-01-20 12:54:24.489288+00', 'Mrs McMillan''s Quadrille', 1807, '');
INSERT INTO 'tune' VALUES (1341, NULL, '2012-01-20 12:54:24.492465+00', 'Mrs Methven', 1402, '');
INSERT INTO 'tune' VALUES (1354, NULL, '2012-01-20 12:54:24.538056+00', 'Mrs Stewart of Fasnacloich', 9999, '');
INSERT INTO 'tune' VALUES (1342, NULL, '2012-01-20 12:54:24.495387+00', 'Mrs Moira Haynes', 1527, '');
INSERT INTO 'tune' VALUES (1343, NULL, '2012-01-20 12:54:24.498282+00', 'Mrs Moray of Abercairney', 9999, '');
INSERT INTO 'tune' VALUES (4349, NULL, '2012-01-20 12:54:34.680139+00', 'North Down Waltz, The', 9998, '');
INSERT INTO 'tune' VALUES (1355, NULL, '2012-01-20 12:54:24.541031+00', 'Mrs Stewart''s Fancy', 1401, '');
INSERT INTO 'tune' VALUES (1344, NULL, '2012-01-20 12:54:24.501901+00', 'Mrs Mosman''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (4341, NULL, '2021-04-22 18:36:49.757542+00', 'New Town of Edinburgh, The', 9999, 'Not to be confused with <<ddt:New Town of Edinburgh, The#1392>> by Iain MacPhail.');
INSERT INTO 'tune' VALUES (4350, NULL, '2012-01-20 12:54:34.683945+00', 'Noup of Noss', 1710, '');
INSERT INTO 'tune' VALUES (1356, NULL, '2012-01-20 12:54:24.544214+00', 'Mrs Stewart''s Strathspey', 1516, '');
INSERT INTO 'tune' VALUES (1357, NULL, '2012-01-20 12:54:24.547163+00', 'Mrs Susan Nedderman', 1825, '');
INSERT INTO 'tune' VALUES (1358, NULL, '2012-01-20 12:54:24.550088+00', 'Mrs W. Lockhart', 1679, '');
INSERT INTO 'tune' VALUES (4351, NULL, '2012-01-20 12:54:34.687736+00', 'To Ian', 1825, '');
INSERT INTO 'tune' VALUES (1359, NULL, '2012-01-20 12:54:24.553073+00', 'Mrs Young''s Strathspey', 1784, '');
INSERT INTO 'tune' VALUES (1360, NULL, '2012-01-20 12:54:24.555981+00', 'Muirland Willie', 9999, '');
INSERT INTO 'tune' VALUES (1361, NULL, '2012-01-20 12:54:24.558879+00', 'Muirtown House', 1784, '');
INSERT INTO 'tune' VALUES (4352, NULL, '2012-01-20 12:54:34.69154+00', 'To Janice', 1825, '');
INSERT INTO 'tune' VALUES (1362, NULL, '2012-01-20 12:54:24.561782+00', 'Munro Rant, The', 9998, '');
INSERT INTO 'tune' VALUES (1363, NULL, '2012-01-20 12:54:24.564705+00', 'Murdo Mackenzie of Torridon', 3058, '');
INSERT INTO 'tune' VALUES (1364, NULL, '2012-01-20 12:54:24.568163+00', 'Muriel Johnstone''s Compliments to Robert MacKay', 1502, '');
INSERT INTO 'tune' VALUES (4353, NULL, '2012-01-20 12:54:34.695336+00', 'O''Carolan''s Receipt for Drinking', 1882, '');
INSERT INTO 'tune' VALUES (1365, NULL, '2012-01-20 12:54:24.571123+00', 'Muriel and Eric Rimmer''s Fancy', 1555, '');
INSERT INTO 'tune' VALUES (1366, NULL, '2012-01-20 12:54:24.574025+00', 'Murphy Delaney', 9998, '');
INSERT INTO 'tune' VALUES (1367, NULL, '2012-01-20 12:54:24.578769+00', 'Murray''s Welcome to the 79th', 1949, '');
INSERT INTO 'tune' VALUES (4354, NULL, '2012-01-20 12:54:34.699138+00', 'Milliam James MacDonald', 467, '');
INSERT INTO 'tune' VALUES (1368, NULL, '2012-01-20 12:54:24.58192+00', 'Music o'' Spey, The', 1512, '');
INSERT INTO 'tune' VALUES (1369, NULL, '2012-01-20 12:54:24.584844+00', 'Miss Penuel Grant of Grant''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (1370, NULL, '2012-01-20 12:54:24.587783+00', 'My Daddy Oh!', 9999, '');
INSERT INTO 'tune' VALUES (4355, NULL, '2012-01-20 12:54:34.70293+00', 'Groom, The', 1582, '');
INSERT INTO 'tune' VALUES (1371, NULL, '2012-01-20 12:54:24.590977+00', 'My Dearie', 2175, '');
INSERT INTO 'tune' VALUES (1372, NULL, '2012-01-20 12:54:24.594005+00', 'Hey Johnnie Lad', 9999, '');
INSERT INTO 'tune' VALUES (4356, NULL, '2012-01-20 12:54:34.706745+00', 'Bride, The', 1582, '');
INSERT INTO 'tune' VALUES (1374, NULL, '2012-01-20 12:54:24.599815+00', 'My Love She''s but a Lassie Yet', 9999, '');
INSERT INTO 'tune' VALUES (1375, NULL, '2012-01-20 12:54:24.602705+00', 'My Mither''s Aye Glow''rin'' Owre Me', 9999, '');
INSERT INTO 'tune' VALUES (1376, NULL, '2012-01-20 12:54:24.605776+00', 'My Pretty Maid', 9999, '');
INSERT INTO 'tune' VALUES (4357, NULL, '2012-01-20 12:54:34.710559+00', 'Iain J McConnell of Solway', 1954, '');
INSERT INTO 'tune' VALUES (1345, NULL, '2022-07-27 17:41:05.487447+00', 'Mrs Muir McKenzie''s Favourite', 1731, '');
INSERT INTO 'tune' VALUES (1334, NULL, '2022-08-06 15:54:51.133492+00', 'Mrs Mary Printy', 1527, '');
INSERT INTO 'tune' VALUES (4358, NULL, '2012-01-20 12:54:34.714368+00', 'Jean of Broomfield', 1607, '');
INSERT INTO 'tune' VALUES (4359, NULL, '2012-01-20 12:54:34.718158+00', 'Borderers, The', 1643, '');
INSERT INTO 'tune' VALUES (4362, NULL, '2012-01-20 12:54:34.730603+00', 'O''Keefe''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (4363, NULL, '2012-01-20 12:54:34.734415+00', 'Auld Adam', 1426, '');
INSERT INTO 'tune' VALUES (4364, NULL, '2012-01-20 12:54:34.738208+00', 'Old Clarsach, The', 1846, '');
INSERT INTO 'tune' VALUES (4365, NULL, '2012-01-20 12:54:34.742004+00', 'Old Man Dillon', 9999, '');
INSERT INTO 'tune' VALUES (4366, NULL, '2012-01-20 12:54:34.745845+00', 'Old Wick Castle', 1789, '');
INSERT INTO 'tune' VALUES (12069, '2012-05-04 19:10:53.725663+00', '2012-05-04 19:10:53.725673+00', 'Jeannie''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (4396, NULL, '2012-01-20 12:54:34.860483+00', 'Doucement', 1203, '');
INSERT INTO 'tune' VALUES (4361, NULL, '2014-08-19 08:08:33.235165+00', 'Miss Admiral Gordon''s Reel', 1516, '');
INSERT INTO 'tune' VALUES (1352, NULL, '2014-11-01 00:25:26.147455+00', 'Mrs Stewart Nicholson', 1517, '');
INSERT INTO 'tune' VALUES (12123, '2012-06-12 14:44:30.390599+00', '2012-06-12 14:44:30.39061+00', 'Fiddlin'' Friends', 1898, '');
INSERT INTO 'tune' VALUES (12269, '2012-12-28 14:54:06.100115+00', '2012-12-28 14:54:06.100126+00', 'Peter MacDonald''s Leather Breeks', 10684, '');
INSERT INTO 'tune' VALUES (12311, '2013-01-02 15:32:31.747011+00', '2013-01-02 15:32:31.747022+00', 'Fiona''s Return from Canada', 9999, '');
INSERT INTO 'tune' VALUES (12384, '2013-01-05 17:18:25.231554+00', '2013-01-05 17:18:25.231565+00', 'Doon Da Gait', 10180, '');
INSERT INTO 'tune' VALUES (12448, '2013-02-02 16:28:42.699334+00', '2013-02-02 16:28:42.699345+00', 'Sunset on Arran''s Shore', 10737, '');
INSERT INTO 'tune' VALUES (12489, '2013-02-22 15:42:53.689845+00', '2013-02-22 15:42:53.689856+00', 'Leslie Angus', 1599, '');
INSERT INTO 'tune' VALUES (12498, '2013-02-27 12:33:50.802357+00', '2013-02-27 12:33:50.802368+00', 'L.S.Q. Figure 4', 9999, '');
INSERT INTO 'tune' VALUES (1397, NULL, '2012-01-20 12:54:24.670257+00', 'Newton Mearns', 1701, '');
INSERT INTO 'tune' VALUES (1377, NULL, '2012-01-20 12:54:24.608692+00', 'My Scottish Connection', 1489, '');
INSERT INTO 'tune' VALUES (4367, NULL, '2012-01-20 12:54:34.749749+00', 'Once a Night', 9998, '');
INSERT INTO 'tune' VALUES (1378, NULL, '2012-01-20 12:54:24.611695+00', 'My Tocher''s the Jewel', 1517, '');
INSERT INTO 'tune' VALUES (1398, NULL, '2012-01-20 12:54:24.673169+00', 'Newton Park', 1590, '');
INSERT INTO 'tune' VALUES (1379, NULL, '2012-01-20 12:54:24.614972+00', 'Willie Cook', 1424, '');
INSERT INTO 'tune' VALUES (4368, NULL, '2012-01-20 12:54:34.753553+00', 'Once I Loved a Maiden Fair', 9999, '');
INSERT INTO 'tune' VALUES (1380, NULL, '2012-01-20 12:54:24.618002+00', 'My Wife''s a Winsome Wee Thing', 9999, '');
INSERT INTO 'tune' VALUES (1399, NULL, '2012-01-20 12:54:24.676112+00', 'Niall Thow''s Reel', 1725, '');
INSERT INTO 'tune' VALUES (1381, NULL, '2012-01-20 12:54:24.620903+00', 'Nancy Dawson', 9999, '');
INSERT INTO 'tune' VALUES (4369, NULL, '2012-01-20 12:54:34.757353+00', 'One More Dance and Then', 2875, '');
INSERT INTO 'tune' VALUES (1382, NULL, '2012-01-20 12:54:24.623947+00', 'Neil''s Two-for-One', 1467, '');
INSERT INTO 'tune' VALUES (1383, NULL, '2012-01-20 12:54:24.626946+00', 'New Ayr Strathspey, The', 1815, '');
INSERT INTO 'tune' VALUES (4370, NULL, '2012-01-20 12:54:34.761163+00', 'Bonnie Isle of Gletness', 1623, '');
INSERT INTO 'tune' VALUES (1384, NULL, '2012-01-20 12:54:24.629853+00', 'New Bob, The', 9998, '');
INSERT INTO 'tune' VALUES (1401, NULL, '2012-01-20 12:54:24.683002+00', 'Niel Gow''s Farewell to Whisky', 1518, '');
INSERT INTO 'tune' VALUES (1385, NULL, '2012-01-20 12:54:24.632793+00', 'New Brig o'' Ayr, The', 9999, '');
INSERT INTO 'tune' VALUES (4371, NULL, '2012-01-20 12:54:34.764956+00', 'Shuter''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (13830, '2018-02-24 03:24:29.867841+00', '2018-02-24 03:24:29.867841+00', 'Hugh Calder', 9998, '');
INSERT INTO 'tune' VALUES (1387, NULL, '2012-01-20 12:54:24.639104+00', 'New Highland Laddie, The', 9998, '');
INSERT INTO 'tune' VALUES (4372, NULL, '2012-01-20 12:54:34.768772+00', 'Rosewood Jig, The', 1512, '');
INSERT INTO 'tune' VALUES (1388, NULL, '2012-01-20 12:54:24.64213+00', 'New Opera Dance', 9998, '');
INSERT INTO 'tune' VALUES (1403, NULL, '2012-01-20 12:54:24.689698+00', 'Night Cap, The', 9999, '');
INSERT INTO 'tune' VALUES (1389, NULL, '2012-01-20 12:54:24.645419+00', 'New Rigged Ship, The', 9999, '');
INSERT INTO 'tune' VALUES (4373, NULL, '2012-01-20 12:54:34.772566+00', 'Orleance Baffled', 9998, '');
INSERT INTO 'tune' VALUES (1390, NULL, '2012-01-20 12:54:24.648747+00', 'Arkansas Traveller', 9999, '');
INSERT INTO 'tune' VALUES (1404, NULL, '2012-01-20 12:54:24.692632+00', 'Nineteenth of December', 9999, '');
INSERT INTO 'tune' VALUES (1391, NULL, '2012-01-20 12:54:24.651684+00', 'New Scotland Strathspey, The', 1411, '');
INSERT INTO 'tune' VALUES (4374, NULL, '2012-01-20 12:54:34.776369+00', 'Orkney Reel, The', 1456, '');
INSERT INTO 'tune' VALUES (1392, NULL, '2012-01-20 12:54:24.654594+00', 'New Town of Edinburgh, The', 1527, '');
INSERT INTO 'tune' VALUES (1405, '2006-01-02 23:00:00+00', '2012-01-20 12:54:24.695564+00', 'Hartfell Jig', 3203, '');
INSERT INTO 'tune' VALUES (1393, NULL, '2012-01-20 12:54:24.657494+00', 'New Water Kettle, The', 1517, '');
INSERT INTO 'tune' VALUES (4375, NULL, '2012-01-20 12:54:34.780166+00', 'Bob and Anne''s Strathspey', 1615, '');
INSERT INTO 'tune' VALUES (1394, NULL, '2012-01-20 12:54:24.660826+00', 'Fisherman, The', 9999, '');
INSERT INTO 'tune' VALUES (1406, NULL, '2012-01-20 12:54:24.698513+00', 'Norman Whitelaw', 1554, '');
INSERT INTO 'tune' VALUES (1395, NULL, '2012-01-20 12:54:24.664368+00', 'Newcastle Hornpipe', 1625, '');
INSERT INTO 'tune' VALUES (4376, NULL, '2012-01-20 12:54:34.783972+00', 'Top of the Morning, The', 9999, '');
INSERT INTO 'tune' VALUES (1396, NULL, '2012-01-20 12:54:24.66735+00', 'Newhall''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (1407, NULL, '2012-01-20 12:54:24.701412+00', 'North Bridge Of Edinburgh, The', 9998, '');
INSERT INTO 'tune' VALUES (1408, NULL, '2012-01-20 12:54:24.704314+00', 'Northern Meeting, The', 9999, '');
INSERT INTO 'tune' VALUES (4377, NULL, '2012-01-20 12:54:34.787773+00', 'Overlander, The', 9998, '');
INSERT INTO 'tune' VALUES (1409, NULL, '2012-01-20 12:54:24.707225+00', 'Craigellachie Bridge', 1516, '');
INSERT INTO 'tune' VALUES (1410, NULL, '2012-01-20 12:54:24.710126+00', 'Novelty, The', 2142, '');
INSERT INTO 'tune' VALUES (1411, NULL, '2012-01-20 12:54:24.713347+00', 'O''er the Hill and Dinna Mind the Ranger', 9998, '');
INSERT INTO 'tune' VALUES (4378, NULL, '2012-01-20 12:54:34.791577+00', 'Over the Rainbow', 1607, '');
INSERT INTO 'tune' VALUES (1412, NULL, '2012-01-20 12:54:24.716282+00', 'O''er the Muir Among the Heather', 9998, '');
INSERT INTO 'tune' VALUES (1413, NULL, '2012-01-20 12:54:24.719562+00', 'O''er the Muir to Ketty', 9999, '');
INSERT INTO 'tune' VALUES (1414, NULL, '2012-01-20 12:54:24.722511+00', 'Oddfellows, The', 1512, '');
INSERT INTO 'tune' VALUES (4379, NULL, '2012-01-20 12:54:34.795364+00', 'Paddy Carey', 9999, '');
INSERT INTO 'tune' VALUES (1415, NULL, '2012-01-20 12:54:24.725649+00', 'Off She Goes', 9999, '');
INSERT INTO 'tune' VALUES (1416, NULL, '2012-01-20 12:54:24.728568+00', 'Off the Rails', 1502, '');
INSERT INTO 'tune' VALUES (4380, NULL, '2012-01-20 12:54:34.799153+00', 'Paddy''s Dream', 9999, '');
INSERT INTO 'tune' VALUES (1417, NULL, '2012-01-20 12:54:24.731486+00', 'Mrs Rigg', 1517, '');
INSERT INTO 'tune' VALUES (1418, NULL, '2012-01-20 12:54:24.73439+00', 'Oh Tell na Me o'' Wind and Rain', 9999, '');
INSERT INTO 'tune' VALUES (1419, NULL, '2012-01-20 12:54:24.737631+00', 'Oh Whistle and I''ll come tae ye', 9999, '');
INSERT INTO 'tune' VALUES (4381, NULL, '2012-01-20 12:54:34.802991+00', 'Paddy''s Leather Breeches', 9999, '');
INSERT INTO 'tune' VALUES (1420, NULL, '2012-01-20 12:54:24.740545+00', 'Oh were my Love yon Lilac Fair', 9998, '');
INSERT INTO 'tune' VALUES (1422, NULL, '2012-01-20 12:54:24.746331+00', 'Donald Cameron', 9998, '');
INSERT INTO 'tune' VALUES (4382, NULL, '2012-01-20 12:54:34.806803+00', 'I''ll Gang Nae Mare tae Yon Toon', 9999, '');
INSERT INTO 'tune' VALUES (1423, NULL, '2012-01-20 12:54:24.749247+00', 'Old Bog Hole, The', 9999, '');
INSERT INTO 'tune' VALUES (1424, NULL, '2012-01-20 12:54:24.753003+00', 'Old Grey Cat, The', 9999, '');
INSERT INTO 'tune' VALUES (1425, NULL, '2012-01-20 12:54:24.756205+00', 'Old Man will Never Die, The', 9999, '');
INSERT INTO 'tune' VALUES (4383, NULL, '2012-01-20 12:54:34.810628+00', 'Leading On', 1865, '');
INSERT INTO 'tune' VALUES (1427, NULL, '2012-01-20 12:54:24.7626+00', 'One O''Clock Cannon, The', 550, '');
INSERT INTO 'tune' VALUES (4384, NULL, '2012-01-20 12:54:34.814421+00', 'Parson, The', 2294, '');
INSERT INTO 'tune' VALUES (4385, NULL, '2012-01-20 12:54:34.818218+00', 'Parting Glass, The', 9998, '');
INSERT INTO 'tune' VALUES (4386, NULL, '2012-01-20 12:54:34.822017+00', 'Altadena Ball', 1584, '');
INSERT INTO 'tune' VALUES (4387, NULL, '2012-01-20 12:54:34.825944+00', 'Stewart Smith Strathspey', 629, '');
INSERT INTO 'tune' VALUES (4388, NULL, '2012-01-20 12:54:34.829759+00', 'Patched Bagpipe, The', 9998, '');
INSERT INTO 'tune' VALUES (4389, NULL, '2012-01-20 12:54:34.833572+00', 'Irish Rambler, The', 9998, '');
INSERT INTO 'tune' VALUES (4390, NULL, '2012-01-20 12:54:34.837399+00', 'Pat''s Parlour', 9999, '');
INSERT INTO 'tune' VALUES (4391, NULL, '2012-01-20 12:54:34.841196+00', 'Paul and Marjie''s Wedding', 1956, '');
INSERT INTO 'tune' VALUES (4392, NULL, '2012-01-20 12:54:34.845001+00', 'Dundry Hill', 1631, '');
INSERT INTO 'tune' VALUES (12070, '2012-05-04 19:11:16.961322+00', '2012-05-04 19:11:16.961333+00', 'Home from Home', 1502, '');
INSERT INTO 'tune' VALUES (12124, '2012-06-12 14:54:21.008418+00', '2012-06-12 14:54:21.008429+00', 'Cambridge Hornpipe, The', 9998, '');
INSERT INTO 'tune' VALUES (1402, NULL, '2012-06-17 14:58:18.592121+00', 'Niel Gow''s Second Wife', 1518, '');
INSERT INTO 'tune' VALUES (12270, '2012-12-28 14:57:30.077205+00', '2012-12-28 14:57:30.077216+00', 'Hairst Blinks', 1710, '');
INSERT INTO 'tune' VALUES (12312, '2013-01-02 15:44:35.755475+00', '2013-01-02 15:44:35.755485+00', 'Mrs Drummond of Megginch', 9999, '');
INSERT INTO 'tune' VALUES (12385, '2013-01-05 17:20:04.95708+00', '2013-01-05 17:20:04.957091+00', 'Muir Street Man, The', 1645, '');
INSERT INTO 'tune' VALUES (12449, '2013-02-02 16:29:56.370492+00', '2013-02-02 16:29:56.370503+00', 'Quiet Water, The', 10737, '');
INSERT INTO 'tune' VALUES (12490, '2013-02-22 15:50:50.498263+00', '2013-02-22 15:50:50.498275+00', 'Førdeminner', 10753, '');
INSERT INTO 'tune' VALUES (12499, '2013-02-27 12:34:19.244475+00', '2013-02-27 12:34:19.244486+00', 'L.S.Q. Figure 5', 9999, '');
INSERT INTO 'tune' VALUES (1428, NULL, '2012-01-20 12:54:24.767762+00', 'Oor Auld Guidman is noo awa''', 1416, '');
INSERT INTO 'tune' VALUES (1449, NULL, '2012-01-20 12:54:24.83399+00', 'Peggie''s Dumpling', 9999, '');
INSERT INTO 'tune' VALUES (1429, NULL, '2012-01-20 12:54:24.770749+00', 'Opera Dance', 1716, '');
INSERT INTO 'tune' VALUES (4393, NULL, '2012-01-20 12:54:34.848802+00', 'Pawky Duke, The', 1902, '');
INSERT INTO 'tune' VALUES (1430, NULL, '2012-01-20 12:54:24.773647+00', 'Standard on the Braes of Mar, The', 9999, '');
INSERT INTO 'tune' VALUES (1450, NULL, '2012-01-20 12:54:24.837123+00', 'Peggie''s Wedding', 9999, '');
INSERT INTO 'tune' VALUES (4394, NULL, '2012-01-20 12:54:34.85289+00', 'Picton Schottische, The', 1758, '');
INSERT INTO 'tune' VALUES (1451, NULL, '2012-01-20 12:54:24.840038+00', 'Penny Whistle Barn Dance', 9998, '');
INSERT INTO 'tune' VALUES (1433, NULL, '2012-01-20 12:54:24.782447+00', 'Over the Hill', 1502, '');
INSERT INTO 'tune' VALUES (4395, NULL, '2012-01-20 12:54:34.856685+00', 'Pig Town', 9999, '');
INSERT INTO 'tune' VALUES (1434, NULL, '2012-01-20 12:54:24.785974+00', 'Salmonfield Poacher, The', 1578, '');
INSERT INTO 'tune' VALUES (1452, NULL, '2012-01-20 12:54:24.842947+00', 'Perth Assembly, The', 1746, '');
INSERT INTO 'tune' VALUES (1435, NULL, '2012-01-20 12:54:24.789058+00', 'Ower the Water', 9999, '');
INSERT INTO 'tune' VALUES (1400, NULL, '2014-11-01 02:31:26.591958+00', 'Niel Gow', 1946, '');
INSERT INTO 'tune' VALUES (1437, NULL, '2012-01-20 12:54:24.794877+00', 'Oyster Girl', 9999, '');
INSERT INTO 'tune' VALUES (4397, NULL, '2012-01-20 12:54:34.864287+00', 'Pipe Major Sam Scott', 1597, '');
INSERT INTO 'tune' VALUES (1438, NULL, '2012-01-20 12:54:24.797805+00', 'Paddle Boat, The', 1701, '');
INSERT INTO 'tune' VALUES (1454, NULL, '2012-01-20 12:54:24.848745+00', 'Perthshire Highlanders, The', 9999, '');
INSERT INTO 'tune' VALUES (1439, NULL, '2012-01-20 12:54:24.80073+00', 'Paddy on the Turnpike', 9999, '');
INSERT INTO 'tune' VALUES (4398, NULL, '2012-01-20 12:54:34.868099+00', 'Miss Elizabeth Green', 1582, '');
INSERT INTO 'tune' VALUES (1440, NULL, '2012-01-20 12:54:24.803644+00', 'Paisley Mondays', 1454, '');
INSERT INTO 'tune' VALUES (1455, NULL, '2012-01-20 12:54:24.851718+00', 'Pet o'' the Pipers', 9999, '');
INSERT INTO 'tune' VALUES (1441, NULL, '2012-01-20 12:54:24.806972+00', 'Panmure House', 9998, '');
INSERT INTO 'tune' VALUES (4399, NULL, '2012-01-20 12:54:34.872532+00', 'Miss Williamson of Oldfield''s Jigg', 9998, '');
INSERT INTO 'tune' VALUES (1442, NULL, '2012-01-20 12:54:24.809998+00', 'Papillon, Le', 9999, '');
INSERT INTO 'tune' VALUES (1456, NULL, '2012-01-20 12:54:24.854677+00', 'Peter Sanderson''s Strathspey', 1533, '');
INSERT INTO 'tune' VALUES (1443, NULL, '2012-01-20 12:54:24.8129+00', 'Para Handy', 2006, '');
INSERT INTO 'tune' VALUES (4400, NULL, '2012-01-20 12:54:34.876349+00', 'Pitlochry Celebration', 1692, '');
INSERT INTO 'tune' VALUES (1444, NULL, '2012-01-20 12:54:24.815819+00', 'Parody of Drumnagarry', 9999, '');
INSERT INTO 'tune' VALUES (1457, NULL, '2012-01-20 12:54:24.857641+00', 'Peter''s Peerie Boat', 1710, '');
INSERT INTO 'tune' VALUES (1445, NULL, '2012-01-20 12:54:24.818733+00', 'Partans in his Creel', 1737, '');
INSERT INTO 'tune' VALUES (4401, NULL, '2012-01-20 12:54:34.884991+00', 'Pitnacree Ferryman, The', 9999, '');
INSERT INTO 'tune' VALUES (1446, NULL, '2012-01-20 12:54:24.823054+00', 'Pat Cushnie''s Strathspey', 1668, '');
INSERT INTO 'tune' VALUES (1458, NULL, '2012-01-20 12:54:24.864243+00', 'Petronella', 1517, '');
INSERT INTO 'tune' VALUES (1447, NULL, '2012-01-20 12:54:24.827789+00', 'Peat Bog, The', 9999, '');
INSERT INTO 'tune' VALUES (4402, NULL, '2012-01-20 12:54:34.888863+00', 'Dawning of the Day', 397, '');
INSERT INTO 'tune' VALUES (1460, NULL, '2012-01-20 12:54:24.87204+00', 'Pibroch of Domnhall Dubh', 9999, '');
INSERT INTO 'tune' VALUES (4403, NULL, '2012-01-20 12:54:34.892696+00', 'Planxty Sir Festus Burke', 1882, '');
INSERT INTO 'tune' VALUES (1461, NULL, '2012-01-20 12:54:24.877235+00', 'Pinkie House', 9999, '');
INSERT INTO 'tune' VALUES (1463, NULL, '2012-01-20 12:54:24.885763+00', 'Piper''s March, The', 9999, '');
INSERT INTO 'tune' VALUES (4404, NULL, '2012-01-20 12:54:34.8965+00', 'Teetotaller, The', 9999, '');
INSERT INTO 'tune' VALUES (1464, NULL, '2012-01-20 12:54:24.889575+00', 'Piper''s Weird, The', 1512, '');
INSERT INTO 'tune' VALUES (1465, NULL, '2012-01-20 12:54:24.893389+00', 'Plantation Reel, The', 9998, '');
INSERT INTO 'tune' VALUES (1466, NULL, '2012-01-20 12:54:24.897244+00', 'Planxty Denis O''Conor', 1882, '');
INSERT INTO 'tune' VALUES (4405, NULL, '2012-01-20 12:54:34.900298+00', 'Plighted Troth, The', 1533, '');
INSERT INTO 'tune' VALUES (1467, NULL, '2012-01-20 12:54:24.900302+00', 'Pleasures of the Night, The', 1563, '');
INSERT INTO 'tune' VALUES (1468, NULL, '2012-01-20 12:54:24.903209+00', 'Ploughboy, The', 9999, '');
INSERT INTO 'tune' VALUES (4406, NULL, '2012-01-20 12:54:34.90409+00', 'Pontius Pilate''s Rant', 9998, '');
INSERT INTO 'tune' VALUES (1469, NULL, '2012-01-20 12:54:24.906102+00', 'Pogo Stick, The', 1502, '');
INSERT INTO 'tune' VALUES (4407, NULL, '2012-01-20 12:54:34.907892+00', 'Pop Goes the Weasel', 9998, '');
INSERT INTO 'tune' VALUES (1470, NULL, '2012-01-20 12:54:24.908999+00', 'Poldwilly Bridge', 9999, '');
INSERT INTO 'tune' VALUES (4408, NULL, '2012-01-20 12:54:34.911685+00', 'Port A''Bhodaich', 1587, '');
INSERT INTO 'tune' VALUES (1471, NULL, '2012-01-20 12:54:24.911891+00', 'Porridge Bowl, The', 2251, '');
INSERT INTO 'tune' VALUES (1472, NULL, '2012-01-20 12:54:24.91524+00', 'Pottinger''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (1473, NULL, '2012-01-20 12:54:24.918318+00', 'Priest and his Books, The', 9999, '');
INSERT INTO 'tune' VALUES (4409, NULL, '2012-01-20 12:54:34.916038+00', 'Portsmouth', 9999, '');
INSERT INTO 'tune' VALUES (1474, NULL, '2012-01-20 12:54:24.921234+00', 'Prince Albert''s Strathspey', 1867, '');
INSERT INTO 'tune' VALUES (4410, NULL, '2012-01-20 12:54:34.919871+00', 'Poussie, Poussie Bawdrons', 9998, '');
INSERT INTO 'tune' VALUES (1475, NULL, '2012-01-20 12:54:24.924147+00', 'Prince Charles of Edinburgh', 1588, '');
INSERT INTO 'tune' VALUES (4411, NULL, '2012-01-20 12:54:34.923675+00', 'Powderhorn Park', 2392, '');
INSERT INTO 'tune' VALUES (1476, NULL, '2012-01-20 12:54:24.927068+00', 'Prince Charlie''s Quickstep', 9999, '');
INSERT INTO 'tune' VALUES (1477, NULL, '2012-01-20 12:54:24.930095+00', 'Prince of Orange', 9998, '');
INSERT INTO 'tune' VALUES (1478, NULL, '2012-01-20 12:54:24.933024+00', 'Prince of Wales Strathspey', 1518, '');
INSERT INTO 'tune' VALUES (4413, NULL, '2012-01-20 12:54:34.933004+00', 'Oxford Street', 9999, '');
INSERT INTO 'tune' VALUES (4414, NULL, '2012-01-20 12:54:34.936841+00', 'Agnes Waltz, The', 1958, '');
INSERT INTO 'tune' VALUES (4416, NULL, '2012-01-20 12:54:34.944602+00', 'Crieff Birches, The', 1607, '');
INSERT INTO 'tune' VALUES (4417, NULL, '2012-01-20 12:54:34.948419+00', 'Prince Edward''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (4418, NULL, '2012-01-20 12:54:34.952259+00', 'Whistler, The', 1831, '');
INSERT INTO 'tune' VALUES (1459, NULL, '2012-05-02 11:52:07.851592+00', 'Philippa Jane', 1607, '');
INSERT INTO 'tune' VALUES (12071, '2012-05-04 19:11:46.053937+00', '2012-05-04 19:11:46.053948+00', 'Sandy C''s Minor', 1502, '');
INSERT INTO 'tune' VALUES (12125, '2012-06-12 14:55:18.834192+00', '2012-06-12 14:55:18.834203+00', 'Harvest Home', 9998, '');
INSERT INTO 'tune' VALUES (12271, '2012-12-28 14:58:31.646517+00', '2012-12-28 14:58:31.646528+00', 'Southern Moon', 1710, '');
INSERT INTO 'tune' VALUES (12313, '2013-01-02 15:48:01.293167+00', '2013-01-02 17:01:24.839598+00', 'Birds of Berries', 3798, '');
INSERT INTO 'tune' VALUES (12386, '2013-01-05 17:23:58.374512+00', '2013-01-05 17:23:58.374524+00', 'Colin and Rona Harcus', 2253, '');
INSERT INTO 'tune' VALUES (12450, '2013-02-02 16:31:14.461109+00', '2013-02-02 16:31:14.461124+00', 'Mist on the Cairns', 10737, '');
INSERT INTO 'tune' VALUES (12500, '2013-02-27 12:35:09.441575+00', '2013-02-27 12:35:09.441587+00', 'L.S.Q. Figure 6 Flirtation', 9999, '');
INSERT INTO 'tune' VALUES (1426, NULL, '2020-01-28 22:37:07.286761+00', 'Old Willie Hunter', 1623, '');
INSERT INTO 'tune' VALUES (1448, NULL, '2020-09-03 11:00:38.78443+00', 'Peat Fire Flame, The', 2437, '');
INSERT INTO 'tune' VALUES (1479, NULL, '2012-01-20 12:54:24.935979+00', 'Prince, The', 9999, '');
INSERT INTO 'tune' VALUES (1494, NULL, '2012-01-20 12:54:24.980297+00', 'Queen, The', 9999, '');
INSERT INTO 'tune' VALUES (4419, NULL, '2012-01-20 12:54:34.956055+00', 'Prince Rupert''s March', 9998, '');
INSERT INTO 'tune' VALUES (1480, NULL, '2012-01-20 12:54:24.938917+00', 'Princess Charlotte''s Favourite, The', 9999, '');
INSERT INTO 'tune' VALUES (1481, NULL, '2012-01-20 12:54:24.941852+00', 'Princess Margaret''s Jig', 1554, '');
INSERT INTO 'tune' VALUES (1495, NULL, '2012-01-20 12:54:24.983239+00', 'Queensway', 1701, '');
INSERT INTO 'tune' VALUES (4420, NULL, '2012-01-20 12:54:34.959895+00', 'Princess Margaret''s Strathspey', 1409, '');
INSERT INTO 'tune' VALUES (1482, NULL, '2012-01-20 12:54:24.944756+00', 'Princess Royal, The', 1882, '');
INSERT INTO 'tune' VALUES (1483, NULL, '2012-01-20 12:54:24.947655+00', 'Pringle''s Quickstep', 9999, '');
INSERT INTO 'tune' VALUES (1496, NULL, '2012-01-20 12:54:24.98615+00', 'Quick Step', 1476, '');
INSERT INTO 'tune' VALUES (4421, NULL, '2012-01-20 12:54:34.963691+00', 'Queen''s Jig, The', 9998, '');
INSERT INTO 'tune' VALUES (1484, NULL, '2012-01-20 12:54:24.950547+00', 'Pudding Pie Lane', 1439, '');
INSERT INTO 'tune' VALUES (1497, NULL, '2012-01-20 12:54:24.989039+00', 'Quickstep', 1517, '');
INSERT INTO 'tune' VALUES (4422, NULL, '2012-01-20 12:54:34.96749+00', 'Prince William', 9998, '');
INSERT INTO 'tune' VALUES (1486, NULL, '2012-01-20 12:54:24.956338+00', 'Punkie Willie', 9998, '');
INSERT INTO 'tune' VALUES (1498, NULL, '2012-01-20 12:54:24.99193+00', 'Balmedie Lasses, The', 1572, '');
INSERT INTO 'tune' VALUES (4423, NULL, '2012-01-20 12:54:34.971293+00', 'Prince William of Glo''ster''s Waltz', 9998, '');
INSERT INTO 'tune' VALUES (1488, NULL, '2012-01-20 12:54:24.962364+00', 'Quarry Weel, The', 2054, '');
INSERT INTO 'tune' VALUES (1489, NULL, '2012-01-20 12:54:24.965639+00', 'Queen Mother''s Progress, The', 326, '');
INSERT INTO 'tune' VALUES (1499, NULL, '2012-01-20 12:54:24.994821+00', 'Quickstep by the Duke of Gordon, A', 1695, '');
INSERT INTO 'tune' VALUES (4424, NULL, '2012-01-20 12:54:34.975101+00', 'Jack''s Pie', 1815, '');
INSERT INTO 'tune' VALUES (1490, NULL, '2012-01-20 12:54:24.968638+00', 'Queen''s Argylls, The', 9998, '');
INSERT INTO 'tune' VALUES (1491, NULL, '2012-01-20 12:54:24.971544+00', 'Queen''s Bridge, The', 1893, '');
INSERT INTO 'tune' VALUES (1500, NULL, '2012-01-20 12:54:24.997816+00', 'Quincentenary Reel, The', 1586, '');
INSERT INTO 'tune' VALUES (4425, NULL, '2012-01-20 12:54:34.978924+00', 'Jack in the Box', 1203, '');
INSERT INTO 'tune' VALUES (1492, NULL, '2012-01-20 12:54:24.97444+00', 'Queen''s Wedding', 1830, '');
INSERT INTO 'tune' VALUES (1493, NULL, '2012-01-20 12:54:24.977346+00', 'Queen''s Welcome', 9998, '');
INSERT INTO 'tune' VALUES (1501, NULL, '2012-01-20 12:54:25.002126+00', 'Rab the Ranter', 1562, '');
INSERT INTO 'tune' VALUES (4426, NULL, '2012-01-20 12:54:34.982726+00', 'Punk''s Delight, The', 9998, '');
INSERT INTO 'tune' VALUES (1502, NULL, '2012-01-20 12:54:25.045775+00', 'Rab''s Wedding', 2308, '');
INSERT INTO 'tune' VALUES (1453, NULL, '2022-07-27 19:52:10.403306+00', 'Perth Hunt', 1420, '');
INSERT INTO 'tune' VALUES (1436, NULL, '2022-08-20 14:49:48.409248+00', 'Owl and the Pussy Cat, The', 10658, '');
INSERT INTO 'tune' VALUES (12491, '2013-02-22 15:55:36.505699+00', '2022-12-10 22:58:26.89362+00', 'Wait ''til the Sun Shines Nellie', 12221, '');
INSERT INTO 'tune' VALUES (1485, NULL, '2023-01-24 21:58:35.591391+00', 'Pulling Bracken', 9999, 'Same as <<ddt:Cutting Bracken#6910>>. To be confirmed and merged?');
INSERT INTO 'tune' VALUES (1504, NULL, '2012-01-20 12:54:25.053498+00', 'Rakes of Glasgow', 459, '');
INSERT INTO 'tune' VALUES (4427, NULL, '2012-01-20 12:54:34.986512+00', 'Thou Art Gane Awa''', 9998, '');
INSERT INTO 'tune' VALUES (1505, NULL, '2012-01-20 12:54:25.0576+00', 'Rakes of Mallow, The', 9999, '');
INSERT INTO 'tune' VALUES (1506, NULL, '2012-01-20 12:54:25.061582+00', 'Rakish Highlandman, The', 9999, '');
INSERT INTO 'tune' VALUES (1507, NULL, '2012-01-20 12:54:25.065395+00', 'Rambling Free', 1439, '');
INSERT INTO 'tune' VALUES (1584, NULL, '2012-01-20 12:54:25.308885+00', 'Scotch Hop', 9998, '');
INSERT INTO 'tune' VALUES (4428, NULL, '2012-01-20 12:54:34.990306+00', 'Great North Run ''86', 1709, '');
INSERT INTO 'tune' VALUES (1508, NULL, '2012-01-20 12:54:25.06923+00', 'Randy Wives of Greenlaw, The', 1416, '');
INSERT INTO 'tune' VALUES (1509, NULL, '2012-01-20 12:54:25.07303+00', 'Rantin'' Rovin'' Robin', 9999, '');
INSERT INTO 'tune' VALUES (1510, NULL, '2012-01-20 12:54:25.076831+00', 'Ray Milbourne', 1527, '');
INSERT INTO 'tune' VALUES (4429, NULL, '2012-01-20 12:54:34.994104+00', 'Wetherell', 1607, '');
INSERT INTO 'tune' VALUES (1511, NULL, '2012-01-20 12:54:25.082715+00', 'Red House', 9999, '');
INSERT INTO 'tune' VALUES (1512, NULL, '2012-01-20 12:54:25.086712+00', 'Reel of Mey, The', 1792, '');
INSERT INTO 'tune' VALUES (4430, NULL, '2012-01-20 12:54:34.997901+00', 'John and Bessie Ferguson', 1439, '');
INSERT INTO 'tune' VALUES (1513, NULL, '2012-01-20 12:54:25.090611+00', 'Reel of Tulloch, The', 9999, '');
INSERT INTO 'tune' VALUES (4431, NULL, '2012-01-20 12:54:35.001684+00', 'Miss Christine Brown''s Jig', 1558, '');
INSERT INTO 'tune' VALUES (1514, NULL, '2012-01-20 12:54:25.094413+00', 'Reel of Tullochgorum, The', 9999, '');
INSERT INTO 'tune' VALUES (1515, NULL, '2012-01-20 12:54:25.098299+00', 'Reel of the Royal Scots, The', 1683, '');
INSERT INTO 'tune' VALUES (4432, NULL, '2012-01-20 12:54:35.00549+00', 'Queen Bess''s Dame of Honour', 9998, '');
INSERT INTO 'tune' VALUES (1516, NULL, '2012-01-20 12:54:25.102126+00', 'Regalia of Scotland', 9998, '');
INSERT INTO 'tune' VALUES (4433, NULL, '2012-01-20 12:54:35.009342+00', 'Mary Scott', 1512, '');
INSERT INTO 'tune' VALUES (1517, NULL, '2012-01-20 12:54:25.105968+00', 'Reids O'' Monymusk, The', 1968, '');
INSERT INTO 'tune' VALUES (1518, NULL, '2012-01-20 12:54:25.109812+00', 'Rendezvous, The', 9999, '');
INSERT INTO 'tune' VALUES (1519, NULL, '2012-01-20 12:54:25.113617+00', 'Rhona''s Reel', 1668, '');
INSERT INTO 'tune' VALUES (1520, NULL, '2012-01-20 12:54:25.117403+00', 'Ridhle mo Nighean Donn', 1910, '');
INSERT INTO 'tune' VALUES (1521, NULL, '2012-01-20 12:54:25.120379+00', 'Rifleman, The', 9998, '');
INSERT INTO 'tune' VALUES (1522, NULL, '2012-01-20 12:54:25.123311+00', 'Rising of the Moon, The', 9998, '');
INSERT INTO 'tune' VALUES (1523, NULL, '2012-01-20 12:54:25.126209+00', 'Rita''s Fancy', 1502, '');
INSERT INTO 'tune' VALUES (4435, NULL, '2012-01-20 12:54:35.016948+00', 'Cumming', 1607, '');
INSERT INTO 'tune' VALUES (1524, NULL, '2012-01-20 12:54:25.12914+00', 'River City, The', 1607, '');
INSERT INTO 'tune' VALUES (1525, NULL, '2012-01-20 12:54:25.132107+00', 'Road to Dundee, The', 1425, '');
INSERT INTO 'tune' VALUES (1526, NULL, '2012-01-20 12:54:25.135002+00', 'Road to Skye', 9999, '');
INSERT INTO 'tune' VALUES (4436, NULL, '2012-01-20 12:54:35.020763+00', 'Millbank Cottage', 1962, '');
INSERT INTO 'tune' VALUES (1528, NULL, '2012-01-20 12:54:25.140806+00', 'Roaring Jelly', 2145, '');
INSERT INTO 'tune' VALUES (4437, NULL, '2012-01-20 12:54:35.024567+00', 'Barney''s Balmoral', 1963, '');
INSERT INTO 'tune' VALUES (1530, NULL, '2012-01-20 12:54:25.146625+00', 'Robert E. Lyon', 1657, '');
INSERT INTO 'tune' VALUES (1531, NULL, '2012-01-20 12:54:25.149526+00', 'Robert Fitchet', 1554, '');
INSERT INTO 'tune' VALUES (1532, NULL, '2012-01-20 12:54:25.152418+00', 'Robert Rolston''s Reel', 1709, '');
INSERT INTO 'tune' VALUES (4438, NULL, '2012-01-20 12:54:35.028373+00', 'O Nanny, Wilt Thou Gaing Wi'' Me', 1964, '');
INSERT INTO 'tune' VALUES (1533, NULL, '2012-01-20 12:54:25.155389+00', 'Robertson''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (12072, '2012-05-04 19:12:20.774143+00', '2012-05-04 19:12:20.774154+00', 'My Best Girl', 1502, '');
INSERT INTO 'tune' VALUES (1534, NULL, '2012-01-20 12:54:25.158311+00', 'Robin Hill', 810, '');
INSERT INTO 'tune' VALUES (1535, NULL, '2012-01-20 12:54:25.161196+00', 'Rock and the Wee Pickle Tow', 9999, '');
INSERT INTO 'tune' VALUES (12126, '2012-06-12 14:57:11.671132+00', '2012-06-12 14:57:11.671143+00', 'Trip to Perth', 1508, '');
INSERT INTO 'tune' VALUES (1536, NULL, '2012-01-20 12:54:25.164091+00', 'Roddy McCorley', 9999, '');
INSERT INTO 'tune' VALUES (1537, NULL, '2012-01-20 12:54:25.166987+00', 'Ron and Evelyn Wake', 1576, '');
INSERT INTO 'tune' VALUES (12272, '2012-12-28 15:01:37.01816+00', '2012-12-28 15:01:37.018171+00', 'Eleanor''s Reel', 10675, '');
INSERT INTO 'tune' VALUES (1538, NULL, '2012-01-20 12:54:25.169864+00', 'Ronald J. Currie Esq.', 1474, '');
INSERT INTO 'tune' VALUES (1539, NULL, '2012-01-20 12:54:25.172792+00', 'Ronde, La', 9998, '');
INSERT INTO 'tune' VALUES (12314, '2013-01-02 15:48:53.277889+00', '2013-01-02 17:00:10.55787+00', 'All Night in the Sugar Bush', 3798, '');
INSERT INTO 'tune' VALUES (1541, NULL, '2012-01-20 12:54:25.178574+00', 'Rose Tree, The', 9999, '');
INSERT INTO 'tune' VALUES (12387, '2013-01-05 17:29:09.030062+00', '2013-01-05 17:29:09.030074+00', 'Burnhouse Bad Boy', 2253, '');
INSERT INTO 'tune' VALUES (12501, '2013-02-27 12:41:41.604132+00', '2013-02-27 12:41:41.604143+00', 'Dancing Piper, The', 1621, '');
INSERT INTO 'tune' VALUES (1542, NULL, '2012-01-20 12:54:25.181779+00', 'Rose among the Heather', 9999, '');
INSERT INTO 'tune' VALUES (1563, NULL, '2012-01-20 12:54:25.244823+00', 'Spear Maiden', 1510, '');
INSERT INTO 'tune' VALUES (4439, NULL, '2012-01-20 12:54:35.03219+00', 'Mrs Margaret Rule', 9998, '');
INSERT INTO 'tune' VALUES (1543, NULL, '2012-01-20 12:54:25.186762+00', 'Lady Menzies of Castle Menzies', 1516, '');
INSERT INTO 'tune' VALUES (1564, NULL, '2012-01-20 12:54:25.247743+00', 'Alex Westwood''s Strathspey', 2134, '');
INSERT INTO 'tune' VALUES (4440, NULL, '2012-01-20 12:54:35.036031+00', 'Lochgarten', 9998, '');
INSERT INTO 'tune' VALUES (13831, '2018-02-24 09:26:03.874613+00', '2018-02-24 09:26:03.874613+00', 'Ian MacLeod', 9998, '');
INSERT INTO 'tune' VALUES (1546, NULL, '2012-01-20 12:54:25.195486+00', 'Lady Macintosh''s Rant', 9999, '');
INSERT INTO 'tune' VALUES (1565, NULL, '2012-01-20 12:54:25.250639+00', 'Sailor''s Wife, The', 1518, '');
INSERT INTO 'tune' VALUES (4441, NULL, '2012-01-20 12:54:35.039861+00', 'In and Out and Roundabout', 1643, '');
INSERT INTO 'tune' VALUES (1547, NULL, '2012-01-20 12:54:25.198372+00', 'Miss Louisa Duff', 1516, '');
INSERT INTO 'tune' VALUES (1548, NULL, '2012-01-20 12:54:25.20127+00', 'Rothes Reel, The', 1719, '');
INSERT INTO 'tune' VALUES (1566, NULL, '2012-01-20 12:54:25.253814+00', 'Sally Gardens, The', 9999, '');
INSERT INTO 'tune' VALUES (4442, NULL, '2012-01-20 12:54:35.043668+00', 'Rambling Pitchfork, The', 9998, '');
INSERT INTO 'tune' VALUES (1549, NULL, '2012-01-20 12:54:25.204211+00', 'Rothesay Rant, The', 1701, '');
INSERT INTO 'tune' VALUES (1550, NULL, '2012-01-20 12:54:25.20711+00', 'Rothiemurchus Rant', 9999, '');
INSERT INTO 'tune' VALUES (1567, NULL, '2012-01-20 12:54:25.256705+00', 'Saltire Society Reel, The', 1556, '');
INSERT INTO 'tune' VALUES (4443, NULL, '2012-01-20 12:54:35.047487+00', 'Ramsgate Assembly', 9998, '');
INSERT INTO 'tune' VALUES (1551, NULL, '2012-01-20 12:54:25.209996+00', 'Rothiemurchus'' Daughter', 9998, '');
INSERT INTO 'tune' VALUES (1552, NULL, '2012-01-20 12:54:25.212895+00', 'Round about Hullachan', 9998, '');
INSERT INTO 'tune' VALUES (1568, NULL, '2012-01-20 12:54:25.259701+00', 'Salutations to Mrs Cramb', 326, '');
INSERT INTO 'tune' VALUES (4444, NULL, '2012-01-20 12:54:35.051296+00', 'Rattlin'' Bog', 9999, '');
INSERT INTO 'tune' VALUES (1553, NULL, '2012-01-20 12:54:25.21579+00', 'Roxburgh Castle', 9999, '');
INSERT INTO 'tune' VALUES (1554, NULL, '2012-01-20 12:54:25.218687+00', 'Roxburgh Quick Step', 9999, '');
INSERT INTO 'tune' VALUES (1569, NULL, '2012-01-20 12:54:25.262617+00', 'Salute to Bath', 1590, '');
INSERT INTO 'tune' VALUES (1555, NULL, '2012-01-20 12:54:25.221577+00', 'Roy Goldring''s Favourite', 1593, '');
INSERT INTO 'tune' VALUES (1556, NULL, '2012-01-20 12:54:25.224473+00', 'Roy''s Wife of Aldivalloch', 9998, '');
INSERT INTO 'tune' VALUES (1570, NULL, '2012-01-20 12:54:25.265514+00', 'Salute to Jim MacLeod', 1715, '');
INSERT INTO 'tune' VALUES (4446, NULL, '2012-01-20 12:54:35.0589+00', 'Red Baron, The', 1607, '');
INSERT INTO 'tune' VALUES (1557, NULL, '2012-01-20 12:54:25.227402+00', 'Royal Captives, The', 1563, '');
INSERT INTO 'tune' VALUES (13895, '2018-06-09 01:02:40.869634+00', '2018-06-09 01:02:40.869634+00', 'Anselm Lingnau', 3436, '');
INSERT INTO 'tune' VALUES (1571, NULL, '2012-01-20 12:54:25.268411+00', 'Salute to Miss Jean Milligan', 1652, '');
INSERT INTO 'tune' VALUES (4447, NULL, '2012-01-20 12:54:35.062688+00', 'Raisin'' a Stour', 1834, '');
INSERT INTO 'tune' VALUES (1559, NULL, '2012-01-20 12:54:25.233236+00', 'Royal Wedding, The', 1563, '');
INSERT INTO 'tune' VALUES (1560, NULL, '2012-01-20 12:54:25.236134+00', 'Ruby Jig, The', 1709, '');
INSERT INTO 'tune' VALUES (1572, NULL, '2012-01-20 12:54:25.271308+00', 'Salute to Rowallan', 1607, '');
INSERT INTO 'tune' VALUES (4448, NULL, '2012-01-20 12:54:35.066541+00', 'Red River Welcome', 1965, '');
INSERT INTO 'tune' VALUES (1561, NULL, '2012-01-20 12:54:25.239024+00', 'Runaway Bride, The', 9999, '');
INSERT INTO 'tune' VALUES (1562, NULL, '2012-01-20 12:54:25.241914+00', 'Sailor at the Bow', 9999, '');
INSERT INTO 'tune' VALUES (1573, NULL, '2012-01-20 12:54:25.274221+00', 'Sands of Asilomar, The', 1745, '');
INSERT INTO 'tune' VALUES (4449, NULL, '2012-01-20 12:54:35.070361+00', 'Joys of Wedlock', 9999, '');
INSERT INTO 'tune' VALUES (1574, NULL, '2012-01-20 12:54:25.279275+00', 'Sandy Nixon', 1527, '');
INSERT INTO 'tune' VALUES (1575, NULL, '2012-01-20 12:54:25.282178+00', 'Sandy Pirie of Hazelhead', 1655, '');
INSERT INTO 'tune' VALUES (1576, NULL, '2012-01-20 12:54:25.285077+00', 'Sandy''s Muckle Box', 1656, '');
INSERT INTO 'tune' VALUES (4450, NULL, '2012-01-20 12:54:35.074155+00', 'Katherine''s Jig', 1582, '');
INSERT INTO 'tune' VALUES (1577, NULL, '2012-01-20 12:54:25.287968+00', 'Sarah Anne Cheyne', 1607, '');
INSERT INTO 'tune' VALUES (1578, NULL, '2012-01-20 12:54:25.290877+00', 'Sarona', 1512, '');
INSERT INTO 'tune' VALUES (1579, NULL, '2012-01-20 12:54:25.293783+00', 'Savage Hornpipe, The', 9998, '');
INSERT INTO 'tune' VALUES (4451, NULL, '2012-01-20 12:54:35.077957+00', 'Dancing the Baby', 1607, '');
INSERT INTO 'tune' VALUES (1580, NULL, '2012-01-20 12:54:25.296682+00', 'Saw Ye My Wee Thing', 1798, '');
INSERT INTO 'tune' VALUES (1581, NULL, '2012-01-20 12:54:25.300157+00', 'Scarce o'' Tatties', 1775, '');
INSERT INTO 'tune' VALUES (4452, NULL, '2012-01-20 12:54:35.08176+00', 'Dancing on the Ramparts', 326, '');
INSERT INTO 'tune' VALUES (1582, NULL, '2012-01-20 12:54:25.303066+00', 'Scholar, The', 2147, '');
INSERT INTO 'tune' VALUES (4453, NULL, '2012-01-20 12:54:35.085855+00', 'Miss Dalrymple', 1781, '');
INSERT INTO 'tune' VALUES (4602, NULL, '2012-01-20 12:54:35.644913+00', 'Allanach', 1607, '');
INSERT INTO 'tune' VALUES (1583, NULL, '2012-01-20 12:54:25.305993+00', 'Scotch Hero''s Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (4434, NULL, '2014-08-24 10:41:21.254636+00', 'Queen Vic''s Washing Day', 1872, '');
INSERT INTO 'tune' VALUES (1585, NULL, '2012-01-20 12:54:25.311797+00', 'Scotch Mist', 9999, '');
INSERT INTO 'tune' VALUES (4454, NULL, '2012-01-20 12:54:35.089649+00', 'Return to Cheltenham', 1661, '');
INSERT INTO 'tune' VALUES (1586, NULL, '2012-01-20 12:54:25.314712+00', 'Scotland the Brave', 2467, '');
INSERT INTO 'tune' VALUES (1587, NULL, '2012-01-20 12:54:25.317604+00', 'Scots Measure, A', 1859, '');
INSERT INTO 'tune' VALUES (4455, NULL, '2012-01-20 12:54:35.093445+00', 'Rhinns of Kells, The', 1437, '');
INSERT INTO 'tune' VALUES (1589, NULL, '2012-01-20 12:54:25.323711+00', 'Scottish Bugler, The', 1701, '');
INSERT INTO 'tune' VALUES (1590, NULL, '2012-01-20 12:54:25.326601+00', 'Scottish Horse, The', 2165, '');
INSERT INTO 'tune' VALUES (4456, NULL, '2012-01-20 12:54:35.097256+00', 'Mr Jack Rennie''s Strathspey', 1584, '');
INSERT INTO 'tune' VALUES (1592, NULL, '2012-01-20 12:54:25.34164+00', 'Scottish Ramble', 9999, '');
INSERT INTO 'tune' VALUES (1593, NULL, '2012-01-20 12:54:25.345495+00', 'Scottish Reform', 9999, '');
INSERT INTO 'tune' VALUES (4457, NULL, '2012-01-20 12:54:35.101141+00', 'Richmora', 2257, '');
INSERT INTO 'tune' VALUES (4458, NULL, '2012-01-20 12:54:35.104942+00', 'Riddle, The', 9998, '');
INSERT INTO 'tune' VALUES (4459, NULL, '2012-01-20 12:54:35.108741+00', 'Scottish Society of Rio de Janeiro, The', 1527, '');
INSERT INTO 'tune' VALUES (4460, NULL, '2012-01-20 12:54:35.112533+00', 'Riverside Jig', 1837, '');
INSERT INTO 'tune' VALUES (4461, NULL, '2012-01-20 12:54:35.11637+00', 'Woolen Mill, The', 1608, '');
INSERT INTO 'tune' VALUES (4462, NULL, '2012-01-20 12:54:35.120952+00', 'Catherine''s Reel', 1657, '');
INSERT INTO 'tune' VALUES (4463, NULL, '2012-01-20 12:54:35.125625+00', 'Black and White, The', 2392, '');
INSERT INTO 'tune' VALUES (4464, NULL, '2012-01-20 12:54:35.129615+00', 'Ron Gonnella''s Compliments to Senator Robert Byrd', 1615, '');
INSERT INTO 'tune' VALUES (12273, '2012-12-28 15:02:58.760944+00', '2012-12-28 15:02:58.760958+00', 'Miss Sonja Scollay', 2912, '');
INSERT INTO 'tune' VALUES (12315, '2013-01-02 15:50:02.910447+00', '2013-01-02 17:01:48.069314+00', 'Blue Spruce Jig', 3798, '');
INSERT INTO 'tune' VALUES (12388, '2013-01-05 17:30:00.900572+00', '2013-01-05 17:30:00.900584+00', 'Norkister', 2253, '');
INSERT INTO 'tune' VALUES (4445, NULL, '2013-01-24 14:33:07.512199+00', 'Ravelston Rant, The', 1463, '');
INSERT INTO 'tune' VALUES (12493, '2013-02-22 16:01:20.543977+00', '2013-02-22 16:01:20.543988+00', 'When you''re Smiling', 10755, '');
INSERT INTO 'tune' VALUES (12502, '2013-02-27 12:49:44.340877+00', '2013-02-27 12:49:44.340888+00', 'Student Lancers Figure 1', 9999, '');
INSERT INTO 'tune' VALUES (1594, NULL, '2012-01-20 12:54:25.349327+00', 'Miss Lyall (reel)', 2142, '');
INSERT INTO 'tune' VALUES (1615, NULL, '2012-01-20 12:54:25.431395+00', 'Singing Strathspey, The', 1614, '');
INSERT INTO 'tune' VALUES (1595, NULL, '2012-01-20 12:54:25.353181+00', 'Shakin'' the Bottle', 1576, '');
INSERT INTO 'tune' VALUES (4465, NULL, '2012-01-20 12:54:35.133436+00', 'Robert Innes of Stirling University', 1969, '');
INSERT INTO 'tune' VALUES (1596, NULL, '2012-01-20 12:54:25.357008+00', 'She''s Fair and Fause', 9999, '');
INSERT INTO 'tune' VALUES (1616, NULL, '2012-01-20 12:54:25.434306+00', 'Sir Archibald Campbell''s Jig', 1493, '');
INSERT INTO 'tune' VALUES (4466, NULL, '2012-01-20 12:54:35.137242+00', 'Rose Kelman''s Reel', 1404, '');
INSERT INTO 'tune' VALUES (1598, NULL, '2012-01-20 12:54:25.365172+00', 'Shepherd''s Wife, The', 1518, '');
INSERT INTO 'tune' VALUES (1617, NULL, '2012-01-20 12:54:25.437199+00', 'Sir Charles Douglas''s Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (1599, NULL, '2012-01-20 12:54:25.369006+00', 'Sherrifmuir', 9998, '');
INSERT INTO 'tune' VALUES (4467, NULL, '2012-01-20 12:54:35.141037+00', 'Ronnie Douglas', 9998, '');
INSERT INTO 'tune' VALUES (1600, NULL, '2012-01-20 12:54:25.372816+00', 'Shetland Fiddler, The', 1426, '');
INSERT INTO 'tune' VALUES (1618, NULL, '2012-01-20 12:54:25.440127+00', 'Sir George Clark of Pennycuik', 1517, '');
INSERT INTO 'tune' VALUES (1601, NULL, '2012-01-20 12:54:25.376639+00', 'Ashgrove, The', 9999, '');
INSERT INTO 'tune' VALUES (4468, NULL, '2012-01-20 12:54:35.144885+00', 'Oran do Iain Breac MacLeoid', 1970, '');
INSERT INTO 'tune' VALUES (1602, NULL, '2012-01-20 12:54:25.380465+00', 'Finlay''s Favourite', 1507, '');
INSERT INTO 'tune' VALUES (1619, NULL, '2012-01-20 12:54:25.443026+00', 'Sir James Baird''s Strathspey', 1518, '');
INSERT INTO 'tune' VALUES (1591, NULL, '2017-07-07 13:06:03.308455+00', 'Scottish Legacy, The', 9999, '');
INSERT INTO 'tune' VALUES (1603, NULL, '2012-01-20 12:54:25.384295+00', 'Shiftin'' Bobbins', 810, '');
INSERT INTO 'tune' VALUES (4469, NULL, '2012-01-20 12:54:35.14869+00', 'Ewan''s Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (1604, NULL, '2012-01-20 12:54:25.388765+00', 'Ship in Full Sail, The', 9999, '');
INSERT INTO 'tune' VALUES (1620, NULL, '2012-01-20 12:54:25.445917+00', 'Six-Twenty Two Step', 1558, '');
INSERT INTO 'tune' VALUES (1605, NULL, '2012-01-20 12:54:25.392725+00', 'Ship o'' Grace', 1607, '');
INSERT INTO 'tune' VALUES (4470, NULL, '2012-01-20 12:54:35.152495+00', 'Rosemary''s Reel', 1615, '');
INSERT INTO 'tune' VALUES (1606, NULL, '2012-01-20 12:54:25.396583+00', 'Shira Glen', 9998, '');
INSERT INTO 'tune' VALUES (1607, NULL, '2012-01-20 12:54:25.40041+00', 'Sic a Wife as Willie had', 9999, '');
INSERT INTO 'tune' VALUES (4471, NULL, '2012-01-20 12:54:35.156295+00', 'Rose of Glamis, The', 1502, '');
INSERT INTO 'tune' VALUES (1608, NULL, '2012-01-20 12:54:25.404244+00', 'We''re A'' Scotsmen', 2228, '');
INSERT INTO 'tune' VALUES (1622, NULL, '2012-01-20 12:54:25.452435+00', 'Auld Lang Syne', 9999, '');
INSERT INTO 'tune' VALUES (1609, NULL, '2012-01-20 12:54:25.408084+00', 'Sidlaw Hills, The', 1492, '');
INSERT INTO 'tune' VALUES (4472, NULL, '2012-01-20 12:54:35.160153+00', 'Jewel in the Crown, The', 1502, '');
INSERT INTO 'tune' VALUES (1610, NULL, '2012-01-20 12:54:25.412212+00', 'Siesta at Antica', 1718, '');
INSERT INTO 'tune' VALUES (1623, NULL, '2012-01-20 12:54:25.455485+00', 'Smashing Set of Reels, A', 9998, '');
INSERT INTO 'tune' VALUES (1611, NULL, '2012-01-20 12:54:25.416901+00', 'Silver Spear', 9999, '');
INSERT INTO 'tune' VALUES (4473, NULL, '2012-01-20 12:54:35.163959+00', 'Rose of Halftown, The', 9998, '');
INSERT INTO 'tune' VALUES (1612, NULL, '2012-01-20 12:54:25.42073+00', 'Simon Brodie', 9998, '');
INSERT INTO 'tune' VALUES (1624, NULL, '2012-01-20 12:54:25.458396+00', 'Smith''s a Gallant Fireman, The', 9999, '');
INSERT INTO 'tune' VALUES (1613, NULL, '2012-01-20 12:54:25.424711+00', 'Singing Bird, The', 9999, '');
INSERT INTO 'tune' VALUES (4474, NULL, '2012-01-20 12:54:35.167761+00', 'Four and Twenty', 9999, '');
INSERT INTO 'tune' VALUES (1614, NULL, '2012-01-20 12:54:25.428429+00', 'Singing Kettle, The', 9998, '');
INSERT INTO 'tune' VALUES (1626, NULL, '2012-01-20 12:54:25.464486+00', 'Society Piper', 1815, '');
INSERT INTO 'tune' VALUES (4475, NULL, '2012-01-20 12:54:35.171561+00', 'Mrs Ethel Mary Ross', 1971, '');
INSERT INTO 'tune' VALUES (1627, NULL, '2012-01-20 12:54:25.467556+00', 'Sodger Laddie', 9999, '');
INSERT INTO 'tune' VALUES (1628, NULL, '2012-01-20 12:54:25.471023+00', 'Soldier''s Dance, The', 9999, '');
INSERT INTO 'tune' VALUES (4551, NULL, '2012-01-20 12:54:35.47743+00', 'Ben Lomond', 9999, '');
INSERT INTO 'tune' VALUES (4476, NULL, '2012-01-20 12:54:35.175377+00', 'Allan o'' Fairfield', 3298, '');
INSERT INTO 'tune' VALUES (1630, NULL, '2012-01-20 12:54:25.477001+00', 'Long-Eared Mule', 9999, '');
INSERT INTO 'tune' VALUES (1631, NULL, '2012-01-20 12:54:25.479899+00', 'Solway Firth, The', 1668, '');
INSERT INTO 'tune' VALUES (4477, NULL, '2012-01-20 12:54:35.17918+00', 'Round, The', 9998, '');
INSERT INTO 'tune' VALUES (1632, NULL, '2012-01-20 12:54:25.482813+00', 'Somebody', 9998, '');
INSERT INTO 'tune' VALUES (4478, NULL, '2012-01-20 12:54:35.182985+00', 'Roundabout', 1244, '');
INSERT INTO 'tune' VALUES (1633, NULL, '2012-01-20 12:54:25.485859+00', 'Song of Spain', 1407, '');
INSERT INTO 'tune' VALUES (1634, NULL, '2012-01-20 12:54:25.488904+00', 'Song to Prince Charlie', 9998, '');
INSERT INTO 'tune' VALUES (4479, NULL, '2012-01-20 12:54:35.186788+00', 'Old Simon the King', 9998, '');
INSERT INTO 'tune' VALUES (1635, NULL, '2012-01-20 12:54:25.491856+00', 'South from Oban', 1607, '');
INSERT INTO 'tune' VALUES (1636, NULL, '2012-01-20 12:54:25.495282+00', 'South of the Grampians', 1512, '');
INSERT INTO 'tune' VALUES (1637, NULL, '2012-01-20 12:54:25.49832+00', 'Sow''s Tail, The', 1518, '');
INSERT INTO 'tune' VALUES (4480, NULL, '2012-01-20 12:54:35.19058+00', 'Duke and Duchess of York, The', 1576, '');
INSERT INTO 'tune' VALUES (1638, NULL, '2012-01-20 12:54:25.501238+00', 'Speed the Plough', 9999, '');
INSERT INTO 'tune' VALUES (1639, NULL, '2012-01-20 12:54:25.504311+00', 'Spey in Spate, The', 1512, '');
INSERT INTO 'tune' VALUES (1640, NULL, '2012-01-20 12:54:25.507231+00', 'Sporran Reel, The', 9998, '');
INSERT INTO 'tune' VALUES (4481, NULL, '2012-01-20 12:54:35.194385+00', 'Miss Mary Mowat', 1607, '');
INSERT INTO 'tune' VALUES (1641, NULL, '2012-01-20 12:54:25.510236+00', 'Sprightly Maiden, The', 9998, '');
INSERT INTO 'tune' VALUES (1643, NULL, '2012-01-20 12:54:25.516552+00', 'Charlie Hunter', 3058, '');
INSERT INTO 'tune' VALUES (4482, NULL, '2012-01-20 12:54:35.198169+00', 'Northern Jig, The', 1538, '');
INSERT INTO 'tune' VALUES (1644, NULL, '2012-01-20 12:54:25.51949+00', 'Squirrel, The', 1589, '');
INSERT INTO 'tune' VALUES (1645, NULL, '2012-01-20 12:54:25.522519+00', 'Saint Alban''s Caledonian Society', 1649, '');
INSERT INTO 'tune' VALUES (4483, NULL, '2012-01-20 12:54:35.201977+00', 'Mod, The', 1607, '');
INSERT INTO 'tune' VALUES (4484, NULL, '2012-01-20 12:54:35.20577+00', 'Rumbling Bridge', 1615, '');
INSERT INTO 'tune' VALUES (4485, NULL, '2012-01-20 12:54:35.209564+00', 'Bobby and his Bone', 1582, '');
INSERT INTO 'tune' VALUES (4486, NULL, '2012-01-20 12:54:35.213377+00', 'Rumford Lilt, The', 928, '');
INSERT INTO 'tune' VALUES (4487, NULL, '2012-01-20 12:54:35.21717+00', 'Mrs Murray of Templewood', 1972, '');
INSERT INTO 'tune' VALUES (4488, NULL, '2012-01-20 12:54:35.221015+00', 'Rural Sports', 9998, '');
INSERT INTO 'tune' VALUES (4489, NULL, '2012-01-20 12:54:35.224955+00', 'Tyneside Scottish Country Dancers, The', 1558, '');
INSERT INTO 'tune' VALUES (4490, NULL, '2012-01-20 12:54:35.228968+00', 'Ailsa''s Fancy', 1551, '');
INSERT INTO 'tune' VALUES (12074, '2012-05-04 19:13:33.496305+00', '2012-05-04 19:13:33.496315+00', 'Em''s Tattie Scones', 1502, '');
INSERT INTO 'tune' VALUES (1629, NULL, '2014-10-26 12:40:32.875829+00', 'Soldier''s Joy', 9999, '');
INSERT INTO 'tune' VALUES (1621, NULL, '2014-11-01 14:28:35.128489+00', 'Sleepy Maggie', 442, '');
INSERT INTO 'tune' VALUES (12128, '2012-06-12 15:06:37.629592+00', '2012-06-12 15:06:37.629607+00', 'Ann Nixon''s Jig', 1576, '');
INSERT INTO 'tune' VALUES (12274, '2012-12-28 15:06:46.063645+00', '2012-12-28 15:06:46.063656+00', 'Ivor Scollay Two Step, The', 1593, '');
INSERT INTO 'tune' VALUES (12316, '2013-01-02 15:53:13.991985+00', '2013-01-02 15:53:13.991995+00', 'Come Along', 9999, '');
INSERT INTO 'tune' VALUES (12389, '2013-01-05 17:31:06.918791+00', '2013-01-05 17:31:06.918802+00', 'Alfie Linklater of Housegarth', 2253, '');
INSERT INTO 'tune' VALUES (12503, '2013-02-27 12:50:05.12269+00', '2013-02-27 12:50:05.122702+00', 'Student Lancers Figure 2', 9999, '');
INSERT INTO 'tune' VALUES (1667, NULL, '2012-01-20 12:54:25.58938+00', 'Storybook Glen', 1557, '');
INSERT INTO 'tune' VALUES (4491, NULL, '2012-01-20 12:54:35.232997+00', 'Sage Leaf', 9998, '');
INSERT INTO 'tune' VALUES (1647, NULL, '2012-01-20 12:54:25.528335+00', 'Saint Andrew''s Parade', 1558, '');
INSERT INTO 'tune' VALUES (13832, '2018-02-24 09:26:58.285808+00', '2018-02-24 09:26:58.285808+00', 'Jacky Latin', 9998, '');
INSERT INTO 'tune' VALUES (1668, NULL, '2012-01-20 12:54:25.59232+00', 'Strawberry Bank', 1658, '');
INSERT INTO 'tune' VALUES (4492, NULL, '2012-01-20 12:54:35.236893+00', 'Sailor Scotty', 1461, '');
INSERT INTO 'tune' VALUES (1649, NULL, '2012-01-20 12:54:25.53545+00', 'Saint Magnus Bay', 1521, '');
INSERT INTO 'tune' VALUES (1650, NULL, '2012-01-20 12:54:25.538421+00', 'Saint Patrick''s Day', 1518, '');
INSERT INTO 'tune' VALUES (1669, NULL, '2012-01-20 12:54:25.595219+00', 'Stronsay Jig', 1413, '');
INSERT INTO 'tune' VALUES (4493, NULL, '2012-01-20 12:54:35.240702+00', 'Donald Sutherland''s Welcome back to Rogart', 1787, '');
INSERT INTO 'tune' VALUES (1651, NULL, '2012-01-20 12:54:25.541329+00', 'Stack of Cards', 1502, '');
INSERT INTO 'tune' VALUES (1652, NULL, '2012-01-20 12:54:25.544226+00', 'Stan Saunders'' Hornpipe', 1576, '');
INSERT INTO 'tune' VALUES (1670, NULL, '2012-01-20 12:54:25.598105+00', 'Struan Robertson''s Rant', 9999, '');
INSERT INTO 'tune' VALUES (4494, NULL, '2012-01-20 12:54:35.244539+00', 'Saint Ebba''s Strand', 1235, '');
INSERT INTO 'tune' VALUES (1653, NULL, '2012-01-20 12:54:25.547131+00', 'Stanley Burn', 1502, '');
INSERT INTO 'tune' VALUES (1654, NULL, '2012-01-20 12:54:25.550022+00', 'Stanley Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (1671, NULL, '2012-01-20 12:54:25.601014+00', 'Stuart Robertson''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (4495, NULL, '2012-01-20 12:54:35.248342+00', 'Hirta Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (1655, NULL, '2012-01-20 12:54:25.553003+00', 'Staten Island', 9999, '');
INSERT INTO 'tune' VALUES (1672, NULL, '2012-01-20 12:54:25.604422+00', 'Stuart''s Rant, The', 9999, '');
INSERT INTO 'tune' VALUES (4496, NULL, '2012-01-20 12:54:35.252154+00', 'O'' A'' the Airts', 9998, '');
INSERT INTO 'tune' VALUES (1657, NULL, '2012-01-20 12:54:25.559637+00', 'Stewart and Chris Adam', 1527, '');
INSERT INTO 'tune' VALUES (1658, NULL, '2012-01-20 12:54:25.562545+00', 'Stewart''s Lassie', 9999, '');
INSERT INTO 'tune' VALUES (4497, NULL, '2012-01-20 12:54:35.255955+00', 'Allan Murray''s Fancy', 9998, '');
INSERT INTO 'tune' VALUES (1659, NULL, '2012-01-20 12:54:25.565474+00', 'Stirling Castle', 1686, '');
INSERT INTO 'tune' VALUES (1660, NULL, '2012-01-20 12:54:25.568366+00', 'Graham Jamieson''s Comphy Pumphy', 1527, '');
INSERT INTO 'tune' VALUES (1674, NULL, '2012-01-20 12:54:25.610472+00', 'Sundrum Castle', 1502, '');
INSERT INTO 'tune' VALUES (4498, NULL, '2012-01-20 12:54:35.259784+00', 'Saint Martin''s Lane', 9998, '');
INSERT INTO 'tune' VALUES (1661, NULL, '2012-01-20 12:54:25.571267+00', 'Stobhall', 1558, '');
INSERT INTO 'tune' VALUES (1662, NULL, '2012-01-20 12:54:25.574165+00', 'Stone Court, The', 1647, '');
INSERT INTO 'tune' VALUES (1675, NULL, '2012-01-20 12:54:25.613423+00', 'Susan''s Reel', 810, '');
INSERT INTO 'tune' VALUES (4499, NULL, '2012-01-20 12:54:35.263583+00', 'Lady Serena James', 1479, '');
INSERT INTO 'tune' VALUES (1663, NULL, '2012-01-20 12:54:25.577069+00', 'Stonedyke Jig, The', 1876, '');
INSERT INTO 'tune' VALUES (1664, NULL, '2012-01-20 12:54:25.579969+00', 'Stoneypath Tower', 1525, '');
INSERT INTO 'tune' VALUES (1676, NULL, '2012-01-20 12:54:25.616317+00', 'Sussex Scot, The', 1718, '');
INSERT INTO 'tune' VALUES (4500, NULL, '2012-01-20 12:54:35.26739+00', 'Down by the Sally Gardens', 9999, '');
INSERT INTO 'tune' VALUES (1665, NULL, '2012-01-20 12:54:25.583468+00', 'Stool of Repentance, The', 1518, '');
INSERT INTO 'tune' VALUES (1666, NULL, '2012-01-20 12:54:25.586466+00', 'Stornoway Castle', 2138, '');
INSERT INTO 'tune' VALUES (1677, NULL, '2012-01-20 12:54:25.619218+00', 'Sutherland''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (4501, NULL, '2012-01-20 12:54:35.271194+00', 'Wigan Thistle', 810, '');
INSERT INTO 'tune' VALUES (1678, NULL, '2012-01-20 12:54:25.622116+00', 'Sutton Park', 1701, '');
INSERT INTO 'tune' VALUES (1679, NULL, '2012-01-20 12:54:25.625445+00', 'Iain Charles Dey', 1527, '');
INSERT INTO 'tune' VALUES (4502, NULL, '2012-01-20 12:54:35.286807+00', 'Brise d''Anjou', 810, '');
INSERT INTO 'tune' VALUES (1681, NULL, '2012-01-20 12:54:25.631271+00', 'Swinging on a Gate', 9999, '');
INSERT INTO 'tune' VALUES (1682, NULL, '2012-01-20 12:54:25.63416+00', 'Sylph, The', 9999, '');
INSERT INTO 'tune' VALUES (4503, NULL, '2012-01-20 12:54:35.290865+00', 'Rozelle', 1418, '');
INSERT INTO 'tune' VALUES (1683, NULL, '2012-01-20 12:54:25.637061+00', 'Tae Gar Ye Loup', 1586, '');
INSERT INTO 'tune' VALUES (1684, NULL, '2012-01-20 12:54:25.639949+00', 'Margaret''s Waltz', 1528, '');
INSERT INTO 'tune' VALUES (4504, NULL, '2012-01-20 12:54:35.294686+00', 'Ken''s Backward Bus', 9998, '');
INSERT INTO 'tune' VALUES (1685, NULL, '2012-01-20 12:54:25.643421+00', 'Tam Bain''s Lum', 1426, '');
INSERT INTO 'tune' VALUES (1686, NULL, '2012-01-20 12:54:25.646461+00', 'Tam Glen', 9999, '');
INSERT INTO 'tune' VALUES (1687, NULL, '2012-01-20 12:54:25.649369+00', 'Tam''s Hunting Horn', 1655, '');
INSERT INTO 'tune' VALUES (4505, NULL, '2012-01-20 12:54:35.298496+00', 'Entente Cordiale', 9998, '');
INSERT INTO 'tune' VALUES (1688, NULL, '2012-01-20 12:54:25.652261+00', 'Tammy', 9999, '');
INSERT INTO 'tune' VALUES (1689, NULL, '2012-01-20 12:54:25.655901+00', 'Tarholm Brig', 1627, '');
INSERT INTO 'tune' VALUES (1690, NULL, '2012-01-20 12:54:25.659376+00', 'Far o''er the sea', 2318, '');
INSERT INTO 'tune' VALUES (1691, NULL, '2012-01-20 12:54:25.662367+00', 'Tarry a While', 9999, '');
INSERT INTO 'tune' VALUES (1692, NULL, '2012-01-20 12:54:25.665271+00', 'Tartan Plaidie', 263, '');
INSERT INTO 'tune' VALUES (1693, NULL, '2012-01-20 12:54:25.668168+00', 'Tartan, The', 1979, '');
INSERT INTO 'tune' VALUES (4507, NULL, '2012-01-20 12:54:35.306279+00', 'Shetland Boston, The', 9999, '');
INSERT INTO 'tune' VALUES (1694, NULL, '2012-01-20 12:54:25.671107+00', 'Taste o'' Moray, The', 1586, '');
INSERT INTO 'tune' VALUES (1695, NULL, '2012-01-20 12:54:25.674001+00', 'Taymouth House', 9998, '');
INSERT INTO 'tune' VALUES (1696, NULL, '2012-01-20 12:54:25.677408+00', 'Teetotaller''s Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (4508, NULL, '2012-01-20 12:54:35.310259+00', 'Broken Riddle, The', 1593, '');
INSERT INTO 'tune' VALUES (1697, NULL, '2012-01-20 12:54:25.680327+00', 'Ten Minute Jig', 709, '');
INSERT INTO 'tune' VALUES (1698, NULL, '2012-01-20 12:54:25.683388+00', 'Ten Thousand Miles Away', 9998, '');
INSERT INTO 'tune' VALUES (1699, NULL, '2012-01-20 12:54:25.686314+00', 'Teribus', 9999, '');
INSERT INTO 'tune' VALUES (4509, NULL, '2012-01-20 12:54:35.314054+00', 'Kincorth Brig', 1614, '');
INSERT INTO 'tune' VALUES (4510, NULL, '2012-01-20 12:54:35.317882+00', 'Sandy Cowie', 467, '');
INSERT INTO 'tune' VALUES (4511, NULL, '2012-01-20 12:54:35.321911+00', 'Saskatchewan Tartan', 9998, '');
INSERT INTO 'tune' VALUES (4512, NULL, '2012-01-20 12:54:35.325757+00', 'Sally Woodward''s Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (4513, NULL, '2012-01-20 12:54:35.329716+00', 'Wilma''s Delight', 629, '');
INSERT INTO 'tune' VALUES (4514, NULL, '2012-01-20 12:54:35.333521+00', 'Scalloway Bay', 1558, '');
INSERT INTO 'tune' VALUES (4515, NULL, '2012-01-20 12:54:35.337315+00', 'Scheessel Reel, The', 1725, '');
INSERT INTO 'tune' VALUES (4516, NULL, '2012-01-20 12:54:35.342216+00', 'Schoolmaster, The', 9998, '');
INSERT INTO 'tune' VALUES (4517, NULL, '2012-01-20 12:54:35.346168+00', 'Scolty', 165, '');
INSERT INTO 'tune' VALUES (4518, NULL, '2012-01-20 12:54:35.349981+00', 'Sea-Horse Frolic', 1329, '');
INSERT INTO 'tune' VALUES (4519, NULL, '2012-01-20 12:54:35.35379+00', 'Miss Gillian Yellop''s Favourite', 1593, '');
INSERT INTO 'tune' VALUES (4520, NULL, '2012-01-20 12:54:35.357611+00', 'Scots Gate, The', 1502, '');
INSERT INTO 'tune' VALUES (4521, NULL, '2012-01-20 12:54:35.361426+00', 'Scraggly Dance, A', 1707, '');
INSERT INTO 'tune' VALUES (4522, NULL, '2012-01-20 12:54:35.365363+00', 'Saratoga Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (12275, '2012-12-28 15:34:28.698953+00', '2012-12-28 15:34:28.698964+00', 'County Longford', 10685, '');
INSERT INTO 'tune' VALUES (12317, '2013-01-02 16:06:49.559646+00', '2013-01-02 16:06:49.559658+00', 'Miss Ann Amelia Murray', 9999, '');
INSERT INTO 'tune' VALUES (12390, '2013-01-05 17:36:45.806877+00', '2013-01-05 17:36:45.806889+00', 'Wee Kirkcudbright Centipede, The', 10704, '');
INSERT INTO 'tune' VALUES (12504, '2013-02-27 12:50:25.577228+00', '2013-02-27 12:50:25.577239+00', 'Student Lancers Figure 3', 9999, '');
INSERT INTO 'tune' VALUES (1700, NULL, '2012-01-20 12:54:25.689206+00', 'Teviot Brig', 9999, '');
INSERT INTO 'tune' VALUES (1721, NULL, '2012-01-20 12:54:25.753615+00', 'Timour the Tartar', 1488, '');
INSERT INTO 'tune' VALUES (1701, NULL, '2012-01-20 12:54:25.692116+00', 'There was a Lad', 9999, '');
INSERT INTO 'tune' VALUES (4523, NULL, '2012-01-20 12:54:35.369163+00', 'Farewell Manchester', 9998, '');
INSERT INTO 'tune' VALUES (1722, NULL, '2012-01-20 12:54:25.75671+00', 'Miss Katrina Margaret Douglas', 1574, '');
INSERT INTO 'tune' VALUES (1703, NULL, '2012-01-20 12:54:25.698644+00', 'Thingummy Jig, The', 1830, '');
INSERT INTO 'tune' VALUES (4524, NULL, '2012-01-20 12:54:35.372979+00', 'Sara Marais', 9998, '');
INSERT INTO 'tune' VALUES (1704, NULL, '2012-01-20 12:54:25.701546+00', 'This is no'' my Ain Hoose', 9999, '');
INSERT INTO 'tune' VALUES (1705, NULL, '2012-01-20 12:54:25.704441+00', 'Thistle of Scotland, The', 9999, '');
INSERT INTO 'tune' VALUES (1723, NULL, '2014-02-25 14:19:43.672426+00', 'Tir nan Og', 9999, 'Exists both as a Reel and as a Strathspey');
INSERT INTO 'tune' VALUES (1646, NULL, '2014-03-19 15:49:24.420213+00', 'Saint Andrew''s Nicht', 9999, '');
INSERT INTO 'tune' VALUES (1673, NULL, '2014-08-24 10:15:54.494923+00', 'Stumpie', 9999, '');
INSERT INTO 'tune' VALUES (4525, NULL, '2012-01-20 12:54:35.376804+00', 'Set in the Sun', 279, '');
INSERT INTO 'tune' VALUES (1706, NULL, '2012-01-20 12:54:25.707333+00', 'Oyster Man, The', 1605, '');
INSERT INTO 'tune' VALUES (1724, NULL, '2012-01-20 12:54:25.762535+00', 'Tobermory Bay', 1454, '');
INSERT INTO 'tune' VALUES (1707, NULL, '2012-01-20 12:54:25.710234+00', 'Thistle, The', 9999, '');
INSERT INTO 'tune' VALUES (1708, NULL, '2012-01-20 12:54:25.713279+00', 'Heights of Dargai', 1529, '');
INSERT INTO 'tune' VALUES (1725, NULL, '2012-01-20 12:54:25.765425+00', 'Key of the Door, The', 1682, '');
INSERT INTO 'tune' VALUES (1709, NULL, '2012-01-20 12:54:25.716242+00', 'Thomas Mark', 1725, '');
INSERT INTO 'tune' VALUES (4527, NULL, '2012-01-20 12:54:35.384591+00', 'Shaggie Burn, The', 1527, '');
INSERT INTO 'tune' VALUES (1710, NULL, '2012-01-20 12:54:25.719851+00', 'Thomas and Sally', 9998, '');
INSERT INTO 'tune' VALUES (1726, NULL, '2012-01-20 12:54:25.768311+00', 'Tocher Band, The', 9998, '');
INSERT INTO 'tune' VALUES (1711, NULL, '2012-01-20 12:54:25.722968+00', 'Thorn Bush', 2154, '');
INSERT INTO 'tune' VALUES (4528, NULL, '2012-01-20 12:54:35.388414+00', 'Shakkin Brig', 1976, '');
INSERT INTO 'tune' VALUES (1712, NULL, '2012-01-20 12:54:25.725893+00', 'Thorngrove Anniversary Strathspey, The', 1607, '');
INSERT INTO 'tune' VALUES (1727, NULL, '2012-01-20 12:54:25.771729+00', 'Todlen Hame', 1458, '');
INSERT INTO 'tune' VALUES (1713, NULL, '2012-01-20 12:54:25.728799+00', 'Thou Bonnie Wood o'' Craigielea', 9999, '');
INSERT INTO 'tune' VALUES (4529, NULL, '2012-01-20 12:54:35.392217+00', 'Mackworth', 1512, '');
INSERT INTO 'tune' VALUES (1714, NULL, '2012-01-20 12:54:25.732528+00', 'Three Times Three', 9999, '');
INSERT INTO 'tune' VALUES (1728, NULL, '2012-01-20 12:54:25.774702+00', 'Tom Elliot''s Reel', 1558, '');
INSERT INTO 'tune' VALUES (1715, NULL, '2012-01-20 12:54:25.735504+00', 'Thrums Cairn, The', 1512, '');
INSERT INTO 'tune' VALUES (4530, NULL, '2012-01-20 12:54:35.39602+00', 'Shepherd''s Fancy', 1668, '');
INSERT INTO 'tune' VALUES (1716, NULL, '2012-01-20 12:54:25.738404+00', 'Thurso Wedding', 1523, '');
INSERT INTO 'tune' VALUES (1729, NULL, '2012-01-20 12:54:25.777608+00', 'Tom Elliot''s Strathspey', 1558, '');
INSERT INTO 'tune' VALUES (4531, NULL, '2012-01-20 12:54:35.399821+00', 'Shepherd''s Reel, The', 1722, '');
INSERT INTO 'tune' VALUES (1730, NULL, '2012-01-20 12:54:25.780505+00', 'Tom Howard''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (1719, NULL, '2012-01-20 12:54:25.74782+00', 'Tiddlediwinks Polka', 9999, '');
INSERT INTO 'tune' VALUES (4532, NULL, '2012-01-20 12:54:35.403742+00', 'Garderhouse Voe', 1710, '');
INSERT INTO 'tune' VALUES (1720, NULL, '2012-01-20 12:54:25.750719+00', 'Tim''s Trout', 1884, '');
INSERT INTO 'tune' VALUES (1731, NULL, '2012-01-20 12:54:25.783403+00', 'Tom''s Highland Fling', 9999, '');
INSERT INTO 'tune' VALUES (4533, NULL, '2012-01-20 12:54:35.407554+00', 'Shrewsbury Lasses, The', 9998, '');
INSERT INTO 'tune' VALUES (1733, NULL, '2012-01-20 12:54:25.789192+00', 'Top o'' the Grampians, The', 1459, '');
INSERT INTO 'tune' VALUES (1734, NULL, '2012-01-20 12:54:25.792825+00', 'Torryburn Lassies', 1518, '');
INSERT INTO 'tune' VALUES (1735, NULL, '2012-01-20 12:54:25.795762+00', 'Tracy''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (4534, NULL, '2012-01-20 12:54:35.411361+00', 'Silver Cross, The', 1547, '');
INSERT INTO 'tune' VALUES (1736, NULL, '2012-01-20 12:54:25.798658+00', 'Tribute to Chris Blair, A', 1709, '');
INSERT INTO 'tune' VALUES (1737, NULL, '2012-01-20 12:54:25.801553+00', 'Trinity Hall', 1607, '');
INSERT INTO 'tune' VALUES (1738, NULL, '2012-01-20 12:54:25.804459+00', 'Trip to Goathland, A', 1576, '');
INSERT INTO 'tune' VALUES (4535, NULL, '2012-01-20 12:54:35.415176+00', 'Silverhaired Dancer, The', 2392, '');
INSERT INTO 'tune' VALUES (4536, NULL, '2012-01-20 12:54:35.418979+00', 'Sion House', 9998, '');
INSERT INTO 'tune' VALUES (1739, NULL, '2012-01-20 12:54:25.80735+00', 'Trip to Saint Andrews, A', 1517, '');
INSERT INTO 'tune' VALUES (1740, NULL, '2012-01-20 12:54:25.810244+00', 'Trip to Strathbogie, A', 9999, '');
INSERT INTO 'tune' VALUES (1741, NULL, '2012-01-20 12:54:25.813211+00', 'Triumph', 9999, '');
INSERT INTO 'tune' VALUES (4537, NULL, '2012-01-20 12:54:35.422878+00', 'Sir Archibald Dunbar', 9998, '');
INSERT INTO 'tune' VALUES (1742, NULL, '2012-01-20 12:54:25.816809+00', 'Troy''s Wedding', 1524, '');
INSERT INTO 'tune' VALUES (1743, NULL, '2012-01-20 12:54:25.819758+00', 'Dancers of Don', 1409, '');
INSERT INTO 'tune' VALUES (1744, NULL, '2012-01-20 12:54:25.822655+00', 'Trumpet Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (4538, NULL, '2012-01-20 12:54:35.426734+00', 'Sir Charles Napier', 9998, '');
INSERT INTO 'tune' VALUES (1745, NULL, '2012-01-20 12:54:25.825552+00', 'Tulchan Lodge', 1512, '');
INSERT INTO 'tune' VALUES (1680, NULL, '2017-07-07 12:55:59.275686+00', 'Sweet Bells of Glasgow, The', 9999, '');
INSERT INTO 'tune' VALUES (1746, NULL, '2012-01-20 12:54:25.828444+00', 'Diamond Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (1747, NULL, '2012-01-20 12:54:25.831342+00', 'Turkish Quick-Step', 1888, '');
INSERT INTO 'tune' VALUES (4539, NULL, '2012-01-20 12:54:35.430541+00', 'Sir Robert Peel', 1516, '');
INSERT INTO 'tune' VALUES (1748, NULL, '2012-01-20 12:54:25.834402+00', 'Tushker, Da', 1623, '');
INSERT INTO 'tune' VALUES (1749, NULL, '2012-01-20 12:54:25.837328+00', 'Mr Ian Russell', 1582, '');
INSERT INTO 'tune' VALUES (1750, NULL, '2012-01-20 12:54:25.841056+00', 'Twa Roguish Een', 9998, '');
INSERT INTO 'tune' VALUES (4540, NULL, '2012-01-20 12:54:35.434351+00', 'Sir Watkin''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (1751, NULL, '2012-01-20 12:54:25.843989+00', 'Tweedside', 9999, '');
INSERT INTO 'tune' VALUES (1752, NULL, '2012-01-20 12:54:25.846884+00', 'Twentyfourth of October', 9998, '');
INSERT INTO 'tune' VALUES (4541, NULL, '2012-01-20 12:54:35.43816+00', 'Sister Jean', 9999, '');
INSERT INTO 'tune' VALUES (4542, NULL, '2012-01-20 12:54:35.442303+00', 'Six and Sevens', 9998, '');
INSERT INTO 'tune' VALUES (4543, NULL, '2012-01-20 12:54:35.446274+00', 'Haste to the Wedding', 9999, '');
INSERT INTO 'tune' VALUES (4544, NULL, '2012-01-20 12:54:35.450086+00', 'Alex Heard', 1797, '');
INSERT INTO 'tune' VALUES (4545, NULL, '2012-01-20 12:54:35.453894+00', 'Diamond, The', 9998, '');
INSERT INTO 'tune' VALUES (4546, NULL, '2012-01-20 12:54:35.458022+00', 'Sly Old Fox, The', 1719, '');
INSERT INTO 'tune' VALUES (4548, NULL, '2012-01-20 12:54:35.465796+00', 'Piper Hamilton', 1558, '');
INSERT INTO 'tune' VALUES (4549, NULL, '2012-01-20 12:54:35.469601+00', 'Willy Mann of Paddy', 1935, '');
INSERT INTO 'tune' VALUES (12076, '2012-05-04 19:14:50.737958+00', '2012-05-04 19:14:50.737969+00', 'Back to your Roots', 1502, '');
INSERT INTO 'tune' VALUES (12318, '2013-01-02 16:11:44.921272+00', '2013-01-02 16:11:44.921283+00', 'Major McBean', 9999, '');
INSERT INTO 'tune' VALUES (12391, '2013-01-05 17:42:39.41727+00', '2013-01-05 17:42:39.417283+00', 'Farewell Ta Yell', 10705, '');
INSERT INTO 'tune' VALUES (12505, '2013-02-27 12:50:44.242519+00', '2013-02-27 12:50:44.24253+00', 'Student Lancers Figure 4', 9999, '');
INSERT INTO 'tune' VALUES (1753, NULL, '2012-01-20 12:54:25.849778+00', 'Twixt Don and Dee', 1533, '');
INSERT INTO 'tune' VALUES (1774, NULL, '2012-01-20 12:54:25.918351+00', 'Waltzing Matilda', 1405, '');
INSERT INTO 'tune' VALUES (1754, NULL, '2012-01-20 12:54:25.852672+00', 'Tynemouth Castle', 1725, '');
INSERT INTO 'tune' VALUES (4550, NULL, '2012-01-20 12:54:35.473422+00', 'Pends, The', 1595, '');
INSERT INTO 'tune' VALUES (1755, NULL, '2012-01-20 12:54:25.855623+00', 'Tyrolean Reel', 1815, '');
INSERT INTO 'tune' VALUES (13833, '2018-02-24 09:27:30.713743+00', '2018-02-24 09:27:30.713743+00', 'John Mackechnie', 9998, '');
INSERT INTO 'tune' VALUES (1756, NULL, '2012-01-20 12:54:25.858533+00', 'Uist Waulking Song, The', 9999, '');
INSERT INTO 'tune' VALUES (1757, NULL, '2012-01-20 12:54:25.86209+00', 'Up in the Morning Early', 1518, '');
INSERT INTO 'tune' VALUES (1758, NULL, '2012-01-20 12:54:25.865056+00', 'Uppies and Doonies', 810, '');
INSERT INTO 'tune' VALUES (4552, NULL, '2012-01-20 12:54:35.481386+00', 'Snow Goose, The', 1607, '');
INSERT INTO 'tune' VALUES (1777, NULL, '2012-01-20 12:54:25.927104+00', 'Tony Reid of Balnakilly', 1646, '');
INSERT INTO 'tune' VALUES (1760, NULL, '2012-01-20 12:54:25.871035+00', 'Val''s Fancy', 1607, '');
INSERT INTO 'tune' VALUES (4553, NULL, '2012-01-20 12:54:35.485194+00', 'Snow in March', 1279, '');
INSERT INTO 'tune' VALUES (1761, NULL, '2012-01-20 12:54:25.873993+00', 'Vale of Leven', 9999, '');
INSERT INTO 'tune' VALUES (1778, NULL, '2012-01-20 12:54:25.929989+00', 'Waves of Tory', 9999, '');
INSERT INTO 'tune' VALUES (1762, NULL, '2012-01-20 12:54:25.876895+00', 'Valerie Farr''s Reel', 1557, '');
INSERT INTO 'tune' VALUES (4554, NULL, '2012-01-20 12:54:35.489119+00', 'Solway Firth', 1454, '');
INSERT INTO 'tune' VALUES (1763, NULL, '2012-01-20 12:54:25.884155+00', 'Vermont Highlander''s Jig, The', 1773, '');
INSERT INTO 'tune' VALUES (1779, NULL, '2012-01-20 12:54:25.933591+00', 'We Parted on the Shore', 1663, '');
INSERT INTO 'tune' VALUES (1764, NULL, '2012-01-20 12:54:25.888209+00', 'Vic''s Fancy', 810, '');
INSERT INTO 'tune' VALUES (4555, NULL, '2012-01-20 12:54:35.49292+00', 'North of the Grampians', 2142, '');
INSERT INTO 'tune' VALUES (1765, NULL, '2012-01-20 12:54:25.891901+00', 'Victoria Reel', 9999, '');
INSERT INTO 'tune' VALUES (1780, NULL, '2012-01-20 12:54:25.936525+00', 'We''re a'' Noddin''', 9999, '');
INSERT INTO 'tune' VALUES (1766, NULL, '2012-01-20 12:54:25.894866+00', 'Village Bells, The', 1453, '');
INSERT INTO 'tune' VALUES (4556, NULL, '2012-01-20 12:54:35.496727+00', 'Something Old - Something New', 1409, '');
INSERT INTO 'tune' VALUES (1767, NULL, '2012-01-20 12:54:25.897771+00', 'Virginia Reel', 1502, '');
INSERT INTO 'tune' VALUES (1781, NULL, '2012-01-20 12:54:25.939421+00', 'Weaver and His Wife, The', 1533, '');
INSERT INTO 'tune' VALUES (1768, NULL, '2012-01-20 12:54:25.900669+00', 'Viscount Reidhaven', 1516, '');
INSERT INTO 'tune' VALUES (4557, NULL, '2012-01-20 12:54:35.500549+00', 'Sorcerer''s Apprentice, The', 1607, '');
INSERT INTO 'tune' VALUES (1769, NULL, '2012-01-20 12:54:25.903804+00', 'Visit to Ireland, A', 9999, '');
INSERT INTO 'tune' VALUES (1782, NULL, '2012-01-20 12:54:25.942304+00', 'Anne Harper of Kaimhill', 1575, '');
INSERT INTO 'tune' VALUES (1770, NULL, '2012-01-20 12:54:25.906714+00', 'Visit, The', 9999, '');
INSERT INTO 'tune' VALUES (4558, NULL, '2012-01-20 12:54:35.504383+00', 'Border City', 1815, '');
INSERT INTO 'tune' VALUES (1717, NULL, '2014-11-01 02:53:30.386673+00', 'Tibby Fowler o'' the Glen', 1451, '');
INSERT INTO 'tune' VALUES (1771, NULL, '2012-01-20 12:54:25.909611+00', 'Wae''s me for Prince Charlie', 9999, '');
INSERT INTO 'tune' VALUES (1783, NULL, '2012-01-20 12:54:25.945207+00', 'Wedding-Dress Lane', 1718, '');
INSERT INTO 'tune' VALUES (1772, NULL, '2012-01-20 12:54:25.912506+00', 'Waggle o'' the Kilt, The', 1663, '');
INSERT INTO 'tune' VALUES (4559, NULL, '2012-01-20 12:54:35.508356+00', 'Lassies of Prague', 1463, '');
INSERT INTO 'tune' VALUES (1773, NULL, '2012-01-20 12:54:25.915415+00', 'Walkers o'' Banchory, The', 1319, '');
INSERT INTO 'tune' VALUES (1784, NULL, '2012-01-20 12:54:25.94821+00', 'Wee Bird cam tae oor ha'' Door, A', 9998, '');
INSERT INTO 'tune' VALUES (1785, NULL, '2012-01-20 12:54:25.951174+00', 'Wee Cooper o'' Fife, The', 9999, '');
INSERT INTO 'tune' VALUES (4560, NULL, '2012-01-20 12:54:35.512169+00', 'Jasan and Jitca', 1463, '');
INSERT INTO 'tune' VALUES (1786, NULL, '2012-01-20 12:54:25.954065+00', 'Wee Corrie', 1551, '');
INSERT INTO 'tune' VALUES (1787, NULL, '2012-01-20 12:54:25.956952+00', 'Wee Hughie', 9999, '');
INSERT INTO 'tune' VALUES (1788, NULL, '2012-01-20 12:54:25.959866+00', 'Wee Sammy', 9999, '');
INSERT INTO 'tune' VALUES (4561, NULL, '2012-01-20 12:54:35.516023+00', 'Mrs Menzies of Culdare''s Strathspey', 1518, '');
INSERT INTO 'tune' VALUES (1789, NULL, '2012-01-20 12:54:25.962769+00', 'Wee Tot', 2877, '');
INSERT INTO 'tune' VALUES (1790, NULL, '2012-01-20 12:54:25.96571+00', 'Welcome Back, Liz', 1679, '');
INSERT INTO 'tune' VALUES (1791, NULL, '2012-01-20 12:54:25.968612+00', 'Welcome Whisky Back Again', 1518, '');
INSERT INTO 'tune' VALUES (4562, NULL, '2012-01-20 12:54:35.51985+00', 'Spae Wife, The', 1725, '');
INSERT INTO 'tune' VALUES (1792, NULL, '2012-01-20 12:54:25.971603+00', 'Welcome to Dunblane', 1652, '');
INSERT INTO 'tune' VALUES (1794, NULL, '2012-01-20 12:54:25.977389+00', 'Welcome to Witney', 9998, '');
INSERT INTO 'tune' VALUES (1795, NULL, '2012-01-20 12:54:25.980281+00', 'Well Tuned Piano, The', 709, '');
INSERT INTO 'tune' VALUES (4563, NULL, '2012-01-20 12:54:35.523657+00', 'Spanish Lady, The', 9998, '');
INSERT INTO 'tune' VALUES (1796, NULL, '2012-01-20 12:54:25.98318+00', 'Largo Bay', 9999, '');
INSERT INTO 'tune' VALUES (1797, NULL, '2012-01-20 12:54:25.986065+00', 'West Kilbride', 1441, '');
INSERT INTO 'tune' VALUES (1798, NULL, '2012-01-20 12:54:25.988957+00', 'West Park', 1582, '');
INSERT INTO 'tune' VALUES (4564, NULL, '2012-01-20 12:54:35.527587+00', 'Spencer Noble''s Strathspey', 1661, '');
INSERT INTO 'tune' VALUES (1799, NULL, '2012-01-20 12:54:25.991959+00', 'Westering Home', 1927, '');
INSERT INTO 'tune' VALUES (1800, NULL, '2012-01-20 12:54:25.994892+00', 'Westwood Reel', 1714, '');
INSERT INTO 'tune' VALUES (1801, NULL, '2012-01-20 12:54:25.997793+00', 'Wha Can Help It', 1518, '');
INSERT INTO 'tune' VALUES (4565, NULL, '2012-01-20 12:54:35.531413+00', 'Brodick Castle', 2521, '');
INSERT INTO 'tune' VALUES (1802, NULL, '2012-01-20 12:54:26.000686+00', 'Wha''ll be King but Charlie?', 9999, '');
INSERT INTO 'tune' VALUES (1803, NULL, '2012-01-20 12:54:26.003592+00', 'What Muckle Sorrow Ails You ?', 9998, '');
INSERT INTO 'tune' VALUES (1804, NULL, '2012-01-20 12:54:26.006487+00', 'What a Beau my Granny was', 9999, '');
INSERT INTO 'tune' VALUES (4566, NULL, '2012-01-20 12:54:35.535231+00', 'Spirits of Old Pulteney', 9998, '');
INSERT INTO 'tune' VALUES (4567, NULL, '2012-01-20 12:54:35.539054+00', 'Sportsman''s Charity Ball, The', 1585, '');
INSERT INTO 'tune' VALUES (4568, NULL, '2012-01-20 12:54:35.542865+00', 'Spriggs of Laurel', 9999, '');
INSERT INTO 'tune' VALUES (4569, NULL, '2012-01-20 12:54:35.546681+00', 'Frank Coutt''s Reel', 1404, '');
INSERT INTO 'tune' VALUES (4570, NULL, '2012-01-20 12:54:35.550687+00', 'Square Tower, The', 1595, '');
INSERT INTO 'tune' VALUES (4571, NULL, '2012-01-20 12:54:35.554897+00', 'Stack of Wheat, The', 9999, '');
INSERT INTO 'tune' VALUES (4572, NULL, '2012-01-20 12:54:35.558137+00', 'Star of the County Down, The', 9998, '');
INSERT INTO 'tune' VALUES (4573, NULL, '2012-01-20 12:54:35.561056+00', 'Stars and Moons', 10, '');
INSERT INTO 'tune' VALUES (4574, NULL, '2012-01-20 12:54:35.563959+00', 'Sterling of Caulder', 2392, '');
INSERT INTO 'tune' VALUES (4575, NULL, '2012-01-20 12:54:35.566867+00', 'Stirling Bridge', 1290, '');
INSERT INTO 'tune' VALUES (12077, '2012-05-04 19:15:32.423527+00', '2012-05-04 19:15:32.423538+00', 'David''s Delight', 1502, '');
INSERT INTO 'tune' VALUES (12131, '2012-06-12 15:11:13.795228+00', '2012-06-12 15:11:13.795238+00', 'Diamond Reflections', 2197, '');
INSERT INTO 'tune' VALUES (12319, '2013-01-02 16:23:03.858245+00', '2013-01-02 16:23:03.858257+00', 'Ian Thow', 1593, '');
INSERT INTO 'tune' VALUES (12392, '2013-01-05 17:43:43.325027+00', '2013-01-05 17:43:43.325039+00', 'Jean, Jean', 9999, '');
INSERT INTO 'tune' VALUES (12506, '2013-02-27 12:51:12.41956+00', '2013-02-27 12:51:12.419571+00', 'Student Lancers Figure 5', 9999, '');
INSERT INTO 'tune' VALUES (1805, NULL, '2012-01-20 12:54:26.00938+00', 'What''s A'' the Steer, Kimmer', 9999, '');
INSERT INTO 'tune' VALUES (1776, NULL, '2017-07-07 13:57:40.991976+00', 'Was There E''er Such a Lassie as I?', 9998, '');
INSERT INTO 'tune' VALUES (1826, NULL, '2012-01-20 12:54:26.07401+00', 'Willie Wilson of Beith', 1585, '');
INSERT INTO 'tune' VALUES (1806, NULL, '2012-01-20 12:54:26.01229+00', 'Miss Doris Kinghorn', 1607, '');
INSERT INTO 'tune' VALUES (4576, NULL, '2012-01-20 12:54:35.569788+00', 'Stirling Tensome, A', 1520, '');
INSERT INTO 'tune' VALUES (1807, NULL, '2012-01-20 12:54:26.015203+00', 'Wheatly Hills', 274, '');
INSERT INTO 'tune' VALUES (1827, NULL, '2012-01-20 12:54:26.076914+00', 'Lowe''s Hornpipe', 1516, '');
INSERT INTO 'tune' VALUES (1808, NULL, '2012-01-20 12:54:26.018095+00', 'Whitby Regatta', 1772, '');
INSERT INTO 'tune' VALUES (4577, NULL, '2012-01-20 12:54:35.572681+00', 'Jig in a Hurry', 1593, '');
INSERT INTO 'tune' VALUES (1809, NULL, '2012-01-20 12:54:26.021041+00', 'White Cockade, The', 9999, '');
INSERT INTO 'tune' VALUES (1828, NULL, '2012-01-20 12:54:26.079855+00', 'Willie was a Wanton Wag', 9999, '');
INSERT INTO 'tune' VALUES (1810, NULL, '2012-01-20 12:54:26.024163+00', 'White Settlers, The', 1815, '');
INSERT INTO 'tune' VALUES (1811, NULL, '2012-01-20 12:54:26.028415+00', 'Whiteley Rant, The', 1701, '');
INSERT INTO 'tune' VALUES (1829, NULL, '2012-01-20 12:54:26.08276+00', 'Willie with his Tartan Trews', 453, '');
INSERT INTO 'tune' VALUES (1812, NULL, '2012-01-20 12:54:26.031442+00', 'Whitesands Jig, The', 9998, '');
INSERT INTO 'tune' VALUES (4579, NULL, '2012-01-20 12:54:35.578454+00', 'Dennis B Murphy', 9998, '');
INSERT INTO 'tune' VALUES (1813, NULL, '2012-01-20 12:54:26.034587+00', 'Wicked Willy', 1533, '');
INSERT INTO 'tune' VALUES (1830, NULL, '2012-01-20 12:54:26.085654+00', 'Willie''s Ga''en A-coortin''', 444, '');
INSERT INTO 'tune' VALUES (4580, NULL, '2012-01-20 12:54:35.581336+00', 'Strathclyde Jig', 1484, '');
INSERT INTO 'tune' VALUES (1815, NULL, '2012-01-20 12:54:26.041819+00', 'John Beedie''s Reel', 1409, '');
INSERT INTO 'tune' VALUES (1831, NULL, '2012-01-20 12:54:26.088547+00', 'Willie''s awa''', 1518, '');
INSERT INTO 'tune' VALUES (1816, NULL, '2012-01-20 12:54:26.044804+00', 'Lament for Lockerbie', 1554, '');
INSERT INTO 'tune' VALUES (4581, NULL, '2012-01-20 12:54:35.584229+00', 'Oakville', 1836, '');
INSERT INTO 'tune' VALUES (1817, NULL, '2012-01-20 12:54:26.04771+00', 'Wilf Milner', 1502, '');
INSERT INTO 'tune' VALUES (1818, NULL, '2012-01-20 12:54:26.050617+00', 'Will Ye No'' Come Back Again?', 2704, '');
INSERT INTO 'tune' VALUES (4582, NULL, '2012-01-20 12:54:35.587155+00', 'Miss I M Banks', 1797, '');
INSERT INTO 'tune' VALUES (1819, NULL, '2012-01-20 12:54:26.053573+00', 'Piper Jock Kerr', 1531, '');
INSERT INTO 'tune' VALUES (1833, NULL, '2012-01-20 12:54:26.094345+00', 'Wilmette Jig, The', 814, '');
INSERT INTO 'tune' VALUES (1820, NULL, '2012-01-20 12:54:26.056501+00', 'Will ye go and marry Ketty?', 9998, '');
INSERT INTO 'tune' VALUES (4583, NULL, '2012-01-20 12:54:35.59005+00', 'John''s Folly', 1657, '');
INSERT INTO 'tune' VALUES (1834, NULL, '2012-01-20 12:54:26.09742+00', 'Wind that Shakes the Barley, The', 9999, '');
INSERT INTO 'tune' VALUES (1822, NULL, '2012-01-20 12:54:26.06233+00', 'William Gibson Craig, M.P.', 1516, '');
INSERT INTO 'tune' VALUES (4584, NULL, '2012-01-20 12:54:35.592947+00', 'Mrs Margaret Livingston''s Reel', 948, '');
INSERT INTO 'tune' VALUES (1823, NULL, '2012-01-20 12:54:26.065317+00', 'William McDonald Black', 1554, '');
INSERT INTO 'tune' VALUES (1835, NULL, '2012-01-20 12:54:26.100309+00', 'Windmill, The', 9999, '');
INSERT INTO 'tune' VALUES (1824, NULL, '2012-01-20 12:54:26.068215+00', 'Willie Gray', 9998, '');
INSERT INTO 'tune' VALUES (4585, NULL, '2012-01-20 12:54:35.595833+00', 'Sun Assembly', 9998, '');
INSERT INTO 'tune' VALUES (1825, NULL, '2012-01-20 12:54:26.07112+00', 'Willie Shaw', 9999, '');
INSERT INTO 'tune' VALUES (1836, NULL, '2012-01-20 12:54:26.103224+00', 'Windmills of Majorca, The', 9998, '');
INSERT INTO 'tune' VALUES (1837, NULL, '2012-01-20 12:54:26.106147+00', 'Windsor', 1502, '');
INSERT INTO 'tune' VALUES (4586, NULL, '2012-01-20 12:54:35.598716+00', 'Susan Jane''s Jig', 1831, '');
INSERT INTO 'tune' VALUES (1839, NULL, '2012-01-20 12:54:26.111941+00', 'Woo''d and Married and A''', 9999, '');
INSERT INTO 'tune' VALUES (1840, NULL, '2012-01-20 12:54:26.114937+00', 'Through the Wood of Fyvie', 1518, '');
INSERT INTO 'tune' VALUES (4587, NULL, '2012-01-20 12:54:35.601599+00', 'Susie''s Delight', 709, '');
INSERT INTO 'tune' VALUES (1867, NULL, '2019-10-28 23:43:24.31996+00', 'Farquhar Mathieson', 1525, 'The name "Farquhar" seems to be frequently misspelled.');
INSERT INTO 'tune' VALUES (1842, NULL, '2012-01-20 12:54:26.122304+00', 'Ye''re Welcome, Charly Stuart', 453, '');
INSERT INTO 'tune' VALUES (1843, NULL, '2012-01-20 12:54:26.125243+00', 'Yellow-Haired Laddie, The', 9999, '');
INSERT INTO 'tune' VALUES (4588, NULL, '2012-01-20 12:54:35.604482+00', 'Margaret & Ted''s Reel', 1582, '');
INSERT INTO 'tune' VALUES (4589, NULL, '2012-01-20 12:54:35.607386+00', 'Swan, The', 317, '');
INSERT INTO 'tune' VALUES (1844, NULL, '2012-01-20 12:54:26.128194+00', 'Young Sandy Tulloch', 1558, '');
INSERT INTO 'tune' VALUES (1846, NULL, '2012-01-20 12:54:26.134452+00', 'Conversazione, The', 1532, '');
INSERT INTO 'tune' VALUES (1847, NULL, '2012-01-20 12:54:26.137371+00', '501st Tactical Missile Wing, The', 1590, '');
INSERT INTO 'tune' VALUES (4590, NULL, '2012-01-20 12:54:35.610279+00', 'Sow''s Tail to Geordie, The', 9998, '');
INSERT INTO 'tune' VALUES (1848, NULL, '2012-01-20 12:54:26.140279+00', '71st Highlanders', 1304, '');
INSERT INTO 'tune' VALUES (1849, NULL, '2012-01-20 12:54:26.143184+00', '72nd Highlanders Farewell to Aberdeen', 1549, '');
INSERT INTO 'tune' VALUES (1838, NULL, '2014-08-19 07:38:46.774797+00', 'Within a Mile of Edinburgh Toon', 2642, '');
INSERT INTO 'tune' VALUES (4578, NULL, '2014-11-01 02:49:09.245032+00', 'Storrers Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (1850, NULL, '2012-01-20 12:54:26.146078+00', 'Malley Lee', 9999, '');
INSERT INTO 'tune' VALUES (4591, NULL, '2012-01-20 12:54:35.613168+00', 'Stanley Nairne', 1978, '');
INSERT INTO 'tune' VALUES (1851, NULL, '2012-01-20 12:54:26.148974+00', 'Caroline''s Tune', 1534, '');
INSERT INTO 'tune' VALUES (1852, NULL, '2012-01-20 12:54:26.15191+00', 'Sands of Murness', 1535, '');
INSERT INTO 'tune' VALUES (1853, NULL, '2012-01-20 12:54:26.154832+00', 'Academy, The', 1397, '');
INSERT INTO 'tune' VALUES (4592, NULL, '2012-01-20 12:54:35.616052+00', 'Take Your Choice', 9998, '');
INSERT INTO 'tune' VALUES (1854, NULL, '2012-01-20 12:54:26.157789+00', 'Agnes Laing''s Fancy', 1521, '');
INSERT INTO 'tune' VALUES (1855, NULL, '2012-01-20 12:54:26.1607+00', 'Kate Farrell', 1536, '');
INSERT INTO 'tune' VALUES (4593, NULL, '2012-01-20 12:54:35.618937+00', 'Tamworth Chase', 1191, '');
INSERT INTO 'tune' VALUES (4594, NULL, '2012-01-20 12:54:35.621826+00', 'T.A. Norris', 1668, '');
INSERT INTO 'tune' VALUES (4595, NULL, '2012-01-20 12:54:35.624718+00', 'Tartan Hoppers, The', 2392, '');
INSERT INTO 'tune' VALUES (4596, NULL, '2012-01-20 12:54:35.6276+00', 'Tartan Track Jig', 1701, '');
INSERT INTO 'tune' VALUES (4597, NULL, '2012-01-20 12:54:35.630498+00', 'Tartan Track Reel', 1701, '');
INSERT INTO 'tune' VALUES (4598, NULL, '2012-01-20 12:54:35.633384+00', 'Tartan Track Strathspey', 1701, '');
INSERT INTO 'tune' VALUES (4599, NULL, '2012-01-20 12:54:35.636266+00', 'T.B. Laing, Esq', 1555, '');
INSERT INTO 'tune' VALUES (4600, NULL, '2012-01-20 12:54:35.639148+00', 'Temple Bar', 9998, '');
INSERT INTO 'tune' VALUES (4601, NULL, '2012-01-20 12:54:35.642033+00', 'Teuchan', 279, '');
INSERT INTO 'tune' VALUES (12078, '2012-05-04 19:15:59.634029+00', '2012-05-04 19:15:59.634043+00', 'Latitude 50', 1502, '');
INSERT INTO 'tune' VALUES (12132, '2012-06-12 15:11:41.147713+00', '2012-06-12 15:11:41.147724+00', 'Diamonds Forever', 2197, '');
INSERT INTO 'tune' VALUES (12320, '2013-01-02 16:24:18.827995+00', '2013-01-02 16:24:18.828006+00', 'Slipping on Ice', 3798, '');
INSERT INTO 'tune' VALUES (12393, '2013-01-05 17:44:30.640437+00', '2013-01-05 17:44:30.640449+00', 'I Come Fae Yell', 9999, '');
INSERT INTO 'tune' VALUES (12507, '2013-02-27 12:55:24.542618+00', '2013-02-27 12:55:24.54263+00', 'Turfman from Ardee, The', 9999, '');
INSERT INTO 'tune' VALUES (1856, NULL, '2012-01-20 12:54:26.163603+00', 'Arran View', 1537, '');
INSERT INTO 'tune' VALUES (1878, NULL, '2012-01-20 12:54:26.232477+00', 'Highland Cathedral', 1545, '');
INSERT INTO 'tune' VALUES (4603, NULL, '2012-01-20 12:54:35.647794+00', 'Lochrynach', 1516, '');
INSERT INTO 'tune' VALUES (1857, NULL, '2012-01-20 12:54:26.166525+00', 'Alasdair of the Dun', 9999, '');
INSERT INTO 'tune' VALUES (1858, NULL, '2012-01-20 12:54:26.169422+00', 'Albert''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (1879, NULL, '2012-01-20 12:54:26.235446+00', 'Layabout, The', 1546, '');
INSERT INTO 'tune' VALUES (4604, NULL, '2012-01-20 12:54:35.650692+00', 'Ron Wallace''s Fancy - The Hard Farewell', 2392, '');
INSERT INTO 'tune' VALUES (1859, NULL, '2012-01-20 12:54:26.172322+00', 'Miss Dorothy Davidson', 1538, '');
INSERT INTO 'tune' VALUES (1860, NULL, '2012-01-20 12:54:26.175247+00', 'Drummossie Muir', 1539, '');
INSERT INTO 'tune' VALUES (4605, NULL, '2012-01-20 12:54:35.653575+00', 'Carse of Stirling', 9998, '');
INSERT INTO 'tune' VALUES (1881, NULL, '2012-01-20 12:54:26.241568+00', 'Cambridge Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (4606, NULL, '2012-01-20 12:54:35.657406+00', 'Three Feathers', 1830, '');
INSERT INTO 'tune' VALUES (1863, NULL, '2012-01-20 12:54:26.18398+00', 'All the rage', 1765, '');
INSERT INTO 'tune' VALUES (1864, NULL, '2012-01-20 12:54:26.186888+00', 'Allan Currie of Monifieth', 1576, '');
INSERT INTO 'tune' VALUES (4607, NULL, '2012-01-20 12:54:35.660839+00', 'Lucy Thompson''s Rant', 1558, '');
INSERT INTO 'tune' VALUES (1865, NULL, '2012-01-20 12:54:26.189795+00', 'Allan Peter Nixon', 1576, '');
INSERT INTO 'tune' VALUES (1866, NULL, '2012-01-20 12:54:26.192691+00', 'Allangrange', 9999, '');
INSERT INTO 'tune' VALUES (1883, NULL, '2012-01-20 12:54:26.248935+00', 'Miss Susan Weddell', 2991, '');
INSERT INTO 'tune' VALUES (4608, NULL, '2012-01-20 12:54:35.663784+00', 'Mrs Florence Lesslie', 9998, '');
INSERT INTO 'tune' VALUES (1884, NULL, '2012-01-20 12:54:26.252222+00', 'Auld Hoose, The', 9999, '');
INSERT INTO 'tune' VALUES (4609, NULL, '2012-01-20 12:54:35.66668+00', 'Turn Ye to Me', 9999, '');
INSERT INTO 'tune' VALUES (1869, NULL, '2012-01-20 12:54:26.201447+00', 'Anda Campbell''s Favourite', 1608, '');
INSERT INTO 'tune' VALUES (1870, NULL, '2012-01-20 12:54:26.204349+00', 'Anderson''s Strathspey', 1558, '');
INSERT INTO 'tune' VALUES (4610, NULL, '2012-01-20 12:54:35.669566+00', 'Glasgow Flourish', 9998, '');
INSERT INTO 'tune' VALUES (1871, NULL, '2012-01-20 12:54:26.207256+00', 'Angie''s 21st', 1622, '');
INSERT INTO 'tune' VALUES (1886, NULL, '2012-01-20 12:54:26.258044+00', 'Effie Glasgow of Longmorn', 1541, '');
INSERT INTO 'tune' VALUES (4611, NULL, '2012-01-20 12:54:35.67247+00', 'Tullamore Piper, The', 9999, '');
INSERT INTO 'tune' VALUES (1882, NULL, '2017-07-07 13:32:58.721557+00', 'Athole Highlanders, The', 9999, '');
INSERT INTO 'tune' VALUES (1873, NULL, '2012-01-20 12:54:26.213058+00', 'Kathleen''s Jig', 1543, '');
INSERT INTO 'tune' VALUES (1887, NULL, '2012-01-20 12:54:26.260954+00', 'Muineira Sul Sacrato Dello Chiesa', 9999, '');
INSERT INTO 'tune' VALUES (4612, NULL, '2012-01-20 12:54:35.675356+00', 'Curly Headed Ploughboy, The', 9999, '');
INSERT INTO 'tune' VALUES (1875, NULL, '2012-01-20 12:54:26.221818+00', 'Anne Fraser MacKenzie', 3058, '');
INSERT INTO 'tune' VALUES (1876, NULL, '2012-01-20 12:54:26.225472+00', 'Annie Laurie', 1703, '');
INSERT INTO 'tune' VALUES (1888, NULL, '2012-01-20 12:54:26.263859+00', 'Auld Rattray', 1492, '');
INSERT INTO 'tune' VALUES (4613, NULL, '2012-01-20 12:54:35.678238+00', 'Guid New Year to Ane an'' A''', 9998, '');
INSERT INTO 'tune' VALUES (1877, NULL, '2012-01-20 12:54:26.228902+00', 'Comlongon Castle', 1544, '');
INSERT INTO 'tune' VALUES (1889, NULL, '2012-01-20 12:54:26.266758+00', 'Aunice Gillie''s Farewell to Lochgilphead', 1558, '');
INSERT INTO 'tune' VALUES (4614, NULL, '2012-01-20 12:54:35.681128+00', 'Champagne Bubbles', 1502, '');
INSERT INTO 'tune' VALUES (1890, NULL, '2012-01-20 12:54:26.269662+00', 'Ayrshire Lasses', 9999, '');
INSERT INTO 'tune' VALUES (1891, NULL, '2012-01-20 12:54:26.2726+00', 'Dad''s Reel', 1534, '');
INSERT INTO 'tune' VALUES (1892, NULL, '2012-01-20 12:54:26.275496+00', 'Antigonish', 1549, '');
INSERT INTO 'tune' VALUES (4615, NULL, '2012-01-20 12:54:35.684019+00', 'To Dance To', 3058, '');
INSERT INTO 'tune' VALUES (1893, NULL, '2012-01-20 12:54:26.27839+00', 'Back to Bonnie Scotland', 2269, '');
INSERT INTO 'tune' VALUES (4616, NULL, '2012-01-20 12:54:35.686904+00', 'Tom Kettles', 1581, '');
INSERT INTO 'tune' VALUES (1894, NULL, '2012-01-20 12:54:26.281291+00', 'Baker''s Wood', 1525, '');
INSERT INTO 'tune' VALUES (4617, NULL, '2012-01-20 12:54:35.68979+00', 'Tom Stephen''s Jig', 1659, '');
INSERT INTO 'tune' VALUES (1896, NULL, '2012-01-20 12:54:26.287097+00', 'Ellenbrook', 1551, '');
INSERT INTO 'tune' VALUES (1897, NULL, '2012-01-20 12:54:26.29002+00', 'Teddy Bears'' Picnic', 1552, '');
INSERT INTO 'tune' VALUES (1898, NULL, '2012-01-20 12:54:26.292918+00', 'Ballochmyle Brig', 1496, '');
INSERT INTO 'tune' VALUES (4618, NULL, '2012-01-20 12:54:35.692691+00', 'Toorie in his Bonnet, A', 9998, '');
INSERT INTO 'tune' VALUES (1899, NULL, '2012-01-20 12:54:26.29586+00', 'Ballochmyle Rant, The', 1576, '');
INSERT INTO 'tune' VALUES (1900, NULL, '2012-01-20 12:54:26.298768+00', 'Isle of Arran', 2298, '');
INSERT INTO 'tune' VALUES (1901, NULL, '2012-01-20 12:54:26.301817+00', 'Banks O''Cart', 9999, '');
INSERT INTO 'tune' VALUES (4619, NULL, '2012-01-20 12:54:35.695576+00', 'Eddie Hutchings of Carswella', 131, '');
INSERT INTO 'tune' VALUES (1902, NULL, '2012-01-20 12:54:26.30476+00', 'Father John MacMillan of Barra', 1553, '');
INSERT INTO 'tune' VALUES (1903, NULL, '2012-01-20 12:54:26.307671+00', 'John Carmichael''s Farewell to Scotland', 1533, '');
INSERT INTO 'tune' VALUES (1904, NULL, '2012-01-20 12:54:26.310577+00', 'Barbara Saunders of Dollar', 1533, '');
INSERT INTO 'tune' VALUES (4620, NULL, '2012-01-20 12:54:35.698467+00', 'Touchstone, The', 9998, '');
INSERT INTO 'tune' VALUES (1905, NULL, '2012-01-20 12:54:26.313475+00', 'Barbara''s Jig', 1690, '');
INSERT INTO 'tune' VALUES (1906, NULL, '2012-01-20 12:54:26.316407+00', 'Bargenny''s Bowling Green', 1762, '');
INSERT INTO 'tune' VALUES (1907, NULL, '2012-01-20 12:54:26.319668+00', 'Tribute to Lindsay Ross, A', 1533, '');
INSERT INTO 'tune' VALUES (4621, NULL, '2012-01-20 12:54:35.701351+00', 'Toward Castle', 9998, '');
INSERT INTO 'tune' VALUES (4622, NULL, '2012-01-20 12:54:35.704234+00', 'Trudy', 3295, '');
INSERT INTO 'tune' VALUES (4623, NULL, '2012-01-20 12:54:35.707165+00', 'Trip to Aberfeldy, A', 1692, '');
INSERT INTO 'tune' VALUES (4624, NULL, '2012-01-20 12:54:35.710064+00', 'Mrs Lily Davison', 1805, '');
INSERT INTO 'tune' VALUES (4625, NULL, '2012-01-20 12:54:35.713007+00', 'Mallorca', 9999, '');
INSERT INTO 'tune' VALUES (4626, NULL, '2012-01-20 12:54:35.715909+00', 'Fred Drew''s Reel', 1714, '');
INSERT INTO 'tune' VALUES (4627, NULL, '2012-01-20 12:54:35.718806+00', 'Moulin Burn', 1692, '');
INSERT INTO 'tune' VALUES (4628, NULL, '2012-01-20 12:54:35.721696+00', 'Trip to Orlando', 1319, '');
INSERT INTO 'tune' VALUES (12321, '2013-01-02 16:32:12.865265+00', '2013-01-02 16:32:12.865276+00', 'Neville''s Point', 3798, '');
INSERT INTO 'tune' VALUES (12394, '2013-01-05 17:49:42.054931+00', '2013-01-05 17:49:42.054943+00', 'To Be or Not to Be', 2253, '');
INSERT INTO 'tune' VALUES (12508, '2013-02-27 12:58:52.080147+00', '2013-02-27 12:58:52.080159+00', 'Brodgar Bjorkis''s Boys', 10675, '');
INSERT INTO 'tune' VALUES (1908, NULL, '2012-01-20 12:54:26.322786+00', 'Bay of Fundy Reel', 9999, '');
INSERT INTO 'tune' VALUES (1929, NULL, '2012-01-20 12:54:26.38446+00', 'Billy Thom''s Reel', 1525, '');
INSERT INTO 'tune' VALUES (1885, NULL, '2013-08-05 11:16:10.917291+00', 'Rookery, The', 1700, '');
INSERT INTO 'tune' VALUES (12079, '2012-05-04 19:16:25.358948+00', '2013-08-19 12:00:20.060458+00', 'Dragon Racers, The', 1502, '');
INSERT INTO 'tune' VALUES (1862, NULL, '2014-08-11 22:05:57.717855+00', 'John Spence o'' Uyeasound', 9999, '');
INSERT INTO 'tune' VALUES (1872, NULL, '2014-08-29 17:09:09.907861+00', 'Rock Valley Jig', 3702, '');
INSERT INTO 'tune' VALUES (1895, NULL, '2014-09-16 08:57:54.431774+00', 'Catherine Margaret Hall', 1550, '');
INSERT INTO 'tune' VALUES (1880, NULL, '2014-09-16 09:12:06.118853+00', 'Aithernie Lodge', 2210, '');
INSERT INTO 'tune' VALUES (1861, NULL, '2014-10-04 01:58:44.631147+00', 'Alex Little MC', 1606, '');
INSERT INTO 'tune' VALUES (1909, NULL, '2012-01-20 12:54:26.325807+00', 'Gadie Rins, The', 9999, '');
INSERT INTO 'tune' VALUES (4630, NULL, '2012-01-20 12:54:35.727699+00', 'Sally''s Reel', 1590, '');
INSERT INTO 'tune' VALUES (1930, NULL, '2012-01-20 12:54:26.387374+00', 'Express, The', 9999, '');
INSERT INTO 'tune' VALUES (1911, NULL, '2012-01-20 12:54:26.331618+00', 'Belfast Ham', 1518, '');
INSERT INTO 'tune' VALUES (1912, NULL, '2012-01-20 12:54:26.334517+00', 'Belinda Clinkscale''s Quickstep', 1527, '');
INSERT INTO 'tune' VALUES (4631, NULL, '2012-01-20 12:54:35.730642+00', 'Duncan''s Fiddle', 1329, '');
INSERT INTO 'tune' VALUES (1931, NULL, '2012-01-20 12:54:26.390274+00', 'Joiner''s Jig, The', 1578, '');
INSERT INTO 'tune' VALUES (1913, NULL, '2012-01-20 12:54:26.337653+00', 'Merry Reapers, The', 9999, '');
INSERT INTO 'tune' VALUES (1914, NULL, '2012-01-20 12:54:26.340564+00', 'Benvie House', 1521, '');
INSERT INTO 'tune' VALUES (4632, NULL, '2012-01-20 12:54:35.733581+00', 'Steele of Dornoch', 1502, '');
INSERT INTO 'tune' VALUES (1932, NULL, '2012-01-20 12:54:26.393314+00', 'Castle Drummond', 9999, '');
INSERT INTO 'tune' VALUES (1915, NULL, '2012-01-20 12:54:26.343639+00', 'Berry Picking, The', 1696, '');
INSERT INTO 'tune' VALUES (1916, NULL, '2012-01-20 12:54:26.34667+00', 'Wattle O''t, The', 9999, '');
INSERT INTO 'tune' VALUES (4633, NULL, '2012-01-20 12:54:35.736482+00', 'Chairman''s Jig, The', 1582, '');
INSERT INTO 'tune' VALUES (1933, NULL, '2012-01-20 12:54:26.396219+00', 'Bitter Lemon Reel, The', 1592, '');
INSERT INTO 'tune' VALUES (1917, NULL, '2012-01-20 12:54:26.349628+00', 'Berwickshire Volunteers, The', 9999, '');
INSERT INTO 'tune' VALUES (1918, NULL, '2012-01-20 12:54:26.352535+00', 'Bessie & Lawrie Kemp', 1521, '');
INSERT INTO 'tune' VALUES (4634, NULL, '2012-01-20 12:54:35.739369+00', 'True North, The', 2392, '');
INSERT INTO 'tune' VALUES (1934, NULL, '2012-01-20 12:54:26.399124+00', 'Bob Duncan of Parkhill', 1579, '');
INSERT INTO 'tune' VALUES (1919, NULL, '2012-01-20 12:54:26.35544+00', 'Biddy the Bowlwife', 9999, '');
INSERT INTO 'tune' VALUES (1920, NULL, '2012-01-20 12:54:26.358335+00', 'Big Dougal', 1551, '');
INSERT INTO 'tune' VALUES (4635, NULL, '2012-01-20 12:54:35.742239+00', 'Tune your Fiddles', 1512, '');
INSERT INTO 'tune' VALUES (1935, NULL, '2012-01-20 12:54:26.402016+00', 'Wroxham Bridge', 1557, '');
INSERT INTO 'tune' VALUES (1921, NULL, '2012-01-20 12:54:26.361229+00', 'Bill Bryce', 1658, '');
INSERT INTO 'tune' VALUES (1922, NULL, '2012-01-20 12:54:26.364128+00', 'Bill Cormack of Blair', 1646, '');
INSERT INTO 'tune' VALUES (4636, NULL, '2012-01-20 12:54:35.745131+00', 'Black Cat Reel, The', 2392, '');
INSERT INTO 'tune' VALUES (1936, NULL, '2012-01-20 12:54:26.404917+00', 'Tom Beeton''s Jig', 1580, '');
INSERT INTO 'tune' VALUES (1923, NULL, '2012-01-20 12:54:26.367056+00', 'Bill Meikle''s Reel', 1640, '');
INSERT INTO 'tune' VALUES (1924, NULL, '2012-01-20 12:54:26.369966+00', 'Auld Stoer''s Back Agen, Da', 9999, '');
INSERT INTO 'tune' VALUES (4637, NULL, '2012-01-20 12:54:35.748117+00', 'Pulp in the Bottom', 1886, '');
INSERT INTO 'tune' VALUES (1937, NULL, '2012-01-20 12:54:26.407819+00', 'Black Mountain Reel, The', 1661, '');
INSERT INTO 'tune' VALUES (1925, NULL, '2012-01-20 12:54:26.372862+00', 'Bill Stroll''s Quadrille Two', 9999, '');
INSERT INTO 'tune' VALUES (1926, NULL, '2012-01-20 12:54:26.375759+00', 'Bill Sutherland', 1598, '');
INSERT INTO 'tune' VALUES (4638, NULL, '2012-01-20 12:54:35.751018+00', 'Irene Craig Morrison', 1550, '');
INSERT INTO 'tune' VALUES (1938, NULL, '2012-01-20 12:54:26.410758+00', 'Black Score, The', 2557, '');
INSERT INTO 'tune' VALUES (1927, NULL, '2012-01-20 12:54:26.37866+00', 'Billy Craib', 3058, '');
INSERT INTO 'tune' VALUES (1928, NULL, '2012-01-20 12:54:26.381557+00', 'Billy Johnstone''s Reel', 1531, '');
INSERT INTO 'tune' VALUES (4639, NULL, '2012-01-20 12:54:35.753911+00', 'Radnor Meeting', 210, '');
INSERT INTO 'tune' VALUES (1939, NULL, '2012-01-20 12:54:26.413709+00', 'Black Snuff Mill, The', 9999, '');
INSERT INTO 'tune' VALUES (1940, NULL, '2012-01-20 12:54:26.416932+00', 'Blackberry Bush, The', 9999, '');
INSERT INTO 'tune' VALUES (1941, NULL, '2012-01-20 12:54:26.419865+00', 'Blackbird, The', 1686, '');
INSERT INTO 'tune' VALUES (4640, NULL, '2012-01-20 12:54:35.756798+00', 'Twas O''er the Hills and Far Away', 9998, '');
INSERT INTO 'tune' VALUES (1942, NULL, '2012-01-20 12:54:26.422828+00', 'Blackthorn Stick, The', 9999, '');
INSERT INTO 'tune' VALUES (1943, NULL, '2012-01-20 12:54:26.42592+00', 'Blin'' Jamie', 1512, '');
INSERT INTO 'tune' VALUES (1944, NULL, '2012-01-20 12:54:26.428985+00', 'Wee Red Breeks', 1578, '');
INSERT INTO 'tune' VALUES (4641, NULL, '2012-01-20 12:54:35.759686+00', 'Twa Sparkling Een', 1607, '');
INSERT INTO 'tune' VALUES (1945, NULL, '2012-01-20 12:54:26.432039+00', 'Dunaskin Glen', 1575, '');
INSERT INTO 'tune' VALUES (1946, NULL, '2012-01-20 12:54:26.435822+00', 'Blow the Wind Southerly', 9999, '');
INSERT INTO 'tune' VALUES (4642, NULL, '2012-01-20 12:54:35.762581+00', 'Edith and Jim Ogilvie of MacDuff', 1520, '');
INSERT INTO 'tune' VALUES (4643, NULL, '2012-01-20 12:54:35.765469+00', 'Road to Leeds, The', 1593, '');
INSERT INTO 'tune' VALUES (1947, NULL, '2012-01-20 12:54:26.438931+00', 'Karen''s Reel', 1576, '');
INSERT INTO 'tune' VALUES (1948, NULL, '2012-01-20 12:54:26.441853+00', 'Bluebells of Scotland, The', 9999, '');
INSERT INTO 'tune' VALUES (1949, NULL, '2012-01-20 12:54:26.444759+00', 'Don Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (4644, NULL, '2012-01-20 12:54:35.768364+00', 'Two Black Cats', 1329, '');
INSERT INTO 'tune' VALUES (1950, NULL, '2012-01-20 12:54:26.447674+00', 'Boatman, The', 9999, '');
INSERT INTO 'tune' VALUES (4645, NULL, '2012-01-20 12:54:35.771258+00', 'Yankee Doodle Boy, The', 3366, '');
INSERT INTO 'tune' VALUES (1951, NULL, '2012-01-20 12:54:26.450585+00', 'Bobby Brown', 3058, '');
INSERT INTO 'tune' VALUES (4646, NULL, '2012-01-20 12:54:35.774149+00', 'Sound of Sleat, The', 1414, '');
INSERT INTO 'tune' VALUES (1952, NULL, '2012-01-20 12:54:26.453494+00', 'Boil Dem Cabbage Down', 9999, '');
INSERT INTO 'tune' VALUES (1953, NULL, '2012-01-20 12:54:26.456486+00', 'Uschi Henco''s Reel', 228, '');
INSERT INTO 'tune' VALUES (1954, NULL, '2012-01-20 12:54:26.459404+00', 'Bonnie Banks of the Cairn, The', 1668, '');
INSERT INTO 'tune' VALUES (4647, NULL, '2012-01-20 12:54:35.777035+00', 'Up and Doon the Gallowgate', 1764, '');
INSERT INTO 'tune' VALUES (1955, NULL, '2012-01-20 12:54:26.462309+00', 'Bonnie Bonnie Lass, The', 9999, '');
INSERT INTO 'tune' VALUES (4648, NULL, '2012-01-20 12:54:35.779926+00', 'Up with Aily', 9998, '');
INSERT INTO 'tune' VALUES (1956, NULL, '2012-01-20 12:54:26.465318+00', 'Waverley Steps', 1660, '');
INSERT INTO 'tune' VALUES (1957, NULL, '2012-01-20 12:54:26.468211+00', 'Bonnie Doon', 9999, '');
INSERT INTO 'tune' VALUES (4649, NULL, '2012-01-20 12:54:35.782821+00', 'Janet Leslie''s Jig', 1782, '');
INSERT INTO 'tune' VALUES (1958, NULL, '2012-01-20 12:54:26.471112+00', 'Jackson''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (1959, NULL, '2012-01-20 12:54:26.474007+00', 'Play the Light', 9999, '');
INSERT INTO 'tune' VALUES (1960, NULL, '2012-01-20 12:54:26.476906+00', 'Miss A Scott', 9999, '');
INSERT INTO 'tune' VALUES (4650, NULL, '2012-01-20 12:54:35.78573+00', 'Valerie Rixon''s Jig', 1653, '');
INSERT INTO 'tune' VALUES (4652, NULL, '2012-01-20 12:54:35.791507+00', 'Ciorsdan Mhor', 9998, '');
INSERT INTO 'tune' VALUES (4653, NULL, '2012-01-20 12:54:35.794396+00', 'Shaalds o'' Foula', 9999, '');
INSERT INTO 'tune' VALUES (4654, NULL, '2012-01-20 12:54:35.797279+00', 'Volpony', 1881, '');
INSERT INTO 'tune' VALUES (4655, NULL, '2012-01-20 12:54:35.800161+00', 'Wakefield Hunt', 9998, '');
INSERT INTO 'tune' VALUES (12080, '2012-05-04 19:17:21.664257+00', '2012-05-04 19:17:21.664268+00', 'Alastair Ross', 1502, '');
INSERT INTO 'tune' VALUES (12322, '2013-01-02 16:39:52.709919+00', '2013-01-02 16:39:52.709929+00', 'Model T, The', 9999, '');
INSERT INTO 'tune' VALUES (12395, '2013-01-05 17:50:38.796301+00', '2013-01-05 17:50:38.796313+00', 'Cheeky Pete', 10703, '');
INSERT INTO 'tune' VALUES (12509, '2013-02-27 13:11:47.353155+00', '2013-02-27 13:11:47.353167+00', 'Me and My Girl', 2492, '');
INSERT INTO 'tune' VALUES (1971, NULL, '2012-01-20 12:54:26.517384+00', 'Jim Anderson''s Delight', 1623, '');
INSERT INTO 'tune' VALUES (1962, NULL, '2012-01-20 12:54:26.48273+00', 'Bonnie Toon O'' Edinburgh, The', 9999, '');
INSERT INTO 'tune' VALUES (4656, NULL, '2012-01-20 12:54:35.803048+00', 'Scots Wha Hae', 9999, '');
INSERT INTO 'tune' VALUES (1963, NULL, '2012-01-20 12:54:26.485635+00', 'Inchmickery', 1501, '');
INSERT INTO 'tune' VALUES (1972, NULL, '2012-01-20 12:54:26.520348+00', 'Marg. McLachlin', 1575, '');
INSERT INTO 'tune' VALUES (2045, NULL, '2012-01-20 12:54:26.752186+00', 'Clan Munro', 9999, '');
INSERT INTO 'tune' VALUES (1964, NULL, '2012-01-20 12:54:26.488622+00', 'Bonniest Lass in a'' the World, The', 9999, '');
INSERT INTO 'tune' VALUES (4657, NULL, '2012-01-20 12:54:35.805947+00', 'Balmore', 975, '');
INSERT INTO 'tune' VALUES (1965, NULL, '2012-01-20 12:54:26.496376+00', 'Family Pride, The', 1522, '');
INSERT INTO 'tune' VALUES (1973, NULL, '2012-01-20 12:54:26.52326+00', 'Waltz for Jamie McKelvie', 1554, '');
INSERT INTO 'tune' VALUES (1966, NULL, '2012-01-20 12:54:26.499329+00', 'Polly Wolly Doodle', 9999, '');
INSERT INTO 'tune' VALUES (4658, NULL, '2012-01-20 12:54:35.808832+00', 'Hang Glider, The', 1456, '');
INSERT INTO 'tune' VALUES (1974, NULL, '2012-01-20 12:54:26.526191+00', 'Braidley''s House', 1558, '');
INSERT INTO 'tune' VALUES (1968, NULL, '2012-01-20 12:54:26.50513+00', 'Charlie Grant Two-step', 1621, '');
INSERT INTO 'tune' VALUES (4659, NULL, '2012-01-20 12:54:35.811718+00', 'Wateraid', 1576, '');
INSERT INTO 'tune' VALUES (1969, NULL, '2012-01-20 12:54:26.508021+00', 'Braemar Highlanders, The', 9999, '');
INSERT INTO 'tune' VALUES (1975, NULL, '2012-01-20 12:54:26.530023+00', 'Linhope Loop', 9999, '');
INSERT INTO 'tune' VALUES (1970, NULL, '2012-01-20 12:54:26.511468+00', 'Quaker, The', 9999, '');
INSERT INTO 'tune' VALUES (4660, NULL, '2012-01-20 12:54:35.814918+00', 'Rattray Man, The', 1439, '');
INSERT INTO 'tune' VALUES (1976, NULL, '2012-01-20 12:54:26.532966+00', 'Humberston Jig', 1626, '');
INSERT INTO 'tune' VALUES (1977, NULL, '2012-01-20 12:54:26.535896+00', 'Willie Tait', 1706, '');
INSERT INTO 'tune' VALUES (4661, NULL, '2012-01-20 12:54:35.817854+00', 'Waukrife Laddie', 165, '');
INSERT INTO 'tune' VALUES (1978, NULL, '2012-01-20 12:54:26.538801+00', 'Brenda Stubbert''s Reel', 1633, '');
INSERT INTO 'tune' VALUES (1979, NULL, '2012-01-20 12:54:26.541742+00', 'Fiddler''s Joy, The', 1700, '');
INSERT INTO 'tune' VALUES (1980, NULL, '2012-01-20 12:54:26.544696+00', 'Bridal, The', 9999, '');
INSERT INTO 'tune' VALUES (4662, NULL, '2012-01-20 12:54:35.820752+00', 'Apor-Crossan', 1473, '');
INSERT INTO 'tune' VALUES (1982, NULL, '2012-01-20 12:54:26.550756+00', 'Brig'' O''Bervie, The', 9999, '');
INSERT INTO 'tune' VALUES (1983, NULL, '2012-01-20 12:54:26.553719+00', 'Calton Hill', 9999, '');
INSERT INTO 'tune' VALUES (1984, NULL, '2012-01-20 12:54:26.556619+00', 'Brinkie Braes', 1558, '');
INSERT INTO 'tune' VALUES (1985, NULL, '2012-01-20 12:54:26.559688+00', 'Bristol Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (1986, NULL, '2012-01-20 12:54:26.562629+00', 'Fiona''s Reel', 1629, '');
INSERT INTO 'tune' VALUES (4664, NULL, '2012-01-20 12:54:35.826518+00', 'Mary Gray', 9998, '');
INSERT INTO 'tune' VALUES (1987, NULL, '2012-01-20 12:54:26.56553+00', 'Brocks Fourth Jig', 1608, '');
INSERT INTO 'tune' VALUES (1988, NULL, '2012-01-20 12:54:26.568463+00', 'Brothers Three', 2207, '');
INSERT INTO 'tune' VALUES (4665, NULL, '2012-01-20 12:54:35.829392+00', 'Sandy is my Darling', 9999, '');
INSERT INTO 'tune' VALUES (1990, NULL, '2012-01-20 12:54:26.574299+00', 'Calm Before The Storm, The', 1643, '');
INSERT INTO 'tune' VALUES (1991, NULL, '2012-01-20 12:54:26.577207+00', 'Skiver the Quilt', 1607, '');
INSERT INTO 'tune' VALUES (4666, NULL, '2012-01-20 12:54:35.832282+00', 'Wedding Knot, The', 1826, '');
INSERT INTO 'tune' VALUES (1992, NULL, '2012-01-20 12:54:26.580196+00', 'Burnieboozle', 316, '');
INSERT INTO 'tune' VALUES (4667, NULL, '2012-01-20 12:54:35.835176+00', 'Jumping the Broom', 1826, '');
INSERT INTO 'tune' VALUES (1993, NULL, '2012-01-20 12:54:26.583113+00', 'Major David MacQueen', 1704, '');
INSERT INTO 'tune' VALUES (1994, NULL, '2012-01-20 12:54:26.586001+00', 'Bush in the Garden', 9998, '');
INSERT INTO 'tune' VALUES (4668, NULL, '2012-01-20 12:54:35.838086+00', 'Tie the Knot', 158, '');
INSERT INTO 'tune' VALUES (1995, NULL, '2012-01-20 12:54:26.588907+00', 'Caberfeidh', 9999, '');
INSERT INTO 'tune' VALUES (4669, NULL, '2012-01-20 12:54:35.840976+00', 'Cathkin House', 158, '');
INSERT INTO 'tune' VALUES (1996, NULL, '2012-01-20 12:54:26.591815+00', 'Cabin in the Woods', 1763, '');
INSERT INTO 'tune' VALUES (1997, NULL, '2012-01-20 12:54:26.594897+00', 'Lad Wi'' the Plaidie, The', 9999, '');
INSERT INTO 'tune' VALUES (4670, NULL, '2012-01-20 12:54:35.843865+00', 'Gordon for Me, A', 2407, '');
INSERT INTO 'tune' VALUES (1998, NULL, '2012-01-20 12:54:26.597814+00', '''S trusaidh mi na Coilleagan', 9998, '');
INSERT INTO 'tune' VALUES (1999, NULL, '2012-01-20 12:54:26.600719+00', 'Canadian Four-Step', 2257, '');
INSERT INTO 'tune' VALUES (4671, NULL, '2012-01-20 12:54:35.846756+00', 'Kerry Jig', 9998, '');
INSERT INTO 'tune' VALUES (2000, NULL, '2012-01-20 12:54:26.603621+00', 'Murray River Jig, The', 1602, '');
INSERT INTO 'tune' VALUES (2002, NULL, '2012-01-20 12:54:26.620334+00', 'Captain Keiller', 9999, '');
INSERT INTO 'tune' VALUES (4672, NULL, '2012-01-20 12:54:35.849643+00', 'Isobel', 405, '');
INSERT INTO 'tune' VALUES (2003, NULL, '2012-01-20 12:54:26.62399+00', 'Bracken''s Reel', 1576, '');
INSERT INTO 'tune' VALUES (12081, '2012-05-04 19:18:01.060583+00', '2012-05-04 19:18:01.060596+00', 'David Cunningham''s Welcome to Canada', 1502, '');
INSERT INTO 'tune' VALUES (2004, NULL, '2012-01-20 12:54:26.626959+00', 'Caledonian Two Step', 1531, '');
INSERT INTO 'tune' VALUES (2005, NULL, '2012-01-20 12:54:26.629872+00', 'Mrs Leila Powrie', 1527, '');
INSERT INTO 'tune' VALUES (12323, '2013-01-02 16:40:53.952808+00', '2013-01-02 16:40:53.95282+00', 'McGurk''s', 9999, '');
INSERT INTO 'tune' VALUES (2007, NULL, '2012-01-20 12:54:26.635677+00', 'Chris Blair', 1533, '');
INSERT INTO 'tune' VALUES (2008, NULL, '2012-01-20 12:54:26.638597+00', 'Major Bobby', 9999, '');
INSERT INTO 'tune' VALUES (12396, '2013-01-05 17:54:13.607395+00', '2013-01-05 17:54:13.607407+00', 'Lintie Waltz, The', 130, '');
INSERT INTO 'tune' VALUES (2009, NULL, '2012-01-20 12:54:26.641547+00', 'Miss Jayne of Violet Bank', 1606, '');
INSERT INTO 'tune' VALUES (2010, NULL, '2012-01-20 12:54:26.644594+00', 'Canadian Jig', 9999, '');
INSERT INTO 'tune' VALUES (2011, NULL, '2012-01-20 12:54:26.647506+00', 'Canberra Reel', 1531, '');
INSERT INTO 'tune' VALUES (2012, NULL, '2012-01-20 12:54:26.651975+00', 'Roseacre', 1512, '');
INSERT INTO 'tune' VALUES (2013, NULL, '2012-01-20 12:54:26.654915+00', 'Cape Breton Welcomes the Auld Fiddler', 1507, '');
INSERT INTO 'tune' VALUES (2014, NULL, '2012-01-20 12:54:26.65782+00', 'Guisborough Reel, The', 1708, '');
INSERT INTO 'tune' VALUES (2015, NULL, '2012-01-20 12:54:26.660944+00', 'Everything Hot and Delicious?', 1576, '');
INSERT INTO 'tune' VALUES (2016, NULL, '2012-01-20 12:54:26.663864+00', 'Roll Her On The Hill', 9999, '');
INSERT INTO 'tune' VALUES (2017, NULL, '2012-01-20 12:54:26.666981+00', 'Captain Horne', 9999, '');
INSERT INTO 'tune' VALUES (2018, NULL, '2012-01-20 12:54:26.669896+00', 'Captain Keeler''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (2019, NULL, '2012-01-20 12:54:26.672796+00', 'Captain Mackintosh', 1518, '');
INSERT INTO 'tune' VALUES (2020, NULL, '2012-01-20 12:54:26.675698+00', 'Iain MacPhail''s Compliments to Mr and Mrs Ian Barbour', 1527, '');
INSERT INTO 'tune' VALUES (1989, NULL, '2017-11-26 13:58:07.999795+00', 'Brown Haired Maiden', 9999, '');
INSERT INTO 'tune' VALUES (2001, NULL, '2018-12-06 22:30:06.803772+00', 'Cailin mo ruin sa', 1871, '');
INSERT INTO 'tune' VALUES (13834, '2018-02-24 09:28:16.335175+00', '2019-06-23 09:16:51.571253+00', 'Kantara to El Arish', 1434, '');
INSERT INTO 'tune' VALUES (2021, NULL, '2012-01-20 12:54:26.678643+00', 'Captain William MacLeod''s Fancy', 1516, '');
INSERT INTO 'tune' VALUES (2022, NULL, '2012-01-20 12:54:26.681537+00', 'Carl Cam O''er the Croft, The', 9999, '');
INSERT INTO 'tune' VALUES (2023, NULL, '2012-01-20 12:54:26.684486+00', 'Carl Volti''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (2024, NULL, '2012-01-20 12:54:26.690452+00', 'Carnie''s Canter', 1512, '');
INSERT INTO 'tune' VALUES (2025, NULL, '2012-01-20 12:54:26.693622+00', 'Meg''s Jig', 1576, '');
INSERT INTO 'tune' VALUES (2026, NULL, '2012-01-20 12:54:26.696532+00', 'Carol''s Jig', 1527, '');
INSERT INTO 'tune' VALUES (2027, NULL, '2012-01-20 12:54:26.699444+00', 'Castle Lyons Jig', 9999, '');
INSERT INTO 'tune' VALUES (2028, NULL, '2012-01-20 12:54:26.702348+00', 'Maggie''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (2029, NULL, '2012-01-20 12:54:26.705243+00', 'Cathkin Braes', 9999, '');
INSERT INTO 'tune' VALUES (2030, NULL, '2012-01-20 12:54:26.708131+00', 'Magnie''s Matchless', 1711, '');
INSERT INTO 'tune' VALUES (2031, NULL, '2012-01-20 12:54:26.711036+00', 'Cavehill', 9999, '');
INSERT INTO 'tune' VALUES (2032, NULL, '2012-01-20 12:54:26.713929+00', 'Parnell House', 1502, '');
INSERT INTO 'tune' VALUES (2053, NULL, '2012-01-20 12:54:26.775443+00', 'Colin Bell', 1730, '');
INSERT INTO 'tune' VALUES (2033, NULL, '2012-01-20 12:54:26.716876+00', 'Jean Lamb Finnie McColm', 1502, '');
INSERT INTO 'tune' VALUES (4673, NULL, '2012-01-20 12:54:35.852529+00', 'Mr Gary Thomas', 2392, '');
INSERT INTO 'tune' VALUES (2034, NULL, '2012-01-20 12:54:26.719783+00', 'Jennie Slater', 1710, '');
INSERT INTO 'tune' VALUES (2054, NULL, '2012-01-20 12:54:26.778345+00', 'College Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (2035, NULL, '2012-01-20 12:54:26.722678+00', 'Challenger Lodge', 1600, '');
INSERT INTO 'tune' VALUES (4674, NULL, '2012-01-20 12:54:35.855572+00', 'Gentle Annie', 9998, '');
INSERT INTO 'tune' VALUES (2036, NULL, '2012-01-20 12:54:26.725578+00', 'Chapelmount House', 1606, '');
INSERT INTO 'tune' VALUES (2037, NULL, '2012-01-20 12:54:26.728548+00', 'Chester Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (4675, NULL, '2012-01-20 12:54:35.858461+00', 'Wee Willie Winkie', 9999, '');
INSERT INTO 'tune' VALUES (2038, NULL, '2012-01-20 12:54:26.731447+00', 'Chinese Breakdown', 9999, '');
INSERT INTO 'tune' VALUES (2039, NULL, '2012-01-20 12:54:26.734343+00', 'Chinese Dance', 9999, '');
INSERT INTO 'tune' VALUES (4676, NULL, '2012-01-20 12:54:35.861346+00', 'Welcome All', 1329, '');
INSERT INTO 'tune' VALUES (2040, NULL, '2012-01-20 12:54:26.737435+00', 'Christine Macaskill', 1680, '');
INSERT INTO 'tune' VALUES (2057, NULL, '2012-01-20 12:54:26.787065+00', 'Manderston House', 1401, '');
INSERT INTO 'tune' VALUES (2041, NULL, '2012-01-20 12:54:26.740564+00', 'Christine''s Jig', 1527, '');
INSERT INTO 'tune' VALUES (4677, NULL, '2012-01-20 12:54:35.864232+00', 'Dufftown Rally, The', 1898, '');
INSERT INTO 'tune' VALUES (2042, NULL, '2012-01-20 12:54:26.74346+00', 'Church of Dromore, The', 9999, '');
INSERT INTO 'tune' VALUES (13835, '2018-02-24 09:28:55.595685+00', '2018-02-24 09:28:55.595685+00', 'Leaving Glendale', 9998, '');
INSERT INTO 'tune' VALUES (2043, NULL, '2012-01-20 12:54:26.746357+00', 'Marquis of Lorne, The', 9999, '');
INSERT INTO 'tune' VALUES (4678, NULL, '2012-01-20 12:54:35.867115+00', 'Well-Hall', 9998, '');
INSERT INTO 'tune' VALUES (2044, NULL, '2012-01-20 12:54:26.749288+00', 'Miss Stewart''s Strathspey - Pittyvaich', 1516, '');
INSERT INTO 'tune' VALUES (2059, NULL, '2012-01-20 12:54:26.792877+00', 'Deer Park Cottage', 1596, '');
INSERT INTO 'tune' VALUES (1981, NULL, '2021-10-16 22:37:06.270418+00', 'Well Wynd, The', 1525, '');
INSERT INTO 'tune' VALUES (4679, NULL, '2012-01-20 12:54:35.869994+00', 'Violet Buchanan of Balfron', 1782, '');
INSERT INTO 'tune' VALUES (2046, NULL, '2012-01-20 12:54:26.755085+00', 'Clucking Hen, The', 1685, '');
INSERT INTO 'tune' VALUES (2060, NULL, '2012-01-20 12:54:26.795784+00', 'Kate''s Coming of Age', 1592, '');
INSERT INTO 'tune' VALUES (2047, NULL, '2012-01-20 12:54:26.757982+00', 'Clumsy Lover, The', 1688, '');
INSERT INTO 'tune' VALUES (4680, NULL, '2012-01-20 12:54:35.873383+00', 'Miss Helene Cleaves', 1582, '');
INSERT INTO 'tune' VALUES (2048, NULL, '2012-01-20 12:54:26.760876+00', 'Brig o'' Potarch, The', 1512, '');
INSERT INTO 'tune' VALUES (2061, NULL, '2012-01-20 12:54:26.798721+00', 'Cloudy Morning', 1608, '');
INSERT INTO 'tune' VALUES (2049, NULL, '2012-01-20 12:54:26.763823+00', 'Miss Leslie Cunningham', 1502, '');
INSERT INTO 'tune' VALUES (4681, NULL, '2012-01-20 12:54:35.876313+00', 'Miss Mary McManus', 9998, '');
INSERT INTO 'tune' VALUES (2050, NULL, '2012-01-20 12:54:26.766727+00', 'Cecil McCausland', 1607, '');
INSERT INTO 'tune' VALUES (2062, NULL, '2012-01-20 12:54:26.801695+00', 'Oliver Jack', 9999, '');
INSERT INTO 'tune' VALUES (2051, NULL, '2012-01-20 12:54:26.769647+00', 'Peerie Dunter, Da', 1710, '');
INSERT INTO 'tune' VALUES (4682, NULL, '2012-01-20 12:54:35.879261+00', 'Marjorie and Brian''s Wedding', 1981, '');
INSERT INTO 'tune' VALUES (2052, NULL, '2012-01-20 12:54:26.772542+00', 'Fuffin'' Low', 1502, '');
INSERT INTO 'tune' VALUES (2063, NULL, '2012-01-20 12:54:26.8046+00', 'Connaughtman''s Rambles, The', 9999, '');
INSERT INTO 'tune' VALUES (4683, NULL, '2012-01-20 12:54:35.88216+00', 'Westward to Washington', 1982, '');
INSERT INTO 'tune' VALUES (4663, NULL, '2014-11-01 02:26:49.035992+00', 'Calver Lodge', 1517, '');
INSERT INTO 'tune' VALUES (2065, NULL, '2012-01-20 12:54:26.810392+00', 'Scottish Snap, The', 1750, '');
INSERT INTO 'tune' VALUES (2066, NULL, '2012-01-20 12:54:26.813611+00', 'Thinking it Over', 1596, '');
INSERT INTO 'tune' VALUES (2067, NULL, '2012-01-20 12:54:26.816533+00', 'Robin Brock''s Farewell to his Gall Bladder', 1608, '');
INSERT INTO 'tune' VALUES (4684, NULL, '2012-01-20 12:54:35.885054+00', 'Mr & Mrs Keith Stacey', 1983, '');
INSERT INTO 'tune' VALUES (2068, NULL, '2012-01-20 12:54:26.819445+00', 'Miss Nellie Wemyss', 1518, '');
INSERT INTO 'tune' VALUES (2069, NULL, '2012-01-20 12:54:26.82234+00', 'Walking the Floor', 2232, '');
INSERT INTO 'tune' VALUES (2070, NULL, '2012-01-20 12:54:26.82524+00', 'Stolen Purse, The', 9999, '');
INSERT INTO 'tune' VALUES (4685, NULL, '2012-01-20 12:54:35.887933+00', 'Bill Smith''s Fancy', 1404, '');
INSERT INTO 'tune' VALUES (2071, NULL, '2012-01-20 12:54:26.828152+00', 'Hail to the Chief', 9999, '');
INSERT INTO 'tune' VALUES (2072, NULL, '2012-01-20 12:54:26.831245+00', 'Craws of Currie', 1501, '');
INSERT INTO 'tune' VALUES (2073, NULL, '2012-01-20 12:54:26.834277+00', 'Cullercoats Fish Lass, The', 9999, '');
INSERT INTO 'tune' VALUES (2074, NULL, '2012-01-20 12:54:26.838342+00', 'Lynsey Dewar''s Strathspey', 1591, '');
INSERT INTO 'tune' VALUES (4686, NULL, '2012-01-20 12:54:35.890826+00', 'Where Did You Get that Hat?', 1984, '');
INSERT INTO 'tune' VALUES (2075, NULL, '2012-01-20 12:54:26.841383+00', 'Cushie Butterfield', 9999, '');
INSERT INTO 'tune' VALUES (2076, NULL, '2012-01-20 12:54:26.844283+00', 'Miss Grace Hay''s Delight', 1518, '');
INSERT INTO 'tune' VALUES (2077, NULL, '2012-01-20 12:54:26.847185+00', 'Daft Willie Dawson', 9999, '');
INSERT INTO 'tune' VALUES (4687, NULL, '2012-01-20 12:54:35.893712+00', 'Where East Meets West', 1745, '');
INSERT INTO 'tune' VALUES (2078, NULL, '2012-01-20 12:54:26.850072+00', 'Smith''s Delight', 9998, '');
INSERT INTO 'tune' VALUES (2079, NULL, '2012-01-20 12:54:26.852999+00', 'Dancie Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (2080, NULL, '2012-01-20 12:54:26.855899+00', 'Danderave', 9998, '');
INSERT INTO 'tune' VALUES (2081, NULL, '2012-01-20 12:54:26.85886+00', 'Dandy Dancer, The', 1525, '');
INSERT INTO 'tune' VALUES (2082, NULL, '2012-01-20 12:54:26.86177+00', 'Dandy Ninth, The', 1607, '');
INSERT INTO 'tune' VALUES (2083, NULL, '2012-01-20 12:54:26.864668+00', 'Danse de Chez Nous', 9999, '');
INSERT INTO 'tune' VALUES (4689, NULL, '2012-01-20 12:54:35.899528+00', 'Glasgow Smiles', 1456, '');
INSERT INTO 'tune' VALUES (4691, NULL, '2012-01-20 12:54:35.905336+00', 'Whitehall Minuet', 9998, '');
INSERT INTO 'tune' VALUES (4692, NULL, '2012-01-20 12:54:35.908228+00', 'Whiteinch', 1659, '');
INSERT INTO 'tune' VALUES (4693, NULL, '2012-01-20 12:54:35.911125+00', 'White Rabbit, The', 1607, '');
INSERT INTO 'tune' VALUES (4694, NULL, '2012-01-20 12:54:35.914002+00', 'Miss Yvonne Mortier', 1582, '');
INSERT INTO 'tune' VALUES (4695, NULL, '2012-01-20 12:54:35.916899+00', 'Glen Chalmadale', 1475, '');
INSERT INTO 'tune' VALUES (4696, NULL, '2012-01-20 12:54:35.919792+00', 'Lochranza Castle', 1475, '');
INSERT INTO 'tune' VALUES (4697, NULL, '2012-01-20 12:54:35.922695+00', 'Whitterick, The', 210, '');
INSERT INTO 'tune' VALUES (4698, NULL, '2012-01-20 12:54:35.925574+00', 'Jack''s Prize Winner', 629, '');
INSERT INTO 'tune' VALUES (12324, '2013-01-02 16:46:00.382955+00', '2013-01-02 16:46:00.382966+00', 'Ralph & Jean''s Reel', 3798, '');
INSERT INTO 'tune' VALUES (4690, NULL, '2013-01-04 09:38:44.574991+00', 'Sporty Boys', 1567, '');
INSERT INTO 'tune' VALUES (12397, '2013-01-05 17:55:31.70454+00', '2013-01-05 17:55:31.704551+00', 'Edwin and Marina''s Silver Wedding', 130, '');
INSERT INTO 'tune' VALUES (12511, '2013-02-27 13:21:09.497277+00', '2013-02-27 13:21:09.497288+00', 'Fraser Neil Sneden', 1621, '');
INSERT INTO 'tune' VALUES (2104, NULL, '2012-01-20 12:54:26.932392+00', 'Lord Blantyre', 9999, '');
INSERT INTO 'tune' VALUES (2084, NULL, '2012-01-20 12:54:26.867575+00', 'More Power to your Elbow O''Reilly', 9999, '');
INSERT INTO 'tune' VALUES (4699, NULL, '2012-01-20 12:54:35.928663+00', 'Miss Jean Budge', 1986, '');
INSERT INTO 'tune' VALUES (2105, NULL, '2012-01-20 12:54:26.935602+00', 'Devil''s Delight', 1766, '');
INSERT INTO 'tune' VALUES (4700, NULL, '2012-01-20 12:54:35.931606+00', 'Wm Birse Esq', 1729, '');
INSERT INTO 'tune' VALUES (2087, NULL, '2012-01-20 12:54:26.876756+00', 'David Findlay''s Hornpipe', 1607, '');
INSERT INTO 'tune' VALUES (2106, NULL, '2012-01-20 12:54:26.9386+00', 'Devil''s in the Kitchen, The', 1635, '');
INSERT INTO 'tune' VALUES (2088, NULL, '2012-01-20 12:54:26.87968+00', 'Davina''s Reel', 1576, '');
INSERT INTO 'tune' VALUES (4701, NULL, '2012-01-20 12:54:35.934496+00', 'Willie-Waught', 609, '');
INSERT INTO 'tune' VALUES (2089, NULL, '2012-01-20 12:54:26.882587+00', 'Weaver, The', 1910, '');
INSERT INTO 'tune' VALUES (2107, NULL, '2012-01-20 12:54:26.941598+00', 'Disappointment, The', 1502, '');
INSERT INTO 'tune' VALUES (2090, NULL, '2012-01-20 12:54:26.885506+00', 'Lambeth Walk', 2492, '');
INSERT INTO 'tune' VALUES (2091, NULL, '2012-01-20 12:54:26.888408+00', 'Dawn Express', 9999, '');
INSERT INTO 'tune' VALUES (2108, NULL, '2012-01-20 12:54:26.944512+00', 'Dodger, The', 1538, '');
INSERT INTO 'tune' VALUES (2092, NULL, '2012-01-20 12:54:26.891307+00', 'Faithful Shepherd, The', 9998, '');
INSERT INTO 'tune' VALUES (4703, NULL, '2012-01-20 12:54:35.940268+00', 'Will Ye Run Awa Wi'' Me?', 9998, '');
INSERT INTO 'tune' VALUES (4769, NULL, '2012-01-20 12:54:36.134163+00', 'American, The', 9998, '');
INSERT INTO 'tune' VALUES (2093, NULL, '2012-01-20 12:54:26.894196+00', 'O''er Bogie tae my Love', 9999, '');
INSERT INTO 'tune' VALUES (2109, NULL, '2012-01-20 12:54:26.948642+00', 'Dolina Mackay', 1684, '');
INSERT INTO 'tune' VALUES (2094, NULL, '2012-01-20 12:54:26.897091+00', 'O She''s Comical', 9999, '');
INSERT INTO 'tune' VALUES (4704, NULL, '2012-01-20 12:54:35.943154+00', 'Winding Deveron, The', 1446, '');
INSERT INTO 'tune' VALUES (2095, NULL, '2012-01-20 12:54:26.900002+00', 'Thack Cottage, The', 9999, '');
INSERT INTO 'tune' VALUES (2110, NULL, '2012-01-20 12:54:26.952381+00', 'Donaghadee', 9999, '');
INSERT INTO 'tune' VALUES (2096, NULL, '2012-01-20 12:54:26.90304+00', 'Dear Old Donegal', 1636, '');
INSERT INTO 'tune' VALUES (4705, NULL, '2012-01-20 12:54:35.946032+00', 'Turriff Square', 1446, '');
INSERT INTO 'tune' VALUES (2097, NULL, '2012-01-20 12:54:26.905939+00', 'Deil Amang the Mealmen, The', 9999, '');
INSERT INTO 'tune' VALUES (2111, NULL, '2012-01-20 12:54:26.955328+00', 'Buck o'' the Cabrach, The', 9999, '');
INSERT INTO 'tune' VALUES (2098, NULL, '2012-01-20 12:54:26.908843+00', 'Poor Little Angeline', 2544, '');
INSERT INTO 'tune' VALUES (4706, NULL, '2012-01-20 12:54:35.948914+00', 'Wind in the Willows, The', 1607, '');
INSERT INTO 'tune' VALUES (2099, NULL, '2012-01-20 12:54:26.913459+00', 'Albany Strathspey, The', 3362, '');
INSERT INTO 'tune' VALUES (2112, NULL, '2012-01-20 12:54:26.958226+00', 'Miss Chalmers', 9999, '');
INSERT INTO 'tune' VALUES (2100, NULL, '2012-01-20 12:54:26.91822+00', 'Derek Lawrence''s Farewell to Scotland', 1603, '');
INSERT INTO 'tune' VALUES (4707, NULL, '2012-01-20 12:54:35.951804+00', 'Wooden Legged Whistler, The', 9998, '');
INSERT INTO 'tune' VALUES (2101, NULL, '2012-01-20 12:54:26.921374+00', 'Deserts of Tulloch', 1470, '');
INSERT INTO 'tune' VALUES (2113, NULL, '2012-01-20 12:54:26.961124+00', 'Donald Ridley''s Compliments to Oliver Waugh', 1593, '');
INSERT INTO 'tune' VALUES (2102, NULL, '2012-01-20 12:54:26.924415+00', 'Jacobite, The', 9999, '');
INSERT INTO 'tune' VALUES (4708, NULL, '2012-01-20 12:54:35.954692+00', 'Betty Keir''s Strathspey', 1520, '');
INSERT INTO 'tune' VALUES (2103, NULL, '2012-01-20 12:54:26.928172+00', 'Munlochy Bridge', 9999, '');
INSERT INTO 'tune' VALUES (2114, NULL, '2012-01-20 12:54:26.964022+00', 'Bonnie Broom, The', 9999, '');
INSERT INTO 'tune' VALUES (2115, NULL, '2012-01-20 12:54:26.966955+00', 'Red Plaid', 9999, '');
INSERT INTO 'tune' VALUES (4709, NULL, '2012-01-20 12:54:35.957589+00', 'Wrekin Havoc', 1590, '');
INSERT INTO 'tune' VALUES (2116, NULL, '2012-01-20 12:54:26.969874+00', 'Dornoch Laddie', 1502, '');
INSERT INTO 'tune' VALUES (2117, NULL, '2012-01-20 12:54:26.972768+00', 'Gareloch, The', 9999, '');
INSERT INTO 'tune' VALUES (2118, NULL, '2012-01-20 12:54:26.975665+00', 'Dorrator Bridge', 1568, '');
INSERT INTO 'tune' VALUES (4710, NULL, '2012-01-20 12:54:35.960475+00', 'Ye Social Powers', 9998, '');
INSERT INTO 'tune' VALUES (2119, NULL, '2012-01-20 12:54:26.978559+00', 'Dougal Craiter, The', 9999, '');
INSERT INTO 'tune' VALUES (2120, NULL, '2012-01-20 12:54:26.98174+00', 'Back of the Change House, The', 2882, '');
INSERT INTO 'tune' VALUES (2121, NULL, '2012-01-20 12:54:26.985037+00', 'Wee Bit Cogie', 9999, '');
INSERT INTO 'tune' VALUES (4711, NULL, '2012-01-20 12:54:35.963362+00', 'Mrs Ida Austin', 1987, '');
INSERT INTO 'tune' VALUES (2122, NULL, '2012-01-20 12:54:26.987985+00', 'Mr Eagers', 9999, '');
INSERT INTO 'tune' VALUES (4712, NULL, '2012-01-20 12:54:35.96624+00', 'Zephyrs and Flora', 9998, '');
INSERT INTO 'tune' VALUES (2123, NULL, '2012-01-20 12:54:26.99101+00', 'Castle Spynie', 1512, '');
INSERT INTO 'tune' VALUES (2124, NULL, '2012-01-20 12:54:26.993927+00', 'Old Traditional Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (2125, NULL, '2012-01-20 12:54:26.996828+00', 'Lady Louisa Cornwallis'' Strathspey', 1516, '');
INSERT INTO 'tune' VALUES (4713, NULL, '2012-01-20 12:54:35.969121+00', 'Janie Duncan''s 92nd Birthday', 1615, '');
INSERT INTO 'tune' VALUES (2126, '2005-02-01 23:00:00+00', '2012-01-20 12:54:26.999765+00', 'Alan and Christine Mair of Cupar', 1507, '');
INSERT INTO 'tune' VALUES (2127, NULL, '2012-01-20 12:54:27.002698+00', 'Dr Keith', 1512, '');
INSERT INTO 'tune' VALUES (2128, NULL, '2012-01-20 12:54:27.005729+00', 'Dr McHardy', 1512, '');
INSERT INTO 'tune' VALUES (4714, NULL, '2012-01-20 12:54:35.972014+00', 'Murphy''s Measure', 1815, '');
INSERT INTO 'tune' VALUES (2130, NULL, '2012-01-20 12:54:27.011528+00', 'Miss Wemyss of Dundee', 1939, '');
INSERT INTO 'tune' VALUES (2131, NULL, '2012-01-20 12:54:27.014422+00', 'Drewie''s Jamboree', 1634, '');
INSERT INTO 'tune' VALUES (4715, NULL, '2012-01-20 12:54:35.974919+00', 'Taghairm', 1502, '');
INSERT INTO 'tune' VALUES (2132, NULL, '2012-01-20 12:54:27.017478+00', 'Peter Gray', 9999, '');
INSERT INTO 'tune' VALUES (2133, NULL, '2012-01-20 12:54:27.020599+00', 'Drum House', 9998, '');
INSERT INTO 'tune' VALUES (4716, NULL, '2012-01-20 12:54:35.977802+00', 'Marchmont House', 9999, '');
INSERT INTO 'tune' VALUES (2129, NULL, '2013-10-31 14:48:52.196889+00', 'Dr Ross''s 50th Welcome to the Argyllshire Gathering', 1910, '');
INSERT INTO 'tune' VALUES (4688, NULL, '2014-08-24 17:34:23.377183+00', 'Whistler and His Dog, The', 10989, '');
INSERT INTO 'tune' VALUES (4717, NULL, '2012-01-20 12:54:35.980709+00', 'Flowers o'' the Forest, The', 9999, '');
INSERT INTO 'tune' VALUES (4718, NULL, '2012-01-20 12:54:35.983622+00', 'Road to Berwick, The', 1516, '');
INSERT INTO 'tune' VALUES (4719, NULL, '2012-01-20 12:54:35.986501+00', 'Both Sides of the Tweed', 9999, '');
INSERT INTO 'tune' VALUES (4720, NULL, '2012-01-20 12:54:35.989386+00', 'Hawick Lasses', 9999, '');
INSERT INTO 'tune' VALUES (4721, NULL, '2012-01-20 12:54:35.992273+00', 'Black Shepherdess, The', 9999, '');
INSERT INTO 'tune' VALUES (4722, NULL, '2012-01-20 12:54:35.995161+00', 'Go to Berwick, Johnny', 9999, '');
INSERT INTO 'tune' VALUES (4723, NULL, '2012-01-20 12:54:35.998035+00', 'Sir John Fenwick''s the Flower of Them All', 9999, '');
INSERT INTO 'tune' VALUES (4724, NULL, '2012-01-20 12:54:36.000919+00', 'Open the Door to Three', 9999, '');
INSERT INTO 'tune' VALUES (12325, '2013-01-02 16:46:51.988578+00', '2013-01-02 16:46:51.988588+00', 'Moose Hunter''s Reel', 3798, '');
INSERT INTO 'tune' VALUES (12398, '2013-01-05 17:58:23.972451+00', '2013-01-05 17:58:23.972463+00', 'Jarl Ingunar Freyr', 130, '');
INSERT INTO 'tune' VALUES (12512, '2013-02-27 13:24:03.440521+00', '2013-02-27 13:24:03.440533+00', 'P/M William MacLean', 1597, '');
INSERT INTO 'tune' VALUES (2135, NULL, '2012-01-20 12:54:27.026484+00', 'John Bain''s Sister''s Wedding', 9999, '');
INSERT INTO 'tune' VALUES (2156, NULL, '2012-01-20 12:54:27.088784+00', 'East Dene', 1508, '');
INSERT INTO 'tune' VALUES (2136, NULL, '2012-01-20 12:54:27.029397+00', 'Miss Laura Andrew', 1512, '');
INSERT INTO 'tune' VALUES (4725, NULL, '2012-01-20 12:54:36.00382+00', 'Ladykirk House', 9998, '');
INSERT INTO 'tune' VALUES (2137, NULL, '2012-01-20 12:54:27.032293+00', 'Rob''s Jig', 1717, '');
INSERT INTO 'tune' VALUES (2157, NULL, '2012-01-20 12:54:27.0917+00', 'Iz and Nick''s Wedding Day', 1534, '');
INSERT INTO 'tune' VALUES (2138, NULL, '2012-01-20 12:54:27.035201+00', 'Christie MacLeod', 1525, '');
INSERT INTO 'tune' VALUES (4726, NULL, '2012-01-20 12:54:36.006715+00', 'Earl of Home, The', 1517, '');
INSERT INTO 'tune' VALUES (2139, NULL, '2012-01-20 12:54:27.038094+00', 'KOSB''s March to the Somme', 2323, '');
INSERT INTO 'tune' VALUES (2158, NULL, '2012-01-20 12:54:27.094594+00', 'Eddie Harding''s Hornpipe', 1668, '');
INSERT INTO 'tune' VALUES (2140, NULL, '2012-01-20 12:54:27.04105+00', 'Manchester Caledonians', 1558, '');
INSERT INTO 'tune' VALUES (4727, NULL, '2012-01-20 12:54:36.009587+00', 'Ca'' the Ewes', 9999, '');
INSERT INTO 'tune' VALUES (2141, NULL, '2012-01-20 12:54:27.043962+00', 'Lullaby for Thomas', 1534, '');
INSERT INTO 'tune' VALUES (2159, NULL, '2012-01-20 12:54:27.097594+00', 'Edmund Mackenzie of Plockton', 1533, '');
INSERT INTO 'tune' VALUES (2142, NULL, '2012-01-20 12:54:27.046906+00', 'Dugald McAngus', 1652, '');
INSERT INTO 'tune' VALUES (4728, NULL, '2012-01-20 12:54:36.012502+00', 'Always Argyll', 2003, '');
INSERT INTO 'tune' VALUES (2143, NULL, '2012-01-20 12:54:27.049855+00', 'Silver Anniversary', 1534, '');
INSERT INTO 'tune' VALUES (2160, NULL, '2012-01-20 12:54:27.100517+00', 'Bill', 1607, '');
INSERT INTO 'tune' VALUES (2144, NULL, '2012-01-20 12:54:27.053066+00', 'Duke of Edinburgh, The', 9999, '');
INSERT INTO 'tune' VALUES (4729, NULL, '2012-01-20 12:54:36.015418+00', 'Bill Black''s Button Box', 1677, '');
INSERT INTO 'tune' VALUES (2145, NULL, '2012-01-20 12:54:27.056114+00', 'Menstrie Castle', 1533, '');
INSERT INTO 'tune' VALUES (2161, NULL, '2012-01-20 12:54:27.10344+00', 'Tweedale Reel, The', 1719, '');
INSERT INTO 'tune' VALUES (2146, NULL, '2012-01-20 12:54:27.059096+00', 'Shannon Reel', 9999, '');
INSERT INTO 'tune' VALUES (4730, NULL, '2012-01-20 12:54:36.018298+00', 'Anda Campbell''s Frolic', 1608, '');
INSERT INTO 'tune' VALUES (2147, NULL, '2012-01-20 12:54:27.062023+00', 'Uncle Tom''s Wedding', 1534, '');
INSERT INTO 'tune' VALUES (2162, NULL, '2012-01-20 12:54:27.106332+00', 'Edward Jay''s Jaunt', 1554, '');
INSERT INTO 'tune' VALUES (4731, NULL, '2012-01-20 12:54:36.021199+00', 'Bert Ferguson', 1724, '');
INSERT INTO 'tune' VALUES (2149, NULL, '2012-01-20 12:54:27.06839+00', 'Duntroon', 9999, '');
INSERT INTO 'tune' VALUES (2163, NULL, '2012-01-20 12:54:27.109233+00', 'Elegant Esther Gray', 1522, '');
INSERT INTO 'tune' VALUES (2150, NULL, '2012-01-20 12:54:27.071323+00', 'Falls of Lorna, The', 9998, '');
INSERT INTO 'tune' VALUES (4732, NULL, '2012-01-20 12:54:36.024094+00', 'Renatton''s Fancy', 1512, '');
INSERT INTO 'tune' VALUES (2151, NULL, '2012-01-20 12:54:27.074226+00', 'Earl Grey', 1625, '');
INSERT INTO 'tune' VALUES (2164, NULL, '2012-01-20 12:54:27.112268+00', 'Bill May of Boddam', 1655, '');
INSERT INTO 'tune' VALUES (4733, NULL, '2012-01-20 12:54:36.02698+00', 'Miss Linda MacFarlane', 1771, '');
INSERT INTO 'tune' VALUES (2165, NULL, '2012-01-20 12:54:27.115391+00', 'Balmullo House', 1585, '');
INSERT INTO 'tune' VALUES (2154, NULL, '2012-01-20 12:54:27.082949+00', 'Isabel Rattray Hall', 1717, '');
INSERT INTO 'tune' VALUES (4734, NULL, '2012-01-20 12:54:36.029859+00', 'MacRostie Park', 1771, '');
INSERT INTO 'tune' VALUES (2155, NULL, '2012-01-20 12:54:27.085859+00', 'Earl of Mansfield, The', 9999, '');
INSERT INTO 'tune' VALUES (2166, NULL, '2012-01-20 12:54:27.118609+00', 'Elliot Anderson', 1502, '');
INSERT INTO 'tune' VALUES (2167, NULL, '2012-01-20 12:54:27.122506+00', 'Emperor''s Warriors, The', 1672, '');
INSERT INTO 'tune' VALUES (4735, NULL, '2012-01-20 12:54:36.032751+00', 'Earl of Dalhousie''s March, The', 9999, '');
INSERT INTO 'tune' VALUES (2168, NULL, '2012-01-20 12:54:27.125461+00', 'Bobers o'' Brechin', 1516, '');
INSERT INTO 'tune' VALUES (2169, NULL, '2012-01-20 12:54:27.128362+00', 'Enniskillen Dragoons, The', 9999, '');
INSERT INTO 'tune' VALUES (2170, NULL, '2012-01-20 12:54:27.131322+00', 'Espie McNabb', 9999, '');
INSERT INTO 'tune' VALUES (4736, NULL, '2012-01-20 12:54:36.035639+00', 'Mr & Mrs John Wilson, Post Office, Elvanfoot', 1730, '');
INSERT INTO 'tune' VALUES (2171, NULL, '2012-01-20 12:54:27.13433+00', 'Ewan MacPhail''s Two Step', 1527, '');
INSERT INTO 'tune' VALUES (2172, NULL, '2012-01-20 12:54:27.137231+00', 'Little Donald''s Wife', 9999, '');
INSERT INTO 'tune' VALUES (2173, NULL, '2012-01-20 12:54:27.140141+00', 'Colonel Thornton', 2148, '');
INSERT INTO 'tune' VALUES (4737, NULL, '2012-01-20 12:54:36.038536+00', 'Peerie Hoose, The', 9999, '');
INSERT INTO 'tune' VALUES (2174, NULL, '2012-01-20 12:54:27.143213+00', 'Farewell to the North', 9998, '');
INSERT INTO 'tune' VALUES (2175, NULL, '2012-01-20 12:54:27.146116+00', 'Miss Johnston of Hilton', 1517, '');
INSERT INTO 'tune' VALUES (2176, NULL, '2012-01-20 12:54:27.149258+00', 'Farewell, The', 1516, '');
INSERT INTO 'tune' VALUES (2177, NULL, '2012-01-20 12:54:27.154295+00', 'Fill Your Glasses', 9999, '');
INSERT INTO 'tune' VALUES (2178, NULL, '2012-01-20 12:54:27.157295+00', 'Filoro', 9999, '');
INSERT INTO 'tune' VALUES (2179, NULL, '2012-01-20 12:54:27.160206+00', 'Firth of Forth, The', 9999, '');
INSERT INTO 'tune' VALUES (4739, NULL, '2012-01-20 12:54:36.044318+00', 'Callum and Ena Wilson''s Compliments to Donald Lyall', 2009, '');
INSERT INTO 'tune' VALUES (2180, NULL, '2012-01-20 12:54:27.163121+00', 'Fisher''s Hornpipe', 1952, '');
INSERT INTO 'tune' VALUES (2181, NULL, '2012-01-20 12:54:27.16602+00', 'Fishers Rant, The', 1874, '');
INSERT INTO 'tune' VALUES (2182, NULL, '2012-01-20 12:54:27.168921+00', 'Five Mark Peace', 1631, '');
INSERT INTO 'tune' VALUES (4740, NULL, '2012-01-20 12:54:36.047213+00', 'Rothesay Bay', 2007, '');
INSERT INTO 'tune' VALUES (2183, NULL, '2012-01-20 12:54:27.171825+00', 'Miss Milligan''s Favourite', 1607, '');
INSERT INTO 'tune' VALUES (2184, NULL, '2012-01-20 12:54:27.174732+00', 'Neil Mackinnon of the Cuilt', 1680, '');
INSERT INTO 'tune' VALUES (2185, NULL, '2012-01-20 12:54:27.177671+00', 'Lady Charlotte Bruce', 1845, '');
INSERT INTO 'tune' VALUES (4741, NULL, '2012-01-20 12:54:36.050094+00', 'Kirkconnel Lea', 9999, '');
INSERT INTO 'tune' VALUES (2186, NULL, '2012-01-20 12:54:27.18057+00', 'Cape Wrath', 1512, '');
INSERT INTO 'tune' VALUES (4742, NULL, '2012-01-20 12:54:36.052971+00', 'Mrs Helen Wilson', 1730, '');
INSERT INTO 'tune' VALUES (4743, NULL, '2012-01-20 12:54:36.056263+00', 'Mrs Jane Wilson B.E.M.', 1730, '');
INSERT INTO 'tune' VALUES (4744, NULL, '2012-01-20 12:54:36.059189+00', 'Mrs Jessie Wright, McLaren Vale, S.A.', 1730, '');
INSERT INTO 'tune' VALUES (4745, NULL, '2012-01-20 12:54:36.062089+00', 'Miss Gordon of Glastirum', 1516, '');
INSERT INTO 'tune' VALUES (4746, NULL, '2012-01-20 12:54:36.064973+00', 'Cameronian Rant, The', 9999, '');
INSERT INTO 'tune' VALUES (4747, NULL, '2012-01-20 12:54:36.067882+00', 'Bonny Barbara Macpherson', 9998, '');
INSERT INTO 'tune' VALUES (4748, NULL, '2012-01-20 12:54:36.070869+00', 'Kitty''s Rambles', 9999, '');
INSERT INTO 'tune' VALUES (2148, NULL, '2012-04-09 22:11:08.862631+00', 'Alison Wynne Hall', 1717, 'C M Hall (Katy) writes: "Alison Wynne Hall is my cousin.  The tune was written by my father, Tom Rattray Hall.   It''s a fine tune, in a difficult key!"');
INSERT INTO 'tune' VALUES (12138, '2012-06-12 15:23:18.7738+00', '2012-06-12 15:23:18.77381+00', 'Constitution Hornpipe, the', 9999, '');
INSERT INTO 'tune' VALUES (4738, NULL, '2012-08-31 20:44:00.170063+00', 'Iain Peterson''s Compliments to Jack Delaney', 1613, 'The composer''s name is sometimes spelled "Ian".');
INSERT INTO 'tune' VALUES (2152, NULL, '2021-04-05 13:13:38.710846+00', 'Navvie, The', 9999, '');
INSERT INTO 'tune' VALUES (12326, '2013-01-02 16:47:38.219929+00', '2013-01-02 16:47:38.21994+00', 'On the Road to Kingston', 3798, '');
INSERT INTO 'tune' VALUES (12513, '2013-02-27 13:27:14.164373+00', '2013-02-27 13:27:14.164384+00', 'Bonanza Two Step, The', 1527, '');
INSERT INTO 'tune' VALUES (2187, '2005-06-19 22:00:00+00', '2012-01-20 12:54:27.183477+00', 'Double Eighty', 1526, '');
INSERT INTO 'tune' VALUES (2208, NULL, '2012-01-20 12:54:27.254238+00', 'University Hall', 1502, '');
INSERT INTO 'tune' VALUES (2188, NULL, '2012-01-20 12:54:27.186402+00', 'Frost is All Over, The', 9999, '');
INSERT INTO 'tune' VALUES (2189, NULL, '2012-01-20 12:54:27.189296+00', 'G B Bell''s Fancy', 1579, '');
INSERT INTO 'tune' VALUES (2190, NULL, '2012-01-20 12:54:27.192192+00', 'Cape Spear', 1502, '');
INSERT INTO 'tune' VALUES (4750, NULL, '2012-01-20 12:54:36.076717+00', 'Major Molle''s', 10510, '');
INSERT INTO 'tune' VALUES (2191, NULL, '2012-01-20 12:54:27.195096+00', 'Gallagher''s Rant', 1585, '');
INSERT INTO 'tune' VALUES (2210, NULL, '2012-01-20 12:54:27.261105+00', 'Glasgow Police Pipers, The', 3296, '');
INSERT INTO 'tune' VALUES (2192, NULL, '2012-01-20 12:54:27.197988+00', 'Welcome to Hamilton House', 1502, '');
INSERT INTO 'tune' VALUES (4751, NULL, '2012-01-20 12:54:36.079641+00', 'Bob Morris', 9999, '');
INSERT INTO 'tune' VALUES (2193, NULL, '2012-01-20 12:54:27.205475+00', 'Pearlin'' Jean', 1502, '');
INSERT INTO 'tune' VALUES (2211, NULL, '2012-01-20 12:54:27.264053+00', 'Glen Esk', 1522, '');
INSERT INTO 'tune' VALUES (2194, NULL, '2012-01-20 12:54:27.209313+00', 'Garden Where The Praties Grow, The', 9999, '');
INSERT INTO 'tune' VALUES (4752, NULL, '2012-01-20 12:54:36.082536+00', 'Over the Isles to America', 9998, '');
INSERT INTO 'tune' VALUES (2195, NULL, '2012-01-20 12:54:27.213168+00', 'Noreen MacLennan', 1502, '');
INSERT INTO 'tune' VALUES (2212, NULL, '2012-01-20 12:54:27.266939+00', 'Glenbuchat Lodge', 1522, '');
INSERT INTO 'tune' VALUES (2196, NULL, '2012-01-20 12:54:27.216969+00', 'Garey Cottage', 1746, '');
INSERT INTO 'tune' VALUES (4753, NULL, '2012-01-20 12:54:36.085419+00', 'Colonel MacLeod''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (2197, NULL, '2012-01-20 12:54:27.220799+00', 'Garster''s Dream', 9999, '');
INSERT INTO 'tune' VALUES (2213, NULL, '2012-01-20 12:54:27.269831+00', 'Torrent, The', 1502, '');
INSERT INTO 'tune' VALUES (2198, NULL, '2012-01-20 12:54:27.224507+00', 'Fair Jean', 1502, '');
INSERT INTO 'tune' VALUES (4754, NULL, '2012-01-20 12:54:36.0883+00', 'Wee Pug, The', 9999, '');
INSERT INTO 'tune' VALUES (2199, NULL, '2012-01-20 12:54:27.227478+00', 'General Election, The', 3058, '');
INSERT INTO 'tune' VALUES (2214, NULL, '2012-01-20 12:54:27.272722+00', 'Glen Caladh Castle', 1700, '');
INSERT INTO 'tune' VALUES (2200, NULL, '2012-01-20 12:54:27.230373+00', 'General Gathering 1745, The', 9999, '');
INSERT INTO 'tune' VALUES (4755, NULL, '2012-01-20 12:54:36.091191+00', 'Green Fields of America', 9998, '');
INSERT INTO 'tune' VALUES (2201, NULL, '2012-01-20 12:54:27.233913+00', 'Miss Cynthia Mackay', 1502, '');
INSERT INTO 'tune' VALUES (2215, NULL, '2012-01-20 12:54:27.275612+00', 'Thank Goodness it''s Monday', 1502, '');
INSERT INTO 'tune' VALUES (2202, NULL, '2012-01-20 12:54:27.236834+00', 'Geordie Affleck', 9999, '');
INSERT INTO 'tune' VALUES (4756, NULL, '2012-01-20 12:54:36.094085+00', 'Traditional Hornpipes 1 and 2', 9999, '');
INSERT INTO 'tune' VALUES (2203, NULL, '2012-01-20 12:54:27.239734+00', 'Geordie Barrie', 1623, '');
INSERT INTO 'tune' VALUES (2216, NULL, '2012-01-20 12:54:27.278502+00', 'Skye Garter, The', 1502, '');
INSERT INTO 'tune' VALUES (2204, NULL, '2012-01-20 12:54:27.24262+00', 'ACH, the Director', 1502, '');
INSERT INTO 'tune' VALUES (4757, NULL, '2012-01-20 12:54:36.097308+00', 'Allt an Gobha', 9999, '');
INSERT INTO 'tune' VALUES (2205, NULL, '2012-01-20 12:54:27.245499+00', 'Georgina Catherine MacDonald''s Fancy', 1558, '');
INSERT INTO 'tune' VALUES (2217, NULL, '2012-01-20 12:54:27.281388+00', 'Marjorie Easton McLaughlin', 1502, '');
INSERT INTO 'tune' VALUES (2206, NULL, '2012-01-20 12:54:27.248409+00', 'Ghoid iad mo bheam uam nan raoir', 9999, '');
INSERT INTO 'tune' VALUES (2207, NULL, '2012-01-20 12:54:27.25135+00', 'Lumsden Wing', 1502, '');
INSERT INTO 'tune' VALUES (2218, NULL, '2012-01-20 12:54:27.284933+00', 'Glenlivet, The', 1512, '');
INSERT INTO 'tune' VALUES (4759, NULL, '2012-01-20 12:54:36.103111+00', 'Bailie Nicol Jarvie', 9998, '');
INSERT INTO 'tune' VALUES (2219, NULL, '2012-01-20 12:54:27.287868+00', 'Glentromie', 1516, '');
INSERT INTO 'tune' VALUES (2220, NULL, '2012-01-20 12:54:27.290789+00', 'Going to the Barndance', 1639, '');
INSERT INTO 'tune' VALUES (2221, NULL, '2012-01-20 12:54:27.2937+00', 'Passeggiatta, La', 1502, '');
INSERT INTO 'tune' VALUES (4760, NULL, '2012-01-20 12:54:36.106005+00', 'Mr Gibson', 9998, '');
INSERT INTO 'tune' VALUES (2222, NULL, '2012-01-20 12:54:27.296597+00', 'Andrew''s Never as Old as Terry', 1502, '');
INSERT INTO 'tune' VALUES (2223, NULL, '2012-01-20 12:54:27.299487+00', 'Goose Feathers', 1503, '');
INSERT INTO 'tune' VALUES (2224, NULL, '2012-01-20 12:54:27.302413+00', 'Laughter Ben the Room', 1502, '');
INSERT INTO 'tune' VALUES (4761, NULL, '2012-01-20 12:54:36.108894+00', 'Market Cross, The', 9998, '');
INSERT INTO 'tune' VALUES (2225, NULL, '2012-01-20 12:54:27.305313+00', 'Gordon Highlanders', 1699, '');
INSERT INTO 'tune' VALUES (2226, NULL, '2012-01-20 12:54:27.308648+00', 'Gordon Pattullo''s Reel', 1646, '');
INSERT INTO 'tune' VALUES (2227, NULL, '2012-01-20 12:54:27.311589+00', 'Gordon the Goalie', 1507, '');
INSERT INTO 'tune' VALUES (4762, NULL, '2012-01-20 12:54:36.111782+00', 'Infare, The', 9998, '');
INSERT INTO 'tune' VALUES (2228, NULL, '2012-01-20 12:54:27.314489+00', 'Gordon''s ''Reel'' Aviation Fuel', 1591, '');
INSERT INTO 'tune' VALUES (2229, NULL, '2012-01-20 12:54:27.317428+00', 'Gordon''s Hornpipe', 1668, '');
INSERT INTO 'tune' VALUES (2230, NULL, '2012-01-20 12:54:27.320314+00', 'Gothenburg Polka, The', 9999, '');
INSERT INTO 'tune' VALUES (4763, NULL, '2012-01-20 12:54:36.114699+00', 'Al''s Fiddle', 1415, '');
INSERT INTO 'tune' VALUES (2231, NULL, '2012-01-20 12:54:27.323235+00', 'Gowan Hill', 1558, '');
INSERT INTO 'tune' VALUES (2232, NULL, '2012-01-20 12:54:27.326151+00', 'Grace Hay''s Delight', 9998, '');
INSERT INTO 'tune' VALUES (2233, NULL, '2012-01-20 12:54:27.329248+00', 'Glenfinnan', 1502, '');
INSERT INTO 'tune' VALUES (4764, NULL, '2012-01-20 12:54:36.117587+00', 'Shepherd''s Crook, The', 9999, '');
INSERT INTO 'tune' VALUES (2235, NULL, '2012-01-20 12:54:27.33513+00', 'Grant Lodge', 1516, '');
INSERT INTO 'tune' VALUES (2236, NULL, '2012-01-20 12:54:27.338032+00', 'Green Meadow, The', 9999, '');
INSERT INTO 'tune' VALUES (4765, NULL, '2012-01-20 12:54:36.12125+00', 'Border Collie, The', 9998, '');
INSERT INTO 'tune' VALUES (2237, NULL, '2012-01-20 12:54:27.340934+00', 'Inverlochy', 1502, '');
INSERT INTO 'tune' VALUES (2238, NULL, '2012-01-20 12:54:27.343818+00', 'Green Dykes, The', 1525, '');
INSERT INTO 'tune' VALUES (4766, NULL, '2012-01-20 12:54:36.125186+00', 'Lamb''s Strathspey', 1608, '');
INSERT INTO 'tune' VALUES (4767, NULL, '2012-01-20 12:54:36.128328+00', 'Laird o'' McNab', 9999, '');
INSERT INTO 'tune' VALUES (4770, NULL, '2012-01-20 12:54:36.137065+00', 'Afton Water', 9998, '');
INSERT INTO 'tune' VALUES (4771, NULL, '2012-01-20 12:54:36.13996+00', 'Lament of Flora McDonald', 9998, '');
INSERT INTO 'tune' VALUES (4772, NULL, '2012-01-20 12:54:36.142849+00', 'Newcastle Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (4773, NULL, '2012-01-20 12:54:36.145736+00', 'Glen Lean', 9998, '');
INSERT INTO 'tune' VALUES (4774, NULL, '2012-01-20 12:54:36.14863+00', 'Bath Medley', 9998, '');
INSERT INTO 'tune' VALUES (4775, NULL, '2012-01-20 12:54:36.151518+00', 'Miss Drummond''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (2209, NULL, '2012-03-23 10:14:53.9472+00', 'Rain Dancin'', Da', 1502, '');
INSERT INTO 'tune' VALUES (12139, '2012-06-12 15:45:10.106018+00', '2012-06-12 15:45:10.106029+00', 'Mischief Right Through', 1631, '');
INSERT INTO 'tune' VALUES (12514, '2013-02-27 13:29:11.524385+00', '2013-02-27 13:29:11.524398+00', 'London Olympics 2012', 1621, '');
INSERT INTO 'tune' VALUES (2239, NULL, '2012-01-20 12:54:27.346732+00', 'Black Grouse, The', 1502, '');
INSERT INTO 'tune' VALUES (2259, NULL, '2012-01-20 12:54:27.405645+00', 'Hey Ho! My Bonny Lass', 9999, '');
INSERT INTO 'tune' VALUES (4776, NULL, '2012-01-20 12:54:36.154413+00', 'Banana-Benders, The', 1502, '');
INSERT INTO 'tune' VALUES (2241, NULL, '2012-01-20 12:54:27.352752+00', 'Grey Buck, The', 9999, '');
INSERT INTO 'tune' VALUES (2260, NULL, '2012-01-20 12:54:27.408564+00', 'Heyken''s Serenade', 10537, '');
INSERT INTO 'tune' VALUES (2242, NULL, '2012-01-20 12:54:27.35577+00', 'Mr & Mrs McLaughlin of San Diego', 1502, '');
INSERT INTO 'tune' VALUES (4777, NULL, '2012-01-20 12:54:36.157298+00', 'Miss Menzies of Culdare', 9999, '');
INSERT INTO 'tune' VALUES (2243, NULL, '2012-01-20 12:54:27.358685+00', 'HRH Princess Alexandra''s Welcome to Wick', 2362, '');
INSERT INTO 'tune' VALUES (2261, NULL, '2012-01-20 12:54:27.411474+00', 'John Derek Evans', 1502, '');
INSERT INTO 'tune' VALUES (2244, NULL, '2012-01-20 12:54:27.361572+00', 'Kiltmaker''s Fancy', 1502, '');
INSERT INTO 'tune' VALUES (4778, NULL, '2012-01-20 12:54:36.160207+00', 'MacArthur''s Road', 2241, '');
INSERT INTO 'tune' VALUES (2245, NULL, '2012-01-20 12:54:27.364466+00', 'Willie Kennedy''s Salute to the Muileach', 1502, '');
INSERT INTO 'tune' VALUES (2262, NULL, '2012-01-20 12:54:27.414406+00', 'Miss Roz Scott Huxley', 1502, '');
INSERT INTO 'tune' VALUES (2246, NULL, '2012-01-20 12:54:27.367396+00', 'Harvester''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (4779, NULL, '2012-01-20 12:54:36.163107+00', 'Swallow''s Tail', 9999, '');
INSERT INTO 'tune' VALUES (2247, NULL, '2012-01-20 12:54:27.370299+00', 'Harveston Castle', 1558, '');
INSERT INTO 'tune' VALUES (2263, NULL, '2012-01-20 12:54:27.417356+00', 'Highland Air', 9999, '');
INSERT INTO 'tune' VALUES (2248, NULL, '2012-01-20 12:54:27.373199+00', 'Marilyn Stocker of Clan Anderson', 1502, '');
INSERT INTO 'tune' VALUES (4780, NULL, '2012-01-20 12:54:36.165993+00', 'Fiddler''s Whim', 9999, '');
INSERT INTO 'tune' VALUES (2249, NULL, '2012-01-20 12:54:27.376312+00', 'Haymakers, The', 9999, '');
INSERT INTO 'tune' VALUES (2264, NULL, '2012-01-20 12:54:27.420253+00', 'Highland Cradle Song, The', 9999, '');
INSERT INTO 'tune' VALUES (2250, NULL, '2012-01-20 12:54:27.379235+00', 'Scamp, The', 1502, '');
INSERT INTO 'tune' VALUES (4781, NULL, '2012-01-20 12:54:36.168882+00', 'Paddy Whack', 9999, '');
INSERT INTO 'tune' VALUES (2251, NULL, '2012-01-20 12:54:27.382129+00', 'Shuttlecock, The', 1502, '');
INSERT INTO 'tune' VALUES (2265, NULL, '2012-01-20 12:54:27.423366+00', 'Tribute to Margaret Gillies, A', 1502, '');
INSERT INTO 'tune' VALUES (4782, NULL, '2012-01-20 12:54:36.171775+00', 'Miss Jenny Younger', 1527, '');
INSERT INTO 'tune' VALUES (2253, NULL, '2012-01-20 12:54:27.387963+00', 'Dancing Dido', 1502, '');
INSERT INTO 'tune' VALUES (2266, NULL, '2012-01-20 12:54:27.426435+00', 'Highland Harry', 9999, '');
INSERT INTO 'tune' VALUES (2254, NULL, '2012-01-20 12:54:27.390968+00', 'Bowlens of Bundoora, The', 1502, '');
INSERT INTO 'tune' VALUES (4783, NULL, '2012-01-20 12:54:36.174681+00', 'Strathspey Forever', 1644, '');
INSERT INTO 'tune' VALUES (2255, NULL, '2012-01-20 12:54:27.393851+00', 'Hebridean Wauking Song', 9999, '');
INSERT INTO 'tune' VALUES (2267, NULL, '2012-01-20 12:54:27.429379+00', 'Fraser''s Fiddle', 1502, '');
INSERT INTO 'tune' VALUES (2256, NULL, '2012-01-20 12:54:27.396751+00', 'Heilan'' Donald', 9999, '');
INSERT INTO 'tune' VALUES (4784, NULL, '2012-01-20 12:54:36.177581+00', 'Wade Hampton''s Hornpipe', 2263, '');
INSERT INTO 'tune' VALUES (2257, NULL, '2012-01-20 12:54:27.39983+00', 'Hepburn Gardens', 1502, '');
INSERT INTO 'tune' VALUES (4785, NULL, '2012-01-20 12:54:36.180472+00', 'Ned Kendall''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (2269, NULL, '2012-01-20 12:54:27.435202+00', 'Highland Lassie Going to the Fair', 9999, '');
INSERT INTO 'tune' VALUES (2268, NULL, '2014-02-25 14:32:30.834174+00', 'Friday the Thirteenth', 1502, 'This tune exists both as a Reel and as a Strathspey');
INSERT INTO 'tune' VALUES (4758, NULL, '2014-08-11 22:15:48.459284+00', 'Billy Mackinnon', 9998, '');
INSERT INTO 'tune' VALUES (2270, NULL, '2012-01-20 12:54:27.438094+00', 'Highland Wedding, The', 2309, '');
INSERT INTO 'tune' VALUES (2271, NULL, '2012-01-20 12:54:27.441027+00', 'Dorchester Dolls, The', 1502, '');
INSERT INTO 'tune' VALUES (4786, NULL, '2012-01-20 12:54:36.183358+00', 'Lady Arbuthnot''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (2272, NULL, '2012-01-20 12:54:27.443917+00', 'Kindness Itself', 1502, '');
INSERT INTO 'tune' VALUES (2273, NULL, '2012-01-20 12:54:27.446917+00', 'Caroline''s Waltz', 1502, '');
INSERT INTO 'tune' VALUES (2274, NULL, '2012-01-20 12:54:27.449834+00', 'Hills of Hampstead, The', 1590, '');
INSERT INTO 'tune' VALUES (4787, NULL, '2012-01-20 12:54:36.186258+00', 'Willie MacHardy''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (2275, NULL, '2012-01-20 12:54:27.452735+00', 'Mimie Hughson''s Welcome', 1502, '');
INSERT INTO 'tune' VALUES (2276, NULL, '2012-01-20 12:54:27.45563+00', 'John & Ponty Connon''s Scotch Measure', 1585, '');
INSERT INTO 'tune' VALUES (2277, NULL, '2012-01-20 12:54:27.458523+00', 'Home from the Sea', 3058, '');
INSERT INTO 'tune' VALUES (4788, NULL, '2012-01-20 12:54:36.189155+00', 'Mountain Top', 2141, '');
INSERT INTO 'tune' VALUES (2278, NULL, '2012-01-20 12:54:27.461612+00', 'Homeward Bound', 2470, '');
INSERT INTO 'tune' VALUES (2279, NULL, '2012-01-20 12:54:27.464525+00', 'Hon Captain Elliot''s Quickstep', 1476, '');
INSERT INTO 'tune' VALUES (2280, NULL, '2012-01-20 12:54:27.467423+00', 'Dufftown Divots, The', 1585, '');
INSERT INTO 'tune' VALUES (4789, NULL, '2012-01-20 12:54:36.192044+00', 'Glen Alen', 9999, '');
INSERT INTO 'tune' VALUES (2281, NULL, '2012-01-20 12:54:27.470316+00', 'Behind the Bush in the Garden', 1710, '');
INSERT INTO 'tune' VALUES (2282, NULL, '2012-01-20 12:54:27.473296+00', 'Struan Robertson''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (2283, NULL, '2012-01-20 12:54:27.476189+00', 'How Can I Live at the Top of the Mountain', 9999, '');
INSERT INTO 'tune' VALUES (4790, NULL, '2012-01-20 12:54:36.19493+00', 'Tomorrow Morning', 9999, '');
INSERT INTO 'tune' VALUES (2284, NULL, '2012-01-20 12:54:27.47908+00', 'Hughie Morrison', 1693, '');
INSERT INTO 'tune' VALUES (2285, NULL, '2012-01-20 12:54:27.481969+00', 'Humours of Castle Glendart, The', 9999, '');
INSERT INTO 'tune' VALUES (2286, NULL, '2012-01-20 12:54:27.484863+00', 'Huntingtower', 9998, '');
INSERT INTO 'tune' VALUES (4791, NULL, '2012-01-20 12:54:36.197817+00', 'Granny Wade''s Jig', 1626, '');
INSERT INTO 'tune' VALUES (2287, NULL, '2012-01-20 12:54:27.487752+00', 'I Ha''e a Wife o'' my Ain', 9999, '');
INSERT INTO 'tune' VALUES (2288, NULL, '2012-01-20 12:54:27.490679+00', 'Stern Polka', 9998, '');
INSERT INTO 'tune' VALUES (2289, NULL, '2012-01-20 12:54:27.493573+00', 'I Lost My Love', 9999, '');
INSERT INTO 'tune' VALUES (4792, NULL, '2012-01-20 12:54:36.20071+00', 'Perthshire Assembly, The', 9999, '');
INSERT INTO 'tune' VALUES (4793, NULL, '2012-01-20 12:54:36.2036+00', 'Whipples Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (4794, NULL, '2012-01-20 12:54:36.206483+00', 'Fairhaired Boy, The', 9998, '');
INSERT INTO 'tune' VALUES (4795, NULL, '2012-01-20 12:54:36.209374+00', 'Pleasures of Home, The', 9999, '');
INSERT INTO 'tune' VALUES (4796, NULL, '2012-01-20 12:54:36.21226+00', 'Ete, L''', 9998, '');
INSERT INTO 'tune' VALUES (4797, NULL, '2012-01-20 12:54:36.215148+00', 'Trenise, La', 9998, '');
INSERT INTO 'tune' VALUES (4798, NULL, '2012-01-20 12:54:36.218029+00', 'Jas Soutar of Plain''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (4799, NULL, '2012-01-20 12:54:36.220921+00', 'Dunblane', 9998, '');
INSERT INTO 'tune' VALUES (4800, NULL, '2012-01-20 12:54:36.223811+00', 'Banks of Garry, The', 1810, '');
INSERT INTO 'tune' VALUES (12140, '2012-06-12 15:45:58.625635+00', '2012-06-12 15:45:58.625646+00', 'Rollicking Irishman, The', 9999, '');
INSERT INTO 'tune' VALUES (12515, '2013-02-27 13:31:41.001492+00', '2013-02-27 13:31:41.001504+00', 'Rhoda''s Bon Hoga', 10758, '');
INSERT INTO 'tune' VALUES (2290, NULL, '2012-01-20 12:54:27.496507+00', 'Miller''s Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (2309, NULL, '2012-01-20 12:54:27.551894+00', 'Irish Girl, The', 2149, '');
INSERT INTO 'tune' VALUES (2291, NULL, '2012-01-20 12:54:27.49941+00', 'Iain Dugald Torquil MacPhail', 1527, '');
INSERT INTO 'tune' VALUES (4802, NULL, '2012-01-20 12:54:36.229576+00', 'Dundrennan Abbey', 9998, '');
INSERT INTO 'tune' VALUES (2292, NULL, '2012-01-20 12:54:27.502302+00', 'Iain Stevenson''s Reel', 1508, '');
INSERT INTO 'tune' VALUES (2310, NULL, '2012-01-20 12:54:27.554873+00', 'Lady Maxwell''s Reel', 1493, '');
INSERT INTO 'tune' VALUES (2293, NULL, '2012-01-20 12:54:27.505198+00', 'Ian Holmes'' Compliments to Bobby Crowe', 1668, '');
INSERT INTO 'tune' VALUES (4803, NULL, '2012-01-20 12:54:36.23247+00', 'Old Traditional Air', 9998, '');
INSERT INTO 'tune' VALUES (2294, NULL, '2012-01-20 12:54:27.508099+00', 'Ian MacKintosh of Pine House', 1522, '');
INSERT INTO 'tune' VALUES (2311, NULL, '2012-01-20 12:54:27.557796+00', 'Irish Soldier Laddie', 9999, '');
INSERT INTO 'tune' VALUES (2295, NULL, '2012-01-20 12:54:27.511022+00', 'Iain MacPhail''s Compliments to Chrissie Leatham', 1527, '');
INSERT INTO 'tune' VALUES (4804, NULL, '2012-01-20 12:54:36.235403+00', 'Mrs Peggy Rae', 9998, '');
INSERT INTO 'tune' VALUES (2296, NULL, '2012-01-20 12:54:27.513918+00', 'Iain MacPhail''s Compliments to John MacInnes', 1527, '');
INSERT INTO 'tune' VALUES (4805, NULL, '2012-01-20 12:54:36.238314+00', 'Reel of Bangholm', 9998, '');
INSERT INTO 'tune' VALUES (2298, NULL, '2012-01-20 12:54:27.519858+00', 'Highlander''s Farewell to Ireland, The', 9999, '');
INSERT INTO 'tune' VALUES (2313, NULL, '2012-01-20 12:54:27.565458+00', 'Irish Whispers', 9998, '');
INSERT INTO 'tune' VALUES (2299, NULL, '2012-01-20 12:54:27.522786+00', 'Ian Muir''s Compliments to Muriel Johnstone', 1590, '');
INSERT INTO 'tune' VALUES (4806, NULL, '2012-01-20 12:54:36.241215+00', 'Lowlands of Holland, The', 9998, '');
INSERT INTO 'tune' VALUES (2300, NULL, '2012-01-20 12:54:27.525692+00', 'Donald Blue', 9999, '');
INSERT INTO 'tune' VALUES (2314, NULL, '2012-01-20 12:54:27.568518+00', 'Isle of Heather', 9998, '');
INSERT INTO 'tune' VALUES (2301, NULL, '2012-01-20 12:54:27.528586+00', 'Ian Woodcraft', 1576, '');
INSERT INTO 'tune' VALUES (4807, NULL, '2012-01-20 12:54:36.244114+00', 'Miss C Little''s Fancy', 9998, '');
INSERT INTO 'tune' VALUES (2302, NULL, '2012-01-20 12:54:27.531519+00', 'If You will marry Me', 9999, '');
INSERT INTO 'tune' VALUES (2315, NULL, '2012-01-20 12:54:27.571432+00', 'Hon John Leslie Melville', 9999, '');
INSERT INTO 'tune' VALUES (2303, NULL, '2012-01-20 12:54:27.534401+00', 'Foot it Neatly', 9999, '');
INSERT INTO 'tune' VALUES (4808, NULL, '2012-01-20 12:54:36.247009+00', 'Lord Duncan''s Fancy', 9998, '');
INSERT INTO 'tune' VALUES (2304, NULL, '2012-01-20 12:54:27.537302+00', 'If You''re Irish, Come into the Parlour', 1305, '');
INSERT INTO 'tune' VALUES (2305, NULL, '2012-01-20 12:54:27.540231+00', 'Inchgarth Strathspey, The', 1538, '');
INSERT INTO 'tune' VALUES (4809, NULL, '2012-01-20 12:54:36.24992+00', 'Burn o'' Cairnie', 9999, '');
INSERT INTO 'tune' VALUES (2306, NULL, '2012-01-20 12:54:27.543143+00', 'Athole Volunteers, The', 1518, '');
INSERT INTO 'tune' VALUES (2317, NULL, '2012-01-20 12:54:27.577276+00', 'Dr Robertson', 1554, '');
INSERT INTO 'tune' VALUES (4810, NULL, '2012-01-20 12:54:36.252811+00', 'Mrs Gordon of Abergeldie', 9998, '');
INSERT INTO 'tune' VALUES (2318, NULL, '2012-01-20 12:54:27.580172+00', 'J. D. MacLennan''s Reel', 1525, '');
INSERT INTO 'tune' VALUES (2319, NULL, '2012-01-20 12:54:27.584175+00', 'Ian and Ishbel Crichton', 1591, '');
INSERT INTO 'tune' VALUES (4811, NULL, '2012-01-20 12:54:36.255696+00', 'Lady Pennel Grant', 9998, '');
INSERT INTO 'tune' VALUES (2320, NULL, '2012-01-20 12:54:27.587099+00', 'Mr Thomson', 1512, '');
INSERT INTO 'tune' VALUES (2322, NULL, '2012-01-20 12:54:27.593296+00', 'Willie Blair, Queen Victoria''s Fiddler', 1632, '');
INSERT INTO 'tune' VALUES (4812, NULL, '2012-01-20 12:54:36.258579+00', 'Lady Ford''s Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (2323, NULL, '2012-01-20 12:54:27.597118+00', 'Jack a'' Tar', 9999, '');
INSERT INTO 'tune' VALUES (2324, NULL, '2012-01-20 12:54:27.600972+00', 'Tipperty''s Jean', 1512, '');
INSERT INTO 'tune' VALUES (2325, NULL, '2012-01-20 12:54:27.607337+00', 'Back of the Haggard', 9999, '');
INSERT INTO 'tune' VALUES (4813, NULL, '2012-01-20 12:54:36.261462+00', 'Pandean Dance', 9998, '');
INSERT INTO 'tune' VALUES (2326, NULL, '2012-01-20 12:54:27.611152+00', 'Jack''s Medley', 9999, '');
INSERT INTO 'tune' VALUES (2327, NULL, '2012-01-20 12:54:27.614995+00', 'James McInnes, Esq', 1512, '');
INSERT INTO 'tune' VALUES (2328, NULL, '2012-01-20 12:54:27.61883+00', 'James Miller, Bullionfield', 1551, '');
INSERT INTO 'tune' VALUES (4814, NULL, '2012-01-20 12:54:36.264353+00', 'Mrs Betty Kerr''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (2329, NULL, '2012-01-20 12:54:27.623218+00', 'One of the Boys', 9999, '');
INSERT INTO 'tune' VALUES (4815, NULL, '2012-01-20 12:54:36.267243+00', 'Miss Brown', 9999, '');
INSERT INTO 'tune' VALUES (2330, NULL, '2012-01-20 12:54:27.627796+00', 'Janette MacInnes', 1527, '');
INSERT INTO 'tune' VALUES (2331, NULL, '2012-01-20 12:54:27.63161+00', 'Janey''s Wedding', 1522, '');
INSERT INTO 'tune' VALUES (2332, NULL, '2012-01-20 12:54:27.635453+00', 'Jean Kirkpatrick''s Fancy', 1598, '');
INSERT INTO 'tune' VALUES (2333, NULL, '2012-01-20 12:54:27.638443+00', 'Jeannie King', 1558, '');
INSERT INTO 'tune' VALUES (4816, NULL, '2012-01-20 12:54:36.270131+00', 'Miss Rutherford''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (2258, NULL, '2020-05-22 22:11:02.017061+00', 'Hesleyside Reel, The', 1676, '');
INSERT INTO 'tune' VALUES (2307, NULL, '2021-05-26 09:25:57.589399+00', 'Invercauld', 9999, 'Possibly duplicated as <<ddt:Invercauld''s Reel#10191>>? To be checked.');
INSERT INTO 'tune' VALUES (2334, NULL, '2012-01-20 12:54:27.641344+00', 'Morning Fair', 9999, '');
INSERT INTO 'tune' VALUES (2335, NULL, '2012-01-20 12:54:27.644282+00', 'Maiden by the Silver Dee, The', 9999, '');
INSERT INTO 'tune' VALUES (4817, NULL, '2012-01-20 12:54:36.273028+00', 'Highland Quickstep, A', 9999, '');
INSERT INTO 'tune' VALUES (2337, NULL, '2012-01-20 12:54:27.650083+00', 'McGillan''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (2338, NULL, '2012-01-20 12:54:27.652989+00', 'Mrs Greig''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (2339, NULL, '2012-01-20 12:54:27.655901+00', 'Mrs Francis Wemyss', 9999, '');
INSERT INTO 'tune' VALUES (4818, NULL, '2012-01-20 12:54:36.275914+00', 'Ron Kerr''s Jig', 2266, '');
INSERT INTO 'tune' VALUES (4819, NULL, '2012-01-20 12:54:36.278861+00', 'Fiddlers, The', 9998, '');
INSERT INTO 'tune' VALUES (2312, NULL, '2014-10-02 00:03:56.336779+00', 'Miss Douglas', 1519, 'The tunes "Miss Douglas''s Strathspey", "Miss Douglas" and "Miss Ann Douglas" are possibly identical.');
INSERT INTO 'tune' VALUES (4820, NULL, '2012-01-20 12:54:36.281768+00', 'Maids O'' Flanders', 2256, '');
INSERT INTO 'tune' VALUES (4821, NULL, '2012-01-20 12:54:36.284654+00', 'Tight Little Island', 9999, '');
INSERT INTO 'tune' VALUES (4822, NULL, '2012-01-20 12:54:36.287544+00', 'Plymouth Lassies Jig', 9999, '');
INSERT INTO 'tune' VALUES (4823, NULL, '2012-01-20 12:54:36.29046+00', 'Hon James Ramsay''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (4824, NULL, '2012-01-20 12:54:36.293357+00', 'Dan & Maureen McCrudden', 1415, '');
INSERT INTO 'tune' VALUES (4825, NULL, '2012-01-20 12:54:36.296248+00', 'Duchess of Hamilton, The', 9999, '');
INSERT INTO 'tune' VALUES (4826, NULL, '2012-01-20 12:54:36.299136+00', 'Lieutenant Colonel H B C Ashmore MBE', 1683, '');
INSERT INTO 'tune' VALUES (4827, NULL, '2012-01-20 12:54:36.302013+00', 'John Laurie', 1442, '');
INSERT INTO 'tune' VALUES (12141, '2012-06-12 15:46:25.663696+00', '2012-06-12 15:46:25.663706+00', 'Galloping O''Hagan', 9999, '');
INSERT INTO 'tune' VALUES (12516, '2013-02-27 13:32:39.344439+00', '2013-02-27 13:32:39.34445+00', 'Jessie Burns', 3186, '');
INSERT INTO 'tune' VALUES (2340, NULL, '2012-01-20 12:54:27.662999+00', 'Jig for Jed', 1609, '');
INSERT INTO 'tune' VALUES (2361, NULL, '2012-01-20 12:54:27.727416+00', 'Glenesk', 1522, '');
INSERT INTO 'tune' VALUES (2342, NULL, '2012-01-20 12:54:27.67037+00', 'Auld Wheel, The', 1512, '');
INSERT INTO 'tune' VALUES (2362, NULL, '2012-01-20 12:54:27.730309+00', 'John Macgregor', 1527, '');
INSERT INTO 'tune' VALUES (2343, NULL, '2012-01-20 12:54:27.673296+00', 'Jiggernaut, The', 1673, '');
INSERT INTO 'tune' VALUES (4829, NULL, '2012-01-20 12:54:36.307802+00', 'Captain Byng', 9999, '');
INSERT INTO 'tune' VALUES (2344, NULL, '2012-01-20 12:54:27.67619+00', 'Corimonie''s Rant', 9999, '');
INSERT INTO 'tune' VALUES (2363, NULL, '2012-01-20 12:54:27.733201+00', 'Whistling Woodman, The', 1538, '');
INSERT INTO 'tune' VALUES (2345, NULL, '2012-01-20 12:54:27.680494+00', 'Jill Simpson of Chapelhill', 1522, '');
INSERT INTO 'tune' VALUES (4830, NULL, '2012-01-20 12:54:36.310695+00', 'Niel Gow''s Recovery', 9999, '');
INSERT INTO 'tune' VALUES (2346, NULL, '2012-01-20 12:54:27.68347+00', 'Jim & Marilyn Healy''s Reel', 1612, '');
INSERT INTO 'tune' VALUES (2364, NULL, '2012-01-20 12:54:27.73609+00', 'Mr & Mrs MacRogerson', 1527, '');
INSERT INTO 'tune' VALUES (4831, NULL, '2012-01-20 12:54:36.313584+00', 'Miss Dundas of Arniston', 1517, '');
INSERT INTO 'tune' VALUES (2348, NULL, '2012-01-20 12:54:27.689318+00', 'Lady Madelina Sinclair', 1516, '');
INSERT INTO 'tune' VALUES (2365, NULL, '2012-01-20 12:54:27.738983+00', 'John Mearn''s Favourite', 1558, '');
INSERT INTO 'tune' VALUES (2349, NULL, '2012-01-20 12:54:27.692321+00', 'Jimmy Shand''s Compliments to Miss Milligan', 1558, '');
INSERT INTO 'tune' VALUES (4832, NULL, '2012-01-20 12:54:36.316473+00', 'Strathspey, A', 1570, '');
INSERT INTO 'tune' VALUES (2350, NULL, '2012-01-20 12:54:27.695245+00', 'Anneliese', 1721, '');
INSERT INTO 'tune' VALUES (2366, NULL, '2012-01-20 12:54:27.741884+00', 'John Monro Sturrock', 1502, '');
INSERT INTO 'tune' VALUES (2351, NULL, '2012-01-20 12:54:27.698151+00', 'Sandy May', 1572, '');
INSERT INTO 'tune' VALUES (4833, NULL, '2012-01-20 12:54:36.319356+00', 'Sgian Dubh', 9999, '');
INSERT INTO 'tune' VALUES (2352, NULL, '2012-01-20 12:54:27.70106+00', 'Catherine May', 1572, '');
INSERT INTO 'tune' VALUES (2367, NULL, '2012-01-20 12:54:27.744918+00', 'Belvidere Jig, The', 1572, '');
INSERT INTO 'tune' VALUES (2353, NULL, '2012-01-20 12:54:27.703959+00', 'Joe Murphy''s Reel', 1593, '');
INSERT INTO 'tune' VALUES (4834, NULL, '2012-01-20 12:54:36.322243+00', 'Lord Moira''s Welcome', 9998, '');
INSERT INTO 'tune' VALUES (2354, NULL, '2012-01-20 12:54:27.706863+00', 'John Bain Mackenzie', 9999, '');
INSERT INTO 'tune' VALUES (2368, NULL, '2012-01-20 12:54:27.748344+00', 'John Peel', 9999, '');
INSERT INTO 'tune' VALUES (2355, NULL, '2012-01-20 12:54:27.709773+00', 'Mrs Kathleen Simpson', 1572, '');
INSERT INTO 'tune' VALUES (4835, NULL, '2012-01-20 12:54:36.325128+00', 'Crail', 9998, '');
INSERT INTO 'tune' VALUES (2356, NULL, '2012-01-20 12:54:27.712678+00', 'John Donald of Coullie', 1598, '');
INSERT INTO 'tune' VALUES (2336, NULL, '2022-12-23 23:38:23.94879+00', 'Jeannie''s Blue E''en', 9999, '');
INSERT INTO 'tune' VALUES (2369, NULL, '2012-01-20 12:54:27.751314+00', 'John Robertson', 3058, '');
INSERT INTO 'tune' VALUES (2357, NULL, '2012-01-20 12:54:27.715812+00', 'John Finlayson''s Jig', 1533, '');
INSERT INTO 'tune' VALUES (4836, NULL, '2012-01-20 12:54:36.328208+00', 'Alma, The', 9999, '');
INSERT INTO 'tune' VALUES (2370, NULL, '2012-01-20 12:54:27.754214+00', 'Cul Na Cnock', 1722, '');
INSERT INTO 'tune' VALUES (2359, NULL, '2012-01-20 12:54:27.721632+00', 'Florence Burns', 1572, '');
INSERT INTO 'tune' VALUES (4837, NULL, '2012-01-20 12:54:36.331129+00', 'An t''Eilean Ard', 9999, '');
INSERT INTO 'tune' VALUES (2360, NULL, '2012-01-20 12:54:27.724527+00', 'Miss Kirsty Bachelor', 1522, '');
INSERT INTO 'tune' VALUES (2371, NULL, '2012-01-20 12:54:27.757148+00', 'Quiraing', 1722, '');
INSERT INTO 'tune' VALUES (2372, NULL, '2012-01-20 12:54:27.760054+00', 'Johnnie Walker', 1505, '');
INSERT INTO 'tune' VALUES (4838, NULL, '2012-01-20 12:54:36.334012+00', 'Glenstriven', 1700, '');
INSERT INTO 'tune' VALUES (2373, NULL, '2012-01-20 12:54:27.762952+00', 'Felicity White', 1722, '');
INSERT INTO 'tune' VALUES (2374, NULL, '2012-01-20 12:54:27.765837+00', 'Jolly Miller, The', 9999, '');
INSERT INTO 'tune' VALUES (2375, NULL, '2012-01-20 12:54:27.768737+00', 'Julia McMahon', 9999, '');
INSERT INTO 'tune' VALUES (4839, NULL, '2012-01-20 12:54:36.336898+00', 'Auld Scots Sangs, The', 9999, '');
INSERT INTO 'tune' VALUES (2376, NULL, '2012-01-20 12:54:27.771816+00', 'Staffin Bay', 1722, '');
INSERT INTO 'tune' VALUES (2377, NULL, '2012-01-20 12:54:27.774722+00', 'Little House Around the Corner, The', 1802, '');
INSERT INTO 'tune' VALUES (2378, NULL, '2012-01-20 12:54:27.777622+00', 'Eddie Shand', 1572, '');
INSERT INTO 'tune' VALUES (4840, NULL, '2012-01-20 12:54:36.339822+00', 'There Grows a Bonnie Brier Bush', 9999, '');
INSERT INTO 'tune' VALUES (2380, NULL, '2012-01-20 12:54:27.783419+00', 'Rachel Discombe', 1572, '');
INSERT INTO 'tune' VALUES (2381, NULL, '2012-01-20 12:54:27.786325+00', 'Keabog', 1512, '');
INSERT INTO 'tune' VALUES (4841, NULL, '2012-01-20 12:54:36.342724+00', 'Bonnie Strathyre', 9999, '');
INSERT INTO 'tune' VALUES (2383, NULL, '2012-01-20 12:54:27.792164+00', 'Kemnay House', 1598, '');
INSERT INTO 'tune' VALUES (2384, NULL, '2012-01-20 12:54:27.795609+00', 'Kempshott Hunt', 9998, '');
INSERT INTO 'tune' VALUES (2385, NULL, '2012-01-20 12:54:27.79949+00', 'Kenneth H Young', 1607, '');
INSERT INTO 'tune' VALUES (4842, NULL, '2012-01-20 12:54:36.345609+00', 'Lay Dee at Dee', 9999, '');
INSERT INTO 'tune' VALUES (2386, NULL, '2012-01-20 12:54:27.80246+00', 'Kettledrum, The', 9999, '');
INSERT INTO 'tune' VALUES (2387, NULL, '2012-01-20 12:54:27.805378+00', 'Killiecrankie', 9999, '');
INSERT INTO 'tune' VALUES (2388, NULL, '2012-01-20 12:54:27.809123+00', 'Kilrenny Jig', 1572, '');
INSERT INTO 'tune' VALUES (4843, NULL, '2012-01-20 12:54:36.348507+00', 'Road to Holligarth, The', 1711, '');
INSERT INTO 'tune' VALUES (2389, NULL, '2012-01-20 12:54:27.812367+00', 'Oor Deencan', 1572, '');
INSERT INTO 'tune' VALUES (2390, NULL, '2012-01-20 12:54:27.815954+00', 'Health to the Ladies, A', 9999, '');
INSERT INTO 'tune' VALUES (4844, NULL, '2012-01-20 12:54:36.351395+00', 'Repulse Bay', 1501, '');
INSERT INTO 'tune' VALUES (2392, NULL, '2012-01-20 12:54:27.822324+00', 'Charlie''s Wedding', 1918, '');
INSERT INTO 'tune' VALUES (2393, NULL, '2012-01-20 12:54:27.825232+00', 'Kinfauns House', 9998, '');
INSERT INTO 'tune' VALUES (4845, NULL, '2012-01-20 12:54:36.354274+00', 'Border Queen, The', 453, '');
INSERT INTO 'tune' VALUES (4846, NULL, '2012-01-20 12:54:36.357167+00', 'Mosstrooper''s Song, The', 1787, '');
INSERT INTO 'tune' VALUES (4847, NULL, '2012-01-20 12:54:36.360055+00', 'Oor Bonnie Border Toon', 9998, '');
INSERT INTO 'tune' VALUES (4848, NULL, '2012-01-20 12:54:36.36296+00', 'Gloria''s Wee Jig', 2961, '');
INSERT INTO 'tune' VALUES (4849, NULL, '2012-01-20 12:54:36.365845+00', 'Dere Street', 1501, '');
INSERT INTO 'tune' VALUES (4850, NULL, '2012-01-20 12:54:36.368733+00', '79th HLI Crossing the Rhine', 9998, '');
INSERT INTO 'tune' VALUES (4851, NULL, '2012-01-20 12:54:36.371625+00', 'Wedding Gift, The', 110, '');
INSERT INTO 'tune' VALUES (4852, NULL, '2012-01-20 12:54:36.374517+00', 'Brechin Lassies', 9998, '');
INSERT INTO 'tune' VALUES (4853, NULL, '2012-01-20 12:54:36.377407+00', 'Shady Lane', 9998, '');
INSERT INTO 'tune' VALUES (2347, NULL, '2012-06-17 14:44:07.898758+00', 'Jim McAllister''s Jig', 1605, '');
INSERT INTO 'tune' VALUES (2415, NULL, '2012-01-20 12:54:27.890869+00', 'Lady Caroline Montague', 1517, '');
INSERT INTO 'tune' VALUES (2394, NULL, '2012-01-20 12:54:27.828206+00', 'Miss Forsyth of Elgin', 9999, '');
INSERT INTO 'tune' VALUES (2395, NULL, '2012-01-20 12:54:27.831134+00', 'Kinkell Braes', 1558, '');
INSERT INTO 'tune' VALUES (2416, NULL, '2012-01-20 12:54:27.893792+00', 'Lady Charlotte Bruce''s Favourite', 1517, '');
INSERT INTO 'tune' VALUES (4855, NULL, '2012-01-20 12:54:36.383187+00', 'Hey for the Hieland Body', 9998, '');
INSERT INTO 'tune' VALUES (2396, NULL, '2012-01-20 12:54:27.834046+00', 'Kinloch of Kinloch', 9999, '');
INSERT INTO 'tune' VALUES (2397, NULL, '2012-01-20 12:54:27.836948+00', 'Kinloss', 1894, '');
INSERT INTO 'tune' VALUES (2417, NULL, '2012-01-20 12:54:27.896694+00', 'Shennachie', 1722, '');
INSERT INTO 'tune' VALUES (4856, NULL, '2012-01-20 12:54:36.386067+00', 'My Own Lass', 9998, '');
INSERT INTO 'tune' VALUES (2398, NULL, '2012-01-20 12:54:27.839869+00', 'Kirk Wynd', 1531, '');
INSERT INTO 'tune' VALUES (2399, NULL, '2012-01-20 12:54:27.842909+00', 'Kirk''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (2418, NULL, '2012-01-20 12:54:27.899586+00', 'Lady Charlotte Murray''s Favourite Jig', 1518, '');
INSERT INTO 'tune' VALUES (4857, NULL, '2012-01-20 12:54:36.388945+00', 'Reel du Forgeron', 9998, '');
INSERT INTO 'tune' VALUES (2400, NULL, '2012-01-20 12:54:27.845808+00', 'Kirkwall Bay', 1558, '');
INSERT INTO 'tune' VALUES (2401, NULL, '2012-01-20 12:54:27.848703+00', 'Jack Stephen''s Jig', 1572, '');
INSERT INTO 'tune' VALUES (2419, NULL, '2012-01-20 12:54:27.902483+00', 'Lady Davidson of Cantray', 445, '');
INSERT INTO 'tune' VALUES (4858, NULL, '2012-01-20 12:54:36.391839+00', 'Down the Tannoch Road', 2362, '');
INSERT INTO 'tune' VALUES (2402, NULL, '2013-08-05 11:15:37.366459+00', 'Kirstie MacCallman''s Favourite', 1700, '');
INSERT INTO 'tune' VALUES (2403, NULL, '2012-01-20 12:54:27.854503+00', 'Kirsty McFarlane', 9999, '');
INSERT INTO 'tune' VALUES (13836, '2018-02-24 09:29:27.551229+00', '2018-02-24 09:29:27.551229+00', 'MacAlister''s Dirk', 9998, '');
INSERT INTO 'tune' VALUES (4859, NULL, '2012-01-20 12:54:36.394726+00', 'Little Burn''t Potato', 9999, '');
INSERT INTO 'tune' VALUES (2404, NULL, '2012-01-20 12:54:27.857392+00', 'My Nannie O''', 9999, '');
INSERT INTO 'tune' VALUES (2405, NULL, '2012-01-20 12:54:27.86124+00', 'Kitten''s Capers', 1605, '');
INSERT INTO 'tune' VALUES (2421, NULL, '2012-01-20 12:54:27.908267+00', 'Lady Dorothea Stewart-Murray''s Wedding March', 1948, '');
INSERT INTO 'tune' VALUES (4860, NULL, '2012-01-20 12:54:36.397616+00', 'Wing and a Prayer, A', 1510, '');
INSERT INTO 'tune' VALUES (2406, NULL, '2012-01-20 12:54:27.864173+00', 'Kitty''s Jig', 1527, '');
INSERT INTO 'tune' VALUES (2407, NULL, '2012-01-20 12:54:27.867108+00', 'Kiwi''s Reel', 1677, '');
INSERT INTO 'tune' VALUES (2422, NULL, '2012-01-20 12:54:27.911166+00', 'Alasdair Cameron''s Reel', 1572, '');
INSERT INTO 'tune' VALUES (4861, NULL, '2012-01-20 12:54:36.400507+00', 'Old Joe Clark', 9999, '');
INSERT INTO 'tune' VALUES (2408, NULL, '2012-01-20 12:54:27.870055+00', 'Captain Grant', 9999, '');
INSERT INTO 'tune' VALUES (2409, NULL, '2012-01-20 12:54:27.873373+00', 'Laddies who fought and won', 1663, '');
INSERT INTO 'tune' VALUES (2423, NULL, '2012-01-20 12:54:27.91409+00', 'Cairdin O''t, The', 9999, '');
INSERT INTO 'tune' VALUES (4862, NULL, '2012-01-20 12:54:36.403387+00', 'Robert MacIntosh''s Fancy', 1510, '');
INSERT INTO 'tune' VALUES (2410, NULL, '2012-01-20 12:54:27.876331+00', 'Earl of Morton''s Jig, The', 1747, '');
INSERT INTO 'tune' VALUES (2411, NULL, '2012-01-20 12:54:27.879248+00', 'Lads O''Dunse, The', 9999, '');
INSERT INTO 'tune' VALUES (4863, NULL, '2012-01-20 12:54:36.406268+00', 'Jig Named Desire, A', 1510, '');
INSERT INTO 'tune' VALUES (2412, NULL, '2012-01-20 12:54:27.882149+00', 'Fiddler''s Friend, The', 1722, '');
INSERT INTO 'tune' VALUES (2413, NULL, '2012-01-20 12:54:27.885061+00', 'Lady Ann Hope', 1476, '');
INSERT INTO 'tune' VALUES (2425, NULL, '2012-01-20 12:54:27.919931+00', 'Lady Harriet Montague''s Favourite', 9998, '');
INSERT INTO 'tune' VALUES (4864, NULL, '2012-01-20 12:54:36.40916+00', 'Lady Gethin', 1882, '');
INSERT INTO 'tune' VALUES (2414, NULL, '2012-01-20 12:54:27.887956+00', 'Lady Carmichael', 9999, '');
INSERT INTO 'tune' VALUES (13837, '2018-02-24 09:29:56.87053+00', '2018-02-24 09:29:56.87053+00', 'Malcolm Macpherson', 9998, '');
INSERT INTO 'tune' VALUES (4865, NULL, '2012-01-20 12:54:36.412331+00', 'Delgaty Castle', 9998, '');
INSERT INTO 'tune' VALUES (2428, NULL, '2012-01-20 12:54:27.928624+00', 'Jimmy Allan''s Favourite', 1572, '');
INSERT INTO 'tune' VALUES (2429, NULL, '2012-01-20 12:54:27.931522+00', 'Maids on the Green, The', 9999, '');
INSERT INTO 'tune' VALUES (2430, NULL, '2012-01-20 12:54:27.934664+00', 'George Wark', 1579, '');
INSERT INTO 'tune' VALUES (4866, NULL, '2012-01-20 12:54:36.415224+00', 'Banks of Nith', 9998, '');
INSERT INTO 'tune' VALUES (2431, NULL, '2012-01-20 12:54:27.93766+00', 'Lady Madeline Sinclair''s Birthday', 9999, '');
INSERT INTO 'tune' VALUES (2432, NULL, '2012-01-20 12:54:27.9406+00', 'Sands of Burrafirth', 1724, '');
INSERT INTO 'tune' VALUES (2433, NULL, '2012-01-20 12:54:27.9435+00', 'Lady Mary Montague', 9999, '');
INSERT INTO 'tune' VALUES (4867, NULL, '2012-01-20 12:54:36.418114+00', 'Mollie McAlpin', 9998, '');
INSERT INTO 'tune' VALUES (2434, NULL, '2012-01-20 12:54:27.94638+00', 'Sir Torquil Munro', 1598, '');
INSERT INTO 'tune' VALUES (4868, NULL, '2012-01-20 12:54:36.420999+00', 'O''Gallagher''s Frolics', 9998, '');
INSERT INTO 'tune' VALUES (2435, NULL, '2012-01-20 12:54:27.949274+00', 'Athole Volunteers Quickstep, The', 9999, '');
INSERT INTO 'tune' VALUES (2436, NULL, '2012-01-20 12:54:27.952169+00', 'Lady Nellie Wemyss', 9999, '');
INSERT INTO 'tune' VALUES (2437, NULL, '2012-01-20 12:54:27.955085+00', 'Lady Ramsay''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (4869, NULL, '2012-01-20 12:54:36.423893+00', 'Miss Ann Stewart of East Craigs', 9998, '');
INSERT INTO 'tune' VALUES (2438, NULL, '2012-01-20 12:54:27.958008+00', 'Lady Spencer Chichester', 9999, '');
INSERT INTO 'tune' VALUES (4870, NULL, '2012-01-20 12:54:36.426786+00', 'Miss Sutherland Gunn', 1512, '');
INSERT INTO 'tune' VALUES (2439, NULL, '2012-01-20 12:54:27.960899+00', 'Mrs Fay Farrell', 9998, '');
INSERT INTO 'tune' VALUES (2440, NULL, '2012-01-20 12:54:27.96384+00', 'Lady Wemyss', 9999, '');
INSERT INTO 'tune' VALUES (2441, NULL, '2012-01-20 12:54:27.966739+00', 'Laird o'' Corrieburn, The', 1585, '');
INSERT INTO 'tune' VALUES (2442, NULL, '2012-01-20 12:54:27.969623+00', 'Laird o'' Drumblair, The', 1512, '');
INSERT INTO 'tune' VALUES (4872, NULL, '2012-01-20 12:54:36.432562+00', 'Miss Lorraine Nelson of Aberdeen', 1575, '');
INSERT INTO 'tune' VALUES (2444, NULL, '2012-01-20 12:54:27.975412+00', 'Mr Charles Stewart, Pettyvaich', 1516, '');
INSERT INTO 'tune' VALUES (4873, NULL, '2012-01-20 12:54:36.435456+00', 'Sylvia Miskoe', 1511, '');
INSERT INTO 'tune' VALUES (4874, NULL, '2012-01-20 12:54:36.438337+00', 'Papa Broon', 1511, '');
INSERT INTO 'tune' VALUES (4875, NULL, '2012-01-20 12:54:36.441222+00', 'Snug in a Blanket', 9998, '');
INSERT INTO 'tune' VALUES (4876, NULL, '2012-01-20 12:54:36.444167+00', 'J.F. Dickie''s Delight', 1750, '');
INSERT INTO 'tune' VALUES (4877, NULL, '2012-01-20 12:54:36.447059+00', 'Reel de mon Voisin', 3720, '');
INSERT INTO 'tune' VALUES (4878, NULL, '2012-01-20 12:54:36.449942+00', 'Red Haired Boy', 9999, '');
INSERT INTO 'tune' VALUES (4879, NULL, '2012-01-20 12:54:36.453201+00', 'Jerusalem Ridge', 2049, '');
INSERT INTO 'tune' VALUES (4880, NULL, '2012-01-20 12:54:36.456143+00', 'Fire in the Rye', 2050, '');
INSERT INTO 'tune' VALUES (12143, '2012-06-12 15:49:23.93965+00', '2012-06-12 15:49:23.93966+00', 'Silver Roses Strathspey', 2197, '');
INSERT INTO 'tune' VALUES (2466, NULL, '2012-01-20 12:54:28.041849+00', 'Norman & Helen Robson', 1508, '');
INSERT INTO 'tune' VALUES (2445, NULL, '2012-01-20 12:54:27.97832+00', 'Mrs Margaret E Campbell', 1543, '');
INSERT INTO 'tune' VALUES (4881, NULL, '2012-01-20 12:54:36.459029+00', 'Stefan''s Folly', 2050, '');
INSERT INTO 'tune' VALUES (2379, NULL, '2016-12-05 01:01:04.026551+00', 'Jackie Coleman''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (2382, NULL, '2017-03-01 23:37:28.740312+00', 'Kelly the Boy from Killane', 9999, '');
INSERT INTO 'tune' VALUES (2391, NULL, '2017-03-04 12:48:53.150019+00', 'Kinclaven Brig', 1598, '');
INSERT INTO 'tune' VALUES (2446, NULL, '2012-01-20 12:54:27.981215+00', 'Lament for Janet', 1631, '');
INSERT INTO 'tune' VALUES (2467, NULL, '2012-01-20 12:54:28.044758+00', 'Let Him Go, Let Him Tarry', 9999, '');
INSERT INTO 'tune' VALUES (2447, NULL, '2012-01-20 12:54:27.98411+00', 'Seafield Strathspey', 1538, '');
INSERT INTO 'tune' VALUES (4882, NULL, '2012-01-20 12:54:36.461913+00', 'Battle of Sherrifmuir, The', 2051, '');
INSERT INTO 'tune' VALUES (2448, NULL, '2012-01-20 12:54:27.987037+00', 'South Inch House', 1728, '');
INSERT INTO 'tune' VALUES (2468, NULL, '2012-01-20 12:54:28.047653+00', 'Life Let Us Cherish', 2878, '');
INSERT INTO 'tune' VALUES (2449, NULL, '2012-01-20 12:54:27.989945+00', 'Legget''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (4883, NULL, '2012-01-20 12:54:36.464805+00', 'Ruaridh Dall', 9998, '');
INSERT INTO 'tune' VALUES (2450, NULL, '2012-01-20 12:54:27.99284+00', 'A M Ritchie', 2402, '');
INSERT INTO 'tune' VALUES (2469, NULL, '2012-01-20 12:54:28.050543+00', 'Light Haired Maid, The', 9999, '');
INSERT INTO 'tune' VALUES (2451, NULL, '2012-01-20 12:54:27.995753+00', 'Archduke John of Austria', 9999, '');
INSERT INTO 'tune' VALUES (4884, NULL, '2012-01-20 12:54:36.46769+00', 'B''fhearr leam fhin gun tigeadh an t''sith', 9998, '');
INSERT INTO 'tune' VALUES (2452, NULL, '2012-01-20 12:54:27.998656+00', 'Angus Fitchet''s Compliments to Ian Powrie', 1554, '');
INSERT INTO 'tune' VALUES (2470, NULL, '2012-01-20 12:54:28.053428+00', 'Little & Large', 1508, '');
INSERT INTO 'tune' VALUES (4885, NULL, '2012-01-20 12:54:36.470601+00', 'Lady Elizabeth', 1510, '');
INSERT INTO 'tune' VALUES (2454, NULL, '2012-01-20 12:54:28.004441+00', 'Auld Reekie', 9999, '');
INSERT INTO 'tune' VALUES (2471, NULL, '2012-01-20 12:54:28.056421+00', 'Little Lad, The', 9999, '');
INSERT INTO 'tune' VALUES (2455, NULL, '2012-01-20 12:54:28.007355+00', 'Gloomie Winter', 2439, '');
INSERT INTO 'tune' VALUES (4886, NULL, '2012-01-20 12:54:36.473507+00', 'Air', 1519, '');
INSERT INTO 'tune' VALUES (2456, NULL, '2012-01-20 12:54:28.012595+00', 'Ould Ireland', 9999, '');
INSERT INTO 'tune' VALUES (2472, NULL, '2012-01-20 12:54:28.059485+00', 'Eagers', 9999, '');
INSERT INTO 'tune' VALUES (2457, NULL, '2012-01-20 12:54:28.015607+00', 'Jean''s Reel', 3058, '');
INSERT INTO 'tune' VALUES (4887, NULL, '2012-01-20 12:54:36.476399+00', 'Gavotte', 1519, '');
INSERT INTO 'tune' VALUES (2473, NULL, '2012-01-20 12:54:28.062485+00', 'Little Pickle', 1632, '');
INSERT INTO 'tune' VALUES (2459, NULL, '2012-01-20 12:54:28.02143+00', 'Fiona Stevenson', 1508, '');
INSERT INTO 'tune' VALUES (4888, NULL, '2012-01-20 12:54:36.479319+00', 'Knotted Chord, The', 2879, '');
INSERT INTO 'tune' VALUES (2474, NULL, '2012-01-20 12:54:28.065646+00', 'Lively Tim', 9999, '');
INSERT INTO 'tune' VALUES (4889, NULL, '2012-01-20 12:54:36.482222+00', 'Crabbit Shona', 2063, '');
INSERT INTO 'tune' VALUES (2460, NULL, '2012-01-20 12:54:28.024321+00', 'Lassie I''ll Come Near Yow', 9999, '');
INSERT INTO 'tune' VALUES (2475, NULL, '2012-01-20 12:54:28.068577+00', 'Liz''s Lilt', 1765, '');
INSERT INTO 'tune' VALUES (4890, NULL, '2012-01-20 12:54:36.485114+00', 'Honors to Karen Tweed', 1511, '');
INSERT INTO 'tune' VALUES (2476, NULL, '2012-01-20 12:54:28.07148+00', 'Lizzie Duncan''s Fancy', 1615, '');
INSERT INTO 'tune' VALUES (2461, NULL, '2012-01-20 12:54:28.027218+00', 'Marie Provan', 1508, '');
INSERT INTO 'tune' VALUES (4891, NULL, '2012-01-20 12:54:36.48802+00', 'Morrison''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (2477, NULL, '2012-01-20 12:54:28.074372+00', 'Prince Arthur''s Highland Fling', 1632, '');
INSERT INTO 'tune' VALUES (4892, NULL, '2012-01-20 12:54:36.490906+00', 'Jessie, The Flower of Dunblane', 9999, '');
INSERT INTO 'tune' VALUES (2462, NULL, '2012-01-20 12:54:28.030112+00', 'Last Time I came O''er the Moor, The', 9999, '');
INSERT INTO 'tune' VALUES (2478, NULL, '2012-01-20 12:54:28.077288+00', 'Loch Ordie', 9999, '');
INSERT INTO 'tune' VALUES (4893, NULL, '2012-01-20 12:54:36.4938+00', 'Captain O''Kane', 1882, '');
INSERT INTO 'tune' VALUES (2479, NULL, '2012-01-20 12:54:28.080188+00', 'I''m the Saftest O'' the Family', 1663, '');
INSERT INTO 'tune' VALUES (2463, NULL, '2012-01-20 12:54:28.033004+00', 'Strathcarron Dancers', 1508, '');
INSERT INTO 'tune' VALUES (4894, NULL, '2012-01-20 12:54:36.496689+00', 'Miss Catherine Chalmers', 1517, '');
INSERT INTO 'tune' VALUES (2480, NULL, '2012-01-20 12:54:28.083424+00', 'Lochaber Gathering, The', 1699, '');
INSERT INTO 'tune' VALUES (2427, NULL, '2014-08-11 22:20:30.382443+00', 'Lady Jemima Johnston', 9999, '');
INSERT INTO 'tune' VALUES (4895, NULL, '2012-01-20 12:54:36.499567+00', 'Lowe''s Reel', 2070, '');
INSERT INTO 'tune' VALUES (2464, NULL, '2012-01-20 12:54:28.035956+00', 'Train, Le', 1618, '');
INSERT INTO 'tune' VALUES (2481, NULL, '2012-01-20 12:54:28.086612+00', 'Blaydon Races', 9999, '');
INSERT INTO 'tune' VALUES (4896, NULL, '2012-01-20 12:54:36.502453+00', 'Broon From Troon', 1501, '');
INSERT INTO 'tune' VALUES (2482, NULL, '2012-01-20 12:54:28.089548+00', 'Lochiel House', 1554, '');
INSERT INTO 'tune' VALUES (2465, NULL, '2012-01-20 12:54:28.038922+00', 'Leaving Barra', 9999, '');
INSERT INTO 'tune' VALUES (4897, NULL, '2012-01-20 12:54:36.505336+00', 'Miss Jane Campbell of Monzie', 9998, '');
INSERT INTO 'tune' VALUES (2483, NULL, '2012-01-20 12:54:28.092614+00', 'Shetland Fiddler''s Society, The', 1623, '');
INSERT INTO 'tune' VALUES (2484, NULL, '2012-01-20 12:54:28.096206+00', 'Long Pond Reel', 1763, '');
INSERT INTO 'tune' VALUES (2485, NULL, '2012-01-20 12:54:28.099777+00', 'Lord Buchan', 9998, '');
INSERT INTO 'tune' VALUES (4899, NULL, '2012-01-20 12:54:36.508222+00', 'None so Pretty', 9998, '');
INSERT INTO 'tune' VALUES (2486, NULL, '2012-01-20 12:54:28.103413+00', 'Lord Duplin', 9999, '');
INSERT INTO 'tune' VALUES (2487, NULL, '2012-01-20 12:54:28.107132+00', 'Groves o'' Larch', 1502, '');
INSERT INTO 'tune' VALUES (2488, NULL, '2012-01-20 12:54:28.11017+00', 'Lewis J Mcleod', 1413, '');
INSERT INTO 'tune' VALUES (4900, NULL, '2012-01-20 12:54:36.511105+00', 'Miss H M Alexander', 9998, '');
INSERT INTO 'tune' VALUES (2489, NULL, '2012-01-20 12:54:28.11475+00', 'Lord Lyndoch', 1199, '');
INSERT INTO 'tune' VALUES (2490, NULL, '2012-01-20 12:54:28.117898+00', 'Merry Girls of Dublin, The', 9998, '');
INSERT INTO 'tune' VALUES (2491, NULL, '2012-01-20 12:54:28.121721+00', 'Norven House', 1623, '');
INSERT INTO 'tune' VALUES (4901, NULL, '2012-01-20 12:54:36.514087+00', 'MacNamara''s Band', 2353, '');
INSERT INTO 'tune' VALUES (2492, NULL, '2012-01-20 12:54:28.124877+00', 'Lord Randall''s Bride', 9999, '');
INSERT INTO 'tune' VALUES (2493, NULL, '2012-01-20 12:54:28.127867+00', 'Lord Randolph''s Bride', 9999, '');
INSERT INTO 'tune' VALUES (2494, NULL, '2012-01-20 12:54:28.130816+00', 'Trip to Tobermory', 1523, '');
INSERT INTO 'tune' VALUES (4902, NULL, '2012-01-20 12:54:36.517006+00', 'Apples in Winter', 2141, '');
INSERT INTO 'tune' VALUES (2495, NULL, '2012-01-20 12:54:28.133724+00', 'Lord Spencer Chichester''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (2496, NULL, '2012-01-20 12:54:28.136732+00', 'MacLeod''s of Mishnish, The', 1668, '');
INSERT INTO 'tune' VALUES (4903, NULL, '2012-01-20 12:54:36.519901+00', 'Osprey, The', 1557, '');
INSERT INTO 'tune' VALUES (4905, NULL, '2012-01-20 12:54:36.525717+00', 'Lothian Lassie, The', 9998, '');
INSERT INTO 'tune' VALUES (4906, NULL, '2012-01-20 12:54:36.528845+00', 'Decadance', 1557, '');
INSERT INTO 'tune' VALUES (4907, NULL, '2012-01-20 12:54:36.531757+00', 'Calum''s Road', 1769, '');
INSERT INTO 'tune' VALUES (12144, '2012-06-12 15:51:11.33454+00', '2012-06-12 15:51:11.334551+00', 'Silver Roses Reel', 2197, '');
INSERT INTO 'tune' VALUES (2497, NULL, '2012-01-20 12:54:28.139759+00', 'Lost Boat, The', 9999, '');
INSERT INTO 'tune' VALUES (2517, NULL, '2012-01-20 12:54:28.212977+00', 'Mrs Oliphant of Condie''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (2498, NULL, '2012-01-20 12:54:28.142726+00', 'Tarbolton Lodge', 9999, '');
INSERT INTO 'tune' VALUES (4908, NULL, '2012-01-20 12:54:36.534664+00', 'Highland Mairi', 9998, '');
INSERT INTO 'tune' VALUES (2499, NULL, '2012-01-20 12:54:28.145756+00', 'Ricky''s Reel', 1613, '');
INSERT INTO 'tune' VALUES (2518, NULL, '2012-01-20 12:54:28.215924+00', 'Macallan', 1512, '');
INSERT INTO 'tune' VALUES (2500, NULL, '2012-01-20 12:54:28.148687+00', 'Mains of Gartly', 9999, '');
INSERT INTO 'tune' VALUES (4909, NULL, '2012-01-20 12:54:36.537561+00', 'Jenny Beaver''s Hat', 9998, '');
INSERT INTO 'tune' VALUES (2501, NULL, '2012-01-20 12:54:28.151588+00', 'Jimmie Lockie''s Jig', 1735, '');
INSERT INTO 'tune' VALUES (2519, NULL, '2012-01-20 12:54:28.218835+00', 'Major John MacLennan', 1699, '');
INSERT INTO 'tune' VALUES (2502, NULL, '2012-01-20 12:54:28.16923+00', 'Lumsden''s Rant', 9999, '');
INSERT INTO 'tune' VALUES (4910, NULL, '2012-01-20 12:54:36.54045+00', 'My Friend Franz', 1557, '');
INSERT INTO 'tune' VALUES (2503, NULL, '2012-01-20 12:54:28.172317+00', 'Luss Road', 9999, '');
INSERT INTO 'tune' VALUES (2520, NULL, '2012-01-20 12:54:28.22175+00', 'Major Mackie', 1452, '');
INSERT INTO 'tune' VALUES (2504, NULL, '2012-01-20 12:54:28.175233+00', 'Lynmore Jig, The', 1531, '');
INSERT INTO 'tune' VALUES (4911, NULL, '2012-01-20 12:54:36.543336+00', 'Isle of Innesfree, The', 3402, '');
INSERT INTO 'tune' VALUES (2505, NULL, '2012-01-20 12:54:28.178137+00', 'MacDonald''s Awa Tae the Wars', 9999, '');
INSERT INTO 'tune' VALUES (2521, NULL, '2012-01-20 12:54:28.224643+00', 'Major Moir', 9999, '');
INSERT INTO 'tune' VALUES (2506, NULL, '2012-01-20 12:54:28.181032+00', 'King of Spades', 1502, '');
INSERT INTO 'tune' VALUES (4912, NULL, '2012-01-20 12:54:36.546225+00', 'MacPherson''s Lament', 2139, '');
INSERT INTO 'tune' VALUES (2507, NULL, '2012-01-20 12:54:28.183929+00', 'Bridge of Brechin, The', 1632, '');
INSERT INTO 'tune' VALUES (2522, NULL, '2012-01-20 12:54:28.22755+00', 'Major Thomas of Cairnleith', 1522, '');
INSERT INTO 'tune' VALUES (2508, NULL, '2012-01-20 12:54:28.186821+00', 'Mrs MacDonald of Clan Ranald', 1517, '');
INSERT INTO 'tune' VALUES (4913, NULL, '2012-01-20 12:54:36.549113+00', 'Sabhal Ian ''ic Uisdean', 9999, '');
INSERT INTO 'tune' VALUES (2523, NULL, '2012-01-20 12:54:28.230454+00', 'Malcolm Beattie (of Galashiels) - The Piano Tuner', 1502, '');
INSERT INTO 'tune' VALUES (2510, NULL, '2012-01-20 12:54:28.192639+00', 'Telegraph Post, The', 9999, '');
INSERT INTO 'tune' VALUES (4914, NULL, '2012-01-20 12:54:36.55202+00', 'Sud Mac A'' Gharraidh', 9998, '');
INSERT INTO 'tune' VALUES (2511, NULL, '2012-01-20 12:54:28.195534+00', 'Bride''s Reel, The', 1512, '');
INSERT INTO 'tune' VALUES (2524, NULL, '2012-01-20 12:54:28.233351+00', 'Malcolm Ross', 1522, '');
INSERT INTO 'tune' VALUES (2512, NULL, '2012-01-20 12:54:28.198444+00', 'Madge Bayne', 1658, '');
INSERT INTO 'tune' VALUES (4915, NULL, '2012-01-20 12:54:36.554918+00', 'He-Ro-Hi-Ro', 9998, '');
INSERT INTO 'tune' VALUES (2513, NULL, '2012-01-20 12:54:28.201338+00', 'Harlequin, The', 9999, '');
INSERT INTO 'tune' VALUES (2525, NULL, '2012-01-20 12:54:28.236315+00', 'Cookie Shine', 9999, '');
INSERT INTO 'tune' VALUES (2514, NULL, '2012-01-20 12:54:28.204278+00', 'Maggie Brown''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (4916, NULL, '2012-01-20 12:54:36.557809+00', 'Lonely am I', 9998, '');
INSERT INTO 'tune' VALUES (2515, NULL, '2012-01-20 12:54:28.207176+00', 'Face me up', 9999, '');
INSERT INTO 'tune' VALUES (2526, NULL, '2012-01-20 12:54:28.239273+00', 'Margaret Brown''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (2516, NULL, '2012-01-20 12:54:28.210076+00', 'Mrs Baird of Newbyth', 1518, '');
INSERT INTO 'tune' VALUES (4917, NULL, '2012-01-20 12:54:36.560699+00', 'Bla''berries', 9998, '');
INSERT INTO 'tune' VALUES (2527, NULL, '2012-01-20 12:54:28.242211+00', 'March to the Battlefield, The', 9999, '');
INSERT INTO 'tune' VALUES (2528, NULL, '2012-01-20 12:54:28.245135+00', 'Miss Stewart of Garth', 9999, '');
INSERT INTO 'tune' VALUES (4918, NULL, '2012-01-20 12:54:36.56359+00', 'Kelly Ann Scott', 2085, '');
INSERT INTO 'tune' VALUES (2529, NULL, '2012-01-20 12:54:28.24803+00', 'Baker''s Jig, The', 9999, '');
INSERT INTO 'tune' VALUES (2530, NULL, '2012-01-20 12:54:28.250915+00', 'Lilting Fisherman, The', 9999, '');
INSERT INTO 'tune' VALUES (4919, NULL, '2012-01-20 12:54:36.56648+00', 'Amanda Kathleen Scott', 2085, '');
INSERT INTO 'tune' VALUES (2532, NULL, '2012-01-20 12:54:28.256905+00', 'Market Chorus', 9999, '');
INSERT INTO 'tune' VALUES (2533, NULL, '2012-01-20 12:54:28.259936+00', 'Marketplace in Inverness', 9999, '');
INSERT INTO 'tune' VALUES (2534, NULL, '2012-01-20 12:54:28.262869+00', 'Marquis of Huntly', 1516, '');
INSERT INTO 'tune' VALUES (4920, NULL, '2012-01-20 12:54:36.569363+00', 'Victoria Jean Brown', 2085, '');
INSERT INTO 'tune' VALUES (4921, NULL, '2012-01-20 12:54:36.572252+00', 'Fred Collins (the Drummer)', 2085, '');
INSERT INTO 'tune' VALUES (2536, NULL, '2012-01-20 12:54:28.268848+00', 'Inver Lasses', 9999, '');
INSERT INTO 'tune' VALUES (2537, NULL, '2012-01-20 12:54:28.27176+00', 'Mary Carson', 1736, '');
INSERT INTO 'tune' VALUES (2538, NULL, '2012-01-20 12:54:28.27465+00', 'Mary Gavin', 9999, '');
INSERT INTO 'tune' VALUES (4922, NULL, '2012-01-20 12:54:36.575163+00', 'Catherine Shaw''s Quickstep', 2085, '');
INSERT INTO 'tune' VALUES (2539, NULL, '2012-01-20 12:54:28.277564+00', 'O Lassie art thou Sleeping yet?', 9999, '');
INSERT INTO 'tune' VALUES (2540, NULL, '2012-01-20 12:54:28.280469+00', 'Mary Scott, Flower of Yarrow', 9999, '');
INSERT INTO 'tune' VALUES (2541, NULL, '2012-01-20 12:54:28.283427+00', 'Mary with the Witchin'' Eyes', 9999, '');
INSERT INTO 'tune' VALUES (4923, NULL, '2012-01-20 12:54:36.578051+00', 'Ashokan Farewell', 2086, '');
INSERT INTO 'tune' VALUES (2542, NULL, '2012-01-20 12:54:28.286352+00', 'New Kelvin Bridge, The', 9999, '');
INSERT INTO 'tune' VALUES (2543, NULL, '2012-01-20 12:54:28.289282+00', 'Forth Bridge, The - Strathspey', 1427, '');
INSERT INTO 'tune' VALUES (2544, NULL, '2012-01-20 12:54:28.292226+00', 'Master Francis Sitwell', 1517, '');
INSERT INTO 'tune' VALUES (4924, NULL, '2012-01-20 12:54:36.580943+00', 'Tobermory', 1512, '');
INSERT INTO 'tune' VALUES (2545, NULL, '2012-01-20 12:54:28.295126+00', 'Miller o'' Dervil, The', 1925, '');
INSERT INTO 'tune' VALUES (2546, NULL, '2012-01-20 12:54:28.298013+00', 'May and Ian Thomson', 1611, '');
INSERT INTO 'tune' VALUES (2547, NULL, '2012-01-20 12:54:28.301006+00', 'Ivy Leaf, The', 9999, '');
INSERT INTO 'tune' VALUES (4925, NULL, '2012-01-20 12:54:36.58384+00', 'Dominion Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (2549, NULL, '2012-01-20 12:54:28.306912+00', 'MacPhail''s Reel', 1677, '');
INSERT INTO 'tune' VALUES (2550, NULL, '2012-01-20 12:54:28.309799+00', 'Graham''s Rant', 9999, '');
INSERT INTO 'tune' VALUES (4926, NULL, '2012-01-20 12:54:36.586805+00', 'Gallant Tipperary', 2135, '');
INSERT INTO 'tune' VALUES (4927, NULL, '2012-01-20 12:54:36.589696+00', 'Jack of All Trades', 9999, '');
INSERT INTO 'tune' VALUES (4928, NULL, '2012-01-20 12:54:36.592588+00', 'Caledonian Rant, The', 2087, '');
INSERT INTO 'tune' VALUES (4929, NULL, '2012-01-20 12:54:36.595487+00', 'Jim Boulton''s Fancy', 2145, '');
INSERT INTO 'tune' VALUES (4930, NULL, '2012-01-20 12:54:36.59837+00', 'Shillelah, The', 9999, '');
INSERT INTO 'tune' VALUES (4931, NULL, '2012-01-20 12:54:36.601259+00', 'Flanagan''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (4932, NULL, '2012-01-20 12:54:36.604153+00', 'Our Boys''', 9999, '');
INSERT INTO 'tune' VALUES (4933, NULL, '2012-01-20 12:54:36.607046+00', 'Parnell''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (12145, '2012-06-12 15:51:41.486908+00', '2012-06-12 15:51:41.486919+00', 'Andrew Davidson''s Reel', 1576, '');
INSERT INTO 'tune' VALUES (2551, NULL, '2012-01-20 12:54:28.312816+00', 'Merlion, The', 1501, '');
INSERT INTO 'tune' VALUES (2573, NULL, '2012-01-20 12:54:28.388744+00', 'Miss Beatrice Whiteford', 1576, '');
INSERT INTO 'tune' VALUES (2552, NULL, '2012-01-20 12:54:28.315763+00', 'Miss Wedderburn', 9999, '');
INSERT INTO 'tune' VALUES (2553, NULL, '2012-01-20 12:54:28.31866+00', 'Michael MacKenzie', 1693, '');
INSERT INTO 'tune' VALUES (4934, NULL, '2012-01-20 12:54:36.609926+00', 'Tin-Ware Lass, The', 9999, '');
INSERT INTO 'tune' VALUES (2574, NULL, '2012-01-20 12:54:28.391649+00', 'Ruby Hunter', 1866, '');
INSERT INTO 'tune' VALUES (2554, NULL, '2012-01-20 12:54:28.321584+00', 'Mickie Ainsworth', 1623, '');
INSERT INTO 'tune' VALUES (2555, NULL, '2012-01-20 12:54:28.324496+00', 'Jack Broke da Prison Door', 3288, '');
INSERT INTO 'tune' VALUES (4935, NULL, '2012-01-20 12:54:36.612824+00', 'Kissing Ring, The', 9999, '');
INSERT INTO 'tune' VALUES (2575, NULL, '2012-01-20 12:54:28.394544+00', 'New Ashludie Rant, The', 1554, '');
INSERT INTO 'tune' VALUES (2556, NULL, '2012-01-20 12:54:28.327432+00', 'Littlejohn''s Hame', 1512, '');
INSERT INTO 'tune' VALUES (2557, NULL, '2012-01-20 12:54:28.330348+00', 'Inverurie', 9999, '');
INSERT INTO 'tune' VALUES (4936, NULL, '2012-01-20 12:54:36.615714+00', 'Fuddlin'' Boys', 9999, '');
INSERT INTO 'tune' VALUES (2576, NULL, '2012-01-20 12:54:28.397438+00', 'Lochiel''s Welcome to Glasgow', 1398, '');
INSERT INTO 'tune' VALUES (2558, NULL, '2012-01-20 12:54:28.333252+00', 'Mike McCartan''s Reel', 1531, '');
INSERT INTO 'tune' VALUES (2559, NULL, '2012-01-20 12:54:28.336147+00', 'Iron Man, The', 1512, '');
INSERT INTO 'tune' VALUES (4937, NULL, '2012-01-20 12:54:36.618645+00', 'Larry Lynch''s Hornpipe', 2145, '');
INSERT INTO 'tune' VALUES (2560, NULL, '2012-01-20 12:54:28.346881+00', 'Reith''s Clarionet', 9999, '');
INSERT INTO 'tune' VALUES (2561, NULL, '2012-01-20 12:54:28.351165+00', 'Crowhillock', 1897, '');
INSERT INTO 'tune' VALUES (4938, NULL, '2012-01-20 12:54:36.621534+00', 'Texarkana Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (2578, NULL, '2012-01-20 12:54:28.403341+00', 'Madam Frederick', 1516, '');
INSERT INTO 'tune' VALUES (2562, NULL, '2012-01-20 12:54:28.354217+00', 'Milltimber Jig, The', 1507, '');
INSERT INTO 'tune' VALUES (2563, NULL, '2012-01-20 12:54:28.357133+00', 'Lads of Tain, The', 9999, '');
INSERT INTO 'tune' VALUES (4939, NULL, '2012-01-20 12:54:36.624433+00', 'Inverness Gathering, The', 9999, '');
INSERT INTO 'tune' VALUES (2579, NULL, '2012-01-20 12:54:28.40627+00', 'Air From Haydn', 1665, '');
INSERT INTO 'tune' VALUES (2564, NULL, '2012-01-20 12:54:28.36088+00', 'Miss Ada Crawford', 9999, '');
INSERT INTO 'tune' VALUES (2580, NULL, '2012-01-20 12:54:28.409527+00', 'Miss Catriona Mhairi Robertson MacPhail', 1527, '');
INSERT INTO 'tune' VALUES (2566, NULL, '2012-01-20 12:54:28.36738+00', 'Miss Agnes Watt', 1522, '');
INSERT INTO 'tune' VALUES (2567, NULL, '2012-01-20 12:54:28.370495+00', 'Miss Alison Little', 1647, '');
INSERT INTO 'tune' VALUES (4941, NULL, '2012-01-20 12:54:36.630203+00', 'Fill Up The Bowl', 9998, '');
INSERT INTO 'tune' VALUES (2581, NULL, '2012-01-20 12:54:28.412479+00', 'Miss Euphemia Lowe''s Jig', 1516, '');
INSERT INTO 'tune' VALUES (2568, NULL, '2012-01-20 12:54:28.373409+00', 'Miss Amelia Oliphant Gask', 9999, '');
INSERT INTO 'tune' VALUES (2569, NULL, '2012-01-20 12:54:28.376297+00', 'Inverness Rant, The', 9999, '');
INSERT INTO 'tune' VALUES (4942, NULL, '2012-01-20 12:54:36.633094+00', 'Taladh', 9999, '');
INSERT INTO 'tune' VALUES (2582, NULL, '2012-01-20 12:54:28.415384+00', 'Lady Charlotte Murray', 1518, '');
INSERT INTO 'tune' VALUES (2571, NULL, '2012-01-20 12:54:28.382183+00', 'Miss Ann Rutherford', 1687, '');
INSERT INTO 'tune' VALUES (4943, NULL, '2012-01-20 12:54:36.635986+00', 'Trip to Galway', 9999, '');
INSERT INTO 'tune' VALUES (2583, NULL, '2012-01-20 12:54:28.418276+00', 'Clay Braes', 1522, '');
INSERT INTO 'tune' VALUES (2572, NULL, '2012-01-20 12:54:28.385829+00', 'Earl of Lauderdale, The', 1518, '');
INSERT INTO 'tune' VALUES (2584, NULL, '2012-01-20 12:54:28.421168+00', 'Miss Diane Cunningham', 1521, '');
INSERT INTO 'tune' VALUES (4944, NULL, '2012-01-20 12:54:36.638887+00', 'Miss Nancy Girdwood of Tillicoutry', 709, '');
INSERT INTO 'tune' VALUES (2585, NULL, '2012-01-20 12:54:28.42447+00', 'Miss Diane Milne', 1626, '');
INSERT INTO 'tune' VALUES (2586, NULL, '2012-01-20 12:54:28.427644+00', 'Miss Catriona Henderson', 1522, '');
INSERT INTO 'tune' VALUES (2587, NULL, '2012-01-20 12:54:28.430587+00', 'Miss Doreen Lambert', 1554, '');
INSERT INTO 'tune' VALUES (4945, NULL, '2012-01-20 12:54:36.641773+00', 'George Walker', 9999, '');
INSERT INTO 'tune' VALUES (2588, NULL, '2012-01-20 12:54:28.433611+00', 'Miss Dorothy Leurs', 1679, '');
INSERT INTO 'tune' VALUES (2589, NULL, '2012-01-20 12:54:28.43652+00', 'Miss Drummond Smith''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (2590, NULL, '2012-01-20 12:54:28.439453+00', 'Miss Eleonora Robertson', 1519, '');
INSERT INTO 'tune' VALUES (4946, NULL, '2012-01-20 12:54:36.644663+00', 'George Kinloch of Kinloch', 9999, '');
INSERT INTO 'tune' VALUES (2591, NULL, '2012-01-20 12:54:28.44236+00', 'Dick Noden''s Strathspey', 1526, '');
INSERT INTO 'tune' VALUES (4947, NULL, '2012-01-20 12:54:36.64755+00', 'Don William''s Steeplechase', 709, '');
INSERT INTO 'tune' VALUES (2593, NULL, '2012-01-20 12:54:28.448254+00', 'Miss Ena Wilson', 1733, '');
INSERT INTO 'tune' VALUES (2594, NULL, '2012-01-20 12:54:28.451334+00', 'Miss F Powers', 9999, '');
INSERT INTO 'tune' VALUES (4948, NULL, '2012-01-20 12:54:36.650442+00', 'Biolog', 709, '');
INSERT INTO 'tune' VALUES (2595, NULL, '2012-01-20 12:54:28.454286+00', 'Doris Buchanan''s Strathspey', 1526, '');
INSERT INTO 'tune' VALUES (13838, '2018-02-24 09:30:31.441533+00', '2018-02-24 09:30:31.441533+00', 'Miss Proud', 9998, '');
INSERT INTO 'tune' VALUES (2597, NULL, '2012-01-20 12:54:28.460096+00', 'Miss Gordon of Park', 1516, '');
INSERT INTO 'tune' VALUES (4949, NULL, '2012-01-20 12:54:36.653334+00', 'Royal Irish', 9999, '');
INSERT INTO 'tune' VALUES (2598, NULL, '2012-01-20 12:54:28.463+00', 'Leaving Skye', 9999, '');
INSERT INTO 'tune' VALUES (2531, NULL, '2019-06-07 12:31:21.071574+00', 'Margaret''s Fancy', 1919, '');
INSERT INTO 'tune' VALUES (2599, NULL, '2012-01-20 12:54:28.465994+00', 'Terry Rice''s Strathspey', 1526, '');
INSERT INTO 'tune' VALUES (2600, NULL, '2012-01-20 12:54:28.468902+00', 'Sour Plumbs in Gallashiels', 9998, '');
INSERT INTO 'tune' VALUES (4950, NULL, '2012-01-20 12:54:36.65623+00', 'Harrington''s Hall', 9999, '');
INSERT INTO 'tune' VALUES (2601, NULL, '2012-01-20 12:54:28.471814+00', 'Miss Hannay''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (2602, NULL, '2012-01-20 12:54:28.474763+00', 'Just a tune', 1508, '');
INSERT INTO 'tune' VALUES (4951, NULL, '2012-01-20 12:54:36.659633+00', 'Elizabeth Grace Bartlett', 709, '');
INSERT INTO 'tune' VALUES (4953, NULL, '2012-01-20 12:54:36.665521+00', 'Cape Rollers', 1502, '');
INSERT INTO 'tune' VALUES (4954, NULL, '2012-01-20 12:54:36.66842+00', 'Braes of Gleniffer', 9999, '');
INSERT INTO 'tune' VALUES (4955, NULL, '2012-01-20 12:54:36.671317+00', 'Australian Homestead', 9999, '');
INSERT INTO 'tune' VALUES (4956, NULL, '2012-01-20 12:54:36.674245+00', 'Skip to My Lou', 9999, '');
INSERT INTO 'tune' VALUES (4957, NULL, '2012-01-20 12:54:36.677203+00', 'Scotian''s Waltz, The', 709, '');
INSERT INTO 'tune' VALUES (4958, NULL, '2012-01-20 12:54:36.680153+00', 'Wha Will Follow Charlie?', 9998, '');
INSERT INTO 'tune' VALUES (4959, NULL, '2012-01-20 12:54:36.683055+00', 'Ayr Races', 1974, '');
INSERT INTO 'tune' VALUES (12146, '2012-06-12 15:53:44.521529+00', '2012-06-12 15:53:44.521544+00', 'Robert Bateson''s Reel', 1590, '');
INSERT INTO 'tune' VALUES (2623, NULL, '2012-01-20 12:54:28.538569+00', 'Miss Ross', 1516, '');
INSERT INTO 'tune' VALUES (2603, NULL, '2012-01-20 12:54:28.477741+00', 'Miss Jean Cattanach', 1531, '');
INSERT INTO 'tune' VALUES (4960, NULL, '2012-01-20 12:54:36.685938+00', 'I''m a Young Man', 9998, '');
INSERT INTO 'tune' VALUES (2604, NULL, '2012-01-20 12:54:28.480646+00', 'David''s Fancy', 1502, '');
INSERT INTO 'tune' VALUES (2624, NULL, '2012-01-20 12:54:28.54158+00', 'Miss Rough of Longbank', 1930, '');
INSERT INTO 'tune' VALUES (2605, NULL, '2012-01-20 12:54:28.483542+00', 'Miss Kay Rose', 1527, '');
INSERT INTO 'tune' VALUES (4961, NULL, '2012-01-20 12:54:36.688832+00', 'James Murray of Abercarney', 1518, '');
INSERT INTO 'tune' VALUES (2606, NULL, '2012-01-20 12:54:28.486865+00', 'Sparkenhoe Circle', 1508, '');
INSERT INTO 'tune' VALUES (2625, NULL, '2012-01-20 12:54:28.544538+00', 'Miss S J Marshall', 1525, '');
INSERT INTO 'tune' VALUES (2607, NULL, '2012-01-20 12:54:28.489948+00', 'Rouken Glen', 9998, '');
INSERT INTO 'tune' VALUES (4962, NULL, '2012-01-20 12:54:36.691729+00', 'Griffith Ap Cyan''s Delight', 9998, '');
INSERT INTO 'tune' VALUES (2608, NULL, '2012-01-20 12:54:28.492863+00', 'Miss Margaret Graham of Gartmore''s Favourite', 1519, '');
INSERT INTO 'tune' VALUES (2626, NULL, '2012-01-20 12:54:28.547705+00', 'Claverhouse Reel', 1558, '');
INSERT INTO 'tune' VALUES (2609, NULL, '2012-01-20 12:54:28.495768+00', 'Miss Marianne Oliphant of Rossie', 1519, '');
INSERT INTO 'tune' VALUES (4963, NULL, '2012-01-20 12:54:36.694621+00', 'Kiss Me Fast', 1517, '');
INSERT INTO 'tune' VALUES (2610, NULL, '2012-01-20 12:54:28.499103+00', 'Miss Heather E Lyon', 1657, '');
INSERT INTO 'tune' VALUES (2627, NULL, '2012-01-20 12:54:28.550674+00', 'Miss Sharp''s Fancy', 1731, '');
INSERT INTO 'tune' VALUES (2611, NULL, '2012-01-20 12:54:28.502206+00', 'Bonnie Bridge', 9999, '');
INSERT INTO 'tune' VALUES (4964, NULL, '2012-01-20 12:54:36.697526+00', 'Laird of Macfarlane''s Strathspey', 1518, '');
INSERT INTO 'tune' VALUES (2612, NULL, '2012-01-20 12:54:28.505123+00', 'Miss Mary Gavin', 9999, '');
INSERT INTO 'tune' VALUES (2628, NULL, '2012-01-20 12:54:28.553663+00', 'Miss Shepherd', 1512, '');
INSERT INTO 'tune' VALUES (2613, NULL, '2012-01-20 12:54:28.50802+00', 'Miss McLauchlan''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (4965, NULL, '2012-01-20 12:54:36.70045+00', 'Douglas Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (2629, NULL, '2012-01-20 12:54:28.556559+00', 'Ron Gonnella', 1527, '');
INSERT INTO 'tune' VALUES (5046, NULL, '2012-01-20 12:54:36.948868+00', 'Hanover Square', 9998, '');
INSERT INTO 'tune' VALUES (4940, NULL, '2014-11-06 16:04:36.018731+00', 'Dundee Military Tattoo', 1579, '');
INSERT INTO 'tune' VALUES (2570, NULL, '2014-11-18 01:08:46.111409+00', 'Miss Ann Monro', 1519, '');
INSERT INTO 'tune' VALUES (4966, NULL, '2012-01-20 12:54:36.703345+00', 'Treasure of Sierra Madre', 1745, '');
INSERT INTO 'tune' VALUES (2616, NULL, '2012-01-20 12:54:28.516972+00', 'Miss Moira Sinclair', 1527, '');
INSERT INTO 'tune' VALUES (2630, NULL, '2012-01-20 12:54:28.559453+00', 'Miss Stewart Robertson', 9999, '');
INSERT INTO 'tune' VALUES (2617, NULL, '2012-01-20 12:54:28.519889+00', 'Sybil Shaw', 1502, '');
INSERT INTO 'tune' VALUES (4967, NULL, '2012-01-20 12:54:36.706226+00', 'Bonnie George Campbell', 9999, '');
INSERT INTO 'tune' VALUES (2618, NULL, '2012-01-20 12:54:28.523029+00', 'Ian James Wilson', 1526, '');
INSERT INTO 'tune' VALUES (2631, NULL, '2012-01-20 12:54:28.562348+00', 'Miss Stewart of Grantully', 1518, '');
INSERT INTO 'tune' VALUES (2619, NULL, '2012-01-20 12:54:28.526024+00', 'Wandering Willie', 1707, '');
INSERT INTO 'tune' VALUES (4968, NULL, '2012-01-20 12:54:36.709117+00', 'Jimmy''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (2620, NULL, '2012-01-20 12:54:28.528956+00', 'Miss Rattray', 9999, '');
INSERT INTO 'tune' VALUES (2632, NULL, '2012-01-20 12:54:28.56524+00', 'River Ugie', 1508, '');
INSERT INTO 'tune' VALUES (4969, NULL, '2012-01-20 12:54:36.712007+00', 'Eva''s Long Step', 2100, '');
INSERT INTO 'tune' VALUES (2622, NULL, '2012-01-20 12:54:28.535663+00', 'Miss Rose of Tarlogie', 9999, '');
INSERT INTO 'tune' VALUES (2633, NULL, '2012-01-20 12:54:28.568133+00', 'Bob Ritchie', 1508, '');
INSERT INTO 'tune' VALUES (2634, NULL, '2012-01-20 12:54:28.571589+00', 'Earl of Errol', 2676, '');
INSERT INTO 'tune' VALUES (4970, NULL, '2012-01-20 12:54:36.714926+00', 'Camp of Pleasure', 9998, '');
INSERT INTO 'tune' VALUES (2635, NULL, '2012-01-20 12:54:28.574606+00', 'Miss Suzanne Barbour', 1527, '');
INSERT INTO 'tune' VALUES (2636, NULL, '2012-01-20 12:54:28.577525+00', 'Miss Trotter', 1937, '');
INSERT INTO 'tune' VALUES (2637, NULL, '2012-01-20 12:54:28.58112+00', 'Miss Viola Robertson', 1527, '');
INSERT INTO 'tune' VALUES (2638, NULL, '2012-01-20 12:54:28.584388+00', 'Moffat Ram, The', 1502, '');
INSERT INTO 'tune' VALUES (2639, NULL, '2012-01-20 12:54:28.587325+00', 'Monarch of the Glen', 1531, '');
INSERT INTO 'tune' VALUES (4972, NULL, '2012-01-20 12:54:36.720724+00', 'Oh My Jock McKay', 9998, '');
INSERT INTO 'tune' VALUES (2640, NULL, '2012-01-20 12:54:28.590537+00', 'Fandango, The', 9998, '');
INSERT INTO 'tune' VALUES (2641, NULL, '2012-01-20 12:54:28.593657+00', 'Mooncoin Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (4973, NULL, '2012-01-20 12:54:36.723621+00', 'MacLeod''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (2642, NULL, '2012-01-20 12:54:28.596817+00', 'Mopsi Don', 9999, '');
INSERT INTO 'tune' VALUES (4974, NULL, '2012-01-20 12:54:36.726651+00', 'Lady Loudon', 9999, '');
INSERT INTO 'tune' VALUES (2644, NULL, '2012-01-20 12:54:28.602637+00', 'Morag Hutton''s Strathspey', 1611, '');
INSERT INTO 'tune' VALUES (2645, NULL, '2012-01-20 12:54:28.605531+00', 'Morag of Dunvegan', 1673, '');
INSERT INTO 'tune' VALUES (2646, NULL, '2012-01-20 12:54:28.608435+00', 'Moulin Dhu', 9999, '');
INSERT INTO 'tune' VALUES (4975, NULL, '2012-01-20 12:54:36.72962+00', 'Frank Jamieson', 1623, '');
INSERT INTO 'tune' VALUES (2647, NULL, '2012-01-20 12:54:28.611339+00', 'Mrs Anna Crawford', 1713, 'Composed 1990.');
INSERT INTO 'tune' VALUES (2648, NULL, '2012-01-20 12:54:28.614325+00', 'Mr & Mrs John Corbett', 1607, '');
INSERT INTO 'tune' VALUES (2649, NULL, '2012-01-20 12:54:28.617229+00', 'Mr & Mrs McDonald of Bedford Road', 1502, '');
INSERT INTO 'tune' VALUES (4976, NULL, '2012-01-20 12:54:36.732529+00', 'Bob''s Shaggy Dug', 2223, '');
INSERT INTO 'tune' VALUES (2651, NULL, '2012-01-20 12:54:28.623558+00', 'Mr Busbie Maitland', 1517, '');
INSERT INTO 'tune' VALUES (2652, NULL, '2012-01-20 12:54:28.626464+00', 'Mr Charles Graham''s Welcome Home', 1747, '');
INSERT INTO 'tune' VALUES (4977, NULL, '2012-01-20 12:54:36.735433+00', 'Donald McLeod', 2224, '');
INSERT INTO 'tune' VALUES (2653, NULL, '2012-01-20 12:54:28.629359+00', 'Mr J S Skinner', 1748, '');
INSERT INTO 'tune' VALUES (2654, NULL, '2012-01-20 12:54:28.632295+00', 'Mr Martin', 1512, '');
INSERT INTO 'tune' VALUES (4978, NULL, '2012-01-20 12:54:36.73832+00', 'CTS Express', 9999, '');
INSERT INTO 'tune' VALUES (4979, NULL, '2012-01-20 12:54:36.741461+00', 'Bonnie Lass of Scotland', 1640, '');
INSERT INTO 'tune' VALUES (4980, NULL, '2012-01-20 12:54:36.744365+00', 'Aviemore', 1640, '');
INSERT INTO 'tune' VALUES (4981, NULL, '2012-01-20 12:54:36.747352+00', 'Lovely Glens of Angus', 9998, '');
INSERT INTO 'tune' VALUES (4982, NULL, '2012-01-20 12:54:36.750265+00', 'Pipe Major Wille McLean', 1910, '');
INSERT INTO 'tune' VALUES (4983, NULL, '2012-01-20 12:54:36.753159+00', 'Down Express, The', 9999, '');
INSERT INTO 'tune' VALUES (4984, NULL, '2012-01-20 12:54:36.757094+00', 'Jeannie Black', 2691, '');
INSERT INTO 'tune' VALUES (4985, NULL, '2012-01-20 12:54:36.760015+00', 'Dora MacLeod', 2138, '');
INSERT INTO 'tune' VALUES (2655, NULL, '2012-01-20 12:54:28.635231+00', 'Gladys Kindness', 1520, '');
INSERT INTO 'tune' VALUES (2676, NULL, '2012-01-20 12:54:28.704255+00', 'Mrs Jean Stalker', 1679, '');
INSERT INTO 'tune' VALUES (4986, NULL, '2012-01-20 12:54:36.762969+00', 'Eilidh', 1985, '');
INSERT INTO 'tune' VALUES (2656, NULL, '2012-01-20 12:54:28.638115+00', 'Dr Gordon of Rathbone', 9999, '');
INSERT INTO 'tune' VALUES (2657, NULL, '2012-01-20 12:54:28.641006+00', 'Drunken Cruik and Duke', 1592, '');
INSERT INTO 'tune' VALUES (4952, NULL, '2022-03-01 23:42:11.501261+00', 'Lass of Waverley', 709, '');
INSERT INTO 'tune' VALUES (2677, NULL, '2012-01-20 12:54:28.707425+00', 'Mrs Jimmy Shand', 1558, '');
INSERT INTO 'tune' VALUES (4987, NULL, '2012-01-20 12:54:36.76589+00', 'Leaving Stornoway', 9999, '');
INSERT INTO 'tune' VALUES (2659, NULL, '2012-01-20 12:54:28.650491+00', 'Shilling Hill', 1525, '');
INSERT INTO 'tune' VALUES (2678, NULL, '2012-01-20 12:54:28.71054+00', 'Mrs MacDonald', 9999, '');
INSERT INTO 'tune' VALUES (4988, NULL, '2012-01-20 12:54:36.768803+00', 'Sine Bhan', 1820, '');
INSERT INTO 'tune' VALUES (2660, NULL, '2012-01-20 12:54:28.653613+00', 'Mrs Agnes Watt', 1522, '');
INSERT INTO 'tune' VALUES (2661, NULL, '2012-01-20 12:54:28.65656+00', 'Spootiskerry', 1724, '');
INSERT INTO 'tune' VALUES (2679, NULL, '2012-01-20 12:54:28.713508+00', 'Katherine Mary', 1607, '');
INSERT INTO 'tune' VALUES (4989, NULL, '2012-01-20 12:54:36.771702+00', 'Donnybrook Boy', 9999, '');
INSERT INTO 'tune' VALUES (2662, NULL, '2012-01-20 12:54:28.66177+00', 'Hurlock''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (2663, NULL, '2012-01-20 12:54:28.664865+00', 'Castle Donovan', 9999, '');
INSERT INTO 'tune' VALUES (2680, NULL, '2012-01-20 12:54:28.716429+00', 'Mrs MacPherson of Cluny', 1632, '');
INSERT INTO 'tune' VALUES (4990, NULL, '2012-01-20 12:54:36.774585+00', 'Jimmy Blue', 1551, '');
INSERT INTO 'tune' VALUES (2664, NULL, '2012-01-20 12:54:28.667965+00', 'Mrs Blair of Avontoun''s favourite', 9998, '');
INSERT INTO 'tune' VALUES (2665, NULL, '2012-01-20 12:54:28.670897+00', 'Tobin''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (2681, NULL, '2012-01-20 12:54:28.719333+00', 'Mrs Mackinnon Corry', 9998, '');
INSERT INTO 'tune' VALUES (4991, NULL, '2012-01-20 12:54:36.777471+00', 'Plough and the Stars, The', 9999, '');
INSERT INTO 'tune' VALUES (2666, NULL, '2012-01-20 12:54:28.67387+00', 'Mrs Chree', 1512, '');
INSERT INTO 'tune' VALUES (2667, NULL, '2012-01-20 12:54:28.676785+00', 'Mrs Col Bailie of Red-Castle', 9999, '');
INSERT INTO 'tune' VALUES (2682, NULL, '2012-01-20 12:54:28.722253+00', 'Ghlass-Ault, The', 1635, '');
INSERT INTO 'tune' VALUES (4992, NULL, '2012-01-20 12:54:36.780354+00', 'Two Sisters, The', 2100, '');
INSERT INTO 'tune' VALUES (2668, NULL, '2012-01-20 12:54:28.679688+00', 'Tenpenny Bit', 9999, '');
INSERT INTO 'tune' VALUES (2669, NULL, '2012-01-20 12:54:28.682801+00', 'Miss Drummond-Smith''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (4993, NULL, '2012-01-20 12:54:36.78326+00', 'Iain''s Hunting Horn', 9998, '');
INSERT INTO 'tune' VALUES (2671, NULL, '2012-01-20 12:54:28.689651+00', 'Mrs Fraser''s (of Cullen) Reel', 1516, '');
INSERT INTO 'tune' VALUES (2684, NULL, '2012-01-20 12:54:28.728049+00', 'Wee David', 1726, '');
INSERT INTO 'tune' VALUES (4994, NULL, '2012-01-20 12:54:36.78615+00', 'Nineteenth Hole, The', 1655, '');
INSERT INTO 'tune' VALUES (2672, NULL, '2012-01-20 12:54:28.692555+00', 'Susan MacLeod', 1910, '');
INSERT INTO 'tune' VALUES (2685, NULL, '2012-01-20 12:54:28.731401+00', 'Mrs Maule of Panmure''s Favourite', 9998, '');
INSERT INTO 'tune' VALUES (4995, NULL, '2012-01-20 12:54:36.789046+00', 'Maguire''s', 9998, '');
INSERT INTO 'tune' VALUES (2674, NULL, '2012-01-20 12:54:28.69844+00', 'Colonel MacLeod', 9999, '');
INSERT INTO 'tune' VALUES (2686, NULL, '2012-01-20 12:54:28.734474+00', 'Iona Bound', 1814, '');
INSERT INTO 'tune' VALUES (4996, NULL, '2012-01-20 12:54:36.791943+00', 'Rattigan''s', 9998, '');
INSERT INTO 'tune' VALUES (2687, NULL, '2012-01-20 12:54:28.737399+00', 'Mrs McGhie''s Reel', 1762, '');
INSERT INTO 'tune' VALUES (2688, NULL, '2012-01-20 12:54:28.740297+00', 'Donegal Jig', 9999, '');
INSERT INTO 'tune' VALUES (4997, NULL, '2012-01-20 12:54:36.794842+00', 'Halls of Montezuma, The', 3364, '');
INSERT INTO 'tune' VALUES (2689, NULL, '2012-01-20 12:54:28.743196+00', 'Pleased to Meet You', 1329, '');
INSERT INTO 'tune' VALUES (2690, '2006-08-27 22:00:00+00', '2012-01-20 12:54:28.746097+00', 'Peter Crichton', 1777, '');
INSERT INTO 'tune' VALUES (4998, NULL, '2012-01-20 12:54:36.797727+00', 'Dublin on the Green', 9999, '');
INSERT INTO 'tune' VALUES (2692, NULL, '2012-01-20 12:54:28.751927+00', 'Mrs Ross', 9999, '');
INSERT INTO 'tune' VALUES (4999, NULL, '2012-01-20 12:54:36.800618+00', 'Caissons go Rolling Along, The', 3365, '');
INSERT INTO 'tune' VALUES (2694, NULL, '2012-01-20 12:54:28.758815+00', 'Mrs Stewart of Grandtully', 1518, '');
INSERT INTO 'tune' VALUES (2695, NULL, '2012-01-20 12:54:28.76173+00', 'Wesley Harry', 1631, '');
INSERT INTO 'tune' VALUES (5000, NULL, '2012-01-20 12:54:36.80352+00', 'Wild Colonial Boy, The', 2424, '');
INSERT INTO 'tune' VALUES (2693, NULL, '2014-09-06 02:34:56.882366+00', 'Laird o'' Mackintosh', 9999, '');
INSERT INTO 'tune' VALUES (2691, NULL, '2014-09-16 09:01:21.537916+00', 'Pomander Jig, The', 1738, '');
INSERT INTO 'tune' VALUES (2696, NULL, '2012-01-20 12:54:28.764643+00', 'Muckin'' o'' Geordie''s Byre, The', 9999, '');
INSERT INTO 'tune' VALUES (2621, NULL, '2020-01-20 11:05:36.037983+00', 'Miss Robertson', 1516, '');
INSERT INTO 'tune' VALUES (2650, NULL, '2020-01-26 22:22:31.917796+00', 'Mr & Mrs T M Robertson', 1527, '');
INSERT INTO 'tune' VALUES (2670, NULL, '2020-05-25 10:41:43.234797+00', 'Mrs Dundas of Arniston', 1747, '');
INSERT INTO 'tune' VALUES (2697, NULL, '2012-01-20 12:54:28.767547+00', 'We''ll Gang Nae Mair tae Yon Toon', 9999, '');
INSERT INTO 'tune' VALUES (2698, NULL, '2012-01-20 12:54:28.770448+00', 'Murray Fiddle', 1609, '');
INSERT INTO 'tune' VALUES (5001, NULL, '2012-01-20 12:54:36.806404+00', 'Why Should Not Poor Folk', 9999, '');
INSERT INTO 'tune' VALUES (2699, NULL, '2012-01-20 12:54:28.773363+00', 'Ray''s Classic', 1677, '');
INSERT INTO 'tune' VALUES (2700, NULL, '2012-01-20 12:54:28.776348+00', 'Burravoe', 1739, '');
INSERT INTO 'tune' VALUES (2701, NULL, '2012-01-20 12:54:28.7796+00', 'Fàilte Do''n Eilean Sgiathanach', 1740, '');
INSERT INTO 'tune' VALUES (5002, NULL, '2012-01-20 12:54:36.809289+00', 'Mrs Nora Coakley', 2257, '');
INSERT INTO 'tune' VALUES (2702, NULL, '2012-01-20 12:54:28.782563+00', 'My Dungannon Sweetheart', 1602, '');
INSERT INTO 'tune' VALUES (2704, NULL, '2012-01-20 12:54:28.788357+00', 'Girl with the Blue Dress On, The', 9999, '');
INSERT INTO 'tune' VALUES (5003, NULL, '2012-01-20 12:54:36.82247+00', 'Kathy Fraser''s Jig', 2257, '');
INSERT INTO 'tune' VALUES (2705, NULL, '2012-01-20 12:54:28.791257+00', 'My Wee Laud''s a Sojer', 9999, '');
INSERT INTO 'tune' VALUES (2706, NULL, '2012-01-20 12:54:28.794191+00', 'My Wife''s a Wanton Wee Thing', 1518, '');
INSERT INTO 'tune' VALUES (5004, NULL, '2012-01-20 12:54:36.825472+00', 'Kitty Magee', 9999, '');
INSERT INTO 'tune' VALUES (5005, NULL, '2012-01-20 12:54:36.828375+00', 'Mr Douglas of Brigton', 9999, '');
INSERT INTO 'tune' VALUES (5006, NULL, '2012-01-20 12:54:36.831273+00', 'Jocky''s Ta''en the Pairtin Kiss', 9999, '');
INSERT INTO 'tune' VALUES (5007, NULL, '2012-01-20 12:54:36.834161+00', 'Miss Gregory', 2423, '');
INSERT INTO 'tune' VALUES (5008, NULL, '2012-01-20 12:54:36.837151+00', 'Skirl of the Pipes, The', 2424, '');
INSERT INTO 'tune' VALUES (5009, NULL, '2012-01-20 12:54:36.840042+00', 'Farewell to Stockley', 2425, '');
INSERT INTO 'tune' VALUES (5010, NULL, '2012-01-20 12:54:36.842943+00', 'She''s Bonnie an'' Braw an''', 1512, '');
INSERT INTO 'tune' VALUES (5011, NULL, '2012-01-20 12:54:36.845835+00', 'Ronas Voe', 1623, '');
INSERT INTO 'tune' VALUES (5012, NULL, '2012-01-20 12:54:36.848727+00', 'Margaret Ann Robertson', 1535, '');
INSERT INTO 'tune' VALUES (5013, NULL, '2012-01-20 12:54:36.851617+00', 'Wha Saw the Tattie Howkers?', 9999, '');
INSERT INTO 'tune' VALUES (5015, NULL, '2012-01-20 12:54:36.857395+00', 'Sean South of Garryowen', 9999, '');
INSERT INTO 'tune' VALUES (5016, NULL, '2012-01-20 12:54:36.860287+00', 'Here''s to the Gordons', 2267, '');
INSERT INTO 'tune' VALUES (5017, NULL, '2012-01-20 12:54:36.863218+00', 'Buttermilk Marys', 9999, '');
INSERT INTO 'tune' VALUES (5018, NULL, '2012-01-20 12:54:36.866122+00', 'Lime Hill', 1766, '');
INSERT INTO 'tune' VALUES (5019, NULL, '2012-01-20 12:54:36.869021+00', 'Mr Dow', 1766, '');
INSERT INTO 'tune' VALUES (5020, NULL, '2012-01-20 12:54:36.872388+00', 'Mrs Dow', 1766, '');
INSERT INTO 'tune' VALUES (2703, NULL, '2012-10-10 22:08:54.446354+00', 'My Heart is Sair', 9999, '');
INSERT INTO 'tune' VALUES (2707, NULL, '2012-01-20 12:54:28.797296+00', 'My Wild Irish Rose', 9999, '');
INSERT INTO 'tune' VALUES (5021, NULL, '2012-01-20 12:54:36.875365+00', 'Jabe Medow', 9999, '');
INSERT INTO 'tune' VALUES (2708, NULL, '2012-01-20 12:54:28.800247+00', 'Ne''er Wed an Old Man', 9998, '');
INSERT INTO 'tune' VALUES (2709, NULL, '2012-01-20 12:54:28.803528+00', 'Neil Donald', 1645, '');
INSERT INTO 'tune' VALUES (2729, NULL, '2012-01-20 12:54:28.863434+00', 'O''er the Bows to Ballindalloch', 9999, '');
INSERT INTO 'tune' VALUES (5022, NULL, '2012-01-20 12:54:36.878279+00', 'Millburn', 2234, '');
INSERT INTO 'tune' VALUES (2710, NULL, '2012-01-20 12:54:28.806486+00', 'Niel Gow''s Strathspey', 10504, '');
INSERT INTO 'tune' VALUES (2711, NULL, '2012-01-20 12:54:28.809386+00', 'Niel Gow''s Wife', 1518, '');
INSERT INTO 'tune' VALUES (2730, NULL, '2012-01-20 12:54:28.866326+00', 'Colonel Robertson', 9999, '');
INSERT INTO 'tune' VALUES (5023, NULL, '2012-01-20 12:54:36.881231+00', 'Napoleon', 9999, '');
INSERT INTO 'tune' VALUES (2712, NULL, '2012-01-20 12:54:28.812278+00', 'New Fiddle, The', 1766, '');
INSERT INTO 'tune' VALUES (2713, NULL, '2012-01-20 12:54:28.81523+00', 'Dingle Regatta', 9999, '');
INSERT INTO 'tune' VALUES (2731, NULL, '2012-01-20 12:54:28.869414+00', 'Alexandria Reel, The', 1533, '');
INSERT INTO 'tune' VALUES (5024, NULL, '2012-01-20 12:54:36.884124+00', 'Pink Rose', 2234, '');
INSERT INTO 'tune' VALUES (2714, NULL, '2012-01-20 12:54:28.818165+00', 'Lord Dreghorn''s Quickstep', 1519, '');
INSERT INTO 'tune' VALUES (2715, NULL, '2012-01-20 12:54:28.821055+00', 'Miss Anne Smith', 9999, '');
INSERT INTO 'tune' VALUES (2732, NULL, '2012-01-20 12:54:28.872824+00', 'Oh, Saw Ye My Wee Thing', 9999, '');
INSERT INTO 'tune' VALUES (5025, NULL, '2012-01-20 12:54:36.887032+00', 'Favourite', 1549, '');
INSERT INTO 'tune' VALUES (2716, NULL, '2012-01-20 12:54:28.824298+00', 'Niel Gow''s House', 1748, '');
INSERT INTO 'tune' VALUES (2717, NULL, '2012-01-20 12:54:28.827222+00', 'Miss Johnstone', 1512, '');
INSERT INTO 'tune' VALUES (2733, NULL, '2012-01-20 12:54:28.875821+00', 'Archie McBride', 9999, '');
INSERT INTO 'tune' VALUES (5026, NULL, '2012-01-20 12:54:36.889916+00', 'Ariel', 9999, '');
INSERT INTO 'tune' VALUES (2718, NULL, '2012-01-20 12:54:28.830111+00', 'Caledonian Hunt, The', 9999, '');
INSERT INTO 'tune' VALUES (2719, NULL, '2012-01-20 12:54:28.833055+00', 'Northern Lights of Aberdeen, The', 2005, '');
INSERT INTO 'tune' VALUES (2734, NULL, '2012-01-20 12:54:28.878772+00', 'Old French', 9999, '');
INSERT INTO 'tune' VALUES (5027, NULL, '2012-01-20 12:54:36.892805+00', 'Irish in America', 9999, '');
INSERT INTO 'tune' VALUES (2720, NULL, '2012-01-20 12:54:28.836357+00', 'Nothing Can Sadden Us', 9999, '');
INSERT INTO 'tune' VALUES (2721, NULL, '2012-01-20 12:54:28.839338+00', 'Talisker', 1512, '');
INSERT INTO 'tune' VALUES (2735, NULL, '2012-01-20 12:54:28.881677+00', 'Abreast of the Times', 1660, '');
INSERT INTO 'tune' VALUES (5028, NULL, '2012-01-20 12:54:36.895702+00', 'Manhattan', 9999, '');
INSERT INTO 'tune' VALUES (2722, NULL, '2012-01-20 12:54:28.842242+00', 'O Hey Ya Seen the Roses blow', 9999, '');
INSERT INTO 'tune' VALUES (2736, NULL, '2012-01-20 12:54:28.884578+00', 'John Ducket of Kelsall', 1743, '');
INSERT INTO 'tune' VALUES (5029, NULL, '2012-01-20 12:54:36.898595+00', 'Sheep Shanks', 1519, '');
INSERT INTO 'tune' VALUES (2725, NULL, '2012-01-20 12:54:28.851722+00', 'Jamie Shearer', 1512, '');
INSERT INTO 'tune' VALUES (5014, NULL, '2015-03-20 18:02:00.862474+00', 'Ballochmyle', 2138, '');
INSERT INTO 'tune' VALUES (2737, NULL, '2012-01-20 12:54:28.887604+00', 'Old Rosin the Beau', 9999, '');
INSERT INTO 'tune' VALUES (5030, NULL, '2012-01-20 12:54:36.901494+00', 'Kennedy Street', 2264, '');
INSERT INTO 'tune' VALUES (2726, NULL, '2012-01-20 12:54:28.854623+00', 'O''Rafferty''s Motor Car', 1637, '');
INSERT INTO 'tune' VALUES (2727, NULL, '2012-01-20 12:54:28.857595+00', 'Coquet Light', 1742, '');
INSERT INTO 'tune' VALUES (2738, NULL, '2012-01-20 12:54:28.890522+00', 'Old Rustic Bridge, The', 9999, '');
INSERT INTO 'tune' VALUES (5031, NULL, '2012-01-20 12:54:36.904415+00', 'Scotsville', 2552, '');
INSERT INTO 'tune' VALUES (2739, NULL, '2012-01-20 12:54:28.893419+00', 'One Morning in May', 9998, '');
INSERT INTO 'tune' VALUES (2740, NULL, '2012-01-20 12:54:28.897052+00', 'Oul'' Lammas Fair', 9998, '');
INSERT INTO 'tune' VALUES (2741, NULL, '2012-01-20 12:54:28.900007+00', 'Archie McHarg', 1871, '');
INSERT INTO 'tune' VALUES (5032, NULL, '2012-01-20 12:54:36.907318+00', 'Lassies of Stewarton', 9999, '');
INSERT INTO 'tune' VALUES (2742, NULL, '2012-01-20 12:54:28.903004+00', 'Over the Sea', 9999, '');
INSERT INTO 'tune' VALUES (2743, NULL, '2012-01-20 12:54:28.905908+00', 'Pipe Major John Stewart', 1699, '');
INSERT INTO 'tune' VALUES (5033, NULL, '2012-01-20 12:54:36.910219+00', 'Miss E Elder', 1695, '');
INSERT INTO 'tune' VALUES (2744, NULL, '2012-01-20 12:54:28.908798+00', 'Paddy O''Rafferty', 9999, '');
INSERT INTO 'tune' VALUES (5034, NULL, '2012-01-20 12:54:36.913122+00', 'Jamie Hardie', 1512, '');
INSERT INTO 'tune' VALUES (2745, NULL, '2012-01-20 12:54:28.911695+00', 'Paddy''s Rickle Bridge', 1668, '');
INSERT INTO 'tune' VALUES (2747, NULL, '2012-01-20 12:54:28.917735+00', 'Pam Finlayson''s Reel', 1608, '');
INSERT INTO 'tune' VALUES (5035, NULL, '2012-01-20 12:54:36.91657+00', 'Weary We''ve Been', 9999, '');
INSERT INTO 'tune' VALUES (2748, NULL, '2012-01-20 12:54:28.921278+00', 'Anderson''s Jig', 1583, '');
INSERT INTO 'tune' VALUES (2749, NULL, '2012-01-20 12:54:28.924223+00', 'Parks of Fochabers, The', 9998, '');
INSERT INTO 'tune' VALUES (2750, NULL, '2012-01-20 12:54:28.927126+00', 'Ta Saliba Crossroads', 1744, '');
INSERT INTO 'tune' VALUES (13839, '2018-02-24 09:31:29.909216+00', '2018-02-24 09:31:29.909216+00', 'Mrs Hugh Calder', 9998, '');
INSERT INTO 'tune' VALUES (2752, NULL, '2012-01-20 12:54:28.932914+00', 'Pat Donald', 1598, '');
INSERT INTO 'tune' VALUES (2753, NULL, '2012-01-20 12:54:28.935814+00', 'Patricia Ann Douglas', 1522, '');
INSERT INTO 'tune' VALUES (5037, NULL, '2012-01-20 12:54:36.922425+00', 'Struan Robertson', 9999, '');
INSERT INTO 'tune' VALUES (2754, NULL, '2012-01-20 12:54:28.939075+00', 'County Ball, The', 9999, '');
INSERT INTO 'tune' VALUES (2755, NULL, '2012-01-20 12:54:28.941999+00', 'Peeler''s Jacket, The', 9999, '');
INSERT INTO 'tune' VALUES (2756, NULL, '2012-01-20 12:54:28.944901+00', 'Saint Andrew''s Celebration', 1582, '');
INSERT INTO 'tune' VALUES (5038, NULL, '2012-01-20 12:54:36.925328+00', 'Duke John', 9999, '');
INSERT INTO 'tune' VALUES (2757, NULL, '2012-01-20 12:54:28.947798+00', 'Miss Maria Stewart''s Jig', 1476, '');
INSERT INTO 'tune' VALUES (2758, NULL, '2012-01-20 12:54:28.951292+00', 'Peking Duck', 1501, '');
INSERT INTO 'tune' VALUES (5040, NULL, '2012-01-20 12:54:36.931463+00', 'Tillitudlum Castle', 2268, '');
INSERT INTO 'tune' VALUES (5041, NULL, '2012-01-20 12:54:36.93436+00', 'Allan Harlan', 1714, '');
INSERT INTO 'tune' VALUES (5042, NULL, '2012-01-20 12:54:36.937264+00', 'South Uist Golf Club', 9998, '');
INSERT INTO 'tune' VALUES (5043, NULL, '2012-01-20 12:54:36.940159+00', 'Rosebud of Allenvale', 1512, '');
INSERT INTO 'tune' VALUES (5044, NULL, '2012-01-20 12:54:36.943049+00', 'Bonnie Glenfarg', 1512, '');
INSERT INTO 'tune' VALUES (5045, NULL, '2012-01-20 12:54:36.945973+00', 'Farewell to Scotland', 1512, '');
INSERT INTO 'tune' VALUES (5047, NULL, '2012-01-20 12:54:36.951763+00', 'Whistling Ploughboy, The', 9998, '');
INSERT INTO 'tune' VALUES (12149, '2012-06-12 16:00:42.57736+00', '2012-06-12 16:00:42.577371+00', 'Alistair''s Reel', 1576, '');
INSERT INTO 'tune' VALUES (2759, NULL, '2012-01-20 12:54:28.954333+00', 'Pennymore Road, The', 1608, '');
INSERT INTO 'tune' VALUES (2781, NULL, '2012-01-20 12:54:29.020675+00', 'Aberlour''s Squeeze', 1516, '');
INSERT INTO 'tune' VALUES (2760, NULL, '2012-01-20 12:54:28.957259+00', 'Pentland Hills', 1859, '');
INSERT INTO 'tune' VALUES (5048, NULL, '2012-01-20 12:54:36.954657+00', 'Tapping Toes', 1898, '');
INSERT INTO 'tune' VALUES (2761, NULL, '2012-01-20 12:54:28.960201+00', 'Persian Dance, The', 1517, '');
INSERT INTO 'tune' VALUES (2782, NULL, '2012-01-20 12:54:29.024427+00', 'Queen Mary, Queen Mary', 9999, '');
INSERT INTO 'tune' VALUES (2762, NULL, '2012-01-20 12:54:28.9631+00', 'Merry Blacksmith, The', 9999, '');
INSERT INTO 'tune' VALUES (5049, NULL, '2012-01-20 12:54:36.957555+00', 'Best o'' Twa, The', 1898, '');
INSERT INTO 'tune' VALUES (2763, NULL, '2012-01-20 12:54:28.965989+00', 'Here''s a Health to the Ladies', 9998, '');
INSERT INTO 'tune' VALUES (2783, NULL, '2012-01-20 12:54:29.027389+00', 'Mrs Joan Moore''s Delight', 1502, '');
INSERT INTO 'tune' VALUES (2764, NULL, '2012-01-20 12:54:28.968885+00', 'Miss Gibson', 9999, '');
INSERT INTO 'tune' VALUES (5050, NULL, '2012-01-20 12:54:36.960452+00', 'Mistress Anne Jamieson', 130, '');
INSERT INTO 'tune' VALUES (2765, NULL, '2012-01-20 12:54:28.97211+00', 'Auld Man, The', 1512, '');
INSERT INTO 'tune' VALUES (2784, NULL, '2012-01-20 12:54:29.03028+00', 'North Shore, The', 1750, '');
INSERT INTO 'tune' VALUES (2766, NULL, '2012-01-20 12:54:28.97582+00', 'Peter Baillie''s Wife', 9999, '');
INSERT INTO 'tune' VALUES (5051, NULL, '2012-01-20 12:54:36.963343+00', 'Lord Napier of Magdala', 9999, '');
INSERT INTO 'tune' VALUES (2767, NULL, '2012-01-20 12:54:28.978898+00', 'House of Bellabeg', 1748, '');
INSERT INTO 'tune' VALUES (2785, NULL, '2012-01-20 12:54:29.033212+00', 'Glengairn', 1748, '');
INSERT INTO 'tune' VALUES (2768, NULL, '2012-01-20 12:54:28.981804+00', 'Mr Gordon Glennie', 1748, '');
INSERT INTO 'tune' VALUES (5052, NULL, '2012-01-20 12:54:36.966239+00', 'Mrs Jessie Thomson of Tillicoultry', 1536, '');
INSERT INTO 'tune' VALUES (2769, NULL, '2012-01-20 12:54:28.984694+00', 'Mr Gordon of Hallhead', 1516, '');
INSERT INTO 'tune' VALUES (2786, NULL, '2012-01-20 12:54:29.036113+00', 'Rakes O'' Kildare, The', 9999, '');
INSERT INTO 'tune' VALUES (2770, NULL, '2012-01-20 12:54:28.987602+00', 'Pibroch of Bonnie Strathearn', 9999, '');
INSERT INTO 'tune' VALUES (5053, NULL, '2012-01-20 12:54:36.96915+00', 'Coming Round the Mountain', 9999, '');
INSERT INTO 'tune' VALUES (2771, NULL, '2012-01-20 12:54:28.990498+00', 'Miss Oliphant', 9999, '');
INSERT INTO 'tune' VALUES (2787, NULL, '2012-01-20 12:54:29.039073+00', 'Miss Jessie Stewart', 9999, '');
INSERT INTO 'tune' VALUES (2772, NULL, '2012-01-20 12:54:28.993467+00', 'Piper of Drummond, The', 9999, '');
INSERT INTO 'tune' VALUES (5054, NULL, '2012-01-20 12:54:36.972048+00', 'Happy Wanderer, The', 9999, '');
INSERT INTO 'tune' VALUES (2773, NULL, '2012-01-20 12:54:28.996389+00', 'Polly Stewart', 9999, '');
INSERT INTO 'tune' VALUES (2788, NULL, '2012-01-20 12:54:29.042111+00', 'Randall''s Reel', 1592, '');
INSERT INTO 'tune' VALUES (2774, NULL, '2012-01-20 12:54:29.00015+00', 'Polwart on the Green', 9999, '');
INSERT INTO 'tune' VALUES (5055, NULL, '2012-01-20 12:54:36.974934+00', 'Swanee River, The', 2293, '');
INSERT INTO 'tune' VALUES (2775, NULL, '2012-01-20 12:54:29.003125+00', 'Portree Reel', 1610, '');
INSERT INTO 'tune' VALUES (2776, NULL, '2012-01-20 12:54:29.006026+00', 'Pretty Jane', 9999, '');
INSERT INTO 'tune' VALUES (5056, NULL, '2012-01-20 12:54:36.97782+00', 'Miss Helen McInnes', 1516, '');
INSERT INTO 'tune' VALUES (2777, NULL, '2012-01-20 12:54:29.008987+00', 'Royal Recovery, The', 9999, '');
INSERT INTO 'tune' VALUES (2790, NULL, '2012-01-20 12:54:29.049038+00', 'Reconciliation, The', 9999, '');
INSERT INTO 'tune' VALUES (2778, NULL, '2012-01-20 12:54:29.011892+00', 'Miss Mathieson', 1512, '');
INSERT INTO 'tune' VALUES (5057, NULL, '2012-01-20 12:54:36.980737+00', 'Oasis Music', 9998, '');
INSERT INTO 'tune' VALUES (2779, NULL, '2012-01-20 12:54:29.014813+00', 'Provost Ross'' House', 1607, '');
INSERT INTO 'tune' VALUES (2791, NULL, '2012-01-20 12:54:29.051977+00', 'Red Coat, the', 9999, '');
INSERT INTO 'tune' VALUES (2780, NULL, '2012-01-20 12:54:29.017705+00', 'Provost Skene''s House', 1607, '');
INSERT INTO 'tune' VALUES (5058, NULL, '2012-01-20 12:54:36.983632+00', 'Pipe Major Callum Campbell', 1672, '');
INSERT INTO 'tune' VALUES (2792, NULL, '2012-01-20 12:54:29.05487+00', 'Bonnie Strathmore', 9999, '');
INSERT INTO 'tune' VALUES (2793, NULL, '2012-01-20 12:54:29.057755+00', 'McDougall''s March', 9999, '');
INSERT INTO 'tune' VALUES (5059, NULL, '2012-01-20 12:54:36.986517+00', 'Kalabakan', 1672, '');
INSERT INTO 'tune' VALUES (2794, NULL, '2012-01-20 12:54:29.060662+00', 'Sma'' Coal for Nailers', 9999, '');
INSERT INTO 'tune' VALUES (2795, NULL, '2012-01-20 12:54:29.063552+00', 'Forge, The', 9998, '');
INSERT INTO 'tune' VALUES (2796, NULL, '2012-01-20 12:54:29.06645+00', 'Dougal More', 1424, '');
INSERT INTO 'tune' VALUES (5060, NULL, '2012-01-20 12:54:36.98942+00', 'Bessie McIntyre', 2480, '');
INSERT INTO 'tune' VALUES (2797, NULL, '2012-01-20 12:54:29.06939+00', 'Rannoch Lodge', 9998, '');
INSERT INTO 'tune' VALUES (2799, NULL, '2012-01-20 12:54:29.07602+00', 'Mrs Gregory', 9998, '');
INSERT INTO 'tune' VALUES (5061, NULL, '2012-01-20 12:54:36.992327+00', 'Back of the Moon', 2214, '');
INSERT INTO 'tune' VALUES (2801, NULL, '2012-01-20 12:54:29.081815+00', 'Jack Cooper', 1554, '');
INSERT INTO 'tune' VALUES (2802, NULL, '2012-01-20 12:54:29.084731+00', 'Marquis of Tullibardine, The', 1810, '');
INSERT INTO 'tune' VALUES (5062, NULL, '2012-01-20 12:54:36.995217+00', 'Dr MacDonald''s Fancy', 1735, '');
INSERT INTO 'tune' VALUES (2803, NULL, '2012-01-20 12:54:29.087633+00', 'Ricky Lowe''s Polka', 9999, '');
INSERT INTO 'tune' VALUES (13840, '2018-02-24 09:33:49.013193+00', '2018-02-24 09:33:49.013193+00', 'Pretty Lilian', 9998, '');
INSERT INTO 'tune' VALUES (2805, NULL, '2012-01-20 12:54:29.093512+00', 'Road to Ullapool, The', 1679, '');
INSERT INTO 'tune' VALUES (5063, NULL, '2012-01-20 12:54:36.998105+00', 'Crow''s Nest, The', 2482, '');
INSERT INTO 'tune' VALUES (2806, NULL, '2012-01-20 12:54:29.097102+00', 'Wha Wadna'' Fecht for Charlie', 9999, '');
INSERT INTO 'tune' VALUES (2807, NULL, '2012-01-20 12:54:29.100033+00', 'Robert Campbell', 1667, '');
INSERT INTO 'tune' VALUES (2808, NULL, '2012-01-20 12:54:29.102961+00', 'Mrs Coutts Trotter''s Favourite', 1516, '');
INSERT INTO 'tune' VALUES (5064, NULL, '2012-01-20 12:54:37.000993+00', 'Up Country', 2176, '');
INSERT INTO 'tune' VALUES (2809, NULL, '2012-01-20 12:54:29.105857+00', 'Kinnegad Slashers, The', 9999, '');
INSERT INTO 'tune' VALUES (2810, NULL, '2012-01-20 12:54:29.108749+00', 'Robin''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (5039, NULL, '2017-11-26 00:31:58.758825+00', 'High Road to Gareloch, The', 9999, '');
INSERT INTO 'tune' VALUES (2811, NULL, '2012-01-20 12:54:29.111733+00', 'Robin''s Nest, The', 9999, '');
INSERT INTO 'tune' VALUES (5065, NULL, '2012-01-20 12:54:37.003879+00', 'Colin Thomson', 2483, '');
INSERT INTO 'tune' VALUES (5066, NULL, '2012-01-20 12:54:37.006769+00', 'Mist Covered Mountains of Home, The', 9999, '');
INSERT INTO 'tune' VALUES (5067, NULL, '2012-01-20 12:54:37.009665+00', 'Echoes of Oban', 2214, '');
INSERT INTO 'tune' VALUES (5068, NULL, '2012-01-20 12:54:37.012551+00', 'Echoes of Oban', 2377, '');
INSERT INTO 'tune' VALUES (5069, NULL, '2012-01-20 12:54:37.015464+00', 'Old Wife of Raasay', 9999, '');
INSERT INTO 'tune' VALUES (5070, NULL, '2012-01-20 12:54:37.018366+00', 'Captain Cameron', 1516, '');
INSERT INTO 'tune' VALUES (5071, NULL, '2012-01-20 12:54:37.021262+00', 'Rickett''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (5072, NULL, '2012-01-20 12:54:37.024165+00', 'Minor Syl', 1135, '');
INSERT INTO 'tune' VALUES (5073, NULL, '2012-01-20 12:54:37.027061+00', 'Larry O'' Gaff', 9999, '');
INSERT INTO 'tune' VALUES (12150, '2012-06-12 16:03:15.930163+00', '2012-06-12 16:03:15.930174+00', 'Lord Brownlow''s Strathspey', 1596, '');
INSERT INTO 'tune' VALUES (2833, NULL, '2012-01-20 12:54:29.212395+00', 'Mrs Wendy Mumford', 1582, '');
INSERT INTO 'tune' VALUES (5074, NULL, '2012-01-20 12:54:37.029953+00', 'Penobscot Memory', 1932, '');
INSERT INTO 'tune' VALUES (13841, '2018-02-24 09:35:19.68287+00', '2018-02-24 09:35:19.68287+00', 'Shaggy Grey Buck', 9998, '');
INSERT INTO 'tune' VALUES (2813, NULL, '2012-01-20 12:54:29.118765+00', 'Ronnie Hunter', 1599, '');
INSERT INTO 'tune' VALUES (2834, NULL, '2012-01-20 12:54:29.216239+00', 'Sandy Ower the Sea', 1512, '');
INSERT INTO 'tune' VALUES (5075, NULL, '2012-01-20 12:54:37.032853+00', 'Bittersweet', 1135, '');
INSERT INTO 'tune' VALUES (2814, NULL, '2012-01-20 12:54:29.122551+00', 'Rory MacLeod', 1910, '');
INSERT INTO 'tune' VALUES (2815, NULL, '2012-01-20 12:54:29.125568+00', 'My Only Jo and Dearie O''', 1518, '');
INSERT INTO 'tune' VALUES (5076, NULL, '2012-01-20 12:54:37.035756+00', 'Four in One', 1135, '');
INSERT INTO 'tune' VALUES (2816, NULL, '2012-01-20 12:54:29.128481+00', 'Miss Drummond of Perth', 1518, '');
INSERT INTO 'tune' VALUES (2817, NULL, '2012-01-20 12:54:29.132223+00', 'Three Girls of Portree, The', 9998, '');
INSERT INTO 'tune' VALUES (2836, NULL, '2012-01-20 12:54:29.223953+00', 'Saut de Lapin', 9999, '');
INSERT INTO 'tune' VALUES (5077, NULL, '2012-01-20 12:54:37.038669+00', 'First Try', 1135, '');
INSERT INTO 'tune' VALUES (2818, NULL, '2012-01-20 12:54:29.135313+00', 'Rosebud by My Early Walk, A', 9999, '');
INSERT INTO 'tune' VALUES (2819, NULL, '2012-01-20 12:54:29.13964+00', 'Rosewood Waltz', 1768, '');
INSERT INTO 'tune' VALUES (2837, NULL, '2012-01-20 12:54:29.227044+00', 'Jim Tweedie''s Sea Legs', 2387, '');
INSERT INTO 'tune' VALUES (5078, NULL, '2012-01-20 12:54:37.041562+00', 'Whimsey', 1135, '');
INSERT INTO 'tune' VALUES (2820, NULL, '2012-01-20 12:54:29.142655+00', 'Rosie O''Grady', 9999, '');
INSERT INTO 'tune' VALUES (2821, NULL, '2012-01-20 12:54:29.145558+00', 'Sandy Duff', 9999, '');
INSERT INTO 'tune' VALUES (2838, NULL, '2012-01-20 12:54:29.229949+00', 'John McDonald''s March', 1558, '');
INSERT INTO 'tune' VALUES (5079, NULL, '2012-01-20 12:54:37.044458+00', 'Mrs Menzies of Culdare''s Reel', 1516, '');
INSERT INTO 'tune' VALUES (2822, NULL, '2012-01-20 12:54:29.148458+00', 'Rowan Tree, The', 9999, '');
INSERT INTO 'tune' VALUES (2823, NULL, '2012-01-20 12:54:29.15144+00', 'Royal Scots Polka', 2420, '');
INSERT INTO 'tune' VALUES (2839, NULL, '2012-01-20 12:54:29.233784+00', 'Scotch on the Rocks', 1697, '');
INSERT INTO 'tune' VALUES (5080, NULL, '2012-01-20 12:54:37.047348+00', 'Mo Chuachag Laghach Thu', 9999, '');
INSERT INTO 'tune' VALUES (2824, NULL, '2012-01-20 12:54:29.154345+00', 'Scarborough Jig', 1582, '');
INSERT INTO 'tune' VALUES (2825, NULL, '2012-01-20 12:54:29.15726+00', 'Marilyn''s Birthday Jig', 1582, '');
INSERT INTO 'tune' VALUES (2840, NULL, '2012-01-20 12:54:29.236721+00', 'Yankee Doodle Dandy', 9999, '');
INSERT INTO 'tune' VALUES (5081, NULL, '2012-01-20 12:54:37.050259+00', 'Cuiream Fa''ill Air An A''gh', 9999, '');
INSERT INTO 'tune' VALUES (2826, NULL, '2012-01-20 12:54:29.160661+00', 'Rusty Nail', 1650, '');
INSERT INTO 'tune' VALUES (2827, NULL, '2012-01-20 12:54:29.1646+00', 'Saddle the Pony', 9999, '');
INSERT INTO 'tune' VALUES (2841, NULL, '2012-01-20 12:54:29.239622+00', 'Scots Bonnet, The', 9999, '');
INSERT INTO 'tune' VALUES (5082, NULL, '2012-01-20 12:54:37.053156+00', 'Dorothy Leurs'' Jig', 2362, '');
INSERT INTO 'tune' VALUES (2828, NULL, '2012-01-20 12:54:29.16755+00', 'Saftest O'' the Family, The', 1663, '');
INSERT INTO 'tune' VALUES (2829, NULL, '2012-01-20 12:54:29.170474+00', 'Kelloholm Jig, The', 36, '');
INSERT INTO 'tune' VALUES (2842, NULL, '2012-01-20 12:54:29.242569+00', 'Scottish Breakaway, The', 9999, '');
INSERT INTO 'tune' VALUES (5083, NULL, '2012-01-20 12:54:37.056051+00', 'Flowers of Dungarvan, The', 9999, '');
INSERT INTO 'tune' VALUES (2830, NULL, '2012-01-20 12:54:29.174062+00', 'Man from Skye, The', 1910, '');
INSERT INTO 'tune' VALUES (2831, NULL, '2012-01-20 12:54:29.179125+00', 'Salisbury Craigs', 9999, '');
INSERT INTO 'tune' VALUES (2843, NULL, '2012-01-20 12:54:29.245488+00', 'Trip to Glasgow', 9999, '');
INSERT INTO 'tune' VALUES (5084, NULL, '2012-01-20 12:54:37.058955+00', 'Mad Hornpipe, The', 2313, '');
INSERT INTO 'tune' VALUES (2832, NULL, '2012-01-20 12:54:29.208044+00', 'West Port, The', 1595, '');
INSERT INTO 'tune' VALUES (2845, NULL, '2012-01-20 12:54:29.251281+00', 'Seabright, The', 9999, '');
INSERT INTO 'tune' VALUES (5085, NULL, '2012-01-20 12:54:37.061837+00', 'White House of Shieldaig, The', 9999, '');
INSERT INTO 'tune' VALUES (2846, NULL, '2012-01-20 12:54:29.254222+00', 'Seton''s Ceilidh Band', 1042, '');
INSERT INTO 'tune' VALUES (2847, NULL, '2012-01-20 12:54:29.257972+00', 'Sheehan''s Reel', 2160, '');
INSERT INTO 'tune' VALUES (2848, NULL, '2012-01-20 12:54:29.26092+00', 'Sheena''s Wedding', 1613, '');
INSERT INTO 'tune' VALUES (2849, NULL, '2012-01-20 12:54:29.263827+00', 'Nameless Lassie, The', 1516, '');
INSERT INTO 'tune' VALUES (5087, NULL, '2012-01-20 12:54:37.067627+00', 'Allan''s Reel', 2097, '');
INSERT INTO 'tune' VALUES (2850, NULL, '2012-01-20 12:54:29.266791+00', 'Mrs Hamilton of Pencaitland', 1517, '');
INSERT INTO 'tune' VALUES (2851, NULL, '2012-01-20 12:54:29.26968+00', 'Niel Gow''s Lamentation for Sir James Moray of Abercairney', 1518, '');
INSERT INTO 'tune' VALUES (5088, NULL, '2012-01-20 12:54:37.070531+00', 'Kiley''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (2852, NULL, '2012-01-20 12:54:29.272805+00', 'Weeping Birches of Kilmorack, The', 1512, '');
INSERT INTO 'tune' VALUES (2853, NULL, '2012-01-20 12:54:29.275801+00', 'Sister Thomson''s Strathspey', 1595, '');
INSERT INTO 'tune' VALUES (2854, NULL, '2012-01-20 12:54:29.279121+00', 'Sitting on the Bridge', 9998, '');
INSERT INTO 'tune' VALUES (5089, NULL, '2012-01-20 12:54:37.073418+00', 'John MacKenzie', 9999, '');
INSERT INTO 'tune' VALUES (2855, NULL, '2012-01-20 12:54:29.282224+00', 'Train Journey North, The', 1710, '');
INSERT INTO 'tune' VALUES (2856, NULL, '2012-01-20 12:54:29.285137+00', 'Sligo Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (2857, NULL, '2012-01-20 12:54:29.288028+00', 'Smith''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (5090, NULL, '2012-01-20 12:54:37.076337+00', 'Merry Mary', 9999, '');
INSERT INTO 'tune' VALUES (2858, NULL, '2012-01-20 12:54:29.290933+00', 'Andrew Knight', 1527, '');
INSERT INTO 'tune' VALUES (2859, NULL, '2012-01-20 12:54:29.293825+00', 'Smithy''s Reel', 1501, '');
INSERT INTO 'tune' VALUES (2860, NULL, '2012-01-20 12:54:29.296763+00', 'Snouts and Ears of America', 1640, '');
INSERT INTO 'tune' VALUES (5091, NULL, '2012-01-20 12:54:37.079242+00', 'Angus Cameron o'' Kirrie', 1520, '');
INSERT INTO 'tune' VALUES (2861, NULL, '2012-01-20 12:54:29.300393+00', 'Baldie''s Reel', 1752, '');
INSERT INTO 'tune' VALUES (2863, NULL, '2012-01-20 12:54:29.306243+00', 'Soho Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (5092, NULL, '2012-01-20 12:54:37.082128+00', 'Geordie Watson''s Co-worker of Whitehills', 1558, '');
INSERT INTO 'tune' VALUES (5093, NULL, '2012-01-20 12:54:37.085322+00', 'Reve de Musette', 9998, '');
INSERT INTO 'tune' VALUES (5094, NULL, '2012-01-20 12:54:37.08823+00', 'Betty MacKinnon Two Step', 1520, '');
INSERT INTO 'tune' VALUES (5095, NULL, '2012-01-20 12:54:37.091135+00', 'Piper''s Farewell to Perth, The', 2284, '');
INSERT INTO 'tune' VALUES (5096, NULL, '2012-01-20 12:54:37.09404+00', 'Brian Bell of Blairgowrie', 2285, '');
INSERT INTO 'tune' VALUES (5097, NULL, '2012-01-20 12:54:37.096932+00', 'Crossing the Alps', 9999, '');
INSERT INTO 'tune' VALUES (5098, NULL, '2012-01-20 12:54:37.099824+00', 'Centenary March', 9999, '');
INSERT INTO 'tune' VALUES (5099, NULL, '2012-01-20 12:54:37.102719+00', 'Fairly Shot O'' Her', 9999, '');
INSERT INTO 'tune' VALUES (2835, NULL, '2012-04-03 20:39:12.396791+00', 'Gypsy Weaver, The', 1763, 'composed 1999');
INSERT INTO 'tune' VALUES (2884, NULL, '2012-01-20 12:54:29.368885+00', 'Stewart Chisholm''s Walkabout', 1674, '');
INSERT INTO 'tune' VALUES (5100, NULL, '2012-01-20 12:54:37.105612+00', 'Bide a Wee', 9998, '');
INSERT INTO 'tune' VALUES (2865, NULL, '2012-01-20 12:54:29.31202+00', 'Kirsty''s Ceilidh', 1527, '');
INSERT INTO 'tune' VALUES (2885, NULL, '2012-01-20 12:54:29.3718+00', 'Stocainnean daoimean', 9998, '');
INSERT INTO 'tune' VALUES (5101, NULL, '2012-01-20 12:54:37.108509+00', 'Glens of Angus', 9998, '');
INSERT INTO 'tune' VALUES (2866, NULL, '2012-01-20 12:54:29.314918+00', 'A.B. Forbes'' Compliments to Dr Ray MIlbourne', 2168, '');
INSERT INTO 'tune' VALUES (2867, NULL, '2012-01-20 12:54:29.317902+00', 'South Lea', 1613, '');
INSERT INTO 'tune' VALUES (2886, NULL, '2012-01-20 12:54:29.374692+00', 'Shandon Bells', 2135, '');
INSERT INTO 'tune' VALUES (5102, NULL, '2012-01-20 12:54:37.111397+00', 'Jim McFarlane of Toddhills', 1935, '');
INSERT INTO 'tune' VALUES (2868, NULL, '2012-01-20 12:54:29.320796+00', 'Alan Brown', 1593, '');
INSERT INTO 'tune' VALUES (2869, NULL, '2012-01-20 12:54:29.323676+00', 'Ann''s Jig', 1582, '');
INSERT INTO 'tune' VALUES (2887, NULL, '2012-01-20 12:54:29.377696+00', 'Stonefield', 1502, '');
INSERT INTO 'tune' VALUES (5103, NULL, '2012-01-20 12:54:37.114324+00', 'Duff House', 1897, '');
INSERT INTO 'tune' VALUES (2870, NULL, '2012-01-20 12:54:29.326574+00', 'Irene Meldrum''s Welcome', 9999, '');
INSERT INTO 'tune' VALUES (2871, NULL, '2012-01-20 12:54:29.329509+00', 'Sprig of Ivy', 1303, '');
INSERT INTO 'tune' VALUES (2888, NULL, '2012-01-20 12:54:29.381237+00', 'Idle Road, The', 2135, '');
INSERT INTO 'tune' VALUES (5104, NULL, '2012-01-20 12:54:37.117228+00', 'Auld Theekit Hoose', 9999, '');
INSERT INTO 'tune' VALUES (2872, NULL, '2012-01-20 12:54:29.333086+00', 'Sprightly Minikin, The', 9999, '');
INSERT INTO 'tune' VALUES (2812, NULL, '2015-08-12 14:17:06.703846+00', 'Ivy House', 9999, '');
INSERT INTO 'tune' VALUES (2889, NULL, '2012-01-20 12:54:29.384158+00', 'Ken Duncan''s Reel', 1756, '');
INSERT INTO 'tune' VALUES (5105, NULL, '2012-01-20 12:54:37.120828+00', 'Lumley Jig', 1935, '');
INSERT INTO 'tune' VALUES (2874, NULL, '2012-01-20 12:54:29.339009+00', 'In Praise of Islay', 9999, '');
INSERT INTO 'tune' VALUES (2875, NULL, '2012-01-20 12:54:29.341905+00', 'Sailing up the Clyde', 2228, '');
INSERT INTO 'tune' VALUES (2890, NULL, '2012-01-20 12:54:29.387078+00', 'Stornoway Sailor, The', 1523, '');
INSERT INTO 'tune' VALUES (5106, NULL, '2012-01-20 12:54:37.124587+00', 'Sandy the Piper', 9999, '');
INSERT INTO 'tune' VALUES (2876, NULL, '2012-01-20 12:54:29.344791+00', 'Saint Ermin''s Reel', 1531, '');
INSERT INTO 'tune' VALUES (2877, NULL, '2012-01-20 12:54:29.347697+00', 'Saint Ninian''s Isle', 1623, '');
INSERT INTO 'tune' VALUES (2891, NULL, '2012-01-20 12:54:29.389994+00', 'And Thou Wert my Own Thing', 9998, '');
INSERT INTO 'tune' VALUES (5107, NULL, '2012-01-20 12:54:37.127842+00', 'Glenmoriston', 9999, '');
INSERT INTO 'tune' VALUES (2878, NULL, '2012-01-20 12:54:29.35067+00', 'Stop Yer Ticklin'' Jock', 1663, '');
INSERT INTO 'tune' VALUES (2879, NULL, '2012-01-20 12:54:29.353592+00', 'Roamin'' in the Gloamin''', 1663, '');
INSERT INTO 'tune' VALUES (2892, NULL, '2012-01-20 12:54:29.392888+00', 'Strawberries Galore', 1593, '');
INSERT INTO 'tune' VALUES (5108, NULL, '2012-01-20 12:54:37.130801+00', 'Mrs Rob Gordon', 1555, '');
INSERT INTO 'tune' VALUES (2880, NULL, '2012-01-20 12:54:29.357138+00', 'Star o'' Rabbie Burns', 2438, '');
INSERT INTO 'tune' VALUES (2893, NULL, '2012-01-20 12:54:29.395777+00', 'Jean''s Fancy', 1621, '');
INSERT INTO 'tune' VALUES (5109, NULL, '2012-01-20 12:54:37.133774+00', 'Cardiff Caledonians', 1555, '');
INSERT INTO 'tune' VALUES (2883, NULL, '2012-01-20 12:54:29.365985+00', 'Sweet Biddy Daly', 9999, '');
INSERT INTO 'tune' VALUES (2894, NULL, '2012-01-20 12:54:29.398752+00', 'Peter Davidson''s Reel', 1623, '');
INSERT INTO 'tune' VALUES (5110, NULL, '2012-01-20 12:54:37.136689+00', 'Audrey Hinchliffe''s Fancy', 1558, '');
INSERT INTO 'tune' VALUES (2895, NULL, '2012-01-20 12:54:29.401646+00', 'Sunday is My Wedding Day', 1516, '');
INSERT INTO 'tune' VALUES (2896, NULL, '2012-01-20 12:54:29.418884+00', 'Joan & Geoff Desborough', 1590, '');
INSERT INTO 'tune' VALUES (2897, NULL, '2012-01-20 12:54:29.421886+00', 'Susan C Maclean', 1605, '');
INSERT INTO 'tune' VALUES (5111, NULL, '2012-01-20 12:54:37.139586+00', 'Rannoch Bhana', 9998, '');
INSERT INTO 'tune' VALUES (2898, NULL, '2012-01-20 12:54:29.42483+00', 'Swansea Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (2899, NULL, '2012-01-20 12:54:29.427728+00', 'Sweet Maid of Glendaruel', 9999, '');
INSERT INTO 'tune' VALUES (2900, NULL, '2012-01-20 12:54:29.430623+00', 'Sweet Maid of Mull', 9999, '');
INSERT INTO 'tune' VALUES (5112, NULL, '2012-01-20 12:54:37.142479+00', 'White Heather Jig, The', 9998, '');
INSERT INTO 'tune' VALUES (2901, NULL, '2012-01-20 12:54:29.433517+00', 'Tae Daunton Me', 9999, '');
INSERT INTO 'tune' VALUES (2902, NULL, '2012-01-20 12:54:29.436414+00', 'Tai-Li-Lo', 1728, '');
INSERT INTO 'tune' VALUES (2903, NULL, '2012-01-20 12:54:29.439415+00', 'Tail Toddle', 9999, '');
INSERT INTO 'tune' VALUES (5113, NULL, '2012-01-20 12:54:37.1454+00', 'Minstrel Boy', 2145, '');
INSERT INTO 'tune' VALUES (2881, NULL, '2013-04-10 09:03:54.96442+00', 'Sing us a Song of Bonnie Scotland', 1621, '');
INSERT INTO 'tune' VALUES (2882, NULL, '2014-09-16 08:53:19.22322+00', 'Macfarlane o'' the Sprotts o'' Burnieboozie', 1532, '');
INSERT INTO 'tune' VALUES (2844, NULL, '2014-09-16 09:17:14.374401+00', 'Sally Pickers', 9999, '');
INSERT INTO 'tune' VALUES (625, NULL, '2018-02-24 10:24:45.494488+00', 'Green Shades of Gask, The', 9999, '');
INSERT INTO 'tune' VALUES (5115, NULL, '2012-01-20 12:54:37.151813+00', 'Leezie Lindsay', 9999, '');
INSERT INTO 'tune' VALUES (2907, NULL, '2012-01-20 12:54:29.453887+00', 'Duke of Edinburgh''s Strathspey, The', 9998, '');
INSERT INTO 'tune' VALUES (5116, NULL, '2012-01-20 12:54:37.154749+00', 'Lady Maxwell', 9998, '');
INSERT INTO 'tune' VALUES (2908, NULL, '2012-01-20 12:54:29.45688+00', 'Tatter Jack Walsh', 9999, '');
INSERT INTO 'tune' VALUES (2909, NULL, '2012-01-20 12:54:29.459888+00', 'Teddy Malo''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (5117, NULL, '2012-01-20 12:54:37.157652+00', 'Celtic Air', 9998, '');
INSERT INTO 'tune' VALUES (2910, NULL, '2012-01-20 12:54:29.462833+00', 'Girl I Left Behind Me, The', 9999, '');
INSERT INTO 'tune' VALUES (5118, NULL, '2012-01-20 12:54:37.16057+00', 'Sound of the Pibroch', 9999, '');
INSERT INTO 'tune' VALUES (2864, NULL, '2021-09-23 17:18:53.952612+00', 'Young Scotty', 1538, '');
INSERT INTO 'tune' VALUES (2911, NULL, '2012-01-20 12:54:29.465739+00', 'Duke of Atholl''s Highlanders, The', 9998, '');
INSERT INTO 'tune' VALUES (2912, NULL, '2012-01-20 12:54:29.469256+00', 'Jack''s Pocket Ashtray', 1757, '');
INSERT INTO 'tune' VALUES (2913, NULL, '2012-01-20 12:54:29.472195+00', 'That Elegant Style', 1644, '');
INSERT INTO 'tune' VALUES (2914, NULL, '2012-01-20 12:54:29.475112+00', 'That''s an Irish Lullaby', 9999, '');
INSERT INTO 'tune' VALUES (5120, NULL, '2012-01-20 12:54:37.166361+00', 'Mrs May', 9998, '');
INSERT INTO 'tune' VALUES (5121, NULL, '2012-01-20 12:54:37.169247+00', 'Craigpark', 9999, '');
INSERT INTO 'tune' VALUES (5122, NULL, '2012-01-20 12:54:37.172133+00', 'Mr & Mrs Tom Pett', 1555, '');
INSERT INTO 'tune' VALUES (5123, NULL, '2012-01-20 12:54:37.175042+00', 'Comin'' Through the Rye', 9999, '');
INSERT INTO 'tune' VALUES (5124, NULL, '2012-01-20 12:54:37.177935+00', 'Wha Saw the Forty Twa', 9999, '');
INSERT INTO 'tune' VALUES (5125, NULL, '2012-01-20 12:54:37.180822+00', 'Pibroch', 9999, '');
INSERT INTO 'tune' VALUES (5126, NULL, '2012-01-20 12:54:37.189237+00', 'Whistle O''er the Lave O''t', 2164, '');
INSERT INTO 'tune' VALUES (5127, NULL, '2012-01-20 12:54:37.193197+00', 'Bonnie Dancers', 1598, '');
INSERT INTO 'tune' VALUES (12152, '2012-06-12 16:07:58.549037+00', '2012-06-12 16:07:58.549047+00', 'Galbraith Gold', 2197, '');
INSERT INTO 'tune' VALUES (2906, NULL, '2012-11-29 07:42:30.291875+00', 'Turriff Schottische, The', 2286, '');
INSERT INTO 'tune' VALUES (2915, NULL, '2012-01-20 12:54:29.478015+00', '£10 Fiddle, The', 1512, '');
INSERT INTO 'tune' VALUES (2935, NULL, '2012-01-20 12:54:29.53796+00', 'Tobermory Two-Step, The', 1689, '');
INSERT INTO 'tune' VALUES (2916, NULL, '2012-01-20 12:54:29.481074+00', 'Andy Renwick''s Ferret', 3129, '');
INSERT INTO 'tune' VALUES (5128, NULL, '2012-01-20 12:54:37.197054+00', 'Up and Warn A'', Willie', 9999, '');
INSERT INTO 'tune' VALUES (2917, NULL, '2012-01-20 12:54:29.484058+00', 'Theme from Haydn', 1665, '');
INSERT INTO 'tune' VALUES (2936, NULL, '2012-01-20 12:54:29.540968+00', 'Tom Clement''s Reel', 1650, '');
INSERT INTO 'tune' VALUES (2918, NULL, '2012-01-20 12:54:29.48696+00', 'There Cam'' a Young Man', 9999, '');
INSERT INTO 'tune' VALUES (5129, NULL, '2012-01-20 12:54:37.200881+00', 'Miss B B Jardine', 9999, '');
INSERT INTO 'tune' VALUES (2919, NULL, '2012-01-20 12:54:29.489864+00', 'Jarl John Mathewson', 1711, '');
INSERT INTO 'tune' VALUES (2937, NULL, '2012-01-20 12:54:29.544462+00', 'Jim Connor''s Jig', 1525, '');
INSERT INTO 'tune' VALUES (2920, NULL, '2012-01-20 12:54:29.49347+00', 'There''s Nae Luck Aboot the Hoose', 9999, '');
INSERT INTO 'tune' VALUES (5130, NULL, '2012-01-20 12:54:37.204688+00', 'Alyth Tattie Pickers', 9999, '');
INSERT INTO 'tune' VALUES (2921, NULL, '2012-01-20 12:54:29.496409+00', 'Gordon''s Favourite', 1623, '');
INSERT INTO 'tune' VALUES (2938, NULL, '2012-01-20 12:54:29.547403+00', 'Tom Ireland''s Reel', 1558, '');
INSERT INTO 'tune' VALUES (2922, NULL, '2012-01-20 12:54:29.499408+00', 'This is no'' my Ain Lassie', 9999, '');
INSERT INTO 'tune' VALUES (5131, NULL, '2012-01-20 12:54:37.208501+00', 'Siege of Ennis', 9999, '');
INSERT INTO 'tune' VALUES (2923, NULL, '2012-01-20 12:54:29.502348+00', 'Thistle Centre, The', 1531, '');
INSERT INTO 'tune' VALUES (2939, NULL, '2012-01-20 12:54:29.550308+00', 'Tom Steele', 1502, '');
INSERT INTO 'tune' VALUES (2925, NULL, '2012-01-20 12:54:29.508153+00', 'Fencing Post, The', 1623, '');
INSERT INTO 'tune' VALUES (2940, NULL, '2012-01-20 12:54:29.553227+00', 'Tom Thumb', 9999, '');
INSERT INTO 'tune' VALUES (2926, NULL, '2012-01-20 12:54:29.511063+00', 'Thomas Mackay', 1675, '');
INSERT INTO 'tune' VALUES (5133, NULL, '2012-01-20 12:54:37.217321+00', 'Johnny Stewart the Piper', 1512, '');
INSERT INTO 'tune' VALUES (2927, NULL, '2012-01-20 12:54:29.513955+00', 'Wee Deoch an Doris, A', 1663, '');
INSERT INTO 'tune' VALUES (2941, NULL, '2012-01-20 12:54:29.556164+00', 'Miss Fiona MacDonald', 1507, '');
INSERT INTO 'tune' VALUES (2928, NULL, '2012-01-20 12:54:29.517482+00', 'Threave Castle Polka', 1558, '');
INSERT INTO 'tune' VALUES (5134, NULL, '2012-01-20 12:54:37.22027+00', 'Black Walnut', 9999, '');
INSERT INTO 'tune' VALUES (2942, NULL, '2012-01-20 12:54:29.559065+00', 'Too Much Throttle on the ''Kilmory''', 1642, '');
INSERT INTO 'tune' VALUES (5135, NULL, '2012-01-20 12:54:37.223169+00', 'On the Road to Cork', 9999, '');
INSERT INTO 'tune' VALUES (2929, NULL, '2012-01-20 12:54:29.520508+00', 'Throopmuir Croft', 1501, '');
INSERT INTO 'tune' VALUES (5136, NULL, '2012-01-20 12:54:37.226051+00', 'Blooming Meadows, The', 9999, '');
INSERT INTO 'tune' VALUES (2944, NULL, '2012-01-20 12:54:29.56498+00', 'Town Crier, The', 9999, '');
INSERT INTO 'tune' VALUES (2930, NULL, '2012-01-20 12:54:29.523455+00', 'Thumbs Up Aonghus', 1605, '');
INSERT INTO 'tune' VALUES (5137, NULL, '2012-01-20 12:54:37.228946+00', 'Kings Rant', 9998, '');
INSERT INTO 'tune' VALUES (2945, NULL, '2012-01-20 12:54:29.568504+00', 'Traditional Air', 9999, '');
INSERT INTO 'tune' VALUES (5138, NULL, '2012-01-20 12:54:37.231848+00', 'Turning Lathe, The', 9998, '');
INSERT INTO 'tune' VALUES (2931, NULL, '2012-01-20 12:54:29.526361+00', 'Dirk Kommer''s Reel', 1525, '');
INSERT INTO 'tune' VALUES (2946, NULL, '2012-01-20 12:54:29.571559+00', 'Aaron Mason''s Reel', 1591, '');
INSERT INTO 'tune' VALUES (5139, NULL, '2012-01-20 12:54:37.234733+00', 'Alloway Kirk', 1632, '');
INSERT INTO 'tune' VALUES (2947, NULL, '2012-01-20 12:54:29.574489+00', 'Doon Hingin'' Tie, The', 1613, '');
INSERT INTO 'tune' VALUES (2932, NULL, '2012-01-20 12:54:29.529253+00', 'Bessie Bell''s Reel', 1525, '');
INSERT INTO 'tune' VALUES (5140, NULL, '2012-01-20 12:54:37.2394+00', 'Earl of Glencairn', 9998, '');
INSERT INTO 'tune' VALUES (5141, NULL, '2012-01-20 12:54:37.243359+00', 'Highland Chieftain, The', 1518, '');
INSERT INTO 'tune' VALUES (2904, NULL, '2016-09-12 23:19:39.925113+00', 'Take the High Road', 1678, '');
INSERT INTO 'tune' VALUES (5114, NULL, '2017-11-25 16:56:29.803336+00', 'Corbie An Da Craa, Da', 9999, '');
INSERT INTO 'tune' VALUES (5132, NULL, '2017-11-09 15:12:00.41629+00', 'Cathkin Braes', 9998, '');
INSERT INTO 'tune' VALUES (2905, NULL, '2022-12-14 16:00:08.891409+00', 'Tam Lin', 1630, 'According to the tune sheet, this translates to "Howling Wind"');
INSERT INTO 'tune' VALUES (2933, NULL, '2012-01-20 12:54:29.532149+00', 'Miss Patricia Simpson''s Jig', 1596, '');
INSERT INTO 'tune' VALUES (2949, NULL, '2012-01-20 12:54:29.580282+00', 'Isla C Mcleod', 1564, '');
INSERT INTO 'tune' VALUES (5142, NULL, '2012-01-20 12:54:37.247182+00', 'Walter Douglas', 1910, '');
INSERT INTO 'tune' VALUES (2950, NULL, '2012-01-20 12:54:29.583275+00', 'Gibby Lang''s Jig', 1525, '');
INSERT INTO 'tune' VALUES (2934, NULL, '2012-01-20 12:54:29.535059+00', 'Tipperary Hills', 2153, '');
INSERT INTO 'tune' VALUES (5143, NULL, '2012-01-20 12:54:37.251013+00', 'Praties are Dug, The', 9999, '');
INSERT INTO 'tune' VALUES (2951, NULL, '2012-01-20 12:54:29.586251+00', 'Tune for Andy Burgess, A', 1652, '');
INSERT INTO 'tune' VALUES (5144, NULL, '2012-01-20 12:54:37.255131+00', 'Hoch Hey Johnnie Lad', 9999, '');
INSERT INTO 'tune' VALUES (2952, NULL, '2012-01-20 12:54:29.589896+00', 'Maureen''s Jig', 3052, '');
INSERT INTO 'tune' VALUES (2953, NULL, '2012-01-20 12:54:29.592821+00', 'Tynecastle Park', 1658, '');
INSERT INTO 'tune' VALUES (5145, NULL, '2012-01-20 12:54:37.259+00', 'Boatman of Pitnacree, The', 9999, '');
INSERT INTO 'tune' VALUES (2954, NULL, '2012-01-20 12:54:29.595729+00', 'Tom McVicar''s', 9999, '');
INSERT INTO 'tune' VALUES (2955, NULL, '2012-01-20 12:54:29.598629+00', 'Unknown, The', 9998, '');
INSERT INTO 'tune' VALUES (2956, NULL, '2012-01-20 12:54:29.601536+00', 'Valley Gold', 2776, '');
INSERT INTO 'tune' VALUES (5146, NULL, '2012-01-20 12:54:37.262811+00', 'Maid of Morven', 9999, '');
INSERT INTO 'tune' VALUES (2957, NULL, '2012-01-20 12:54:29.604455+00', 'Victoria Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (2958, NULL, '2012-01-20 12:54:29.607355+00', 'Saint Mary''s', 9999, '');
INSERT INTO 'tune' VALUES (2959, NULL, '2012-01-20 12:54:29.610334+00', 'Lady Presidents, The', 1502, '');
INSERT INTO 'tune' VALUES (5147, NULL, '2012-01-20 12:54:37.266635+00', 'Fair Young Mary', 9999, '');
INSERT INTO 'tune' VALUES (2960, NULL, '2012-01-20 12:54:29.613908+00', 'Waltz for Mary Kay', 1763, '');
INSERT INTO 'tune' VALUES (2961, NULL, '2012-01-20 12:54:29.616851+00', 'Wandering Drummer, The', 1558, '');
INSERT INTO 'tune' VALUES (2962, NULL, '2012-01-20 12:54:29.620197+00', 'Waters of Feugh, The', 1538, '');
INSERT INTO 'tune' VALUES (5148, NULL, '2012-01-20 12:54:37.270442+00', 'Farewell to Fuinary', 9999, '');
INSERT INTO 'tune' VALUES (2963, NULL, '2012-01-20 12:54:29.623701+00', 'Dennis Murphy', 9999, '');
INSERT INTO 'tune' VALUES (2964, NULL, '2012-01-20 12:54:29.626663+00', 'We''re No'' Awa tae Bide Awa''', 9999, '');
INSERT INTO 'tune' VALUES (2965, NULL, '2012-01-20 12:54:29.629662+00', 'MacDonald of the Isles (alternative tune)', 9999, '');
INSERT INTO 'tune' VALUES (5149, NULL, '2012-01-20 12:54:37.274568+00', 'Why Should I Sit and Sigh?', 9999, '');
INSERT INTO 'tune' VALUES (5150, NULL, '2012-01-20 12:54:37.278508+00', 'Hush-A-Bye Bairnie', 9999, '');
INSERT INTO 'tune' VALUES (5151, NULL, '2012-01-20 12:54:37.282609+00', 'Schiehallion', 9999, '');
INSERT INTO 'tune' VALUES (5152, NULL, '2012-01-20 12:54:37.28644+00', 'Lumps o'' Puddin''', 9999, '');
INSERT INTO 'tune' VALUES (12153, '2012-06-12 16:09:21.010109+00', '2012-06-12 16:09:21.01012+00', 'Mrs MacKenzie of Hazel Brae', 2158, '');
INSERT INTO 'tune' VALUES (2966, NULL, '2012-01-20 12:54:29.63257+00', 'Weavers of Newley, The', 9999, '');
INSERT INTO 'tune' VALUES (2978, NULL, '2012-01-20 12:54:29.669514+00', 'Who fears speak of the ''98', 9999, '');
INSERT INTO 'tune' VALUES (2967, NULL, '2012-01-20 12:54:29.636112+00', 'Wee Man at the Loom, The', 9999, '');
INSERT INTO 'tune' VALUES (5154, NULL, '2012-01-20 12:54:37.294071+00', 'Dr J G Hunter of Aultbea', 1669, '');
INSERT INTO 'tune' VALUES (2968, NULL, '2012-01-20 12:54:29.639076+00', 'Wee Murdie', 3058, '');
INSERT INTO 'tune' VALUES (2969, NULL, '2012-01-20 12:54:29.641978+00', 'Wee Red Seat, The', 1656, '');
INSERT INTO 'tune' VALUES (5155, NULL, '2012-01-20 12:54:37.298045+00', '6/8 March', 9998, '');
INSERT INTO 'tune' VALUES (2970, NULL, '2012-01-20 12:54:29.644879+00', 'Wee Sergeant, The', 9999, '');
INSERT INTO 'tune' VALUES (2980, NULL, '2012-01-20 12:54:29.675992+00', 'Barrowburn Reel, The', 2362, '');
INSERT INTO 'tune' VALUES (2971, NULL, '2012-01-20 12:54:29.647781+00', 'Welcome to Tyneside', 1658, '');
INSERT INTO 'tune' VALUES (5156, NULL, '2012-01-20 12:54:37.301853+00', 'Handsome Ploughboy, The', 9999, '');
INSERT INTO 'tune' VALUES (2972, NULL, '2012-01-20 12:54:29.650768+00', 'Wendy''s Jig', 1527, '');
INSERT INTO 'tune' VALUES (2981, NULL, '2012-01-20 12:54:29.678924+00', 'Dean Strathspey, The', 1525, '');
INSERT INTO 'tune' VALUES (2973, NULL, '2012-01-20 12:54:29.653676+00', 'West Kirkton', 1547, '');
INSERT INTO 'tune' VALUES (5157, NULL, '2012-01-20 12:54:37.305672+00', 'Flower of France and England O', 9998, '');
INSERT INTO 'tune' VALUES (2974, NULL, '2012-01-20 12:54:29.656603+00', 'West''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (2982, NULL, '2012-01-20 12:54:29.681827+00', 'Dewars of Kingskettle, The', 1507, '');
INSERT INTO 'tune' VALUES (2975, NULL, '2012-01-20 12:54:29.659945+00', 'MacPhail''s Magic', 1591, '');
INSERT INTO 'tune' VALUES (5158, NULL, '2012-01-20 12:54:37.310242+00', 'Birkwood Castle', 9999, '');
INSERT INTO 'tune' VALUES (2976, NULL, '2012-01-20 12:54:29.663564+00', 'What You Please', 9999, '');
INSERT INTO 'tune' VALUES (2983, NULL, '2012-01-20 12:54:29.684811+00', 'Birkland Jig, The', 1591, '');
INSERT INTO 'tune' VALUES (2977, NULL, '2012-01-20 12:54:29.666604+00', 'Where I was Yestreen', 9999, '');
INSERT INTO 'tune' VALUES (5159, NULL, '2012-01-20 12:54:37.314125+00', 'Beaver Hat', 9999, '');
INSERT INTO 'tune' VALUES (2984, NULL, '2012-01-20 12:54:29.688471+00', 'Willie Anderson of Condie', 1579, '');
INSERT INTO 'tune' VALUES (2985, NULL, '2012-01-20 12:54:29.691493+00', 'Willie Anderson of Dalharn', 1579, '');
INSERT INTO 'tune' VALUES (5160, NULL, '2012-01-20 12:54:37.318057+00', 'Carey Alexander''s Jig', 1558, '');
INSERT INTO 'tune' VALUES (2987, NULL, '2012-01-20 12:54:29.697333+00', 'Elizabeth Campbell''s Jig', 1608, '');
INSERT INTO 'tune' VALUES (2988, NULL, '2012-01-20 12:54:29.700225+00', 'Willie Davie', 9999, '');
INSERT INTO 'tune' VALUES (2989, NULL, '2012-01-20 12:54:29.703126+00', 'Willie Gillingham R M', 1502, '');
INSERT INTO 'tune' VALUES (5161, NULL, '2012-01-20 12:54:37.321878+00', 'Port Singil Gan Ainm', 9999, '');
INSERT INTO 'tune' VALUES (2990, NULL, '2012-01-20 12:54:29.706024+00', 'Willie MacLean of Aultbea', 1533, '');
INSERT INTO 'tune' VALUES (2991, NULL, '2012-01-20 12:54:29.709542+00', 'Willie the Woodcutter', 1531, '');
INSERT INTO 'tune' VALUES (2992, NULL, '2012-01-20 12:54:29.712565+00', 'Peter Rae''s Jig', 1525, '');
INSERT INTO 'tune' VALUES (5162, NULL, '2012-01-20 12:54:37.325677+00', 'John Kelly', 9999, '');
INSERT INTO 'tune' VALUES (2993, NULL, '2012-01-20 12:54:29.715544+00', 'Fergie''s Jig', 1525, '');
INSERT INTO 'tune' VALUES (2994, NULL, '2012-01-20 12:54:29.718448+00', 'Willie''s Rare and Willie''s Fair', 9999, '');
INSERT INTO 'tune' VALUES (5163, NULL, '2012-01-20 12:54:37.329663+00', 'Peter Straughan''s Reel', 1554, '');
INSERT INTO 'tune' VALUES (2996, NULL, '2012-01-20 12:54:29.72425+00', 'Windmill Bastion', 1502, '');
INSERT INTO 'tune' VALUES (2997, NULL, '2012-01-20 12:54:29.727162+00', 'Bonnie Woods of Craigielea, The', 9999, '');
INSERT INTO 'tune' VALUES (2998, NULL, '2012-01-20 12:54:29.73006+00', 'With My Shillelagh Under My Arm', 1638, '');
INSERT INTO 'tune' VALUES (5164, NULL, '2012-01-20 12:54:37.333496+00', 'Longueval', 9998, '');
INSERT INTO 'tune' VALUES (3000, NULL, '2012-01-20 12:54:29.736563+00', 'Ash Plant, The', 1726, '');
INSERT INTO 'tune' VALUES (5165, NULL, '2012-01-20 12:54:37.337723+00', 'Birkhall', 1588, '');
INSERT INTO 'tune' VALUES (3002, NULL, '2012-01-20 12:54:29.874785+00', 'Woodhaven Pier', 1658, '');
INSERT INTO 'tune' VALUES (3003, NULL, '2012-01-20 12:54:29.878758+00', 'Ye Banks and Braes', 9999, '');
INSERT INTO 'tune' VALUES (5166, NULL, '2012-01-20 12:54:37.341524+00', 'Dundee Weaver', 9999, '');
INSERT INTO 'tune' VALUES (5167, NULL, '2012-01-20 12:54:37.34566+00', 'Gentleman Soldier', 9999, '');
INSERT INTO 'tune' VALUES (3005, NULL, '2012-01-20 12:54:29.886456+00', 'Cape Breton Symphony''s Welcome to Shetland, The', 1677, '');
INSERT INTO 'tune' VALUES (3006, NULL, '2012-01-20 12:54:29.891022+00', 'Northlands, The', 1668, '');
INSERT INTO 'tune' VALUES (3007, NULL, '2012-01-20 12:54:29.895347+00', 'Wee Bus, The', 1769, '');
INSERT INTO 'tune' VALUES (5168, '2006-02-12 23:00:00+00', '2012-01-20 12:54:37.349513+00', 'West School, The', 1831, '');
INSERT INTO 'tune' VALUES (3008, NULL, '2012-01-20 12:54:29.89932+00', 'Peerie Willie', 1677, '');
INSERT INTO 'tune' VALUES (3009, NULL, '2012-01-20 12:54:29.903202+00', 'Jim Kennedy''s Jig', 1522, '');
INSERT INTO 'tune' VALUES (3010, NULL, '2012-01-20 12:54:29.907107+00', 'Bill Buchan', 1770, '');
INSERT INTO 'tune' VALUES (5169, NULL, '2012-01-20 12:54:37.35334+00', 'Happy New Year', 1872, '');
INSERT INTO 'tune' VALUES (3011, NULL, '2012-01-20 12:54:29.910994+00', 'MacLeod''s Farewell', 1769, '');
INSERT INTO 'tune' VALUES (3012, NULL, '2012-01-20 12:54:29.915336+00', 'Piper, Play the Light Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (3013, NULL, '2012-01-20 12:54:29.919463+00', 'Piper''s Cave, The', 1878, '');
INSERT INTO 'tune' VALUES (5170, NULL, '2012-01-20 12:54:37.357144+00', 'Tandem Jig', 2304, '');
INSERT INTO 'tune' VALUES (13842, '2018-02-25 22:46:13.476302+00', '2018-03-07 11:51:35.642201+00', 'Confiture Maison', 3220, '');
INSERT INTO 'tune' VALUES (3015, NULL, '2012-01-20 12:54:29.927209+00', 'Parnell''s Dragoons', 9999, '');
INSERT INTO 'tune' VALUES (3016, NULL, '2012-01-20 12:54:29.931049+00', 'Danny MacPhail''s Dilemma', 1527, '');
INSERT INTO 'tune' VALUES (3018, NULL, '2012-01-20 12:54:29.940259+00', 'Dean Brig Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (3019, NULL, '2012-01-20 12:54:29.943963+00', 'Sheilis', 1613, '');
INSERT INTO 'tune' VALUES (3020, NULL, '2012-01-20 12:54:29.946923+00', 'Bonnie Theekit Hoose, The', 1512, '');
INSERT INTO 'tune' VALUES (3021, NULL, '2012-01-20 12:54:29.949825+00', 'House in the Glen, The', 1771, '');
INSERT INTO 'tune' VALUES (3022, NULL, '2012-01-20 12:54:29.952828+00', 'Jig for June', 1576, '');
INSERT INTO 'tune' VALUES (3023, NULL, '2012-01-20 12:54:29.955804+00', 'Milton Bridge', 1525, '');
INSERT INTO 'tune' VALUES (3024, NULL, '2012-01-20 12:54:29.959418+00', 'Dollar Glen', 1613, '');
INSERT INTO 'tune' VALUES (3025, NULL, '2012-01-20 12:54:29.962435+00', 'Balmoral Castle', 1748, '');
INSERT INTO 'tune' VALUES (3026, NULL, '2012-01-20 12:54:29.96537+00', 'Harry C Ogilvie', 1554, '');
INSERT INTO 'tune' VALUES (3017, NULL, '2017-02-12 12:13:08.96564+00', 'Willie Mann of Paddy', 1646, '');
INSERT INTO 'tune' VALUES (2999, NULL, '2017-08-26 22:42:46.240331+00', 'John Brennan', 9999, '');
INSERT INTO 'tune' VALUES (13897, '2018-06-09 21:11:51.059933+00', '2018-06-09 21:11:51.059933+00', 'Flowerdale', 9999, '');
INSERT INTO 'tune' VALUES (3027, NULL, '2012-01-20 12:54:29.968314+00', 'Elizabeth Donald of Mosside', 1598, '');
INSERT INTO 'tune' VALUES (3028, NULL, '2012-01-20 12:54:29.971226+00', 'Mr & Mrs Bobby Jamieson', 1527, '');
INSERT INTO 'tune' VALUES (3029, NULL, '2012-01-20 12:54:29.974112+00', 'Cape Breton Jig in A', 9999, '');
INSERT INTO 'tune' VALUES (3030, NULL, '2012-01-20 12:54:29.977081+00', 'Cape Breton Jig in Gm', 9999, '');
INSERT INTO 'tune' VALUES (3031, NULL, '2012-01-20 12:54:29.980784+00', 'Bessie Bell and Mary Gray', 9999, '');
INSERT INTO 'tune' VALUES (3032, NULL, '2012-01-20 12:54:29.983722+00', 'Marquess of Lorn, The', 9999, '');
INSERT INTO 'tune' VALUES (3033, NULL, '2012-01-20 12:54:29.986611+00', 'Perthshire Volunteers, The', 1518, '');
INSERT INTO 'tune' VALUES (3034, NULL, '2012-01-20 12:54:29.989531+00', 'Lees of Luncarty, The', 9999, '');
INSERT INTO 'tune' VALUES (3056, NULL, '2012-01-20 12:54:30.055836+00', 'Airlie Bobbies', 1550, '');
INSERT INTO 'tune' VALUES (3035, NULL, '2012-01-20 12:54:29.992436+00', 'King''s Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (3036, NULL, '2012-01-20 12:54:29.995338+00', 'Saint Kilda Wedding', 9999, '');
INSERT INTO 'tune' VALUES (5171, NULL, '2012-01-20 12:54:37.361038+00', 'Queen''s Four Marys', 9999, '');
INSERT INTO 'tune' VALUES (3057, NULL, '2012-01-20 12:54:30.058868+00', 'Warwick''s Land', 1533, '');
INSERT INTO 'tune' VALUES (3037, NULL, '2012-01-20 12:54:29.998229+00', 'Elizabeth''s White Coat', 9999, '');
INSERT INTO 'tune' VALUES (5172, NULL, '2012-01-20 12:54:37.364856+00', 'Highland Fairy Lullaby', 9998, '');
INSERT INTO 'tune' VALUES (3058, NULL, '2012-01-20 12:54:30.062367+00', 'Trip to Tir Nan Og', 1582, '');
INSERT INTO 'tune' VALUES (3039, NULL, '2012-01-20 12:54:30.004174+00', 'Mirth and Melody', 1750, '');
INSERT INTO 'tune' VALUES (3040, NULL, '2012-01-20 12:54:30.007796+00', 'Cape Breton Symphony Strathspey, The', 1633, '');
INSERT INTO 'tune' VALUES (5173, NULL, '2012-01-20 12:54:37.368664+00', 'Anniesland', 1659, '');
INSERT INTO 'tune' VALUES (3059, NULL, '2012-01-20 12:54:30.065344+00', 'Cape Breton Favorite', 9999, '');
INSERT INTO 'tune' VALUES (3041, NULL, '2012-01-20 12:54:30.010784+00', 'Hilda''s Slow Strathspey', 1633, '');
INSERT INTO 'tune' VALUES (3042, NULL, '2012-01-20 12:54:30.0137+00', 'Miss MacLeod of Geanie', 1517, '');
INSERT INTO 'tune' VALUES (5174, NULL, '2012-01-20 12:54:37.372478+00', 'Primrose Polka', 2085, '');
INSERT INTO 'tune' VALUES (3060, NULL, '2012-01-20 12:54:30.06824+00', 'Guilderoy', 9999, '');
INSERT INTO 'tune' VALUES (3043, NULL, '2012-01-20 12:54:30.016602+00', 'Waltzing to Tokyo', 1773, '');
INSERT INTO 'tune' VALUES (3044, NULL, '2012-01-20 12:54:30.019497+00', 'To the Weavers', 9999, '');
INSERT INTO 'tune' VALUES (5175, NULL, '2012-01-20 12:54:37.376419+00', 'Jimmy''s Favourite Jig', 1452, '');
INSERT INTO 'tune' VALUES (3061, NULL, '2012-01-20 12:54:30.071162+00', 'Kenny Wilson''s Jig', 1668, '');
INSERT INTO 'tune' VALUES (3045, NULL, '2012-01-20 12:54:30.022496+00', 'Ho Ro, My Auburn-Haired-Maid', 9999, '');
INSERT INTO 'tune' VALUES (3046, NULL, '2012-01-20 12:54:30.025459+00', 'Donal'' Don', 9999, '');
INSERT INTO 'tune' VALUES (5176, NULL, '2012-01-20 12:54:37.380719+00', 'King Robin', 9998, '');
INSERT INTO 'tune' VALUES (3062, NULL, '2012-01-20 12:54:30.074078+00', 'Ian Barbour''s Jig', 1709, '');
INSERT INTO 'tune' VALUES (3047, NULL, '2012-01-20 12:54:30.02837+00', 'Gorthleck''s Highland Plaid', 9999, '');
INSERT INTO 'tune' VALUES (3004, NULL, '2014-11-17 01:05:06.588381+00', 'Ythan Bar', 1551, '');
INSERT INTO 'tune' VALUES (3048, NULL, '2012-01-20 12:54:30.031908+00', 'Miss Jessy Cumming', 9999, '');
INSERT INTO 'tune' VALUES (3063, NULL, '2012-01-20 12:54:30.330407+00', 'Kitty Tyrrell', 9999, '');
INSERT INTO 'tune' VALUES (3049, NULL, '2012-01-20 12:54:30.034898+00', 'Auld Reekie', 1773, '');
INSERT INTO 'tune' VALUES (3050, NULL, '2012-01-20 12:54:30.037797+00', 'Burns'' Night', 1773, '');
INSERT INTO 'tune' VALUES (5178, NULL, '2012-01-20 12:54:37.388438+00', 'Ca'' Canny', 9998, '');
INSERT INTO 'tune' VALUES (3064, NULL, '2012-01-20 12:54:30.333534+00', 'Rab Smillie''s Jig', 1777, '');
INSERT INTO 'tune' VALUES (3051, NULL, '2012-01-20 12:54:30.04078+00', 'Bridgeton Cross', 1773, '');
INSERT INTO 'tune' VALUES (3052, NULL, '2012-01-20 12:54:30.043708+00', 'Stan Hamilton', 1773, '');
INSERT INTO 'tune' VALUES (5179, NULL, '2012-01-20 12:54:37.392256+00', 'Duke of Rothesay', 9998, '');
INSERT INTO 'tune' VALUES (3065, NULL, '2012-01-20 12:54:30.336456+00', 'Ross Hunter', 1543, '');
INSERT INTO 'tune' VALUES (3053, NULL, '2012-01-20 12:54:30.046612+00', 'Susan''s Reel', 1773, '');
INSERT INTO 'tune' VALUES (3054, NULL, '2012-01-20 12:54:30.049516+00', 'Alasdair''s Awa''', 1773, '');
INSERT INTO 'tune' VALUES (5180, NULL, '2012-01-20 12:54:37.396074+00', 'Hidcote Manor', 9998, '');
INSERT INTO 'tune' VALUES (3066, NULL, '2012-01-20 12:54:30.339358+00', 'Maidens', 1533, '');
INSERT INTO 'tune' VALUES (3055, NULL, '2012-01-20 12:54:30.052427+00', 'Carfuffle Shuffle, The', 717, '');
INSERT INTO 'tune' VALUES (3067, NULL, '2012-01-20 12:54:30.342253+00', 'Maryhill Highlanders, The', 1554, '');
INSERT INTO 'tune' VALUES (5181, NULL, '2012-01-20 12:54:37.399985+00', 'Wallace, The', 9998, '');
INSERT INTO 'tune' VALUES (3068, NULL, '2012-01-20 12:54:30.345191+00', 'Fair Jenny''s Jig', 1779, '');
INSERT INTO 'tune' VALUES (3069, NULL, '2012-01-20 12:54:30.348845+00', 'Ghillies on the Golden Gate', 1780, '');
INSERT INTO 'tune' VALUES (3070, NULL, '2012-01-20 12:54:30.351826+00', 'Reduce Squirrel Unemployment!', 1780, '');
INSERT INTO 'tune' VALUES (5182, NULL, '2012-01-20 12:54:37.403794+00', 'Saint Mary''s Walk', 9998, '');
INSERT INTO 'tune' VALUES (3071, NULL, '2012-01-20 12:54:30.354848+00', 'Lady Gwyder', 1749, '');
INSERT INTO 'tune' VALUES (3072, NULL, '2012-01-20 12:54:30.357762+00', 'Waulking o'' the Feld', 9999, '');
INSERT INTO 'tune' VALUES (3073, NULL, '2012-01-20 12:54:30.360667+00', 'Airlie House', 1773, '');
INSERT INTO 'tune' VALUES (5183, NULL, '2012-01-20 12:54:37.407612+00', 'Isle o'' Walsay', 9999, '');
INSERT INTO 'tune' VALUES (3074, NULL, '2012-01-20 12:54:30.363571+00', 'Tommy''s Tarbukas', 1782, '');
INSERT INTO 'tune' VALUES (3075, NULL, '2012-01-20 12:54:30.366465+00', 'Con Cassidy''s Drowsy Maggie', 1783, '');
INSERT INTO 'tune' VALUES (5184, NULL, '2012-01-20 12:54:37.411421+00', 'Jim Moor''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (3076, NULL, '2012-01-20 12:54:30.369351+00', 'J.B. Reel', 1750, '');
INSERT INTO 'tune' VALUES (3077, NULL, '2012-01-20 12:54:30.373204+00', 'Delavaird Brig', 1646, '');
INSERT INTO 'tune' VALUES (3078, NULL, '2012-01-20 12:54:30.376288+00', 'Long Live the Queen', 1607, '');
INSERT INTO 'tune' VALUES (3079, NULL, '2012-01-20 12:54:30.379246+00', 'Carolynn''s Waltz', 1773, '');
INSERT INTO 'tune' VALUES (3080, NULL, '2012-01-20 12:54:30.382156+00', 'Patchwork Polka', 1613, '');
INSERT INTO 'tune' VALUES (3081, NULL, '2012-01-20 12:54:30.38505+00', 'Old Man''s Delight, The', 2259, '');
INSERT INTO 'tune' VALUES (5186, NULL, '2012-01-20 12:54:37.419698+00', 'Ashludie Rant, The', 1554, '');
INSERT INTO 'tune' VALUES (3082, NULL, '2012-01-20 12:54:30.38794+00', 'Eradynate House', 1785, '');
INSERT INTO 'tune' VALUES (3083, NULL, '2012-01-20 12:54:30.390837+00', 'Caisteal Chuimri', 9999, '');
INSERT INTO 'tune' VALUES (3084, NULL, '2012-01-20 12:54:30.393813+00', 'Miss Sarah Drummond of Perth', 9999, '');
INSERT INTO 'tune' VALUES (5187, NULL, '2012-01-20 12:54:37.423572+00', 'Isobel Taylor Bell', 1579, '');
INSERT INTO 'tune' VALUES (3085, NULL, '2012-01-20 12:54:30.397488+00', 'Crofter''s Wife, Da', 1786, '');
INSERT INTO 'tune' VALUES (3086, NULL, '2012-01-20 12:54:30.400419+00', 'Ferry Reel, Da', 9999, '');
INSERT INTO 'tune' VALUES (5188, NULL, '2012-01-20 12:54:37.427561+00', 'Absent-Minded Man, The', 9999, '');
INSERT INTO 'tune' VALUES (5189, NULL, '2012-01-20 12:54:37.431378+00', 'Hawick - Queen o'' all the Border', 453, '');
INSERT INTO 'tune' VALUES (5191, NULL, '2012-01-20 12:54:37.439025+00', 'Four Hundred Horsemen', 9999, '');
INSERT INTO 'tune' VALUES (5192, NULL, '2012-01-20 12:54:37.443069+00', 'Honeysuckle', 2153, '');
INSERT INTO 'tune' VALUES (5193, NULL, '2012-01-20 12:54:37.446933+00', 'Man from Newry, The', 9999, '');
INSERT INTO 'tune' VALUES (5194, NULL, '2012-01-20 12:54:37.453282+00', 'Madam Bonaparte', 9999, '');
INSERT INTO 'tune' VALUES (5195, NULL, '2012-01-20 12:54:37.457102+00', 'Marche aux Etoiles', 2314, '');
INSERT INTO 'tune' VALUES (5196, NULL, '2012-01-20 12:54:37.460925+00', 'Heroes of Kohima', 2315, '');
INSERT INTO 'tune' VALUES (12155, '2012-06-12 16:13:23.75737+00', '2012-06-12 16:13:23.757381+00', 'Other Left, The', 1631, '');
INSERT INTO 'tune' VALUES (3087, NULL, '2012-01-20 12:54:30.403323+00', 'Miss Seonaid Renton', 1596, '');
INSERT INTO 'tune' VALUES (3108, NULL, '2012-01-20 12:54:30.467035+00', 'Coldoch, The', 1795, '');
INSERT INTO 'tune' VALUES (5197, NULL, '2012-01-20 12:54:37.464741+00', 'Triste Sourire', 2316, '');
INSERT INTO 'tune' VALUES (3088, NULL, '2012-01-20 12:54:30.406223+00', 'Rosabell', 1787, '');
INSERT INTO 'tune' VALUES (3089, NULL, '2012-01-20 12:54:30.409135+00', 'Quodlibet, The', 1788, '');
INSERT INTO 'tune' VALUES (3109, NULL, '2012-01-20 12:54:30.469944+00', 'Struy Lodge', 1635, '');
INSERT INTO 'tune' VALUES (5198, NULL, '2012-01-20 12:54:37.468561+00', 'Kenny MacDonald''s Jig', 1553, '');
INSERT INTO 'tune' VALUES (3090, NULL, '2012-01-20 12:54:30.412229+00', 'Flight of the Islander, The', 1789, '');
INSERT INTO 'tune' VALUES (3091, NULL, '2012-01-20 12:54:30.41523+00', 'Twice Brewed', 1789, '');
INSERT INTO 'tune' VALUES (3110, NULL, '2012-01-20 12:54:30.472949+00', 'Staney Hill', 9999, '');
INSERT INTO 'tune' VALUES (5199, NULL, '2012-01-20 12:54:37.472369+00', 'Ladies'' Fancy', 9999, '');
INSERT INTO 'tune' VALUES (3092, NULL, '2012-01-20 12:54:30.418133+00', 'Leburn''s Highland Bagpipe', 1512, '');
INSERT INTO 'tune' VALUES (3093, NULL, '2012-01-20 12:54:30.422174+00', 'Mrs Will', 1512, '');
INSERT INTO 'tune' VALUES (5200, NULL, '2012-01-20 12:54:37.476174+00', 'High Road', 9999, '');
INSERT INTO 'tune' VALUES (3094, NULL, '2012-01-20 12:54:30.425099+00', 'Miss Ginning''s Fancy', 1516, '');
INSERT INTO 'tune' VALUES (3095, NULL, '2012-01-20 12:54:30.427994+00', 'Seamus Meehan''s', 9999, '');
INSERT INTO 'tune' VALUES (3112, NULL, '2012-01-20 12:54:30.479233+00', 'Morven House', 1558, '');
INSERT INTO 'tune' VALUES (5201, NULL, '2012-01-20 12:54:37.479973+00', 'Highland Minstrel Boy, The', 9999, '');
INSERT INTO 'tune' VALUES (3096, NULL, '2012-01-20 12:54:30.430891+00', 'Good En'' Well', 9999, '');
INSERT INTO 'tune' VALUES (3097, NULL, '2012-01-20 12:54:30.433837+00', 'Paraffin Paddy', 1580, '');
INSERT INTO 'tune' VALUES (3113, NULL, '2012-01-20 12:54:30.482139+00', 'Gertie Gibb', 1512, '');
INSERT INTO 'tune' VALUES (5202, NULL, '2012-01-20 12:54:37.48377+00', 'Tocherless Lass, The', 9999, '');
INSERT INTO 'tune' VALUES (3001, NULL, '2019-10-01 13:52:43.938699+00', 'Wing Commander Donald Mackenzie''s Reel', 1761, '');
INSERT INTO 'tune' VALUES (3098, NULL, '2012-01-20 12:54:30.43675+00', 'Lionel Muise', 1791, '');
INSERT INTO 'tune' VALUES (3099, NULL, '2012-01-20 12:54:30.439659+00', 'Buddy''s Favorite', 1791, '');
INSERT INTO 'tune' VALUES (3114, NULL, '2012-01-20 12:54:30.485416+00', 'Tibbie''s New Petticoat', 9999, '');
INSERT INTO 'tune' VALUES (5203, NULL, '2012-01-20 12:54:37.487573+00', 'Teinside Cottage', 2383, '');
INSERT INTO 'tune' VALUES (3100, NULL, '2012-01-20 12:54:30.442565+00', 'Alison Robertson''s Strathspey', 1507, '');
INSERT INTO 'tune' VALUES (3101, NULL, '2012-01-20 12:54:30.446221+00', 'Sheila Williams', 1505, '');
INSERT INTO 'tune' VALUES (3115, NULL, '2012-01-20 12:54:30.488336+00', 'John C Douglas', 1725, '');
INSERT INTO 'tune' VALUES (5204, NULL, '2012-01-20 12:54:37.491379+00', 'Braemar Gathering', 1699, '');
INSERT INTO 'tune' VALUES (3102, NULL, '2012-01-20 12:54:30.449148+00', 'Annabel''s Jig', 1605, '');
INSERT INTO 'tune' VALUES (3103, NULL, '2012-01-20 12:54:30.45205+00', 'Dalchenna House', 1596, '');
INSERT INTO 'tune' VALUES (5205, NULL, '2012-01-20 12:54:37.495184+00', 'Scotsmen Every One', 1663, '');
INSERT INTO 'tune' VALUES (3104, NULL, '2012-01-20 12:54:30.455046+00', 'Glenbucket Castle', 1748, '');
INSERT INTO 'tune' VALUES (3105, NULL, '2012-01-20 12:54:30.457963+00', 'Scott''s Jiggin''', 1793, '');
INSERT INTO 'tune' VALUES (3117, NULL, '2012-01-20 12:54:30.494138+00', 'Miss Jean Ritchie', 1521, '');
INSERT INTO 'tune' VALUES (5206, NULL, '2012-01-20 12:54:37.498984+00', 'Swallow', 9998, '');
INSERT INTO 'tune' VALUES (3106, NULL, '2012-01-20 12:54:30.460861+00', 'Mr & Mrs Bob Galloway', 1521, '');
INSERT INTO 'tune' VALUES (3107, NULL, '2012-01-20 12:54:30.464098+00', 'Mrs McNair Snadden''s Reel', 1795, '');
INSERT INTO 'tune' VALUES (3118, NULL, '2012-01-20 12:54:30.497146+00', 'Whistling Cowboy, The', 1655, '');
INSERT INTO 'tune' VALUES (5207, NULL, '2012-01-20 12:54:37.502786+00', 'Marie Pottinger''s Reel', 1623, '');
INSERT INTO 'tune' VALUES (3119, NULL, '2012-01-20 12:54:30.500065+00', 'Soho', 9999, '');
INSERT INTO 'tune' VALUES (5208, '2003-03-02 23:00:00+00', '2012-01-20 12:54:37.506593+00', 'Palindrome, The', 1526, '');
INSERT INTO 'tune' VALUES (3121, NULL, '2012-01-20 12:54:30.506572+00', 'Mrs Helen Russell', 1582, '');
INSERT INTO 'tune' VALUES (3122, NULL, '2012-01-20 12:54:30.509477+00', 'Happy May the Pair Be', 1615, '');
INSERT INTO 'tune' VALUES (3123, NULL, '2012-01-20 12:54:30.512372+00', 'Piteucher Jig, The', 1735, '');
INSERT INTO 'tune' VALUES (5209, NULL, '2012-01-20 12:54:37.510424+00', 'Arthur Bignold of Loch Rosque', 1889, '');
INSERT INTO 'tune' VALUES (3124, NULL, '2012-01-20 12:54:30.515301+00', 'Isle of Mull, The', 1701, '');
INSERT INTO 'tune' VALUES (5210, NULL, '2012-01-20 12:54:37.514221+00', 'Old Island Air', 9999, '');
INSERT INTO 'tune' VALUES (3125, NULL, '2012-01-20 12:54:30.51831+00', 'Coronation March', 1640, '');
INSERT INTO 'tune' VALUES (5211, NULL, '2012-01-20 12:54:37.518025+00', 'Hills O'' Perth', 9998, '');
INSERT INTO 'tune' VALUES (3126, NULL, '2012-01-20 12:54:30.521219+00', 'Frank and Maureen Robb', 1521, '');
INSERT INTO 'tune' VALUES (3127, NULL, '2012-01-20 12:54:30.52413+00', 'John Crawford of Freuchie', 1521, '');
INSERT INTO 'tune' VALUES (3128, NULL, '2012-01-20 12:54:30.527577+00', 'Red Lion, The', 1570, '');
INSERT INTO 'tune' VALUES (3129, NULL, '2012-01-20 12:54:30.531924+00', 'Miss Mary Gibb', 1522, '');
INSERT INTO 'tune' VALUES (5212, NULL, '2012-01-20 12:54:37.521827+00', 'Argyllshire Gathering', 1889, '');
INSERT INTO 'tune' VALUES (3130, NULL, '2012-01-20 12:54:30.534856+00', 'Jock Hosie''s Fancy', 1522, '');
INSERT INTO 'tune' VALUES (3131, NULL, '2012-01-20 12:54:30.538081+00', 'O Why I Left My Hame', 9999, '');
INSERT INTO 'tune' VALUES (5213, NULL, '2012-01-20 12:54:37.52566+00', 'Ray Horrick''s Reel', 2319, '');
INSERT INTO 'tune' VALUES (3133, NULL, '2012-01-20 12:54:30.543962+00', 'Cran Hill', 1538, '');
INSERT INTO 'tune' VALUES (3134, NULL, '2012-01-20 12:54:30.54687+00', 'Robin Brock''s Reel', 1554, '');
INSERT INTO 'tune' VALUES (3135, NULL, '2012-01-20 12:54:30.549769+00', 'Cumbria', 1593, '');
INSERT INTO 'tune' VALUES (5214, NULL, '2012-01-20 12:54:37.529641+00', 'David Cunningham''s Fancy', 2389, '');
INSERT INTO 'tune' VALUES (3136, NULL, '2012-01-20 12:54:30.55271+00', 'O Wha''s at the Window', 9999, '');
INSERT INTO 'tune' VALUES (3137, NULL, '2012-01-20 12:54:30.556362+00', 'Mrs Agnes Ritchie', 1521, '');
INSERT INTO 'tune' VALUES (3138, NULL, '2012-01-20 12:54:30.559371+00', 'William B Cunningham', 1521, '');
INSERT INTO 'tune' VALUES (5215, NULL, '2012-01-20 12:54:37.533444+00', 'Misses Farrell of Alloa', 1531, '');
INSERT INTO 'tune' VALUES (3139, NULL, '2012-01-20 12:54:30.56228+00', 'Bert Pozzi BSc', 1505, '');
INSERT INTO 'tune' VALUES (5216, NULL, '2012-01-20 12:54:37.537248+00', 'Bill Ireland', 1531, '');
INSERT INTO 'tune' VALUES (5217, NULL, '2012-01-20 12:54:37.541045+00', 'Easdale House', 2390, '');
INSERT INTO 'tune' VALUES (5218, NULL, '2012-01-20 12:54:37.544851+00', 'It''s Still Tuesday', 1780, '');
INSERT INTO 'tune' VALUES (5219, NULL, '2012-01-20 12:54:37.548659+00', 'Jogging in Hyde Park', 2319, '');
INSERT INTO 'tune' VALUES (5220, NULL, '2012-01-20 12:54:37.552454+00', 'Tam O'' Shanter', 1650, '');
INSERT INTO 'tune' VALUES (5221, NULL, '2012-01-20 12:54:37.556259+00', 'Tom Watson', 1531, '');
INSERT INTO 'tune' VALUES (5222, NULL, '2012-01-20 12:54:37.560068+00', 'Younie''s Reel', 2219, '');
INSERT INTO 'tune' VALUES (5223, NULL, '2012-01-20 12:54:37.563879+00', 'Dan McIldowie''s Reel', 1652, '');
INSERT INTO 'tune' VALUES (3140, NULL, '2012-01-20 12:54:30.56519+00', 'Fair Maid of Perth, The', 885, '');
INSERT INTO 'tune' VALUES (3160, NULL, '2012-01-20 12:54:30.625422+00', 'Ap Shenkin', 9999, '');
INSERT INTO 'tune' VALUES (5224, NULL, '2012-01-20 12:54:37.567691+00', 'Doune Castle', 9998, '');
INSERT INTO 'tune' VALUES (3141, NULL, '2012-01-20 12:54:30.5681+00', 'Roderick MacDonald', 9999, '');
INSERT INTO 'tune' VALUES (3142, NULL, '2012-01-20 12:54:30.571006+00', 'Aspen Bank', 9999, '');
INSERT INTO 'tune' VALUES (3161, NULL, '2012-01-20 12:54:30.628327+00', 'Railway, The', 9999, '');
INSERT INTO 'tune' VALUES (5225, NULL, '2012-01-20 12:54:37.57152+00', 'Pelstream Jig, The', 9998, '');
INSERT INTO 'tune' VALUES (3143, NULL, '2012-01-20 12:54:30.573901+00', 'Colonel Hamilton of Pencaitland', 9999, '');
INSERT INTO 'tune' VALUES (3144, NULL, '2012-01-20 12:54:30.577016+00', 'Earl of Dalhousie''s Happy Return to Scotland, The', 9999, '');
INSERT INTO 'tune' VALUES (5226, NULL, '2012-01-20 12:54:37.575319+00', 'Stirling Caledonian', 9998, '');
INSERT INTO 'tune' VALUES (3145, NULL, '2012-01-20 12:54:30.579979+00', 'Tom Dey', 1512, '');
INSERT INTO 'tune' VALUES (3146, NULL, '2012-01-20 12:54:30.583486+00', 'Pretty Peggy', 2145, '');
INSERT INTO 'tune' VALUES (3163, NULL, '2012-01-20 12:54:30.634836+00', 'Cocklawburn', 1502, '');
INSERT INTO 'tune' VALUES (5227, NULL, '2012-01-20 12:54:37.579121+00', 'Jack MacLeod''s Frolic', 9998, '');
INSERT INTO 'tune' VALUES (3148, NULL, '2012-01-20 12:54:30.589412+00', 'Mr Sharpe of Hoddam', 9999, '');
INSERT INTO 'tune' VALUES (3164, NULL, '2012-01-20 12:54:30.637738+00', 'Pinewoods Auction', 1502, '');
INSERT INTO 'tune' VALUES (5228, NULL, '2012-01-20 12:54:37.58293+00', 'Auld Scotch', 9998, '');
INSERT INTO 'tune' VALUES (3149, NULL, '2012-01-20 12:54:30.592307+00', 'Father O'' Flynn', 9999, '');
INSERT INTO 'tune' VALUES (3150, NULL, '2012-01-20 12:54:30.595325+00', 'Tell Her I Am', 2158, '');
INSERT INTO 'tune' VALUES (3165, NULL, '2012-01-20 12:54:30.640734+00', 'Engine Room, The', 1502, '');
INSERT INTO 'tune' VALUES (5229, NULL, '2012-01-20 12:54:37.586751+00', 'Road to Strathdon, The', 1531, '');
INSERT INTO 'tune' VALUES (3151, NULL, '2012-01-20 12:54:30.598338+00', 'Hey! Jenny, Come Down to Jock', 9999, 'Note the differences with the name of the dance');
INSERT INTO 'tune' VALUES (3152, NULL, '2012-01-20 12:54:30.601306+00', 'Sir John Henderson', 1518, '');
INSERT INTO 'tune' VALUES (3166, NULL, '2012-01-20 12:54:30.643639+00', 'Mrs Alice Anderson', 1502, '');
INSERT INTO 'tune' VALUES (5230, NULL, '2012-01-20 12:54:37.590546+00', 'Winding Forth', 9998, '');
INSERT INTO 'tune' VALUES (3153, NULL, '2012-01-20 12:54:30.604205+00', 'Lady MacKenzie of Gairloch', 9999, '');
INSERT INTO 'tune' VALUES (3154, NULL, '2012-01-20 12:54:30.607119+00', 'Oyster Wives'' Rant, The', 9999, '');
INSERT INTO 'tune' VALUES (3167, NULL, '2012-01-20 12:54:30.64654+00', 'Coirebreachan', 1502, '');
INSERT INTO 'tune' VALUES (5231, NULL, '2012-01-20 12:54:37.594355+00', 'Wallace and Thomas', 2392, '');
INSERT INTO 'tune' VALUES (3155, NULL, '2012-01-20 12:54:30.610039+00', 'Briodag Aim M''Omish', 9999, '');
INSERT INTO 'tune' VALUES (3156, NULL, '2012-01-20 12:54:30.613688+00', 'Loch Earn', 1517, '');
INSERT INTO 'tune' VALUES (3168, NULL, '2012-01-20 12:54:30.649436+00', 'Mark''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (5232, NULL, '2012-01-20 12:54:37.598146+00', 'London Scottish', 9998, '');
INSERT INTO 'tune' VALUES (3157, NULL, '2012-01-20 12:54:30.616645+00', 'Piper''s Glass, The', 9999, '');
INSERT INTO 'tune' VALUES (3158, NULL, '2012-01-20 12:54:30.61961+00', 'Nell Flaherty''s Drake', 9999, '');
INSERT INTO 'tune' VALUES (3169, NULL, '2012-01-20 12:54:30.65236+00', 'Margo''s Love', 1502, '');
INSERT INTO 'tune' VALUES (5233, NULL, '2012-01-20 12:54:37.601945+00', 'Dunster Reel', 9998, '');
INSERT INTO 'tune' VALUES (3159, NULL, '2012-01-20 12:54:30.622526+00', 'Denis, Don''t be Threatening', 2145, '');
INSERT INTO 'tune' VALUES (3170, NULL, '2012-01-20 12:54:30.656013+00', 'Colly Skerr', 1502, '');
INSERT INTO 'tune' VALUES (3171, NULL, '2012-01-20 12:54:30.659456+00', 'City of Port Elizabeth', 1502, '');
INSERT INTO 'tune' VALUES (5234, NULL, '2012-01-20 12:54:37.606309+00', 'Pipe Jig', 9998, '');
INSERT INTO 'tune' VALUES (3172, NULL, '2012-01-20 12:54:30.662543+00', 'Corner Cottage Waltz', 1502, '');
INSERT INTO 'tune' VALUES (3173, NULL, '2012-01-20 12:54:30.665457+00', 'From Southport to Melbourne', 1502, '');
INSERT INTO 'tune' VALUES (3174, NULL, '2012-01-20 12:54:30.668364+00', 'Leslye''s Waltz', 1502, '');
INSERT INTO 'tune' VALUES (5235, NULL, '2012-01-20 12:54:37.610146+00', 'Mull of the Cool High Bens', 2595, '');
INSERT INTO 'tune' VALUES (3175, NULL, '2012-01-20 12:54:30.671267+00', 'Tullybaccart', 1502, '');
INSERT INTO 'tune' VALUES (3176, NULL, '2012-01-20 12:54:30.674161+00', 'Grey-Faced Ewe, The', 1502, '');
INSERT INTO 'tune' VALUES (3177, NULL, '2012-01-20 12:54:30.677058+00', 'Jackie Lindsay', 1502, '');
INSERT INTO 'tune' VALUES (5236, NULL, '2012-01-20 12:54:37.614033+00', 'Cuckoo', 9999, '');
INSERT INTO 'tune' VALUES (3178, NULL, '2012-01-20 12:54:30.680077+00', 'Coldingham', 1502, '');
INSERT INTO 'tune' VALUES (3179, NULL, '2012-01-20 12:54:30.683742+00', 'Half a Ton', 1502, '');
INSERT INTO 'tune' VALUES (5237, NULL, '2012-01-20 12:54:37.617843+00', 'Galley of Lorne', 9999, '');
INSERT INTO 'tune' VALUES (3180, NULL, '2012-01-20 12:54:30.686751+00', 'Diane Thorburn Holden', 1502, '');
INSERT INTO 'tune' VALUES (5238, NULL, '2012-01-20 12:54:37.621643+00', 'Standing Stones', 848, '');
INSERT INTO 'tune' VALUES (3181, NULL, '2012-01-20 12:54:30.689658+00', 'College Reel, The', 1502, '');
INSERT INTO 'tune' VALUES (3182, NULL, '2012-01-20 12:54:30.692564+00', 'Wright''s Hornpipe', 1502, '');
INSERT INTO 'tune' VALUES (3183, NULL, '2012-01-20 12:54:30.695462+00', 'Walking the Dogs', 1502, '');
INSERT INTO 'tune' VALUES (3184, NULL, '2012-01-20 12:54:30.698364+00', 'Fred''s Fancy', 1502, '');
INSERT INTO 'tune' VALUES (3185, NULL, '2012-01-20 12:54:30.701337+00', 'Ayton Jig', 1502, '');
INSERT INTO 'tune' VALUES (5239, NULL, '2012-01-20 12:54:37.625457+00', 'Walls of Troy, The', 9998, '');
INSERT INTO 'tune' VALUES (3186, NULL, '2012-01-20 12:54:30.704261+00', 'Dawning of the Day, The', 1502, '');
INSERT INTO 'tune' VALUES (3187, NULL, '2012-01-20 12:54:30.707979+00', 'Awakening, The', 1502, '');
INSERT INTO 'tune' VALUES (3188, NULL, '2012-01-20 12:54:30.710953+00', 'Laxo Burn', 1644, '');
INSERT INTO 'tune' VALUES (5240, NULL, '2012-01-20 12:54:37.629256+00', 'Walls of Limerick, The', 9998, '');
INSERT INTO 'tune' VALUES (3189, NULL, '2012-01-20 12:54:30.713893+00', 'Finella', 1607, '');
INSERT INTO 'tune' VALUES (3190, NULL, '2012-01-20 12:54:30.716815+00', 'Eavesdropper, The', 9999, '');
INSERT INTO 'tune' VALUES (3191, NULL, '2012-01-20 12:54:30.720215+00', 'Guid to Ken Ye', 1329, '');
INSERT INTO 'tune' VALUES (5241, NULL, '2012-01-20 12:54:37.633065+00', 'Fair Lullaby, A', 9998, '');
INSERT INTO 'tune' VALUES (3192, NULL, '2012-01-20 12:54:30.723221+00', 'Farewell to Whisky, O', 1512, '');
INSERT INTO 'tune' VALUES (5242, NULL, '2012-01-20 12:54:37.636864+00', 'Queen''s Welcome to Duart Castle', 9998, '');
INSERT INTO 'tune' VALUES (5244, NULL, '2012-01-20 12:54:37.644504+00', 'Seagull, The', 9998, '');
INSERT INTO 'tune' VALUES (5245, NULL, '2012-01-20 12:54:37.648309+00', 'Doreen''s Reel', 1629, '');
INSERT INTO 'tune' VALUES (5247, NULL, '2012-01-20 12:54:37.655918+00', 'Miss Eleonora Robertson''s Favourite', 1518, '');
INSERT INTO 'tune' VALUES (5248, NULL, '2012-01-20 12:54:37.660191+00', 'Miss C Montgomery ''Skermolies', 9998, '');
INSERT INTO 'tune' VALUES (5249, NULL, '2012-01-20 12:54:37.664027+00', 'Brig o'' Blair', 1579, '');
INSERT INTO 'tune' VALUES (3210, NULL, '2018-08-17 16:04:35.146128+00', 'Highlands of Banffshire', 9999, '');
INSERT INTO 'tune' VALUES (3213, NULL, '2012-01-20 12:54:30.788201+00', 'John Taylor of San Jose', 1505, '');
INSERT INTO 'tune' VALUES (5250, NULL, '2012-01-20 12:54:37.667836+00', 'Back-Peddlin'' Mudguard', 2550, '');
INSERT INTO 'tune' VALUES (3193, NULL, '2012-01-20 12:54:30.726163+00', 'Finlay is his Father''s Darling', 9999, '');
INSERT INTO 'tune' VALUES (3194, NULL, '2012-01-20 12:54:30.729785+00', 'Headteacher, The', 1778, '');
INSERT INTO 'tune' VALUES (3214, NULL, '2012-01-20 12:54:30.791228+00', 'Blue Mull Soond', 1710, '');
INSERT INTO 'tune' VALUES (5251, NULL, '2012-01-20 12:54:37.671667+00', 'Blink Bonny, The', 1512, '');
INSERT INTO 'tune' VALUES (3276, NULL, '2012-01-20 12:54:30.983612+00', 'Slievenamon', 9999, '');
INSERT INTO 'tune' VALUES (3195, NULL, '2012-01-20 12:54:30.732727+00', 'Miss Margaret Brown''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (3196, NULL, '2012-01-20 12:54:30.735639+00', 'Patty''s Flute', 1745, '');
INSERT INTO 'tune' VALUES (3215, NULL, '2012-01-20 12:54:30.794122+00', 'Trip to Windsor', 1766, '');
INSERT INTO 'tune' VALUES (5252, NULL, '2012-01-20 12:54:37.675516+00', 'Duntroon Castle', 1644, '');
INSERT INTO 'tune' VALUES (3197, NULL, '2012-01-20 12:54:30.738551+00', 'Marci''s Strathspey', 1745, '');
INSERT INTO 'tune' VALUES (3198, NULL, '2012-01-20 12:54:30.742135+00', 'Aberdeen City Festival Strathspey', 1803, '');
INSERT INTO 'tune' VALUES (3216, NULL, '2012-01-20 12:54:30.797007+00', 'Michael Calder', 1558, '');
INSERT INTO 'tune' VALUES (5253, NULL, '2012-01-20 12:54:37.679313+00', 'Cuckoo Waltz, The', 2481, '');
INSERT INTO 'tune' VALUES (3199, NULL, '2012-01-20 12:54:30.745062+00', 'Miss Susan Cooper', 1623, '');
INSERT INTO 'tune' VALUES (3200, NULL, '2012-01-20 12:54:30.747976+00', 'Swarrbanks Minn', 1710, '');
INSERT INTO 'tune' VALUES (3217, NULL, '2012-01-20 12:54:30.799902+00', 'Below the Aigas Dam', 1761, '');
INSERT INTO 'tune' VALUES (5254, NULL, '2012-01-20 12:54:37.68311+00', 'Kiwi Records', 9998, '');
INSERT INTO 'tune' VALUES (3201, NULL, '2012-01-20 12:54:30.750869+00', 'Ron Ramsay''s Reel', 1507, '');
INSERT INTO 'tune' VALUES (3202, NULL, '2012-01-20 12:54:30.753761+00', 'Stroopie Brae, The', 1804, '');
INSERT INTO 'tune' VALUES (3218, NULL, '2012-01-20 12:54:30.8029+00', 'Gordon Shand''s Compliments to Mrs Yasumuro', 1808, '');
INSERT INTO 'tune' VALUES (5255, NULL, '2012-01-20 12:54:37.686922+00', 'Eilean Donan Castle', 2319, '');
INSERT INTO 'tune' VALUES (3203, NULL, '2012-01-20 12:54:30.756671+00', 'Dave Ford''s Jig', 1811, '');
INSERT INTO 'tune' VALUES (3204, NULL, '2012-01-20 12:54:30.760568+00', 'Cunningsburgh Lassies', 1805, '');
INSERT INTO 'tune' VALUES (3219, NULL, '2012-01-20 12:54:30.805829+00', 'George Harrison''s Reel', 1558, '');
INSERT INTO 'tune' VALUES (5246, NULL, '2021-05-12 18:50:14.358653+00', 'Humours of Donnybrook, The', 9999, '');
INSERT INTO 'tune' VALUES (5256, NULL, '2012-01-20 12:54:37.690729+00', 'Old Highland Air', 9999, '');
INSERT INTO 'tune' VALUES (3205, NULL, '2012-01-20 12:54:30.763603+00', 'Miss Shirley Ashdown', 2085, '');
INSERT INTO 'tune' VALUES (3206, NULL, '2012-01-20 12:54:30.76652+00', 'Herr Roloff''s Farewell', 1512, '');
INSERT INTO 'tune' VALUES (3220, NULL, '2012-01-20 12:54:30.808731+00', 'Boy''s Lament for his Dragon, The', 9999, '');
INSERT INTO 'tune' VALUES (5257, NULL, '2012-01-20 12:54:37.694536+00', 'L J C Irvine', 9998, '');
INSERT INTO 'tune' VALUES (3207, NULL, '2012-01-20 12:54:30.76942+00', 'Lady Louisa Russell''s Jig', 1516, '');
INSERT INTO 'tune' VALUES (3208, NULL, '2012-01-20 12:54:30.772327+00', 'Mrs Hamilton''s Quadrille', 1807, '');
INSERT INTO 'tune' VALUES (3221, NULL, '2012-01-20 12:54:30.81256+00', 'Faraway Grandchild, The', 1809, '');
INSERT INTO 'tune' VALUES (5258, NULL, '2012-01-20 12:54:37.698349+00', 'Murdo Mackenzie of Plockton', 9998, '');
INSERT INTO 'tune' VALUES (3209, NULL, '2012-01-20 12:54:30.775237+00', 'Compliments to Allie Anderson', 1542, '');
INSERT INTO 'tune' VALUES (3222, NULL, '2012-01-20 12:54:30.815508+00', 'Duncan Campbell of Oban', 1543, '');
INSERT INTO 'tune' VALUES (5259, NULL, '2012-01-20 12:54:37.702146+00', 'John Kirkpatrick''s Fancy', 9998, '');
INSERT INTO 'tune' VALUES (3211, NULL, '2012-01-20 12:54:30.781108+00', 'Bonny Boy, The', 1766, '');
INSERT INTO 'tune' VALUES (3212, NULL, '2012-01-20 12:54:30.78401+00', 'Young Rabbit, The', 1710, '');
INSERT INTO 'tune' VALUES (3223, NULL, '2012-01-20 12:54:30.818583+00', 'Mrs Joan Newby', 1527, '');
INSERT INTO 'tune' VALUES (5260, NULL, '2012-01-20 12:54:37.705953+00', 'Lannagan''s Ball', 9999, '');
INSERT INTO 'tune' VALUES (3224, NULL, '2012-01-20 12:54:30.821572+00', 'Skye Barbecue', 1782, '');
INSERT INTO 'tune' VALUES (3225, NULL, '2012-01-20 12:54:30.824489+00', 'Fiona''s Dance Diaries', 1507, '');
INSERT INTO 'tune' VALUES (3226, NULL, '2012-01-20 12:54:30.82739+00', 'Luggin'' The Amp', 1590, '');
INSERT INTO 'tune' VALUES (5261, NULL, '2012-01-20 12:54:37.709764+00', 'Gayton''s Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (3227, NULL, '2012-01-20 12:54:30.830289+00', 'Aunt Mary''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (3228, NULL, '2012-01-20 12:54:30.833186+00', 'Travelling on the Tube', 1590, '');
INSERT INTO 'tune' VALUES (3229, NULL, '2012-01-20 12:54:30.837085+00', 'July Jig', 1538, '');
INSERT INTO 'tune' VALUES (5262, NULL, '2012-01-20 12:54:37.713564+00', 'John D. Burgess', 2227, '');
INSERT INTO 'tune' VALUES (3230, NULL, '2012-01-20 12:54:30.840056+00', 'Miss Harriet Milbourne''s Reel', 1754, '');
INSERT INTO 'tune' VALUES (3231, NULL, '2012-01-20 12:54:30.843046+00', 'Redesdale Hornpipe, The', 1625, '');
INSERT INTO 'tune' VALUES (3232, NULL, '2012-01-20 12:54:30.845957+00', 'Davie Taylor', 1512, '');
INSERT INTO 'tune' VALUES (5263, NULL, '2012-01-20 12:54:37.717376+00', 'Angus MacKinnon', 1426, '');
INSERT INTO 'tune' VALUES (3233, NULL, '2012-01-20 12:54:30.848851+00', 'Miller''s Rant, The', 1512, '');
INSERT INTO 'tune' VALUES (3234, NULL, '2012-01-20 12:54:30.851955+00', 'Waterloo Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (3235, NULL, '2012-01-20 12:54:30.856307+00', 'Popinjay, The', 1814, '');
INSERT INTO 'tune' VALUES (3236, NULL, '2012-01-20 12:54:30.859342+00', 'Constitution Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (5264, NULL, '2012-01-20 12:54:37.72121+00', 'Daphne Taylor', 2194, '');
INSERT INTO 'tune' VALUES (3237, NULL, '2012-01-20 12:54:30.862306+00', 'Quarter Deck', 9999, '');
INSERT INTO 'tune' VALUES (3238, NULL, '2012-01-20 12:54:30.86525+00', 'Wallace Tower, The', 1502, '');
INSERT INTO 'tune' VALUES (3239, NULL, '2012-01-20 12:54:30.868149+00', 'Bill Clement', 1815, '');
INSERT INTO 'tune' VALUES (5265, NULL, '2012-01-20 12:54:37.725004+00', 'Jamie Rae', 9999, '');
INSERT INTO 'tune' VALUES (3240, NULL, '2012-01-20 12:54:30.871136+00', 'Crow Road, The', 1815, '');
INSERT INTO 'tune' VALUES (3241, NULL, '2012-01-20 12:54:30.874089+00', 'When Dewy Fields Are Green', 1814, '');
INSERT INTO 'tune' VALUES (3242, NULL, '2012-01-20 12:54:30.877558+00', 'Pigeon on the Gate, The', 9999, '');
INSERT INTO 'tune' VALUES (5266, NULL, '2012-01-20 12:54:37.72902+00', 'Upper Denton', 9999, '');
INSERT INTO 'tune' VALUES (3243, NULL, '2012-01-20 12:54:30.880512+00', 'Walking on the Moon', 2362, '');
INSERT INTO 'tune' VALUES (5267, NULL, '2012-01-20 12:54:37.732831+00', 'Clydeside', 9999, '');
INSERT INTO 'tune' VALUES (5270, NULL, '2012-01-20 12:54:37.744245+00', 'Brazilia', 9998, '');
INSERT INTO 'tune' VALUES (5271, NULL, '2012-01-20 12:54:37.74827+00', 'Fear A Feuge', 9999, '');
INSERT INTO 'tune' VALUES (5272, NULL, '2012-01-20 12:54:37.752095+00', 'Newcastle Bridge', 1401, '');
INSERT INTO 'tune' VALUES (3244, NULL, '2012-01-20 12:54:30.883809+00', 'Miss Dale', 9999, '');
INSERT INTO 'tune' VALUES (3245, NULL, '2012-01-20 12:54:30.886797+00', 'Carlingwark Hornpipe', 1504, '');
INSERT INTO 'tune' VALUES (5273, NULL, '2012-01-20 12:54:37.755926+00', 'Lady Louisa Gordon''s Strathspey', 1519, 'This tune is, in fact, by Robert Mackintosh -- even though <<ddp:William Marshall>> wrote many tunes for other members of the Duke of Gordon''s family (his day job was factor for the Duke of Gordon). There''s a William Marshall tune called <<ddt:Lady Louisa Gordon''s Reel>> (not strathspey) but it has nothing to do with this tune.');
INSERT INTO 'tune' VALUES (3246, NULL, '2012-01-20 12:54:30.889706+00', 'Tomtain Brae', 1507, '');
INSERT INTO 'tune' VALUES (3268, NULL, '2012-01-20 12:54:30.960308+00', 'Ray''s Reel', 1502, '');
INSERT INTO 'tune' VALUES (3247, NULL, '2012-01-20 12:54:30.892598+00', 'Blackhall', 1501, '');
INSERT INTO 'tune' VALUES (5274, NULL, '2012-01-20 12:54:37.759799+00', 'Miss Clementina Drummond', 9999, '');
INSERT INTO 'tune' VALUES (3248, NULL, '2012-01-20 12:54:30.896024+00', 'Wiston Lodge', 1508, '');
INSERT INTO 'tune' VALUES (3269, NULL, '2012-01-20 12:54:30.963213+00', 'Miss Anne Hughes', 1502, '');
INSERT INTO 'tune' VALUES (3249, NULL, '2012-01-20 12:54:30.898992+00', 'Redheugh', 1502, '');
INSERT INTO 'tune' VALUES (5275, NULL, '2012-01-20 12:54:37.763606+00', 'Clyde Hornpipe, The', 9998, '');
INSERT INTO 'tune' VALUES (3270, NULL, '2012-01-20 12:54:30.966187+00', 'Colin Lander''s Reel', 1502, '');
INSERT INTO 'tune' VALUES (3251, NULL, '2012-01-20 12:54:30.905038+00', 'Cutting Ferns', 9999, '');
INSERT INTO 'tune' VALUES (5276, NULL, '2012-01-20 12:54:37.76741+00', 'Lethamhill', 9998, '');
INSERT INTO 'tune' VALUES (3252, NULL, '2012-01-20 12:54:30.907956+00', 'Peter Baillie', 1512, '');
INSERT INTO 'tune' VALUES (3271, NULL, '2012-01-20 12:54:30.969088+00', 'Gaelforce Wind', 1673, '');
INSERT INTO 'tune' VALUES (3253, NULL, '2012-01-20 12:54:30.91086+00', 'Betty Keir''s Reel', 1594, '');
INSERT INTO 'tune' VALUES (5277, NULL, '2012-01-20 12:54:37.771213+00', 'I Wish I Were Married', 9998, '');
INSERT INTO 'tune' VALUES (3254, NULL, '2012-01-20 12:54:30.914976+00', 'Corn Field', 9999, '');
INSERT INTO 'tune' VALUES (3272, NULL, '2012-01-20 12:54:30.971979+00', 'Sound of Islay, The', 1824, '');
INSERT INTO 'tune' VALUES (3255, NULL, '2012-01-20 12:54:30.919387+00', 'Wood''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (5278, NULL, '2012-01-20 12:54:37.77501+00', 'Prince of Wales, The', 1632, '');
INSERT INTO 'tune' VALUES (3256, NULL, '2012-01-20 12:54:30.923287+00', 'Blairnanes Rant', 1512, '');
INSERT INTO 'tune' VALUES (3273, NULL, '2012-01-20 12:54:30.974876+00', 'Glenview', 1537, '');
INSERT INTO 'tune' VALUES (3257, NULL, '2012-01-20 12:54:30.926349+00', 'Hunters Hill', 1512, '');
INSERT INTO 'tune' VALUES (5279, NULL, '2012-01-20 12:54:37.778811+00', 'Dolly MacLean of Aultbea', 2266, '');
INSERT INTO 'tune' VALUES (3258, NULL, '2012-01-20 12:54:30.930891+00', 'John Worth''s Jig', 1652, '');
INSERT INTO 'tune' VALUES (3274, NULL, '2012-01-20 12:54:30.977766+00', 'Susan Jane Barr', 1831, '');
INSERT INTO 'tune' VALUES (3259, NULL, '2012-01-20 12:54:30.933881+00', 'Jack Campbell', 228, '');
INSERT INTO 'tune' VALUES (5280, NULL, '2012-01-20 12:54:37.782611+00', 'Forth Road Bridge Silver Jubilee, The', 1585, '');
INSERT INTO 'tune' VALUES (3260, NULL, '2012-01-20 12:54:30.936854+00', 'Orton House', 1470, '');
INSERT INTO 'tune' VALUES (3275, NULL, '2012-01-20 12:54:30.980678+00', 'Gertrude''s Delight', 1832, '');
INSERT INTO 'tune' VALUES (3261, NULL, '2012-01-20 12:54:30.939904+00', 'Arbeadie', 1512, '');
INSERT INTO 'tune' VALUES (5281, NULL, '2012-01-20 12:54:37.786392+00', 'Quayside, The', 9998, '');
INSERT INTO 'tune' VALUES (3262, NULL, '2012-01-20 12:54:30.942825+00', 'Jessie Walker', 1502, '');
INSERT INTO 'tune' VALUES (3263, NULL, '2012-01-20 12:54:30.945792+00', 'Alastair Ross Taylor', 1502, '');
INSERT INTO 'tune' VALUES (5282, NULL, '2012-01-20 12:54:37.790455+00', 'Blaydon Flats', 9999, '');
INSERT INTO 'tune' VALUES (3264, NULL, '2012-01-20 12:54:30.948685+00', 'Reversal, The', 1502, '');
INSERT INTO 'tune' VALUES (3277, NULL, '2012-01-20 12:54:30.986572+00', 'Hills o'' Castlereagh', 1833, '');
INSERT INTO 'tune' VALUES (3265, NULL, '2012-01-20 12:54:30.95159+00', 'Castle Hill', 1502, '');
INSERT INTO 'tune' VALUES (5283, NULL, '2012-01-20 12:54:37.794248+00', 'Mrs Jean Cameron', 1646, '');
INSERT INTO 'tune' VALUES (3266, NULL, '2012-01-20 12:54:30.95448+00', 'Balmoral Castle', 2478, '');
INSERT INTO 'tune' VALUES (3278, NULL, '2012-01-20 12:54:30.98992+00', 'Glenariff', 1537, '');
INSERT INTO 'tune' VALUES (5284, NULL, '2012-01-20 12:54:37.798047+00', 'Amelia''s Waltz', 2125, '');
INSERT INTO 'tune' VALUES (3279, NULL, '2012-01-20 12:54:30.992846+00', 'Lagan Streams', 1832, '');
INSERT INTO 'tune' VALUES (3280, NULL, '2012-01-20 12:54:30.995742+00', 'Golden Corn, The', 1537, '');
INSERT INTO 'tune' VALUES (3281, NULL, '2012-01-20 12:54:30.998634+00', 'Bunegee', 1537, '');
INSERT INTO 'tune' VALUES (5285, NULL, '2012-01-20 12:54:37.801861+00', 'Old Saint Paul''s', 1567, '');
INSERT INTO 'tune' VALUES (3282, NULL, '2012-01-20 12:54:31.001525+00', 'Skye Lullaby', 9999, '');
INSERT INTO 'tune' VALUES (3283, NULL, '2012-01-20 12:54:31.004938+00', 'Halley''s Comet', 1834, '');
INSERT INTO 'tune' VALUES (5286, NULL, '2012-01-20 12:54:37.805694+00', 'Athole Brose', 1401, '');
INSERT INTO 'tune' VALUES (3284, NULL, '2012-01-20 12:54:31.007893+00', 'Diane Kathleen', 1763, '');
INSERT INTO 'tune' VALUES (5287, NULL, '2012-01-20 12:54:37.809494+00', 'Beer Barrel Polka', 10228, '');
INSERT INTO 'tune' VALUES (3285, NULL, '2012-01-20 12:54:31.010799+00', 'White Picket Fence, The', 1763, '');
INSERT INTO 'tune' VALUES (3286, NULL, '2012-01-20 12:54:31.013685+00', 'Miss Jessie Heron of Skye', 1763, '');
INSERT INTO 'tune' VALUES (3287, '2005-04-19 22:00:00+00', '2012-01-20 12:54:31.016641+00', 'Flourish, The', 1502, '');
INSERT INTO 'tune' VALUES (5288, NULL, '2012-01-20 12:54:37.813277+00', 'Miss Thompson', 9999, '');
INSERT INTO 'tune' VALUES (5269, NULL, '2020-07-10 08:21:33.642413+00', 'Tug Argan Gap', 11964, '');
INSERT INTO 'tune' VALUES (3288, NULL, '2012-01-20 12:54:31.019589+00', 'Nigg Connection, The', 1502, '');
INSERT INTO 'tune' VALUES (3289, NULL, '2012-01-20 12:54:31.022491+00', 'Loch Ba', 1745, '');
INSERT INTO 'tune' VALUES (3290, NULL, '2012-01-20 12:54:31.025452+00', 'MHBHM', 1502, '');
INSERT INTO 'tune' VALUES (5289, NULL, '2012-01-20 12:54:37.817077+00', 'Henrietta Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (3291, NULL, '2012-01-20 12:54:31.028463+00', 'Andrew Gardner''s Reel', 1764, '');
INSERT INTO 'tune' VALUES (3292, NULL, '2012-01-20 12:54:31.031384+00', 'Campbell''s Jig', 1835, '');
INSERT INTO 'tune' VALUES (3293, NULL, '2012-01-20 12:54:31.034269+00', 'Rats Awa', 1768, '');
INSERT INTO 'tune' VALUES (5290, NULL, '2012-01-20 12:54:37.820879+00', 'de Martelly', 2127, '');
INSERT INTO 'tune' VALUES (3294, NULL, '2012-01-20 12:54:31.037168+00', 'Untitled Hornpipe', 1768, '');
INSERT INTO 'tune' VALUES (3295, NULL, '2012-01-20 12:54:31.040073+00', 'Untitled Strathspey', 1836, '');
INSERT INTO 'tune' VALUES (3296, NULL, '2012-01-20 12:54:31.042966+00', 'Abbey Craig', 1837, '');
INSERT INTO 'tune' VALUES (5291, NULL, '2012-01-20 12:54:37.82468+00', 'Miskoe''s Reel', 2128, '');
INSERT INTO 'tune' VALUES (3297, NULL, '2012-01-20 12:54:31.045948+00', 'Second Teaser, A', 1582, '');
INSERT INTO 'tune' VALUES (3298, NULL, '2012-01-20 12:54:31.048889+00', 'Miss Nicola Higgs', 1582, '');
INSERT INTO 'tune' VALUES (5292, NULL, '2012-01-20 12:54:37.828553+00', 'I Gaed a Gate awa Fu Yestreen', 9999, '');
INSERT INTO 'tune' VALUES (5293, NULL, '2012-01-20 12:54:37.832357+00', 'Piper''s Leg, The', 2128, '');
INSERT INTO 'tune' VALUES (5294, NULL, '2012-01-20 12:54:37.836157+00', 'Electric Jig', 1407, '');
INSERT INTO 'tune' VALUES (5295, NULL, '2012-01-20 12:54:37.840018+00', 'Four Maries', 9999, '');
INSERT INTO 'tune' VALUES (5296, NULL, '2012-01-20 12:54:37.843867+00', 'Skye Gathering, The', 9999, '');
INSERT INTO 'tune' VALUES (12159, '2012-06-12 16:16:58.348378+00', '2012-06-12 16:16:58.348389+00', 'Betty Arrol''s Reel', 1596, '');
INSERT INTO 'tune' VALUES (3299, NULL, '2012-01-20 12:54:31.051796+00', 'Blinkbonny', 1508, '');
INSERT INTO 'tune' VALUES (3321, NULL, '2012-01-20 12:54:31.121302+00', 'Letham Ladies', 1429, '');
INSERT INTO 'tune' VALUES (5297, NULL, '2012-01-20 12:54:37.847677+00', 'Lady Lever Park', 2138, '');
INSERT INTO 'tune' VALUES (3300, NULL, '2012-01-20 12:54:31.054706+00', 'Angela''s Delight', 1508, '');
INSERT INTO 'tune' VALUES (3301, NULL, '2012-01-20 12:54:31.057616+00', 'Cairn Edward', 129, '');
INSERT INTO 'tune' VALUES (3322, NULL, '2012-01-20 12:54:31.125632+00', 'Avril Lovie''s Reel', 1404, '');
INSERT INTO 'tune' VALUES (5298, NULL, '2012-01-20 12:54:37.851511+00', 'Summer in Assynt', 1701, '');
INSERT INTO 'tune' VALUES (3302, NULL, '2012-01-20 12:54:31.060512+00', 'Laurieston', 129, '');
INSERT INTO 'tune' VALUES (3303, NULL, '2012-01-20 12:54:31.063449+00', 'Glentrool', 129, '');
INSERT INTO 'tune' VALUES (3323, NULL, '2012-01-20 12:54:31.129059+00', 'Aldivalloch', 9998, '');
INSERT INTO 'tune' VALUES (3304, NULL, '2012-01-20 12:54:31.06652+00', 'Dundeugh', 129, '');
INSERT INTO 'tune' VALUES (3305, NULL, '2012-01-20 12:54:31.069434+00', 'Mamie''s Jig', 1764, '');
INSERT INTO 'tune' VALUES (3324, NULL, '2012-01-20 12:54:31.131986+00', 'Aldridge''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (5300, NULL, '2012-01-20 12:54:37.859134+00', 'Joan C MacKenzie', 1669, '');
INSERT INTO 'tune' VALUES (3306, NULL, '2012-01-20 12:54:31.072446+00', 'Muckle Kirk, The', 467, '');
INSERT INTO 'tune' VALUES (3307, NULL, '2012-01-20 12:54:31.075368+00', 'Rustico', 210, '');
INSERT INTO 'tune' VALUES (3325, NULL, '2012-01-20 12:54:31.134902+00', 'Ada Johnstone''s Jig', 1668, '');
INSERT INTO 'tune' VALUES (5301, NULL, '2012-01-20 12:54:37.862932+00', 'Bernera Bridge', 9998, '');
INSERT INTO 'tune' VALUES (3308, NULL, '2012-01-20 12:54:31.078273+00', 'Absence of Forethought', 2392, '');
INSERT INTO 'tune' VALUES (3309, NULL, '2012-01-20 12:54:31.081174+00', 'Miss Heather Bartel', 1502, '');
INSERT INTO 'tune' VALUES (13843, '2018-03-07 23:21:32.890432+00', '2018-03-07 23:22:26.668635+00', 'Linda Henderson', 1631, '');
INSERT INTO 'tune' VALUES (5302, NULL, '2012-01-20 12:54:37.866733+00', 'Farewell to Skye', 2139, '');
INSERT INTO 'tune' VALUES (3310, NULL, '2012-01-20 12:54:31.084098+00', 'Susie''s Favourite Dram Until Further Notice', 1773, '');
INSERT INTO 'tune' VALUES (3311, NULL, '2012-01-20 12:54:31.087092+00', 'Achnahennich', 1586, '');
INSERT INTO 'tune' VALUES (3327, NULL, '2012-01-20 12:54:31.140686+00', 'Alice''s Strathspey', 1406, '');
INSERT INTO 'tune' VALUES (5303, NULL, '2012-01-20 12:54:37.870823+00', 'Sunset Over Foula', 1623, '');
INSERT INTO 'tune' VALUES (3313, NULL, '2012-01-20 12:54:31.0929+00', 'Ackergill Agreement, The', 1502, '');
INSERT INTO 'tune' VALUES (3328, NULL, '2012-01-20 12:54:31.143582+00', 'Alison and Sandy Grant', 9998, '');
INSERT INTO 'tune' VALUES (5304, NULL, '2012-01-20 12:54:37.874773+00', 'Flett from Flotta', 1910, '');
INSERT INTO 'tune' VALUES (3314, NULL, '2012-01-20 12:54:31.095892+00', 'Adam Buchan O!', 9999, '');
INSERT INTO 'tune' VALUES (3315, NULL, '2012-01-20 12:54:31.100591+00', 'Miss Stewart''s Fancy', 1401, '');
INSERT INTO 'tune' VALUES (3329, NULL, '2012-01-20 12:54:31.146513+00', 'Mrs Roberta Buckel', 1555, '');
INSERT INTO 'tune' VALUES (5305, NULL, '2012-01-20 12:54:37.878598+00', 'Headlands', 1623, '');
INSERT INTO 'tune' VALUES (3316, NULL, '2012-01-20 12:54:31.103736+00', 'Adieu, The', 9998, '');
INSERT INTO 'tune' VALUES (3317, NULL, '2012-01-20 12:54:31.106732+00', 'After the Ball', 609, '');
INSERT INTO 'tune' VALUES (3330, NULL, '2012-01-20 12:54:31.149468+00', 'Allana M. Creighton', 1520, '');
INSERT INTO 'tune' VALUES (5306, NULL, '2012-01-20 12:54:37.882546+00', 'When You and I were Young', 9998, '');
INSERT INTO 'tune' VALUES (3312, NULL, '2018-01-18 21:26:22.253678+00', 'Falkland Palace', 1815, 'Composed in 1974');
INSERT INTO 'tune' VALUES (3318, NULL, '2012-01-20 12:54:31.110109+00', 'After the Battle', 9999, '');
INSERT INTO 'tune' VALUES (3319, NULL, '2012-01-20 12:54:31.113344+00', 'Ahint the Kirk', 1403, '');
INSERT INTO 'tune' VALUES (3331, NULL, '2012-01-20 12:54:31.152633+00', 'Allan''s Rant, The', 1837, '');
INSERT INTO 'tune' VALUES (5307, NULL, '2012-01-20 12:54:37.886524+00', 'Just a wee Deoch-an-dorus', 1663, '');
INSERT INTO 'tune' VALUES (3320, NULL, '2012-01-20 12:54:31.11686+00', 'Ainster Fisherman', 1558, '');
INSERT INTO 'tune' VALUES (3332, NULL, '2012-01-20 12:54:31.155617+00', 'Woodlands', 1590, '');
INSERT INTO 'tune' VALUES (5308, NULL, '2012-01-20 12:54:37.890676+00', 'Merryn''s Reel', 1623, '');
INSERT INTO 'tune' VALUES (3333, NULL, '2012-01-20 12:54:31.158525+00', 'All Kinds of Everything', 1643, '');
INSERT INTO 'tune' VALUES (3334, NULL, '2012-01-20 12:54:31.161433+00', 'Jack''s Rant', 1408, '');
INSERT INTO 'tune' VALUES (3335, NULL, '2012-01-20 12:54:31.164461+00', 'Bonnie Brux', 1409, '');
INSERT INTO 'tune' VALUES (5309, NULL, '2012-01-20 12:54:37.894487+00', 'Ladies of Kildare', 9998, '');
INSERT INTO 'tune' VALUES (3336, NULL, '2012-01-20 12:54:31.167471+00', 'High Road to Alford, The', 1409, '');
INSERT INTO 'tune' VALUES (3337, NULL, '2012-01-20 12:54:31.170384+00', 'All Together, One After Another', 9998, '');
INSERT INTO 'tune' VALUES (3338, NULL, '2012-01-20 12:54:31.17333+00', 'Alpin Fancy', 1725, '');
INSERT INTO 'tune' VALUES (5310, NULL, '2012-01-20 12:54:37.898283+00', 'Braeside', 9998, '');
INSERT INTO 'tune' VALUES (3339, NULL, '2012-01-20 12:54:31.176222+00', 'Altnabreac', 9999, '');
INSERT INTO 'tune' VALUES (5311, NULL, '2012-01-20 12:54:37.90208+00', 'Auld Maid in a Garret', 9999, '');
INSERT INTO 'tune' VALUES (3340, NULL, '2012-01-20 12:54:31.179119+00', 'Andrew Rankine''s Reel', 1412, '');
INSERT INTO 'tune' VALUES (3341, NULL, '2012-01-20 12:54:31.182013+00', 'Ian Pullman''s Special', 1643, '');
INSERT INTO 'tune' VALUES (3342, NULL, '2012-01-20 12:54:31.184903+00', 'Janet Rennie''s Strathspey', 629, '');
INSERT INTO 'tune' VALUES (5312, NULL, '2012-01-20 12:54:37.905885+00', 'Miss Jane of Violetbank', 1606, '');
INSERT INTO 'tune' VALUES (3343, NULL, '2012-01-20 12:54:31.187812+00', 'Andy Stewart''s Reel', 1413, '');
INSERT INTO 'tune' VALUES (3344, NULL, '2012-01-20 12:54:31.190785+00', 'Ian Meldrum''s Welcome to Bon Accord', 9998, '');
INSERT INTO 'tune' VALUES (3345, NULL, '2012-01-20 12:54:31.193684+00', 'Capon Tree, The', 1593, '');
INSERT INTO 'tune' VALUES (5313, NULL, '2012-01-20 12:54:37.909703+00', 'Rory MacLeod''s Welcome to Lochcarron', 1525, '');
INSERT INTO 'tune' VALUES (3346, NULL, '2012-01-20 12:54:31.196615+00', 'Jet''s Hornpipe', 1415, '');
INSERT INTO 'tune' VALUES (3347, NULL, '2012-01-20 12:54:31.199555+00', 'Anne Eltham''s Fancy', 1558, '');
INSERT INTO 'tune' VALUES (3348, NULL, '2012-01-20 12:54:31.202454+00', 'Helen Brown', 1582, '');
INSERT INTO 'tune' VALUES (5314, NULL, '2012-01-20 12:54:37.913501+00', 'Silver Darlings', 9998, '');
INSERT INTO 'tune' VALUES (3349, NULL, '2012-01-20 12:54:31.20535+00', 'Belleisle', 1418, '');
INSERT INTO 'tune' VALUES (3350, NULL, '2012-01-20 12:54:31.208248+00', 'Apley House', 9998, '');
INSERT INTO 'tune' VALUES (3351, NULL, '2012-01-20 12:54:31.211234+00', 'Jane of Pintalia Jig', 1419, '');
INSERT INTO 'tune' VALUES (5315, NULL, '2012-01-20 12:54:37.917298+00', 'Manchester Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (5316, NULL, '2012-01-20 12:54:37.921116+00', 'Gillespie''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (5317, NULL, '2012-01-20 12:54:37.924962+00', 'Newcastleton Reel, The', 1557, '');
INSERT INTO 'tune' VALUES (5318, NULL, '2012-01-20 12:54:37.929011+00', 'George Butler', 1557, '');
INSERT INTO 'tune' VALUES (5319, NULL, '2012-01-20 12:54:37.932833+00', 'Triumphal March', 9999, '');
INSERT INTO 'tune' VALUES (5321, NULL, '2012-01-20 12:54:37.940451+00', 'Wearing of the Green, The', 9999, '');
INSERT INTO 'tune' VALUES (5322, NULL, '2012-01-20 12:54:37.944271+00', 'Barbara Bane of New Deer', 1522, '');
INSERT INTO 'tune' VALUES (3352, NULL, '2012-01-20 12:54:31.214145+00', 'Sir David Hunter Blair', 9999, '');
INSERT INTO 'tune' VALUES (3374, NULL, '2012-01-20 12:54:31.285581+00', 'Lum Hat Wantin'' the Croon', 1432, '');
INSERT INTO 'tune' VALUES (5323, NULL, '2012-01-20 12:54:37.948072+00', 'Sing to me the Auld Scots Sang', 9999, '');
INSERT INTO 'tune' VALUES (3353, NULL, '2012-01-20 12:54:31.217064+00', 'Archie Patterson', 1607, '');
INSERT INTO 'tune' VALUES (3354, NULL, '2012-01-20 12:54:31.220368+00', 'Ardbeg', 1659, '');
INSERT INTO 'tune' VALUES (3375, NULL, '2012-01-20 12:54:31.288539+00', 'Auretti''s Dutch Skipper', 9998, '');
INSERT INTO 'tune' VALUES (5324, NULL, '2012-01-20 12:54:37.951923+00', 'Night at Glenzier, The', 2362, '');
INSERT INTO 'tune' VALUES (3355, NULL, '2012-01-20 12:54:31.224908+00', 'Argyll Strathspey', 948, '');
INSERT INTO 'tune' VALUES (3356, NULL, '2012-01-20 12:54:31.229391+00', 'New Morn', 948, '');
INSERT INTO 'tune' VALUES (3376, NULL, '2012-01-20 12:54:31.291847+00', 'Road to Stirling, The', 1815, '');
INSERT INTO 'tune' VALUES (5325, NULL, '2012-01-20 12:54:37.955707+00', 'Stein Song', 9998, '');
INSERT INTO 'tune' VALUES (3357, NULL, '2012-01-20 12:54:31.232365+00', 'Why Left I My Hame?', 1423, '');
INSERT INTO 'tune' VALUES (3358, NULL, '2012-01-20 12:54:31.235278+00', 'Cooper''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (3377, NULL, '2012-01-20 12:54:31.294793+00', 'Awa'' Wi'' Your Witchcraft o'' Beauty''s Alarms', 9999, '');
INSERT INTO 'tune' VALUES (5326, NULL, '2012-01-20 12:54:37.959949+00', 'Whistler''s Song', 9998, '');
INSERT INTO 'tune' VALUES (3359, NULL, '2012-01-20 12:54:31.238175+00', 'Argyll Jig', 9999, '');
INSERT INTO 'tune' VALUES (3360, NULL, '2012-01-20 12:54:31.242917+00', 'Captain Whiteside''s Quickstep', 1425, '');
INSERT INTO 'tune' VALUES (3378, NULL, '2012-01-20 12:54:31.297895+00', 'Sheila''s Strathspey', 1590, '');
INSERT INTO 'tune' VALUES (3361, NULL, '2012-01-20 12:54:31.245855+00', 'Allan Gibb', 1554, '');
INSERT INTO 'tune' VALUES (3362, NULL, '2012-01-20 12:54:31.248761+00', 'Arniston House', 9999, '');
INSERT INTO 'tune' VALUES (3379, NULL, '2012-01-20 12:54:31.300821+00', 'Loncraig Jig, The', 2668, '');
INSERT INTO 'tune' VALUES (5328, NULL, '2012-01-20 12:54:37.96756+00', 'Forres Cradle Song', 1512, '');
INSERT INTO 'tune' VALUES (3363, NULL, '2012-01-20 12:54:31.251779+00', 'Winsten Galop', 9999, '');
INSERT INTO 'tune' VALUES (3364, NULL, '2012-01-20 12:54:31.254697+00', 'Ian''s Fancy', 1557, '');
INSERT INTO 'tune' VALUES (3380, NULL, '2012-01-20 12:54:31.304619+00', 'Shepherd of Luss, The', 9999, '');
INSERT INTO 'tune' VALUES (5329, NULL, '2012-01-20 12:54:37.971358+00', 'Mother of Mine', 9998, '');
INSERT INTO 'tune' VALUES (3365, NULL, '2012-01-20 12:54:31.257742+00', 'Tom Drysdale''s Barn Dance', 1643, '');
INSERT INTO 'tune' VALUES (3366, NULL, '2012-01-20 12:54:31.261634+00', 'Heart o'' the Thomas', 2392, '');
INSERT INTO 'tune' VALUES (3381, NULL, '2012-01-20 12:54:31.307653+00', 'Oh Gin I Were Where Gadie Rins', 9999, '');
INSERT INTO 'tune' VALUES (5330, NULL, '2012-01-20 12:54:37.975162+00', 'Tak Your Gun to the Hill', 9999, '');
INSERT INTO 'tune' VALUES (3367, NULL, '2012-01-20 12:54:31.264582+00', 'Norma''s Tune', 1527, '');
INSERT INTO 'tune' VALUES (3368, NULL, '2012-01-20 12:54:31.267492+00', 'Richard Ross', 1430, '');
INSERT INTO 'tune' VALUES (3370, NULL, '2018-12-10 15:38:21.033219+00', 'Tara''s Theme', 11761, '');
INSERT INTO 'tune' VALUES (5331, NULL, '2012-01-20 12:54:37.978959+00', 'Duncan Lamont', 1910, '');
INSERT INTO 'tune' VALUES (3369, NULL, '2012-01-20 12:54:31.270443+00', 'Margaret Ross', 1430, '');
INSERT INTO 'tune' VALUES (3383, NULL, '2012-01-20 12:54:31.313527+00', 'Balkan Hills', 1436, '');
INSERT INTO 'tune' VALUES (5332, NULL, '2012-01-20 12:54:37.982764+00', 'Aberdeen Accordion Fiddle Club', 1735, '');
INSERT INTO 'tune' VALUES (3371, NULL, '2012-01-20 12:54:31.276312+00', 'Forecastle', 9999, '');
INSERT INTO 'tune' VALUES (3372, NULL, '2012-01-20 12:54:31.279709+00', 'Magdalen Fields', 1502, '');
INSERT INTO 'tune' VALUES (3384, NULL, '2012-01-20 12:54:31.316431+00', 'Miss Isabella McPherson Grant''s Strathspey', 1516, '');
INSERT INTO 'tune' VALUES (5333, NULL, '2012-01-20 12:54:37.986572+00', 'Fiona MacLeod', 1910, '');
INSERT INTO 'tune' VALUES (3373, NULL, '2012-01-20 12:54:31.282681+00', 'Auld Kirk, The', 9999, '');
INSERT INTO 'tune' VALUES (3385, NULL, '2012-01-20 12:54:31.320041+00', 'Ballochmyle House', 1437, '');
INSERT INTO 'tune' VALUES (5334, NULL, '2012-01-20 12:54:37.990382+00', 'May Loudon', 1457, '');
INSERT INTO 'tune' VALUES (3386, NULL, '2012-01-20 12:54:31.322998+00', 'Bambooselum', 9999, '');
INSERT INTO 'tune' VALUES (3387, NULL, '2012-01-20 12:54:31.326072+00', 'Erik''s Wedding', 9998, '');
INSERT INTO 'tune' VALUES (3388, NULL, '2012-01-20 12:54:31.33022+00', 'Flight of the Newlyweds', 9998, '');
INSERT INTO 'tune' VALUES (5335, NULL, '2012-01-20 12:54:37.994175+00', 'Janet Dickson', 1457, '');
INSERT INTO 'tune' VALUES (3389, NULL, '2012-01-20 12:54:31.333274+00', 'Bangor Regatta', 9999, '');
INSERT INTO 'tune' VALUES (3390, NULL, '2012-01-20 12:54:31.336215+00', 'Saint Anne''s', 9999, '');
INSERT INTO 'tune' VALUES (5336, NULL, '2012-01-20 12:54:37.997973+00', 'West of Rhue', 1457, '');
INSERT INTO 'tune' VALUES (3391, NULL, '2012-01-20 12:54:31.339118+00', 'Banks of the Limmat', 326, '');
INSERT INTO 'tune' VALUES (3392, NULL, '2012-01-20 12:54:31.342014+00', 'Banshee, The', 9999, '');
INSERT INTO 'tune' VALUES (5337, NULL, '2012-01-20 12:54:38.00177+00', 'By Lovely Loch Broom', 1871, '');
INSERT INTO 'tune' VALUES (3393, NULL, '2012-01-20 12:54:31.344915+00', 'Bantry Lassies', 9999, '');
INSERT INTO 'tune' VALUES (5338, NULL, '2012-01-20 12:54:38.005578+00', 'Miss Mary O''Bierne''s Welcome to Kildonan', 2386, '');
INSERT INTO 'tune' VALUES (3394, NULL, '2012-01-20 12:54:31.347811+00', 'Barmaid, The', 9999, '');
INSERT INTO 'tune' VALUES (5339, NULL, '2012-01-20 12:54:38.009547+00', 'Puffin Mad', 1415, '');
INSERT INTO 'tune' VALUES (3395, NULL, '2012-01-20 12:54:31.35071+00', 'Cot Green', 1430, '');
INSERT INTO 'tune' VALUES (3396, NULL, '2012-01-20 12:54:31.353911+00', 'Bath Carnival', 9998, '');
INSERT INTO 'tune' VALUES (3397, NULL, '2012-01-20 12:54:31.357539+00', 'Battle of the Boyne', 9999, '');
INSERT INTO 'tune' VALUES (3398, NULL, '2012-01-20 12:54:31.360474+00', 'Silver Rose', 1508, '');
INSERT INTO 'tune' VALUES (5340, NULL, '2012-01-20 12:54:38.013482+00', 'Mount Seymour Waltz', 1457, '');
INSERT INTO 'tune' VALUES (3399, NULL, '2012-01-20 12:54:31.363459+00', 'Major Bill', 1135, '');
INSERT INTO 'tune' VALUES (3400, NULL, '2012-01-20 12:54:31.366356+00', 'Beaux of Oakhill', 9999, '');
INSERT INTO 'tune' VALUES (3401, NULL, '2012-01-20 12:54:31.36926+00', 'Bee''s Wing Hornpipe, The', 1625, '');
INSERT INTO 'tune' VALUES (5341, NULL, '2012-01-20 12:54:38.021358+00', 'Rose Wood', 1512, '');
INSERT INTO 'tune' VALUES (3402, NULL, '2012-01-20 12:54:31.372216+00', 'Belfast Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (3403, NULL, '2012-01-20 12:54:31.375134+00', 'Teem the Tide', 1506, '');
INSERT INTO 'tune' VALUES (3404, NULL, '2012-01-20 12:54:31.37803+00', 'Belladrum''s Strathspey', 2142, '');
INSERT INTO 'tune' VALUES (5342, NULL, '2012-01-20 12:54:38.024502+00', 'Polharrow Burn', 9999, '');
INSERT INTO 'tune' VALUES (5343, NULL, '2012-01-20 12:54:38.027746+00', 'MacGregor''s March', 9999, '');
INSERT INTO 'tune' VALUES (5344, NULL, '2012-01-20 12:54:38.03072+00', 'Mrs McHardy', 1512, '');
INSERT INTO 'tune' VALUES (5345, NULL, '2012-01-20 12:54:38.03367+00', 'Sonja''s Pipes', 2100, '');
INSERT INTO 'tune' VALUES (5346, NULL, '2012-01-20 12:54:38.036988+00', 'Gillie Calum', 9999, '');
INSERT INTO 'tune' VALUES (5347, NULL, '2012-01-20 12:54:38.040266+00', 'Thady You Gander', 9998, '');
INSERT INTO 'tune' VALUES (5348, NULL, '2012-01-20 12:54:38.043753+00', 'Celtic Lament, The', 9999, '');
INSERT INTO 'tune' VALUES (5349, NULL, '2012-01-20 12:54:38.048012+00', 'Mrs Stuart MacDonald''s Strathspey', 1558, '');
INSERT INTO 'tune' VALUES (3405, NULL, '2012-01-20 12:54:31.381633+00', 'Squadron Leader Douglas Henderson', 1607, '');
INSERT INTO 'tune' VALUES (3427, NULL, '2012-01-20 12:54:31.448577+00', 'Rhodes House', 1590, '');
INSERT INTO 'tune' VALUES (3406, NULL, '2012-01-20 12:54:31.38473+00', 'Russell''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (5350, NULL, '2012-01-20 12:54:38.051939+00', 'Duke of Gordon Quickstep, The', 1695, '');
INSERT INTO 'tune' VALUES (3407, NULL, '2012-01-20 12:54:31.387685+00', 'Belle of the Ball', 1329, '');
INSERT INTO 'tune' VALUES (3428, NULL, '2012-01-20 12:54:31.452065+00', 'Lord Lovat''s Lament', 9999, '');
INSERT INTO 'tune' VALUES (3408, NULL, '2012-01-20 12:54:31.390585+00', 'Thor and Richard''s Rant', 1502, '');
INSERT INTO 'tune' VALUES (5351, NULL, '2012-01-20 12:54:38.05576+00', 'Sarah''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (3409, NULL, '2012-01-20 12:54:31.393546+00', 'Beryl''s Bouquet', 1408, '');
INSERT INTO 'tune' VALUES (3410, NULL, '2012-01-20 12:54:31.396449+00', 'Best Man, The', 1445, '');
INSERT INTO 'tune' VALUES (5352, NULL, '2012-01-20 12:54:38.059718+00', 'Mrs Jimmy Shand''s Fancy', 1558, '');
INSERT INTO 'tune' VALUES (3411, NULL, '2012-01-20 12:54:31.399537+00', 'Beth Wilson''s Delight', 1558, '');
INSERT INTO 'tune' VALUES (3430, NULL, '2012-01-20 12:54:31.458016+00', 'Lesley''s March to Scotland', 9999, '');
INSERT INTO 'tune' VALUES (3412, NULL, '2012-01-20 12:54:31.402458+00', 'Betty Paton', 9999, '');
INSERT INTO 'tune' VALUES (5353, NULL, '2012-01-20 12:54:38.063669+00', 'Quiet and Snug', 9999, '');
INSERT INTO 'tune' VALUES (3413, NULL, '2012-01-20 12:54:31.405881+00', 'Betty''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (3414, NULL, '2012-01-20 12:54:31.408928+00', 'Miss Rae Afrin', 1446, '');
INSERT INTO 'tune' VALUES (3431, NULL, '2014-11-17 22:11:39.64535+00', 'Miss Monaghan''s Reel', 3058, '');
INSERT INTO 'tune' VALUES (5354, NULL, '2012-01-20 12:54:38.067497+00', 'Bisham Abbey', 1407, '');
INSERT INTO 'tune' VALUES (3415, NULL, '2012-01-20 12:54:31.412108+00', 'Tom Grieve', 1446, '');
INSERT INTO 'tune' VALUES (3432, NULL, '2012-01-20 12:54:31.463859+00', 'Jig for Jo, A', 1584, '');
INSERT INTO 'tune' VALUES (3416, NULL, '2012-01-20 12:54:31.415059+00', 'Big Corral, The', 9998, '');
INSERT INTO 'tune' VALUES (5355, NULL, '2012-01-20 12:54:38.071395+00', 'Twa Bonnie Maidens', 9999, '');
INSERT INTO 'tune' VALUES (3417, NULL, '2012-01-20 12:54:31.417963+00', 'Big Law Burn, The', 689, '');
INSERT INTO 'tune' VALUES (3418, NULL, '2012-01-20 12:54:31.42101+00', 'For Pete''s Sake', 629, '');
INSERT INTO 'tune' VALUES (5356, NULL, '2012-01-20 12:54:38.075259+00', 'O Gin I were a Bonnie Lad', 9999, '');
INSERT INTO 'tune' VALUES (3419, NULL, '2012-01-20 12:54:31.423945+00', 'Bab at the Bowster', 9999, '');
INSERT INTO 'tune' VALUES (3434, NULL, '2012-01-20 12:54:31.469652+00', 'Blue Tartan', 1508, '');
INSERT INTO 'tune' VALUES (5357, NULL, '2012-01-20 12:54:38.0784+00', 'Frances Gow''s Favourite', 1558, '');
INSERT INTO 'tune' VALUES (5358, NULL, '2012-01-20 12:54:38.081317+00', 'Mechanic''s Jig, The', 1558, '');
INSERT INTO 'tune' VALUES (3420, NULL, '2012-01-20 12:54:31.427374+00', 'Bill Pimm', 9999, '');
INSERT INTO 'tune' VALUES (3435, NULL, '2012-01-20 12:54:31.472546+00', 'Bobby Crowe''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (5359, NULL, '2012-01-20 12:54:38.084213+00', 'Ben Lyon''s Favourite', 1558, '');
INSERT INTO 'tune' VALUES (3436, NULL, '2012-01-20 12:54:31.47586+00', 'Bobby Dunlop''s Jig', 2257, '');
INSERT INTO 'tune' VALUES (3421, NULL, '2012-01-20 12:54:31.430417+00', 'Mains of Charleston, The', 467, '');
INSERT INTO 'tune' VALUES (5360, NULL, '2012-01-20 12:54:38.087123+00', 'Bessie Lee''s Jig', 1558, '');
INSERT INTO 'tune' VALUES (3437, NULL, '2012-01-20 12:54:31.479461+00', 'Bobby Watson', 1607, '');
INSERT INTO 'tune' VALUES (5361, NULL, '2012-01-20 12:54:38.090011+00', 'Honeymoon', 1607, '');
INSERT INTO 'tune' VALUES (3422, NULL, '2012-01-20 12:54:31.433458+00', 'Bishop, The', 9998, '');
INSERT INTO 'tune' VALUES (3438, NULL, '2012-01-20 12:54:31.482464+00', 'Bob Johnstone', 9999, '');
INSERT INTO 'tune' VALUES (5362, NULL, '2012-01-20 12:54:38.0929+00', 'Major Moir of Villeveque', 1700, '');
INSERT INTO 'tune' VALUES (3439, NULL, '2012-01-20 12:54:31.485366+00', 'Mrs Macintyre of Glencoe', 9998, '');
INSERT INTO 'tune' VALUES (3423, NULL, '2012-01-20 12:54:31.436702+00', 'Black Agnes', 1448, '');
INSERT INTO 'tune' VALUES (5363, NULL, '2012-01-20 12:54:38.09582+00', 'Memories of Orkney', 9999, '');
INSERT INTO 'tune' VALUES (3440, NULL, '2012-01-20 12:54:31.488261+00', 'Bonawe Highlanders, The', 1455, '');
INSERT INTO 'tune' VALUES (5364, NULL, '2012-01-20 12:54:38.098798+00', 'Diane Margaret Shand''s Jig', 1558, '');
INSERT INTO 'tune' VALUES (3424, NULL, '2012-01-20 12:54:31.439799+00', 'Blacksmith, The', 9999, '');
INSERT INTO 'tune' VALUES (3441, NULL, '2012-01-20 12:54:31.491391+00', 'Hamish Gow''s Reel', 1531, '');
INSERT INTO 'tune' VALUES (5365, NULL, '2012-01-20 12:54:38.101706+00', 'Loch Rannoch', 1581, '');
INSERT INTO 'tune' VALUES (3442, NULL, '2012-01-20 12:54:31.494387+00', 'Highland Diamond', 1533, '');
INSERT INTO 'tune' VALUES (3425, NULL, '2012-01-20 12:54:31.442764+00', 'Farewell to the City of Glasgow Police', 1450, '');
INSERT INTO 'tune' VALUES (5366, NULL, '2012-01-20 12:54:38.104795+00', 'O Gin I were a Baron''s Heir', 9999, '');
INSERT INTO 'tune' VALUES (3443, NULL, '2012-01-20 12:54:31.497298+00', 'Chrissie Leatham Two-step', 1527, '');
INSERT INTO 'tune' VALUES (3426, NULL, '2012-01-20 12:54:31.445674+00', 'Walnut Tree, The', 249, '');
INSERT INTO 'tune' VALUES (3444, NULL, '2012-01-20 12:54:31.501157+00', 'Duncryne', 1533, '');
INSERT INTO 'tune' VALUES (5367, NULL, '2012-01-20 12:54:38.107711+00', 'Two and Two', 9999, '');
INSERT INTO 'tune' VALUES (3445, NULL, '2012-01-20 12:54:31.504094+00', 'Evelyn''s Reel', 1593, '');
INSERT INTO 'tune' VALUES (3446, NULL, '2012-01-20 12:54:31.506991+00', 'Ian MacKenzie''s Reel', 1533, '');
INSERT INTO 'tune' VALUES (3447, NULL, '2012-01-20 12:54:31.509882+00', 'Tinker''s Wedding, The', 1609, '');
INSERT INTO 'tune' VALUES (5368, NULL, '2012-01-20 12:54:38.11061+00', 'Kaly Shaw''s Fancy', 1558, '');
INSERT INTO 'tune' VALUES (3448, NULL, '2012-01-20 12:54:31.512781+00', 'Caerleol Cross', 1815, '');
INSERT INTO 'tune' VALUES (3449, NULL, '2012-01-20 12:54:31.515904+00', 'Birthday Bubbles', 1590, '');
INSERT INTO 'tune' VALUES (3450, NULL, '2012-01-20 12:54:31.518826+00', 'Joy''s Lucky Number', 1593, '');
INSERT INTO 'tune' VALUES (5369, NULL, '2012-01-20 12:54:38.113499+00', 'Garthlands', 1950, '');
INSERT INTO 'tune' VALUES (3451, NULL, '2012-01-20 12:54:31.521729+00', 'Miss Mary Steele', 1610, '');
INSERT INTO 'tune' VALUES (3452, NULL, '2012-01-20 12:54:31.524629+00', 'Cockermouth Lasses', 1593, '');
INSERT INTO 'tune' VALUES (3453, NULL, '2012-01-20 12:54:31.529721+00', 'Goofy''s Return', 1593, '');
INSERT INTO 'tune' VALUES (5370, NULL, '2012-01-20 12:54:38.116428+00', 'Irish Hut, The', 9999, '');
INSERT INTO 'tune' VALUES (3454, NULL, '2012-01-20 12:54:31.532691+00', 'Tatties Galore', 1593, '');
INSERT INTO 'tune' VALUES (3455, NULL, '2012-01-20 12:54:31.535766+00', 'Jo Anning''s Jig', 1457, '');
INSERT INTO 'tune' VALUES (3456, NULL, '2012-01-20 12:54:31.538751+00', 'David Turnbull''s Reel', 1575, '');
INSERT INTO 'tune' VALUES (5371, NULL, '2012-01-20 12:54:38.119992+00', 'Logie O''Buchan', 9999, '');
INSERT INTO 'tune' VALUES (3457, NULL, '2012-01-20 12:54:31.541651+00', 'Barbara Rae', 1745, '');
INSERT INTO 'tune' VALUES (5372, NULL, '2012-01-20 12:54:38.123433+00', 'Pat Cushnie''s Fancy', 1558, '');
INSERT INTO 'tune' VALUES (5373, NULL, '2012-01-20 12:54:38.126858+00', 'Jean MacKinnon''s Jig', 1558, '');
INSERT INTO 'tune' VALUES (5374, NULL, '2012-01-20 12:54:38.129791+00', 'Newhaven Jig', 1558, '');
INSERT INTO 'tune' VALUES (3458, NULL, '2012-01-20 12:54:31.544849+00', 'Merry We''ve Been', 9999, '');
INSERT INTO 'tune' VALUES (3468, NULL, '2012-01-20 12:54:31.585752+00', 'Wright''s Rant, The', 9998, '');
INSERT INTO 'tune' VALUES (3459, NULL, '2012-01-20 12:54:31.550156+00', 'Hummle Doddies', 1614, '');
INSERT INTO 'tune' VALUES (3460, NULL, '2012-01-20 12:54:31.554049+00', 'Bonnie Hoose O'' Airlie', 9999, '');
INSERT INTO 'tune' VALUES (3469, NULL, '2012-01-20 12:54:31.589505+00', 'Miss Joan Warren', 1439, '');
INSERT INTO 'tune' VALUES (3461, NULL, '2012-01-20 12:54:31.558059+00', 'Mrs Jean Law', 467, '');
INSERT INTO 'tune' VALUES (3462, NULL, '2012-01-20 12:54:31.562074+00', 'Bonnie Lassie, A', 709, '');
INSERT INTO 'tune' VALUES (3470, NULL, '2012-01-20 12:54:31.592461+00', 'Uncle Henry''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (3463, NULL, '2012-01-20 12:54:31.565957+00', 'Inverquharity Castle', 1646, '');
INSERT INTO 'tune' VALUES (3464, NULL, '2012-01-20 12:54:31.569781+00', 'Bonspiel, The', 249, '');
INSERT INTO 'tune' VALUES (3471, NULL, '2012-01-20 12:54:31.595373+00', 'Molendinar Burn', 1679, '');
INSERT INTO 'tune' VALUES (3465, NULL, '2012-01-20 12:54:31.573625+00', 'Border Bridge', 1502, '');
INSERT INTO 'tune' VALUES (3466, NULL, '2012-01-20 12:54:31.57813+00', 'Borderer''s Jig, The', 145, '');
INSERT INTO 'tune' VALUES (3472, NULL, '2012-01-20 12:54:31.598262+00', 'Scottish Emigrant''s Farewell', 1460, '');
INSERT INTO 'tune' VALUES (3467, NULL, '2012-01-20 12:54:31.581948+00', 'Balfron Boy, The', 1815, '');
INSERT INTO 'tune' VALUES (3473, NULL, '2012-01-20 12:54:31.601405+00', 'Boston Hospitality', 1461, '');
INSERT INTO 'tune' VALUES (3475, NULL, '2012-01-20 12:54:31.607215+00', 'Miss Emma Sergeant', 1582, '');
INSERT INTO 'tune' VALUES (3476, NULL, '2012-01-20 12:54:31.610109+00', 'Rose Wood''s Dirk', 1512, '');
INSERT INTO 'tune' VALUES (3477, NULL, '2012-01-20 12:54:31.613004+00', 'Boys of Blue Hill, The', 9999, '');
INSERT INTO 'tune' VALUES (3478, NULL, '2012-01-20 12:54:31.615941+00', 'Lady Niven Lumsden of Achindor''s Strathspey', 1516, '');
INSERT INTO 'tune' VALUES (3479, NULL, '2012-01-20 12:54:31.618868+00', 'Braes of Crosskirk, The', 1789, '');
INSERT INTO 'tune' VALUES (3480, NULL, '2012-01-20 12:54:31.621751+00', 'Braes of Dornoch', 9999, '');
INSERT INTO 'tune' VALUES (3481, NULL, '2012-01-20 12:54:31.624692+00', 'Miller, The', 9998, '');
INSERT INTO 'tune' VALUES (3482, NULL, '2012-01-20 12:54:31.627591+00', 'Ian Barbour', 1527, '');
INSERT INTO 'tune' VALUES (3483, NULL, '2012-01-20 12:54:31.630488+00', 'Miss Florence Adams', 1607, '');
INSERT INTO 'tune' VALUES (3484, NULL, '2012-01-20 12:54:31.63338+00', 'Wonder Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (3485, NULL, '2012-01-20 12:54:31.636279+00', 'Breathless Piper, The', 9999, '');
INSERT INTO 'tune' VALUES (3486, NULL, '2012-01-20 12:54:31.639191+00', 'Breeks are Loose and the Buttons Awa'', The', 9998, '');
INSERT INTO 'tune' VALUES (3487, NULL, '2012-01-20 12:54:31.64212+00', 'Brick Makers, The', 9999, '');
INSERT INTO 'tune' VALUES (3488, NULL, '2012-01-20 12:54:31.645007+00', 'Bridal Jig, The', 9999, '');
INSERT INTO 'tune' VALUES (3489, NULL, '2012-01-20 12:54:31.647939+00', 'Bride''s Favourite, The', 9999, '');
INSERT INTO 'tune' VALUES (3490, NULL, '2012-01-20 12:54:31.650855+00', 'Dr and Mrs Nedderman', 1465, '');
INSERT INTO 'tune' VALUES (3491, NULL, '2012-01-20 12:54:31.653746+00', 'Farnie House', 9999, '');
INSERT INTO 'tune' VALUES (3492, NULL, '2012-01-20 12:54:31.656643+00', 'Lee''s Reel', 1557, '');
INSERT INTO 'tune' VALUES (3493, NULL, '2012-01-20 12:54:31.660055+00', 'Freemason, The', 9999, '');
INSERT INTO 'tune' VALUES (3494, NULL, '2012-01-20 12:54:31.663015+00', 'Four-leaf Clover, The', 9999, '');
INSERT INTO 'tune' VALUES (3495, NULL, '2012-01-20 12:54:31.665913+00', 'Brisk Bob', 9998, '');
INSERT INTO 'tune' VALUES (3496, NULL, '2012-01-20 12:54:31.668809+00', 'Sucky Bids Me', 9999, '');
INSERT INTO 'tune' VALUES (3497, NULL, '2012-01-20 12:54:31.671984+00', 'I''ll Take This one and That One Over There', 2257, '');
INSERT INTO 'tune' VALUES (3498, NULL, '2012-01-20 12:54:31.6749+00', 'Bung Your Eye', 1518, '');
INSERT INTO 'tune' VALUES (3499, NULL, '2012-01-20 12:54:31.677828+00', 'Burdett, The', 9999, '');
INSERT INTO 'tune' VALUES (3500, NULL, '2012-01-20 12:54:31.680721+00', 'Burgundy''s Flight', 9999, '');
INSERT INTO 'tune' VALUES (3501, NULL, '2012-01-20 12:54:31.683607+00', 'Burnhervie Picnic', 2310, '');
INSERT INTO 'tune' VALUES (3503, NULL, '2012-01-20 12:54:31.701223+00', 'Hawk That Swoops on High, The', 2365, '');
INSERT INTO 'tune' VALUES (3504, NULL, '2012-01-20 12:54:31.704139+00', 'Tail of My Coat', 9999, '');
INSERT INTO 'tune' VALUES (3505, NULL, '2012-01-20 12:54:31.707062+00', 'Three Rivers, The', 9999, '');
INSERT INTO 'tune' VALUES (3506, NULL, '2012-01-20 12:54:31.709954+00', 'Miss Lesley Higgs', 1582, '');
INSERT INTO 'tune' VALUES (3507, NULL, '2012-01-20 12:54:31.71285+00', 'Caerlaverock Castle', 1668, '');
INSERT INTO 'tune' VALUES (3508, NULL, '2012-01-20 12:54:31.715811+00', 'Dunkeld Volunteers, The', 1518, '');
INSERT INTO 'tune' VALUES (3509, NULL, '2012-01-20 12:54:31.718756+00', 'Caithness Volunteers', 9999, '');
INSERT INTO 'tune' VALUES (3510, NULL, '2012-01-20 12:54:31.721644+00', 'Morag''s Reel', 1471, '');
INSERT INTO 'tune' VALUES (3511, NULL, '2012-01-20 12:54:31.724539+00', 'Mrs Cramb''s Favourite', 1607, '');
INSERT INTO 'tune' VALUES (3512, NULL, '2012-01-20 12:54:31.727676+00', 'Dr Neil Stewart McLeod', 1782, '');
INSERT INTO 'tune' VALUES (3513, NULL, '2012-01-20 12:54:31.730638+00', 'Callum Donaldson', 1623, '');
INSERT INTO 'tune' VALUES (3514, NULL, '2012-01-20 12:54:31.73358+00', 'Bobby Jack''s Compliments to Mary Prentice', 1821, '');
INSERT INTO 'tune' VALUES (3515, NULL, '2012-01-20 12:54:31.736546+00', 'Cambusdoon', 1608, '');
INSERT INTO 'tune' VALUES (3516, NULL, '2012-01-20 12:54:31.739611+00', 'Siege of Delhi, The', 9999, '');
INSERT INTO 'tune' VALUES (3517, NULL, '2012-01-20 12:54:31.742519+00', 'Cameron Highlanders, The', 1512, '');
INSERT INTO 'tune' VALUES (3518, NULL, '2012-01-20 12:54:31.74541+00', 'Peakes o'' Ben Lomond, The', 9998, '');
INSERT INTO 'tune' VALUES (3519, NULL, '2012-01-20 12:54:31.748355+00', 'Campbell of Laphroaig', 1502, '');
INSERT INTO 'tune' VALUES (3520, NULL, '2012-01-20 12:54:31.751265+00', 'Graham''s Black Bottle', 1502, '');
INSERT INTO 'tune' VALUES (3521, NULL, '2012-01-20 12:54:31.754163+00', 'Campbell''s Farewell to Redcastle', 1635, '');
INSERT INTO 'tune' VALUES (13844, '2018-03-11 09:24:11.854776+00', '2018-03-11 09:24:11.854776+00', 'Matz und Mona', 11607, '');
INSERT INTO 'tune' VALUES (3523, NULL, '2012-01-20 12:54:31.760069+00', 'Miss Margaret MacDonald Goes to Town', 1759, '');
INSERT INTO 'tune' VALUES (3524, NULL, '2012-01-20 12:54:31.763022+00', 'Canty Couple, The', 9999, '');
INSERT INTO 'tune' VALUES (3525, NULL, '2012-01-20 12:54:31.765912+00', 'Capon Tree, The', 1523, '');
INSERT INTO 'tune' VALUES (3526, NULL, '2012-01-20 12:54:31.768816+00', 'Capstan, The', 609, '');
INSERT INTO 'tune' VALUES (3527, NULL, '2012-01-20 12:54:31.771725+00', 'Captain E.G. Elder, Black Watch', 1411, '');
INSERT INTO 'tune' VALUES (3528, NULL, '2012-01-20 12:54:31.774619+00', 'Captain Francis Wemyss', 9999, '');
INSERT INTO 'tune' VALUES (3529, NULL, '2012-01-20 12:54:31.777513+00', 'Captain Henderson''s Hornpipe', 609, '');
INSERT INTO 'tune' VALUES (3550, NULL, '2012-01-20 12:54:31.839404+00', 'Miss Stewart', 1518, '');
INSERT INTO 'tune' VALUES (3530, NULL, '2012-10-17 11:08:56.128676+00', 'Captain H. Munro', 1790, '');
INSERT INTO 'tune' VALUES (3531, NULL, '2012-01-20 12:54:31.783348+00', 'Mill Brig, The', 9998, '');
INSERT INTO 'tune' VALUES (3551, NULL, '2012-01-20 12:54:31.842312+00', 'Edith Watson''s Favourite', 1483, '');
INSERT INTO 'tune' VALUES (3532, NULL, '2012-01-20 12:54:31.786255+00', 'Broxburn Fiddler, The', 1329, '');
INSERT INTO 'tune' VALUES (3533, NULL, '2012-01-20 12:54:31.789153+00', 'H.M.S. Success', 1473, '');
INSERT INTO 'tune' VALUES (3552, NULL, '2012-01-20 12:54:31.845201+00', 'Welcome to Hayes', 1980, '');
INSERT INTO 'tune' VALUES (3534, NULL, '2012-01-20 12:54:31.792043+00', 'Fore and Aft', 9998, '');
INSERT INTO 'tune' VALUES (3535, NULL, '2012-01-20 12:54:31.794937+00', 'Oregon Reel, The', 1584, '');
INSERT INTO 'tune' VALUES (3553, NULL, '2012-01-20 12:54:31.848095+00', 'Channel Fleet', 9999, '');
INSERT INTO 'tune' VALUES (3536, NULL, '2012-01-20 12:54:31.797824+00', 'Carm Oliver''s Jig', 2257, '');
INSERT INTO 'tune' VALUES (3537, NULL, '2012-01-20 12:54:31.800734+00', 'Caroline Robertson''s Wedding', 1538, '');
INSERT INTO 'tune' VALUES (3554, NULL, '2012-01-20 12:54:31.850986+00', 'Miss Lisa Taylor', 1582, '');
INSERT INTO 'tune' VALUES (3538, NULL, '2012-01-20 12:54:31.803654+00', 'Last Carousel, The', 1477, '');
INSERT INTO 'tune' VALUES (3539, NULL, '2012-01-20 12:54:31.807018+00', 'Carrick Realm, The', 1408, '');
INSERT INTO 'tune' VALUES (3555, NULL, '2012-01-20 12:54:31.853914+00', 'Charles Stuart', 9998, '');
INSERT INTO 'tune' VALUES (3540, NULL, '2012-01-20 12:54:31.810094+00', 'My Dearie an thou die', 9998, '');
INSERT INTO 'tune' VALUES (3541, NULL, '2012-01-20 12:54:31.813015+00', 'Carse of Lecropt, The', 754, '');
INSERT INTO 'tune' VALUES (3556, NULL, '2012-01-20 12:54:31.856907+00', 'Charlotte and Aileen', 1485, '');
INSERT INTO 'tune' VALUES (3542, NULL, '2012-01-20 12:54:31.815908+00', 'Captain Johnstone''s Piped Aboard', 1479, '');
INSERT INTO 'tune' VALUES (3543, NULL, '2012-01-20 12:54:31.818805+00', 'Mrs Trotter of Castlelaw''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (3557, NULL, '2012-01-20 12:54:31.859809+00', 'George Carr''s Reel', 316, '');
INSERT INTO 'tune' VALUES (3544, NULL, '2012-01-20 12:54:31.821774+00', 'Candida''s Strathspey', 948, '');
INSERT INTO 'tune' VALUES (3558, NULL, '2012-01-20 12:54:31.862707+00', 'Chelmsford Assembly', 9998, '');
INSERT INTO 'tune' VALUES (3546, NULL, '2012-01-20 12:54:31.827596+00', 'Catherine McIsaac''s Wedding Day', 9998, '');
INSERT INTO 'tune' VALUES (3547, NULL, '2012-01-20 12:54:31.830503+00', 'Across the Sound of Sleat', 1480, '');
INSERT INTO 'tune' VALUES (3559, NULL, '2012-01-20 12:54:31.8656+00', 'Cheviot Gate, The', 1533, '');
INSERT INTO 'tune' VALUES (3548, NULL, '2012-01-20 12:54:31.833612+00', 'Cawdor Castle', 1719, '');
INSERT INTO 'tune' VALUES (3549, NULL, '2012-01-20 12:54:31.836506+00', 'Happy Sam', 1482, '');
INSERT INTO 'tune' VALUES (3560, NULL, '2012-01-20 12:54:31.868523+00', 'Norma''s Favourite', 1613, '');
INSERT INTO 'tune' VALUES (3561, NULL, '2012-01-20 12:54:31.871832+00', 'Christian''s Strathspey', 1538, '');
INSERT INTO 'tune' VALUES (3562, NULL, '2012-01-20 12:54:31.874797+00', 'O Tannenbaum', 9998, '');
INSERT INTO 'tune' VALUES (3563, NULL, '2012-01-20 12:54:31.877693+00', 'Jingle Bells', 9999, '');
INSERT INTO 'tune' VALUES (3564, NULL, '2012-01-20 12:54:31.880607+00', 'Natal Day, The', 9999, '');
INSERT INTO 'tune' VALUES (3565, NULL, '2012-01-20 12:54:31.883819+00', 'Churchill Barracks', 1719, '');
INSERT INTO 'tune' VALUES (3566, NULL, '2012-01-20 12:54:31.886743+00', 'Tribute to Leeds SCD Society', 1593, '');
INSERT INTO 'tune' VALUES (3568, NULL, '2012-01-20 12:54:31.892564+00', 'Mrs Macintosh of Raigmore', 1632, '');
INSERT INTO 'tune' VALUES (3569, NULL, '2012-01-20 12:54:31.895458+00', 'Cluny Castle', 1487, '');
INSERT INTO 'tune' VALUES (3570, NULL, '2012-01-20 12:54:31.898345+00', 'Clyne''s Trek Ower the Muirie', 1586, '');
INSERT INTO 'tune' VALUES (3571, NULL, '2012-01-20 12:54:31.901265+00', 'C. M. Beattie', 1525, '');
INSERT INTO 'tune' VALUES (3572, NULL, '2012-01-20 12:54:31.904165+00', 'Dan the Cobbler', 9999, '');
INSERT INTO 'tune' VALUES (3573, NULL, '2012-01-20 12:54:31.907055+00', 'Moving Bog, The', 9999, '');
INSERT INTO 'tune' VALUES (3574, NULL, '2012-01-20 12:54:31.909938+00', 'Jenny''s Blue E''en', 9999, '');
INSERT INTO 'tune' VALUES (3575, NULL, '2012-01-20 12:54:31.912911+00', 'Neusiedl', 1489, '');
INSERT INTO 'tune' VALUES (3576, NULL, '2012-01-20 12:54:31.915808+00', 'Cock-a-Leekie', 9999, '');
INSERT INTO 'tune' VALUES (3577, NULL, '2012-01-20 12:54:31.918699+00', 'Cockle Shells', 9998, '');
INSERT INTO 'tune' VALUES (3578, NULL, '2012-01-20 12:54:31.921601+00', 'Cock Up Your Beaver', 9998, '');
INSERT INTO 'tune' VALUES (3579, NULL, '2012-01-20 12:54:31.92455+00', 'Coffee Leaf, The', 9999, '');
INSERT INTO 'tune' VALUES (3580, NULL, '2012-01-20 12:54:31.928317+00', 'Collier''s Daughter, The', 9999, '');
INSERT INTO 'tune' VALUES (3581, NULL, '2012-01-20 12:54:31.931327+00', 'Collie''s Reel', 1525, '');
INSERT INTO 'tune' VALUES (3582, NULL, '2012-01-20 12:54:31.934215+00', 'Miss Sandra Webster', 1615, '');
INSERT INTO 'tune' VALUES (3604, NULL, '2012-01-20 12:54:31.998703+00', 'Crathes', 165, '');
INSERT INTO 'tune' VALUES (3583, NULL, '2012-01-20 12:54:31.937372+00', 'Colonel''s Quickstep, The', 1556, '');
INSERT INTO 'tune' VALUES (3584, NULL, '2012-01-20 12:54:31.940272+00', 'Colosseum, The', 9999, '');
INSERT INTO 'tune' VALUES (3605, NULL, '2012-01-20 12:54:32.001601+00', 'Treasurer, The', 1643, '');
INSERT INTO 'tune' VALUES (3585, NULL, '2012-01-20 12:54:31.943161+00', 'M. Q. Ewing', 210, '');
INSERT INTO 'tune' VALUES (3586, NULL, '2012-01-20 12:54:31.946138+00', 'Melanie', 1203, '');
INSERT INTO 'tune' VALUES (3606, NULL, '2012-01-20 12:54:32.004491+00', 'For Pat', 948, '');
INSERT INTO 'tune' VALUES (3587, NULL, '2012-01-20 12:54:31.949056+00', 'Gavotta from Trio Sonata Opus 2, No 1', 1494, '');
INSERT INTO 'tune' VALUES (3588, NULL, '2012-01-20 12:54:31.952008+00', 'Marquis of Queensberry', 9999, '');
INSERT INTO 'tune' VALUES (3607, NULL, '2012-01-20 12:54:32.007432+00', 'James Glen''s Jig', 1531, '');
INSERT INTO 'tune' VALUES (3589, NULL, '2012-01-20 12:54:31.955139+00', 'Cork Hill', 9999, '');
INSERT INTO 'tune' VALUES (3590, NULL, '2012-01-20 12:54:31.958048+00', 'Sterlini', 1815, '');
INSERT INTO 'tune' VALUES (3608, NULL, '2012-01-20 12:54:32.010342+00', 'Solway Sunset', 1815, '');
INSERT INTO 'tune' VALUES (3591, NULL, '2012-01-20 12:54:31.960946+00', 'Coronation, The', 9998, '');
INSERT INTO 'tune' VALUES (3592, NULL, '2012-01-20 12:54:31.963838+00', 'Corporation, The', 9998, '');
INSERT INTO 'tune' VALUES (3609, NULL, '2012-01-20 12:54:32.013237+00', 'Cobham Hall', 1502, '');
INSERT INTO 'tune' VALUES (3593, NULL, '2012-01-20 12:54:31.966738+00', 'Cotyburn', 9998, '');
INSERT INTO 'tune' VALUES (3594, NULL, '2012-01-20 12:54:31.96964+00', 'Countess of Lauderdale''s Reel', 1401, '');
INSERT INTO 'tune' VALUES (3610, NULL, '2012-01-20 12:54:32.016146+00', 'Donald Chisholm', 3058, '');
INSERT INTO 'tune' VALUES (3595, NULL, '2012-01-20 12:54:31.97258+00', 'Jean Mullen''s Jig', 1615, '');
INSERT INTO 'tune' VALUES (3596, NULL, '2012-01-20 12:54:31.975472+00', 'Country Wife''s Ball, The', 2392, '');
INSERT INTO 'tune' VALUES (3611, NULL, '2012-01-20 12:54:32.019036+00', 'Oban High School Centenary Jig', 1572, '');
INSERT INTO 'tune' VALUES (3597, NULL, '2012-01-20 12:54:31.978366+00', 'Craigmillar Castle', 9999, '');
INSERT INTO 'tune' VALUES (3598, NULL, '2012-01-20 12:54:31.981253+00', 'Varsovienne, La', 9999, '');
INSERT INTO 'tune' VALUES (3612, NULL, '2012-01-20 12:54:32.021919+00', 'Mrs Harriet MacLeod of Knockfarrel', 1543, '');
INSERT INTO 'tune' VALUES (3599, NULL, '2012-01-20 12:54:31.984212+00', 'Cowal Games Jig', 629, '');
INSERT INTO 'tune' VALUES (3600, NULL, '2012-01-20 12:54:31.987133+00', 'Russe, La', 9999, '');
INSERT INTO 'tune' VALUES (3613, NULL, '2012-01-20 12:54:32.02481+00', 'Reel of the Gordon Highlanders, The', 1497, '');
INSERT INTO 'tune' VALUES (13846, '2018-03-11 10:38:57.874775+00', '2018-03-11 10:38:57.874775+00', 'Ramona''s Wedding Strathspey', 11608, '');
INSERT INTO 'tune' VALUES (3602, NULL, '2012-01-20 12:54:31.992921+00', 'Bride of the Winds, The', 1452, '');
INSERT INTO 'tune' VALUES (3614, NULL, '2012-01-20 12:54:32.027815+00', 'Rejected Suitor, The', 9999, '');
INSERT INTO 'tune' VALUES (3603, NULL, '2012-01-20 12:54:31.995813+00', 'Jimmy''s Return', 9998, '');
INSERT INTO 'tune' VALUES (3615, NULL, '2012-01-20 12:54:32.030718+00', 'Ferryman, The', 1910, '');
INSERT INTO 'tune' VALUES (3617, NULL, '2012-01-20 12:54:32.036506+00', 'Jock Gudmundson''s Farewell to the Auctioneers', 1811, '');
INSERT INTO 'tune' VALUES (3618, NULL, '2012-01-20 12:54:32.039423+00', 'Alan Pattullo''s Reel', 1811, '');
INSERT INTO 'tune' VALUES (3619, NULL, '2012-01-20 12:54:32.042309+00', 'Nortel Jig, The', 1811, '');
INSERT INTO 'tune' VALUES (3620, NULL, '2012-01-20 12:54:32.045196+00', 'Sandy Todd''s Half Century', 1811, '');
INSERT INTO 'tune' VALUES (3621, NULL, '2012-01-20 12:54:32.048245+00', 'Doug MacPhee''s Welcome', 1791, '');
INSERT INTO 'tune' VALUES (3623, NULL, '2012-01-20 12:54:32.054097+00', 'Basker''s Delight', 1791, '');
INSERT INTO 'tune' VALUES (3624, NULL, '2012-01-20 12:54:32.057031+00', 'Rita''s Tearoom', 1791, '');
INSERT INTO 'tune' VALUES (3625, NULL, '2012-01-20 12:54:32.059927+00', 'Sandy MacIntyre''s Jig', 1791, '');
INSERT INTO 'tune' VALUES (3626, NULL, '2012-01-20 12:54:32.062824+00', 'Lauchie Stubbert''s Jig', 1791, '');
INSERT INTO 'tune' VALUES (3628, NULL, '2012-01-20 12:54:32.070639+00', 'Ruthven House', 1492, '');
INSERT INTO 'tune' VALUES (3629, NULL, '2012-01-20 12:54:32.073558+00', 'Miss Evelina Edwards', 1538, '');
INSERT INTO 'tune' VALUES (3630, NULL, '2012-01-20 12:54:32.076455+00', 'Kinermony', 1807, '');
INSERT INTO 'tune' VALUES (3631, NULL, '2012-01-20 12:54:32.079387+00', 'Burries Brae', 810, '');
INSERT INTO 'tune' VALUES (3632, NULL, '2012-01-20 12:54:32.082402+00', 'Fiona''s Jig', 1539, '');
INSERT INTO 'tune' VALUES (3633, NULL, '2012-01-20 12:54:32.085735+00', 'Lion Rampant, The', 9998, '');
INSERT INTO 'tune' VALUES (3634, NULL, '2012-01-20 12:54:32.089743+00', 'Stirlingshire Militia', 9998, '');
INSERT INTO 'tune' VALUES (3684, NULL, '2013-01-24 22:33:51.433822+00', 'Dr David Rorie of Cults', 1902, '');
INSERT INTO 'tune' VALUES (3635, NULL, '2012-01-20 12:54:32.092753+00', 'Cuil an Duin', 1581, '');
INSERT INTO 'tune' VALUES (3678, NULL, '2013-02-09 01:02:10.633792+00', 'Peter''s Jig', 1582, 'August 1991');
INSERT INTO 'tune' VALUES (3636, NULL, '2012-01-20 12:54:32.096028+00', 'Cupid''s Guess', 9998, '');
INSERT INTO 'tune' VALUES (3638, NULL, '2012-01-20 12:54:32.104335+00', 'Polka des Patronaux', 9999, '');
INSERT INTO 'tune' VALUES (3639, NULL, '2012-01-20 12:54:32.107239+00', 'Mackintosh Hall', 1502, '');
INSERT INTO 'tune' VALUES (3640, NULL, '2012-01-20 12:54:32.110162+00', 'Sandy O''er the Lea', 1512, '');
INSERT INTO 'tune' VALUES (3641, NULL, '2012-01-20 12:54:32.113058+00', 'Dance of the Cuckoos', 9998, '');
INSERT INTO 'tune' VALUES (3642, NULL, '2012-01-20 12:54:32.115985+00', '10th Battalion HLI Crossing the Rhine', 1426, '');
INSERT INTO 'tune' VALUES (3643, NULL, '2012-01-20 12:54:32.119947+00', 'Stornoway Bay', 1446, '');
INSERT INTO 'tune' VALUES (3644, NULL, '2012-01-20 12:54:32.123531+00', 'Dorothy''s Reel', 1709, '');
INSERT INTO 'tune' VALUES (3645, NULL, '2012-01-20 12:54:32.127034+00', 'Mrs Fiona Rudd', 1582, '');
INSERT INTO 'tune' VALUES (3647, NULL, '2012-01-20 12:54:32.133115+00', 'Miss Macpherson of Scone', 405, '');
INSERT INTO 'tune' VALUES (3648, NULL, '2012-01-20 12:54:32.136014+00', 'David Findlay''s Jig', 60, '');
INSERT INTO 'tune' VALUES (3649, NULL, '2012-01-20 12:54:32.139196+00', 'Mr David Gray', 1472, '');
INSERT INTO 'tune' VALUES (3650, NULL, '2012-01-20 12:54:32.142111+00', 'David Ross', 2217, '');
INSERT INTO 'tune' VALUES (3651, NULL, '2012-01-20 12:54:32.145182+00', 'Dietitian, The', 1538, '');
INSERT INTO 'tune' VALUES (3652, NULL, '2012-01-20 12:54:32.148276+00', 'Debauche, Le', 9998, '');
INSERT INTO 'tune' VALUES (3653, NULL, '2012-01-20 12:54:32.151428+00', 'Shetland Shells', 9998, '');
INSERT INTO 'tune' VALUES (3654, NULL, '2012-01-20 12:54:32.15453+00', 'Deep Drams', 1834, '');
INSERT INTO 'tune' VALUES (3655, NULL, '2012-01-20 12:54:32.15755+00', 'Pinkie Knowe', 1815, '');
INSERT INTO 'tune' VALUES (3656, NULL, '2012-01-20 12:54:32.1606+00', 'Leckie', 1815, '');
INSERT INTO 'tune' VALUES (3657, NULL, '2012-01-20 12:54:32.168646+00', 'Delaney''s Drummers', 9999, '');
INSERT INTO 'tune' VALUES (3658, NULL, '2012-01-20 12:54:32.172785+00', 'Delaware Highland Gathering, The', 1399, '');
INSERT INTO 'tune' VALUES (3659, NULL, '2012-01-20 12:54:32.176671+00', 'Miss Stewart''s Welcome to Delft', 1468, '');
INSERT INTO 'tune' VALUES (3660, NULL, '2012-01-20 12:54:32.180534+00', 'Delvin House', 1518, '');
INSERT INTO 'tune' VALUES (3661, NULL, '2012-01-20 12:54:32.184358+00', 'Sandy Milne', 1502, '');
INSERT INTO 'tune' VALUES (3662, NULL, '2012-01-20 12:54:32.189517+00', 'Derry Boat, The', 9999, '');
INSERT INTO 'tune' VALUES (3663, NULL, '2012-01-20 12:54:32.193404+00', 'Craig''s Welcome', 1815, '');
INSERT INTO 'tune' VALUES (3664, NULL, '2012-01-20 12:54:32.196975+00', 'Devorgilla Reel', 1668, '');
INSERT INTO 'tune' VALUES (3666, NULL, '2012-01-20 12:54:32.202874+00', 'Hiland Lass', 9998, '');
INSERT INTO 'tune' VALUES (3667, NULL, '2012-01-20 12:54:32.205767+00', 'Dirleton Gate', 1484, '');
INSERT INTO 'tune' VALUES (3668, NULL, '2012-01-20 12:54:32.209969+00', 'Douglas Henderson', 1607, '');
INSERT INTO 'tune' VALUES (3669, NULL, '2012-01-20 12:54:32.212989+00', 'Donald Stewart (The Piper)', 1512, '');
INSERT INTO 'tune' VALUES (3670, NULL, '2012-01-20 12:54:32.215907+00', 'Bonanza Two-step, The', 1490, '');
INSERT INTO 'tune' VALUES (3671, NULL, '2012-01-20 12:54:32.218994+00', 'Don''s Favourite', 9998, '');
INSERT INTO 'tune' VALUES (3673, NULL, '2012-01-20 12:54:32.224802+00', 'Doodler''s, The', 9999, '');
INSERT INTO 'tune' VALUES (3674, NULL, '2012-01-20 12:54:32.227691+00', 'Glencairn Reel, The', 1668, '');
INSERT INTO 'tune' VALUES (3675, NULL, '2012-01-20 12:54:32.230893+00', 'Dorothy Drew''s Reel', 1714, '');
INSERT INTO 'tune' VALUES (3676, NULL, '2012-01-20 12:54:32.234005+00', 'Leven Lassies', 1646, '');
INSERT INTO 'tune' VALUES (3677, NULL, '2012-01-20 12:54:32.236948+00', 'Double Scotch', 837, '');
INSERT INTO 'tune' VALUES (3679, NULL, '2012-01-20 12:54:32.242971+00', 'Logan Brig, The', 1931, '');
INSERT INTO 'tune' VALUES (3680, NULL, '2012-01-20 12:54:32.245896+00', 'Dover Pier', 9998, '');
INSERT INTO 'tune' VALUES (3681, NULL, '2012-01-20 12:54:32.248801+00', 'Borthwick Castle', 1473, '');
INSERT INTO 'tune' VALUES (3682, NULL, '2012-01-20 12:54:32.252769+00', 'Millbrae', 1623, '');
INSERT INTO 'tune' VALUES (3683, NULL, '2012-01-20 12:54:32.255749+00', 'Jim''s Reel', 1607, '');
INSERT INTO 'tune' VALUES (3685, NULL, '2012-01-20 12:54:32.261562+00', 'Dr Finlay', 2273, '');
INSERT INTO 'tune' VALUES (3686, NULL, '2012-01-20 12:54:32.264466+00', 'Avon School March, The', 1439, '');
INSERT INTO 'tune' VALUES (3687, NULL, '2012-01-20 12:54:32.267369+00', 'Draper''s Gardens', 9999, '');
INSERT INTO 'tune' VALUES (3688, NULL, '2012-01-20 12:54:32.270261+00', 'Draper''s Maggot', 9999, '');
INSERT INTO 'tune' VALUES (3689, NULL, '2012-01-20 12:54:32.273251+00', 'Dublin Bay', 9998, '');
INSERT INTO 'tune' VALUES (3717, NULL, '2012-01-20 12:54:32.360789+00', 'Caidil Gu La', 9998, '');
INSERT INTO 'tune' VALUES (3690, NULL, '2012-01-20 12:54:32.276735+00', 'Duke of Fife''s Welcome to Deeside', 1512, '');
INSERT INTO 'tune' VALUES (3691, NULL, '2012-01-20 12:54:32.279677+00', 'Duke of Gordon''s Welcome to Aberdeen', 9998, '');
INSERT INTO 'tune' VALUES (3692, NULL, '2012-01-20 12:54:32.282574+00', 'Duke of Kent''s Waltz, The', 9998, '');
INSERT INTO 'tune' VALUES (3718, '2006-08-30 22:00:00+00', '2012-01-20 12:54:32.364325+00', 'Beechwood House', 1981, '');
INSERT INTO 'tune' VALUES (3693, NULL, '2012-01-20 12:54:32.285468+00', 'Dull Sir John', 9998, '');
INSERT INTO 'tune' VALUES (3694, NULL, '2012-01-20 12:54:32.288363+00', 'Shakin'' o'' the Pocky', 1512, '');
INSERT INTO 'tune' VALUES (3695, NULL, '2012-01-20 12:54:32.291346+00', 'Border Hills', 1815, '');
INSERT INTO 'tune' VALUES (3719, NULL, '2012-01-20 12:54:32.367291+00', 'Ellen Richard''s Delight', 1558, '');
INSERT INTO 'tune' VALUES (3696, NULL, '2012-01-20 12:54:32.294246+00', 'Dunbar Castle', 1523, '');
INSERT INTO 'tune' VALUES (3697, NULL, '2012-01-20 12:54:32.297231+00', 'Ian Duncan''s Reel', 1623, '');
INSERT INTO 'tune' VALUES (3698, NULL, '2012-01-20 12:54:32.301151+00', 'Just for Karen', 848, '');
INSERT INTO 'tune' VALUES (3720, NULL, '2012-01-20 12:54:32.370187+00', 'Tribute to Gary Donaldson, A', 1582, '');
INSERT INTO 'tune' VALUES (3699, NULL, '2012-01-20 12:54:32.304094+00', 'Duncan the Gauger', 9998, '');
INSERT INTO 'tune' VALUES (3622, NULL, '2017-03-01 23:33:17.553871+00', 'Dan Harry Burton', 1791, '');
INSERT INTO 'tune' VALUES (3627, NULL, '2017-09-04 21:05:39.478801+00', 'Doreen Goldring', 1502, '');
INSERT INTO 'tune' VALUES (3637, NULL, '2017-09-18 13:22:02.747716+00', 'Slan gun t''hig mo run a nall', 9999, '');
INSERT INTO 'tune' VALUES (3616, NULL, '2017-11-08 12:53:21.953191+00', 'John MacDonald''s Reel', 1499, '');
INSERT INTO 'tune' VALUES (3700, NULL, '2012-01-20 12:54:32.307006+00', 'Dundee City Police Pipe Band', 1558, '');
INSERT INTO 'tune' VALUES (3701, NULL, '2012-01-20 12:54:32.309905+00', '800 Celebration Jig', 1692, '');
INSERT INTO 'tune' VALUES (3721, NULL, '2012-01-20 12:54:32.37309+00', 'Elsie Ritchie', 1838, '');
INSERT INTO 'tune' VALUES (3703, NULL, '2012-01-20 12:54:32.315767+00', 'Colonel, The', 9999, '');
INSERT INTO 'tune' VALUES (3704, NULL, '2012-01-20 12:54:32.31871+00', 'Dunlugas House', 1446, '');
INSERT INTO 'tune' VALUES (3722, NULL, '2012-01-20 12:54:32.375992+00', 'Emerald Queen', 709, '');
INSERT INTO 'tune' VALUES (3705, NULL, '2012-01-20 12:54:32.3216+00', 'Granny''s Tune', 1657, '');
INSERT INTO 'tune' VALUES (3706, NULL, '2012-01-20 12:54:32.326231+00', 'Dunse Dings A''', 9999, '');
INSERT INTO 'tune' VALUES (3707, NULL, '2012-01-20 12:54:32.329845+00', 'Dunstaffnage Castle', 1725, '');
INSERT INTO 'tune' VALUES (3723, NULL, '2012-01-20 12:54:32.378979+00', 'Emigrant''s Adieu, The', 2142, '');
INSERT INTO 'tune' VALUES (3708, NULL, '2012-01-20 12:54:32.332777+00', 'Ye Mauchline Belles', 9999, '');
INSERT INTO 'tune' VALUES (3709, NULL, '2012-01-20 12:54:32.335738+00', 'Santa Monica Bay', 629, '');
INSERT INTO 'tune' VALUES (3710, NULL, '2012-01-20 12:54:32.338808+00', 'Mr Maguire''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (3724, NULL, '2012-01-20 12:54:32.382017+00', 'Take me Back', 9999, '');
INSERT INTO 'tune' VALUES (3711, NULL, '2012-01-20 12:54:32.34171+00', 'Peter Laing', 1512, '');
INSERT INTO 'tune' VALUES (3712, NULL, '2012-01-20 12:54:32.346145+00', 'Light Touch', 1815, '');
INSERT INTO 'tune' VALUES (5375, NULL, '2012-01-20 12:54:38.132682+00', 'Miss Margaret Brown''s Fancy', 1558, '');
INSERT INTO 'tune' VALUES (3713, NULL, '2012-01-20 12:54:32.349082+00', 'Haddington Assembly', 2174, '');
INSERT INTO 'tune' VALUES (3714, NULL, '2012-01-20 12:54:32.351988+00', 'Edith Raitt''s Jig', 1615, '');
INSERT INTO 'tune' VALUES (3715, NULL, '2012-01-20 12:54:32.354888+00', 'Edith''s Tattie Cairt', 1586, '');
INSERT INTO 'tune' VALUES (5376, NULL, '2012-01-20 12:54:38.136515+00', 'Eleanor Margaret Laing''s Jig', 1558, '');
INSERT INTO 'tune' VALUES (3716, NULL, '2012-01-20 12:54:32.357884+00', 'Eevy Atha', 9998, '');
INSERT INTO 'tune' VALUES (5377, NULL, '2012-01-20 12:54:38.139861+00', 'Cawder Fair', 9999, '');
INSERT INTO 'tune' VALUES (5378, NULL, '2012-01-20 12:54:38.143401+00', 'Leila Powrie''s Fancy', 1558, '');
INSERT INTO 'tune' VALUES (5379, NULL, '2012-01-20 12:54:38.146443+00', 'Wee Robert''s Jig', 1554, '');
INSERT INTO 'tune' VALUES (5380, NULL, '2012-01-20 12:54:38.149539+00', 'Bressay Sound', 1558, '');
INSERT INTO 'tune' VALUES (5381, NULL, '2012-01-20 12:54:38.152442+00', 'Donald''s Awa'' Tae the Wars', 9999, '');
INSERT INTO 'tune' VALUES (5382, NULL, '2012-01-20 12:54:38.155338+00', 'Castlebay Jig', 9999, '');
INSERT INTO 'tune' VALUES (5383, NULL, '2012-01-20 12:54:38.158225+00', 'Bette Fitchet''s Fancy', 1558, '');
INSERT INTO 'tune' VALUES (5384, NULL, '2012-01-20 12:54:38.16121+00', 'Aikey Brae', 2511, '');
INSERT INTO 'tune' VALUES (5385, NULL, '2012-01-20 12:54:38.164112+00', 'Muckle Friday Fair', 2281, '');
INSERT INTO 'tune' VALUES (5386, NULL, '2012-01-20 12:54:38.167+00', 'Mrs Brown''s Favourite', 1558, '');
INSERT INTO 'tune' VALUES (5387, NULL, '2012-01-20 12:54:38.169887+00', 'Snow in Summer', 1958, '');
INSERT INTO 'tune' VALUES (5388, NULL, '2012-01-20 12:54:38.172797+00', 'Dr. Ross', 9999, '');
INSERT INTO 'tune' VALUES (5389, NULL, '2012-01-20 12:54:38.175682+00', 'Alison''s Jig', 2421, '');
INSERT INTO 'tune' VALUES (5391, NULL, '2012-01-20 12:54:38.181536+00', 'Wee Kerry''s Welcome', 2212, '');
INSERT INTO 'tune' VALUES (5392, NULL, '2012-01-20 12:54:38.184617+00', 'Heather Dagg''s Strathspey', 2421, '');
INSERT INTO 'tune' VALUES (5393, NULL, '2012-01-20 12:54:38.18753+00', 'Margaret and Alf Bailey', 2421, '');
INSERT INTO 'tune' VALUES (5394, NULL, '2012-01-20 12:54:38.190594+00', 'Heather Dagg''s Reel', 2421, '');
INSERT INTO 'tune' VALUES (5395, NULL, '2012-01-20 12:54:38.193492+00', 'Carey Burn', 2212, '');
INSERT INTO 'tune' VALUES (5396, NULL, '2012-01-20 12:54:38.196381+00', 'Derek Haynes'' Hornpipe', 1437, '');
INSERT INTO 'tune' VALUES (5397, NULL, '2012-01-20 12:54:38.199267+00', 'Rab Simpson''s Delight', 1437, '');
INSERT INTO 'tune' VALUES (5398, NULL, '2012-01-20 12:54:38.202214+00', 'Mrs Mabel Young''s Frolic', 1437, '');
INSERT INTO 'tune' VALUES (5399, NULL, '2012-01-20 12:54:38.205115+00', 'Mrs Jean Littlejohn''s Strathspey', 1437, '');
INSERT INTO 'tune' VALUES (5400, NULL, '2012-01-20 12:54:38.208015+00', 'Mrs Willie Hutchieson''s Fancy', 1437, '');
INSERT INTO 'tune' VALUES (5401, NULL, '2012-01-20 12:54:38.210904+00', 'Miss Margaret Grace Bender''s Jig', 1437, '');
INSERT INTO 'tune' VALUES (5402, NULL, '2012-01-20 12:54:38.213786+00', 'Donald Head', 9998, '');
INSERT INTO 'tune' VALUES (5403, NULL, '2012-01-20 12:54:38.216675+00', 'Ron McDonald''s Reel', 2345, '');
INSERT INTO 'tune' VALUES (5404, NULL, '2012-01-20 12:54:38.219573+00', 'Ann English', 1709, '');
INSERT INTO 'tune' VALUES (5405, NULL, '2012-01-20 12:54:38.22254+00', 'Oot Be Est Da Vong', 9999, '');
INSERT INTO 'tune' VALUES (5406, NULL, '2012-01-20 12:54:38.22543+00', 'Widow MacGee, The', 9999, '');
INSERT INTO 'tune' VALUES (5407, NULL, '2012-01-20 12:54:38.228316+00', 'Sweet Molly', 9999, '');
INSERT INTO 'tune' VALUES (5408, NULL, '2012-01-20 12:54:38.23121+00', 'Paddy McGuire', 9999, '');
INSERT INTO 'tune' VALUES (5516, NULL, '2012-01-20 12:54:38.560502+00', 'Duke of Atholl', 1748, '');
INSERT INTO 'tune' VALUES (5390, NULL, '2012-04-03 20:32:56.029021+00', 'Miss Hannah of Elgin', 1516, '');
INSERT INTO 'tune' VALUES (5460, NULL, '2018-11-14 23:57:00.949454+00', 'Devil''s Dance', 3383, '');
INSERT INTO 'tune' VALUES (5410, NULL, '2012-01-20 12:54:38.23698+00', 'Kitty MacFarlane', 9999, '');
INSERT INTO 'tune' VALUES (5411, NULL, '2012-01-20 12:54:38.239866+00', 'Rustic Reel', 9999, '');
INSERT INTO 'tune' VALUES (5412, NULL, '2012-01-20 12:54:38.242828+00', 'Goat Fell', 9999, '');
INSERT INTO 'tune' VALUES (5413, NULL, '2012-01-20 12:54:38.245718+00', 'Willie Duncan', 9999, '');
INSERT INTO 'tune' VALUES (5414, NULL, '2012-01-20 12:54:38.248737+00', 'Oxtail Soup', 2961, '');
INSERT INTO 'tune' VALUES (5415, NULL, '2012-01-20 12:54:38.25169+00', 'Donald McLellan of Rothesay', 1910, '');
INSERT INTO 'tune' VALUES (5416, NULL, '2012-01-20 12:54:38.254575+00', 'Loch Glassie', 9999, '');
INSERT INTO 'tune' VALUES (5417, NULL, '2012-01-20 12:54:38.257457+00', 'Mr Thomas Jarvis''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (5418, NULL, '2012-01-20 12:54:38.26034+00', 'General Drummond', 9999, '');
INSERT INTO 'tune' VALUES (5419, NULL, '2012-01-20 12:54:38.263306+00', 'Miss Muir MacKenzie', 9999, '');
INSERT INTO 'tune' VALUES (5420, NULL, '2012-01-20 12:54:38.266196+00', 'Willie Wastle', 9999, '');
INSERT INTO 'tune' VALUES (5421, NULL, '2012-01-20 12:54:38.269163+00', 'Blackberry Quadrille', 9999, '');
INSERT INTO 'tune' VALUES (5422, NULL, '2012-01-20 12:54:38.272056+00', 'A Allan''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (5423, NULL, '2012-01-20 12:54:38.27515+00', 'Forrester Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (5424, NULL, '2012-01-20 12:54:38.278054+00', 'Eochar Reel', 2324, '');
INSERT INTO 'tune' VALUES (5425, NULL, '2012-01-20 12:54:38.280937+00', 'Soldier''s Cloak, The', 9999, '');
INSERT INTO 'tune' VALUES (5426, NULL, '2012-01-20 12:54:38.283905+00', 'Wee Lairdie John', 2085, '');
INSERT INTO 'tune' VALUES (5427, NULL, '2012-01-20 12:54:38.286823+00', 'MacLaine of Lochbuie''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (5428, NULL, '2012-01-20 12:54:38.289715+00', 'Roddy MacDonald''s Fancy', 9998, '');
INSERT INTO 'tune' VALUES (5429, NULL, '2012-01-20 12:54:38.292612+00', 'Salmon Leap', 1581, '');
INSERT INTO 'tune' VALUES (5430, NULL, '2012-01-20 12:54:38.295509+00', 'Durham Rangers Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (5431, NULL, '2012-01-20 12:54:38.298421+00', 'Love in the Village', 9999, '');
INSERT INTO 'tune' VALUES (5432, NULL, '2012-01-20 12:54:38.30131+00', 'Lincolnshire Poacher, The', 9999, '');
INSERT INTO 'tune' VALUES (5433, NULL, '2012-01-20 12:54:38.304272+00', 'My Bonnie lies over the Ocean', 9999, '');
INSERT INTO 'tune' VALUES (5434, NULL, '2012-01-20 12:54:38.30718+00', 'Little Annie Rooney', 9999, '');
INSERT INTO 'tune' VALUES (5435, NULL, '2012-01-20 12:54:38.310065+00', 'Man on the Flying Trapeze', 9999, '');
INSERT INTO 'tune' VALUES (5436, NULL, '2012-01-20 12:54:38.312945+00', 'Miss Eliza Forsythe', 9999, '');
INSERT INTO 'tune' VALUES (5437, NULL, '2012-01-20 12:54:38.31584+00', 'My Love is in America', 2158, '');
INSERT INTO 'tune' VALUES (5438, NULL, '2012-01-20 12:54:38.318733+00', 'Alison and Bobby''s Farewell to the Chase', 1508, '');
INSERT INTO 'tune' VALUES (5439, NULL, '2012-01-20 12:54:38.321621+00', 'Miss Brady', 9999, '');
INSERT INTO 'tune' VALUES (5440, NULL, '2012-01-20 12:54:38.324581+00', 'Oh Susanna', 2293, '');
INSERT INTO 'tune' VALUES (5441, NULL, '2012-01-20 12:54:38.32752+00', 'Playing On the Old Banjo', 9999, '');
INSERT INTO 'tune' VALUES (5442, NULL, '2012-01-20 12:54:38.330414+00', 'Dixie', 2411, '');
INSERT INTO 'tune' VALUES (5443, NULL, '2012-01-20 12:54:38.333297+00', 'Leith Wynd', 9998, '');
INSERT INTO 'tune' VALUES (5444, NULL, '2012-01-20 12:54:38.336184+00', 'Black Man is the Bravest, The', 9998, '');
INSERT INTO 'tune' VALUES (5445, NULL, '2012-01-20 12:54:38.339246+00', 'Peggie I Must Love Thee', 9998, '');
INSERT INTO 'tune' VALUES (5446, NULL, '2012-01-20 12:54:38.342145+00', 'Gaberlunzi Man, The', 9998, '');
INSERT INTO 'tune' VALUES (5447, NULL, '2012-01-20 12:54:38.345502+00', 'Catharine Oggie', 9998, '');
INSERT INTO 'tune' VALUES (5448, NULL, '2012-01-20 12:54:38.348416+00', 'Throw the Wood Laddie', 9998, '');
INSERT INTO 'tune' VALUES (5449, NULL, '2012-01-20 12:54:38.351858+00', 'Jockie''s Fow & Jannie''s Faine', 9998, '');
INSERT INTO 'tune' VALUES (5450, NULL, '2012-01-20 12:54:38.355185+00', 'Bonny Jean of Aberdeen', 9998, '');
INSERT INTO 'tune' VALUES (5451, NULL, '2012-01-20 12:54:38.358097+00', 'Sutters of Selkirk, The', 9998, '');
INSERT INTO 'tune' VALUES (5452, NULL, '2012-01-20 12:54:38.361104+00', 'Bush Aboon Traquair, The', 9998, '');
INSERT INTO 'tune' VALUES (5453, NULL, '2012-01-20 12:54:38.364014+00', 'I Wish My Love were in a Myre', 9998, '');
INSERT INTO 'tune' VALUES (5454, NULL, '2012-01-20 12:54:38.367124+00', 'My Apron Dearie', 9998, '');
INSERT INTO 'tune' VALUES (5455, NULL, '2012-01-20 12:54:38.370019+00', 'Brooch, The', 1407, '');
INSERT INTO 'tune' VALUES (5456, NULL, '2012-01-20 12:54:38.372912+00', 'And the Kirk Would Let Me Be', 9998, '');
INSERT INTO 'tune' VALUES (5457, NULL, '2012-01-20 12:54:38.375808+00', 'Bonny Christie', 9998, '');
INSERT INTO 'tune' VALUES (5458, NULL, '2012-01-20 12:54:38.378701+00', 'Ther''s my Thumb I''ll nere beguile you', 9998, '');
INSERT INTO 'tune' VALUES (5459, NULL, '2012-01-20 12:54:38.381588+00', 'Old Rob Morries', 9998, '');
INSERT INTO 'tune' VALUES (5461, NULL, '2012-01-20 12:54:38.387442+00', 'Wild Rover', 9999, '');
INSERT INTO 'tune' VALUES (5897, NULL, '2012-01-20 12:54:39.690012+00', 'Sligo Maid', 9999, '');
INSERT INTO 'tune' VALUES (5462, NULL, '2012-01-20 12:54:38.390341+00', 'Sir Roger de Coverly', 9998, '');
INSERT INTO 'tune' VALUES (5463, NULL, '2012-01-20 12:54:38.393223+00', 'Favourite Dram, The', 9999, '');
INSERT INTO 'tune' VALUES (5465, NULL, '2012-01-20 12:54:38.399057+00', 'Laird o'' Gulberwick, Da', 1710, '');
INSERT INTO 'tune' VALUES (5466, NULL, '2012-01-20 12:54:38.401945+00', 'Paddy McGinty''s Goat', 2230, '');
INSERT INTO 'tune' VALUES (5467, NULL, '2012-01-20 12:54:38.404832+00', 'Peter Wyper''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (5468, NULL, '2012-01-20 12:54:38.407811+00', 'Miss Bruce', 2145, '');
INSERT INTO 'tune' VALUES (5469, NULL, '2012-01-20 12:54:38.41071+00', 'Going to Donnybrook', 2151, '');
INSERT INTO 'tune' VALUES (5470, NULL, '2012-01-20 12:54:38.413601+00', 'How Are You Kitty', 9999, '');
INSERT INTO 'tune' VALUES (5471, NULL, '2012-01-20 12:54:38.416489+00', 'J Scott Skinner', 1750, '');
INSERT INTO 'tune' VALUES (5472, NULL, '2012-01-20 12:54:38.419381+00', 'West Mabou', 2163, '');
INSERT INTO 'tune' VALUES (5473, NULL, '2012-01-20 12:54:38.422306+00', 'Mr W Jopp', 2262, '');
INSERT INTO 'tune' VALUES (5474, NULL, '2012-01-20 12:54:38.425225+00', 'James Hadden Esquire', 2262, '');
INSERT INTO 'tune' VALUES (5475, NULL, '2012-01-20 12:54:38.42819+00', 'Florida Crackers', 2263, '');
INSERT INTO 'tune' VALUES (5476, NULL, '2012-01-20 12:54:38.431094+00', 'Trip to Mabou Ridge, A', 2264, '');
INSERT INTO 'tune' VALUES (5477, NULL, '2012-01-20 12:54:38.433982+00', 'Raigmore House', 1632, '');
INSERT INTO 'tune' VALUES (5479, NULL, '2012-01-20 12:54:38.439764+00', 'Spring, The', 1766, '');
INSERT INTO 'tune' VALUES (5480, NULL, '2012-01-20 12:54:38.44266+00', 'Queenie', 1512, '');
INSERT INTO 'tune' VALUES (5481, NULL, '2012-01-20 12:54:38.445543+00', 'Good Old John', 1750, '');
INSERT INTO 'tune' VALUES (5482, NULL, '2012-01-20 12:54:38.448511+00', 'Miller''s', 2244, '');
INSERT INTO 'tune' VALUES (5483, NULL, '2012-01-20 12:54:38.451414+00', 'Anthony''s Bridge', 2265, '');
INSERT INTO 'tune' VALUES (5484, NULL, '2012-01-20 12:54:38.454309+00', 'Victoria Bridge', 1766, '');
INSERT INTO 'tune' VALUES (5485, NULL, '2012-01-20 12:54:38.457196+00', 'Hillsdale Road', 2265, '');
INSERT INTO 'tune' VALUES (5486, NULL, '2012-01-20 12:54:38.460081+00', 'Morton''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (5487, NULL, '2012-01-20 12:54:38.462971+00', 'Bogentassie Brae', 1735, '');
INSERT INTO 'tune' VALUES (5488, NULL, '2012-01-20 12:54:38.465851+00', 'Miss Jessie Scales'' Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (5489, NULL, '2012-01-20 12:54:38.468816+00', 'Gallop, The', 9998, '');
INSERT INTO 'tune' VALUES (5490, NULL, '2012-01-20 12:54:38.471727+00', 'Mrs Oswald of Auchencruive''s Favourite Reel', 1519, '');
INSERT INTO 'tune' VALUES (5492, NULL, '2012-01-20 12:54:38.477706+00', 'Funeral March of the Marionettes, The', 2921, '');
INSERT INTO 'tune' VALUES (5493, NULL, '2012-01-20 12:54:38.480601+00', '17th Century Air', 9999, '');
INSERT INTO 'tune' VALUES (5494, NULL, '2012-01-20 12:54:38.483491+00', 'Irish Whiskey', 9999, '');
INSERT INTO 'tune' VALUES (5495, NULL, '2012-01-20 12:54:38.486387+00', 'Man on the Couch', 2306, '');
INSERT INTO 'tune' VALUES (5496, NULL, '2012-01-20 12:54:38.489352+00', 'Am Muilean Dubh', 9999, '');
INSERT INTO 'tune' VALUES (5497, NULL, '2012-01-20 12:54:38.492246+00', 'Fiddler''s Monikie', 2266, '');
INSERT INTO 'tune' VALUES (5498, NULL, '2012-01-20 12:54:38.49514+00', 'Dugald Torquil MacPhail of Kilberry', 1527, '');
INSERT INTO 'tune' VALUES (5499, NULL, '2012-01-20 12:54:38.498025+00', 'When Irish Eyes are Smiling', 2549, '');
INSERT INTO 'tune' VALUES (5500, NULL, '2012-01-20 12:54:38.500918+00', 'Cockles and Mussels', 2305, '');
INSERT INTO 'tune' VALUES (5501, NULL, '2012-01-20 12:54:38.503812+00', 'Mountains of Morne, The', 9999, '');
INSERT INTO 'tune' VALUES (5502, NULL, '2012-01-20 12:54:38.50684+00', 'Little Old Town in the Ould Country', 9999, '');
INSERT INTO 'tune' VALUES (5503, NULL, '2012-01-20 12:54:38.520413+00', 'H.M.S. Invincible', 1502, '');
INSERT INTO 'tune' VALUES (5505, '2005-02-01 23:00:00+00', '2012-01-20 12:54:38.52794+00', 'Four-Leaved Clover, The', 3187, '');
INSERT INTO 'tune' VALUES (5506, NULL, '2012-01-20 12:54:38.531005+00', 'Highland Division at Wadi Akari, The', 2338, '');
INSERT INTO 'tune' VALUES (5507, NULL, '2012-01-20 12:54:38.533906+00', 'Major Norman Orr Ewing', 1635, '');
INSERT INTO 'tune' VALUES (5508, NULL, '2012-01-20 12:54:38.536967+00', 'Soldier''s Return, The', 9999, '');
INSERT INTO 'tune' VALUES (5509, NULL, '2012-01-20 12:54:38.539903+00', '25th K.O.S.B. Slow March', 2329, '');
INSERT INTO 'tune' VALUES (5510, NULL, '2012-01-20 12:54:38.542999+00', 'Lady MacKenzie of Fairburn', 9999, '');
INSERT INTO 'tune' VALUES (5511, NULL, '2012-01-20 12:54:38.545907+00', 'Bobby Brown''s Jig', 2257, '');
INSERT INTO 'tune' VALUES (5512, NULL, '2012-01-20 12:54:38.548793+00', 'Wee Robin', 1659, '');
INSERT INTO 'tune' VALUES (5513, NULL, '2012-01-20 12:54:38.5518+00', 'Harold''s Strathspey', 1717, '');
INSERT INTO 'tune' VALUES (5514, NULL, '2012-01-20 12:54:38.554721+00', 'No Name Tune, The', 1615, '');
INSERT INTO 'tune' VALUES (5515, NULL, '2012-01-20 12:54:38.55761+00', 'Aunt Sarah''s Reel', 2191, '');
INSERT INTO 'tune' VALUES (5491, NULL, '2020-05-10 08:23:53.21048+00', 'Miss Napier of Merchiston Hall', 1519, '');
INSERT INTO 'tune' VALUES (5517, NULL, '2012-01-20 12:54:38.563391+00', 'Brechin Castle', 9999, '');
INSERT INTO 'tune' VALUES (5518, NULL, '2012-01-20 12:54:38.56628+00', 'Mrs Ozwald', 9998, '');
INSERT INTO 'tune' VALUES (5519, NULL, '2012-01-20 12:54:38.569169+00', 'H.M.S. Berwick', 1502, '');
INSERT INTO 'tune' VALUES (5520, NULL, '2012-01-20 12:54:38.572145+00', 'Wheena Burn, Da', 3297, '');
INSERT INTO 'tune' VALUES (5521, NULL, '2012-01-20 12:54:38.575055+00', 'Tin Palace, The', 2222, '');
INSERT INTO 'tune' VALUES (5522, NULL, '2012-01-20 12:54:38.577942+00', 'Chieftan''s Frolic, The', 9999, '');
INSERT INTO 'tune' VALUES (5523, NULL, '2012-01-20 12:54:38.582042+00', 'Lady Georgina Gordon''s Strathspey', 1516, '');
INSERT INTO 'tune' VALUES (5524, NULL, '2012-01-20 12:54:38.584958+00', 'Drunken Wives of Fochabers', 9999, '');
INSERT INTO 'tune' VALUES (5525, NULL, '2012-01-20 12:54:38.587856+00', 'Jenny Lind', 9999, '');
INSERT INTO 'tune' VALUES (5526, NULL, '2012-01-20 12:54:38.590767+00', 'Pipe Major William Grey''s Farewell to Cowal', 2595, '');
INSERT INTO 'tune' VALUES (5527, NULL, '2012-01-20 12:54:38.593716+00', 'Inniskilling Dragoons', 9999, '');
INSERT INTO 'tune' VALUES (5528, NULL, '2012-01-20 12:54:38.596608+00', 'Mrs Norman MacKeigan', 1766, '');
INSERT INTO 'tune' VALUES (5529, NULL, '2012-01-20 12:54:38.599505+00', 'Munster Lass', 9999, '');
INSERT INTO 'tune' VALUES (5530, NULL, '2012-01-20 12:54:38.602401+00', 'Janet Beaton', 9999, '');
INSERT INTO 'tune' VALUES (5531, NULL, '2012-01-20 12:54:38.60529+00', 'Oriental', 9999, '');
INSERT INTO 'tune' VALUES (5532, NULL, '2012-01-20 12:54:38.608175+00', 'Olive Branch', 9999, '');
INSERT INTO 'tune' VALUES (5533, NULL, '2012-01-20 12:54:38.611069+00', 'My Brother''s Letter', 2469, '');
INSERT INTO 'tune' VALUES (5534, NULL, '2012-01-20 12:54:38.61404+00', 'Picnic, The', 9999, '');
INSERT INTO 'tune' VALUES (5536, NULL, '2012-01-20 12:54:38.619963+00', 'Snowplough', 2264, '');
INSERT INTO 'tune' VALUES (5537, NULL, '2012-01-20 12:54:38.622931+00', 'Wilfred''s Fiddle', 1766, '');
INSERT INTO 'tune' VALUES (5538, NULL, '2012-01-20 12:54:38.625827+00', 'Jessie Anne''s Favourite', 2471, '');
INSERT INTO 'tune' VALUES (5539, NULL, '2012-01-20 12:54:38.628877+00', 'Dr Keith of Aberdeen', 9999, '');
INSERT INTO 'tune' VALUES (5540, NULL, '2012-01-20 12:54:38.631789+00', 'Mary Clare''s', 1633, '');
INSERT INTO 'tune' VALUES (5541, NULL, '2012-01-20 12:54:38.63476+00', 'Earl of Crawford''s', 1818, '');
INSERT INTO 'tune' VALUES (5542, NULL, '2012-01-20 12:54:38.637656+00', 'Judy''s', 9999, '');
INSERT INTO 'tune' VALUES (5543, NULL, '2012-01-20 12:54:38.640555+00', 'Democratic Rage', 9999, '');
INSERT INTO 'tune' VALUES (5544, NULL, '2012-01-20 12:54:38.643452+00', 'President Garfield''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (5545, NULL, '2012-01-20 12:54:38.646344+00', 'Bonfire', 9999, '');
INSERT INTO 'tune' VALUES (5546, NULL, '2012-01-20 12:54:38.649233+00', 'Red Mill', 2264, '');
INSERT INTO 'tune' VALUES (5547, NULL, '2012-01-20 12:54:38.652116+00', 'Walker Street', 9999, '');
INSERT INTO 'tune' VALUES (5548, NULL, '2012-01-20 12:54:38.655084+00', 'Miss Fraser', 9998, '');
INSERT INTO 'tune' VALUES (5550, NULL, '2012-01-20 12:54:38.661061+00', 'Gordon Well', 9998, '');
INSERT INTO 'tune' VALUES (5551, NULL, '2012-01-20 12:54:38.663973+00', 'Taymouth Heritage', 9999, '');
INSERT INTO 'tune' VALUES (5552, NULL, '2012-01-20 12:54:38.666867+00', 'Burning of the Piper''s Hut, The', 9999, '');
INSERT INTO 'tune' VALUES (5553, NULL, '2012-01-20 12:54:38.669834+00', 'Caves of Mieuville St. Vaast, The', 9999, '');
INSERT INTO 'tune' VALUES (5554, NULL, '2012-01-20 12:54:38.672771+00', 'Stan and Anne Hamilton''s Reel', 1615, '');
INSERT INTO 'tune' VALUES (5555, NULL, '2012-01-20 12:54:38.675772+00', 'Miss Maureen Fraser''s Strathspey', 1615, '');
INSERT INTO 'tune' VALUES (5556, NULL, '2012-01-20 12:54:38.678747+00', 'Donald Mowatt''s March', 1615, '');
INSERT INTO 'tune' VALUES (5557, NULL, '2012-01-20 12:54:38.681664+00', 'Auchmountain''s Bonnie Glen', 2329, '');
INSERT INTO 'tune' VALUES (5558, NULL, '2012-01-20 12:54:38.684565+00', 'Coggie o'' Ale and a Pickle Aitmeal, A', 9999, '');
INSERT INTO 'tune' VALUES (5559, NULL, '2012-01-20 12:54:38.687472+00', 'Miss Allison Frew', 1521, '');
INSERT INTO 'tune' VALUES (5560, NULL, '2012-01-20 12:54:38.690364+00', 'Miss Christina Ireland', 1521, '');
INSERT INTO 'tune' VALUES (5561, NULL, '2012-01-20 12:54:38.693252+00', 'Christening, The', 2192, '');
INSERT INTO 'tune' VALUES (5564, NULL, '2012-01-20 12:54:38.702018+00', 'MacDougall''s March', 9999, '');
INSERT INTO 'tune' VALUES (5565, NULL, '2012-01-20 12:54:38.705084+00', 'Border Polka, The', 2275, '');
INSERT INTO 'tune' VALUES (5566, NULL, '2012-01-20 12:54:38.708016+00', 'Mr & Mrs John Sanderson of Hagley', 9998, '');
INSERT INTO 'tune' VALUES (5567, NULL, '2012-01-20 12:54:38.710912+00', 'Lassies Trust in Providence', 9999, '');
INSERT INTO 'tune' VALUES (5568, NULL, '2012-01-20 12:54:38.713838+00', 'Queen Visits Duart Castle, The', 1605, '');
INSERT INTO 'tune' VALUES (5569, NULL, '2012-01-20 12:54:38.716877+00', 'Mill Mill O'', The', 9999, '');
INSERT INTO 'tune' VALUES (5571, NULL, '2012-01-20 12:54:38.722677+00', 'Four Winds, Da', 1527, '');
INSERT INTO 'tune' VALUES (5504, NULL, '2017-12-19 00:05:58.794638+00', 'Sandy''s Bounty', 11579, '');
INSERT INTO 'tune' VALUES (5572, NULL, '2012-01-20 12:54:38.725567+00', 'Jake MacKay''s Two-Step', 1634, '');
INSERT INTO 'tune' VALUES (5573, NULL, '2012-01-20 12:54:38.728653+00', 'Mo''s Peerie Boston', 1710, '');
INSERT INTO 'tune' VALUES (5574, NULL, '2012-01-20 12:54:38.731561+00', 'Cat and the Mountain Squirrel, The', 1590, '');
INSERT INTO 'tune' VALUES (5575, NULL, '2012-01-20 12:54:38.734519+00', 'Hills Around Portuairk, The', 1613, '');
INSERT INTO 'tune' VALUES (5576, NULL, '2012-01-20 12:54:38.737675+00', 'Kathleen''s Fancy', 1543, '');
INSERT INTO 'tune' VALUES (5577, NULL, '2012-01-20 12:54:38.740765+00', 'Kirrie Hill', 1646, '');
INSERT INTO 'tune' VALUES (5578, NULL, '2012-01-20 12:54:38.74431+00', 'Perth Place', 1631, '');
INSERT INTO 'tune' VALUES (5579, NULL, '2012-01-20 12:54:38.747289+00', 'Maid of Selma', 9998, '');
INSERT INTO 'tune' VALUES (5580, NULL, '2012-01-20 12:54:38.750188+00', 'Dusty Bob''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (5582, NULL, '2012-01-20 12:54:38.75601+00', 'Granny Manson of Kilblane', 2277, '');
INSERT INTO 'tune' VALUES (5583, NULL, '2012-01-20 12:54:38.758999+00', 'Wings', 9999, '');
INSERT INTO 'tune' VALUES (5584, NULL, '2012-01-20 12:54:38.761902+00', 'Cockney Jocks', 2278, '');
INSERT INTO 'tune' VALUES (5585, NULL, '2012-01-20 12:54:38.764796+00', 'An Gearran', 1790, '');
INSERT INTO 'tune' VALUES (5586, NULL, '2012-01-20 12:54:38.76769+00', 'Dounie Weaver', 9998, '');
INSERT INTO 'tune' VALUES (5587, NULL, '2012-01-20 12:54:38.770604+00', 'Waverley Market', 1502, '');
INSERT INTO 'tune' VALUES (5588, NULL, '2012-01-20 12:54:38.773519+00', 'Hot Toddy', 1502, '');
INSERT INTO 'tune' VALUES (5589, NULL, '2012-01-20 12:54:38.776413+00', 'Hit the Spot', 1502, '');
INSERT INTO 'tune' VALUES (5590, NULL, '2012-01-20 12:54:38.779426+00', 'Dingles'' Eightsome Room, The', 1502, '');
INSERT INTO 'tune' VALUES (5591, NULL, '2012-01-20 12:54:38.782336+00', 'George''s Reel', 1536, '');
INSERT INTO 'tune' VALUES (5592, NULL, '2012-01-20 12:54:38.785234+00', 'Countess of Eglinton''s Delight', 9999, '');
INSERT INTO 'tune' VALUES (5581, NULL, '2014-11-01 02:37:07.109492+00', 'Miss Lauren Rose Patrick', 1668, '');
INSERT INTO 'tune' VALUES (5594, NULL, '2012-01-20 12:54:38.791017+00', 'Winterdene', 1502, '');
INSERT INTO 'tune' VALUES (5595, NULL, '2012-01-20 12:54:38.793901+00', 'Sea Eagles Over the Minch', 1502, '');
INSERT INTO 'tune' VALUES (5596, NULL, '2012-01-20 12:54:38.796789+00', 'Orkney Silver', 1502, '');
INSERT INTO 'tune' VALUES (5597, NULL, '2012-01-20 12:54:38.799764+00', 'Pharmacist, The', 1502, '');
INSERT INTO 'tune' VALUES (5598, NULL, '2012-01-20 12:54:38.802657+00', 'Iain Stuart Robertson', 1502, '');
INSERT INTO 'tune' VALUES (5599, NULL, '2012-01-20 12:54:38.805818+00', 'Miss Jenny Tawse', 1502, '');
INSERT INTO 'tune' VALUES (5600, NULL, '2012-01-20 12:54:38.808748+00', 'Allan Gillie', 1502, '');
INSERT INTO 'tune' VALUES (5601, NULL, '2012-01-20 12:54:38.811643+00', 'Rolicking Irishman', 9998, '');
INSERT INTO 'tune' VALUES (5602, NULL, '2012-01-20 12:54:38.814535+00', 'Harry Holmes', 1442, '');
INSERT INTO 'tune' VALUES (5603, NULL, '2012-01-20 12:54:38.817437+00', 'Edith Lauder''s March', 1442, '');
INSERT INTO 'tune' VALUES (5604, NULL, '2012-01-20 12:54:38.820407+00', 'Househill Farm', 1407, '');
INSERT INTO 'tune' VALUES (5605, NULL, '2012-01-20 12:54:38.823299+00', 'William Woodham''s', 1407, '');
INSERT INTO 'tune' VALUES (5606, NULL, '2012-01-20 12:54:38.826178+00', 'Catriona''s Bracelet', 1407, '');
INSERT INTO 'tune' VALUES (5607, NULL, '2012-01-20 12:54:38.829067+00', 'Visiting Fiddler', 1407, '');
INSERT INTO 'tune' VALUES (5608, NULL, '2012-01-20 12:54:38.831971+00', 'Polly Put the Kettle On', 9999, '');
INSERT INTO 'tune' VALUES (5609, NULL, '2012-01-20 12:54:38.835091+00', 'Tom, Tom the Piper''s Son', 9998, '');
INSERT INTO 'tune' VALUES (5610, NULL, '2012-01-20 12:54:38.838261+00', 'Cherish the Life', 9998, '');
INSERT INTO 'tune' VALUES (5611, NULL, '2012-01-20 12:54:38.84121+00', 'Fur, Feathers & Fin', 1407, '');
INSERT INTO 'tune' VALUES (5612, NULL, '2012-01-20 12:54:38.844113+00', '4472', 1407, '');
INSERT INTO 'tune' VALUES (5613, NULL, '2012-01-20 12:54:38.847013+00', 'Arundel Court', 1407, '');
INSERT INTO 'tune' VALUES (5614, NULL, '2012-01-20 12:54:38.849903+00', 'Waterman''s Jig', 1587, '');
INSERT INTO 'tune' VALUES (5615, NULL, '2012-01-20 12:54:38.852793+00', 'Queen''s Fancy, The', 1587, '');
INSERT INTO 'tune' VALUES (5616, NULL, '2012-01-20 12:54:38.855682+00', 'James James Morrison Morrison', 1615, '');
INSERT INTO 'tune' VALUES (5617, NULL, '2012-01-20 12:54:38.858632+00', 'Duchess of Manchester', 1516, '');
INSERT INTO 'tune' VALUES (5618, NULL, '2012-01-20 12:54:38.862252+00', 'Lisbeth & Douglas Henderson Jig', 1615, '');
INSERT INTO 'tune' VALUES (5619, NULL, '2012-01-20 12:54:38.865175+00', 'Wedding, The', 1761, '');
INSERT INTO 'tune' VALUES (5620, NULL, '2012-01-20 12:54:38.868066+00', 'Come Under My Plaidie', 9999, '');
INSERT INTO 'tune' VALUES (5621, NULL, '2012-01-20 12:54:38.871062+00', 'Wild Mountain Thyme', 9999, '');
INSERT INTO 'tune' VALUES (5622, NULL, '2012-01-20 12:54:38.874023+00', 'John Collie, Insh', 1615, '');
INSERT INTO 'tune' VALUES (5623, NULL, '2012-01-20 12:54:38.876962+00', 'Alan MacPherson of Mosspark', 1672, '');
INSERT INTO 'tune' VALUES (5624, NULL, '2012-01-20 12:54:38.87995+00', 'Paddy''s Green Isle', 9999, '');
INSERT INTO 'tune' VALUES (5625, NULL, '2012-01-20 12:54:38.882866+00', 'Davie Patrick''s Ceilidh', 2143, '');
INSERT INTO 'tune' VALUES (5626, NULL, '2012-01-20 12:54:38.885753+00', 'David''s Advent', 2279, '');
INSERT INTO 'tune' VALUES (5627, NULL, '2012-01-20 12:54:38.888653+00', 'Shetland Reel', 1623, '');
INSERT INTO 'tune' VALUES (5549, NULL, '2020-05-10 08:25:50.604375+00', 'Miss Margaret Brown', 1517, '');
INSERT INTO 'tune' VALUES (5570, NULL, '2020-10-31 10:41:39.219534+00', 'P W Elder', 11992, '');
INSERT INTO 'tune' VALUES (5628, NULL, '2012-01-20 12:54:38.891547+00', 'Sunset on the Saint Lawrence', 2302, '');
INSERT INTO 'tune' VALUES (5629, NULL, '2012-01-20 12:54:38.894637+00', 'Lewis and Harris Gathering, The', 1597, '');
INSERT INTO 'tune' VALUES (5630, NULL, '2012-01-20 12:54:38.897556+00', 'Sliabh Namon', 9998, '');
INSERT INTO 'tune' VALUES (5631, NULL, '2012-01-20 12:54:38.900499+00', 'Irish Cradle Song', 9998, '');
INSERT INTO 'tune' VALUES (5632, NULL, '2012-01-20 12:54:38.903434+00', 'Major General Bruce Matthews', 2436, '');
INSERT INTO 'tune' VALUES (5633, NULL, '2012-01-20 12:54:38.906338+00', 'Janette Gibb''s Polka', 1598, '');
INSERT INTO 'tune' VALUES (5635, NULL, '2012-01-20 12:54:38.912119+00', 'Miss Baird of Newbyth', 9999, '');
INSERT INTO 'tune' VALUES (5636, NULL, '2012-01-20 12:54:38.915126+00', 'Loddie', 1623, '');
INSERT INTO 'tune' VALUES (5637, NULL, '2012-01-20 12:54:38.918094+00', 'Coates Crescent Rose', 2197, '');
INSERT INTO 'tune' VALUES (5634, NULL, '2012-08-30 05:24:57.506626+00', 'Our Highland Queen', 1512, '');
INSERT INTO 'tune' VALUES (5638, NULL, '2012-01-20 12:54:38.921057+00', 'Moss-side', 1598, '');
INSERT INTO 'tune' VALUES (5639, NULL, '2012-01-20 12:54:38.923975+00', 'Duke of Montrose', 9999, '');
INSERT INTO 'tune' VALUES (5640, NULL, '2012-01-20 12:54:38.926893+00', 'Politician Whiskey', 1722, '');
INSERT INTO 'tune' VALUES (5641, NULL, '2012-01-20 12:54:38.929903+00', 'Jessie''s Jig', 1505, '');
INSERT INTO 'tune' VALUES (5642, NULL, '2012-01-20 12:54:38.932871+00', 'Father Tom''s Wager', 9999, '');
INSERT INTO 'tune' VALUES (5643, NULL, '2012-01-20 12:54:38.935774+00', 'Coilsfield House', 1517, '');
INSERT INTO 'tune' VALUES (5644, NULL, '2012-01-20 12:54:38.938666+00', 'Oracle', 1512, '');
INSERT INTO 'tune' VALUES (5645, NULL, '2012-01-20 12:54:38.941809+00', 'Adagio Cantabile', 2455, '');
INSERT INTO 'tune' VALUES (5646, NULL, '2012-01-20 12:54:38.944996+00', 'Pretty Peg', 9999, '');
INSERT INTO 'tune' VALUES (5647, NULL, '2012-01-20 12:54:38.947923+00', 'Road to Tarskavaig', 1782, '');
INSERT INTO 'tune' VALUES (5648, NULL, '2012-01-20 12:54:38.950826+00', 'Mr Lumsden of Auchindores', 1516, '');
INSERT INTO 'tune' VALUES (5649, NULL, '2012-01-20 12:54:38.953716+00', 'Earl of Hyndford''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (5650, NULL, '2012-01-20 12:54:38.956606+00', 'Roslin Castle', 9999, '');
INSERT INTO 'tune' VALUES (5651, NULL, '2012-01-20 12:54:38.959505+00', 'Planxty Hewlett', 1882, '');
INSERT INTO 'tune' VALUES (5652, NULL, '2012-01-20 12:54:38.96249+00', 'Waltz in B Minor op. 69 No. 2', 2456, '');
INSERT INTO 'tune' VALUES (13847, '2018-03-29 18:41:56.677831+00', '2018-03-29 18:41:56.677831+00', 'These Claws are made for Lovin''', 2977, '');
INSERT INTO 'tune' VALUES (5654, NULL, '2012-01-20 12:54:38.968294+00', 'Ewe with the Crooked Horn', 9999, '');
INSERT INTO 'tune' VALUES (5655, NULL, '2012-01-20 12:54:38.97119+00', 'Miss Stewart Menzies', 9999, '');
INSERT INTO 'tune' VALUES (5656, NULL, '2012-01-20 12:54:38.97407+00', 'Mozart, The', 2399, '');
INSERT INTO 'tune' VALUES (5657, NULL, '2012-01-20 12:54:38.976965+00', 'Dublin Hornpipe', 2400, '');
INSERT INTO 'tune' VALUES (5658, NULL, '2012-01-20 12:54:38.979862+00', 'Tara''s Reel', 2127, '');
INSERT INTO 'tune' VALUES (5659, NULL, '2012-01-20 12:54:38.983869+00', 'Tami Lane', 1467, '');
INSERT INTO 'tune' VALUES (5660, NULL, '2012-01-20 12:54:38.986851+00', 'Pleasures of May', 1932, '');
INSERT INTO 'tune' VALUES (5661, NULL, '2012-01-20 12:54:38.989765+00', 'Doug''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (5662, NULL, '2012-01-20 12:54:38.992665+00', 'Irene''s Fancy', 1886, '');
INSERT INTO 'tune' VALUES (5663, NULL, '2012-01-20 12:54:38.995572+00', 'Perth Waltz', 9999, '');
INSERT INTO 'tune' VALUES (5664, NULL, '2012-01-20 12:54:38.998468+00', 'Colonel Riddick''s Reel', 1590, '');
INSERT INTO 'tune' VALUES (5665, NULL, '2012-01-20 12:54:39.001356+00', 'Loch Rhuan', 1671, '');
INSERT INTO 'tune' VALUES (5666, NULL, '2012-01-20 12:54:39.004335+00', 'Mrs Rae Wallace', 1525, '');
INSERT INTO 'tune' VALUES (5667, NULL, '2012-01-20 12:54:39.007242+00', 'Belfast Reel, The', 9998, '');
INSERT INTO 'tune' VALUES (5668, NULL, '2012-01-20 12:54:39.010132+00', 'Ian MacPhail''s Shetland Welcome', 1535, '');
INSERT INTO 'tune' VALUES (5669, NULL, '2012-01-20 12:54:39.013031+00', 'Sarah Elizabeth Carter', 1590, '');
INSERT INTO 'tune' VALUES (5670, NULL, '2012-01-20 12:54:39.01593+00', 'Boney Crossing the Alps', 9998, '');
INSERT INTO 'tune' VALUES (5671, NULL, '2012-01-20 12:54:39.018852+00', 'Kintore House', 2160, '');
INSERT INTO 'tune' VALUES (5673, NULL, '2012-01-20 12:54:39.024758+00', 'Clans Gather, The', 2193, '');
INSERT INTO 'tune' VALUES (5674, NULL, '2012-01-20 12:54:39.027671+00', 'David and Maggie Berridge', 1360, '');
INSERT INTO 'tune' VALUES (5675, NULL, '2012-01-20 12:54:39.030669+00', 'Elderberry Wine', 1489, '');
INSERT INTO 'tune' VALUES (5676, NULL, '2012-01-20 12:54:39.033575+00', 'Gillian''s Jig', 2195, '');
INSERT INTO 'tune' VALUES (5677, NULL, '2012-01-20 12:54:39.036468+00', 'Girnin'' Gates', 2196, '');
INSERT INTO 'tune' VALUES (5678, NULL, '2012-01-20 12:54:39.039438+00', 'Glas Maol', 1590, '');
INSERT INTO 'tune' VALUES (5679, NULL, '2012-01-20 12:54:39.042346+00', 'Gothenburg''s Welcome', 1442, '');
INSERT INTO 'tune' VALUES (5680, NULL, '2012-01-20 12:54:39.045398+00', 'Heather & Sunshine', 2197, '');
INSERT INTO 'tune' VALUES (5681, NULL, '2012-01-20 12:54:39.04831+00', 'Heather Reel', 2198, '');
INSERT INTO 'tune' VALUES (5682, NULL, '2012-01-20 12:54:39.051311+00', 'Humming Top, The', 1653, '');
INSERT INTO 'tune' VALUES (5683, NULL, '2012-01-20 12:54:39.054403+00', 'Ian Muir''s Compliments to Ben Dorkin', 1590, '');
INSERT INTO 'tune' VALUES (5684, NULL, '2012-01-20 12:54:39.057375+00', 'Jean Highstead''s Wedding', 1442, '');
INSERT INTO 'tune' VALUES (5685, NULL, '2012-01-20 12:54:39.060284+00', 'Jig Without A Name', 1842, '');
INSERT INTO 'tune' VALUES (5686, NULL, '2012-01-20 12:54:39.063177+00', 'Jim Cooper''s Hornpipe', 1884, '');
INSERT INTO 'tune' VALUES (5687, NULL, '2012-01-20 12:54:39.066159+00', 'John H. Purcell Esq.', 1649, '');
INSERT INTO 'tune' VALUES (5688, NULL, '2012-01-20 12:54:39.069052+00', 'Lad From Auchnagatt, The', 1360, '');
INSERT INTO 'tune' VALUES (5689, NULL, '2012-01-20 12:54:39.071949+00', 'Lady Rosalind Manzie', 1653, '');
INSERT INTO 'tune' VALUES (5690, NULL, '2012-01-20 12:54:39.074848+00', 'Loch Garten', 1557, '');
INSERT INTO 'tune' VALUES (5691, NULL, '2012-01-20 12:54:39.07775+00', 'Lost Your Marbles?', 1842, '');
INSERT INTO 'tune' VALUES (5692, NULL, '2012-01-20 12:54:39.080639+00', 'Margaret Henderson of Feltham', 1653, '');
INSERT INTO 'tune' VALUES (5693, NULL, '2012-01-20 12:54:39.083573+00', 'Mary Gavin', 2196, '');
INSERT INTO 'tune' VALUES (5694, NULL, '2012-01-20 12:54:39.087535+00', 'Mary Howard''s Jig', 1407, '');
INSERT INTO 'tune' VALUES (5695, NULL, '2012-01-20 12:54:39.090472+00', 'Miss Gavin Of Ochtertyre', 2196, '');
INSERT INTO 'tune' VALUES (5696, NULL, '2012-01-20 12:54:39.093369+00', 'Miss J. Collison Of Warrender', 1754, '');
INSERT INTO 'tune' VALUES (5697, NULL, '2012-01-20 12:54:39.096283+00', 'Miss Margaret Grant of Catrine', 2200, '');
INSERT INTO 'tune' VALUES (5698, NULL, '2012-01-20 12:54:39.099767+00', 'Miss Nelson''s Favourite', 2201, '');
INSERT INTO 'tune' VALUES (5699, NULL, '2012-01-20 12:54:39.10289+00', 'Mrs Allan Nicol', 2192, '');
INSERT INTO 'tune' VALUES (5700, NULL, '2012-01-20 12:54:39.106084+00', 'Mrs Peter''s Strathspey', 2192, '');
INSERT INTO 'tune' VALUES (5701, NULL, '2012-01-20 12:54:39.109008+00', 'Mrs Sandison''s Strathspey', 2196, '');
INSERT INTO 'tune' VALUES (5702, NULL, '2012-01-20 12:54:39.112146+00', 'Oor Mary', 2202, '');
INSERT INTO 'tune' VALUES (5703, NULL, '2012-01-20 12:54:39.115084+00', 'Queen''s Guides, The', 2192, '');
INSERT INTO 'tune' VALUES (5704, NULL, '2012-01-20 12:54:39.118005+00', 'Saint Columba''s, Pont Street', 1713, '');
INSERT INTO 'tune' VALUES (5705, NULL, '2012-01-20 12:54:39.121164+00', 'Sam''s Hornpipe', 2134, '');
INSERT INTO 'tune' VALUES (5706, NULL, '2012-01-20 12:54:39.124807+00', 'Sandy''s Silver Chanter', 1754, '');
INSERT INTO 'tune' VALUES (5707, NULL, '2012-01-20 12:54:39.127967+00', 'New Biggin', 2204, '');
INSERT INTO 'tune' VALUES (5708, NULL, '2012-01-20 12:54:39.13089+00', 'Original Sett of Killiecrankie, The', 1518, '');
INSERT INTO 'tune' VALUES (5709, NULL, '2012-01-20 12:54:39.133788+00', 'Lady Mary Montgomery''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (5710, NULL, '2012-01-20 12:54:39.136684+00', 'Pirriwig, The', 9999, '');
INSERT INTO 'tune' VALUES (5711, NULL, '2012-01-20 12:54:39.139577+00', 'Collonel, The', 2204, '');
INSERT INTO 'tune' VALUES (5712, NULL, '2012-01-20 12:54:39.142465+00', 'Old Set Tune', 9998, '');
INSERT INTO 'tune' VALUES (5713, '2003-03-02 23:00:00+00', '2012-01-20 12:54:39.145365+00', 'Strathcarron Jig', 1531, '');
INSERT INTO 'tune' VALUES (13848, '2018-03-29 18:42:49.152618+00', '2018-03-29 18:42:49.152618+00', 'Glen Echo Gala Two-Step', 2977, '');
INSERT INTO 'tune' VALUES (5715, NULL, '2012-01-20 12:54:39.151247+00', 'Frisco Waltz', 2199, '');
INSERT INTO 'tune' VALUES (5716, NULL, '2012-01-20 12:54:39.15413+00', 'Geordie Hinney', 2205, '');
INSERT INTO 'tune' VALUES (5717, NULL, '2012-01-20 12:54:39.15702+00', 'Mrs Hay of Easthaven', 2206, '');
INSERT INTO 'tune' VALUES (5718, NULL, '2012-01-20 12:54:39.159925+00', 'My Heart is in the Highlands', 9999, '');
INSERT INTO 'tune' VALUES (5719, NULL, '2012-01-20 12:54:39.162823+00', 'Fair Haired Lassie, The', 9999, '');
INSERT INTO 'tune' VALUES (5720, NULL, '2012-01-20 12:54:39.165714+00', 'Merry Ploughboy, The', 9999, '');
INSERT INTO 'tune' VALUES (5721, NULL, '2012-01-20 12:54:39.168644+00', 'I''ve Got a Bonnet Trimmed in Blue', 9999, '');
INSERT INTO 'tune' VALUES (5722, NULL, '2012-01-20 12:54:39.171559+00', 'Craithes Castle', 1554, '');
INSERT INTO 'tune' VALUES (5723, NULL, '2012-01-20 12:54:39.174457+00', 'Johnnie Walker''s Jig', 1404, '');
INSERT INTO 'tune' VALUES (5724, NULL, '2012-01-20 12:54:39.177337+00', 'Bonnie Dunoon', 1613, '');
INSERT INTO 'tune' VALUES (5725, NULL, '2012-01-20 12:54:39.180233+00', 'Kirrie Lads, The', 2208, '');
INSERT INTO 'tune' VALUES (5726, NULL, '2012-01-20 12:54:39.18313+00', 'Harp That Once Was, The', 9999, '');
INSERT INTO 'tune' VALUES (5727, NULL, '2012-01-20 12:54:39.186029+00', 'Oft in the Stilly Night', 9999, '');
INSERT INTO 'tune' VALUES (5728, NULL, '2012-01-20 12:54:39.188918+00', 'Marlborough March, The', 1567, '');
INSERT INTO 'tune' VALUES (5729, NULL, '2012-01-20 12:54:39.191884+00', 'Abercairney Highlanders', 2209, '');
INSERT INTO 'tune' VALUES (5730, NULL, '2012-01-20 12:54:39.194783+00', 'For a British Tar is a Soaring Soul', 1900, '');
INSERT INTO 'tune' VALUES (5731, NULL, '2012-01-20 12:54:39.197676+00', 'I Am the Captain of the Pinafore', 1900, '');
INSERT INTO 'tune' VALUES (5732, NULL, '2012-01-20 12:54:39.200577+00', 'I Am the Ruler of the Queen''s Navee', 1900, '');
INSERT INTO 'tune' VALUES (5733, NULL, '2012-01-20 12:54:39.203474+00', 'He is an Englishman', 1900, '');
INSERT INTO 'tune' VALUES (5734, NULL, '2012-01-20 12:54:39.206366+00', 'Never Mind the Why and Wherefore', 1900, '');
INSERT INTO 'tune' VALUES (5735, NULL, '2012-01-20 12:54:39.209253+00', 'Edwin Harald''s Strathspey', 2208, '');
INSERT INTO 'tune' VALUES (5736, NULL, '2012-01-20 12:54:39.212258+00', 'Queen Elizabeth''s March', 1635, '');
INSERT INTO 'tune' VALUES (5737, NULL, '2012-01-20 12:54:39.215164+00', 'Wull Mulligan of Kirrie', 2208, '');
INSERT INTO 'tune' VALUES (5738, NULL, '2012-01-20 12:54:39.218209+00', 'Gay Gordons', 9999, '');
INSERT INTO 'tune' VALUES (5739, NULL, '2012-01-20 12:54:39.221138+00', 'Miss Delicia Chisholm', 2174, '');
INSERT INTO 'tune' VALUES (5740, NULL, '2012-01-20 12:54:39.22403+00', 'Arcadia', 2211, '');
INSERT INTO 'tune' VALUES (5741, NULL, '2012-01-20 12:54:39.226921+00', 'Jim Sturrock''s Reel', 2208, '');
INSERT INTO 'tune' VALUES (5742, NULL, '2012-01-20 12:54:39.229808+00', 'California Cotillion, The', 9999, '');
INSERT INTO 'tune' VALUES (5743, NULL, '2012-01-20 12:54:39.23277+00', 'Shot Merchant from Harris, The', 1580, '');
INSERT INTO 'tune' VALUES (5744, NULL, '2012-01-20 12:54:39.235678+00', 'Duncan''s Return', 1580, '');
INSERT INTO 'tune' VALUES (5745, NULL, '2012-01-20 12:54:39.238567+00', 'Sixteen Miles to the Bottle', 1580, '');
INSERT INTO 'tune' VALUES (5746, NULL, '2012-01-20 12:54:39.241458+00', 'Lesley Wood''s Reel', 1580, '');
INSERT INTO 'tune' VALUES (5747, NULL, '2012-01-20 12:54:39.244355+00', 'Burgh of Barony, The', 1580, '');
INSERT INTO 'tune' VALUES (5748, NULL, '2012-01-20 12:54:39.247246+00', 'Dodger, The', 1580, '');
INSERT INTO 'tune' VALUES (5749, NULL, '2012-01-20 12:54:39.250245+00', 'Pearl Wedding, The', 2212, '');
INSERT INTO 'tune' VALUES (5750, NULL, '2012-01-20 12:54:39.254687+00', 'Beating the Carpets', 2213, '');
INSERT INTO 'tune' VALUES (5751, NULL, '2012-01-20 12:54:39.257628+00', 'Neck and Neck', 1857, '');
INSERT INTO 'tune' VALUES (5752, NULL, '2012-01-20 12:54:39.260549+00', 'Bonnie Brier Bush, The', 9999, '');
INSERT INTO 'tune' VALUES (5753, NULL, '2012-01-20 12:54:39.264093+00', 'Out in the Ocean', 9999, '');
INSERT INTO 'tune' VALUES (5754, NULL, '2012-01-20 12:54:39.267021+00', 'Lady in the Bottle, The', 2214, '');
INSERT INTO 'tune' VALUES (5755, NULL, '2012-01-20 12:54:39.269912+00', 'Burnbrae', 2215, '');
INSERT INTO 'tune' VALUES (5756, NULL, '2012-01-20 12:54:39.272865+00', 'Pitlochry Highland Games, The', 1580, '');
INSERT INTO 'tune' VALUES (5757, NULL, '2012-01-20 12:54:39.275794+00', 'Calais Packet, The', 9999, '');
INSERT INTO 'tune' VALUES (5758, NULL, '2012-01-20 12:54:39.278705+00', 'March of the Cameron Men, The', 9999, '');
INSERT INTO 'tune' VALUES (5759, NULL, '2012-01-20 12:54:39.281596+00', 'Hunter of the Yak', 1580, '');
INSERT INTO 'tune' VALUES (5760, NULL, '2012-01-20 12:54:39.284498+00', 'Brendan Mulvihill''s Compliments to Sean McQuire', 2216, '');
INSERT INTO 'tune' VALUES (5761, NULL, '2012-01-20 12:54:39.287406+00', 'Tommy''s E Flat CLog', 9998, '');
INSERT INTO 'tune' VALUES (5762, NULL, '2012-01-20 12:54:39.2903+00', 'Granny MacLeod', 2218, '');
INSERT INTO 'tune' VALUES (5763, NULL, '2012-01-20 12:54:39.293276+00', 'Caileach an Dudain', 9999, '');
INSERT INTO 'tune' VALUES (5764, NULL, '2012-01-20 12:54:39.296189+00', 'Final Fling, The', 1673, '');
INSERT INTO 'tune' VALUES (5765, NULL, '2012-01-20 12:54:39.299093+00', 'Lawfield', 1502, '');
INSERT INTO 'tune' VALUES (5766, NULL, '2012-01-20 12:54:39.301986+00', 'Daisy Rae of Duns', 1502, '');
INSERT INTO 'tune' VALUES (5767, NULL, '2012-01-20 12:54:39.305033+00', 'Janet Stewart', 1646, '');
INSERT INTO 'tune' VALUES (5768, NULL, '2012-01-20 12:54:39.307957+00', 'Empty Bird Box, The', 1646, '');
INSERT INTO 'tune' VALUES (5769, NULL, '2012-01-20 12:54:39.310858+00', 'Whisky Association Reel, The', 1502, '');
INSERT INTO 'tune' VALUES (5770, NULL, '2012-01-20 12:54:39.313812+00', 'Downfield Reel, The', 1656, '');
INSERT INTO 'tune' VALUES (5771, NULL, '2012-01-20 12:54:39.316707+00', 'Sir John Swinton of Kimmerghame', 1502, '');
INSERT INTO 'tune' VALUES (5772, NULL, '2012-01-20 12:54:39.31961+00', 'Sarah Elizabeth (Great Wee Legs)', 1502, '');
INSERT INTO 'tune' VALUES (5773, NULL, '2012-01-20 12:54:39.322509+00', 'Kinlochmoidart', 1502, '');
INSERT INTO 'tune' VALUES (5774, NULL, '2012-01-20 12:54:39.325396+00', 'Johnny Johnson', 1623, '');
INSERT INTO 'tune' VALUES (5775, NULL, '2012-01-20 12:54:39.328488+00', 'Dryfesdale Reel', 1523, '');
INSERT INTO 'tune' VALUES (5776, NULL, '2012-01-20 12:54:39.331413+00', 'Fu'' as a Puggy', 1502, '');
INSERT INTO 'tune' VALUES (5777, NULL, '2012-01-20 12:54:39.334391+00', 'Glenfiddich', 2219, '');
INSERT INTO 'tune' VALUES (5778, NULL, '2012-01-20 12:54:39.337289+00', 'Eyemouth Petronella, The', 1502, '');
INSERT INTO 'tune' VALUES (5779, NULL, '2012-01-20 12:54:39.340177+00', 'Jim''s Lady', 1502, '');
INSERT INTO 'tune' VALUES (5780, NULL, '2012-01-20 12:54:39.343067+00', 'Peggy''s Joy', 1235, '');
INSERT INTO 'tune' VALUES (5781, NULL, '2012-01-20 12:54:39.345957+00', 'Robert''s Delight', 1235, '');
INSERT INTO 'tune' VALUES (5782, NULL, '2012-01-20 12:54:39.348854+00', 'Lady Swan of Blackhouse', 1235, '');
INSERT INTO 'tune' VALUES (5783, NULL, '2012-01-20 12:54:39.351756+00', 'Heart of Fire', 1235, '');
INSERT INTO 'tune' VALUES (5784, NULL, '2012-01-20 12:54:39.354783+00', 'Wind and the Waves, The', 1235, '');
INSERT INTO 'tune' VALUES (5785, NULL, '2012-01-20 12:54:39.357685+00', 'Margaret''s Reel', 1235, '');
INSERT INTO 'tune' VALUES (5787, NULL, '2012-01-20 12:54:39.363477+00', 'Izzy''s Reel', 1966, '');
INSERT INTO 'tune' VALUES (5788, NULL, '2012-01-20 12:54:39.366369+00', 'Great Earthen Stone, The', 1966, '');
INSERT INTO 'tune' VALUES (5789, NULL, '2012-01-20 12:54:39.369258+00', 'Strand, The', 9999, '');
INSERT INTO 'tune' VALUES (5790, NULL, '2012-01-20 12:54:39.372148+00', 'Marchioness of Huntly''s Favourite Jig, The', 1516, '');
INSERT INTO 'tune' VALUES (5791, NULL, '2012-01-20 12:54:39.3751+00', 'Lowlands of Scotland, The', 9999, '');
INSERT INTO 'tune' VALUES (5792, NULL, '2012-01-20 12:54:39.378026+00', 'Ginnie Put Your Bonnet On', 9999, '');
INSERT INTO 'tune' VALUES (5793, NULL, '2012-01-20 12:54:39.380917+00', 'Parting, The', 1966, '');
INSERT INTO 'tune' VALUES (5794, NULL, '2012-01-20 12:54:39.383808+00', 'Rosemont', 1966, '');
INSERT INTO 'tune' VALUES (5795, NULL, '2012-01-20 12:54:39.386701+00', 'KJC', 2221, '');
INSERT INTO 'tune' VALUES (5796, NULL, '2012-01-20 12:54:39.389585+00', 'Nellie Wemyss', 9999, '');
INSERT INTO 'tune' VALUES (5797, NULL, '2012-01-20 12:54:39.39247+00', '''Ille Chrubaich', 9999, '');
INSERT INTO 'tune' VALUES (5798, NULL, '2012-01-20 12:54:39.395416+00', 'Nighinn Na Cailliche', 9999, '');
INSERT INTO 'tune' VALUES (5799, NULL, '2012-01-20 12:54:39.398318+00', 'Fhuaras am Pige Ruadh', 9999, '');
INSERT INTO 'tune' VALUES (5800, NULL, '2012-01-20 12:54:39.40121+00', 'An Fhaighear Mhulleach', 9998, '');
INSERT INTO 'tune' VALUES (5801, NULL, '2012-01-20 12:54:39.404096+00', 'N'' Oichde bha na Gobhar Ann', 9999, '');
INSERT INTO 'tune' VALUES (5802, NULL, '2012-01-20 12:54:39.407246+00', 'Siuthad a Bhalachabh', 9999, '');
INSERT INTO 'tune' VALUES (5803, NULL, '2012-01-20 12:54:39.410365+00', 'Thoir a Nall Ailein Thugam', 9999, '');
INSERT INTO 'tune' VALUES (5804, NULL, '2012-01-20 12:54:39.413278+00', 'Seinn o Churadal', 9999, '');
INSERT INTO 'tune' VALUES (5805, NULL, '2012-01-20 12:54:39.416245+00', 'Wee Malcolm', 1659, '');
INSERT INTO 'tune' VALUES (5806, NULL, '2012-01-20 12:54:39.421066+00', 'Island Homing song', 2226, '');
INSERT INTO 'tune' VALUES (5807, NULL, '2012-01-20 12:54:39.424322+00', 'Miss Millicent''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (5808, NULL, '2012-01-20 12:54:39.427242+00', 'Blair''s Reel', 1659, '');
INSERT INTO 'tune' VALUES (5809, NULL, '2012-01-20 12:54:39.430144+00', 'Bobby MacLoed''s Visit to Dumfries', 1606, '');
INSERT INTO 'tune' VALUES (5922, NULL, '2012-01-20 12:54:39.762859+00', 'Suilven', 1502, '');
INSERT INTO 'tune' VALUES (5810, NULL, '2012-01-20 12:54:39.434044+00', 'Fagail Steornabhagh', 9999, '');
INSERT INTO 'tune' VALUES (5811, NULL, '2012-01-20 12:54:39.436956+00', 'A'' Chutag', 9999, '');
INSERT INTO 'tune' VALUES (5812, NULL, '2012-01-20 12:54:39.440097+00', 'An t''Eilean Shiar a Dhag Mi', 9999, '');
INSERT INTO 'tune' VALUES (5813, NULL, '2012-01-20 12:54:39.443046+00', 'Caisteal a Ghlinne', 9999, '');
INSERT INTO 'tune' VALUES (5814, NULL, '2012-01-20 12:54:39.445938+00', 'Madamoiselle from Armentieres', 2355, '');
INSERT INTO 'tune' VALUES (5815, NULL, '2012-01-20 12:54:39.449023+00', 'Humours of Castle Comer', 9999, '');
INSERT INTO 'tune' VALUES (5816, NULL, '2012-01-20 12:54:39.451965+00', 'Crossing the Minch', 1910, '');
INSERT INTO 'tune' VALUES (5817, NULL, '2012-01-20 12:54:39.454879+00', 'Drifting', 1701, '');
INSERT INTO 'tune' VALUES (5818, NULL, '2012-01-20 12:54:39.457769+00', 'Queen Victoria''s Jubilee', 9998, '');
INSERT INTO 'tune' VALUES (5820, NULL, '2012-01-20 12:54:39.464081+00', 'O''Kane''s March', 9998, '');
INSERT INTO 'tune' VALUES (5822, NULL, '2012-01-20 12:54:39.469941+00', 'Athlone, The', 9998, '');
INSERT INTO 'tune' VALUES (5823, NULL, '2012-01-20 12:54:39.472832+00', 'Sherlock''s', 9998, '');
INSERT INTO 'tune' VALUES (5824, NULL, '2012-01-20 12:54:39.475725+00', 'Hot Potato, The', 9998, '');
INSERT INTO 'tune' VALUES (5825, NULL, '2012-01-20 12:54:39.478614+00', 'Earl Gaddis', 1502, '');
INSERT INTO 'tune' VALUES (5826, NULL, '2012-01-20 12:54:39.481616+00', 'Andy', 9999, '');
INSERT INTO 'tune' VALUES (5827, NULL, '2012-01-20 12:54:39.484512+00', 'Whistling Farmer, The', 9999, '');
INSERT INTO 'tune' VALUES (5828, NULL, '2012-01-20 12:54:39.487409+00', 'Old Man and The Old Woman, The', 9999, '');
INSERT INTO 'tune' VALUES (5829, NULL, '2012-01-20 12:54:39.4903+00', 'John A Cameron''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (5830, NULL, '2012-01-20 12:54:39.493244+00', 'Hugaibh Oirbh', 9999, '');
INSERT INTO 'tune' VALUES (5831, NULL, '2012-01-20 12:54:39.496136+00', 'Inverary Wedding, The', 9999, '');
INSERT INTO 'tune' VALUES (5832, NULL, '2012-01-20 12:54:39.499026+00', 'Bobby Watson', 1558, '');
INSERT INTO 'tune' VALUES (5833, NULL, '2012-01-20 12:54:39.502008+00', 'Piper''s Picnic, The', 9999, '');
INSERT INTO 'tune' VALUES (5834, NULL, '2012-01-20 12:54:39.504911+00', 'Banks of Loch Gowna, The', 9999, '');
INSERT INTO 'tune' VALUES (5835, NULL, '2012-01-20 12:54:39.507802+00', 'Jackson''s Maid', 9999, '');
INSERT INTO 'tune' VALUES (5836, NULL, '2012-01-20 12:54:39.510703+00', 'Alison''s Reel', 1591, '');
INSERT INTO 'tune' VALUES (5838, NULL, '2012-01-20 12:54:39.516586+00', 'Lang Stracht Fiddler, The', 1507, '');
INSERT INTO 'tune' VALUES (5839, NULL, '2012-01-20 12:54:39.519575+00', 'Mrs Judy Wheelan''s Fancy', 1646, '');
INSERT INTO 'tune' VALUES (5840, NULL, '2012-01-20 12:54:39.52251+00', 'Heather''s Hebridean Hornpipe', 1507, '');
INSERT INTO 'tune' VALUES (5841, NULL, '2012-01-20 12:54:39.525407+00', 'Mountain Road, The', 9999, '');
INSERT INTO 'tune' VALUES (5842, NULL, '2012-01-20 12:54:39.528347+00', 'Down the Broom', 9999, '');
INSERT INTO 'tune' VALUES (5843, NULL, '2012-01-20 12:54:39.531256+00', 'All Around the World', 9999, '');
INSERT INTO 'tune' VALUES (5821, '2006-09-03 22:00:00+00', '2012-04-03 20:48:18.755181+00', 'Blue Crab Hornpipe, The', 2977, 'Composed 2006');
INSERT INTO 'tune' VALUES (5844, NULL, '2012-01-20 12:54:39.534142+00', 'Road to Rio, The', 9999, '');
INSERT INTO 'tune' VALUES (5845, NULL, '2012-01-20 12:54:39.537055+00', 'Tom Billy''s', 9999, '');
INSERT INTO 'tune' VALUES (5846, NULL, '2012-01-20 12:54:39.540037+00', 'Our Vet from Inverary', 1507, '');
INSERT INTO 'tune' VALUES (5847, NULL, '2012-01-20 12:54:39.542948+00', 'Canadian Reel', 9998, '');
INSERT INTO 'tune' VALUES (5848, NULL, '2012-01-20 12:54:39.545841+00', 'Willie Anderson of Beith', 1579, '');
INSERT INTO 'tune' VALUES (5849, NULL, '2012-01-20 12:54:39.548736+00', 'Great Wood Corners, The', 1502, '');
INSERT INTO 'tune' VALUES (5850, NULL, '2012-01-20 12:54:39.551712+00', 'Ian Peterson', 1596, '');
INSERT INTO 'tune' VALUES (5851, NULL, '2012-01-20 12:54:39.554622+00', 'Miss Aileen Jack', 1576, '');
INSERT INTO 'tune' VALUES (5852, NULL, '2012-01-20 12:54:39.557514+00', 'Mr Garden of Troup''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (5853, NULL, '2012-01-20 12:54:39.560428+00', 'Catchin'' Rabbits', 1551, '');
INSERT INTO 'tune' VALUES (5854, NULL, '2012-01-20 12:54:39.564184+00', 'Miss Nancy Dick''s Favourite', 1519, '');
INSERT INTO 'tune' VALUES (5856, NULL, '2012-01-20 12:54:39.569994+00', 'McLaughlin''s Strathspey', 1782, '');
INSERT INTO 'tune' VALUES (5857, NULL, '2012-01-20 12:54:39.572884+00', 'Boidag Ain McOmish', 9999, '');
INSERT INTO 'tune' VALUES (5858, NULL, '2012-01-20 12:54:39.575793+00', 'Anne McAndrew', 1502, '');
INSERT INTO 'tune' VALUES (5859, NULL, '2012-01-20 12:54:39.57869+00', 'Margaret William''s Strathspey', 1590, '');
INSERT INTO 'tune' VALUES (5860, NULL, '2012-01-20 12:54:39.581658+00', 'Charles Duff''s Compliments to his Brother', 9999, '');
INSERT INTO 'tune' VALUES (5861, NULL, '2012-01-20 12:54:39.584574+00', 'Mafsa Me', 9999, '');
INSERT INTO 'tune' VALUES (5862, NULL, '2012-01-20 12:54:39.58748+00', 'Mrs Rosalind Snaith', 1593, '');
INSERT INTO 'tune' VALUES (5863, NULL, '2012-01-20 12:54:39.590379+00', 'Mrs Patricia Maxwell''s Jig', 1680, '');
INSERT INTO 'tune' VALUES (5864, NULL, '2012-01-20 12:54:39.593279+00', 'A Dhomhnuill, A Dhomhnuill', 9999, '');
INSERT INTO 'tune' VALUES (5865, NULL, '2012-01-20 12:54:39.596171+00', 'Miss Wilhelmina McDowal''s Reel of Ardnilly', 1516, '');
INSERT INTO 'tune' VALUES (5866, NULL, '2012-01-20 12:54:39.599089+00', 'Fishers Wedding', 9999, '');
INSERT INTO 'tune' VALUES (5867, NULL, '2012-01-20 12:54:39.602154+00', 'Morning Mist', 9999, '');
INSERT INTO 'tune' VALUES (5868, NULL, '2012-01-20 12:54:39.605118+00', 'Belles of St. Louis, The', 9999, '');
INSERT INTO 'tune' VALUES (5869, NULL, '2012-01-20 12:54:39.608026+00', 'Harold & Gladys Craig of Rosyth', 1505, '');
INSERT INTO 'tune' VALUES (5870, NULL, '2012-01-20 12:54:39.610923+00', 'Iain Fraser of West Park', 2914, '');
INSERT INTO 'tune' VALUES (5872, NULL, '2012-01-20 12:54:39.616703+00', 'Briggie Stanes', 1645, '');
INSERT INTO 'tune' VALUES (5873, NULL, '2012-01-20 12:54:39.619602+00', 'Jimmy Mann''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (5875, NULL, '2012-01-20 12:54:39.625617+00', 'Fiddling Phil', 9998, '');
INSERT INTO 'tune' VALUES (5876, NULL, '2012-01-20 12:54:39.628505+00', 'Arthur Walker''s Jig', 1811, '');
INSERT INTO 'tune' VALUES (5877, NULL, '2012-01-20 12:54:39.631392+00', 'Trip to Toronto', 1633, '');
INSERT INTO 'tune' VALUES (5878, NULL, '2012-01-20 12:54:39.634282+00', 'Adam Hickey''s', 2238, '');
INSERT INTO 'tune' VALUES (5879, NULL, '2012-01-20 12:54:39.637166+00', 'William McKenzie Crowe', 1522, '');
INSERT INTO 'tune' VALUES (5880, NULL, '2012-01-20 12:54:39.640052+00', 'Bonxie, Da', 1786, '');
INSERT INTO 'tune' VALUES (5881, NULL, '2012-01-20 12:54:39.64301+00', 'Hill of Keir', 1538, '');
INSERT INTO 'tune' VALUES (5882, NULL, '2012-01-20 12:54:39.645911+00', 'Elizabeth Maxwell''s Strathspey', 1507, '');
INSERT INTO 'tune' VALUES (5883, NULL, '2012-01-20 12:54:39.648809+00', 'Harry Picken''s Hornpipe', 1413, '');
INSERT INTO 'tune' VALUES (5884, NULL, '2012-01-20 12:54:39.651705+00', 'Jig for Midge, A', 2897, '');
INSERT INTO 'tune' VALUES (5885, NULL, '2012-01-20 12:54:39.654588+00', 'Jack Delaney', 1613, '');
INSERT INTO 'tune' VALUES (5886, NULL, '2012-01-20 12:54:39.657472+00', 'Miss Frances Urquhart', 9999, '');
INSERT INTO 'tune' VALUES (5887, NULL, '2012-01-20 12:54:39.660572+00', 'Mrs Oswald of Auchencruive''s New Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (5888, NULL, '2012-01-20 12:54:39.663814+00', 'Earl of Haddington, The', 1518, '');
INSERT INTO 'tune' VALUES (5889, NULL, '2012-01-20 12:54:39.666758+00', 'Witches Hill, The', 9999, '');
INSERT INTO 'tune' VALUES (5890, NULL, '2012-01-20 12:54:39.669675+00', 'Sron MacIlleathain', 1613, '');
INSERT INTO 'tune' VALUES (5891, NULL, '2012-01-20 12:54:39.672565+00', 'Miss Oliphant of Gask''s Delight', 9998, '');
INSERT INTO 'tune' VALUES (5892, NULL, '2012-01-20 12:54:39.675467+00', 'Craig o'' Barnes', 1810, '');
INSERT INTO 'tune' VALUES (5893, NULL, '2012-01-20 12:54:39.678363+00', 'Miss Isabella Robertson''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (5894, NULL, '2012-01-20 12:54:39.681257+00', 'Cecil and Mona Tulloch', 2239, '');
INSERT INTO 'tune' VALUES (5895, NULL, '2012-01-20 12:54:39.684212+00', 'Roddy Ross of Brora', 2406, '');
INSERT INTO 'tune' VALUES (5896, NULL, '2012-01-20 12:54:39.687122+00', 'Donald MacLeod''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (5871, NULL, '2016-06-09 09:36:57.097184+00', 'Fishnish Ferry, The', 1605, '');
INSERT INTO 'tune' VALUES (5898, NULL, '2012-01-20 12:54:39.692891+00', 'Flowers of Limerick, The', 9999, '');
INSERT INTO 'tune' VALUES (5899, NULL, '2012-01-20 12:54:39.695789+00', 'Leys of Luncarty, The', 9999, '');
INSERT INTO 'tune' VALUES (5900, NULL, '2012-01-20 12:54:39.698687+00', 'Barbara Emslie', 1724, '');
INSERT INTO 'tune' VALUES (5901, NULL, '2012-01-20 12:54:39.701575+00', 'Mrs Helen Jamieson', 1645, '');
INSERT INTO 'tune' VALUES (5902, NULL, '2012-01-20 12:54:39.704463+00', 'Irish Jig', 9999, '');
INSERT INTO 'tune' VALUES (5903, NULL, '2012-01-20 12:54:39.707447+00', 'Lady Madelina Palmer', 1516, '');
INSERT INTO 'tune' VALUES (5904, NULL, '2012-01-20 12:54:39.710347+00', 'Lindsay Zobel', 1502, '');
INSERT INTO 'tune' VALUES (5905, NULL, '2012-01-20 12:54:39.713239+00', 'Mrs Dorothy Johnstone', 1502, '');
INSERT INTO 'tune' VALUES (5906, NULL, '2012-01-20 12:54:39.716127+00', 'Alastair''s Hornpipe', 1502, '');
INSERT INTO 'tune' VALUES (5907, NULL, '2012-01-20 12:54:39.719023+00', 'Have Kilt Will Travel', 1502, '');
INSERT INTO 'tune' VALUES (5908, NULL, '2012-01-20 12:54:39.721919+00', 'Mel''s Fiddle', 1502, '');
INSERT INTO 'tune' VALUES (5909, NULL, '2012-01-20 12:54:39.724817+00', 'Miss Carole Stoker', 1502, '');
INSERT INTO 'tune' VALUES (5910, NULL, '2012-01-20 12:54:39.727803+00', 'Miss Jean McColm', 1502, '');
INSERT INTO 'tune' VALUES (5911, NULL, '2012-01-20 12:54:39.730706+00', 'Dancing Fingers', 1502, '');
INSERT INTO 'tune' VALUES (5912, NULL, '2012-01-20 12:54:39.733796+00', 'Confluence, The', 1502, '');
INSERT INTO 'tune' VALUES (5913, NULL, '2012-01-20 12:54:39.7367+00', 'Majician, The', 1502, '');
INSERT INTO 'tune' VALUES (5914, NULL, '2012-01-20 12:54:39.739603+00', 'Postmaster, The', 1502, '');
INSERT INTO 'tune' VALUES (5915, NULL, '2012-01-20 12:54:39.742494+00', 'Mowden Hall', 1502, '');
INSERT INTO 'tune' VALUES (5916, NULL, '2012-01-20 12:54:39.74538+00', 'Longridge Towers', 1502, '');
INSERT INTO 'tune' VALUES (5917, NULL, '2012-01-20 12:54:39.748369+00', 'Ravensdowne', 1502, '');
INSERT INTO 'tune' VALUES (5918, NULL, '2012-01-20 12:54:39.751278+00', 'Eyemouth Harbour', 1502, '');
INSERT INTO 'tune' VALUES (5919, NULL, '2012-01-20 12:54:39.754162+00', 'Berwick Waltz', 1502, '');
INSERT INTO 'tune' VALUES (5920, NULL, '2012-01-20 12:54:39.757054+00', 'Fiona May', 1502, '');
INSERT INTO 'tune' VALUES (5921, NULL, '2012-01-20 12:54:39.759955+00', 'Canisp', 1502, '');
INSERT INTO 'tune' VALUES (5923, NULL, '2012-01-20 12:54:39.765751+00', 'Shibumi', 1502, '');
INSERT INTO 'tune' VALUES (5924, NULL, '2012-01-20 12:54:39.768713+00', 'Grist to the Mill', 1502, '');
INSERT INTO 'tune' VALUES (5925, NULL, '2012-01-20 12:54:39.771613+00', 'Mary', 9999, '');
INSERT INTO 'tune' VALUES (5926, NULL, '2012-01-20 12:54:39.774502+00', 'Song of Home', 1935, '');
INSERT INTO 'tune' VALUES (5927, NULL, '2012-01-20 12:54:39.777388+00', 'Traditional Canadian Air', 9999, '');
INSERT INTO 'tune' VALUES (5928, NULL, '2012-01-20 12:54:39.780473+00', 'Come to the Ceilidh', 2225, '');
INSERT INTO 'tune' VALUES (5929, NULL, '2012-01-20 12:54:39.783431+00', 'Hartigan''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (5930, NULL, '2012-01-20 12:54:39.786438+00', 'Priest''s Lap, The', 9999, '');
INSERT INTO 'tune' VALUES (5931, NULL, '2012-01-20 12:54:39.789366+00', 'Jig Runrig, The', 3052, '');
INSERT INTO 'tune' VALUES (5933, NULL, '2012-01-20 12:54:39.795327+00', 'Calliope House', 2241, '');
INSERT INTO 'tune' VALUES (5934, NULL, '2012-01-20 12:54:39.798224+00', 'Rickety', 2242, '');
INSERT INTO 'tune' VALUES (5935, NULL, '2012-01-20 12:54:39.801156+00', 'Miss Fiona Mitchell', 1585, '');
INSERT INTO 'tune' VALUES (5936, NULL, '2012-01-20 12:54:39.804102+00', 'Down in the Coalmine', 9999, '');
INSERT INTO 'tune' VALUES (5937, NULL, '2012-01-20 12:54:39.807053+00', 'Walking with my Sheep', 9999, '');
INSERT INTO 'tune' VALUES (5938, NULL, '2012-01-20 12:54:39.809949+00', 'High Barbaree', 9999, '');
INSERT INTO 'tune' VALUES (5939, NULL, '2012-01-20 12:54:39.81284+00', 'Oak and the Ash, The', 9999, '');
INSERT INTO 'tune' VALUES (5940, NULL, '2012-01-20 12:54:39.815732+00', 'Polka fra Laeso', 9999, '');
INSERT INTO 'tune' VALUES (5941, NULL, '2012-01-20 12:54:39.818625+00', 'Ebba Polka', 9999, '');
INSERT INTO 'tune' VALUES (5942, NULL, '2012-01-20 12:54:39.821512+00', 'Katie''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (5943, NULL, '2012-01-20 12:54:39.824427+00', 'Rakes of Clonmel, The', 9999, '');
INSERT INTO 'tune' VALUES (5944, NULL, '2012-01-20 12:54:39.827318+00', 'Luck Penny, The', 9999, '');
INSERT INTO 'tune' VALUES (5945, NULL, '2012-01-20 12:54:39.830302+00', 'Ross''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (5946, NULL, '2012-01-20 12:54:39.833204+00', 'Pointe au Pic', 9999, '');
INSERT INTO 'tune' VALUES (5947, NULL, '2012-01-20 12:54:39.836089+00', 'Quigley''s Reel', 1712, '');
INSERT INTO 'tune' VALUES (5948, NULL, '2012-01-20 12:54:39.838979+00', 'Rosebud Reel', 9999, '');
INSERT INTO 'tune' VALUES (5949, NULL, '2012-01-20 12:54:39.841865+00', 'Prince Charlie', 9999, '');
INSERT INTO 'tune' VALUES (5950, NULL, '2012-01-20 12:54:39.84476+00', 'Balquhidder Lasses', 9999, '');
INSERT INTO 'tune' VALUES (5951, NULL, '2012-01-20 12:54:39.847663+00', 'Sandra''s Jig', 2166, '');
INSERT INTO 'tune' VALUES (5952, NULL, '2012-01-20 12:54:39.85064+00', 'Tea Gardens', 2243, '');
INSERT INTO 'tune' VALUES (5953, NULL, '2012-01-20 12:54:39.853533+00', 'Dinkie''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (5954, NULL, '2012-01-20 12:54:39.856424+00', 'David Anderson''s Shand''s Hornpipe', 1558, '');
INSERT INTO 'tune' VALUES (5955, NULL, '2012-01-20 12:54:39.859321+00', 'Morag''s Reel', 3058, '');
INSERT INTO 'tune' VALUES (5957, NULL, '2012-01-20 12:54:39.865493+00', 'Corner House, The', 9999, '');
INSERT INTO 'tune' VALUES (5958, NULL, '2012-01-20 12:54:39.86856+00', 'High Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (5959, NULL, '2012-01-20 12:54:39.871657+00', 'Silver Spire, The', 9999, '');
INSERT INTO 'tune' VALUES (5960, NULL, '2012-01-20 12:54:39.874595+00', 'Saint Margaret''s Inch', 1578, '');
INSERT INTO 'tune' VALUES (5961, NULL, '2012-01-20 12:54:39.877488+00', 'Martin Stewart', 1592, '');
INSERT INTO 'tune' VALUES (5963, NULL, '2012-01-20 12:54:39.883316+00', 'Crusader''s March, The', 9999, '');
INSERT INTO 'tune' VALUES (5964, NULL, '2012-01-20 12:54:39.886202+00', 'Lyndhurst', 2223, '');
INSERT INTO 'tune' VALUES (5965, NULL, '2012-01-20 12:54:39.889163+00', 'Bannocks o'' Barley Meal', 9999, '');
INSERT INTO 'tune' VALUES (5966, NULL, '2012-01-20 12:54:39.892078+00', 'Maid of Glengarrysdale, The', 9999, '');
INSERT INTO 'tune' VALUES (5967, NULL, '2012-01-20 12:54:39.89518+00', 'Tartan Ball, The', 2250, '');
INSERT INTO 'tune' VALUES (5968, NULL, '2012-01-20 12:54:39.898295+00', 'Highland Polka', 1550, '');
INSERT INTO 'tune' VALUES (5969, NULL, '2012-01-20 12:54:39.901197+00', 'River Cree, The', 9999, '');
INSERT INTO 'tune' VALUES (5970, NULL, '2012-01-20 12:54:39.904086+00', 'Camerhouse', 9999, '');
INSERT INTO 'tune' VALUES (5971, NULL, '2012-01-20 12:54:39.906969+00', 'Disused Railway, The', 9999, '');
INSERT INTO 'tune' VALUES (5972, NULL, '2012-01-20 12:54:39.909921+00', 'Padruig Og', 2225, '');
INSERT INTO 'tune' VALUES (5973, NULL, '2012-01-20 12:54:39.912836+00', 'Bobby Crowe''s Compliments to the Laird o'' Corrieburn', 1585, '');
INSERT INTO 'tune' VALUES (5974, NULL, '2012-01-20 12:54:39.915737+00', 'John Ross MacKenzie', 1585, '');
INSERT INTO 'tune' VALUES (5975, NULL, '2012-01-20 12:54:39.918632+00', 'Murdo Morrison of Borve', 1634, '');
INSERT INTO 'tune' VALUES (5976, NULL, '2012-01-20 12:54:39.921519+00', 'Fiddling Mathematician, The', 1578, '');
INSERT INTO 'tune' VALUES (5977, NULL, '2012-01-20 12:54:39.924408+00', 'Doctor''s Dilemma, The', 1576, '');
INSERT INTO 'tune' VALUES (5978, NULL, '2012-01-20 12:54:39.927314+00', 'Culzean Castle', 1871, '');
INSERT INTO 'tune' VALUES (5979, NULL, '2012-01-20 12:54:39.930275+00', 'Inside Oot Fish Eater, The', 2253, '');
INSERT INTO 'tune' VALUES (5980, NULL, '2012-01-20 12:54:39.933183+00', 'Highlandman''s Umbrella, The', 2254, '');
INSERT INTO 'tune' VALUES (5981, NULL, '2012-01-20 12:54:39.936077+00', 'Summer Road, The', 1883, '');
INSERT INTO 'tune' VALUES (5982, NULL, '2012-01-20 12:54:39.938961+00', 'Fairy''s Love Song, A', 9999, '');
INSERT INTO 'tune' VALUES (5983, NULL, '2012-01-20 12:54:39.941858+00', 'Deaconsbank', 1659, '');
INSERT INTO 'tune' VALUES (5984, NULL, '2012-01-20 12:54:39.944751+00', 'Pretty Girl Milking her Cow, The', 9999, '');
INSERT INTO 'tune' VALUES (5985, NULL, '2012-01-20 12:54:39.947643+00', 'Caledonian Laddie', 9999, '');
INSERT INTO 'tune' VALUES (5987, NULL, '2012-01-20 12:54:39.953579+00', 'Lady Mary''s Marriage', 9999, '');
INSERT INTO 'tune' VALUES (5988, NULL, '2012-01-20 12:54:39.956479+00', 'Pipers Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (5989, NULL, '2012-01-20 12:54:39.959373+00', 'Charlie', 9999, '');
INSERT INTO 'tune' VALUES (5990, NULL, '2012-01-20 12:54:39.962264+00', 'When Johnny Comes Marching Home', 9999, '');
INSERT INTO 'tune' VALUES (5991, NULL, '2012-01-20 12:54:39.965151+00', 'One More River to Cross', 9999, '');
INSERT INTO 'tune' VALUES (5992, NULL, '2012-01-20 12:54:39.968035+00', 'Heather Jock', 9999, '');
INSERT INTO 'tune' VALUES (5993, NULL, '2012-01-20 12:54:39.97093+00', 'Jessie', 9999, '');
INSERT INTO 'tune' VALUES (5994, NULL, '2012-01-20 12:54:39.973885+00', 'Melodion, The', 1659, '');
INSERT INTO 'tune' VALUES (5995, NULL, '2012-01-20 12:54:39.976782+00', 'Trip to the Cottage', 9999, '');
INSERT INTO 'tune' VALUES (5996, NULL, '2012-01-20 12:54:39.979687+00', 'Heart of Midlothian, The', 2255, '');
INSERT INTO 'tune' VALUES (5997, NULL, '2012-01-20 12:54:39.982578+00', 'Bonnie Lassie of Dundee, The', 2255, '');
INSERT INTO 'tune' VALUES (5998, NULL, '2012-01-20 12:54:39.985474+00', 'Bugler on the Battlements, The', 326, '');
INSERT INTO 'tune' VALUES (5999, NULL, '2012-01-20 12:54:39.988382+00', 'Summer with MacKinnon', 9999, '');
INSERT INTO 'tune' VALUES (6000, NULL, '2012-01-20 12:54:39.991275+00', 'Margaret of Inverary', 1551, '');
INSERT INTO 'tune' VALUES (6001, NULL, '2012-01-20 12:54:39.994255+00', 'Traditional Scottish Air', 9999, '');
INSERT INTO 'tune' VALUES (6002, NULL, '2012-01-20 12:54:39.997158+00', 'Fox and the Grapes, The', 9999, '');
INSERT INTO 'tune' VALUES (6003, NULL, '2012-01-20 12:54:40.031168+00', 'Ada Finlay of Farmhall', 1551, '');
INSERT INTO 'tune' VALUES (6004, NULL, '2012-01-20 12:54:40.034359+00', 'Ussher and MacRae', 9999, '');
INSERT INTO 'tune' VALUES (6005, NULL, '2012-01-20 12:54:40.037973+00', 'Bonnie Bessie Lee', 9999, '');
INSERT INTO 'tune' VALUES (6006, NULL, '2012-01-20 12:54:40.041836+00', 'Washing Day', 9999, '');
INSERT INTO 'tune' VALUES (6007, NULL, '2012-01-20 12:54:40.045642+00', 'Rothesay O''', 9999, '');
INSERT INTO 'tune' VALUES (6008, NULL, '2012-01-20 12:54:40.049459+00', 'Ordaal Waltz', 1535, '');
INSERT INTO 'tune' VALUES (6009, NULL, '2012-01-20 12:54:40.05326+00', 'Tinker''s Horse, The', 9998, '');
INSERT INTO 'tune' VALUES (6010, NULL, '2012-01-20 12:54:40.056741+00', 'Crawford''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (6011, NULL, '2012-01-20 12:54:40.059696+00', 'Charley the Prayermaster', 9999, '');
INSERT INTO 'tune' VALUES (6012, NULL, '2012-01-20 12:54:40.062602+00', 'Garden of Skye, The', 2362, '');
INSERT INTO 'tune' VALUES (6013, NULL, '2012-01-20 12:54:40.06549+00', 'Yellow Corn, The', 2362, '');
INSERT INTO 'tune' VALUES (6014, NULL, '2012-01-20 12:54:40.068375+00', 'Gaelic Air', 9999, '');
INSERT INTO 'tune' VALUES (6015, NULL, '2012-01-20 12:54:40.071259+00', 'By the Shores of Loch Maree', 9998, '');
INSERT INTO 'tune' VALUES (6016, NULL, '2012-01-20 12:54:40.074143+00', 'Battle''s O''er, The', 1635, '');
INSERT INTO 'tune' VALUES (6017, NULL, '2012-01-20 12:54:40.077041+00', 'Lonely by Myself', 9998, '');
INSERT INTO 'tune' VALUES (6018, NULL, '2012-01-20 12:54:40.07993+00', 'Herd on the Hill, The', 9998, '');
INSERT INTO 'tune' VALUES (6019, NULL, '2012-01-20 12:54:40.082814+00', 'Innis Dhomb''s Ca''l Cadal', 9998, '');
INSERT INTO 'tune' VALUES (6020, NULL, '2012-01-20 12:54:40.085694+00', 'Haidh-O-Haidhrium', 9998, '');
INSERT INTO 'tune' VALUES (6021, NULL, '2012-01-20 12:54:40.088619+00', 'Bheil An Cadal Ort', 9998, '');
INSERT INTO 'tune' VALUES (6022, NULL, '2012-01-20 12:54:40.091516+00', 'Barney O''Neill', 9998, '');
INSERT INTO 'tune' VALUES (6023, NULL, '2012-01-20 12:54:40.094406+00', 'Humors of Ballycastle, The', 9998, '');
INSERT INTO 'tune' VALUES (6024, NULL, '2012-01-20 12:54:40.097628+00', 'J Spence of Yeasound', 9998, '');
INSERT INTO 'tune' VALUES (6025, NULL, '2012-01-20 12:54:40.100545+00', 'Anne''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (6026, NULL, '2012-01-20 12:54:40.10344+00', 'Margaret Webster''s Reel', 1522, '');
INSERT INTO 'tune' VALUES (6027, NULL, '2012-01-20 12:54:40.106324+00', 'Robbie the Sheep Shearer', 2362, '');
INSERT INTO 'tune' VALUES (6028, NULL, '2012-01-20 12:54:40.109201+00', 'Soraidh', 9999, '');
INSERT INTO 'tune' VALUES (6029, NULL, '2012-01-20 12:54:40.112083+00', 'Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (6030, NULL, '2012-01-20 12:54:40.115004+00', 'Cathy Hayes', 2257, '');
INSERT INTO 'tune' VALUES (6031, NULL, '2012-01-20 12:54:40.11791+00', 'Heather Hayes', 2257, '');
INSERT INTO 'tune' VALUES (6032, NULL, '2012-01-20 12:54:40.121165+00', 'Iron Kettle, The', 2257, '');
INSERT INTO 'tune' VALUES (6033, NULL, '2012-01-20 12:54:40.124736+00', 'George C. Armstrong', 1554, '');
INSERT INTO 'tune' VALUES (6034, NULL, '2012-01-20 12:54:40.1279+00', 'Mrs Grace Armstrong Baker', 1554, '');
INSERT INTO 'tune' VALUES (6035, NULL, '2012-01-20 12:54:40.130832+00', '51st Highlander''s Division, The', 1910, '');
INSERT INTO 'tune' VALUES (6036, NULL, '2012-01-20 12:54:40.133728+00', '79th Highlanders', 9999, '');
INSERT INTO 'tune' VALUES (6037, NULL, '2012-01-20 12:54:40.136623+00', 'Intercontinental Highland Gathering, The', 2258, '');
INSERT INTO 'tune' VALUES (6038, NULL, '2012-01-20 12:54:40.139535+00', 'Robin Brock''s Jig', 2085, '');
INSERT INTO 'tune' VALUES (6039, NULL, '2012-01-20 12:54:40.142424+00', 'Last Day of August, The', 1796, '');
INSERT INTO 'tune' VALUES (6040, NULL, '2012-01-20 12:54:40.145308+00', 'Flora MacDonald', 9999, '');
INSERT INTO 'tune' VALUES (6041, NULL, '2012-01-20 12:54:40.148198+00', 'Easter Elchies', 1516, '');
INSERT INTO 'tune' VALUES (6042, NULL, '2012-01-20 12:54:40.151085+00', 'Meikleour Beeches', 1512, '');
INSERT INTO 'tune' VALUES (6043, NULL, '2012-01-20 12:54:40.15396+00', 'Gane is my Jean', 1512, '');
INSERT INTO 'tune' VALUES (6044, NULL, '2012-01-20 12:54:40.156853+00', 'Kickin'' The Ba''', 1796, '');
INSERT INTO 'tune' VALUES (6045, NULL, '2012-01-20 12:54:40.15977+00', 'Mr John Drewry', 1502, '');
INSERT INTO 'tune' VALUES (6046, NULL, '2012-01-20 12:54:40.162676+00', 'My Home', 9999, '');
INSERT INTO 'tune' VALUES (6048, NULL, '2012-01-20 12:54:40.168456+00', 'Uist Tramping Song, The', 1985, '');
INSERT INTO 'tune' VALUES (6049, NULL, '2012-01-20 12:54:40.171362+00', 'Miss Jean Armstrong Milligan', 1554, '');
INSERT INTO 'tune' VALUES (6050, NULL, '2012-01-20 12:54:40.174255+00', 'Miss Bunty Clark''s Fancy', 1558, '');
INSERT INTO 'tune' VALUES (6051, NULL, '2012-01-20 12:54:40.177156+00', 'Miss Fidler''s Jig', 1413, '');
INSERT INTO 'tune' VALUES (6052, NULL, '2012-01-20 12:54:40.180074+00', 'Beamish Hall', 1413, '');
INSERT INTO 'tune' VALUES (6053, NULL, '2012-01-20 12:54:40.182961+00', 'Freda Ireland''s Hornpipe', 1558, '');
INSERT INTO 'tune' VALUES (6054, NULL, '2012-01-20 12:54:40.185845+00', 'David White''s Fancy', 1725, '');
INSERT INTO 'tune' VALUES (6055, NULL, '2012-01-20 12:54:40.188732+00', 'Bracken Rigg', 1742, '');
INSERT INTO 'tune' VALUES (6056, NULL, '2012-01-20 12:54:40.191621+00', 'Blue Stone of Hartley, The', 1725, '');
INSERT INTO 'tune' VALUES (6057, NULL, '2012-01-20 12:54:40.194499+00', 'Ailsa Jane Powrie', 1551, '');
INSERT INTO 'tune' VALUES (6058, NULL, '2012-01-20 12:54:40.197383+00', 'Kielder Reel', 2260, '');
INSERT INTO 'tune' VALUES (6059, NULL, '2012-01-20 12:54:40.200286+00', 'Border Forest', 2260, '');
INSERT INTO 'tune' VALUES (6060, NULL, '2012-01-20 12:54:40.203178+00', 'Old North British, The', 2260, '');
INSERT INTO 'tune' VALUES (6061, NULL, '2012-01-20 12:54:40.206056+00', 'Bardon Mill', 2362, '');
INSERT INTO 'tune' VALUES (6062, NULL, '2012-01-20 12:54:40.208954+00', 'Saint Patrick''s', 2264, '');
INSERT INTO 'tune' VALUES (6063, NULL, '2012-01-20 12:54:40.211841+00', 'Awl Man, The', 1817, '');
INSERT INTO 'tune' VALUES (6064, NULL, '2012-01-20 12:54:40.214724+00', 'Shelder Geö', 9998, '');
INSERT INTO 'tune' VALUES (6065, NULL, '2012-01-20 12:54:40.217609+00', 'Wha''ll Dance Wi'' Wattie?', 9998, '');
INSERT INTO 'tune' VALUES (6066, NULL, '2012-01-20 12:54:40.220507+00', 'Fashion o'' Da Delting Lasses, Da', 9998, '');
INSERT INTO 'tune' VALUES (6067, NULL, '2012-01-20 12:54:40.223398+00', 'Leaving Saint Kilda', 9998, '');
INSERT INTO 'tune' VALUES (6068, NULL, '2012-01-20 12:54:40.226286+00', 'James Stout Angus', 9998, '');
INSERT INTO 'tune' VALUES (6069, NULL, '2012-01-20 12:54:40.22917+00', 'Bastrangue, La', 9998, '');
INSERT INTO 'tune' VALUES (6070, NULL, '2012-01-20 12:54:40.232061+00', 'Wm Murray''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (6071, NULL, '2012-01-20 12:54:40.234957+00', 'Lexy McAskill', 2554, '');
INSERT INTO 'tune' VALUES (6072, NULL, '2012-01-20 12:54:40.237847+00', 'Oran Road, The', 9998, '');
INSERT INTO 'tune' VALUES (6073, NULL, '2012-01-20 12:54:40.240749+00', 'W.S. Taylor of Slackhead', 9998, '');
INSERT INTO 'tune' VALUES (6074, NULL, '2012-01-20 12:54:40.243639+00', 'Down the Slack', 9998, '');
INSERT INTO 'tune' VALUES (6075, NULL, '2012-01-20 12:54:40.246523+00', 'Old Highland Line, The', 9998, '');
INSERT INTO 'tune' VALUES (6076, NULL, '2012-01-20 12:54:40.249408+00', 'Thistle on the Faultline', 9998, '');
INSERT INTO 'tune' VALUES (6077, NULL, '2012-01-20 12:54:40.252307+00', 'Welcoming Light', 9998, '');
INSERT INTO 'tune' VALUES (6078, NULL, '2012-01-20 12:54:40.255199+00', 'Barbara''s Tune', 9998, '');
INSERT INTO 'tune' VALUES (6079, NULL, '2012-01-20 12:54:40.258083+00', 'Bonawe Highlanders, The', 1889, '');
INSERT INTO 'tune' VALUES (6080, NULL, '2012-01-20 12:54:40.260987+00', 'Agnes Ritchie', 9999, '');
INSERT INTO 'tune' VALUES (6082, NULL, '2012-01-20 12:54:40.266783+00', 'Portree Men, The', 1913, '');
INSERT INTO 'tune' VALUES (6083, NULL, '2012-01-20 12:54:40.269684+00', 'McEwan''s Barn', 9999, '');
INSERT INTO 'tune' VALUES (6084, NULL, '2012-01-20 12:54:40.272612+00', 'I''ve Never Kissed a Bonnie Lass Before', 1883, '');
INSERT INTO 'tune' VALUES (6085, NULL, '2012-01-20 12:54:40.275516+00', 'Paddy Mack', 9999, '');
INSERT INTO 'tune' VALUES (6086, NULL, '2012-01-20 12:54:40.278444+00', 'Kingdom Coming', 9999, '');
INSERT INTO 'tune' VALUES (6087, NULL, '2012-01-20 12:54:40.281331+00', 'Dixie''s Land', 9999, '');
INSERT INTO 'tune' VALUES (6088, NULL, '2012-01-20 12:54:40.28425+00', 'Some Folks Do', 9999, '');
INSERT INTO 'tune' VALUES (6089, NULL, '2012-01-20 12:54:40.287151+00', 'O''Brien of Arra', 9999, '');
INSERT INTO 'tune' VALUES (6090, NULL, '2012-01-20 12:54:40.29004+00', 'Captain Dunne''s March', 9999, '');
INSERT INTO 'tune' VALUES (6091, NULL, '2012-01-20 12:54:40.29297+00', 'Waulking Song, The', 9999, '');
INSERT INTO 'tune' VALUES (6092, NULL, '2012-01-20 12:54:40.295879+00', 'My Mother', 9999, '');
INSERT INTO 'tune' VALUES (6094, NULL, '2012-01-20 12:54:40.301668+00', 'Donald MacLeod', 9999, '');
INSERT INTO 'tune' VALUES (6095, NULL, '2012-01-20 12:54:40.30458+00', 'Matt Watson''s Jig', 2257, '');
INSERT INTO 'tune' VALUES (6096, NULL, '2012-01-20 12:54:40.30747+00', 'Thou Hast Left Me Melancholy', 9999, '');
INSERT INTO 'tune' VALUES (6097, NULL, '2012-01-20 12:54:40.310354+00', 'Miss Stewart', 1401, '');
INSERT INTO 'tune' VALUES (6098, NULL, '2012-01-20 12:54:40.313242+00', 'Lough Conn', 9999, '');
INSERT INTO 'tune' VALUES (6099, NULL, '2012-01-20 12:54:40.316121+00', 'Belfast Lassies, The', 9999, '');
INSERT INTO 'tune' VALUES (6100, NULL, '2012-01-20 12:54:40.319017+00', 'Waverley Ball, The', 1632, '');
INSERT INTO 'tune' VALUES (6101, NULL, '2012-01-20 12:54:40.321903+00', 'Bonnie Anne', 1781, '');
INSERT INTO 'tune' VALUES (6102, NULL, '2012-01-20 12:54:40.324812+00', 'Jean Day Brown', 2085, '');
INSERT INTO 'tune' VALUES (6103, NULL, '2012-01-20 12:54:40.327856+00', 'Rambler''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (6104, NULL, '2012-01-20 12:54:40.330788+00', 'Debbie''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (6105, NULL, '2012-01-20 12:54:40.333686+00', 'Frances Gray', 709, '');
INSERT INTO 'tune' VALUES (6106, NULL, '2012-01-20 12:54:40.336602+00', 'Bala-Kynwyd', 709, '');
INSERT INTO 'tune' VALUES (6107, NULL, '2012-01-20 12:54:40.339532+00', 'Sunset View', 709, '');
INSERT INTO 'tune' VALUES (6108, NULL, '2012-01-20 12:54:40.342419+00', 'John Trevenen - 2', 1814, '');
INSERT INTO 'tune' VALUES (6109, NULL, '2012-01-20 12:54:40.345318+00', 'Miss Alison o''Connor', 1793, '');
INSERT INTO 'tune' VALUES (6111, NULL, '2012-01-20 12:54:40.351095+00', 'Rowan and the Maple, The', 1502, '');
INSERT INTO 'tune' VALUES (6112, NULL, '2012-01-20 12:54:40.353992+00', 'Correspondents, The', 1502, '');
INSERT INTO 'tune' VALUES (6113, NULL, '2012-01-20 12:54:40.356891+00', 'Sunrise Over the Esk', 1502, '');
INSERT INTO 'tune' VALUES (6114, NULL, '2012-01-20 12:54:40.35978+00', 'Kings Manor', 1502, '');
INSERT INTO 'tune' VALUES (6115, NULL, '2012-01-20 12:54:40.362669+00', 'Edinburgh Lady, An', 1502, '');
INSERT INTO 'tune' VALUES (6116, NULL, '2012-01-20 12:54:40.365571+00', 'Springfield', 1502, '');
INSERT INTO 'tune' VALUES (6117, NULL, '2012-01-20 12:54:40.368451+00', 'Bright Sea', 1502, '');
INSERT INTO 'tune' VALUES (6118, NULL, '2012-01-20 12:54:40.371333+00', 'Maid that Tends the Goats, The', 9999, '');
INSERT INTO 'tune' VALUES (6119, NULL, '2012-01-20 12:54:40.374222+00', 'Gary Thomas Rant, The', 1502, '');
INSERT INTO 'tune' VALUES (6774, NULL, '2012-01-20 12:54:42.292364+00', 'Gallowa'' Hills', 9999, '');
INSERT INTO 'tune' VALUES (6120, NULL, '2012-01-20 12:54:40.377116+00', 'What Care I for the Minister', 9999, '');
INSERT INTO 'tune' VALUES (6121, NULL, '2012-01-20 12:54:40.380005+00', 'Haggis, The', 2142, '');
INSERT INTO 'tune' VALUES (6122, NULL, '2012-01-20 12:54:40.382906+00', 'Wedding, The', 9999, '');
INSERT INTO 'tune' VALUES (6123, NULL, '2012-01-20 12:54:40.3858+00', 'Legends of the Sea', 1502, '');
INSERT INTO 'tune' VALUES (6124, NULL, '2012-01-20 12:54:40.388691+00', 'C. M. Hall', 1550, '');
INSERT INTO 'tune' VALUES (6125, NULL, '2012-01-20 12:54:40.39159+00', 'Miss Pat Marshall', 1547, '');
INSERT INTO 'tune' VALUES (6126, NULL, '2012-01-20 12:54:40.394481+00', 'Lindsay Barrie', 9999, '');
INSERT INTO 'tune' VALUES (6127, NULL, '2012-01-20 12:54:40.397357+00', 'Mary Gavin', 1930, '');
INSERT INTO 'tune' VALUES (6128, NULL, '2012-01-20 12:54:40.400249+00', 'Happy Harry', 1523, '');
INSERT INTO 'tune' VALUES (13845, '2018-03-11 09:31:19.208086+00', '2018-03-11 09:31:19.208086+00', 'Ring Dance', 11067, 'See <<ddd:Olympic Village>> for notes.');
INSERT INTO 'tune' VALUES (6131, NULL, '2012-01-20 12:54:40.408897+00', 'Kern''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (6132, NULL, '2012-01-20 12:54:40.411792+00', 'Irish Air', 9998, '');
INSERT INTO 'tune' VALUES (6133, NULL, '2012-01-20 12:54:40.414685+00', 'MacPherson''s Farewell', 9998, '');
INSERT INTO 'tune' VALUES (6134, NULL, '2012-01-20 12:54:40.41756+00', 'J.F. Mackenzie', 9999, '');
INSERT INTO 'tune' VALUES (6135, NULL, '2012-01-20 12:54:40.420454+00', 'Lovely Stornoway', 2259, '');
INSERT INTO 'tune' VALUES (6136, NULL, '2012-01-20 12:54:40.423408+00', 'Eileen Alannah', 9999, '');
INSERT INTO 'tune' VALUES (6137, NULL, '2012-01-20 12:54:40.426307+00', 'John A Doig', 9998, '');
INSERT INTO 'tune' VALUES (6138, NULL, '2012-01-20 12:54:40.429199+00', 'Auld Donald', 9999, '');
INSERT INTO 'tune' VALUES (6139, NULL, '2012-01-20 12:54:40.432098+00', 'Miss Paul', 1512, '');
INSERT INTO 'tune' VALUES (6140, NULL, '2012-01-20 12:54:40.434997+00', 'Morpeth Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (6141, NULL, '2012-01-20 12:54:40.437885+00', 'Croghan Hill', 2280, '');
INSERT INTO 'tune' VALUES (6142, NULL, '2012-01-20 12:54:40.440768+00', 'Walter Cosburn''s Reel', 2257, '');
INSERT INTO 'tune' VALUES (6143, NULL, '2012-01-20 12:54:40.443651+00', 'Old Victoria, The', 9999, '');
INSERT INTO 'tune' VALUES (6144, NULL, '2012-01-20 12:54:40.446548+00', 'Clear The Track', 9999, '');
INSERT INTO 'tune' VALUES (6145, NULL, '2012-01-20 12:54:40.449446+00', 'Alston', 9999, '');
INSERT INTO 'tune' VALUES (6146, NULL, '2012-01-20 12:54:40.452331+00', 'Bamford', 9999, '');
INSERT INTO 'tune' VALUES (6147, NULL, '2012-01-20 12:54:40.455218+00', 'Glen''s', 9999, '');
INSERT INTO 'tune' VALUES (6081, NULL, '2022-12-26 21:47:14.615987+00', 'John MacDonald of Glencoe', 12248, '');
INSERT INTO 'tune' VALUES (6150, NULL, '2012-01-20 12:54:40.463896+00', 'Wee Polka I Wrote Myself, A', 2085, '');
INSERT INTO 'tune' VALUES (6151, NULL, '2012-01-20 12:54:40.46679+00', 'Auld Fisher, The', 1705, '');
INSERT INTO 'tune' VALUES (6152, NULL, '2012-01-20 12:54:40.469675+00', 'Lisdoonvarna Puck', 9999, '');
INSERT INTO 'tune' VALUES (6153, NULL, '2012-01-20 12:54:40.47256+00', 'Recruit, The', 9999, '');
INSERT INTO 'tune' VALUES (6156, NULL, '2012-01-20 12:54:40.481226+00', 'Downderry', 2576, '');
INSERT INTO 'tune' VALUES (6157, NULL, '2012-01-20 12:54:40.484108+00', 'An Cluimn Thu, Leannain', 9999, '');
INSERT INTO 'tune' VALUES (6158, NULL, '2012-01-20 12:54:40.487007+00', 'Dealochodh Leannain', 9999, '');
INSERT INTO 'tune' VALUES (6159, NULL, '2012-01-20 12:54:40.489896+00', 'Margaret Chisolm', 2264, '');
INSERT INTO 'tune' VALUES (6160, NULL, '2012-01-20 12:54:40.49279+00', 'Mrs Gordon of Park', 1516, '');
INSERT INTO 'tune' VALUES (6161, NULL, '2012-01-20 12:54:40.495679+00', 'Dalinlongart', 2288, '');
INSERT INTO 'tune' VALUES (6155, NULL, '2012-11-29 07:24:45.239405+00', 'Loch Leven Polka', 2286, '');
INSERT INTO 'tune' VALUES (6162, NULL, '2012-01-20 12:54:40.498562+00', 'Mrs Rachael Gibson', 9999, '');
INSERT INTO 'tune' VALUES (6163, NULL, '2012-01-20 12:54:40.501446+00', 'Magnetic', 9999, '');
INSERT INTO 'tune' VALUES (6164, NULL, '2012-01-20 12:54:40.504343+00', 'Loch Tay Boat Song, The', 9999, '');
INSERT INTO 'tune' VALUES (6165, NULL, '2012-01-20 12:54:40.507254+00', 'Spinning Wheel, The', 2289, '');
INSERT INTO 'tune' VALUES (6166, NULL, '2012-01-20 12:54:40.510812+00', 'Hey Tuttie Tattie', 9999, '');
INSERT INTO 'tune' VALUES (6167, NULL, '2012-01-20 12:54:40.513702+00', 'Andrew Carr', 9999, '');
INSERT INTO 'tune' VALUES (6168, NULL, '2012-01-20 12:54:40.516595+00', 'Iain MacPhail''s Compliments to Euan Kennedy of Scone', 1527, '');
INSERT INTO 'tune' VALUES (6169, NULL, '2012-01-20 12:54:40.519497+00', 'Miss Crawford', 2290, '');
INSERT INTO 'tune' VALUES (6170, NULL, '2012-01-20 12:54:40.522389+00', 'Betty Robertson', 9998, '');
INSERT INTO 'tune' VALUES (6171, NULL, '2012-01-20 12:54:40.52529+00', 'Lizzie Lindsay', 9998, '');
INSERT INTO 'tune' VALUES (6172, NULL, '2012-01-20 12:54:40.528315+00', 'Inverary Cross', 9998, '');
INSERT INTO 'tune' VALUES (6173, NULL, '2012-01-20 12:54:40.531224+00', 'Miss Lindsay''s Trowell', 9998, '');
INSERT INTO 'tune' VALUES (6174, NULL, '2012-01-20 12:54:40.534122+00', 'Margaret McCabe''s Fancy', 9998, '');
INSERT INTO 'tune' VALUES (6175, NULL, '2012-01-20 12:54:40.53717+00', 'Fiona''s Fiddle', 9998, '');
INSERT INTO 'tune' VALUES (6176, NULL, '2012-01-20 12:54:40.540067+00', 'Britta''s Fancy', 9998, '');
INSERT INTO 'tune' VALUES (6177, NULL, '2012-01-20 12:54:40.542952+00', 'Colonel Robertson''s March', 9999, '');
INSERT INTO 'tune' VALUES (6178, NULL, '2012-01-20 12:54:40.545831+00', 'Woodland Flowers', 9999, '');
INSERT INTO 'tune' VALUES (6179, NULL, '2012-01-20 12:54:40.548772+00', 'Peggy O''Neill', 9999, '');
INSERT INTO 'tune' VALUES (6180, NULL, '2012-01-20 12:54:40.551677+00', 'I Belong to Glasgow', 2228, '');
INSERT INTO 'tune' VALUES (6181, NULL, '2012-01-20 12:54:40.554571+00', 'I''ll Be Your Sweetheart', 2349, '');
INSERT INTO 'tune' VALUES (6182, NULL, '2012-01-20 12:54:40.557456+00', 'Hamilton Rant', 9999, '');
INSERT INTO 'tune' VALUES (6183, NULL, '2012-01-20 12:54:40.560343+00', 'Till We Meet Again', 9999, '');
INSERT INTO 'tune' VALUES (6184, NULL, '2012-01-20 12:54:40.563234+00', 'George Black Polka, The', 1555, '');
INSERT INTO 'tune' VALUES (6185, NULL, '2012-01-20 12:54:40.566121+00', 'Little Sir Echo', 10276, '');
INSERT INTO 'tune' VALUES (6186, NULL, '2012-01-20 12:54:40.569006+00', 'In the Shade of the Old Apple Tree', 3509, '');
INSERT INTO 'tune' VALUES (6187, NULL, '2012-01-20 12:54:40.571928+00', 'Let Me Call You Sweetheart', 10275, '');
INSERT INTO 'tune' VALUES (6188, NULL, '2012-01-20 12:54:40.574826+00', 'Gordon Waltz, The', 9998, '');
INSERT INTO 'tune' VALUES (6189, NULL, '2012-01-20 12:54:40.577704+00', 'McDonald of the Isles March to Harlaw', 9999, '');
INSERT INTO 'tune' VALUES (6190, NULL, '2012-01-20 12:54:40.580591+00', 'Dunbarton Castle', 9998, '');
INSERT INTO 'tune' VALUES (6191, NULL, '2012-01-20 12:54:40.583495+00', 'Deerness Reel, The', 2297, '');
INSERT INTO 'tune' VALUES (6192, NULL, '2012-01-20 12:54:40.586382+00', 'Pride of Scotland, The', 9998, '');
INSERT INTO 'tune' VALUES (6193, NULL, '2012-01-20 12:54:40.58928+00', 'Kerry Polka, The', 9999, '');
INSERT INTO 'tune' VALUES (6194, NULL, '2012-01-20 12:54:40.592246+00', 'Ballydesmond', 9999, '');
INSERT INTO 'tune' VALUES (6195, NULL, '2012-01-20 12:54:40.595136+00', 'Wexford Polka', 9999, '');
INSERT INTO 'tune' VALUES (6196, NULL, '2012-01-20 12:54:40.598018+00', 'Deerness Jig, The', 1525, '');
INSERT INTO 'tune' VALUES (6197, NULL, '2012-01-20 12:54:40.600904+00', 'Graemeshell Bay', 2442, '');
INSERT INTO 'tune' VALUES (6198, NULL, '2012-01-20 12:54:40.603797+00', 'R. Aim''s Compliments to J. Craigie, Rousay', 2442, '');
INSERT INTO 'tune' VALUES (6199, NULL, '2012-01-20 12:54:40.606683+00', 'Frank Thompson''s Visit to Wick', 2299, '');
INSERT INTO 'tune' VALUES (6200, NULL, '2012-01-20 12:54:40.609566+00', 'Bill Cook', 2300, '');
INSERT INTO 'tune' VALUES (6201, NULL, '2012-01-20 12:54:40.612463+00', 'Elwyn''s Fairy Glen', 9999, '');
INSERT INTO 'tune' VALUES (6202, NULL, '2012-01-20 12:54:40.615351+00', 'Regiment, The', 9999, '');
INSERT INTO 'tune' VALUES (6204, NULL, '2012-01-20 12:54:40.62112+00', 'Maggie Brown', 9999, '');
INSERT INTO 'tune' VALUES (6205, NULL, '2012-01-20 12:54:40.624009+00', 'Jim McBay''s Welcome', 1795, '');
INSERT INTO 'tune' VALUES (6206, NULL, '2012-01-20 12:54:40.6269+00', 'Scott Skinner''s Compliments to Dr. MacDonald', 1512, '');
INSERT INTO 'tune' VALUES (6207, NULL, '2012-01-20 12:54:40.629787+00', 'Harry Carmichael', 1554, '');
INSERT INTO 'tune' VALUES (6208, NULL, '2012-01-20 12:54:40.632692+00', 'Provost Tonge of Monifieth', 1554, '');
INSERT INTO 'tune' VALUES (6209, NULL, '2012-01-20 12:54:40.635593+00', 'Jim Johnstone', 1554, '');
INSERT INTO 'tune' VALUES (6210, NULL, '2012-01-20 12:54:40.63847+00', 'Bob Harvey', 1554, '');
INSERT INTO 'tune' VALUES (6211, NULL, '2012-01-20 12:54:40.641364+00', 'Alistair''s Barn Dance', 9999, '');
INSERT INTO 'tune' VALUES (6212, NULL, '2012-01-20 12:54:40.644252+00', 'Sharp''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (6213, NULL, '2012-01-20 12:54:40.647134+00', 'Clog Dance', 9999, '');
INSERT INTO 'tune' VALUES (6214, NULL, '2012-01-20 12:54:40.650024+00', 'Peter Street', 9998, '');
INSERT INTO 'tune' VALUES (6215, NULL, '2012-01-20 12:54:40.652987+00', 'Danish Double Quadrille', 9999, '');
INSERT INTO 'tune' VALUES (6216, NULL, '2012-01-20 12:54:40.655882+00', 'Silver and Gold', 9999, '');
INSERT INTO 'tune' VALUES (6217, NULL, '2012-01-20 12:54:40.659029+00', 'Gentle Mary', 9998, '');
INSERT INTO 'tune' VALUES (6218, NULL, '2012-01-20 12:54:40.66212+00', 'My Ain Wee Hoose', 9998, '');
INSERT INTO 'tune' VALUES (6220, NULL, '2012-01-20 12:54:40.66791+00', 'Nelly Kelly', 9998, '');
INSERT INTO 'tune' VALUES (6221, NULL, '2012-01-20 12:54:40.670804+00', 'Anne Drummond Smithie', 9998, '');
INSERT INTO 'tune' VALUES (6222, NULL, '2012-01-20 12:54:40.673699+00', 'Fairy Lullaby', 9998, '');
INSERT INTO 'tune' VALUES (6224, NULL, '2012-01-20 12:54:40.679491+00', 'Saint Bernard''s Waltz', 2520, '');
INSERT INTO 'tune' VALUES (6225, NULL, '2012-01-20 12:54:40.682378+00', 'Carnwath Mill', 9998, '');
INSERT INTO 'tune' VALUES (6226, NULL, '2012-01-20 12:54:40.685262+00', 'Clarence Tough', 9999, '');
INSERT INTO 'tune' VALUES (6227, NULL, '2012-01-20 12:54:40.688162+00', 'Smaim a'' phosaidh - Nuptial Knot', 9999, '');
INSERT INTO 'tune' VALUES (6228, NULL, '2012-01-20 12:54:40.691054+00', 'Lady Lepley', 1461, '');
INSERT INTO 'tune' VALUES (6229, NULL, '2012-01-20 12:54:40.693946+00', 'Pipe Major W. Ross'' Farewell to the Scots Guards', 9999, '');
INSERT INTO 'tune' VALUES (6230, NULL, '2012-01-20 12:54:40.696839+00', 'Lovely Lass of Inverness, The', 1859, '');
INSERT INTO 'tune' VALUES (6231, NULL, '2012-01-20 12:54:40.699729+00', 'Maiden of the Golden Tresses', 9999, '');
INSERT INTO 'tune' VALUES (6232, NULL, '2012-01-20 12:54:40.702623+00', 'Brown Haired Nymph, The', 9999, '');
INSERT INTO 'tune' VALUES (6233, NULL, '2012-01-20 12:54:40.70551+00', 'Bonnie Brown Maid, The', 9999, '');
INSERT INTO 'tune' VALUES (6234, NULL, '2012-01-20 12:54:40.708401+00', 'Auckland Police Pipe Band', 2307, '');
INSERT INTO 'tune' VALUES (6235, NULL, '2012-01-20 12:54:40.711285+00', 'Geordie''s Wedding', 2308, '');
INSERT INTO 'tune' VALUES (6236, NULL, '2012-01-20 12:54:40.714186+00', 'Lucknow Polka', 9999, '');
INSERT INTO 'tune' VALUES (6237, NULL, '2012-01-20 12:54:40.717082+00', 'Adam Haugh', 2311, '');
INSERT INTO 'tune' VALUES (6238, NULL, '2012-01-20 12:54:40.719964+00', 'British Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (6239, NULL, '2012-01-20 12:54:40.722853+00', 'Pride of the North, The', 9999, '');
INSERT INTO 'tune' VALUES (6240, NULL, '2012-01-20 12:54:40.72575+00', 'Willie Bishop', 9998, '');
INSERT INTO 'tune' VALUES (6241, NULL, '2012-01-20 12:54:40.728789+00', 'Auchengowan', 9999, '');
INSERT INTO 'tune' VALUES (6242, NULL, '2012-01-20 12:54:40.731736+00', 'Bells, The', 1735, '');
INSERT INTO 'tune' VALUES (6243, NULL, '2012-01-20 12:54:40.734701+00', 'Traditional Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (6244, NULL, '2012-01-20 12:54:40.7376+00', 'Wishaw''s Delight', 9999, '');
INSERT INTO 'tune' VALUES (6245, NULL, '2012-01-20 12:54:40.740493+00', 'Liberty Bell', 2312, '');
INSERT INTO 'tune' VALUES (6246, NULL, '2012-01-20 12:54:40.7434+00', 'Betty MacLean of Blair Dhu', 1525, '');
INSERT INTO 'tune' VALUES (6247, NULL, '2012-01-20 12:54:40.746284+00', 'George Bell Polka, The', 1531, '');
INSERT INTO 'tune' VALUES (6248, NULL, '2012-01-20 12:54:40.749224+00', 'Heroes of Vittoria', 1700, '');
INSERT INTO 'tune' VALUES (6219, NULL, '2014-08-24 14:16:49.261986+00', 'Bill Caldwell Two-Step, The', 1555, '');
INSERT INTO 'tune' VALUES (6203, NULL, '2014-11-01 00:29:18.264232+00', 'Biddy of Sligo', 9999, '');
INSERT INTO 'tune' VALUES (6249, NULL, '2012-01-20 12:54:40.752126+00', 'Morag''s Waltz', 1525, '');
INSERT INTO 'tune' VALUES (6250, NULL, '2012-01-20 12:54:40.755034+00', 'Thingummyjig Polka, The', 1525, '');
INSERT INTO 'tune' VALUES (6251, NULL, '2012-01-20 12:54:40.757918+00', 'Lewisvale', 1525, '');
INSERT INTO 'tune' VALUES (6252, NULL, '2012-01-20 12:54:40.760806+00', 'New Bumpkin, The', 9999, '');
INSERT INTO 'tune' VALUES (6253, NULL, '2012-01-20 12:54:40.763688+00', 'Dream Angus', 9999, '');
INSERT INTO 'tune' VALUES (6255, NULL, '2012-01-20 12:54:40.769467+00', 'Aileen Alonna', 9998, '');
INSERT INTO 'tune' VALUES (6256, NULL, '2012-01-20 12:54:40.772352+00', 'Showman''s Fancy, The', 9999, '');
INSERT INTO 'tune' VALUES (6257, NULL, '2012-01-20 12:54:40.775252+00', 'Humours of California, The', 9999, '');
INSERT INTO 'tune' VALUES (6258, NULL, '2012-01-20 12:54:40.778138+00', 'Royal Guards Polka', 9999, '');
INSERT INTO 'tune' VALUES (6259, NULL, '2012-01-20 12:54:40.781021+00', 'Donach Head', 9999, '');
INSERT INTO 'tune' VALUES (6260, NULL, '2012-01-20 12:54:40.783911+00', 'I''m Looking Over A Four Leaf Clover', 2320, '');
INSERT INTO 'tune' VALUES (6261, NULL, '2012-01-20 12:54:40.786816+00', 'Alexander''s Ragtime Band', 2321, '');
INSERT INTO 'tune' VALUES (6262, NULL, '2012-01-20 12:54:40.789718+00', 'Chilliwack Barn Dance', 2322, '');
INSERT INTO 'tune' VALUES (6263, NULL, '2012-01-20 12:54:40.792617+00', 'Iona Boat Song', 9999, '');
INSERT INTO 'tune' VALUES (6264, NULL, '2012-01-20 12:54:40.795517+00', 'Tiree Love Song', 9999, '');
INSERT INTO 'tune' VALUES (6265, NULL, '2012-01-20 12:54:40.798423+00', 'Pipes and Drums of Powell River, The', 1669, '');
INSERT INTO 'tune' VALUES (6223, NULL, '2012-11-29 07:28:20.359076+00', 'Balintore Fishermen, The', 1640, '');
INSERT INTO 'tune' VALUES (6266, NULL, '2012-01-20 12:54:40.801326+00', 'Scotland Yet', 9999, '');
INSERT INTO 'tune' VALUES (6267, NULL, '2012-01-20 12:54:40.804225+00', 'Leaving Glenurquhart', 9999, '');
INSERT INTO 'tune' VALUES (6268, NULL, '2012-01-20 12:54:40.807112+00', 'Let''s be Merry', 9998, '');
INSERT INTO 'tune' VALUES (6269, NULL, '2012-01-20 12:54:40.81001+00', 'Blw the Man Down', 9999, '');
INSERT INTO 'tune' VALUES (6270, NULL, '2012-01-20 12:54:40.81291+00', 'Shirley''s Reel', 2212, '');
INSERT INTO 'tune' VALUES (6271, NULL, '2012-01-20 12:54:40.815807+00', 'Maggie''s Bucket', 1623, '');
INSERT INTO 'tune' VALUES (6272, NULL, '2012-01-20 12:54:40.818696+00', 'Jack Adrift', 1910, '');
INSERT INTO 'tune' VALUES (6273, NULL, '2012-01-20 12:54:40.821579+00', 'Ae Fond Kiss', 9999, '');
INSERT INTO 'tune' VALUES (6274, NULL, '2012-01-20 12:54:40.824475+00', 'Bonnie wee Thing', 9999, '');
INSERT INTO 'tune' VALUES (6277, NULL, '2012-01-20 12:54:40.833117+00', 'Loupin'' Bugle Boy, The', 326, '');
INSERT INTO 'tune' VALUES (6278, NULL, '2012-01-20 12:54:40.836041+00', 'Bonny Toun a'' Kenmore, The', 9999, '');
INSERT INTO 'tune' VALUES (6279, NULL, '2012-01-20 12:54:40.838956+00', 'Peter Archibald of Edinburgh', 509, '');
INSERT INTO 'tune' VALUES (6280, NULL, '2012-01-20 12:54:40.841855+00', 'Carradale Bay', 2325, '');
INSERT INTO 'tune' VALUES (6281, NULL, '2012-01-20 12:54:40.844747+00', 'March of the Rangers', 2326, '');
INSERT INTO 'tune' VALUES (6283, NULL, '2012-01-20 12:54:40.850529+00', 'David Crosbie Miller', 2319, '');
INSERT INTO 'tune' VALUES (6284, NULL, '2012-01-20 12:54:40.85341+00', 'Heights of Cassino', 2327, '');
INSERT INTO 'tune' VALUES (6286, NULL, '2012-01-20 12:54:40.859212+00', 'Kitchener''s Army', 1699, '');
INSERT INTO 'tune' VALUES (6287, NULL, '2012-01-20 12:54:40.8621+00', '25th K.O.S.B''s Farewell to Meerut, The', 2329, '');
INSERT INTO 'tune' VALUES (6288, NULL, '2012-01-20 12:54:40.864989+00', 'Lord Macdonald of the Isles', 9999, '');
INSERT INTO 'tune' VALUES (6289, NULL, '2012-01-20 12:54:40.86788+00', 'Major McKay''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (6290, NULL, '2012-01-20 12:54:40.871156+00', 'Mrs Fraser Macpherson''s Strathspey', 1541, '');
INSERT INTO 'tune' VALUES (6291, NULL, '2012-01-20 12:54:40.874164+00', 'Ballachroan', 1516, '');
INSERT INTO 'tune' VALUES (6292, NULL, '2012-01-20 12:54:40.877065+00', 'Stramashie', 9999, '');
INSERT INTO 'tune' VALUES (6293, NULL, '2012-01-20 12:54:40.879985+00', 'Mr A.F. Macpherson''s Reel', 1516, '');
INSERT INTO 'tune' VALUES (6294, NULL, '2012-01-20 12:54:40.88288+00', 'Fiona''s Polka', 2331, '');
INSERT INTO 'tune' VALUES (6295, NULL, '2012-01-20 12:54:40.885768+00', 'Jeannie Caruthers', 1694, '');
INSERT INTO 'tune' VALUES (6296, NULL, '2012-01-20 12:54:40.888665+00', 'Farewell to Barra', 2175, '');
INSERT INTO 'tune' VALUES (6297, NULL, '2012-01-20 12:54:40.891561+00', 'Per Ardua', 1671, '');
INSERT INTO 'tune' VALUES (6298, NULL, '2012-01-20 12:54:40.894449+00', '79th Highlanders Entering Barracks', 9999, '');
INSERT INTO 'tune' VALUES (6299, NULL, '2012-01-20 12:54:40.89733+00', 'Eternal Surge of the Sea, The', 9999, '');
INSERT INTO 'tune' VALUES (6300, NULL, '2012-01-20 12:54:40.900236+00', 'When We Were Young', 9999, '');
INSERT INTO 'tune' VALUES (6301, NULL, '2012-01-20 12:54:40.90312+00', 'Paddy be Easy', 9999, '');
INSERT INTO 'tune' VALUES (6302, NULL, '2012-01-20 12:54:40.905999+00', 'Waverley Steps', 1558, '');
INSERT INTO 'tune' VALUES (6303, NULL, '2012-01-20 12:54:40.908887+00', 'O''er the Sea', 9999, '');
INSERT INTO 'tune' VALUES (6304, NULL, '2012-01-20 12:54:40.911773+00', 'Will ye gang tae Kelvingrove', 9999, '');
INSERT INTO 'tune' VALUES (6305, NULL, '2012-01-20 12:54:40.914958+00', 'Mary''s Fiddle', 2335, '');
INSERT INTO 'tune' VALUES (6306, NULL, '2012-01-20 12:54:40.918052+00', 'Jackson''s Morning Blush', 9999, '');
INSERT INTO 'tune' VALUES (6307, NULL, '2012-01-20 12:54:40.920975+00', 'Coates Crecent Thistle', 2197, '');
INSERT INTO 'tune' VALUES (6308, NULL, '2012-01-20 12:54:40.923881+00', 'As a Thoiseach', 2142, '');
INSERT INTO 'tune' VALUES (6309, NULL, '2012-01-20 12:54:40.92681+00', '''S ann an ile', 9999, '');
INSERT INTO 'tune' VALUES (6310, NULL, '2012-01-20 12:54:40.929773+00', 'Streaker, The', 1525, '');
INSERT INTO 'tune' VALUES (6311, NULL, '2012-01-20 12:54:40.932672+00', 'Mrs MacDonald of Uig', 1910, '');
INSERT INTO 'tune' VALUES (6313, NULL, '2012-01-20 12:54:40.93853+00', 'Gade Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (6314, NULL, '2012-01-20 12:54:40.941436+00', 'Kenneth J. MacLeod', 1910, '');
INSERT INTO 'tune' VALUES (6315, NULL, '2012-01-20 12:54:40.944327+00', 'Hills of Tyron, The', 1668, '');
INSERT INTO 'tune' VALUES (6316, NULL, '2012-01-20 12:54:40.947222+00', 'Wearie Maid, The', 9999, '');
INSERT INTO 'tune' VALUES (6317, NULL, '2012-01-20 12:54:40.950105+00', 'Alisdair of the Fort', 9999, '');
INSERT INTO 'tune' VALUES (6276, NULL, '2012-10-10 22:07:49.984899+00', 'Braes Aboon Bonawe', 9999, '');
INSERT INTO 'tune' VALUES (6318, NULL, '2012-01-20 12:54:40.952999+00', 'Gun Chrodh Gun Aighean', 9999, '');
INSERT INTO 'tune' VALUES (6319, NULL, '2012-01-20 12:54:40.955893+00', 'Sunderland A Fhuairmi Fis', 9999, '');
INSERT INTO 'tune' VALUES (6320, NULL, '2012-01-20 12:54:40.958954+00', 'O Luaidh', 9999, '');
INSERT INTO 'tune' VALUES (6321, NULL, '2012-01-20 12:54:40.962075+00', 'Old Rigadoo, The', 9999, '');
INSERT INTO 'tune' VALUES (6322, NULL, '2012-01-20 12:54:40.964969+00', 'Stack of Barley', 9999, '');
INSERT INTO 'tune' VALUES (6323, NULL, '2012-01-20 12:54:40.967862+00', 'Mavis Wood', 9999, '');
INSERT INTO 'tune' VALUES (6324, NULL, '2012-01-20 12:54:40.970749+00', 'Dance of the South-West Wind', 140, '');
INSERT INTO 'tune' VALUES (6325, NULL, '2012-01-20 12:54:40.973639+00', 'Firelight Waltz', 140, '');
INSERT INTO 'tune' VALUES (6326, NULL, '2012-01-20 12:54:40.976527+00', 'Come by the Hills', 9999, '');
INSERT INTO 'tune' VALUES (6328, NULL, '2012-01-20 12:54:40.98231+00', 'Argylls Crossing River Po', 9998, '');
INSERT INTO 'tune' VALUES (6330, NULL, '2012-01-20 12:54:40.988098+00', 'Boy is Young But-A-Growin''', 9998, '');
INSERT INTO 'tune' VALUES (6331, NULL, '2012-01-20 12:54:40.990987+00', 'Wild Irish Rose', 9998, '');
INSERT INTO 'tune' VALUES (6332, NULL, '2012-01-20 12:54:40.993865+00', 'Dear Old Erin''s Isle', 9998, '');
INSERT INTO 'tune' VALUES (6333, NULL, '2012-01-20 12:54:40.996752+00', 'Accordion in Switzerland', 9998, '');
INSERT INTO 'tune' VALUES (6334, NULL, '2012-01-20 12:54:40.999646+00', 'Orkney Air', 9998, '');
INSERT INTO 'tune' VALUES (6335, NULL, '2012-01-20 12:54:41.002542+00', 'Marquis of Huntly''s Highland Fling, The', 1495, '');
INSERT INTO 'tune' VALUES (6336, NULL, '2012-01-20 12:54:41.005431+00', 'Gentle Maiden, The', 9999, '');
INSERT INTO 'tune' VALUES (6338, NULL, '2012-01-20 12:54:41.011216+00', 'David Todd''s 40th Birthday', 2220, '');
INSERT INTO 'tune' VALUES (6339, NULL, '2012-01-20 12:54:41.014133+00', 'Captain C.M. Usher''s Reel', 1515, '');
INSERT INTO 'tune' VALUES (6340, NULL, '2012-01-20 12:54:41.01703+00', 'Silver Salver, The', 1609, '');
INSERT INTO 'tune' VALUES (6341, NULL, '2012-01-20 12:54:41.019934+00', 'Skye Centenary Ball, The', 1609, '');
INSERT INTO 'tune' VALUES (6342, NULL, '2012-01-20 12:54:41.02284+00', 'On the Banks of the Allan Water', 9999, '');
INSERT INTO 'tune' VALUES (6344, NULL, '2012-01-20 12:54:41.028621+00', 'Doornkop', 1699, '');
INSERT INTO 'tune' VALUES (6345, NULL, '2012-01-20 12:54:41.031512+00', 'Captain Norman Orr-Ewing', 1635, '');
INSERT INTO 'tune' VALUES (6346, NULL, '2012-01-20 12:54:41.034406+00', 'Smiling Jenny', 1814, '');
INSERT INTO 'tune' VALUES (6347, NULL, '2012-01-20 12:54:41.037292+00', 'Mrs Helen Bowman', 1814, '');
INSERT INTO 'tune' VALUES (6348, NULL, '2012-01-20 12:54:41.040247+00', 'Mrs Betty Hildebrand', 1814, '');
INSERT INTO 'tune' VALUES (6349, NULL, '2012-01-20 12:54:41.043173+00', 'Cambrian Reel', 1814, '');
INSERT INTO 'tune' VALUES (6350, NULL, '2012-01-20 12:54:41.04606+00', 'Parkfield Reel', 1814, '');
INSERT INTO 'tune' VALUES (6351, NULL, '2012-01-20 12:54:41.048947+00', 'Bruce of Briargreen', 1814, '');
INSERT INTO 'tune' VALUES (6352, NULL, '2012-01-20 12:54:41.051847+00', 'Miss Sheila Barber', 1814, '');
INSERT INTO 'tune' VALUES (6353, NULL, '2012-01-20 12:54:41.05474+00', 'Bill Little', 1814, '');
INSERT INTO 'tune' VALUES (6354, NULL, '2012-01-20 12:54:41.057628+00', 'Carlingwark Loch', 1814, '');
INSERT INTO 'tune' VALUES (6355, NULL, '2012-01-20 12:54:41.060547+00', 'Archie and Marie', 1814, '');
INSERT INTO 'tune' VALUES (6356, NULL, '2012-01-20 12:54:41.063462+00', 'Cascade Mountain', 1814, '');
INSERT INTO 'tune' VALUES (6337, NULL, '2013-08-05 11:04:28.473384+00', 'My Native Highland Home', 10822, '');
INSERT INTO 'tune' VALUES (6357, NULL, '2012-01-20 12:54:41.066353+00', 'Mr Archie Nixon', 1814, '');
INSERT INTO 'tune' VALUES (6358, NULL, '2012-01-20 12:54:41.069239+00', 'Lanark Braes', 1814, '');
INSERT INTO 'tune' VALUES (6359, NULL, '2012-01-20 12:54:41.072122+00', 'Falls of Clyde, The', 1814, '');
INSERT INTO 'tune' VALUES (6360, NULL, '2012-01-20 12:54:41.075014+00', 'Rena''s Jig', 1814, '');
INSERT INTO 'tune' VALUES (6361, NULL, '2012-01-20 12:54:41.077883+00', 'Glenlivet', 1814, '');
INSERT INTO 'tune' VALUES (6362, NULL, '2012-01-20 12:54:41.080771+00', 'Craignethan Castle', 1814, '');
INSERT INTO 'tune' VALUES (6363, NULL, '2012-01-20 12:54:41.084233+00', 'John T', 1814, '');
INSERT INTO 'tune' VALUES (6364, NULL, '2012-01-20 12:54:41.087584+00', 'Strathaven Way', 1814, '');
INSERT INTO 'tune' VALUES (6365, NULL, '2012-01-20 12:54:41.090674+00', 'Cora Linn', 1814, '');
INSERT INTO 'tune' VALUES (6366, NULL, '2012-01-20 12:54:41.093612+00', 'Tinto Top', 1814, '');
INSERT INTO 'tune' VALUES (6367, NULL, '2012-01-20 12:54:41.096511+00', 'Little Red Ford', 2340, '');
INSERT INTO 'tune' VALUES (6368, NULL, '2012-01-20 12:54:41.099413+00', 'Kisses from Maisie', 2340, '');
INSERT INTO 'tune' VALUES (6369, NULL, '2012-01-20 12:54:41.102311+00', 'Dance Piper, The', 2340, '');
INSERT INTO 'tune' VALUES (6370, NULL, '2012-01-20 12:54:41.105212+00', 'Dawn''s Rest', 1710, '');
INSERT INTO 'tune' VALUES (6329, NULL, '2012-02-06 12:10:56.001247+00', 'Joyce''s Reel', 1777, '');
INSERT INTO 'tune' VALUES (6285, NULL, '2023-01-05 13:02:13.933171+00', 'John MacColl''s March to Kilbowie Cottage', 12248, '');
INSERT INTO 'tune' VALUES (6327, NULL, '2012-02-06 12:16:09.529061+00', 'Ogilvy Arms Two-Step, The', 10602, '');
INSERT INTO 'tune' VALUES (6371, NULL, '2012-01-20 12:54:41.108108+00', 'Shepherd o'' the Hills', 1766, '');
INSERT INTO 'tune' VALUES (6372, NULL, '2012-01-20 12:54:41.111005+00', 'John Wilmot''s Jig', 2341, '');
INSERT INTO 'tune' VALUES (6373, NULL, '2012-01-20 12:54:41.11389+00', 'Cleveland Park', 2342, '');
INSERT INTO 'tune' VALUES (6374, NULL, '2012-01-20 12:54:41.116825+00', 'Easy Club Reel, The', 1878, '');
INSERT INTO 'tune' VALUES (6375, NULL, '2012-01-20 12:54:41.119966+00', 'Major Stewart''s Reel, of the Island of Java', 1516, '');
INSERT INTO 'tune' VALUES (6376, NULL, '2012-01-20 12:54:41.123483+00', 'Myra''s Jig', 2343, '');
INSERT INTO 'tune' VALUES (6377, NULL, '2012-01-20 12:54:41.126759+00', 'Moray Club, The', 9999, '');
INSERT INTO 'tune' VALUES (6378, NULL, '2012-01-20 12:54:41.129735+00', 'Bonaparte''s Retreat', 9999, '');
INSERT INTO 'tune' VALUES (6379, NULL, '2012-01-20 12:54:41.132643+00', 'High Level, The', 1512, '');
INSERT INTO 'tune' VALUES (6380, NULL, '2012-01-20 12:54:41.135562+00', 'Jennie Shock da Bairn', 9999, '');
INSERT INTO 'tune' VALUES (6381, NULL, '2012-01-20 12:54:41.138508+00', 'Mackenzie Highlanders', 9998, '');
INSERT INTO 'tune' VALUES (6382, NULL, '2012-01-20 12:54:41.141752+00', 'Lord Lovat', 9998, '');
INSERT INTO 'tune' VALUES (6383, NULL, '2012-01-20 12:54:41.144654+00', 'Dark-eyed Dinah', 9998, '');
INSERT INTO 'tune' VALUES (6384, NULL, '2012-01-20 12:54:41.147541+00', 'Kildare Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (6385, NULL, '2012-01-20 12:54:41.150426+00', 'I Gave my Love', 9999, '');
INSERT INTO 'tune' VALUES (6386, NULL, '2012-01-20 12:54:41.153307+00', 'Incarceration, The', 9999, '');
INSERT INTO 'tune' VALUES (6388, NULL, '2012-01-20 12:54:41.159129+00', 'Lady MacBeth', 9998, '');
INSERT INTO 'tune' VALUES (6389, NULL, '2012-01-20 12:54:41.162219+00', 'My Lodging on the Cold Cold Ground', 9998, '');
INSERT INTO 'tune' VALUES (6390, NULL, '2012-01-20 12:54:41.16517+00', 'Cameron Men', 9998, '');
INSERT INTO 'tune' VALUES (6391, NULL, '2012-01-20 12:54:41.168063+00', 'Jenny''s Black E''e', 9998, '');
INSERT INTO 'tune' VALUES (6393, NULL, '2012-01-20 12:54:41.17384+00', 'Irish Jauntin'' Car, The', 9999, '');
INSERT INTO 'tune' VALUES (6394, NULL, '2012-01-20 12:54:41.176728+00', 'Terence''s Farewell', 9998, '');
INSERT INTO 'tune' VALUES (6395, NULL, '2012-01-20 12:54:41.179614+00', 'Kitty of Coleraine', 9998, '');
INSERT INTO 'tune' VALUES (6396, NULL, '2012-01-20 12:54:41.182501+00', 'Jean Ireland', 1558, '');
INSERT INTO 'tune' VALUES (6397, NULL, '2012-01-20 12:54:41.1854+00', 'Martalette', 9998, '');
INSERT INTO 'tune' VALUES (6398, NULL, '2012-01-20 12:54:41.188287+00', 'Marino Polka', 9998, '');
INSERT INTO 'tune' VALUES (6399, NULL, '2012-01-20 12:54:41.191178+00', 'Naomi''s Jig', 2348, '');
INSERT INTO 'tune' VALUES (6400, NULL, '2012-01-20 12:54:41.194056+00', 'Brass Knob, The', 2257, '');
INSERT INTO 'tune' VALUES (6401, NULL, '2012-01-20 12:54:41.19696+00', 'Yetts of Muckart, The', 9999, '');
INSERT INTO 'tune' VALUES (6402, NULL, '2012-01-20 12:54:41.199851+00', 'Archie Brown', 1512, '');
INSERT INTO 'tune' VALUES (6403, NULL, '2012-01-20 12:54:41.202739+00', 'Bicycle Built for Two, A', 2349, '');
INSERT INTO 'tune' VALUES (6404, NULL, '2012-01-20 12:54:41.205637+00', 'Take Me Out to the Ball Game', 2350, '');
INSERT INTO 'tune' VALUES (6405, NULL, '2012-01-20 12:54:41.208525+00', 'Sweet Rosie O''Grady', 2351, '');
INSERT INTO 'tune' VALUES (6406, NULL, '2012-01-20 12:54:41.211413+00', 'My Dearest Sally', 2085, '');
INSERT INTO 'tune' VALUES (6407, NULL, '2012-01-20 12:54:41.214318+00', 'I''ve Got a Lovely Bunch of Coconuts', 2352, '');
INSERT INTO 'tune' VALUES (6408, NULL, '2012-01-20 12:54:41.217199+00', 'I Do Like to be Beside the Seaside', 2354, '');
INSERT INTO 'tune' VALUES (6409, NULL, '2012-01-20 12:54:41.220084+00', 'King George V''s Army', 1699, '');
INSERT INTO 'tune' VALUES (6410, NULL, '2012-01-20 12:54:41.222975+00', 'Braes of Forbes, The', 1699, '');
INSERT INTO 'tune' VALUES (13849, '2018-03-29 18:43:26.459375+00', '2018-03-29 18:43:26.459375+00', 'Twenty and Three Two-step', 2977, '');
INSERT INTO 'tune' VALUES (6412, NULL, '2012-01-20 12:54:41.228752+00', 'We''ll Aye be Fond o'' Ingram', 1512, '');
INSERT INTO 'tune' VALUES (6413, NULL, '2012-01-20 12:54:41.231646+00', 'Black Velvet Band, The', 9999, '');
INSERT INTO 'tune' VALUES (6414, NULL, '2012-01-20 12:54:41.234526+00', 'Major Manson''s Farewell to Clachantrushal', 2283, '');
INSERT INTO 'tune' VALUES (6415, NULL, '2012-01-20 12:54:41.237408+00', 'New Pair of Shoes, The', 9999, '');
INSERT INTO 'tune' VALUES (6416, NULL, '2012-01-20 12:54:41.240294+00', 'Yellow Little Boy, The', 9999, '');
INSERT INTO 'tune' VALUES (6417, NULL, '2012-01-20 12:54:41.243179+00', 'Cahirmee Fair', 1744, '');
INSERT INTO 'tune' VALUES (6418, NULL, '2012-01-20 12:54:41.246062+00', 'Miller''s Maid, The', 9999, '');
INSERT INTO 'tune' VALUES (6419, NULL, '2012-01-20 12:54:41.248963+00', 'Old Pipe Reel', 9999, '');
INSERT INTO 'tune' VALUES (6420, NULL, '2012-01-20 12:54:41.25185+00', 'Loon''s Last Dream, The', 9998, '');
INSERT INTO 'tune' VALUES (6421, NULL, '2012-01-20 12:54:41.254745+00', 'Copeshaw Reel, The', 9998, '');
INSERT INTO 'tune' VALUES (6422, NULL, '2012-01-20 12:54:41.25763+00', 'Portree Bay', 1908, '');
INSERT INTO 'tune' VALUES (6392, NULL, '2012-11-29 07:33:53.45195+00', 'Para Handy Polka, The', 1523, '');
INSERT INTO 'tune' VALUES (6423, NULL, '2012-01-20 12:54:41.260512+00', 'Edinburgh Castle', 9998, '');
INSERT INTO 'tune' VALUES (6424, NULL, '2012-01-20 12:54:41.263414+00', 'Linden Anniversary Strathspey, The', 1643, '');
INSERT INTO 'tune' VALUES (6425, NULL, '2012-01-20 12:54:41.266392+00', 'Guid Tae See Ye', 1899, '');
INSERT INTO 'tune' VALUES (6426, NULL, '2012-01-20 12:54:41.26943+00', 'Caroline', 2197, '');
INSERT INTO 'tune' VALUES (6427, NULL, '2012-01-20 12:54:41.27233+00', 'Maids of Kintail', 9998, '');
INSERT INTO 'tune' VALUES (6428, NULL, '2012-01-20 12:54:41.275228+00', 'Miss Elizabeth Cargill', 1764, '');
INSERT INTO 'tune' VALUES (6429, NULL, '2012-01-20 12:54:41.278253+00', 'John McPhail', 1764, '');
INSERT INTO 'tune' VALUES (6430, NULL, '2012-01-20 12:54:41.281172+00', 'C. Stewart Smith', 1764, '');
INSERT INTO 'tune' VALUES (6431, NULL, '2012-01-20 12:54:41.28407+00', 'Santa Monica Jig', 1764, '');
INSERT INTO 'tune' VALUES (6432, NULL, '2012-01-20 12:54:41.286972+00', 'Pasadena Prom', 1764, '');
INSERT INTO 'tune' VALUES (6433, NULL, '2012-01-20 12:54:41.289864+00', 'Corsair Field', 1764, '');
INSERT INTO 'tune' VALUES (6434, NULL, '2012-01-20 12:54:41.292796+00', 'Flemings, The', 1764, '');
INSERT INTO 'tune' VALUES (6435, NULL, '2012-01-20 12:54:41.295721+00', 'Barley Bree', 1764, '');
INSERT INTO 'tune' VALUES (6436, NULL, '2012-01-20 12:54:41.298618+00', 'By The Beautiful Sea', 2361, '');
INSERT INTO 'tune' VALUES (6437, NULL, '2012-01-20 12:54:41.301501+00', 'Fen', 389, '');
INSERT INTO 'tune' VALUES (6438, NULL, '2012-01-20 12:54:41.304405+00', 'Fran''s Tiraluin', 1780, '');
INSERT INTO 'tune' VALUES (6439, NULL, '2012-01-20 12:54:41.307299+00', 'Laird of Atherton, The', 1782, '');
INSERT INTO 'tune' VALUES (6440, NULL, '2012-01-20 12:54:41.310187+00', 'Shower Reel, The', 1780, '');
INSERT INTO 'tune' VALUES (6441, NULL, '2012-01-20 12:54:41.313078+00', 'Wee Glaswegian, The', 1773, '');
INSERT INTO 'tune' VALUES (6442, NULL, '2012-01-20 12:54:41.315968+00', 'Not Her First Choice', 1780, '');
INSERT INTO 'tune' VALUES (6443, NULL, '2012-01-20 12:54:41.318855+00', 'Briar Rose', 1780, '');
INSERT INTO 'tune' VALUES (6444, NULL, '2012-01-20 12:54:41.321738+00', 'Royal Highland Fusiliers', 1719, '');
INSERT INTO 'tune' VALUES (6445, NULL, '2012-01-20 12:54:41.324628+00', 'Walter''s Reel', 1592, '');
INSERT INTO 'tune' VALUES (6446, NULL, '2012-01-20 12:54:41.327677+00', 'Manse Brae', 1592, '');
INSERT INTO 'tune' VALUES (6447, NULL, '2012-01-20 12:54:41.330598+00', 'James Alexander''s Hornpipe', 1592, '');
INSERT INTO 'tune' VALUES (6448, NULL, '2012-01-20 12:54:41.333486+00', 'Barbed Wire Reel, The', 1592, '');
INSERT INTO 'tune' VALUES (6449, NULL, '2012-01-20 12:54:41.336388+00', 'Fergie Plus One', 1592, '');
INSERT INTO 'tune' VALUES (6450, NULL, '2012-01-20 12:54:41.339274+00', 'Gordon Davidson Of Banchory', 1592, '');
INSERT INTO 'tune' VALUES (6451, NULL, '2012-01-20 12:54:41.342153+00', 'Dunecht Loon, The', 1592, '');
INSERT INTO 'tune' VALUES (6452, NULL, '2012-01-20 12:54:41.345044+00', '2 Bin Avenue', 1592, '');
INSERT INTO 'tune' VALUES (6453, NULL, '2012-01-20 12:54:41.347938+00', 'Mike & Jenny Shaw, Strathpeffer', 1592, '');
INSERT INTO 'tune' VALUES (6454, NULL, '2012-01-20 12:54:41.350835+00', 'Oonie''s March', 1592, '');
INSERT INTO 'tune' VALUES (6455, NULL, '2012-01-20 12:54:41.353714+00', 'Minors for MacMillan', 1592, '');
INSERT INTO 'tune' VALUES (6456, NULL, '2012-01-20 12:54:41.356604+00', 'Fine Fettle', 1592, '');
INSERT INTO 'tune' VALUES (6457, NULL, '2012-01-20 12:54:41.359488+00', 'Drop Of The Electric Soup', 1592, '');
INSERT INTO 'tune' VALUES (6458, NULL, '2012-01-20 12:54:41.362386+00', 'Sandy Gauld''s Jig', 1592, '');
INSERT INTO 'tune' VALUES (6459, NULL, '2012-01-20 12:54:41.365414+00', 'Forbes Raeburn Of Huntly', 1592, '');
INSERT INTO 'tune' VALUES (6460, NULL, '2012-01-20 12:54:41.368306+00', 'Inchlonaig', 1592, '');
INSERT INTO 'tune' VALUES (6461, NULL, '2012-01-20 12:54:41.371201+00', 'Duncan Christie - who else?', 1592, '');
INSERT INTO 'tune' VALUES (6462, NULL, '2012-01-20 12:54:41.374086+00', 'Crackens', 1592, '');
INSERT INTO 'tune' VALUES (6464, NULL, '2012-01-20 12:54:41.379869+00', 'Donny The Post', 1592, '');
INSERT INTO 'tune' VALUES (6465, NULL, '2012-01-20 12:54:41.38275+00', 'Angus MacFadyen''s Trip On Inchmoan', 1592, '');
INSERT INTO 'tune' VALUES (6466, NULL, '2012-01-20 12:54:41.385642+00', 'Power To The Harmonica', 1592, '');
INSERT INTO 'tune' VALUES (6467, NULL, '2012-01-20 12:54:41.388543+00', 'Big Fin, The', 1592, '');
INSERT INTO 'tune' VALUES (6468, NULL, '2012-01-20 12:54:41.391436+00', 'Navtarf Reel', 1592, '');
INSERT INTO 'tune' VALUES (6469, NULL, '2012-01-20 12:54:41.394327+00', 'Dochie Macallum Esq.', 1592, '');
INSERT INTO 'tune' VALUES (6470, NULL, '2012-01-20 12:54:41.397213+00', 'Drewy Hawick of Lerwick', 1592, '');
INSERT INTO 'tune' VALUES (6471, NULL, '2012-01-20 12:54:41.400094+00', 'Dochie Doo''s Jig', 1592, '');
INSERT INTO 'tune' VALUES (6472, NULL, '2012-01-20 12:54:41.402983+00', 'Peter & Chris Sydserff, Hawaii', 1592, '');
INSERT INTO 'tune' VALUES (6473, NULL, '2012-01-20 12:54:41.405899+00', 'Ceilidhs At Crowbutts', 1592, '');
INSERT INTO 'tune' VALUES (6474, NULL, '2012-01-20 12:54:41.408787+00', 'Sandy & Aileen Mitchell', 1592, '');
INSERT INTO 'tune' VALUES (6475, NULL, '2012-01-20 12:54:41.411683+00', 'One For The Kids', 1592, '');
INSERT INTO 'tune' VALUES (6476, NULL, '2012-01-20 12:54:41.414573+00', 'Bill''s Legacy Lives On', 1592, '');
INSERT INTO 'tune' VALUES (6477, NULL, '2012-01-20 12:54:41.41747+00', 'Mortlach', 1592, '');
INSERT INTO 'tune' VALUES (6478, NULL, '2012-01-20 12:54:41.420363+00', 'Pipe Major Jim Christie of Wick', 2362, '');
INSERT INTO 'tune' VALUES (6479, NULL, '2012-01-20 12:54:41.423257+00', 'June and Sandy Adams', 1520, '');
INSERT INTO 'tune' VALUES (6480, NULL, '2012-01-20 12:54:41.426138+00', 'Nancy', 1676, '');
INSERT INTO 'tune' VALUES (6481, NULL, '2012-01-20 12:54:41.429028+00', 'Dhon Express', 9999, '');
INSERT INTO 'tune' VALUES (6482, NULL, '2012-01-20 12:54:41.431967+00', 'Curler''s Reel, The', 1646, '');
INSERT INTO 'tune' VALUES (6483, NULL, '2012-01-20 12:54:41.435418+00', 'Jean Reid''s Jig', 1520, '');
INSERT INTO 'tune' VALUES (6484, NULL, '2012-01-20 12:54:41.438319+00', 'Chic Boath of Cramflat', 1520, '');
INSERT INTO 'tune' VALUES (6485, NULL, '2012-01-20 12:54:41.441237+00', 'Doreen''s Waltz', 1599, '');
INSERT INTO 'tune' VALUES (6486, NULL, '2012-01-20 12:54:41.444127+00', 'Bob Fenton of Barnhead Smiddy', 1520, '');
INSERT INTO 'tune' VALUES (6487, NULL, '2012-01-20 12:54:41.447018+00', 'Dave and Carrie Napier''s Ruby Wedding', 1520, '');
INSERT INTO 'tune' VALUES (6488, NULL, '2012-01-20 12:54:41.449915+00', 'Bob Croy', 2366, '');
INSERT INTO 'tune' VALUES (6489, NULL, '2012-01-20 12:54:41.452813+00', 'Whitehall Jig, The', 1646, '');
INSERT INTO 'tune' VALUES (6490, NULL, '2012-01-20 12:54:41.455702+00', 'Miss Nora Kindness', 1502, '');
INSERT INTO 'tune' VALUES (6491, NULL, '2012-01-20 12:54:41.458587+00', 'Balgeddie Mains', 1764, '');
INSERT INTO 'tune' VALUES (6492, NULL, '2012-01-20 12:54:41.461475+00', 'Ronald Cooper', 1535, '');
INSERT INTO 'tune' VALUES (6493, NULL, '2012-01-20 12:54:41.464362+00', 'Way to Ceres, The', 1764, '');
INSERT INTO 'tune' VALUES (6494, NULL, '2012-01-20 12:54:41.467252+00', 'Balsillie', 50, '');
INSERT INTO 'tune' VALUES (6495, NULL, '2012-01-20 12:54:41.470131+00', 'Ballenbreich', 50, '');
INSERT INTO 'tune' VALUES (6496, NULL, '2012-01-20 12:54:41.473032+00', 'Earl of Rothes, The', 50, '');
INSERT INTO 'tune' VALUES (6497, NULL, '2012-01-20 12:54:41.475924+00', 'Lord Leslie', 50, '');
INSERT INTO 'tune' VALUES (6498, NULL, '2012-01-20 12:54:41.478815+00', 'Cupar Haugh', 1764, '');
INSERT INTO 'tune' VALUES (6499, NULL, '2012-01-20 12:54:41.481706+00', 'Mac Nichol', 1764, '');
INSERT INTO 'tune' VALUES (6500, NULL, '2012-01-20 12:54:41.484601+00', 'Bramble Jig, The', 1764, '');
INSERT INTO 'tune' VALUES (6501, NULL, '2012-01-20 12:54:41.487508+00', 'Stromness', 1764, '');
INSERT INTO 'tune' VALUES (6502, NULL, '2012-01-20 12:54:41.490401+00', 'Officer and a Gentleman, An', 1764, '');
INSERT INTO 'tune' VALUES (6503, NULL, '2012-01-20 12:54:41.503383+00', 'Rena Dewar''s Delight', 1764, '');
INSERT INTO 'tune' VALUES (6504, NULL, '2012-01-20 12:54:41.506382+00', 'Salute to Glasgow', 1418, '');
INSERT INTO 'tune' VALUES (6505, NULL, '2012-01-20 12:54:41.509273+00', 'Alyson Margaret Crowe', 1585, '');
INSERT INTO 'tune' VALUES (6506, NULL, '2012-01-20 12:54:41.512162+00', 'Langholm Fair', 9998, '');
INSERT INTO 'tune' VALUES (6507, NULL, '2012-01-20 12:54:41.515089+00', 'Anne and Tam Leggat', 1554, '');
INSERT INTO 'tune' VALUES (6508, NULL, '2012-01-20 12:54:41.517981+00', 'Garden Clock, The', 1554, '');
INSERT INTO 'tune' VALUES (6509, NULL, '2012-01-20 12:54:41.520896+00', 'Claybraes Two-Step, The', 1521, '');
INSERT INTO 'tune' VALUES (6510, NULL, '2012-01-20 12:54:41.523822+00', 'Little Girl', 1640, '');
INSERT INTO 'tune' VALUES (6511, NULL, '2012-01-20 12:54:41.526807+00', 'Edinburgh Ladies Pipe Band, The', 2373, '');
INSERT INTO 'tune' VALUES (6512, NULL, '2012-01-20 12:54:41.529774+00', 'Master Alastair Cunningham', 1771, '');
INSERT INTO 'tune' VALUES (6513, NULL, '2012-01-20 12:54:41.532676+00', 'Bobby Brown''s Welcome to Scotland', 1771, '');
INSERT INTO 'tune' VALUES (6514, NULL, '2012-01-20 12:54:41.535576+00', 'Achill Island', 2374, '');
INSERT INTO 'tune' VALUES (6515, NULL, '2012-01-20 12:54:41.538464+00', 'Shores of Loch Alvie, The', 1585, '');
INSERT INTO 'tune' VALUES (6516, NULL, '2012-01-20 12:54:41.54135+00', 'Love of Early Daye, The', 9999, '');
INSERT INTO 'tune' VALUES (6517, NULL, '2012-01-20 12:54:41.544282+00', 'O Happy May I See Thee', 9999, '');
INSERT INTO 'tune' VALUES (6518, NULL, '2012-01-20 12:54:41.547197+00', 'Isobel MacDonald of Enzie Manse', 2375, '');
INSERT INTO 'tune' VALUES (6519, NULL, '2012-01-20 12:54:41.550078+00', 'Marjorie Jane Barclay', 1554, '');
INSERT INTO 'tune' VALUES (6521, NULL, '2012-01-20 12:54:41.555871+00', 'Master Dylan''s Hornpipe', 2376, '');
INSERT INTO 'tune' VALUES (6522, NULL, '2012-01-20 12:54:41.558771+00', 'Couldnae Care Less', 1551, '');
INSERT INTO 'tune' VALUES (6524, NULL, '2012-01-20 12:54:41.564579+00', 'Song of the Clyde', 2006, '');
INSERT INTO 'tune' VALUES (6525, NULL, '2012-01-20 12:54:41.567464+00', 'New Claret', 9999, '');
INSERT INTO 'tune' VALUES (6527, NULL, '2012-01-20 12:54:41.573238+00', 'Down in the Glen', 9999, '');
INSERT INTO 'tune' VALUES (6528, NULL, '2012-01-20 12:54:41.57612+00', 'Fasten the Leggin''', 9999, '');
INSERT INTO 'tune' VALUES (6529, NULL, '2012-01-20 12:54:41.579007+00', 'Bonnie Udny', 9999, '');
INSERT INTO 'tune' VALUES (6530, NULL, '2012-01-20 12:54:41.581889+00', 'Tramps and Hawkers', 9999, '');
INSERT INTO 'tune' VALUES (6531, NULL, '2012-01-20 12:54:41.584777+00', 'Sands of Loch Bee, The', 9999, '');
INSERT INTO 'tune' VALUES (6532, NULL, '2012-01-20 12:54:41.587693+00', 'Road to Garrinish, The', 9999, '');
INSERT INTO 'tune' VALUES (6533, NULL, '2012-01-20 12:54:41.590586+00', 'Provost of Falkirk, The', 1735, '');
INSERT INTO 'tune' VALUES (6534, NULL, '2012-01-20 12:54:41.593467+00', 'Aviemore Jig', 1735, '');
INSERT INTO 'tune' VALUES (6535, NULL, '2012-01-20 12:54:41.596369+00', 'Peter MacKinnon of Skeabost', 9998, '');
INSERT INTO 'tune' VALUES (6536, NULL, '2012-01-20 12:54:41.599263+00', 'Cuillin of Mull, The', 9999, '');
INSERT INTO 'tune' VALUES (6537, NULL, '2012-01-20 12:54:41.602139+00', 'Captain Cameron''s March', 9999, '');
INSERT INTO 'tune' VALUES (6538, NULL, '2012-01-20 12:54:41.605027+00', 'Scotlandwell', 1735, '');
INSERT INTO 'tune' VALUES (6539, NULL, '2012-01-20 12:54:41.607918+00', 'Bonnie Lassie Will Ye Lo'' e Me', 9999, '');
INSERT INTO 'tune' VALUES (6540, NULL, '2012-01-20 12:54:41.610816+00', 'Love of My Youth, The', 9999, '');
INSERT INTO 'tune' VALUES (6541, NULL, '2012-01-20 12:54:41.613695+00', 'Redondo Beach', 2311, '');
INSERT INTO 'tune' VALUES (6542, NULL, '2012-01-20 12:54:41.616604+00', 'Banks of the Avon, The', 1426, '');
INSERT INTO 'tune' VALUES (6543, NULL, '2012-01-20 12:54:41.619499+00', 'George Fleming', 1735, '');
INSERT INTO 'tune' VALUES (6544, NULL, '2012-01-20 12:54:41.622419+00', 'Bob MacPherson''s Jig', 1426, '');
INSERT INTO 'tune' VALUES (6545, NULL, '2012-01-20 12:54:41.625306+00', 'Kildrummy Castle Gardens', 1735, '');
INSERT INTO 'tune' VALUES (6546, NULL, '2012-01-20 12:54:41.628194+00', 'Glenfurness Blacksmith, The', 2378, '');
INSERT INTO 'tune' VALUES (6547, NULL, '2012-01-20 12:54:41.631078+00', 'Loch Maree Gaelic Air', 9999, '');
INSERT INTO 'tune' VALUES (6548, NULL, '2012-01-20 12:54:41.63396+00', 'Sandy Cameron', 9999, '');
INSERT INTO 'tune' VALUES (6549, NULL, '2012-01-20 12:54:41.636845+00', 'Glen Massan', 2381, '');
INSERT INTO 'tune' VALUES (6550, NULL, '2012-01-20 12:54:41.639746+00', 'Maid of Glengarryside, The', 2384, '');
INSERT INTO 'tune' VALUES (6551, NULL, '2012-01-20 12:54:41.642632+00', 'Bonnie Muir', 1735, '');
INSERT INTO 'tune' VALUES (6552, NULL, '2012-01-20 12:54:41.645514+00', 'Colonel Laidlay', 1609, '');
INSERT INTO 'tune' VALUES (6553, NULL, '2012-01-20 12:54:41.648402+00', 'Arisaig Ceilidh', 2385, '');
INSERT INTO 'tune' VALUES (6554, NULL, '2012-01-20 12:54:41.651288+00', 'Edgefauld House', 1512, '');
INSERT INTO 'tune' VALUES (6555, NULL, '2012-01-20 12:54:41.654167+00', 'Mrs Busby Maitland', 9999, '');
INSERT INTO 'tune' VALUES (6556, NULL, '2012-01-20 12:54:41.657117+00', 'Mrs Fraser', 1516, '');
INSERT INTO 'tune' VALUES (6557, NULL, '2012-01-20 12:54:41.660548+00', 'Staffin Bay', 1754, '');
INSERT INTO 'tune' VALUES (6558, NULL, '2012-01-20 12:54:41.663488+00', 'March Hall Crescent', 2388, '');
INSERT INTO 'tune' VALUES (7100, NULL, '2012-01-20 12:54:43.29102+00', 'Norrah Malone', 2548, '');
INSERT INTO 'tune' VALUES (6559, NULL, '2012-01-20 12:54:41.666396+00', 'Rebel''s Flight from Cawnpore, The', 1735, '');
INSERT INTO 'tune' VALUES (6560, NULL, '2012-01-20 12:54:41.669291+00', '1st Burma Rifles, The', 1910, '');
INSERT INTO 'tune' VALUES (6561, NULL, '2012-01-20 12:54:41.672179+00', 'Chrobhain''s Galley', 9999, '');
INSERT INTO 'tune' VALUES (6562, NULL, '2012-01-20 12:54:41.67507+00', 'Uist My Love', 1673, '');
INSERT INTO 'tune' VALUES (6563, NULL, '2012-01-20 12:54:41.677952+00', 'Hugh MacDonald', 1304, '');
INSERT INTO 'tune' VALUES (6564, NULL, '2012-01-20 12:54:41.680846+00', 'Ina MacPhail', 9998, '');
INSERT INTO 'tune' VALUES (6565, NULL, '2012-01-20 12:54:41.683741+00', 'Black Watch Polka, The', 9999, '');
INSERT INTO 'tune' VALUES (6566, NULL, '2012-01-20 12:54:41.686626+00', 'John C Muir', 1735, '');
INSERT INTO 'tune' VALUES (6567, NULL, '2012-01-20 12:54:41.689511+00', 'Battle of Waterloo, The', 9999, '');
INSERT INTO 'tune' VALUES (6569, NULL, '2012-01-20 12:54:41.695292+00', 'Mrs Macleod of Rosses', 9998, '');
INSERT INTO 'tune' VALUES (6570, NULL, '2012-01-20 12:54:41.698177+00', 'In the Gun Room', 1539, '');
INSERT INTO 'tune' VALUES (6571, NULL, '2012-01-20 12:54:41.701081+00', 'Drumlithie', 2225, '');
INSERT INTO 'tune' VALUES (6572, NULL, '2012-01-20 12:54:41.703991+00', '15th Scottish Division', 9998, '');
INSERT INTO 'tune' VALUES (6573, NULL, '2012-01-20 12:54:41.706887+00', 'Deanes of Winchester, The', 1590, '');
INSERT INTO 'tune' VALUES (6574, NULL, '2012-01-20 12:54:41.709775+00', 'Hamilton''s Drums', 1590, '');
INSERT INTO 'tune' VALUES (6575, NULL, '2012-01-20 12:54:41.712666+00', 'Jig of the Blacks, The', 1660, '');
INSERT INTO 'tune' VALUES (6576, NULL, '2012-01-20 12:54:41.715557+00', 'Bonnie Cluden Mill', 1606, '');
INSERT INTO 'tune' VALUES (6577, NULL, '2012-01-20 12:54:41.718438+00', 'Wee Callum Bay', 9999, '');
INSERT INTO 'tune' VALUES (6578, NULL, '2012-01-20 12:54:41.721333+00', 'Tarland Memories', 1818, '');
INSERT INTO 'tune' VALUES (6579, NULL, '2012-01-20 12:54:41.724247+00', 'Grizzly Bear, The', 2176, '');
INSERT INTO 'tune' VALUES (6580, NULL, '2012-01-20 12:54:41.727212+00', 'Dennis Tucker Two Step', 1590, '');
INSERT INTO 'tune' VALUES (6581, NULL, '2012-01-20 12:54:41.730189+00', 'Forbes'' Fiddle', 1590, '');
INSERT INTO 'tune' VALUES (6582, NULL, '2012-01-20 12:54:41.733092+00', 'Loch Levenside', 9998, '');
INSERT INTO 'tune' VALUES (6583, NULL, '2012-01-20 12:54:41.736021+00', 'Iain MacPhail''s Compliments to Stuart Forbes', 1527, '');
INSERT INTO 'tune' VALUES (6584, NULL, '2012-01-20 12:54:41.738922+00', 'James M Cameron of Glasgow', 1527, '');
INSERT INTO 'tune' VALUES (6585, NULL, '2012-01-20 12:54:41.741806+00', 'Charles Anthony Pegram', 1590, '');
INSERT INTO 'tune' VALUES (6586, NULL, '2012-01-20 12:54:41.744698+00', 'Mrs Diana Tucker of Cumnor', 1590, '');
INSERT INTO 'tune' VALUES (6587, NULL, '2012-01-20 12:54:41.747693+00', 'Master John B Douglas', 1574, '');
INSERT INTO 'tune' VALUES (6588, NULL, '2012-01-20 12:54:41.750608+00', 'Reluctant Fiddler, The', 1780, '');
INSERT INTO 'tune' VALUES (6589, NULL, '2012-01-20 12:54:41.753489+00', 'Put Me in the Big Chest', 9999, '');
INSERT INTO 'tune' VALUES (6590, NULL, '2012-01-20 12:54:41.756384+00', 'Mrs Dow''s Reel', 1766, '');
INSERT INTO 'tune' VALUES (6591, NULL, '2012-01-20 12:54:41.759278+00', 'Where''s the Wean?', 2340, '');
INSERT INTO 'tune' VALUES (6592, NULL, '2012-01-20 12:54:41.762165+00', 'Flibbertigibbet', 2391, '');
INSERT INTO 'tune' VALUES (6593, NULL, '2012-01-20 12:54:41.765114+00', 'Jane''s Reel', 1780, '');
INSERT INTO 'tune' VALUES (6594, NULL, '2012-01-20 12:54:41.768013+00', 'Ides of March', 2392, '');
INSERT INTO 'tune' VALUES (6595, NULL, '2012-01-20 12:54:41.770922+00', 'Russian River, The', 2393, '');
INSERT INTO 'tune' VALUES (6597, NULL, '2012-01-20 12:54:41.776705+00', 'Scotty''s Favourite Reel', 1766, '');
INSERT INTO 'tune' VALUES (6598, NULL, '2012-01-20 12:54:41.779596+00', 'Hybrid Vigor', 1780, '');
INSERT INTO 'tune' VALUES (6599, NULL, '2012-01-20 12:54:41.782481+00', 'Moose the Cat', 2395, '');
INSERT INTO 'tune' VALUES (6600, NULL, '2012-01-20 12:54:41.785376+00', 'Grand Marshal, The', 2391, '');
INSERT INTO 'tune' VALUES (6601, NULL, '2012-01-20 12:54:41.788264+00', 'Father Francis Cameron', 2126, '');
INSERT INTO 'tune' VALUES (6602, NULL, '2012-01-20 12:54:41.791154+00', 'Gypsy Dancer', 2396, '');
INSERT INTO 'tune' VALUES (6603, NULL, '2012-01-20 12:54:41.794045+00', 'Bob Breheny''s Bunnet', 2340, '');
INSERT INTO 'tune' VALUES (6604, NULL, '2012-01-20 12:54:41.796968+00', 'Mr & Mrs Neill''s Birthday Party', 9998, '');
INSERT INTO 'tune' VALUES (6606, NULL, '2012-01-20 12:54:41.802758+00', 'Flora MacDonald''s Lament', 9998, '');
INSERT INTO 'tune' VALUES (6607, NULL, '2012-01-20 12:54:41.805645+00', 'Lunam Bay', 1558, '');
INSERT INTO 'tune' VALUES (6608, NULL, '2012-01-20 12:54:41.808557+00', 'Jim Gray Goes to Market', 9998, '');
INSERT INTO 'tune' VALUES (6609, NULL, '2012-01-20 12:54:41.811444+00', 'Ivana', 9998, '');
INSERT INTO 'tune' VALUES (6610, NULL, '2012-01-20 12:54:41.814341+00', 'Ardskinish House', 9998, '');
INSERT INTO 'tune' VALUES (6611, NULL, '2012-01-20 12:54:41.817234+00', 'Malcolm''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (6612, NULL, '2012-01-20 12:54:41.820121+00', 'Roselath Cross, The', 2790, '');
INSERT INTO 'tune' VALUES (6613, NULL, '2012-01-20 12:54:41.823005+00', 'Corriechoille', 9999, '');
INSERT INTO 'tune' VALUES (6614, NULL, '2012-01-20 12:54:41.825885+00', 'Miss Elizabeth Baillie', 9998, '');
INSERT INTO 'tune' VALUES (6615, NULL, '2012-01-20 12:54:41.828772+00', 'Stuarts Jig', 9998, '');
INSERT INTO 'tune' VALUES (6616, NULL, '2012-01-20 12:54:41.831731+00', 'Isle of Colonsay, The', 9998, '');
INSERT INTO 'tune' VALUES (6617, NULL, '2012-01-20 12:54:41.834639+00', 'Kiloran Bay', 10168, '');
INSERT INTO 'tune' VALUES (6618, NULL, '2012-01-20 12:54:41.837531+00', 'Helen Little of Woodside', 9998, '');
INSERT INTO 'tune' VALUES (6620, NULL, '2012-01-20 12:54:41.84332+00', 'J Carnegie''s March', 9998, '');
INSERT INTO 'tune' VALUES (6621, NULL, '2012-01-20 12:54:41.846209+00', 'Scots Guards', 9998, '');
INSERT INTO 'tune' VALUES (6622, NULL, '2012-01-20 12:54:41.8491+00', 'March Through Jerusalem', 9998, '');
INSERT INTO 'tune' VALUES (6623, NULL, '2012-01-20 12:54:41.85205+00', 'Games Day at Aboyne', 9998, '');
INSERT INTO 'tune' VALUES (6624, NULL, '2012-01-20 12:54:41.854945+00', 'Bob Grier of Largoward', 9998, '');
INSERT INTO 'tune' VALUES (6626, NULL, '2012-01-20 12:54:41.860757+00', 'Crooked Stovepipe, The', 9999, '');
INSERT INTO 'tune' VALUES (6627, NULL, '2012-01-20 12:54:41.863664+00', 'Mrs Muriel Boal', 9998, '');
INSERT INTO 'tune' VALUES (6628, NULL, '2012-01-20 12:54:41.866571+00', 'David Little', 9998, '');
INSERT INTO 'tune' VALUES (6629, NULL, '2012-01-20 12:54:41.869476+00', 'Anne Stephen of Aberdeen', 9998, '');
INSERT INTO 'tune' VALUES (6630, NULL, '2012-01-20 12:54:41.872783+00', 'Miss Grant''s Jig', 1516, '');
INSERT INTO 'tune' VALUES (6631, NULL, '2012-01-20 12:54:41.875716+00', 'Miss Maitland (of Rankeillor''s) Reel', 9998, '');
INSERT INTO 'tune' VALUES (6632, NULL, '2012-01-20 12:54:41.878638+00', 'Patrick George Moncrieff of Reedie', 1967, 'This tune is probably the same as »Patrick George Moncrieff Esq.« as recorded by John Renton on the RSCDS book 11 CD. The association to Alexander Leburn is made on the strength of that conjecture.');
INSERT INTO 'tune' VALUES (6633, NULL, '2012-01-20 12:54:41.881546+00', 'Heather''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (6634, NULL, '2012-01-20 12:54:41.884444+00', 'Joanna Cramb', 9998, '');
INSERT INTO 'tune' VALUES (6635, NULL, '2012-01-20 12:54:41.887338+00', 'Lucy Cramb', 9998, '');
INSERT INTO 'tune' VALUES (6636, NULL, '2012-01-20 12:54:41.890225+00', 'Mrs Muir McKenzie''s Delight', 1731, '');
INSERT INTO 'tune' VALUES (6637, NULL, '2012-01-20 12:54:41.893113+00', 'Miss D Grant''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (6638, NULL, '2012-01-20 12:54:41.896+00', 'Miss Smythe (of Methven''s) Favourite', 9998, '');
INSERT INTO 'tune' VALUES (6639, NULL, '2012-01-20 12:54:41.898898+00', 'Miss Betty Kerr''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (6640, NULL, '2012-01-20 12:54:41.901787+00', 'Lady Jane Nevill''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (6641, NULL, '2012-01-20 12:54:41.904675+00', 'Sean Chaisteal Ghart', 9998, '');
INSERT INTO 'tune' VALUES (6642, NULL, '2012-01-20 12:54:41.907571+00', 'Sean Rong Mor', 9998, '');
INSERT INTO 'tune' VALUES (6643, NULL, '2012-01-20 12:54:41.910455+00', 'Lads of Glasgow', 9998, '');
INSERT INTO 'tune' VALUES (6644, NULL, '2012-01-20 12:54:41.91334+00', 'Gallant Fireman', 9998, '');
INSERT INTO 'tune' VALUES (6645, NULL, '2012-01-20 12:54:41.916237+00', 'Miss Stewart of Grantully', 1671, '');
INSERT INTO 'tune' VALUES (13850, '2018-03-30 08:31:57.643987+00', '2018-03-30 08:31:57.643987+00', 'Wrens and Dogwoods Consider Springtime', 11614, '');
INSERT INTO 'tune' VALUES (6647, NULL, '2012-01-20 12:54:41.922038+00', 'Colonel Rodney', 9999, '');
INSERT INTO 'tune' VALUES (6648, NULL, '2012-01-20 12:54:41.924941+00', 'Gallowglass', 9999, '');
INSERT INTO 'tune' VALUES (6649, NULL, '2012-01-20 12:54:41.928041+00', 'Dawn, The', 9998, '');
INSERT INTO 'tune' VALUES (6650, NULL, '2012-01-20 12:54:41.930959+00', 'Twenty-fourth of June', 1710, '');
INSERT INTO 'tune' VALUES (6651, NULL, '2012-01-20 12:54:41.933843+00', 'Alpine Jig', 1450, '');
INSERT INTO 'tune' VALUES (6652, NULL, '2012-01-20 12:54:41.936727+00', 'James Maxwell Robertson', 1606, '');
INSERT INTO 'tune' VALUES (6653, NULL, '2012-01-20 12:54:41.939617+00', 'Keep Your Feet Still', 9999, '');
INSERT INTO 'tune' VALUES (6654, NULL, '2012-01-20 12:54:41.942494+00', 'Lambton Worm', 9999, '');
INSERT INTO 'tune' VALUES (6655, NULL, '2012-01-20 12:54:41.945382+00', 'Heh Ye Seen Wor Jimmy', 9999, '');
INSERT INTO 'tune' VALUES (6656, NULL, '2012-01-20 12:54:41.948441+00', 'Foggy Dew', 9999, '');
INSERT INTO 'tune' VALUES (6657, NULL, '2012-01-20 12:54:41.951383+00', 'Leavin'' of Liverpool', 9999, '');
INSERT INTO 'tune' VALUES (6659, NULL, '2012-01-20 12:54:41.957195+00', 'Two Traditional Airs', 9998, '');
INSERT INTO 'tune' VALUES (6660, NULL, '2012-01-20 12:54:41.960094+00', 'Roll Back The Carpet', 1681, '');
INSERT INTO 'tune' VALUES (6661, NULL, '2012-01-20 12:54:41.963+00', 'Assynt Crofters, The', 1681, '');
INSERT INTO 'tune' VALUES (6662, NULL, '2012-01-20 12:54:41.965895+00', 'West End, The', 1681, '');
INSERT INTO 'tune' VALUES (6663, NULL, '2012-01-20 12:54:41.968787+00', 'Black Dry Snout', 1580, '');
INSERT INTO 'tune' VALUES (6664, NULL, '2012-01-20 12:54:41.971673+00', 'White Gold', 2403, '');
INSERT INTO 'tune' VALUES (6665, NULL, '2012-01-20 12:54:41.974566+00', 'First Snow, The', 2404, '');
INSERT INTO 'tune' VALUES (6666, NULL, '2012-01-20 12:54:41.977449+00', 'Pinnacles, The', 2404, '');
INSERT INTO 'tune' VALUES (6667, NULL, '2012-01-20 12:54:41.980332+00', 'Capel Vale', 2404, '');
INSERT INTO 'tune' VALUES (6668, NULL, '2012-01-20 12:54:41.983229+00', 'Brig, The', 9999, '');
INSERT INTO 'tune' VALUES (6669, NULL, '2012-01-20 12:54:41.986115+00', 'Fiddler''s Toolshed, The', 1580, '');
INSERT INTO 'tune' VALUES (6672, NULL, '2012-01-20 12:54:41.994806+00', 'Man at the Loom, The', 9999, '');
INSERT INTO 'tune' VALUES (6673, NULL, '2012-01-20 12:54:41.997689+00', 'Far Isles, The', 1457, '');
INSERT INTO 'tune' VALUES (6674, NULL, '2012-01-20 12:54:42.000582+00', 'David Ross', 2407, '');
INSERT INTO 'tune' VALUES (6675, NULL, '2012-01-20 12:54:42.003467+00', 'Wendy''s Jig', 1407, '');
INSERT INTO 'tune' VALUES (6676, NULL, '2012-01-20 12:54:42.006357+00', 'Miss Kitty Ahearne of Ferrybank', 2413, '');
INSERT INTO 'tune' VALUES (6677, NULL, '2012-01-20 12:54:42.009244+00', 'Lansdowne House', 2413, '');
INSERT INTO 'tune' VALUES (6678, NULL, '2012-01-20 12:54:42.012126+00', 'Bert''s Highland Polka', 1550, '');
INSERT INTO 'tune' VALUES (6679, NULL, '2012-01-20 12:54:42.015022+00', 'Green Hills of Tyrol, The', 1914, '');
INSERT INTO 'tune' VALUES (6680, NULL, '2012-01-20 12:54:42.017905+00', 'Dream Valley of Glendaruel', 9999, '');
INSERT INTO 'tune' VALUES (6681, NULL, '2012-01-20 12:54:42.020804+00', 'Sligo Fancy', 9999, '');
INSERT INTO 'tune' VALUES (6625, NULL, '2014-05-09 09:14:27.098022+00', 'Granite City, The', 10954, '');
INSERT INTO 'tune' VALUES (6619, NULL, '2014-11-08 20:29:04.165266+00', 'Skymen of Arnhem, The', 1920, '');
INSERT INTO 'tune' VALUES (6682, NULL, '2012-01-20 12:54:42.023698+00', '74ths Farewell to Edinburgh', 1414, '');
INSERT INTO 'tune' VALUES (6683, NULL, '2012-01-20 12:54:42.026652+00', 'Johnny Hayes of the Isle', 2413, '');
INSERT INTO 'tune' VALUES (6684, NULL, '2012-01-20 12:54:42.029546+00', 'Davidson''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (6685, NULL, '2012-01-20 12:54:42.032431+00', 'Miss Finlay''s Delight', 9999, '');
INSERT INTO 'tune' VALUES (6686, NULL, '2012-01-20 12:54:42.035321+00', 'Blinkin'' o''t, The', 9999, '');
INSERT INTO 'tune' VALUES (6687, NULL, '2012-01-20 12:54:42.038203+00', 'MacRimmon''s Lament', 9999, '');
INSERT INTO 'tune' VALUES (6688, NULL, '2012-01-20 12:54:42.041128+00', 'Hiking Song, The', 2415, '');
INSERT INTO 'tune' VALUES (6689, NULL, '2012-01-20 12:54:42.044017+00', 'Red River Valley', 9999, '');
INSERT INTO 'tune' VALUES (6690, NULL, '2012-01-20 12:54:42.046926+00', 'Mrs Stewart of Inverugie', 1516, '');
INSERT INTO 'tune' VALUES (6691, NULL, '2012-01-20 12:54:42.049838+00', 'Qumdaro', 9999, '');
INSERT INTO 'tune' VALUES (6692, NULL, '2012-01-20 12:54:42.05273+00', 'Bob Gilmour''s Return to Scotland', 9998, '');
INSERT INTO 'tune' VALUES (6693, NULL, '2012-01-20 12:54:42.055623+00', 'Pierette', 1567, '');
INSERT INTO 'tune' VALUES (6694, NULL, '2012-01-20 12:54:42.058521+00', 'Duchess of Atholl''s Favourite, The', 9998, '');
INSERT INTO 'tune' VALUES (6695, NULL, '2012-01-20 12:54:42.06144+00', 'Isles of Gletness, The', 10109, '');
INSERT INTO 'tune' VALUES (6670, NULL, '2012-10-17 11:10:16.689961+00', 'Gordon Crombie Munro', 1512, '');
INSERT INTO 'tune' VALUES (6696, NULL, '2012-01-20 12:54:42.064336+00', 'Starry Nights of Shetland, Da', 9998, '');
INSERT INTO 'tune' VALUES (6697, NULL, '2012-01-20 12:54:42.067224+00', 'David Griffiths'' Compliments to Sandy Nixon', 1648, '');
INSERT INTO 'tune' VALUES (6698, NULL, '2012-01-20 12:54:42.070108+00', 'Sandy Nixon''s Compliments to the St Andrews Band', 1576, '');
INSERT INTO 'tune' VALUES (6699, NULL, '2012-01-20 12:54:42.073004+00', 'Ornithologist, The', 1580, '');
INSERT INTO 'tune' VALUES (6700, NULL, '2012-01-20 12:54:42.075915+00', 'Shambellie Woods', 1606, '');
INSERT INTO 'tune' VALUES (6701, NULL, '2012-01-20 12:54:42.078808+00', 'McMaths of Silverburn, The', 3621, '');
INSERT INTO 'tune' VALUES (6702, NULL, '2012-01-20 12:54:42.081694+00', 'Tribute to George Fleming, A', 1576, '');
INSERT INTO 'tune' VALUES (6703, NULL, '2012-01-20 12:54:42.084584+00', 'Willie Pollock''s Compliments to George Fleming', 1435, '');
INSERT INTO 'tune' VALUES (6704, NULL, '2012-01-20 12:54:42.087482+00', 'Morrison''s Academy Anniversary March', 1615, '');
INSERT INTO 'tune' VALUES (6706, NULL, '2012-01-20 12:54:42.09329+00', 'Marchfield Brae Scotch Measure, The', 1615, '');
INSERT INTO 'tune' VALUES (6707, NULL, '2012-01-20 12:54:42.096508+00', 'Alex and Hazel Barbour of Bonskeld', 1615, '');
INSERT INTO 'tune' VALUES (6708, NULL, '2012-01-20 12:54:42.099442+00', 'General Baillie', 1512, '');
INSERT INTO 'tune' VALUES (6709, NULL, '2012-01-20 12:54:42.102329+00', 'Black Jock of Skellater', 1512, '');
INSERT INTO 'tune' VALUES (6710, NULL, '2012-01-20 12:54:42.105217+00', 'Cape Breton March', 9999, '');
INSERT INTO 'tune' VALUES (6711, NULL, '2012-01-20 12:54:42.108103+00', 'Herbie MacLeod (of Boston''s) Hornpipe', 1615, '');
INSERT INTO 'tune' VALUES (6712, NULL, '2012-01-20 12:54:42.110996+00', 'Evelyn M E Murray of Cambridge, Mass.', 1615, '');
INSERT INTO 'tune' VALUES (6713, NULL, '2012-01-20 12:54:42.113883+00', 'Rev. Archibald Minto''s Farewell to St Andrews', 1615, '');
INSERT INTO 'tune' VALUES (6714, NULL, '2012-01-20 12:54:42.116808+00', 'Queen''s Welcome to Invercauld, The', 1512, '');
INSERT INTO 'tune' VALUES (6715, NULL, '2012-01-20 12:54:42.119952+00', 'Gibson''s Whisky', 1512, '');
INSERT INTO 'tune' VALUES (6716, NULL, '2012-01-20 12:54:42.123463+00', 'Loch Torphichen', 9999, '');
INSERT INTO 'tune' VALUES (6717, NULL, '2012-01-20 12:54:42.126715+00', 'Colin and Margaret''s Reel', 1404, '');
INSERT INTO 'tune' VALUES (6718, NULL, '2012-01-20 12:54:42.129697+00', 'Leslie Aitken of Banchory', 1404, '');
INSERT INTO 'tune' VALUES (6719, NULL, '2012-01-20 12:54:42.132616+00', 'Gillian Kindness', 1520, '');
INSERT INTO 'tune' VALUES (6720, NULL, '2012-01-20 12:54:42.13552+00', 'Mr Compton', 9999, '');
INSERT INTO 'tune' VALUES (6721, NULL, '2012-01-20 12:54:42.13841+00', 'Alison Kindness', 1520, '');
INSERT INTO 'tune' VALUES (6722, NULL, '2012-01-20 12:54:42.141291+00', 'Queen Victoria''s Diamond Jubilee', 9998, '');
INSERT INTO 'tune' VALUES (6723, NULL, '2012-01-20 12:54:42.144176+00', 'Jack the Fat Black Cat', 2183, '');
INSERT INTO 'tune' VALUES (6724, NULL, '2012-01-20 12:54:42.147069+00', 'Prince''s Stream, The', 1336, '');
INSERT INTO 'tune' VALUES (6725, NULL, '2012-01-20 12:54:42.149952+00', 'Itinerating Jane', 1644, '');
INSERT INTO 'tune' VALUES (6726, NULL, '2012-01-20 12:54:42.152844+00', 'Hairy Bug, The', 2183, '');
INSERT INTO 'tune' VALUES (6727, NULL, '2012-01-20 12:54:42.155731+00', 'Windy House, The', 2183, '');
INSERT INTO 'tune' VALUES (6728, NULL, '2012-01-20 12:54:42.158643+00', 'Little Cascade, The', 1699, '');
INSERT INTO 'tune' VALUES (6729, NULL, '2012-01-20 12:54:42.161545+00', 'Alastair and Pauline Tocher', 2183, '');
INSERT INTO 'tune' VALUES (6730, NULL, '2012-01-20 12:54:42.164829+00', 'Ever the Optimist', 2183, '');
INSERT INTO 'tune' VALUES (6731, NULL, '2012-01-20 12:54:42.167743+00', 'Lass-less Tocher, The', 2183, '');
INSERT INTO 'tune' VALUES (6732, NULL, '2012-01-20 12:54:42.17065+00', 'Sweetness of Mary', 2416, '');
INSERT INTO 'tune' VALUES (6733, NULL, '2012-01-20 12:54:42.173651+00', 'Tom Brigg''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (6734, NULL, '2012-01-20 12:54:42.176551+00', 'Bob Chadduck''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (6735, NULL, '2012-01-20 12:54:42.179442+00', 'Get on de Train', 9998, '');
INSERT INTO 'tune' VALUES (6736, NULL, '2012-01-20 12:54:42.182348+00', 'Hoop-de-Dooden-do', 9998, '');
INSERT INTO 'tune' VALUES (6737, NULL, '2012-01-20 12:54:42.185232+00', 'Robertson''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (6738, NULL, '2012-01-20 12:54:42.188113+00', 'Twist Ye Twine Ye', 1512, '');
INSERT INTO 'tune' VALUES (6739, NULL, '2012-01-20 12:54:42.191002+00', 'Craig Chattan', 1512, '');
INSERT INTO 'tune' VALUES (6740, NULL, '2012-01-20 12:54:42.193881+00', 'Coleraine', 9998, '');
INSERT INTO 'tune' VALUES (6741, NULL, '2012-01-20 12:54:42.196782+00', 'Jump at the Sun', 2417, '');
INSERT INTO 'tune' VALUES (6742, NULL, '2012-01-20 12:54:42.199674+00', 'Shiela MacGregor', 1693, '');
INSERT INTO 'tune' VALUES (6743, NULL, '2012-01-20 12:54:42.202568+00', 'Old Fire Engine, The', 2183, '');
INSERT INTO 'tune' VALUES (6744, NULL, '2012-01-20 12:54:42.205452+00', 'Ben the Blacksmith', 1605, '');
INSERT INTO 'tune' VALUES (6745, NULL, '2012-01-20 12:54:42.208333+00', 'Rattlin'' Rollin'' Rachel', 2183, '');
INSERT INTO 'tune' VALUES (6746, NULL, '2012-01-20 12:54:42.211252+00', 'Bass Wrecker''s Boogie, The', 2183, '');
INSERT INTO 'tune' VALUES (6747, NULL, '2012-01-20 12:54:42.214137+00', 'Miss Drummond of Perth''s Favourite Scotch Measure', 1695, '');
INSERT INTO 'tune' VALUES (6748, NULL, '2012-01-20 12:54:42.217038+00', 'Margaret-Ann Robertson', 1623, '');
INSERT INTO 'tune' VALUES (6749, NULL, '2012-01-20 12:54:42.21997+00', 'Cherish the Ladies', 2147, '');
INSERT INTO 'tune' VALUES (6750, NULL, '2012-01-20 12:54:42.222863+00', 'Wood Duck, The', 2426, '');
INSERT INTO 'tune' VALUES (6751, NULL, '2012-01-20 12:54:42.225739+00', '92nd''s Farewell to Aberdeen, The', 9998, '');
INSERT INTO 'tune' VALUES (6752, NULL, '2012-01-20 12:54:42.228636+00', 'Bellman''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (6753, NULL, '2012-01-20 12:54:42.231527+00', 'Happy Farmer', 9998, '');
INSERT INTO 'tune' VALUES (6754, NULL, '2012-01-20 12:54:42.234419+00', 'Aunt May''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (6755, NULL, '2012-01-20 12:54:42.2373+00', 'Let There be Drama', 9998, '');
INSERT INTO 'tune' VALUES (6756, NULL, '2012-01-20 12:54:42.240186+00', 'Wissahickon Drive', 9998, '');
INSERT INTO 'tune' VALUES (6757, NULL, '2012-01-20 12:54:42.243071+00', 'Peter Barnes', 9998, '');
INSERT INTO 'tune' VALUES (6758, NULL, '2012-01-20 12:54:42.245962+00', 'Eddie Kelly''s', 9998, '');
INSERT INTO 'tune' VALUES (6759, '2006-02-15 23:00:00+00', '2012-01-20 12:54:42.248858+00', 'J. Wilson''s Reel', 1437, '');
INSERT INTO 'tune' VALUES (6760, NULL, '2012-01-20 12:54:42.251769+00', 'DeLong Reel', 1836, '');
INSERT INTO 'tune' VALUES (6761, NULL, '2012-01-20 12:54:42.254657+00', 'Hen''s March', 1910, '');
INSERT INTO 'tune' VALUES (6762, NULL, '2012-01-20 12:54:42.257541+00', 'Maid with the Lustrious Hair', 9999, '');
INSERT INTO 'tune' VALUES (6763, NULL, '2012-01-20 12:54:42.260429+00', 'Drumloist', 1525, '');
INSERT INTO 'tune' VALUES (6765, NULL, '2012-01-20 12:54:42.266202+00', 'Messe, Le', 1512, '');
INSERT INTO 'tune' VALUES (6766, NULL, '2012-01-20 12:54:42.269087+00', 'Bonnie Scotland', 2319, '');
INSERT INTO 'tune' VALUES (6767, NULL, '2012-01-20 12:54:42.271977+00', 'Gluss Ayre', 1535, '');
INSERT INTO 'tune' VALUES (6768, NULL, '2012-01-20 12:54:42.274862+00', 'Mary Darroch', 9999, '');
INSERT INTO 'tune' VALUES (6769, NULL, '2012-01-20 12:54:42.277779+00', 'Shoemaker, The', 9998, '');
INSERT INTO 'tune' VALUES (6770, NULL, '2012-01-20 12:54:42.280681+00', 'Queen of the South', 1668, '');
INSERT INTO 'tune' VALUES (6771, NULL, '2012-01-20 12:54:42.283575+00', 'Carnival March', 1786, '');
INSERT INTO 'tune' VALUES (6772, NULL, '2012-01-20 12:54:42.28653+00', 'Guizer''s March, The', 1786, '');
INSERT INTO 'tune' VALUES (6773, NULL, '2012-01-20 12:54:42.289421+00', 'Trowie Burn', 1753, '');
INSERT INTO 'tune' VALUES (6775, NULL, '2012-01-20 12:54:42.295259+00', 'Fetler Lullabye, The', 9999, '');
INSERT INTO 'tune' VALUES (6776, NULL, '2012-01-20 12:54:42.298132+00', 'When It''s Springtime in the Rockies', 1960, '');
INSERT INTO 'tune' VALUES (6777, NULL, '2012-01-20 12:54:42.301075+00', 'Phil the Fluter''s Ball', 1961, '');
INSERT INTO 'tune' VALUES (6778, NULL, '2012-01-20 12:54:42.303977+00', 'Lady Dorothy Stewart', 9999, '');
INSERT INTO 'tune' VALUES (6779, NULL, '2012-01-20 12:54:42.306864+00', 'Won''t You Buy Me Pretty Flowers', 9999, '');
INSERT INTO 'tune' VALUES (6780, NULL, '2012-01-20 12:54:42.309747+00', 'Oh Dear What Can the Matter Be', 9999, '');
INSERT INTO 'tune' VALUES (6782, NULL, '2012-01-20 12:54:42.315588+00', 'Flower of Love, The', 1846, '');
INSERT INTO 'tune' VALUES (6783, NULL, '2012-01-20 12:54:42.318501+00', 'Logan Water', 9999, '');
INSERT INTO 'tune' VALUES (6784, NULL, '2012-01-20 12:54:42.321393+00', 'Dominie, The', 1846, '');
INSERT INTO 'tune' VALUES (6785, NULL, '2012-01-20 12:54:42.324282+00', 'Mr & Mrs W.A. Gray', 1657, '');
INSERT INTO 'tune' VALUES (6705, NULL, '2014-11-06 17:53:10.01574+00', 'Crieff Hydro March', 1615, '');
INSERT INTO 'tune' VALUES (6786, NULL, '2012-01-20 12:54:42.327216+00', 'Mathematician, The', 1512, '');
INSERT INTO 'tune' VALUES (6787, NULL, '2012-01-20 12:54:42.330178+00', 'Culloden House', 1444, '');
INSERT INTO 'tune' VALUES (6788, NULL, '2012-01-20 12:54:42.333077+00', 'Juliana''s Jig', 1846, '');
INSERT INTO 'tune' VALUES (6789, NULL, '2012-01-20 12:54:42.335969+00', 'Teacher, The', 1846, '');
INSERT INTO 'tune' VALUES (6790, NULL, '2012-01-20 12:54:42.338874+00', 'Tea Song, The', 9999, '');
INSERT INTO 'tune' VALUES (6791, NULL, '2012-01-20 12:54:42.341758+00', 'Joiner''s Saw', 9999, '');
INSERT INTO 'tune' VALUES (6792, NULL, '2012-01-20 12:54:42.34471+00', 'Grays of Cardiff, The', 1936, '');
INSERT INTO 'tune' VALUES (6793, NULL, '2012-01-20 12:54:42.347609+00', 'When Charlie Comes', 9999, '');
INSERT INTO 'tune' VALUES (6794, NULL, '2012-01-20 12:54:42.350503+00', 'Host of the Air, The', 1846, '');
INSERT INTO 'tune' VALUES (6795, NULL, '2012-01-20 12:54:42.353394+00', 'Eshaness Two-Step', 1710, '');
INSERT INTO 'tune' VALUES (6796, NULL, '2012-01-20 12:54:42.356278+00', 'Morit Lamb', 9998, '');
INSERT INTO 'tune' VALUES (6797, NULL, '2012-01-20 12:54:42.359165+00', 'Nan MacDonald', 9998, '');
INSERT INTO 'tune' VALUES (6798, NULL, '2012-01-20 12:54:42.362049+00', 'Ann Fionnghal MacDonald', 9998, '');
INSERT INTO 'tune' VALUES (6799, NULL, '2012-01-20 12:54:42.364929+00', 'Leslie Craig', 9998, '');
INSERT INTO 'tune' VALUES (6800, NULL, '2012-01-20 12:54:42.367827+00', 'Willie''s Brogues', 9998, '');
INSERT INTO 'tune' VALUES (6801, NULL, '2012-01-20 12:54:42.370733+00', 'Hugh McKenna''s Reel', 1551, '');
INSERT INTO 'tune' VALUES (6802, NULL, '2012-01-20 12:54:42.373646+00', 'Surge of the Sea', 9998, '');
INSERT INTO 'tune' VALUES (13851, '2018-03-30 08:55:55.176878+00', '2018-03-30 08:55:55.176878+00', 'Happy Tenth', 3731, '');
INSERT INTO 'tune' VALUES (6804, NULL, '2012-01-20 12:54:42.379429+00', 'Madam La Rue', 9998, '');
INSERT INTO 'tune' VALUES (6805, NULL, '2012-01-20 12:54:42.382317+00', 'Down Line from Georgemas to Wick, The', 1728, '');
INSERT INTO 'tune' VALUES (6806, NULL, '2012-01-20 12:54:42.385197+00', 'Fairy Jig, The', 1551, '');
INSERT INTO 'tune' VALUES (7250, NULL, '2012-01-20 12:54:43.732956+00', 'Eric Wallace', 2197, '');
INSERT INTO 'tune' VALUES (6807, NULL, '2012-01-20 12:54:42.388078+00', 'Ian Powrie''s Compliments to John Carmichael', 1551, '');
INSERT INTO 'tune' VALUES (6808, NULL, '2012-01-20 12:54:42.390967+00', 'Pipe Major J. K. Cairn''s Retreat', 2443, '');
INSERT INTO 'tune' VALUES (6810, NULL, '2012-01-20 12:54:42.396747+00', 'Major Campbell Graham, M.B.E.', 9998, '');
INSERT INTO 'tune' VALUES (6811, NULL, '2012-01-20 12:54:42.399631+00', 'Indifference', 9998, '');
INSERT INTO 'tune' VALUES (6813, NULL, '2012-01-20 12:54:42.405405+00', 'General Sir Michael Gow''s Farewell to Edinburgh Castle', 9998, '');
INSERT INTO 'tune' VALUES (6814, NULL, '2012-01-20 12:54:42.408284+00', 'Jimmy Lindsay of Glenalmond', 9998, '');
INSERT INTO 'tune' VALUES (6815, NULL, '2012-01-20 12:54:42.411197+00', 'Jimmy Boyce''s Fancy', 9998, '');
INSERT INTO 'tune' VALUES (6816, NULL, '2012-01-20 12:54:42.414079+00', 'Fittie Boatman, The', 9998, '');
INSERT INTO 'tune' VALUES (6817, NULL, '2012-01-20 12:54:42.416998+00', 'Kiwi Hornpipe, The', 9998, '');
INSERT INTO 'tune' VALUES (6818, NULL, '2012-01-20 12:54:42.419898+00', 'Curlew, The', 2377, '');
INSERT INTO 'tune' VALUES (6819, NULL, '2012-01-20 12:54:42.422793+00', 'Miller''s Fair Daughter, The', 9998, '');
INSERT INTO 'tune' VALUES (6820, NULL, '2012-01-20 12:54:42.425688+00', 'Jimmy Burgess Two-Step', 1527, '');
INSERT INTO 'tune' VALUES (6821, NULL, '2012-01-20 12:54:42.428572+00', 'Mrs Betty MacPhail of Kilberry', 1527, '');
INSERT INTO 'tune' VALUES (6822, NULL, '2012-01-20 12:54:42.431482+00', 'Land of My Youth', 1700, '');
INSERT INTO 'tune' VALUES (6823, NULL, '2012-01-20 12:54:42.434375+00', 'Loch Maree', 1699, '');
INSERT INTO 'tune' VALUES (6824, NULL, '2012-01-20 12:54:42.437259+00', 'Moray River Jig', 2257, '');
INSERT INTO 'tune' VALUES (6825, NULL, '2012-01-20 12:54:42.440147+00', 'Ett Sensommarminne', 2444, '');
INSERT INTO 'tune' VALUES (6826, NULL, '2012-01-20 12:54:42.443041+00', 'Bel Viso', 2346, '');
INSERT INTO 'tune' VALUES (6827, NULL, '2012-01-20 12:54:42.445924+00', 'Killarney', 9999, '');
INSERT INTO 'tune' VALUES (6828, NULL, '2012-01-20 12:54:42.448814+00', 'Jeannie''s Black E''e', 9999, '');
INSERT INTO 'tune' VALUES (6829, NULL, '2012-01-20 12:54:42.451699+00', 'Hey! Look Me Over', 2445, '');
INSERT INTO 'tune' VALUES (6830, NULL, '2012-01-20 12:54:42.454579+00', 'Consider Yourself One of Us', 2446, '');
INSERT INTO 'tune' VALUES (6831, NULL, '2012-01-20 12:54:42.457456+00', 'Christina''s Waltz', 1527, '');
INSERT INTO 'tune' VALUES (6832, NULL, '2012-01-20 12:54:42.460343+00', 'Carol''s Waltz', 1527, '');
INSERT INTO 'tune' VALUES (6833, NULL, '2012-01-20 12:54:42.46325+00', 'Saint Andrew''s Society of Rio de Janeiro, The', 1527, '');
INSERT INTO 'tune' VALUES (6834, NULL, '2012-01-20 12:54:42.466139+00', 'Wullie Nicholl''s Samba', 1527, '');
INSERT INTO 'tune' VALUES (6835, NULL, '2012-01-20 12:54:42.469021+00', 'Golondrina, La', 2447, '');
INSERT INTO 'tune' VALUES (6836, NULL, '2012-01-20 12:54:42.471905+00', 'Du Schwarzer Zigeuner', 2448, '');
INSERT INTO 'tune' VALUES (6837, NULL, '2012-01-20 12:54:42.474791+00', 'Oh! Donna Clara!', 2449, '');
INSERT INTO 'tune' VALUES (6838, NULL, '2012-01-20 12:54:42.47767+00', 'Alan & Elizabeth Gifford', 1527, '');
INSERT INTO 'tune' VALUES (6839, NULL, '2012-01-20 12:54:42.48055+00', 'Neil & Eileen Donald', 1527, '');
INSERT INTO 'tune' VALUES (6840, NULL, '2012-01-20 12:54:42.483435+00', 'Old Folks at Home, De', 9999, '');
INSERT INTO 'tune' VALUES (6841, NULL, '2012-01-20 12:54:42.486335+00', 'Fustra Two-Step, Da', 1527, '');
INSERT INTO 'tune' VALUES (6842, NULL, '2012-01-20 12:54:42.489223+00', 'Wullie Black - Half Dan of Brouster', 1527, '');
INSERT INTO 'tune' VALUES (6843, NULL, '2012-01-20 12:54:42.492107+00', 'Balindean Castle', 9999, '');
INSERT INTO 'tune' VALUES (6844, NULL, '2012-01-20 12:54:42.494993+00', 'Mississippi Dip, The', 9999, '');
INSERT INTO 'tune' VALUES (6845, NULL, '2012-01-20 12:54:42.497872+00', 'Anchors Aweigh', 9999, '');
INSERT INTO 'tune' VALUES (6847, NULL, '2012-01-20 12:54:42.503644+00', 'Hughsons of Sandwick, The', 1527, '');
INSERT INTO 'tune' VALUES (6848, NULL, '2012-01-20 12:54:42.506525+00', 'Iain MacPhail''s Compliments to the Late John Gibson', 1527, '');
INSERT INTO 'tune' VALUES (6809, NULL, '2013-02-05 15:18:43.337803+00', 'Festival March, The', 10740, '');
INSERT INTO 'tune' VALUES (6849, NULL, '2012-01-20 12:54:42.509409+00', 'Fiona MacPhail''s Twostep', 1527, '');
INSERT INTO 'tune' VALUES (6850, NULL, '2012-01-20 12:54:42.512298+00', 'Raasay House', 2638, '');
INSERT INTO 'tune' VALUES (6851, NULL, '2012-01-20 12:54:42.515186+00', 'Hunting Boys, The', 9999, '');
INSERT INTO 'tune' VALUES (6852, NULL, '2012-01-20 12:54:42.518064+00', 'Grange Loan', 1525, '');
INSERT INTO 'tune' VALUES (6853, NULL, '2012-01-20 12:54:42.520966+00', 'Andrew Rankine''s Compliments to Jimmy Clinkscale', 1533, '');
INSERT INTO 'tune' VALUES (6854, NULL, '2012-01-20 12:54:42.523917+00', 'Kinconnel Lea', 9998, '');
INSERT INTO 'tune' VALUES (6855, NULL, '2012-01-20 12:54:42.527018+00', 'Keilder Waltz, The', 2453, '');
INSERT INTO 'tune' VALUES (6856, NULL, '2012-01-20 12:54:42.529962+00', 'Kilberry Bay', 1527, '');
INSERT INTO 'tune' VALUES (6857, NULL, '2012-01-20 12:54:42.532854+00', 'Reel of the MacPhails, The', 1527, '');
INSERT INTO 'tune' VALUES (6858, NULL, '2012-01-20 12:54:42.535799+00', 'Solskenvalsen', 9998, '');
INSERT INTO 'tune' VALUES (6859, NULL, '2012-01-20 12:54:42.538702+00', 'Lovely Polly Stewart', 9999, '');
INSERT INTO 'tune' VALUES (6861, NULL, '2012-01-20 12:54:42.544483+00', 'Mrs E M Ross''s Welcome', 1512, '');
INSERT INTO 'tune' VALUES (6862, NULL, '2012-01-20 12:54:42.547377+00', 'Mrs James McInnes, Edinburgh', 1516, '');
INSERT INTO 'tune' VALUES (6863, NULL, '2012-01-20 12:54:42.550276+00', 'Captain Frank Thomson, Crieff Golf Club', 1615, '');
INSERT INTO 'tune' VALUES (6864, NULL, '2012-01-20 12:54:42.553175+00', 'Bill Craig''s Jig', 1615, '');
INSERT INTO 'tune' VALUES (6866, NULL, '2012-01-20 12:54:42.558972+00', 'Miss Barbara Stewart, West Park, Elgin', 1516, '');
INSERT INTO 'tune' VALUES (6867, NULL, '2012-01-20 12:54:42.561863+00', 'An I''ll Awa'' to Bonny Tweedside', 9999, '');
INSERT INTO 'tune' VALUES (6868, NULL, '2012-01-20 12:54:42.564793+00', 'Sir Walter Scott', 1903, '');
INSERT INTO 'tune' VALUES (6869, NULL, '2012-01-20 12:54:42.567692+00', 'Bethena', 2457, '');
INSERT INTO 'tune' VALUES (6870, NULL, '2012-01-20 12:54:42.570675+00', 'Golliwog''s Cakewalk', 2458, '');
INSERT INTO 'tune' VALUES (6871, NULL, '2012-01-20 12:54:42.57359+00', '51st Division at Beaumont Hamel, The', 9999, '');
INSERT INTO 'tune' VALUES (6872, NULL, '2012-01-20 12:54:42.576494+00', 'Scottish Division, The', 2459, '');
INSERT INTO 'tune' VALUES (6873, NULL, '2012-01-20 12:54:42.57938+00', 'Glen Patrick', 9999, '');
INSERT INTO 'tune' VALUES (6875, NULL, '2012-01-20 12:54:42.585174+00', 'Glasgow - City of Culture 1990', 1585, '');
INSERT INTO 'tune' VALUES (6877, NULL, '2012-01-20 12:54:42.590982+00', 'Bonnie Black Isle, The', 2460, '');
INSERT INTO 'tune' VALUES (6878, NULL, '2012-01-20 12:54:42.593864+00', 'Fagail Brorraidl', 1775, '');
INSERT INTO 'tune' VALUES (6879, NULL, '2012-01-20 12:54:42.596753+00', 'Fagail Liosmor', 2461, '');
INSERT INTO 'tune' VALUES (6880, NULL, '2012-01-20 12:54:42.599641+00', 'Mi Seo ''Nam Aonar', 1935, '');
INSERT INTO 'tune' VALUES (6881, NULL, '2012-01-20 12:54:42.602525+00', 'Northlands, The', 9999, '');
INSERT INTO 'tune' VALUES (6882, NULL, '2012-01-20 12:54:42.605413+00', 'Provost of Forgandenny, The', 1585, '');
INSERT INTO 'tune' VALUES (6883, NULL, '2012-01-20 12:54:42.608303+00', 'Jimmy''s Aye Diggin''', 1554, '');
INSERT INTO 'tune' VALUES (6884, NULL, '2012-01-20 12:54:42.619614+00', 'Palais Glide, The', 9999, '');
INSERT INTO 'tune' VALUES (6885, NULL, '2012-01-20 12:54:42.623878+00', 'Waverley Polka, The', 1668, '');
INSERT INTO 'tune' VALUES (6886, NULL, '2012-01-20 12:54:42.627834+00', 'Gleann Bhaile Chaoil', 9999, '');
INSERT INTO 'tune' VALUES (6887, NULL, '2012-01-20 12:54:42.632288+00', 'Our Norrie', 1585, '');
INSERT INTO 'tune' VALUES (6888, NULL, '2012-01-20 12:54:42.636253+00', '80th Regiment (Scottish Horse), The', 1580, '');
INSERT INTO 'tune' VALUES (6889, NULL, '2012-01-20 12:54:42.640609+00', 'Memory Waltz, The', 9999, '');
INSERT INTO 'tune' VALUES (6890, NULL, '2012-01-20 12:54:42.644762+00', 'Sildevalsen', 9999, '');
INSERT INTO 'tune' VALUES (6846, NULL, '2014-08-24 14:57:27.200731+00', 'Dam Busters March, The', 10988, '');
INSERT INTO 'tune' VALUES (6891, NULL, '2012-01-20 12:54:42.647952+00', 'Kvaesarvalsen', 9999, '');
INSERT INTO 'tune' VALUES (6892, NULL, '2012-01-20 12:54:42.650943+00', 'Swarta Rudolf', 9999, '');
INSERT INTO 'tune' VALUES (6893, NULL, '2012-01-20 12:54:42.653841+00', 'Avants, Les', 1580, '');
INSERT INTO 'tune' VALUES (6894, NULL, '2012-01-20 12:54:42.657108+00', 'Robert Murphy''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (6895, NULL, '2012-01-20 12:54:42.660207+00', 'G S Coutts of Scourgure', 9998, '');
INSERT INTO 'tune' VALUES (6896, NULL, '2012-01-20 12:54:42.66314+00', 'Hills of Moffat, The', 2227, '');
INSERT INTO 'tune' VALUES (6897, NULL, '2012-01-20 12:54:42.666027+00', 'Ma Nannie''s Awa', 9998, '');
INSERT INTO 'tune' VALUES (6898, NULL, '2012-01-20 12:54:42.668918+00', 'Balmoral Highlanders, The', 2478, '');
INSERT INTO 'tune' VALUES (6900, NULL, '2012-01-20 12:54:42.674802+00', 'Ouvie Avia', 9999, '');
INSERT INTO 'tune' VALUES (6901, NULL, '2012-01-20 12:54:42.677692+00', 'Briar Bush, The', 9999, '');
INSERT INTO 'tune' VALUES (6902, NULL, '2012-01-20 12:54:42.680576+00', 'Two Highland Airs', 9999, '');
INSERT INTO 'tune' VALUES (6903, NULL, '2012-01-20 12:54:42.683471+00', 'Nighean Donn Nan Cuailean Riomach', 9999, '');
INSERT INTO 'tune' VALUES (6904, NULL, '2012-01-20 12:54:42.686542+00', 'Lia Ora', 9999, '');
INSERT INTO 'tune' VALUES (6905, NULL, '2012-01-20 12:54:42.689451+00', 'Miss M. H. Alexander', 2175, '');
INSERT INTO 'tune' VALUES (6906, NULL, '2012-01-20 12:54:42.692369+00', 'She Moved Through the Fair', 9999, '');
INSERT INTO 'tune' VALUES (6907, NULL, '2012-01-20 12:54:42.695265+00', 'Jacqueline Waltz', 1806, '');
INSERT INTO 'tune' VALUES (6908, NULL, '2012-01-20 12:54:42.698162+00', 'Fear A'' Bhata', 9999, '');
INSERT INTO 'tune' VALUES (6909, NULL, '2012-01-20 12:54:42.701052+00', 'Buachaille Etive Mor', 1896, '');
INSERT INTO 'tune' VALUES (6911, NULL, '2012-01-20 12:54:42.706841+00', 'Winter Draws On', 2272, '');
INSERT INTO 'tune' VALUES (6912, NULL, '2012-01-20 12:54:42.70973+00', 'Hey for the Hielan'' Laddie', 9999, '');
INSERT INTO 'tune' VALUES (6913, NULL, '2012-01-20 12:54:42.712699+00', 'Reel of the Blackcocks, The', 9999, '');
INSERT INTO 'tune' VALUES (6876, NULL, '2022-07-27 21:04:17.469357+00', 'Forth Bridge, The - Reel', 1427, '');
INSERT INTO 'tune' VALUES (6910, NULL, '2023-01-24 21:58:39.780121+00', 'Cutting Bracken', 9998, 'Same as <<ddt:Pulling Bracken#1485>>. To be confirmed and merged?');
INSERT INTO 'tune' VALUES (6914, NULL, '2012-01-20 12:54:42.715602+00', 'Brose and Butter', 9998, '');
INSERT INTO 'tune' VALUES (6915, NULL, '2012-01-20 12:54:42.7185+00', 'Far Awa'' Wedding, The', 9998, '');
INSERT INTO 'tune' VALUES (6916, NULL, '2012-01-20 12:54:42.721391+00', 'Blackcock''s Feather', 1473, '');
INSERT INTO 'tune' VALUES (6917, NULL, '2012-01-20 12:54:42.724277+00', 'Wyn''s Fancy', 1473, '');
INSERT INTO 'tune' VALUES (6918, NULL, '2012-01-20 12:54:42.727186+00', 'Humble Woods', 1473, '');
INSERT INTO 'tune' VALUES (6919, NULL, '2012-01-20 12:54:42.73008+00', 'Drumossie Muir', 1473, '');
INSERT INTO 'tune' VALUES (6920, NULL, '2012-01-20 12:54:42.733109+00', 'Night in Shieldaig, A', 1473, '');
INSERT INTO 'tune' VALUES (6921, NULL, '2012-01-20 12:54:42.736001+00', 'Kepposh Hill', 1473, '');
INSERT INTO 'tune' VALUES (6922, NULL, '2012-01-20 12:54:42.739048+00', 'Mount Stuart House', 1598, '');
INSERT INTO 'tune' VALUES (6923, NULL, '2012-01-20 12:54:42.741971+00', 'Konfetti Valse', 2463, '');
INSERT INTO 'tune' VALUES (6924, NULL, '2012-01-20 12:54:42.745095+00', 'Waters of Kylesku', 2637, '');
INSERT INTO 'tune' VALUES (6925, NULL, '2012-01-20 12:54:42.748026+00', 'Accordion Banter Polka', 2464, '');
INSERT INTO 'tune' VALUES (6926, NULL, '2012-01-20 12:54:42.750985+00', 'Norman Orr Ewing', 9999, '');
INSERT INTO 'tune' VALUES (6927, NULL, '2012-01-20 12:54:42.75391+00', 'Linda McFarlane', 1771, '');
INSERT INTO 'tune' VALUES (6928, NULL, '2012-01-20 12:54:42.756809+00', 'Miss Judith Robertson', 1590, '');
INSERT INTO 'tune' VALUES (6929, NULL, '2012-01-20 12:54:42.759704+00', 'Jerry''s Beaver Hat', 9999, '');
INSERT INTO 'tune' VALUES (6930, NULL, '2012-01-20 12:54:42.762764+00', 'Merry Harriers, The', 9999, '');
INSERT INTO 'tune' VALUES (6931, NULL, '2012-01-20 12:54:42.765709+00', 'Newbury Caledonian Society', 1590, '');
INSERT INTO 'tune' VALUES (6932, NULL, '2012-01-20 12:54:42.768611+00', 'Gordon Castle', 1516, '');
INSERT INTO 'tune' VALUES (6933, NULL, '2012-01-20 12:54:42.771723+00', 'Saint Andrew''s Lhanbryde Bicentenary', 1634, '');
INSERT INTO 'tune' VALUES (6934, NULL, '2012-01-20 12:54:42.774672+00', 'J R Coutts', 9998, '');
INSERT INTO 'tune' VALUES (6935, NULL, '2012-01-20 12:54:42.777568+00', 'Forefit o'' da Ship, Da', 9998, '');
INSERT INTO 'tune' VALUES (6936, NULL, '2012-01-20 12:54:42.781451+00', 'Hielandman, Da', 9999, '');
INSERT INTO 'tune' VALUES (6938, NULL, '2012-01-20 12:54:42.787396+00', 'Darling Darcy', 1763, '');
INSERT INTO 'tune' VALUES (6939, NULL, '2012-01-20 12:54:42.790292+00', 'I''m a Rover', 9999, '');
INSERT INTO 'tune' VALUES (6940, NULL, '2012-01-20 12:54:42.793302+00', 'Shira ''s Jig', 1551, '');
INSERT INTO 'tune' VALUES (6941, NULL, '2012-01-20 12:54:42.796215+00', 'Kelso Polka, The', 9998, '');
INSERT INTO 'tune' VALUES (6942, NULL, '2012-01-20 12:54:42.799113+00', 'Lament for Will Starr', 1554, '');
INSERT INTO 'tune' VALUES (6943, NULL, '2012-01-20 12:54:42.802012+00', 'Young King, The', 1512, '');
INSERT INTO 'tune' VALUES (6944, NULL, '2012-01-20 12:54:42.804938+00', 'Mickey''s Fancy', 2279, '');
INSERT INTO 'tune' VALUES (6946, NULL, '2012-01-20 12:54:42.810809+00', 'Longwise Eightsome Reel', 2484, '');
INSERT INTO 'tune' VALUES (6947, NULL, '2012-01-20 12:54:42.813811+00', 'Carnegie''s March', 2485, '');
INSERT INTO 'tune' VALUES (6948, NULL, '2012-01-20 12:54:42.816734+00', 'Trip to Ponca City', 1862, '');
INSERT INTO 'tune' VALUES (6949, NULL, '2012-01-20 12:54:42.819628+00', 'Miss Morag Alexander', 1525, '');
INSERT INTO 'tune' VALUES (6950, NULL, '2012-01-20 12:54:42.822522+00', 'Toby', 2522, '');
INSERT INTO 'tune' VALUES (6951, NULL, '2012-01-20 12:54:42.825493+00', 'Grand Prix Circuit, The', 1534, '');
INSERT INTO 'tune' VALUES (6952, NULL, '2012-01-20 12:54:42.828441+00', 'Jarabe Tapatio', 9998, '');
INSERT INTO 'tune' VALUES (6953, NULL, '2012-01-20 12:54:42.831336+00', 'Makin'' The Tartan', 1586, '');
INSERT INTO 'tune' VALUES (6954, NULL, '2012-01-20 12:54:42.834292+00', 'Willie Atkinson''s Hornpipe', 1558, '');
INSERT INTO 'tune' VALUES (6955, NULL, '2012-01-20 12:54:42.837235+00', 'Rothbury Hills', 1742, '');
INSERT INTO 'tune' VALUES (6957, NULL, '2012-01-20 12:54:42.843018+00', 'Whittingham Green Lane', 9998, '');
INSERT INTO 'tune' VALUES (6958, NULL, '2012-01-20 12:54:42.8459+00', 'Waters of Tyne', 9998, '');
INSERT INTO 'tune' VALUES (6959, NULL, '2012-01-20 12:54:42.848784+00', 'Bonnie Cragside', 1947, '');
INSERT INTO 'tune' VALUES (6960, NULL, '2012-01-20 12:54:42.851734+00', 'Nancy', 9999, '');
INSERT INTO 'tune' VALUES (6961, NULL, '2012-01-20 12:54:42.854729+00', 'Jane''s Fancy', 2157, '');
INSERT INTO 'tune' VALUES (6962, NULL, '2012-01-20 12:54:42.857626+00', 'Boys of Wexford, The', 9999, '');
INSERT INTO 'tune' VALUES (6963, NULL, '2012-01-20 12:54:42.860527+00', 'Winister Gallop', 9999, '');
INSERT INTO 'tune' VALUES (6964, NULL, '2012-01-20 12:54:42.863425+00', 'Ormskirk Country Dance Club', 1558, '');
INSERT INTO 'tune' VALUES (6965, NULL, '2012-01-20 12:54:42.866327+00', 'Early in the Morning', 9998, '');
INSERT INTO 'tune' VALUES (6966, NULL, '2012-01-20 12:54:42.869613+00', 'Briars of Newbay, The', 9999, '');
INSERT INTO 'tune' VALUES (6967, NULL, '2012-01-20 12:54:42.872677+00', 'Skillet, The', 9999, '');
INSERT INTO 'tune' VALUES (6968, NULL, '2012-01-20 12:54:42.875695+00', 'Father O'' Carroll', 9999, '');
INSERT INTO 'tune' VALUES (6970, NULL, '2012-01-20 12:54:42.881541+00', 'Bugle Call, The', 1567, '');
INSERT INTO 'tune' VALUES (6971, NULL, '2012-01-20 12:54:42.884433+00', 'David Tague''s Whistler', 2085, '');
INSERT INTO 'tune' VALUES (6972, NULL, '2012-01-20 12:54:42.887553+00', 'Irishman''s Heart to the Ladies', 9999, '');
INSERT INTO 'tune' VALUES (6973, NULL, '2012-01-20 12:54:42.890483+00', 'Vienna, City of My Dreams', 2490, '');
INSERT INTO 'tune' VALUES (6974, NULL, '2012-01-20 12:54:42.893378+00', 'Merry Widow Waltz, The', 2491, '');
INSERT INTO 'tune' VALUES (6975, NULL, '2012-01-20 12:54:42.896341+00', 'Clarinet Polka, The', 9999, '');
INSERT INTO 'tune' VALUES (6976, NULL, '2012-01-20 12:54:42.899241+00', 'Royal Empress Tango, The', 2493, '');
INSERT INTO 'tune' VALUES (6977, NULL, '2012-01-20 12:54:42.902132+00', 'Wilson & Doris Richardson', 1593, '');
INSERT INTO 'tune' VALUES (6978, NULL, '2012-01-20 12:54:42.9052+00', 'Prince Albert''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (6979, NULL, '2012-01-20 12:54:42.908097+00', 'One-Legged Man, The', 9999, '');
INSERT INTO 'tune' VALUES (6980, NULL, '2012-01-20 12:54:42.911006+00', 'Christine McCann Gauthier', 2234, '');
INSERT INTO 'tune' VALUES (6981, NULL, '2012-01-20 12:54:42.913897+00', 'Christine (The Bash!)', 2085, '');
INSERT INTO 'tune' VALUES (6982, NULL, '2012-01-20 12:54:42.917138+00', 'Down at the Old Bull and Bush', 2496, '');
INSERT INTO 'tune' VALUES (6983, NULL, '2012-01-20 12:54:42.920085+00', 'After the Ball', 2494, '');
INSERT INTO 'tune' VALUES (6984, NULL, '2012-01-20 12:54:42.92298+00', 'Bless ''Em All', 2495, '');
INSERT INTO 'tune' VALUES (6985, NULL, '2012-01-20 12:54:42.925867+00', 'Now is the Hour', 9999, '');
INSERT INTO 'tune' VALUES (6986, NULL, '2012-01-20 12:54:42.928781+00', 'Amazing Grace', 9999, '');
INSERT INTO 'tune' VALUES (6987, NULL, '2012-01-20 12:54:42.931678+00', 'Killworth Hills', 1699, '');
INSERT INTO 'tune' VALUES (6988, NULL, '2012-01-20 12:54:42.934567+00', 'Tom McHale''s March', 9999, '');
INSERT INTO 'tune' VALUES (6989, NULL, '2012-01-20 12:54:42.93753+00', 'Atholl Highlanders'' March to Taymouth, The', 9999, '');
INSERT INTO 'tune' VALUES (6990, NULL, '2012-01-20 12:54:42.940434+00', 'Mull Emigrant''s Farewell, The', 2497, '');
INSERT INTO 'tune' VALUES (13852, '2018-03-30 08:59:30.17679+00', '2018-12-11 18:15:15.251348+00', 'Georgian Strathspey', 11762, '');
INSERT INTO 'tune' VALUES (6991, NULL, '2012-01-20 12:54:42.944083+00', 'Hebridean Sunset', 2499, '');
INSERT INTO 'tune' VALUES (6992, NULL, '2012-01-20 12:54:42.94701+00', 'Isle of Iona, The', 2500, '');
INSERT INTO 'tune' VALUES (6993, NULL, '2012-01-20 12:54:42.949968+00', 'Charlie Hunter', 1505, '');
INSERT INTO 'tune' VALUES (6994, NULL, '2012-01-20 12:54:42.952872+00', 'Baron''s Heir', 2506, '');
INSERT INTO 'tune' VALUES (6995, NULL, '2012-01-20 12:54:42.955926+00', 'Mrs Elizabeth Beaton', 1596, '');
INSERT INTO 'tune' VALUES (6996, NULL, '2012-01-20 12:54:42.959048+00', 'Roderick B. MacDiarmid', 1596, '');
INSERT INTO 'tune' VALUES (6997, NULL, '2012-01-20 12:54:42.961954+00', 'Heiland Lassie', 2508, '');
INSERT INTO 'tune' VALUES (6998, NULL, '2012-01-20 12:54:42.964845+00', 'Dreaming of Home', 9998, '');
INSERT INTO 'tune' VALUES (6999, NULL, '2012-01-20 12:54:42.967743+00', 'Kinpurnie Hill', 2509, '');
INSERT INTO 'tune' VALUES (7000, NULL, '2012-01-20 12:54:42.970644+00', 'McKenna''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (7001, NULL, '2012-01-20 12:54:42.973535+00', 'Bunch of Currants, The', 9999, '');
INSERT INTO 'tune' VALUES (13853, '2018-03-30 09:04:36.531903+00', '2018-03-30 09:04:36.531903+00', 'Judie''s Farewell', 11614, '');
INSERT INTO 'tune' VALUES (7003, NULL, '2012-01-20 12:54:42.990184+00', 'Kissin'' in the Dark', 1523, '');
INSERT INTO 'tune' VALUES (7004, NULL, '2012-01-20 12:54:42.994104+00', 'Crooked Pool, The', 2208, '');
INSERT INTO 'tune' VALUES (7005, NULL, '2012-01-20 12:54:42.99799+00', 'Stella''s Jig', 2512, '');
INSERT INTO 'tune' VALUES (7006, NULL, '2012-01-20 12:54:43.001172+00', 'Bedstefars Walsen', 2513, '');
INSERT INTO 'tune' VALUES (7007, NULL, '2012-01-20 12:54:43.00408+00', 'Donald Clerk of Meigle', 2208, '');
INSERT INTO 'tune' VALUES (7009, NULL, '2012-01-20 12:54:43.009883+00', 'Roberta Buckel''s Strathspey', 2208, '');
INSERT INTO 'tune' VALUES (7010, NULL, '2012-01-20 12:54:43.013412+00', 'Sergeant Major, The', 2514, '');
INSERT INTO 'tune' VALUES (7011, NULL, '2012-01-20 12:54:43.016387+00', 'Cod End, The', 2515, '');
INSERT INTO 'tune' VALUES (7012, NULL, '2012-01-20 12:54:43.019606+00', 'Hark the Hour of Ten is Sounding', 1900, '');
INSERT INTO 'tune' VALUES (7013, NULL, '2012-01-20 12:54:43.022618+00', 'Judges Song, The', 1900, '');
INSERT INTO 'tune' VALUES (7014, NULL, '2012-01-20 12:54:43.025549+00', 'Now Jurymen, Hear My Advice', 1900, '');
INSERT INTO 'tune' VALUES (7015, NULL, '2012-01-20 12:54:43.028465+00', 'Ian Stewart Cruikshanks', 1558, '');
INSERT INTO 'tune' VALUES (7016, NULL, '2012-01-20 12:54:43.03146+00', 'Donald Ferrier of Kirkton of Glenisla', 1550, '');
INSERT INTO 'tune' VALUES (7017, NULL, '2012-01-20 12:54:43.034375+00', 'Peerie Jim', 2516, '');
INSERT INTO 'tune' VALUES (7018, NULL, '2012-01-20 12:54:43.03727+00', 'Miss Sarah Linghard', 2516, '');
INSERT INTO 'tune' VALUES (7019, NULL, '2012-01-20 12:54:43.040173+00', 'Elizabeth Harper Sturrock', 2517, '');
INSERT INTO 'tune' VALUES (7020, NULL, '2012-01-20 12:54:43.044195+00', 'Haste ye back', 2518, '');
INSERT INTO 'tune' VALUES (7021, NULL, '2012-01-20 12:54:43.047137+00', 'Traditional Irish Air', 9999, '');
INSERT INTO 'tune' VALUES (7023, NULL, '2012-01-20 12:54:43.052932+00', 'Culburnie Cottage', 1782, '');
INSERT INTO 'tune' VALUES (7024, NULL, '2012-01-20 12:54:43.055944+00', 'Louis Waltz', 9999, '');
INSERT INTO 'tune' VALUES (7026, NULL, '2012-01-20 12:54:43.06228+00', 'Arran Boat, The', 9999, '');
INSERT INTO 'tune' VALUES (7027, NULL, '2012-01-20 12:54:43.065402+00', 'Song of the Sea, The', 1950, '');
INSERT INTO 'tune' VALUES (7028, NULL, '2012-01-20 12:54:43.069651+00', 'Chicane, The', 2523, '');
INSERT INTO 'tune' VALUES (7029, NULL, '2012-01-20 12:54:43.073283+00', 'Kilt and Crash Helmet, The', 1824, '');
INSERT INTO 'tune' VALUES (13898, '2018-06-09 21:19:01.096435+00', '2018-06-09 21:19:01.096435+00', 'Stuart''s Road', 3436, '');
INSERT INTO 'tune' VALUES (7031, NULL, '2012-01-20 12:54:43.084898+00', 'Pure Scotch Two-Step', 1525, '');
INSERT INTO 'tune' VALUES (7032, NULL, '2012-01-20 12:54:43.087944+00', 'Forres Accordion & Fiddle Club', 9998, '');
INSERT INTO 'tune' VALUES (7033, NULL, '2012-01-20 12:54:43.090905+00', 'Royal Burgh Forres'' Wlcm to Citizens of Vienenburg', 2530, '');
INSERT INTO 'tune' VALUES (7034, NULL, '2012-01-20 12:54:43.093856+00', 'Douglas James Anderson', 2172, '');
INSERT INTO 'tune' VALUES (7035, NULL, '2012-01-20 12:54:43.096819+00', 'Mr & Mrs Sandy Hall', 1811, '');
INSERT INTO 'tune' VALUES (7036, NULL, '2012-01-20 12:54:43.099818+00', 'Maureen & Neil''s Waltz', 2530, '');
INSERT INTO 'tune' VALUES (7037, NULL, '2012-01-20 12:54:43.103088+00', 'Waltz for Janet', 2172, '');
INSERT INTO 'tune' VALUES (7038, NULL, '2012-01-20 12:54:43.106052+00', 'Ruby Wedding W & M Brian', 2531, '');
INSERT INTO 'tune' VALUES (7039, NULL, '2012-01-20 12:54:43.109948+00', 'Gordon Jamieson''s Reel', 2532, '');
INSERT INTO 'tune' VALUES (7040, NULL, '2012-01-20 12:54:43.113316+00', 'Fiddlehead Reel', 2199, '');
INSERT INTO 'tune' VALUES (7041, NULL, '2012-01-20 12:54:43.116514+00', 'Old Mud Cabin, The', 9998, '');
INSERT INTO 'tune' VALUES (7042, NULL, '2012-01-20 12:54:43.119593+00', 'Alan Clark''s Reel', 1646, '');
INSERT INTO 'tune' VALUES (7043, NULL, '2012-01-20 12:54:43.122948+00', 'For Ireland I''ll Not Tell Her Name', 9999, '');
INSERT INTO 'tune' VALUES (7044, NULL, '2012-01-20 12:54:43.126745+00', 'Jimmy & Anne Shand''s Golden Wedding Two-Step', 2226, '');
INSERT INTO 'tune' VALUES (7045, NULL, '2012-01-20 12:54:43.129812+00', 'Perles d''Accordeon', 2535, '');
INSERT INTO 'tune' VALUES (7046, NULL, '2012-01-20 12:54:43.132911+00', 'Drunken Sailor, The', 9999, '');
INSERT INTO 'tune' VALUES (7047, NULL, '2012-01-20 12:54:43.135829+00', 'Sands of Kuwait', 2536, '');
INSERT INTO 'tune' VALUES (7048, NULL, '2012-01-20 12:54:43.138727+00', 'Gordon''s Home, The', 2537, '');
INSERT INTO 'tune' VALUES (7049, NULL, '2012-01-20 12:54:43.141622+00', 'Captain Alex M Fraser', 1684, '');
INSERT INTO 'tune' VALUES (7050, NULL, '2012-01-20 12:54:43.144592+00', 'Stonehouse Jig, The', 9998, '');
INSERT INTO 'tune' VALUES (7051, NULL, '2012-01-20 12:54:43.147498+00', 'Border Reel', 1673, '');
INSERT INTO 'tune' VALUES (7052, NULL, '2012-01-20 12:54:43.150393+00', 'Patrick McGovern', 2539, '');
INSERT INTO 'tune' VALUES (7053, NULL, '2012-01-20 12:54:43.153276+00', 'Shorthouse Waltz', 2286, '');
INSERT INTO 'tune' VALUES (7054, NULL, '2012-01-20 12:54:43.156176+00', 'Expedition, The', 2318, '');
INSERT INTO 'tune' VALUES (7055, NULL, '2012-01-20 12:54:43.15907+00', 'Davie Davidson', 1505, '');
INSERT INTO 'tune' VALUES (7056, NULL, '2012-01-20 12:54:43.161964+00', 'Morayshire Reel', 1745, '');
INSERT INTO 'tune' VALUES (13908, '2018-06-09 22:24:37.866126+00', '2018-06-09 22:24:37.866126+00', 'Tom Reid''s Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (7059, NULL, '2012-01-20 12:54:43.170725+00', 'Academy Jig', 9999, '');
INSERT INTO 'tune' VALUES (7060, NULL, '2012-01-20 12:54:43.173613+00', 'Archie Beaton', 1817, '');
INSERT INTO 'tune' VALUES (7061, NULL, '2012-01-20 12:54:43.176496+00', 'Curleywee', 1437, '');
INSERT INTO 'tune' VALUES (7064, NULL, '2012-01-20 12:54:43.185345+00', 'Captain Whiteside', 9998, '');
INSERT INTO 'tune' VALUES (7065, NULL, '2012-01-20 12:54:43.188267+00', 'MacDonald March', 9999, '');
INSERT INTO 'tune' VALUES (7066, NULL, '2012-01-20 12:54:43.191163+00', '72nd Highlanders Farewell to Aberdeen', 45, '');
INSERT INTO 'tune' VALUES (7067, NULL, '2012-01-20 12:54:43.194054+00', 'Audrey Cant of Craigton', 1777, '');
INSERT INTO 'tune' VALUES (7068, NULL, '2012-01-20 12:54:43.196944+00', 'Dave Crighton', 1646, '');
INSERT INTO 'tune' VALUES (7069, NULL, '2012-01-20 12:54:43.199835+00', 'Mr A. G. Wilken''s Favourite', 1512, '');
INSERT INTO 'tune' VALUES (7070, NULL, '2012-01-20 12:54:43.202735+00', 'John McCroskie''s Jig', 2239, '');
INSERT INTO 'tune' VALUES (7071, NULL, '2012-01-20 12:54:43.205698+00', 'John Rooney of Ballynahinch', 1543, '');
INSERT INTO 'tune' VALUES (7072, NULL, '2012-01-20 12:54:43.208598+00', 'David Finlay', 1668, '');
INSERT INTO 'tune' VALUES (7073, NULL, '2012-01-20 12:54:43.211495+00', 'Tony and Linda''s Reel', 1502, '');
INSERT INTO 'tune' VALUES (7074, NULL, '2012-01-20 12:54:43.214384+00', 'Miss Lynda Wood of Burnmouth', 1502, '');
INSERT INTO 'tune' VALUES (7075, NULL, '2012-01-20 12:54:43.217273+00', 'Gordon Jamieson of Cullivoe', 2534, '');
INSERT INTO 'tune' VALUES (7076, NULL, '2012-01-20 12:54:43.220166+00', 'Montfield Two-step, The', 1535, '');
INSERT INTO 'tune' VALUES (7077, NULL, '2012-01-20 12:54:43.223053+00', 'Morag Ramsey', 1597, '');
INSERT INTO 'tune' VALUES (7078, NULL, '2012-01-20 12:54:43.226015+00', 'Road and the Miles to Dundee, The', 1532, '');
INSERT INTO 'tune' VALUES (7079, NULL, '2012-01-20 12:54:43.228913+00', 'Laughing Samba, The', 2540, '');
INSERT INTO 'tune' VALUES (7080, NULL, '2012-01-20 12:54:43.231802+00', 'Mrs Lily Christie', 1426, '');
INSERT INTO 'tune' VALUES (7081, NULL, '2012-01-20 12:54:43.234686+00', 'Violets in Bloom', 1507, '');
INSERT INTO 'tune' VALUES (7082, NULL, '2012-01-20 12:54:43.237571+00', 'Side by Side', 2541, '');
INSERT INTO 'tune' VALUES (7083, NULL, '2012-01-20 12:54:43.240456+00', 'Light of Foot', 2542, '');
INSERT INTO 'tune' VALUES (7084, NULL, '2012-01-20 12:54:43.243514+00', 'Don''t Dilly Dally', 2543, '');
INSERT INTO 'tune' VALUES (7085, NULL, '2012-01-20 12:54:43.246494+00', 'Tipperary', 9999, '');
INSERT INTO 'tune' VALUES (7086, NULL, '2012-01-20 12:54:43.24938+00', 'Who Were You With Last Night?', 9999, '');
INSERT INTO 'tune' VALUES (7087, NULL, '2012-01-20 12:54:43.252263+00', 'Doonaree', 2545, '');
INSERT INTO 'tune' VALUES (7088, NULL, '2012-01-20 12:54:43.255149+00', 'Eileen o'' Grady', 9999, '');
INSERT INTO 'tune' VALUES (7089, NULL, '2012-01-20 12:54:43.258034+00', 'Come Back Paddy Reilly', 1961, '');
INSERT INTO 'tune' VALUES (7090, NULL, '2012-01-20 12:54:43.26092+00', 'Loch Maree Islands', 2546, '');
INSERT INTO 'tune' VALUES (7091, NULL, '2012-01-20 12:54:43.263812+00', 'Linzer Polka', 9999, '');
INSERT INTO 'tune' VALUES (7092, NULL, '2012-01-20 12:54:43.266705+00', 'Edgewood', 1593, '');
INSERT INTO 'tune' VALUES (7093, NULL, '2012-01-20 12:54:43.26967+00', 'Jimmy Norman', 1599, '');
INSERT INTO 'tune' VALUES (7094, NULL, '2012-01-20 12:54:43.272721+00', 'Chadwick''s Bog', 1623, '');
INSERT INTO 'tune' VALUES (7095, NULL, '2012-01-20 12:54:43.275642+00', 'Banks of Roses', 9999, '');
INSERT INTO 'tune' VALUES (7096, NULL, '2012-01-20 12:54:43.278533+00', 'Donal'' Aboc', 9999, '');
INSERT INTO 'tune' VALUES (7097, NULL, '2012-01-20 12:54:43.281728+00', 'Green Glens of Antrim, The', 2547, '');
INSERT INTO 'tune' VALUES (7099, NULL, '2012-01-20 12:54:43.288061+00', 'Angus McLeod of Auggar', 1558, '');
INSERT INTO 'tune' VALUES (7057, NULL, '2015-04-23 09:33:35.775438+00', 'Donald Manson''s Reel', 1530, '');
INSERT INTO 'tune' VALUES (7101, NULL, '2012-01-20 12:54:43.293909+00', 'Leaving Lunge', 9998, '');
INSERT INTO 'tune' VALUES (7103, NULL, '2012-01-20 12:54:43.2997+00', 'Let''s all Sing like the Birdies Sing', 9998, '');
INSERT INTO 'tune' VALUES (7104, NULL, '2012-01-20 12:54:43.302605+00', 'She''s My Sweetheart', 9998, '');
INSERT INTO 'tune' VALUES (7105, NULL, '2012-01-20 12:54:43.305642+00', 'Border Polka, The', 1522, '');
INSERT INTO 'tune' VALUES (7106, NULL, '2012-01-20 12:54:43.308624+00', 'Mairi''s', 1522, '');
INSERT INTO 'tune' VALUES (7107, NULL, '2012-01-20 12:54:43.311537+00', 'Dundee Two-Step', 1522, '');
INSERT INTO 'tune' VALUES (7108, NULL, '2012-01-20 12:54:43.314564+00', 'Mairi Ellen Ross', 1522, '');
INSERT INTO 'tune' VALUES (7109, NULL, '2012-01-20 12:54:43.317479+00', 'Out at the Meadowbank Inn', 1522, '');
INSERT INTO 'tune' VALUES (7110, NULL, '2012-01-20 12:54:43.320373+00', 'Provost of Saint Vigean''s, The', 1522, '');
INSERT INTO 'tune' VALUES (7111, NULL, '2012-01-20 12:54:43.323292+00', 'Catriona', 1522, '');
INSERT INTO 'tune' VALUES (7112, NULL, '2012-01-20 12:54:43.3262+00', '2/4 March in A', 1522, '');
INSERT INTO 'tune' VALUES (7113, NULL, '2012-01-20 12:54:43.329185+00', 'Farewell to Glenbuchat', 1522, '');
INSERT INTO 'tune' VALUES (7114, NULL, '2012-01-20 12:54:43.33208+00', 'Nellie and George', 1522, '');
INSERT INTO 'tune' VALUES (7115, NULL, '2012-01-20 12:54:43.334981+00', 'Reel in D', 1522, '');
INSERT INTO 'tune' VALUES (7116, NULL, '2012-01-20 12:54:43.337865+00', 'Reel in A', 1522, '');
INSERT INTO 'tune' VALUES (7117, NULL, '2012-01-20 12:54:43.340751+00', 'Billy Craib''s Reel', 1525, '');
INSERT INTO 'tune' VALUES (7118, NULL, '2012-01-20 12:54:43.343647+00', 'Master Craig McCallum', 1525, '');
INSERT INTO 'tune' VALUES (7119, NULL, '2012-01-20 12:54:43.346539+00', 'Banks of the Nith, The', 1525, '');
INSERT INTO 'tune' VALUES (7120, NULL, '2012-01-20 12:54:43.352209+00', 'Swedish Masquerade (alternative)', 1525, '');
INSERT INTO 'tune' VALUES (7121, NULL, '2012-01-20 12:54:43.356048+00', 'Fordlands Two-Step', 1525, '');
INSERT INTO 'tune' VALUES (7122, NULL, '2012-01-20 12:54:43.359855+00', 'Waltz for Tracey', 1525, '');
INSERT INTO 'tune' VALUES (7123, NULL, '2012-01-20 12:54:43.363672+00', 'Roddy Hamilton Esquire', 1525, '');
INSERT INTO 'tune' VALUES (7124, NULL, '2012-01-20 12:54:43.367502+00', 'Kathleen''s Tune', 1525, '');
INSERT INTO 'tune' VALUES (7125, NULL, '2012-01-20 12:54:43.370554+00', 'Miss Betty MacLean of Blair Dhu''', 1525, '');
INSERT INTO 'tune' VALUES (7126, NULL, '2012-01-20 12:54:43.373451+00', 'Cream of the Barley', 1525, '');
INSERT INTO 'tune' VALUES (7127, NULL, '2012-01-20 12:54:43.376347+00', 'Fisherrow Polka', 1525, '');
INSERT INTO 'tune' VALUES (7128, NULL, '2012-01-20 12:54:43.37924+00', 'Stewart & Kathleen Walker', 1525, '');
INSERT INTO 'tune' VALUES (7129, NULL, '2012-01-20 12:54:43.382117+00', 'Inveresk March', 1525, '');
INSERT INTO 'tune' VALUES (7130, NULL, '2012-01-20 12:54:43.385003+00', 'Green Hill, The', 1525, '');
INSERT INTO 'tune' VALUES (7131, NULL, '2012-01-20 12:54:43.387902+00', 'Jackie Clarke''s Jig', 1525, '');
INSERT INTO 'tune' VALUES (7132, NULL, '2012-01-20 12:54:43.390799+00', 'Kitchener''s Hall', 1525, '');
INSERT INTO 'tune' VALUES (7133, NULL, '2012-01-20 12:54:43.393682+00', 'Bill Hendry Esq.', 1525, '');
INSERT INTO 'tune' VALUES (7134, NULL, '2012-01-20 12:54:43.396572+00', 'Dean Brae, The', 1525, '');
INSERT INTO 'tune' VALUES (7102, NULL, '2012-10-10 22:06:34.467328+00', 'My Boy Tammy', 9999, '');
INSERT INTO 'tune' VALUES (7135, NULL, '2012-01-20 12:54:43.399461+00', 'Kiss the Train Goodbye', 1673, '');
INSERT INTO 'tune' VALUES (7136, NULL, '2012-01-20 12:54:43.402374+00', 'Andrew Gillies of Dunoon', 1653, '');
INSERT INTO 'tune' VALUES (7137, NULL, '2012-01-20 12:54:43.405261+00', 'Mountain Skies', 1773, '');
INSERT INTO 'tune' VALUES (7139, NULL, '2012-01-20 12:54:43.411048+00', 'Miss Lucy Helen Thompson', 316, '');
INSERT INTO 'tune' VALUES (7140, NULL, '2012-01-20 12:54:43.413967+00', 'Isabella Lyon''s Reel', 1657, '');
INSERT INTO 'tune' VALUES (7141, NULL, '2012-01-20 12:54:43.416865+00', 'Charlie Mullard''s Reel', 2208, '');
INSERT INTO 'tune' VALUES (7142, NULL, '2012-01-20 12:54:43.419757+00', 'Miss Diana Denoon', 2517, '');
INSERT INTO 'tune' VALUES (7143, NULL, '2012-01-20 12:54:43.422648+00', 'Purvey, The', 810, '');
INSERT INTO 'tune' VALUES (7144, NULL, '2012-01-20 12:54:43.42553+00', 'Three Kings, The', 1558, '');
INSERT INTO 'tune' VALUES (7145, NULL, '2012-01-20 12:54:43.428422+00', 'Three Brethren, The', 2556, '');
INSERT INTO 'tune' VALUES (7146, NULL, '2012-01-20 12:54:43.431329+00', 'Gordon Robertson''s Jig', 2208, '');
INSERT INTO 'tune' VALUES (7147, NULL, '2012-01-20 12:54:43.434228+00', 'Cairndale Strathspey, The', 1657, '');
INSERT INTO 'tune' VALUES (7148, NULL, '2012-01-20 12:54:43.437109+00', 'Jane Lloyd''s Reel', 2208, '');
INSERT INTO 'tune' VALUES (7149, NULL, '2012-01-20 12:54:43.439995+00', 'Jolly Dancers, The', 2516, '');
INSERT INTO 'tune' VALUES (7150, NULL, '2012-01-20 12:54:43.442886+00', 'Margaret Rowe''s Jig', 2555, '');
INSERT INTO 'tune' VALUES (7151, NULL, '2012-01-20 12:54:43.445762+00', 'North to Inverness', 810, '');
INSERT INTO 'tune' VALUES (7152, NULL, '2012-01-20 12:54:43.448663+00', 'Ben Wyvis', 316, '');
INSERT INTO 'tune' VALUES (7153, NULL, '2012-01-20 12:54:43.451548+00', 'Road to Wigan Pier, The', 316, '');
INSERT INTO 'tune' VALUES (7154, NULL, '2012-01-20 12:54:43.454441+00', 'John and Janet Martin''s Jig', 2208, '');
INSERT INTO 'tune' VALUES (7155, NULL, '2012-01-20 12:54:43.457316+00', 'Peter Straughan''s Jig', 1554, '');
INSERT INTO 'tune' VALUES (7156, NULL, '2012-01-20 12:54:43.46019+00', 'Maiden of Morven', 9999, '');
INSERT INTO 'tune' VALUES (7157, NULL, '2012-01-20 12:54:43.463078+00', 'Duchess of Edinburgh', 9999, '');
INSERT INTO 'tune' VALUES (7158, NULL, '2012-01-20 12:54:43.465958+00', 'South West Wind, The', 140, '');
INSERT INTO 'tune' VALUES (7159, NULL, '2012-01-20 12:54:43.46884+00', 'Hills of Alva', 2325, '');
INSERT INTO 'tune' VALUES (7160, NULL, '2012-01-20 12:54:43.47174+00', 'Ian Holmes'' Compliments to Jimmy Shand', 1668, '');
INSERT INTO 'tune' VALUES (7161, NULL, '2012-01-20 12:54:43.474653+00', 'Farewell to Huntly', 1512, '');
INSERT INTO 'tune' VALUES (7722, NULL, '2012-01-20 12:54:45.124739+00', 'Donegal Bay', 1203, '');
INSERT INTO 'tune' VALUES (7138, NULL, '2021-04-09 10:49:47.341595+00', 'Kathleen Dunbar''s Reel', 2555, '');
INSERT INTO 'tune' VALUES (7162, NULL, '2012-01-20 12:54:43.477532+00', 'Jubilee March, The', 1554, '');
INSERT INTO 'tune' VALUES (7163, NULL, '2012-01-20 12:54:43.480414+00', 'Miss Heather Louise Lawrie', 1543, '');
INSERT INTO 'tune' VALUES (7164, NULL, '2012-01-20 12:54:43.483465+00', 'James Simpson Hook', 1543, '');
INSERT INTO 'tune' VALUES (7165, NULL, '2012-01-20 12:54:43.486354+00', 'Jackie Dunn', 1543, '');
INSERT INTO 'tune' VALUES (7166, NULL, '2012-01-20 12:54:43.489236+00', 'Dornie Ferry', 9999, '');
INSERT INTO 'tune' VALUES (7167, NULL, '2012-01-20 12:54:43.492124+00', 'Arniston Castle', 9999, '');
INSERT INTO 'tune' VALUES (7168, NULL, '2012-01-20 12:54:43.495031+00', 'O''er the Ferry', 1737, '');
INSERT INTO 'tune' VALUES (7169, NULL, '2012-01-20 12:54:43.497912+00', 'Bridge of Gairn, The', 1748, '');
INSERT INTO 'tune' VALUES (7170, NULL, '2012-01-20 12:54:43.500816+00', 'Lord MacDuff', 1748, '');
INSERT INTO 'tune' VALUES (7171, NULL, '2012-01-20 12:54:43.503703+00', 'Shearing of the Shepherd, The', 1538, '');
INSERT INTO 'tune' VALUES (7172, NULL, '2012-01-20 12:54:43.506587+00', 'Willbergs of Rechberg', 1572, '');
INSERT INTO 'tune' VALUES (7173, NULL, '2012-01-20 12:54:43.509474+00', 'Carola Tress', 1572, '');
INSERT INTO 'tune' VALUES (7174, NULL, '2012-01-20 12:54:43.51235+00', 'Karin Schnabl', 1572, '');
INSERT INTO 'tune' VALUES (7175, NULL, '2012-01-20 12:54:43.515261+00', 'Eileen''s Waltz', 1572, '');
INSERT INTO 'tune' VALUES (7176, NULL, '2012-01-20 12:54:43.518141+00', 'Mrs Monair of ''Bruach''', 1598, '');
INSERT INTO 'tune' VALUES (7177, NULL, '2012-01-20 12:54:43.521037+00', 'Bill''s Bell-Bottoms', 1502, '');
INSERT INTO 'tune' VALUES (7178, NULL, '2012-01-20 12:54:43.523959+00', 'Ron''s Hornpipe', 1502, '');
INSERT INTO 'tune' VALUES (7179, NULL, '2012-01-20 12:54:43.526915+00', 'Tapsalteerie', 1502, '');
INSERT INTO 'tune' VALUES (7180, NULL, '2012-01-20 12:54:43.529886+00', 'Cianalas', 1502, '');
INSERT INTO 'tune' VALUES (7181, NULL, '2012-01-20 12:54:43.532785+00', 'Norma Wheeler', 2197, '');
INSERT INTO 'tune' VALUES (7182, NULL, '2012-01-20 12:54:43.535683+00', 'Sainte Placide', 1502, '');
INSERT INTO 'tune' VALUES (7183, NULL, '2012-01-20 12:54:43.538568+00', 'Moira Abernethy', 1502, '');
INSERT INTO 'tune' VALUES (7184, NULL, '2012-01-20 12:54:43.541451+00', 'Avis''s Delight', 1456, '');
INSERT INTO 'tune' VALUES (7185, NULL, '2012-01-20 12:54:43.544329+00', 'Glasgow Green', 1719, '');
INSERT INTO 'tune' VALUES (7186, NULL, '2012-01-20 12:54:43.547224+00', 'Miss Fiona Jane Forrest', 1490, '');
INSERT INTO 'tune' VALUES (7187, NULL, '2012-01-20 12:54:43.550104+00', 'Crowbull''s Fire', 1634, '');
INSERT INTO 'tune' VALUES (7188, NULL, '2012-01-20 12:54:43.553013+00', 'Nancy''s Frolic', 2565, '');
INSERT INTO 'tune' VALUES (7189, NULL, '2012-01-20 12:54:43.555913+00', 'Lieutenant Maguire''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (7190, NULL, '2012-01-20 12:54:43.558803+00', 'Mrs Elizabeth MacPhail''s Welcome to Kilberry', 1527, '');
INSERT INTO 'tune' VALUES (7191, NULL, '2012-01-20 12:54:43.561686+00', 'David John Robertson', 1527, '');
INSERT INTO 'tune' VALUES (7192, NULL, '2012-01-20 12:54:43.56457+00', 'Rights of Man, The', 9999, '');
INSERT INTO 'tune' VALUES (7193, NULL, '2012-01-20 12:54:43.567458+00', 'Election, The', 3058, '');
INSERT INTO 'tune' VALUES (7195, NULL, '2012-01-20 12:54:43.573238+00', 'Beyond Hope', 1457, '');
INSERT INTO 'tune' VALUES (7196, NULL, '2012-01-20 12:54:43.576215+00', 'Gran Douglas', 1502, '');
INSERT INTO 'tune' VALUES (7197, NULL, '2012-01-20 12:54:43.579126+00', 'Miss Angela Ivinson', 1593, '');
INSERT INTO 'tune' VALUES (7198, NULL, '2012-01-20 12:54:43.582022+00', 'Gordon Smith of Trenent', 2567, '');
INSERT INTO 'tune' VALUES (7199, NULL, '2012-01-20 12:54:43.584941+00', 'Broomfield Cottage', 2568, '');
INSERT INTO 'tune' VALUES (7200, NULL, '2012-01-20 12:54:43.587862+00', 'Whitehill Jig', 2568, '');
INSERT INTO 'tune' VALUES (7201, NULL, '2012-01-20 12:54:43.590749+00', 'Inverness, Cape Breton', 1457, '');
INSERT INTO 'tune' VALUES (7202, NULL, '2012-01-20 12:54:43.59363+00', 'Garve Mailbus, The', 1457, '');
INSERT INTO 'tune' VALUES (7204, NULL, '2012-01-20 12:54:43.59942+00', 'Debby ''M''', 2569, '');
INSERT INTO 'tune' VALUES (7205, NULL, '2012-01-20 12:54:43.6023+00', 'Nancy''s Magic Fingers', 1593, '');
INSERT INTO 'tune' VALUES (7206, NULL, '2012-01-20 12:54:43.605178+00', 'Langholm Fiddlers', 2568, '');
INSERT INTO 'tune' VALUES (7207, NULL, '2012-01-20 12:54:43.608056+00', 'Graeme & Norma Hutcheson', 1572, '');
INSERT INTO 'tune' VALUES (7208, NULL, '2012-01-20 12:54:43.610947+00', 'Bill and Betty Galbraith', 1593, '');
INSERT INTO 'tune' VALUES (7209, NULL, '2012-01-20 12:54:43.613827+00', 'Jimmy Wilson''s Jig', 1593, '');
INSERT INTO 'tune' VALUES (7210, NULL, '2012-01-20 12:54:43.616723+00', 'Cousin Joyce''s Favourite', 1593, '');
INSERT INTO 'tune' VALUES (7211, NULL, '2012-01-20 12:54:43.619607+00', 'Copshaw Calypso', 1593, '');
INSERT INTO 'tune' VALUES (7212, NULL, '2012-01-20 12:54:43.622483+00', 'Captain Jimmy Bain', 1576, '');
INSERT INTO 'tune' VALUES (7213, NULL, '2012-01-20 12:54:43.625359+00', 'Backshore Hornpipe, The', 1586, '');
INSERT INTO 'tune' VALUES (7214, NULL, '2012-01-20 12:54:43.628254+00', 'Hardanger', 1505, '');
INSERT INTO 'tune' VALUES (7215, NULL, '2012-01-20 12:54:43.631144+00', 'Alex McAdam', 1505, '');
INSERT INTO 'tune' VALUES (7216, NULL, '2012-01-20 12:54:43.634024+00', 'Glint of Gold, A', 1586, '');
INSERT INTO 'tune' VALUES (7217, NULL, '2012-01-20 12:54:43.636922+00', 'Pot Black', 2571, '');
INSERT INTO 'tune' VALUES (7218, NULL, '2012-01-20 12:54:43.639811+00', 'Lang and Short o''t', 1505, '');
INSERT INTO 'tune' VALUES (7219, NULL, '2012-01-20 12:54:43.642692+00', 'Grampian', 1505, '');
INSERT INTO 'tune' VALUES (7220, NULL, '2012-01-20 12:54:43.64557+00', 'Penny Farthing', 1505, '');
INSERT INTO 'tune' VALUES (7221, NULL, '2012-01-20 12:54:43.648454+00', 'Lanes of Templestones, The', 2571, '');
INSERT INTO 'tune' VALUES (7222, NULL, '2012-01-20 12:54:43.651369+00', 'Wee Scottie', 1505, '');
INSERT INTO 'tune' VALUES (7223, NULL, '2012-01-20 12:54:43.654252+00', 'Murray''s Rant', 1505, '');
INSERT INTO 'tune' VALUES (7224, NULL, '2012-01-20 12:54:43.657133+00', 'Shoppie Wifie, The', 1505, '');
INSERT INTO 'tune' VALUES (7225, NULL, '2012-01-20 12:54:43.660458+00', 'Oil and Corn Rigs', 1505, '');
INSERT INTO 'tune' VALUES (7226, NULL, '2012-01-20 12:54:43.663417+00', 'Return to Tchernobyle', 3104, '');
INSERT INTO 'tune' VALUES (7227, NULL, '2012-01-20 12:54:43.666308+00', 'Dancers'' Delight', 1505, '');
INSERT INTO 'tune' VALUES (7228, NULL, '2012-01-20 12:54:43.669197+00', 'Step it Out', 1505, '');
INSERT INTO 'tune' VALUES (7229, NULL, '2012-01-20 12:54:43.672083+00', 'Bedlam', 2572, '');
INSERT INTO 'tune' VALUES (7230, NULL, '2012-01-20 12:54:43.674985+00', 'David and Nina Russell', 2571, '');
INSERT INTO 'tune' VALUES (7231, NULL, '2012-01-20 12:54:43.677862+00', 'Sherbrooke Castle', 1583, '');
INSERT INTO 'tune' VALUES (7232, NULL, '2012-01-20 12:54:43.680754+00', 'Short Back and Sides', 2573, '');
INSERT INTO 'tune' VALUES (7233, NULL, '2012-01-20 12:54:43.683668+00', 'Cameron James Stewart', 2572, '');
INSERT INTO 'tune' VALUES (7234, NULL, '2012-01-20 12:54:43.686567+00', 'Muffin Man, The', 2572, '');
INSERT INTO 'tune' VALUES (7235, NULL, '2012-01-20 12:54:43.689451+00', 'Bennett''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (7236, NULL, '2012-01-20 12:54:43.692343+00', 'Alistair''s 21st', 1586, '');
INSERT INTO 'tune' VALUES (7237, NULL, '2012-01-20 12:54:43.695231+00', 'Dance Willie Dance', 2572, '');
INSERT INTO 'tune' VALUES (7238, NULL, '2012-01-20 12:54:43.698138+00', 'Butter on the Bow', 1737, '');
INSERT INTO 'tune' VALUES (7239, NULL, '2012-01-20 12:54:43.701039+00', 'Barren Spade, The', 810, '');
INSERT INTO 'tune' VALUES (7242, NULL, '2012-01-20 12:54:43.709691+00', 'Black to MacPhail', 1660, '');
INSERT INTO 'tune' VALUES (7243, NULL, '2012-01-20 12:54:43.71258+00', 'Major Graham of Inchbrakie', 9999, '');
INSERT INTO 'tune' VALUES (7244, NULL, '2012-01-20 12:54:43.715462+00', 'Green Groves of Erin', 9999, '');
INSERT INTO 'tune' VALUES (7245, NULL, '2012-01-20 12:54:43.718353+00', 'Ken Duncan''s Reel', 1655, '');
INSERT INTO 'tune' VALUES (7246, NULL, '2012-01-20 12:54:43.721242+00', 'Lezlie and Gordon''s Waltz', 1773, '');
INSERT INTO 'tune' VALUES (7247, NULL, '2012-01-20 12:54:43.724129+00', 'Dreams Vanished', 1763, '');
INSERT INTO 'tune' VALUES (7248, NULL, '2012-01-20 12:54:43.727079+00', 'Posadh peathar In bhain', 9998, '');
INSERT INTO 'tune' VALUES (7249, NULL, '2012-01-20 12:54:43.730053+00', 'Lullabye for Kim', 2581, '');
INSERT INTO 'tune' VALUES (7251, NULL, '2012-01-20 12:54:43.735851+00', 'Eider Ducks, The', 2197, '');
INSERT INTO 'tune' VALUES (7252, NULL, '2012-01-20 12:54:43.738753+00', 'Fiona Grant', 2197, '');
INSERT INTO 'tune' VALUES (7253, NULL, '2012-01-20 12:54:43.741644+00', 'Pirn, The', 2589, '');
INSERT INTO 'tune' VALUES (7254, NULL, '2012-01-20 12:54:43.744552+00', 'Here''s a Health to Him That''s Awa', 9998, '');
INSERT INTO 'tune' VALUES (7255, NULL, '2012-01-20 12:54:43.747536+00', 'Liggeram Cosh', 9998, '');
INSERT INTO 'tune' VALUES (7256, NULL, '2012-01-20 12:54:43.750444+00', 'Balinamona and Ora', 9998, '');
INSERT INTO 'tune' VALUES (7257, NULL, '2012-01-20 12:54:43.753333+00', 'Minnie''s Aye Glowerin O''er Me', 9998, '');
INSERT INTO 'tune' VALUES (7258, NULL, '2012-01-20 12:54:43.756216+00', 'Wren''s Nest, The', 9998, '');
INSERT INTO 'tune' VALUES (7259, NULL, '2012-01-20 12:54:43.759119+00', 'For A'' That an'' A'' That', 9998, '');
INSERT INTO 'tune' VALUES (7260, NULL, '2012-01-20 12:54:43.76202+00', 'I''ll Ay Ca'' In by Yon Town', 9998, '');
INSERT INTO 'tune' VALUES (7261, NULL, '2012-01-20 12:54:43.764913+00', 'Maggie''s Fancy', 9998, '');
INSERT INTO 'tune' VALUES (7262, NULL, '2012-01-20 12:54:43.767796+00', 'Triumph Street Pipe Band', 2593, '');
INSERT INTO 'tune' VALUES (7263, NULL, '2012-01-20 12:54:43.77068+00', 'Lime Street', 9999, '');
INSERT INTO 'tune' VALUES (7264, NULL, '2012-01-20 12:54:43.773563+00', 'Soft Lowland Tongue o'' the Borders, The', 9999, '');
INSERT INTO 'tune' VALUES (7265, NULL, '2012-01-20 12:54:43.776457+00', 'Galawa'' Hills, The', 9998, '');
INSERT INTO 'tune' VALUES (7266, NULL, '2012-01-20 12:54:43.779347+00', 'Merry Wooer, The', 2594, '');
INSERT INTO 'tune' VALUES (7267, NULL, '2012-01-20 12:54:43.782318+00', 'Ferndern', 1499, '');
INSERT INTO 'tune' VALUES (7269, NULL, '2012-01-20 12:54:43.788146+00', 'Loch Leven', 9999, '');
INSERT INTO 'tune' VALUES (7270, NULL, '2012-01-20 12:54:43.791041+00', 'Farewell to Uist', 9998, '');
INSERT INTO 'tune' VALUES (7271, NULL, '2012-01-20 12:54:43.79393+00', 'Captain Duncan MacRae of Ballimore', 2482, '');
INSERT INTO 'tune' VALUES (7272, NULL, '2012-01-20 12:54:43.796821+00', '7th-8th K. O. S. B.''s March to the Somme, The', 2323, '');
INSERT INTO 'tune' VALUES (7273, NULL, '2012-01-20 12:54:43.799715+00', 'Howard Lockhart Polka', 1558, '');
INSERT INTO 'tune' VALUES (7274, NULL, '2012-01-20 12:54:43.80265+00', 'Iron Division, The', 1699, '');
INSERT INTO 'tune' VALUES (7275, NULL, '2012-01-20 12:54:43.805534+00', 'My Darling Asleep', 9999, '');
INSERT INTO 'tune' VALUES (7276, NULL, '2012-01-20 12:54:43.808416+00', 'We''d Better Bide A Wee', 9999, '');
INSERT INTO 'tune' VALUES (7277, NULL, '2012-01-20 12:54:43.811304+00', 'Captain Campbell of Brum A Voisk', 2597, '');
INSERT INTO 'tune' VALUES (7278, NULL, '2012-01-20 12:54:43.814188+00', 'Fairy Millahy', 9998, '');
INSERT INTO 'tune' VALUES (7279, NULL, '2012-01-20 12:54:43.817073+00', 'Herding Song', 9998, '');
INSERT INTO 'tune' VALUES (7280, NULL, '2012-01-20 12:54:43.819963+00', 'Little Mischief', 1415, '');
INSERT INTO 'tune' VALUES (7281, NULL, '2012-01-20 12:54:43.82286+00', 'Sandy''s New Chanter', 2598, '');
INSERT INTO 'tune' VALUES (7282, NULL, '2012-01-20 12:54:43.825764+00', 'Jovial Ken', 1593, '');
INSERT INTO 'tune' VALUES (7283, NULL, '2012-01-20 12:54:43.828777+00', 'Mrs Elizabeth Hunter', 1572, '');
INSERT INTO 'tune' VALUES (7284, NULL, '2012-01-20 12:54:43.831685+00', 'Miss Field''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (7285, NULL, '2012-01-20 12:54:43.834583+00', 'Case Apart, A', 1502, '');
INSERT INTO 'tune' VALUES (7286, NULL, '2012-01-20 12:54:43.837473+00', 'Bill Clement', 1502, '');
INSERT INTO 'tune' VALUES (7287, NULL, '2012-01-20 12:54:43.840359+00', 'Leaving the Shepherd''s Inn', 1593, '');
INSERT INTO 'tune' VALUES (7288, NULL, '2012-01-20 12:54:43.843276+00', 'William''s Jig', 2197, '');
INSERT INTO 'tune' VALUES (7289, NULL, '2012-01-20 12:54:43.846153+00', 'Mo Ghenar Duit', 2197, '');
INSERT INTO 'tune' VALUES (7290, NULL, '2012-01-20 12:54:43.849041+00', 'Follow Your Love', 2197, '');
INSERT INTO 'tune' VALUES (7291, NULL, '2012-01-20 12:54:43.851923+00', '75 Years Young', 2197, '');
INSERT INTO 'tune' VALUES (7292, NULL, '2012-01-20 12:54:43.854832+00', 'Mr & Mrs Bryan Ridley', 1593, '');
INSERT INTO 'tune' VALUES (7294, NULL, '2012-01-20 12:54:43.860611+00', 'Roy of Olicana', 1508, '');
INSERT INTO 'tune' VALUES (7295, NULL, '2012-01-20 12:54:43.863501+00', 'Dunstanburgh Castle', 2606, '');
INSERT INTO 'tune' VALUES (7296, NULL, '2012-01-20 12:54:43.866397+00', 'Jock Wilson of Fenton', 1595, '');
INSERT INTO 'tune' VALUES (7297, NULL, '2012-01-20 12:54:43.869275+00', 'Snowy Monday', 2607, '');
INSERT INTO 'tune' VALUES (7298, NULL, '2012-01-20 12:54:43.872575+00', 'Jimmie''s Jig', 1538, '');
INSERT INTO 'tune' VALUES (7299, NULL, '2012-01-20 12:54:43.875506+00', 'Christopher Whitehead', 2608, '');
INSERT INTO 'tune' VALUES (7300, NULL, '2012-01-20 12:54:43.878395+00', 'Countryfare', 2609, '');
INSERT INTO 'tune' VALUES (7301, NULL, '2012-01-20 12:54:43.881287+00', 'Corsenside Common', 2609, '');
INSERT INTO 'tune' VALUES (7302, NULL, '2012-01-20 12:54:43.884304+00', 'Susan Cooper', 1623, '');
INSERT INTO 'tune' VALUES (7303, NULL, '2012-01-20 12:54:43.887254+00', 'One Tune Piper, The', 9999, '');
INSERT INTO 'tune' VALUES (7304, NULL, '2012-01-20 12:54:43.890142+00', 'Norman''s Law', 9999, '');
INSERT INTO 'tune' VALUES (7305, NULL, '2012-01-20 12:54:43.893032+00', 'Dave Provan''s Jig', 1596, '');
INSERT INTO 'tune' VALUES (7306, NULL, '2012-01-20 12:54:43.895923+00', 'Jim Cook', 2197, '');
INSERT INTO 'tune' VALUES (7307, NULL, '2012-01-20 12:54:43.898815+00', 'Ully''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (7308, NULL, '2012-01-20 12:54:43.901687+00', 'Lord Huntly', 9999, '');
INSERT INTO 'tune' VALUES (7309, NULL, '2012-01-20 12:54:43.904578+00', 'Queen''s Quay', 1502, '');
INSERT INTO 'tune' VALUES (7311, NULL, '2012-01-20 12:54:43.910387+00', 'Denise''s Tune', 1817, '');
INSERT INTO 'tune' VALUES (7313, NULL, '2012-01-20 12:54:43.916167+00', 'Peggy Dykes'' Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (7314, NULL, '2012-01-20 12:54:43.919055+00', 'Cairngorm Dancers, The', 1502, '');
INSERT INTO 'tune' VALUES (7315, NULL, '2012-01-20 12:54:43.921934+00', 'Mrs Roy (of Nenthorn''s) Favourite', 1519, '');
INSERT INTO 'tune' VALUES (7316, NULL, '2012-01-20 12:54:43.924829+00', 'Pamela Rose McLeod', 1782, '');
INSERT INTO 'tune' VALUES (7317, NULL, '2012-01-20 12:54:43.927921+00', 'Blackfriars Hall', 1502, '');
INSERT INTO 'tune' VALUES (7318, NULL, '2012-01-20 12:54:43.930842+00', 'Helen Brown''s Delight', 1502, '');
INSERT INTO 'tune' VALUES (7319, NULL, '2012-01-20 12:54:43.933725+00', 'Andrew Gillies', 1502, '');
INSERT INTO 'tune' VALUES (7320, NULL, '2012-01-20 12:54:43.936618+00', 'Noreen MacLennan of Stonehaven', 345, '');
INSERT INTO 'tune' VALUES (7321, NULL, '2012-01-20 12:54:43.939506+00', 'Evenie Water', 9998, '');
INSERT INTO 'tune' VALUES (7322, NULL, '2012-01-20 12:54:43.942388+00', 'O my Jock McKay', 9998, '');
INSERT INTO 'tune' VALUES (7323, '2005-06-19 22:00:00+00', '2012-01-20 12:54:43.945286+00', 'Rosie', 2768, '');
INSERT INTO 'tune' VALUES (7324, NULL, '2012-01-20 12:54:43.948209+00', 'Little Nellie Kelly', 9998, '');
INSERT INTO 'tune' VALUES (7325, NULL, '2012-01-20 12:54:43.951097+00', 'Daisy Bell', 2349, '');
INSERT INTO 'tune' VALUES (7326, NULL, '2012-01-20 12:54:43.953984+00', 'Lass of Bon Accord', 9998, '');
INSERT INTO 'tune' VALUES (7327, NULL, '2012-01-20 12:54:43.956865+00', 'Road of No Return', 9998, '');
INSERT INTO 'tune' VALUES (7328, NULL, '2012-01-20 12:54:43.959752+00', 'Summer Cheese', 9998, '');
INSERT INTO 'tune' VALUES (7329, NULL, '2012-01-20 12:54:43.962636+00', 'I''m Tired Cutting Rannoch', 9998, '');
INSERT INTO 'tune' VALUES (7330, NULL, '2012-01-20 12:54:43.965515+00', 'Mho Mhathair', 9998, '');
INSERT INTO 'tune' VALUES (7331, NULL, '2012-01-20 12:54:43.968441+00', 'Welcome to Scalpay', 2981, '');
INSERT INTO 'tune' VALUES (7332, NULL, '2012-01-20 12:54:43.97133+00', 'Kennag M''hor', 9998, '');
INSERT INTO 'tune' VALUES (7333, NULL, '2012-01-20 12:54:43.974218+00', 'Take this Message to my Mother', 9998, '');
INSERT INTO 'tune' VALUES (7335, NULL, '2012-01-20 12:54:43.979997+00', 'Lament of the Reed Makers, The', 2407, '');
INSERT INTO 'tune' VALUES (7336, NULL, '2012-01-20 12:54:43.98288+00', 'Men O'' Argyle', 1700, '');
INSERT INTO 'tune' VALUES (7337, NULL, '2012-01-20 12:54:43.985756+00', 'Tommy MacKay', 9999, '');
INSERT INTO 'tune' VALUES (7338, NULL, '2012-01-20 12:54:43.988656+00', 'Spider and the Gaff', 9999, '');
INSERT INTO 'tune' VALUES (7339, NULL, '2012-01-20 12:54:43.991549+00', 'Killiecrankie', 1663, '');
INSERT INTO 'tune' VALUES (7340, NULL, '2012-01-20 12:54:43.99443+00', 'When I Meet MacKay', 1663, '');
INSERT INTO 'tune' VALUES (7341, NULL, '2012-01-20 12:54:43.997312+00', 'Isle of Lewis, The', 9999, '');
INSERT INTO 'tune' VALUES (7342, NULL, '2012-01-20 12:54:44.000204+00', 'Mrs Margaret Shand', 9998, '');
INSERT INTO 'tune' VALUES (7343, NULL, '2012-01-20 12:54:44.003097+00', 'Diane''s Favourite', 9998, '');
INSERT INTO 'tune' VALUES (7344, NULL, '2012-01-20 12:54:44.005994+00', 'Miss McLeod''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (7345, NULL, '2012-01-20 12:54:44.008899+00', 'Horee Horo', 9999, '');
INSERT INTO 'tune' VALUES (7310, NULL, '2012-05-04 18:34:41.16408+00', 'Doctor and his Lady, The', 1502, '');
INSERT INTO 'tune' VALUES (7346, NULL, '2012-01-20 12:54:44.011813+00', 'Sir Charles Forbes Baronet of Newe', 1748, '');
INSERT INTO 'tune' VALUES (7347, NULL, '2012-01-20 12:54:44.015133+00', 'Miss Cochrane''s Jig', 2612, '');
INSERT INTO 'tune' VALUES (7348, NULL, '2012-01-20 12:54:44.018114+00', 'Jack''s Jig', 1538, '');
INSERT INTO 'tune' VALUES (7349, NULL, '2012-01-20 12:54:44.021031+00', 'Mrs Forbes of Boharm''s Strathspey', 1516, '');
INSERT INTO 'tune' VALUES (7350, NULL, '2012-01-20 12:54:44.023921+00', 'Averil Parker', 1582, '');
INSERT INTO 'tune' VALUES (7351, NULL, '2012-01-20 12:54:44.02681+00', 'Bett Wilson''s Strathspey', 1582, '');
INSERT INTO 'tune' VALUES (7352, NULL, '2012-01-20 12:54:44.029732+00', 'Elizabeth''s Jig', 1582, '');
INSERT INTO 'tune' VALUES (7353, NULL, '2012-01-20 12:54:44.032618+00', 'Hamefarers', 1582, '');
INSERT INTO 'tune' VALUES (7354, NULL, '2012-01-20 12:54:44.035505+00', 'Mill Hill', 1582, '');
INSERT INTO 'tune' VALUES (7355, NULL, '2012-01-20 12:54:44.038414+00', 'Hillcrest', 1582, '');
INSERT INTO 'tune' VALUES (7356, NULL, '2012-01-20 12:54:44.041303+00', 'Mr & Mrs Rennilson', 1582, '');
INSERT INTO 'tune' VALUES (7357, NULL, '2012-01-20 12:54:44.044185+00', 'Parashandy Jig', 1582, '');
INSERT INTO 'tune' VALUES (7358, NULL, '2012-01-20 12:54:44.047071+00', 'Pat O''Hara''s Strathspey', 1582, '');
INSERT INTO 'tune' VALUES (7359, NULL, '2012-01-20 12:54:44.049964+00', 'Sheila''s Fancy', 1582, '');
INSERT INTO 'tune' VALUES (7360, NULL, '2012-01-20 12:54:44.052852+00', 'Boys'' Brigade, The', 1582, '');
INSERT INTO 'tune' VALUES (7361, NULL, '2012-01-20 12:54:44.055751+00', 'Tribute to Roy & Tim Willingale', 1582, '');
INSERT INTO 'tune' VALUES (7362, NULL, '2012-01-20 12:54:44.058647+00', 'Brenda Burnell', 1582, '');
INSERT INTO 'tune' VALUES (7363, NULL, '2012-01-20 12:54:44.061525+00', 'Dandice', 1582, '');
INSERT INTO 'tune' VALUES (7364, NULL, '2012-01-20 12:54:44.064414+00', 'DJ Taylor', 1582, '');
INSERT INTO 'tune' VALUES (7365, NULL, '2012-01-20 12:54:44.067308+00', 'Doreen''s Tune', 1582, '');
INSERT INTO 'tune' VALUES (7366, NULL, '2012-01-20 12:54:44.070208+00', 'Dorothy''s Reel', 1582, '');
INSERT INTO 'tune' VALUES (7367, NULL, '2012-01-20 12:54:44.073088+00', 'Dr A MacFadyen', 1582, '');
INSERT INTO 'tune' VALUES (7368, NULL, '2012-01-20 12:54:44.075975+00', 'Gayton Road', 1582, '');
INSERT INTO 'tune' VALUES (7369, NULL, '2012-01-20 12:54:44.078884+00', 'Gilpin House', 1582, '');
INSERT INTO 'tune' VALUES (7370, NULL, '2012-01-20 12:54:44.081795+00', 'Ian & Joan''s Strathspey', 1582, '');
INSERT INTO 'tune' VALUES (7371, NULL, '2012-01-20 12:54:44.085027+00', 'In Honour of Bill & Hope Little', 1582, '');
INSERT INTO 'tune' VALUES (7372, NULL, '2012-01-20 12:54:44.087981+00', 'Jessica''s Welcome', 1582, '');
INSERT INTO 'tune' VALUES (7373, NULL, '2012-01-20 12:54:44.090977+00', 'Jim Rae', 1582, '');
INSERT INTO 'tune' VALUES (7374, NULL, '2012-01-20 12:54:44.093866+00', 'Johan MacLean''s Strathspey', 1582, '');
INSERT INTO 'tune' VALUES (7375, NULL, '2012-01-20 12:54:44.097139+00', 'K N Clark', 1582, '');
INSERT INTO 'tune' VALUES (7376, NULL, '2012-01-20 12:54:44.100055+00', 'Katherine''s Hornpipe', 1582, '');
INSERT INTO 'tune' VALUES (7377, NULL, '2012-01-20 12:54:44.102966+00', 'Little Jessica', 1582, '');
INSERT INTO 'tune' VALUES (7378, NULL, '2012-01-20 12:54:44.105891+00', 'Mary & Peter Braithwaite', 1582, '');
INSERT INTO 'tune' VALUES (7379, NULL, '2012-01-20 12:54:44.108788+00', 'Mary Stoker', 1582, '');
INSERT INTO 'tune' VALUES (7380, NULL, '2012-01-20 12:54:44.111687+00', 'Miss Lesley Martin', 1582, '');
INSERT INTO 'tune' VALUES (7381, NULL, '2012-01-20 12:54:44.114602+00', 'Miss Lindsay Martin''s Reel', 1582, '');
INSERT INTO 'tune' VALUES (7382, NULL, '2012-01-20 12:54:44.117494+00', 'Miss Mary Murray', 1582, '');
INSERT INTO 'tune' VALUES (7383, NULL, '2012-01-20 12:54:44.120679+00', 'Mr & Mrs Chater', 1582, '');
INSERT INTO 'tune' VALUES (7384, NULL, '2012-01-20 12:54:44.124285+00', 'Mrs Edith Clark', 1582, '');
INSERT INTO 'tune' VALUES (7385, NULL, '2012-01-20 12:54:44.12755+00', 'Mrs Marjorie Macrae', 1582, '');
INSERT INTO 'tune' VALUES (7386, NULL, '2012-01-20 12:54:44.130597+00', 'Mrs Pam Dignan', 1582, '');
INSERT INTO 'tune' VALUES (7387, NULL, '2012-01-20 12:54:44.133506+00', 'Pat''s Compliments to Muriel Johnstone', 1582, '');
INSERT INTO 'tune' VALUES (7388, NULL, '2012-01-20 12:54:44.136408+00', 'Pat''s Piano', 1582, '');
INSERT INTO 'tune' VALUES (7389, NULL, '2012-01-20 12:54:44.139302+00', 'Peter John Clark', 1582, '');
INSERT INTO 'tune' VALUES (7390, NULL, '2012-01-20 12:54:44.14221+00', 'Reel for Amanda', 1582, '');
INSERT INTO 'tune' VALUES (7391, NULL, '2012-01-20 12:54:44.1451+00', 'Rene''s Reel', 1582, '');
INSERT INTO 'tune' VALUES (7392, NULL, '2012-01-20 12:54:44.148001+00', 'Richard Clark', 1582, '');
INSERT INTO 'tune' VALUES (7393, NULL, '2012-01-20 12:54:44.150892+00', 'Roy''s Tune', 1582, '');
INSERT INTO 'tune' VALUES (7394, NULL, '2012-01-20 12:54:44.153796+00', 'Terry''s Jig', 1582, '');
INSERT INTO 'tune' VALUES (7395, NULL, '2012-01-20 12:54:44.156695+00', 'McKenzie Reel, The', 1582, '');
INSERT INTO 'tune' VALUES (7396, NULL, '2012-01-20 12:54:44.159604+00', 'Teaser, The', 1582, '');
INSERT INTO 'tune' VALUES (7397, NULL, '2012-01-20 12:54:44.162497+00', 'Helen''s Reel', 1582, '');
INSERT INTO 'tune' VALUES (7398, NULL, '2012-01-20 12:54:44.165386+00', 'Mr Malcolm Brown', 1582, '');
INSERT INTO 'tune' VALUES (7399, NULL, '2012-01-20 12:54:44.168282+00', 'Pipe Band, The', 1582, '');
INSERT INTO 'tune' VALUES (7401, NULL, '2012-01-20 12:54:44.174073+00', 'Twin City Reel', 1582, '');
INSERT INTO 'tune' VALUES (7402, NULL, '2012-01-20 12:54:44.176967+00', 'Malcolm''s Jig', 1582, '');
INSERT INTO 'tune' VALUES (7403, NULL, '2012-01-20 12:54:44.17986+00', 'Alasdair Brown', 1582, '');
INSERT INTO 'tune' VALUES (7404, NULL, '2012-01-20 12:54:44.182747+00', 'Bill & Maureen Bishop', 1582, '');
INSERT INTO 'tune' VALUES (7405, NULL, '2012-01-20 12:54:44.185623+00', 'Bonnie Brenda''s Jig', 1582, '');
INSERT INTO 'tune' VALUES (7406, NULL, '2012-01-20 12:54:44.188517+00', 'Captain Donald Johnson', 1582, '');
INSERT INTO 'tune' VALUES (7407, NULL, '2012-01-20 12:54:44.191422+00', 'Celebration', 1582, '');
INSERT INTO 'tune' VALUES (7408, NULL, '2012-01-20 12:54:44.194317+00', 'Clark''s Reel', 1582, '');
INSERT INTO 'tune' VALUES (7409, NULL, '2012-01-20 12:54:44.197212+00', 'Gordonian Strathspey, The', 1582, '');
INSERT INTO 'tune' VALUES (7410, NULL, '2012-01-20 12:54:44.200102+00', 'MacDonalds Skye Wedding, The', 1582, '');
INSERT INTO 'tune' VALUES (7411, NULL, '2012-01-20 12:54:44.202995+00', 'McCabe Strathspey, The', 1582, '');
INSERT INTO 'tune' VALUES (7412, NULL, '2012-01-20 12:54:44.205881+00', 'McCabe Reel', 1582, '');
INSERT INTO 'tune' VALUES (7413, NULL, '2012-01-20 12:54:44.20877+00', 'Molly & Albert', 1582, '');
INSERT INTO 'tune' VALUES (7414, NULL, '2012-01-20 12:54:44.211688+00', 'Northallerton Caledonian Society', 1582, '');
INSERT INTO 'tune' VALUES (7415, NULL, '2012-01-20 12:54:44.214596+00', 'Sunset in Seattle', 1582, '');
INSERT INTO 'tune' VALUES (7416, NULL, '2012-01-20 12:54:44.217485+00', 'McCausland Jig, The', 1582, '');
INSERT INTO 'tune' VALUES (7417, '2003-03-08 23:00:00+00', '2012-01-20 12:54:44.22039+00', 'Fells of Campsie, The', 3298, '');
INSERT INTO 'tune' VALUES (7418, NULL, '2012-01-20 12:54:44.223309+00', 'DM Scarr', 1582, '');
INSERT INTO 'tune' VALUES (7419, NULL, '2012-01-20 12:54:44.226201+00', 'Enid of Winchester', 1582, '');
INSERT INTO 'tune' VALUES (7420, NULL, '2012-01-20 12:54:44.229084+00', 'For Rona & Charlie', 1582, '');
INSERT INTO 'tune' VALUES (7421, NULL, '2012-01-20 12:54:44.231971+00', 'Cannon Hill', 1582, '');
INSERT INTO 'tune' VALUES (7422, NULL, '2012-01-20 12:54:44.234872+00', 'Mary''s Jig', 1582, '');
INSERT INTO 'tune' VALUES (7423, NULL, '2012-01-20 12:54:44.237767+00', 'Miss Joanna Cramb', 1607, '');
INSERT INTO 'tune' VALUES (7424, NULL, '2012-01-20 12:54:44.240682+00', 'Ness House', 1582, '');
INSERT INTO 'tune' VALUES (7425, NULL, '2012-01-20 12:54:44.243566+00', 'Mrs Peggy Dykes', 1502, '');
INSERT INTO 'tune' VALUES (7426, NULL, '2012-01-20 12:54:44.246463+00', 'Bailey Bridge, The', 2626, '');
INSERT INTO 'tune' VALUES (7427, NULL, '2012-01-20 12:54:44.249352+00', 'Ayrshire Wheelie Bin, The', 1576, '');
INSERT INTO 'tune' VALUES (7428, NULL, '2012-01-20 12:54:44.252244+00', 'Paddy''s Milestone', 1575, '');
INSERT INTO 'tune' VALUES (7429, NULL, '2012-01-20 12:54:44.255164+00', 'Dancing Doctor, The', 1575, '');
INSERT INTO 'tune' VALUES (7430, NULL, '2012-01-20 12:54:44.258657+00', 'Dancing Peggy', 1502, '');
INSERT INTO 'tune' VALUES (7431, NULL, '2012-01-20 12:54:44.261551+00', 'Mrs Gray''s Jig', 2630, '');
INSERT INTO 'tune' VALUES (7432, NULL, '2012-01-20 12:54:44.26445+00', 'Bill Rodie', 1871, '');
INSERT INTO 'tune' VALUES (7433, NULL, '2012-01-20 12:54:44.267348+00', 'Miss Lisa Emery', 2626, '');
INSERT INTO 'tune' VALUES (7434, NULL, '2012-01-20 12:54:44.270245+00', 'Whiskey Hornpipe, The', 9998, '');
INSERT INTO 'tune' VALUES (7435, NULL, '2012-01-20 12:54:44.273127+00', 'Irene''s Strathspey', 1656, '');
INSERT INTO 'tune' VALUES (7436, NULL, '2012-01-20 12:54:44.276026+00', 'Mira Stables Cook''s Delight', 1502, '');
INSERT INTO 'tune' VALUES (7438, NULL, '2012-01-20 12:54:44.281825+00', 'Miss Alison MacLeod', 9998, '');
INSERT INTO 'tune' VALUES (7439, NULL, '2012-01-20 12:54:44.284718+00', 'Tune for Donald MacDonald, A', 9998, '');
INSERT INTO 'tune' VALUES (7440, NULL, '2012-01-20 12:54:44.287617+00', 'Morag''s Fairy Glen', 2933, '');
INSERT INTO 'tune' VALUES (7441, NULL, '2012-01-20 12:54:44.290663+00', 'Trip to Madeira, A', 9998, '');
INSERT INTO 'tune' VALUES (7442, NULL, '2012-01-20 12:54:44.293599+00', 'Walter Sinton of Perth', 9998, '');
INSERT INTO 'tune' VALUES (7443, NULL, '2012-01-20 12:54:44.296527+00', 'Sheltie, The', 2632, '');
INSERT INTO 'tune' VALUES (7444, NULL, '2012-01-20 12:54:44.299417+00', 'Kittimor', 9999, '');
INSERT INTO 'tune' VALUES (7445, NULL, '2012-01-20 12:54:44.302309+00', 'Inveresk Lassies, The', 1606, '');
INSERT INTO 'tune' VALUES (7446, NULL, '2012-01-20 12:54:44.305192+00', 'Minard Castle', 2633, '');
INSERT INTO 'tune' VALUES (7447, NULL, '2012-01-20 12:54:44.308101+00', 'Anne''s Wedding', 2632, '');
INSERT INTO 'tune' VALUES (7448, NULL, '2012-01-20 12:54:44.311016+00', 'Blackwood', 1659, '');
INSERT INTO 'tune' VALUES (7449, NULL, '2012-01-20 12:54:44.313911+00', 'Braes of Castle Grant, The', 9998, '');
INSERT INTO 'tune' VALUES (7450, NULL, '2012-01-20 12:54:44.316815+00', 'Wind on the Heath', 9999, '');
INSERT INTO 'tune' VALUES (7451, NULL, '2012-01-20 12:54:44.31971+00', 'Dulsie Water', 1754, '');
INSERT INTO 'tune' VALUES (7452, NULL, '2012-01-20 12:54:44.322596+00', 'Margaret''s Polka', 1606, '');
INSERT INTO 'tune' VALUES (7453, '2006-09-03 22:00:00+00', '2012-04-03 20:38:18.364349+00', 'Haggarty''s Brig', 2977, 'Composed 2002');
INSERT INTO 'tune' VALUES (7454, NULL, '2012-01-20 12:54:44.328543+00', 'Moors of Perth', 1567, '');
INSERT INTO 'tune' VALUES (7455, NULL, '2012-01-20 12:54:44.33152+00', 'Hamilton Rant', 2054, '');
INSERT INTO 'tune' VALUES (7456, NULL, '2012-01-20 12:54:44.334444+00', 'Miss Alison Gray', 1804, '');
INSERT INTO 'tune' VALUES (7457, NULL, '2012-01-20 12:54:44.3374+00', 'Ness Bothan', 3052, '');
INSERT INTO 'tune' VALUES (7458, NULL, '2012-01-20 12:54:44.340316+00', 'Salmon Tails up the Water', 9999, '');
INSERT INTO 'tune' VALUES (7459, NULL, '2012-01-20 12:54:44.343212+00', 'Water Lily Pond, The', 2362, '');
INSERT INTO 'tune' VALUES (7460, NULL, '2012-01-20 12:54:44.346088+00', 'Piper''s Wedding, The', 9999, '');
INSERT INTO 'tune' VALUES (7461, NULL, '2012-01-20 12:54:44.348977+00', 'James Hamilton of Sandwill', 2636, '');
INSERT INTO 'tune' VALUES (7462, NULL, '2012-01-20 12:54:44.351871+00', 'Donald B McTaggart', 2362, '');
INSERT INTO 'tune' VALUES (7463, NULL, '2012-01-20 12:54:44.35476+00', 'Crauford Amos', 2636, '');
INSERT INTO 'tune' VALUES (7464, NULL, '2012-01-20 12:54:44.357651+00', 'When I Grow Too Old to Dream', 2880, '');
INSERT INTO 'tune' VALUES (7465, NULL, '2012-01-20 12:54:44.360544+00', 'Mrs Elliot', 1558, '');
INSERT INTO 'tune' VALUES (7466, NULL, '2012-01-20 12:54:44.363442+00', 'Archiestown Reel, The', 2362, '');
INSERT INTO 'tune' VALUES (7467, NULL, '2012-01-20 12:54:44.366335+00', 'Fair Haired Boy, The', 9999, '');
INSERT INTO 'tune' VALUES (7468, NULL, '2012-01-20 12:54:44.369216+00', 'O Horo Mo Chailin Donn', 2636, '');
INSERT INTO 'tune' VALUES (7469, NULL, '2012-01-20 12:54:44.372111+00', 'A Mhairi Bhoidheach', 9999, '');
INSERT INTO 'tune' VALUES (7470, NULL, '2012-01-20 12:54:44.375003+00', 'Jim''s Delight', 9998, '');
INSERT INTO 'tune' VALUES (13854, '2018-03-30 09:30:43.828419+00', '2018-03-30 09:30:43.828419+00', 'Rambling Wreck', 9999, '');
INSERT INTO 'tune' VALUES (7473, NULL, '2012-01-20 12:54:44.383671+00', 'Hornpipe 75', 9998, '');
INSERT INTO 'tune' VALUES (7474, NULL, '2012-01-20 12:54:44.386556+00', 'Maria Stewart', 9998, '');
INSERT INTO 'tune' VALUES (7475, NULL, '2012-01-20 12:54:44.389442+00', 'Sally Hunter', 9998, '');
INSERT INTO 'tune' VALUES (7476, NULL, '2012-01-20 12:54:44.39233+00', 'Miss Joan C Mackenzie', 1669, '');
INSERT INTO 'tune' VALUES (7477, NULL, '2012-01-20 12:54:44.39523+00', 'Roses in Bloom', 9999, '');
INSERT INTO 'tune' VALUES (7478, NULL, '2012-01-20 12:54:44.398111+00', 'Northumbrian Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (7479, NULL, '2012-01-20 12:54:44.401011+00', 'My Nannie''s Awa', 9999, '');
INSERT INTO 'tune' VALUES (7480, NULL, '2012-01-20 12:54:44.403897+00', 'C.T.S. Empress', 9999, '');
INSERT INTO 'tune' VALUES (7481, NULL, '2012-01-20 12:54:44.406784+00', 'Lakeside Road, The', 9999, '');
INSERT INTO 'tune' VALUES (7482, NULL, '2012-01-20 12:54:44.409671+00', 'Jean''s Jig', 2644, '');
INSERT INTO 'tune' VALUES (7484, NULL, '2012-01-20 12:54:44.415466+00', 'Wild Rose Strathspey', 234, '');
INSERT INTO 'tune' VALUES (7485, NULL, '2012-01-20 12:54:44.418357+00', 'Merkel Dene', 1725, '');
INSERT INTO 'tune' VALUES (7486, NULL, '2012-01-20 12:54:44.421281+00', 'Mrs Duncan''s Delight', 9998, '');
INSERT INTO 'tune' VALUES (7487, NULL, '2012-01-20 12:54:44.42421+00', 'Banker''s Brae', 1725, '');
INSERT INTO 'tune' VALUES (7488, NULL, '2012-01-20 12:54:44.427094+00', 'Miss Alison Frew', 1521, '');
INSERT INTO 'tune' VALUES (7489, NULL, '2012-01-20 12:54:44.429979+00', 'Hoot Awa Ye Loon', 2642, '');
INSERT INTO 'tune' VALUES (7490, NULL, '2012-01-20 12:54:44.432886+00', 'Spring Chicken', 234, '');
INSERT INTO 'tune' VALUES (7491, NULL, '2012-01-20 12:54:44.435787+00', 'Molly Thow''s Reel', 1725, '');
INSERT INTO 'tune' VALUES (7492, NULL, '2012-01-20 12:54:44.438673+00', 'Kirkbister Reel', 2286, '');
INSERT INTO 'tune' VALUES (7493, NULL, '2012-01-20 12:54:44.441576+00', 'ABC Jig, The', 1413, '');
INSERT INTO 'tune' VALUES (7494, NULL, '2012-01-20 12:54:44.444473+00', 'Miss Campbell of Monzie', 1519, '');
INSERT INTO 'tune' VALUES (7495, NULL, '2012-01-20 12:54:44.447362+00', 'Kirsty MacKinnon', 1605, '');
INSERT INTO 'tune' VALUES (7496, NULL, '2012-01-20 12:54:44.450257+00', 'Blue Mountain Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (7497, NULL, '2012-01-20 12:54:44.453142+00', 'Brace Ridge Centennial Hornpipe, The', 2569, '');
INSERT INTO 'tune' VALUES (7498, NULL, '2012-01-20 12:54:44.456026+00', 'De''nt-Ainma Th''air', 9998, '');
INSERT INTO 'tune' VALUES (7499, NULL, '2012-01-20 12:54:44.45891+00', 'Cion A''Bhuntata', 9998, '');
INSERT INTO 'tune' VALUES (7500, NULL, '2012-01-20 12:54:44.461811+00', 'Ian Powrie''s Compliments to Angus Fitchet', 1551, '');
INSERT INTO 'tune' VALUES (7501, NULL, '2012-01-20 12:54:44.464704+00', 'Agnes Lowden', 9999, '');
INSERT INTO 'tune' VALUES (7502, NULL, '2012-01-20 12:54:44.467612+00', 'Ballochmyle Brig', 1512, '');
INSERT INTO 'tune' VALUES (7503, NULL, '2012-01-20 12:54:44.4809+00', 'South of the Grampians', 2646, '');
INSERT INTO 'tune' VALUES (7504, NULL, '2012-01-20 12:54:44.483936+00', 'Lord Moira', 10504, '');
INSERT INTO 'tune' VALUES (7505, NULL, '2012-01-20 12:54:44.486839+00', 'Gray''s Second Chance', 1602, '');
INSERT INTO 'tune' VALUES (7506, NULL, '2012-01-20 12:54:44.489729+00', 'Sporting Jamie', 9999, '');
INSERT INTO 'tune' VALUES (7507, NULL, '2012-01-20 12:54:44.492626+00', 'Katie Stammers', 1623, '');
INSERT INTO 'tune' VALUES (7508, NULL, '2012-01-20 12:54:44.495524+00', 'Cortez Island Hornpipe', 1835, '');
INSERT INTO 'tune' VALUES (7509, NULL, '2012-01-20 12:54:44.498408+00', 'Catlodge', 1910, '');
INSERT INTO 'tune' VALUES (7510, NULL, '2012-01-20 12:54:44.501314+00', 'Alister McDonald of Fasgadh', 1605, '');
INSERT INTO 'tune' VALUES (7511, NULL, '2012-01-20 12:54:44.504213+00', 'Peerie Willie Johnson', 1710, '');
INSERT INTO 'tune' VALUES (7512, NULL, '2012-01-20 12:54:44.5071+00', 'Debbie''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (7513, NULL, '2012-01-20 12:54:44.509992+00', 'Vic''s Jig', 2647, '');
INSERT INTO 'tune' VALUES (7514, NULL, '2012-01-20 12:54:44.51287+00', 'Old Box Stove, The', 2648, '');
INSERT INTO 'tune' VALUES (7515, NULL, '2012-01-20 12:54:44.515765+00', 'Marg''s Jig', 2649, '');
INSERT INTO 'tune' VALUES (7516, NULL, '2012-01-20 12:54:44.518655+00', 'Father Kelly''s Jig', 2650, '');
INSERT INTO 'tune' VALUES (7517, NULL, '2012-01-20 12:54:44.521538+00', 'Gemma''s Jig', 2651, '');
INSERT INTO 'tune' VALUES (7518, NULL, '2012-01-20 12:54:44.524492+00', 'Miss Kirsty Jamieson', 1645, '');
INSERT INTO 'tune' VALUES (7519, NULL, '2012-01-20 12:54:44.527566+00', 'Crystal City Breakdown, The', 2652, '');
INSERT INTO 'tune' VALUES (7520, NULL, '2012-01-20 12:54:44.530489+00', 'Fairy Reel, Da', 9999, '');
INSERT INTO 'tune' VALUES (7521, NULL, '2012-01-20 12:54:44.533378+00', 'Norm Burgess Breakdown', 2653, '');
INSERT INTO 'tune' VALUES (7522, NULL, '2012-01-20 12:54:44.536269+00', 'Horner''s Trophy Reel', 2654, '');
INSERT INTO 'tune' VALUES (7523, NULL, '2012-01-20 12:54:44.539179+00', 'Muskoka Homestead Reel, The', 2569, '');
INSERT INTO 'tune' VALUES (7524, NULL, '2012-01-20 12:54:44.542065+00', 'Crooks of the Kingdom', 2655, '');
INSERT INTO 'tune' VALUES (7525, NULL, '2012-01-20 12:54:44.544965+00', 'Bronnis Blue Brozzi', 2656, '');
INSERT INTO 'tune' VALUES (7526, NULL, '2012-01-20 12:54:44.547866+00', 'F''e Is Bharraidh', 2657, '');
INSERT INTO 'tune' VALUES (7527, NULL, '2012-01-20 12:54:44.550768+00', 'Changeling, The', 2656, '');
INSERT INTO 'tune' VALUES (7528, NULL, '2012-01-20 12:54:44.553657+00', 'Welcome to Cork', 9999, '');
INSERT INTO 'tune' VALUES (7529, NULL, '2012-01-20 12:54:44.556553+00', 'Swallow''s Nest, The', 9999, '');
INSERT INTO 'tune' VALUES (7530, NULL, '2012-01-20 12:54:44.559444+00', 'Ballochyle', 2138, '');
INSERT INTO 'tune' VALUES (7531, NULL, '2012-01-20 12:54:44.56233+00', 'Telephone Box, The', 1580, '');
INSERT INTO 'tune' VALUES (7532, NULL, '2012-01-20 12:54:44.565226+00', 'Musselburgh Common Riding', 9999, '');
INSERT INTO 'tune' VALUES (7533, NULL, '2012-01-20 12:54:44.568163+00', 'Melrose', 9999, '');
INSERT INTO 'tune' VALUES (7534, NULL, '2012-01-20 12:54:44.571063+00', 'Auld Selkirk', 2659, '');
INSERT INTO 'tune' VALUES (7535, NULL, '2012-01-20 12:54:44.573951+00', 'Peebles', 9999, '');
INSERT INTO 'tune' VALUES (7536, NULL, '2012-01-20 12:54:44.576842+00', 'Jethart''s Here', 2660, '');
INSERT INTO 'tune' VALUES (7539, NULL, '2012-01-20 12:54:44.585586+00', 'Bert Murray the Fiddler', 1726, '');
INSERT INTO 'tune' VALUES (7540, NULL, '2012-01-20 12:54:44.588522+00', 'Invercauld March, The', 9999, '');
INSERT INTO 'tune' VALUES (7541, NULL, '2012-01-20 12:54:44.591427+00', 'Quick Step', 9999, '');
INSERT INTO 'tune' VALUES (7542, NULL, '2012-01-20 12:54:44.594329+00', 'Carol the Pointer', 1660, '');
INSERT INTO 'tune' VALUES (7543, NULL, '2012-01-20 12:54:44.597213+00', 'Angus Grant''s Reel', 2666, '');
INSERT INTO 'tune' VALUES (7544, NULL, '2012-01-20 12:54:44.600105+00', 'Thrums March', 9999, '');
INSERT INTO 'tune' VALUES (7545, NULL, '2012-01-20 12:54:44.602996+00', 'Miss Rona McLachlan', 2667, '');
INSERT INTO 'tune' VALUES (7546, NULL, '2012-01-20 12:54:44.605885+00', 'Forth Bridge Jig', 2668, '');
INSERT INTO 'tune' VALUES (7547, NULL, '2012-01-20 12:54:44.60878+00', 'Glendale Strathspey, The', 2608, '');
INSERT INTO 'tune' VALUES (7548, NULL, '2012-01-20 12:54:44.611674+00', 'Pentland Jig, The', 1585, '');
INSERT INTO 'tune' VALUES (7549, NULL, '2012-01-20 12:54:44.61456+00', 'Harbour, The', 1505, '');
INSERT INTO 'tune' VALUES (7538, NULL, '2014-08-11 15:34:26.696405+00', 'Calgary Fiddlers'' Welcome to Shetland, The', 2662, '');
INSERT INTO 'tune' VALUES (7471, NULL, '2014-08-24 14:47:14.04614+00', 'Bob Cotton', 9999, '');
INSERT INTO 'tune' VALUES (7483, NULL, '2014-11-06 17:26:24.396389+00', 'Tibbertey''s Jean', 1512, '');
INSERT INTO 'tune' VALUES (7550, NULL, '2012-01-20 12:54:44.617445+00', 'Home to Bon Accord', 1817, '');
INSERT INTO 'tune' VALUES (7551, NULL, '2012-01-20 12:54:44.620368+00', 'On the Fiddle', 2669, '');
INSERT INTO 'tune' VALUES (7552, NULL, '2012-01-20 12:54:44.62326+00', 'Salute to Glen Grant', 1601, '');
INSERT INTO 'tune' VALUES (7553, NULL, '2012-01-20 12:54:44.626152+00', 'Fond Farewell', 1601, '');
INSERT INTO 'tune' VALUES (7554, NULL, '2012-01-20 12:54:44.629045+00', 'Rev. Peter Davidson, The', 1598, '');
INSERT INTO 'tune' VALUES (7555, NULL, '2012-01-20 12:54:44.631936+00', 'Busker''s Delight', 1791, '');
INSERT INTO 'tune' VALUES (7556, NULL, '2012-01-20 12:54:44.634827+00', 'Murray River Jig, The', 9999, '');
INSERT INTO 'tune' VALUES (7557, NULL, '2012-01-20 12:54:44.637708+00', 'Heather Hills', 9999, '');
INSERT INTO 'tune' VALUES (7558, NULL, '2012-01-20 12:54:44.640592+00', 'Alex Muir''s Reel', 1531, '');
INSERT INTO 'tune' VALUES (7559, NULL, '2012-01-20 12:54:44.643491+00', 'Clatty Pat''s', 1812, '');
INSERT INTO 'tune' VALUES (7560, NULL, '2012-01-20 12:54:44.646379+00', 'Balmoral Castle', 9999, '');
INSERT INTO 'tune' VALUES (7561, NULL, '2012-01-20 12:54:44.649275+00', 'Jim Rae of Lockerbie', 2085, '');
INSERT INTO 'tune' VALUES (7562, NULL, '2012-01-20 12:54:44.652166+00', 'Jim Rae', 1502, '');
INSERT INTO 'tune' VALUES (7563, NULL, '2012-01-20 12:54:44.65506+00', 'Out of the Doldrums', 1582, '');
INSERT INTO 'tune' VALUES (7564, NULL, '2012-01-20 12:54:44.657943+00', 'Celtic Fling', 1815, '');
INSERT INTO 'tune' VALUES (7565, NULL, '2012-01-20 12:54:44.661376+00', 'Leeks and Thistles', 1815, '');
INSERT INTO 'tune' VALUES (7566, NULL, '2012-01-20 12:54:44.6643+00', 'Grants of Lochinver, The', 1586, '');
INSERT INTO 'tune' VALUES (7567, NULL, '2012-01-20 12:54:44.667202+00', 'David Low, Kintore', 2629, '');
INSERT INTO 'tune' VALUES (7568, NULL, '2012-01-20 12:54:44.670096+00', 'Highlandman Kissed his Mother, The', 1518, '');
INSERT INTO 'tune' VALUES (7570, NULL, '2012-01-20 12:54:44.677986+00', 'Noble Society of Celts Reel', 2671, '');
INSERT INTO 'tune' VALUES (7571, NULL, '2012-01-20 12:54:44.680913+00', 'Glasgow Lasses', 9998, '');
INSERT INTO 'tune' VALUES (7572, NULL, '2012-01-20 12:54:44.683816+00', 'Duke of Rothesay, The', 326, '');
INSERT INTO 'tune' VALUES (7573, NULL, '2012-01-20 12:54:44.686716+00', 'Sunlit Glen', 326, '');
INSERT INTO 'tune' VALUES (7574, NULL, '2012-01-20 12:54:44.689616+00', 'Ochil View', 1084, '');
INSERT INTO 'tune' VALUES (7575, NULL, '2012-01-20 12:54:44.692524+00', 'Scott Meikle', 1508, '');
INSERT INTO 'tune' VALUES (7576, NULL, '2012-01-20 12:54:44.695433+00', 'Kathkin Braes', 9999, '');
INSERT INTO 'tune' VALUES (7577, NULL, '2012-01-20 12:54:44.698348+00', 'Dancing Dominie, The', 1508, '');
INSERT INTO 'tune' VALUES (7578, NULL, '2012-01-20 12:54:44.70124+00', 'Waverley Steps', 9999, '');
INSERT INTO 'tune' VALUES (7579, NULL, '2012-01-20 12:54:44.704142+00', 'Auchinellan Jig', 1508, '');
INSERT INTO 'tune' VALUES (7580, NULL, '2012-01-20 12:54:44.70704+00', 'Mrs Shena Steen', 1813, '');
INSERT INTO 'tune' VALUES (7581, NULL, '2012-01-20 12:54:44.709934+00', 'Three Score Years and Ten', 1502, '');
INSERT INTO 'tune' VALUES (7582, NULL, '2012-01-20 12:54:44.71283+00', 'Amherst Two-Step', 2689, '');
INSERT INTO 'tune' VALUES (7583, NULL, '2012-01-20 12:54:44.715733+00', 'Gardener''s Fancy, A', 2692, '');
INSERT INTO 'tune' VALUES (7584, NULL, '2012-01-20 12:54:44.71863+00', 'Coire nam Mang', 2690, '');
INSERT INTO 'tune' VALUES (7585, NULL, '2012-01-20 12:54:44.721519+00', 'Cha Till Mis''a''Seoladh', 2691, '');
INSERT INTO 'tune' VALUES (7586, NULL, '2012-01-20 12:54:44.724437+00', 'Mo Dhachaidh', 9999, '');
INSERT INTO 'tune' VALUES (7587, NULL, '2012-01-20 12:54:44.727567+00', 'Away to Chincoteague', 2692, '');
INSERT INTO 'tune' VALUES (7588, NULL, '2012-01-20 12:54:44.730869+00', 'Tin Woodman, The', 2692, '');
INSERT INTO 'tune' VALUES (7589, NULL, '2012-01-20 12:54:44.733817+00', 'Jim Hendrie''s Reel', 2693, '');
INSERT INTO 'tune' VALUES (7590, NULL, '2012-01-20 12:54:44.736726+00', 'Bobby Stewart''s Reel', 2693, '');
INSERT INTO 'tune' VALUES (7591, NULL, '2012-01-20 12:54:44.73963+00', 'Ross''s Reel', 2693, '');
INSERT INTO 'tune' VALUES (7592, NULL, '2012-01-20 12:54:44.742526+00', 'Miss Emma Hendrie', 2693, '');
INSERT INTO 'tune' VALUES (7593, NULL, '2012-01-20 12:54:44.745418+00', 'Grace Renwick Polka', 1527, '');
INSERT INTO 'tune' VALUES (7594, NULL, '2012-01-20 12:54:44.74837+00', 'Half Pint Jig', 2692, '');
INSERT INTO 'tune' VALUES (7595, NULL, '2012-01-20 12:54:44.751292+00', 'Springtime Jig, A', 2692, '');
INSERT INTO 'tune' VALUES (7597, NULL, '2012-01-20 12:54:44.757085+00', 'Five Minute Strathspey', 2692, '');
INSERT INTO 'tune' VALUES (7598, NULL, '2012-01-20 12:54:44.759983+00', 'Such a Wife as Wille Had', 9999, '');
INSERT INTO 'tune' VALUES (7600, NULL, '2012-01-20 12:54:44.765779+00', 'Braighe Bhanbh', 9999, '');
INSERT INTO 'tune' VALUES (7601, NULL, '2012-01-20 12:54:44.768679+00', 'Mrs Maitland of Freugh''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (7603, NULL, '2012-01-20 12:54:44.774483+00', 'Rolling Jig, The', 2695, '');
INSERT INTO 'tune' VALUES (7604, NULL, '2012-01-20 12:54:44.777377+00', 'Joan''s Birthday Jig', 2695, '');
INSERT INTO 'tune' VALUES (7605, NULL, '2012-01-20 12:54:44.780285+00', 'Jonty''s Jig', 2695, '');
INSERT INTO 'tune' VALUES (7606, NULL, '2012-01-20 12:54:44.783183+00', 'Ragtime Annie', 9999, '');
INSERT INTO 'tune' VALUES (7607, NULL, '2012-01-20 12:54:44.78608+00', 'Up Jumped the Devil', 2697, '');
INSERT INTO 'tune' VALUES (7608, NULL, '2012-01-20 12:54:44.78898+00', 'Raggity Anne', 9999, '');
INSERT INTO 'tune' VALUES (7602, NULL, '2020-02-29 15:12:13.905332+00', 'Raincloud, The', 2695, '');
INSERT INTO 'tune' VALUES (7609, NULL, '2012-01-20 12:54:44.79189+00', 'Miss Irene Armstrong of Helensburgh', 2698, '');
INSERT INTO 'tune' VALUES (7610, NULL, '2012-01-20 12:54:44.794787+00', 'Ian and Carol Aitken of MacGregor', 2698, '');
INSERT INTO 'tune' VALUES (7611, NULL, '2012-01-20 12:54:44.797677+00', 'Vivianae', 1539, '');
INSERT INTO 'tune' VALUES (7612, NULL, '2012-01-20 12:54:44.800575+00', 'Mr John Trotter of Castlelaw''s Hornpipe', 1519, '');
INSERT INTO 'tune' VALUES (7613, NULL, '2012-01-20 12:54:44.803485+00', 'Callam Brougach', 9999, '');
INSERT INTO 'tune' VALUES (7614, NULL, '2012-01-20 12:54:44.806369+00', 'Miss Grant''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (7615, NULL, '2012-01-20 12:54:44.809261+00', 'We Are All Right at Canterbury', 9999, '');
INSERT INTO 'tune' VALUES (7616, NULL, '2012-01-20 12:54:44.812176+00', 'Resolution, The', 9999, '');
INSERT INTO 'tune' VALUES (7617, NULL, '2012-01-20 12:54:44.815081+00', 'Abercairney House', 9999, '');
INSERT INTO 'tune' VALUES (7618, NULL, '2012-01-20 12:54:44.817965+00', 'Miss Jardine''s Strathspey', 2646, '');
INSERT INTO 'tune' VALUES (7619, NULL, '2012-01-20 12:54:44.82087+00', 'Strath-Mhathaisidh', 2142, '');
INSERT INTO 'tune' VALUES (7620, NULL, '2012-01-20 12:54:44.823787+00', 'Old Spedling Castle''s Ghost''s Dance, The', 2646, '');
INSERT INTO 'tune' VALUES (7621, NULL, '2012-01-20 12:54:44.826685+00', 'Lady Ross''s Jig', 2646, '');
INSERT INTO 'tune' VALUES (13855, '2018-03-30 09:31:03.272516+00', '2018-03-30 09:31:03.272516+00', 'Teach the World to Sing', 9999, '');
INSERT INTO 'tune' VALUES (7623, NULL, '2012-01-20 12:54:44.832476+00', 'Lieutenant Charles Clapperton''s Jig', 2646, '');
INSERT INTO 'tune' VALUES (7624, NULL, '2012-01-20 12:54:44.835429+00', 'She Beg She More', 1882, '');
INSERT INTO 'tune' VALUES (7625, NULL, '2012-01-20 12:54:44.838337+00', 'Sir George Mackenzie', 9999, '');
INSERT INTO 'tune' VALUES (7626, NULL, '2012-01-20 12:54:44.841265+00', 'Miss E Macleod''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (7627, NULL, '2012-01-20 12:54:44.844172+00', 'Miss Mary Stewart of Derculich', 1695, '');
INSERT INTO 'tune' VALUES (7628, NULL, '2012-01-20 12:54:44.847078+00', 'Duke of York''s Camp, The', 2613, '');
INSERT INTO 'tune' VALUES (7629, NULL, '2012-01-20 12:54:44.849973+00', 'Miss Helen Campbell Ardmore''s Jig', 2478, '');
INSERT INTO 'tune' VALUES (7630, NULL, '2012-01-20 12:54:44.852866+00', 'T.C. Humbley''s', 2699, '');
INSERT INTO 'tune' VALUES (7631, NULL, '2012-01-20 12:54:44.855761+00', 'C-Scape', 1539, '');
INSERT INTO 'tune' VALUES (7632, NULL, '2012-01-20 12:54:44.858652+00', 'Blue Head Reel, The', 1539, '');
INSERT INTO 'tune' VALUES (7633, NULL, '2012-01-20 12:54:44.861654+00', 'Breakdown, The', 1539, '');
INSERT INTO 'tune' VALUES (7634, NULL, '2012-01-20 12:54:44.864555+00', 'Just a Small One - I Have to Dance', 1539, '');
INSERT INTO 'tune' VALUES (7636, NULL, '2012-01-20 12:54:44.870347+00', 'Daft Willie', 9998, '');
INSERT INTO 'tune' VALUES (7637, NULL, '2012-01-20 12:54:44.873679+00', 'Lone Vale, The', 9998, '');
INSERT INTO 'tune' VALUES (7638, NULL, '2012-01-20 12:54:44.876616+00', 'Glenelg', 9998, '');
INSERT INTO 'tune' VALUES (7639, NULL, '2012-01-20 12:54:44.879527+00', 'Land o'' the Lilt', 9998, '');
INSERT INTO 'tune' VALUES (7640, NULL, '2012-01-20 12:54:44.882446+00', 'Jack Liberson''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (7641, NULL, '2012-01-20 12:54:44.885356+00', 'Earl of Dunmore, The', 9999, '');
INSERT INTO 'tune' VALUES (7642, NULL, '2012-01-20 12:54:44.888254+00', 'Celtic Braid, The', 2392, '');
INSERT INTO 'tune' VALUES (7643, NULL, '2012-01-20 12:54:44.891156+00', 'Shy Anne', 2208, '');
INSERT INTO 'tune' VALUES (7644, NULL, '2012-01-20 12:54:44.894048+00', 'Flight of the Falcon, The', 2208, '');
INSERT INTO 'tune' VALUES (7645, NULL, '2012-01-20 12:54:44.896945+00', 'Beyond Ambivalence', 2392, '');
INSERT INTO 'tune' VALUES (7646, NULL, '2012-01-20 12:54:44.899898+00', 'Hazelwood', 2392, '');
INSERT INTO 'tune' VALUES (7647, NULL, '2012-01-20 12:54:44.902806+00', 'Chickadee, The', 2392, '');
INSERT INTO 'tune' VALUES (7648, NULL, '2012-01-20 12:54:44.905698+00', 'Kettle River Strathspey', 2392, '');
INSERT INTO 'tune' VALUES (7649, NULL, '2012-01-20 12:54:44.908592+00', 'Lady Grace', 2392, '');
INSERT INTO 'tune' VALUES (7650, NULL, '2012-01-20 12:54:44.911481+00', 'McIntosh Legs, The', 2392, '');
INSERT INTO 'tune' VALUES (7651, NULL, '2012-01-20 12:54:44.914377+00', 'Rush Hour Reel', 2392, '');
INSERT INTO 'tune' VALUES (7652, NULL, '2012-01-20 12:54:44.91779+00', 'Tapestry, The', 2392, '');
INSERT INTO 'tune' VALUES (7653, NULL, '2012-01-20 12:54:44.920726+00', 'Andrew Knight', 1576, '');
INSERT INTO 'tune' VALUES (7654, NULL, '2012-01-20 12:54:44.923651+00', 'Joan''s Jig', 1527, '');
INSERT INTO 'tune' VALUES (7655, NULL, '2012-01-20 12:54:44.926633+00', 'Farmer''s Daughter, The', 9999, '');
INSERT INTO 'tune' VALUES (7656, NULL, '2012-01-20 12:54:44.929598+00', 'Kinlochmore', 1543, '');
INSERT INTO 'tune' VALUES (7657, NULL, '2012-01-20 12:54:44.932509+00', 'Corriegills', 1424, '');
INSERT INTO 'tune' VALUES (7658, NULL, '2012-01-20 12:54:44.9354+00', 'Kitchener''s Reel', 1525, '');
INSERT INTO 'tune' VALUES (7659, NULL, '2012-01-20 12:54:44.938295+00', 'Alistair P Thomson', 1603, '');
INSERT INTO 'tune' VALUES (7660, NULL, '2012-01-20 12:54:44.941249+00', 'Jock McLeod''s Wedding March', 2715, '');
INSERT INTO 'tune' VALUES (7661, NULL, '2012-01-20 12:54:44.944165+00', 'Hal Robinson''s Rant', 2717, '');
INSERT INTO 'tune' VALUES (7662, NULL, '2012-01-20 12:54:44.947058+00', 'Dance for Sylvia, A', 1505, '');
INSERT INTO 'tune' VALUES (7663, NULL, '2012-01-20 12:54:44.949948+00', 'Aberdeen Schottische', 1505, '');
INSERT INTO 'tune' VALUES (7664, NULL, '2012-01-20 12:54:44.952833+00', 'Earl of Northampton, The', 2720, '');
INSERT INTO 'tune' VALUES (7665, NULL, '2012-01-20 12:54:44.955723+00', '25th Reel, The', 1461, '');
INSERT INTO 'tune' VALUES (7666, NULL, '2012-01-20 12:54:44.958612+00', 'Craigies, The', 2724, '');
INSERT INTO 'tune' VALUES (7667, NULL, '2012-01-20 12:54:44.961501+00', 'Furth, Fortune, and Fill the Fetters', 1773, '');
INSERT INTO 'tune' VALUES (7668, NULL, '2012-01-20 12:54:44.964401+00', 'To the Next Twenty-Five', 2726, '');
INSERT INTO 'tune' VALUES (7669, NULL, '2012-01-20 12:54:44.967298+00', 'Heather''s Song', 2726, '');
INSERT INTO 'tune' VALUES (7670, NULL, '2012-01-20 12:54:44.970186+00', 'Tein''aigheir air gach beann dhuibh', 9999, '');
INSERT INTO 'tune' VALUES (7671, NULL, '2012-01-20 12:54:44.973081+00', 'Cameron MacFadyen', 9998, '');
INSERT INTO 'tune' VALUES (7672, NULL, '2012-01-20 12:54:44.975978+00', 'Lucy''s Song', 9998, '');
INSERT INTO 'tune' VALUES (7673, NULL, '2012-01-20 12:54:44.978868+00', 'Lord Byron''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (7674, NULL, '2012-01-20 12:54:44.981748+00', 'Dunkeld Hermitage', 1518, '');
INSERT INTO 'tune' VALUES (7675, NULL, '2012-01-20 12:54:44.984638+00', 'Kipling''s Rant', 2717, '');
INSERT INTO 'tune' VALUES (7676, NULL, '2012-01-20 12:54:44.987549+00', 'Ettrick Banks', 9999, '');
INSERT INTO 'tune' VALUES (7677, NULL, '2012-01-20 12:54:44.990441+00', 'Allan Water', 9999, '');
INSERT INTO 'tune' VALUES (7678, NULL, '2012-01-20 12:54:44.993323+00', 'Lady Elizabeth Cole''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (7679, NULL, '2012-01-20 12:54:44.996216+00', 'Baddeck Gathering, The', 2738, '');
INSERT INTO 'tune' VALUES (7681, NULL, '2012-01-20 12:54:45.002008+00', 'But and Ben', 9999, '');
INSERT INTO 'tune' VALUES (7682, NULL, '2012-01-20 12:54:45.004909+00', 'Wappinschaw, The', 9999, '');
INSERT INTO 'tune' VALUES (7683, NULL, '2012-01-20 12:54:45.007811+00', 'Sudmalinas', 9999, '');
INSERT INTO 'tune' VALUES (7684, NULL, '2012-01-20 12:54:45.010741+00', 'Shetland Welcome, A', 1692, '');
INSERT INTO 'tune' VALUES (7685, NULL, '2012-01-20 12:54:45.013639+00', 'Dervaig Ladies Jig, The', 1692, '');
INSERT INTO 'tune' VALUES (7686, NULL, '2012-01-20 12:54:45.016533+00', 'Simmer Dim, The', 1692, '');
INSERT INTO 'tune' VALUES (7687, NULL, '2012-01-20 12:54:45.020234+00', 'Dancing Forth', 2743, '');
INSERT INTO 'tune' VALUES (7680, NULL, '2012-04-03 20:47:26.018835+00', 'Hughie Shortie''s Reel', 2341, 'Taken from Paul Cranford''s website.  Composer named as "Johnny Wilmot"');
INSERT INTO 'tune' VALUES (7689, NULL, '2012-01-20 12:54:45.026113+00', 'Brian''s Bairns', 2744, '');
INSERT INTO 'tune' VALUES (7691, NULL, '2012-01-20 12:54:45.031922+00', 'Dersingham Bog', 9998, '');
INSERT INTO 'tune' VALUES (7692, NULL, '2012-01-20 12:54:45.034814+00', 'New Town, The', 1522, '');
INSERT INTO 'tune' VALUES (7693, NULL, '2012-01-20 12:54:45.037707+00', 'Peterborough Ten, The', 2251, '');
INSERT INTO 'tune' VALUES (7694, NULL, '2012-01-20 12:54:45.040672+00', 'Cross Keys, The', 2251, '');
INSERT INTO 'tune' VALUES (7695, NULL, '2012-01-20 12:54:45.043611+00', 'Snow on Snow', 1479, '');
INSERT INTO 'tune' VALUES (7696, NULL, '2012-01-20 12:54:45.046521+00', 'George', 1522, '');
INSERT INTO 'tune' VALUES (7697, NULL, '2012-01-20 12:54:45.049418+00', 'Cantie''s Brig', 1610, '');
INSERT INTO 'tune' VALUES (7698, NULL, '2012-01-20 12:54:45.052314+00', 'Country Ball, The', 9998, '');
INSERT INTO 'tune' VALUES (7699, NULL, '2012-01-20 12:54:45.055208+00', 'Cat on the Fiddle, The', 2763, '');
INSERT INTO 'tune' VALUES (7700, NULL, '2012-01-20 12:54:45.05811+00', 'Entwives, The', 2763, '');
INSERT INTO 'tune' VALUES (7701, NULL, '2012-01-20 12:54:45.061003+00', 'Point Road, The', 1890, '');
INSERT INTO 'tune' VALUES (7702, NULL, '2012-01-20 12:54:45.063889+00', 'Gilly Flower, The', 9998, '');
INSERT INTO 'tune' VALUES (7703, NULL, '2012-01-20 12:54:45.0668+00', 'Mrs Flora Inglis', 1815, '');
INSERT INTO 'tune' VALUES (7704, NULL, '2012-01-20 12:54:45.069701+00', 'Distillery Reel, The', 1591, '');
INSERT INTO 'tune' VALUES (7705, NULL, '2012-01-20 12:54:45.072609+00', 'Balnain House', 2768, '');
INSERT INTO 'tune' VALUES (7706, NULL, '2012-01-20 12:54:45.075502+00', 'Highland Ladies', 1586, '');
INSERT INTO 'tune' VALUES (7708, NULL, '2012-01-20 12:54:45.081283+00', 'Swinmark Reel, The', 228, '');
INSERT INTO 'tune' VALUES (7709, NULL, '2012-01-20 12:54:45.084723+00', 'Aline Cook', 2197, '');
INSERT INTO 'tune' VALUES (7711, NULL, '2012-01-20 12:54:45.090667+00', 'Hunt of the Gnomes, The', 228, '');
INSERT INTO 'tune' VALUES (7712, NULL, '2012-01-20 12:54:45.093762+00', 'Giant''s Causeway, The', 1203, '');
INSERT INTO 'tune' VALUES (7714, NULL, '2012-01-20 12:54:45.099844+00', 'Mill-Ennium Jig, The', 228, '');
INSERT INTO 'tune' VALUES (7715, NULL, '2012-01-20 12:54:45.102895+00', 'Humphrey''s Tune', 228, '');
INSERT INTO 'tune' VALUES (7716, NULL, '2012-01-20 12:54:45.105975+00', 'Heike Nagorny (Strathspey)', 228, '');
INSERT INTO 'tune' VALUES (7717, NULL, '2012-01-20 12:54:45.109103+00', 'Heike Nagorny (Reel)', 228, '');
INSERT INTO 'tune' VALUES (7718, NULL, '2012-01-20 12:54:45.112103+00', 'Trip to Ireland, A', 1634, '');
INSERT INTO 'tune' VALUES (7719, NULL, '2012-01-20 12:54:45.115029+00', 'Yellow Rose of Texas', 9998, '');
INSERT INTO 'tune' VALUES (7720, NULL, '2012-01-20 12:54:45.117932+00', 'Bill Reid', 9998, '');
INSERT INTO 'tune' VALUES (7721, NULL, '2012-01-20 12:54:45.121142+00', 'Thames Bridge', 9998, '');
INSERT INTO 'tune' VALUES (7723, NULL, '2012-01-20 12:54:45.127987+00', 'Inisfree', 1203, '');
INSERT INTO 'tune' VALUES (7724, NULL, '2012-01-20 12:54:45.130972+00', 'Blue Stack Mountains, The', 1203, '');
INSERT INTO 'tune' VALUES (7725, NULL, '2012-01-20 12:54:45.133872+00', 'Tatting Shuttle, The', 1203, '');
INSERT INTO 'tune' VALUES (7726, NULL, '2012-01-20 12:54:45.136776+00', 'Leprechaun, The', 1203, '');
INSERT INTO 'tune' VALUES (7727, NULL, '2012-01-20 12:54:45.139676+00', 'Wee Folk, The', 1203, '');
INSERT INTO 'tune' VALUES (7728, NULL, '2012-01-20 12:54:45.142572+00', 'Magic Circle, The', 1203, '');
INSERT INTO 'tune' VALUES (7729, NULL, '2012-01-20 12:54:45.145459+00', 'Claddagh Ring, The', 1203, '');
INSERT INTO 'tune' VALUES (7730, NULL, '2012-01-20 12:54:45.148347+00', 'Pledge of Love, The', 1203, '');
INSERT INTO 'tune' VALUES (7731, NULL, '2012-01-20 12:54:45.15127+00', 'Craic, The', 1203, '');
INSERT INTO 'tune' VALUES (7732, NULL, '2012-01-20 12:54:45.154239+00', 'Irish Mist', 1203, '');
INSERT INTO 'tune' VALUES (7733, NULL, '2012-01-20 12:54:45.157137+00', 'Wee Dram, A', 1203, '');
INSERT INTO 'tune' VALUES (7734, NULL, '2012-01-20 12:54:45.160061+00', 'Flaxen Maiden, The', 1203, '');
INSERT INTO 'tune' VALUES (7735, NULL, '2012-01-20 12:54:45.162965+00', 'Gentle Mist, The', 1203, '');
INSERT INTO 'tune' VALUES (7736, NULL, '2012-01-20 12:54:45.165854+00', 'Shamrock Two Step, The', 1203, '');
INSERT INTO 'tune' VALUES (7737, NULL, '2012-01-20 12:54:45.168764+00', 'Tens Pins, The', 1203, '');
INSERT INTO 'tune' VALUES (7738, NULL, '2012-01-20 12:54:45.171674+00', 'Mpho''s Majority', 550, '');
INSERT INTO 'tune' VALUES (7739, NULL, '2012-01-20 12:54:45.176638+00', 'Tryst with Cati Ramsay, A', 1502, '');
INSERT INTO 'tune' VALUES (7740, NULL, '2012-01-20 12:54:45.179555+00', 'Ken Simm', 810, '');
INSERT INTO 'tune' VALUES (7741, NULL, '2012-01-20 12:54:45.182454+00', 'Peter and Madeleine''s Wedding', 1576, '');
INSERT INTO 'tune' VALUES (7742, NULL, '2012-01-20 12:54:45.185355+00', 'Off to Tipperary', 9998, '');
INSERT INTO 'tune' VALUES (7710, NULL, '2012-09-02 20:23:25.713282+00', 'Jim and Aline Cook', 2197, '');
INSERT INTO 'tune' VALUES (7743, NULL, '2012-01-20 12:54:45.188257+00', 'Birdbone, The', 2775, '');
INSERT INTO 'tune' VALUES (7744, NULL, '2012-01-20 12:54:45.19117+00', 'Michael''s Broken Leg', 2775, '');
INSERT INTO 'tune' VALUES (7745, NULL, '2012-01-20 12:54:45.194051+00', 'Brindister Two Step', 2775, '');
INSERT INTO 'tune' VALUES (7746, NULL, '2012-01-20 12:54:45.196945+00', 'Veterinarian, The', 1572, '');
INSERT INTO 'tune' VALUES (7747, NULL, '2012-01-20 12:54:45.199833+00', 'Mrs Effie McKelvie''s Reel', 2777, '');
INSERT INTO 'tune' VALUES (7748, NULL, '2012-01-20 12:54:45.202734+00', 'Jean Thomson', 1871, '');
INSERT INTO 'tune' VALUES (7749, NULL, '2012-01-20 12:54:45.205638+00', 'Brian Webb''s March', 1580, '');
INSERT INTO 'tune' VALUES (7751, NULL, '2012-01-20 12:54:45.211681+00', 'Startled Cat', 1593, '');
INSERT INTO 'tune' VALUES (7752, NULL, '2012-01-20 12:54:45.214601+00', 'Fair Wind, A', 2778, '');
INSERT INTO 'tune' VALUES (7753, NULL, '2012-01-20 12:54:45.217501+00', 'For tonight we''ll merry, merry be', 9998, '');
INSERT INTO 'tune' VALUES (7754, NULL, '2012-01-20 12:54:45.220419+00', 'Constellation', 2786, '');
INSERT INTO 'tune' VALUES (7755, NULL, '2012-01-20 12:54:45.223315+00', 'Corny Reel', 2785, '');
INSERT INTO 'tune' VALUES (7756, NULL, '2012-01-20 12:54:45.22621+00', 'Dancing on Parnassus', 2763, '');
INSERT INTO 'tune' VALUES (7757, NULL, '2012-01-20 12:54:45.229097+00', 'Laddie''s Choice', 2763, '');
INSERT INTO 'tune' VALUES (7758, NULL, '2012-01-20 12:54:45.232005+00', 'Full Moon', 2786, '');
INSERT INTO 'tune' VALUES (7759, NULL, '2012-01-20 12:54:45.2349+00', 'Galaxy, The', 2786, '');
INSERT INTO 'tune' VALUES (7760, NULL, '2012-01-20 12:54:45.237788+00', 'Connie''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (7761, NULL, '2012-01-20 12:54:45.240696+00', 'John Middleton''s Reel', 2085, '');
INSERT INTO 'tune' VALUES (7762, NULL, '2012-01-20 12:54:45.243616+00', 'Roy''s Threescore and Ten', 1572, '');
INSERT INTO 'tune' VALUES (7763, NULL, '2012-01-20 12:54:45.246518+00', 'Gie Us A Hand', 2392, '');
INSERT INTO 'tune' VALUES (7764, NULL, '2012-01-20 12:54:45.249414+00', 'Mews, The', 2392, '');
INSERT INTO 'tune' VALUES (7707, NULL, '2018-08-17 11:53:53.435118+00', 'Memories of Father Angus MacDonnell', 2769, '');
INSERT INTO 'tune' VALUES (7765, NULL, '2012-01-20 12:54:45.252317+00', 'Campanula Strathspey', 2392, '');
INSERT INTO 'tune' VALUES (7766, NULL, '2012-01-20 12:54:45.255214+00', 'Streaky Bacon Reel', 2392, '');
INSERT INTO 'tune' VALUES (7767, NULL, '2012-01-20 12:54:45.258102+00', 'Red Sash, The', 2392, '');
INSERT INTO 'tune' VALUES (7768, NULL, '2012-01-20 12:54:45.260994+00', 'Left-Handed Queen, The', 2392, '');
INSERT INTO 'tune' VALUES (7872, NULL, '2012-01-20 12:54:45.5649+00', 'Reflections', 2197, '');
INSERT INTO 'tune' VALUES (7769, NULL, '2012-01-20 12:54:45.263888+00', 'All-Soul''s Strathspey', 2392, '');
INSERT INTO 'tune' VALUES (7770, NULL, '2012-01-20 12:54:45.266778+00', 'Grand Portage Reel', 2392, '');
INSERT INTO 'tune' VALUES (7771, NULL, '2012-01-20 12:54:45.269663+00', 'Circles on the Moor', 2392, '');
INSERT INTO 'tune' VALUES (7772, NULL, '2012-01-20 12:54:45.272573+00', 'Groom''s Jig, The', 1506, '');
INSERT INTO 'tune' VALUES (7773, NULL, '2012-01-20 12:54:45.275468+00', 'Warehouse, The', 1501, '');
INSERT INTO 'tune' VALUES (7774, NULL, '2012-01-20 12:54:45.278367+00', 'Ardrossan Hornpipe', 1502, '');
INSERT INTO 'tune' VALUES (7775, NULL, '2012-01-20 12:54:45.281256+00', 'Soft Shoe Hornpipe, The', 1502, '');
INSERT INTO 'tune' VALUES (7777, NULL, '2012-01-20 12:54:45.287051+00', 'Ruby Wedding, The', 1501, '');
INSERT INTO 'tune' VALUES (7778, NULL, '2012-01-20 12:54:45.28994+00', 'Brighouse Feast', 1506, '');
INSERT INTO 'tune' VALUES (7779, NULL, '2012-01-20 12:54:45.29286+00', 'Susanne Hegel''s Strathspey', 1815, '');
INSERT INTO 'tune' VALUES (7780, NULL, '2012-01-20 12:54:45.295756+00', '42nds Farewell to Waterloo', 9999, '');
INSERT INTO 'tune' VALUES (7781, NULL, '2012-01-20 12:54:45.298654+00', '42nds Farewell to India', 2738, '');
INSERT INTO 'tune' VALUES (7782, NULL, '2012-01-20 12:54:45.301539+00', 'Dukes of Buccleuch''s March, The', 9999, '');
INSERT INTO 'tune' VALUES (7783, NULL, '2012-01-20 12:54:45.304431+00', 'Argyllshire Squadron of the Scottish Horse, The', 1889, '');
INSERT INTO 'tune' VALUES (7784, NULL, '2012-01-20 12:54:45.307326+00', 'Braes of Rannoch, The', 9999, '');
INSERT INTO 'tune' VALUES (7785, NULL, '2012-01-20 12:54:45.310222+00', 'Mr Yasumuro''s Strathspey', 1556, '');
INSERT INTO 'tune' VALUES (7786, NULL, '2012-01-20 12:54:45.313183+00', 'Lady Charlotte Anne''s Wedding March, The', 1556, '');
INSERT INTO 'tune' VALUES (7787, NULL, '2012-01-20 12:54:45.316095+00', 'Thick Lies the Mist on Yonder Hill', 9999, '');
INSERT INTO 'tune' VALUES (7788, NULL, '2012-01-20 12:54:45.318996+00', 'Madam McKerrell of Hillhouse', 1556, '');
INSERT INTO 'tune' VALUES (7789, NULL, '2012-01-20 12:54:45.321885+00', 'Lt. Col. Ashmore', 1683, '');
INSERT INTO 'tune' VALUES (7790, NULL, '2012-01-20 12:54:45.324786+00', 'Piper''s Waltz, The', 9999, '');
INSERT INTO 'tune' VALUES (7791, NULL, '2012-01-20 12:54:45.327715+00', 'Atsuko''s Waltz', 1556, '');
INSERT INTO 'tune' VALUES (7792, NULL, '2012-01-20 12:54:45.330612+00', 'Ladies frae Hell, The', 2799, '');
INSERT INTO 'tune' VALUES (7793, NULL, '2012-01-20 12:54:45.333533+00', 'Nick Randall''s Jig', 1556, '');
INSERT INTO 'tune' VALUES (7794, NULL, '2012-01-20 12:54:45.336435+00', 'Jig for Charlotte Anne, A', 1556, '');
INSERT INTO 'tune' VALUES (7750, NULL, '2012-02-12 20:52:26.525864+00', '40 Shades of Green', 10605, 'Johhny Cash was a world famous Country and Western singer who wrote the 

music and the words which go with it for Fourty Shades of Green in the 

1960''s following a visit to Ireland.  Born 26/2/1932 died 12/9/2003.

If you google him plenty of more information

');
INSERT INTO 'tune' VALUES (7795, NULL, '2012-01-20 12:54:45.339332+00', 'Country Girl and the Hungarian Fiddler, The', 2800, '');
INSERT INTO 'tune' VALUES (7796, NULL, '2012-01-20 12:54:45.342234+00', 'I Am A Young Man That Lived with my Mother', 9999, '');
INSERT INTO 'tune' VALUES (7797, NULL, '2012-01-20 12:54:45.345122+00', 'Robin Anderson (Orkney)', 1593, '');
INSERT INTO 'tune' VALUES (7798, NULL, '2012-01-20 12:54:45.348011+00', 'Portree Blue Boat, The', 1735, '');
INSERT INTO 'tune' VALUES (7799, NULL, '2012-01-20 12:54:45.350896+00', 'Hiding Behind the Pillars', 1502, '');
INSERT INTO 'tune' VALUES (7800, NULL, '2012-01-20 12:54:45.353785+00', 'Birches, The', 1551, '');
INSERT INTO 'tune' VALUES (7801, NULL, '2012-01-20 12:54:45.356696+00', 'Murray McAndrew', 1502, '');
INSERT INTO 'tune' VALUES (7803, NULL, '2012-01-20 12:54:45.362513+00', 'Slockit Light, Da', 1710, '');
INSERT INTO 'tune' VALUES (7804, NULL, '2012-01-20 12:54:45.365425+00', 'Shiela Gardiner''s Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (7805, NULL, '2012-01-20 12:54:45.368323+00', 'Mary Murphy', 9999, '');
INSERT INTO 'tune' VALUES (7806, NULL, '2012-01-20 12:54:45.371224+00', 'Muriel Johnstone''s Compliments to Ian Findlay', 1502, '');
INSERT INTO 'tune' VALUES (7807, NULL, '2012-01-20 12:54:45.374114+00', 'Splice the Mainbrace', 1502, '');
INSERT INTO 'tune' VALUES (7808, NULL, '2012-01-20 12:54:45.377019+00', 'You Can''t Pay That Bill', 2801, '');
INSERT INTO 'tune' VALUES (7809, NULL, '2012-01-20 12:54:45.379932+00', 'Miss Eileen Meiklejohn', 1502, '');
INSERT INTO 'tune' VALUES (7810, NULL, '2012-01-20 12:54:45.382841+00', 'George & Carmen Ritchie', 1502, '');
INSERT INTO 'tune' VALUES (7811, NULL, '2012-01-20 12:54:45.385734+00', 'Sue''s Hot Tub', 1502, '');
INSERT INTO 'tune' VALUES (7812, NULL, '2012-01-20 12:54:45.388631+00', 'Kirk House', 1585, '');
INSERT INTO 'tune' VALUES (7813, NULL, '2012-01-20 12:54:45.391527+00', 'Miss Margaret Johnstone', 1585, '');
INSERT INTO 'tune' VALUES (7814, NULL, '2012-01-20 12:54:45.39443+00', 'Shoot the Craw', 1502, '');
INSERT INTO 'tune' VALUES (7815, NULL, '2012-01-20 12:54:45.397328+00', 'H.M.S. Aurora', 1506, '');
INSERT INTO 'tune' VALUES (7816, NULL, '2012-01-20 12:54:45.400221+00', 'Corpach Ceilidh, The', 1502, '');
INSERT INTO 'tune' VALUES (7817, NULL, '2012-01-20 12:54:45.403128+00', 'Alan''s Jig', 1582, '');
INSERT INTO 'tune' VALUES (7818, NULL, '2012-01-20 12:54:45.408112+00', 'Half Century Jig, The', 2807, '');
INSERT INTO 'tune' VALUES (7819, NULL, '2012-01-20 12:54:45.411027+00', 'Jan Douglas', 1725, '');
INSERT INTO 'tune' VALUES (7820, NULL, '2012-01-20 12:54:45.413917+00', 'Inglesyde', 2807, '');
INSERT INTO 'tune' VALUES (7821, NULL, '2012-01-20 12:54:45.416824+00', 'Helen Andrew''s Jig', 1725, '');
INSERT INTO 'tune' VALUES (7822, NULL, '2012-01-20 12:54:45.419719+00', 'Sheila Mannall', 1725, '');
INSERT INTO 'tune' VALUES (7823, NULL, '2012-01-20 12:54:45.42263+00', 'Lilburn Tower', 2807, '');
INSERT INTO 'tune' VALUES (7802, NULL, '2021-07-06 22:02:59.295321+00', 'Miss Mary MacKay''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (7824, NULL, '2012-01-20 12:54:45.425531+00', 'Gary Tulloch''s Reel', 1709, '');
INSERT INTO 'tune' VALUES (7825, NULL, '2012-01-20 12:54:45.428426+00', 'Stronchullin Strathspey', 1709, '');
INSERT INTO 'tune' VALUES (7826, NULL, '2012-01-20 12:54:45.431338+00', 'Happy Couple, The', 2807, '');
INSERT INTO 'tune' VALUES (7827, NULL, '2012-01-20 12:54:45.434238+00', 'Reception, The', 2807, '');
INSERT INTO 'tune' VALUES (7828, NULL, '2012-01-20 12:54:45.437139+00', 'Farewell to the Rise', 1725, '');
INSERT INTO 'tune' VALUES (7829, NULL, '2012-01-20 12:54:45.440036+00', 'Stonewell Cottage', 1725, '');
INSERT INTO 'tune' VALUES (7830, NULL, '2012-01-20 12:54:45.442992+00', 'Eileen Midgley of Pinchinthorpe', 1709, '');
INSERT INTO 'tune' VALUES (7831, NULL, '2012-01-20 12:54:45.445914+00', 'Tyneside Jig, The', 1725, '');
INSERT INTO 'tune' VALUES (7832, NULL, '2012-01-20 12:54:45.448805+00', 'Caylie''s Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (7833, NULL, '2012-01-20 12:54:45.451704+00', 'Jan Wilson''s Strathspey', 1899, '');
INSERT INTO 'tune' VALUES (7834, NULL, '2012-01-20 12:54:45.454601+00', 'Betty Washington', 1512, '');
INSERT INTO 'tune' VALUES (7836, NULL, '2012-01-20 12:54:45.460405+00', 'Metric Jig, The', 9998, '');
INSERT INTO 'tune' VALUES (7837, NULL, '2012-01-20 12:54:45.463297+00', 'Kelvingrove Park', 9998, '');
INSERT INTO 'tune' VALUES (7838, NULL, '2012-01-20 12:54:45.466187+00', 'Mrs Loreta Blair', 9998, '');
INSERT INTO 'tune' VALUES (7839, NULL, '2012-01-20 12:54:45.469077+00', 'Franklyn Hall', 9998, '');
INSERT INTO 'tune' VALUES (7840, NULL, '2012-01-20 12:54:45.47197+00', 'Cauld Comfort', 1899, '');
INSERT INTO 'tune' VALUES (7841, NULL, '2012-01-20 12:54:45.474866+00', 'Loch Ruadhainn', 9998, '');
INSERT INTO 'tune' VALUES (7843, NULL, '2012-01-20 12:54:45.480664+00', 'Mac mhic Alastair', 9998, '');
INSERT INTO 'tune' VALUES (7845, NULL, '2012-01-20 12:54:45.486449+00', 'Mackenzie Fraser', 9998, '');
INSERT INTO 'tune' VALUES (7846, NULL, '2012-01-20 12:54:45.489333+00', 'Bungalow, The', 1512, '');
INSERT INTO 'tune' VALUES (7842, NULL, '2012-10-17 11:20:44.122971+00', '''Bhliadhn'' ur', 2142, '');
INSERT INTO 'tune' VALUES (7847, NULL, '2012-01-20 12:54:45.492226+00', 'Pushee''s Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (7848, NULL, '2012-01-20 12:54:45.495133+00', 'Resident Fiddler Marries, The', 2222, '');
INSERT INTO 'tune' VALUES (7849, NULL, '2012-01-20 12:54:45.498035+00', 'Captain MacDuff''s Delight', 1519, '');
INSERT INTO 'tune' VALUES (7850, NULL, '2012-01-20 12:54:45.50094+00', 'Mrs Duff''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (7851, NULL, '2012-01-20 12:54:45.503828+00', 'James Duff, M.P.', 1516, '');
INSERT INTO 'tune' VALUES (7852, NULL, '2012-01-20 12:54:45.506721+00', 'Mr Aldridge''s Favorite Hornpipe', 1519, '');
INSERT INTO 'tune' VALUES (7853, NULL, '2012-01-20 12:54:45.509617+00', 'Wemyss Castle', 1517, '');
INSERT INTO 'tune' VALUES (7854, NULL, '2012-01-20 12:54:45.512508+00', 'Jig', 1928, '');
INSERT INTO 'tune' VALUES (7855, NULL, '2012-01-20 12:54:45.515399+00', 'Gigg', 1928, '');
INSERT INTO 'tune' VALUES (7856, NULL, '2012-01-20 12:54:45.518301+00', 'Ian MacLeish', 1554, '');
INSERT INTO 'tune' VALUES (7857, NULL, '2012-01-20 12:54:45.521206+00', 'Tilly Tennant', 1538, '');
INSERT INTO 'tune' VALUES (7858, NULL, '2012-01-20 12:54:45.524112+00', 'Mrs Babs Anderson', 1710, '');
INSERT INTO 'tune' VALUES (7859, NULL, '2012-01-20 12:54:45.527101+00', 'Master Sandy Meldrum', 1507, '');
INSERT INTO 'tune' VALUES (7860, NULL, '2012-01-20 12:54:45.530088+00', 'Eugene & Marion Skinner of Trail B.C.', 1576, '');
INSERT INTO 'tune' VALUES (7861, NULL, '2012-01-20 12:54:45.532995+00', 'Alistair Hunter', 1505, '');
INSERT INTO 'tune' VALUES (7862, NULL, '2012-01-20 12:54:45.535891+00', 'Poacher Wattie', 1538, '');
INSERT INTO 'tune' VALUES (7863, NULL, '2012-01-20 12:54:45.538794+00', 'William''s Hope', 2197, '');
INSERT INTO 'tune' VALUES (7864, NULL, '2012-01-20 12:54:45.541689+00', 'In Memory of William', 2197, '');
INSERT INTO 'tune' VALUES (7865, NULL, '2012-01-20 12:54:45.544578+00', 'William''s Delight', 2197, '');
INSERT INTO 'tune' VALUES (7866, NULL, '2012-01-20 12:54:45.547484+00', 'Light on Your Feet', 2197, '');
INSERT INTO 'tune' VALUES (7867, NULL, '2012-01-20 12:54:45.550392+00', 'Betty Wilde''s Delight', 2197, '');
INSERT INTO 'tune' VALUES (7868, NULL, '2012-01-20 12:54:45.553303+00', 'Wallace Strathspey, The', 2197, '');
INSERT INTO 'tune' VALUES (7869, NULL, '2012-01-20 12:54:45.556202+00', 'Gae Doon the Wynds', 2197, '');
INSERT INTO 'tune' VALUES (7870, NULL, '2012-01-20 12:54:45.55911+00', 'Follow in Hope', 2197, '');
INSERT INTO 'tune' VALUES (7871, NULL, '2012-01-20 12:54:45.562003+00', 'Reminiscences', 2197, '');
INSERT INTO 'tune' VALUES (7873, NULL, '2012-01-20 12:54:45.567796+00', 'Shadow Catcher', 1836, '');
INSERT INTO 'tune' VALUES (7874, NULL, '2012-01-20 12:54:45.570693+00', 'Stan Hamilton''s Compliments to Gordon McHaffie', 2054, '');
INSERT INTO 'tune' VALUES (7875, NULL, '2012-01-20 12:54:45.573593+00', 'Salute to the Chip Shop', 228, '');
INSERT INTO 'tune' VALUES (7876, NULL, '2012-01-20 12:54:45.576492+00', 'Margaret and David Williams', 1590, '');
INSERT INTO 'tune' VALUES (7877, NULL, '2012-01-20 12:54:45.579403+00', 'Ready Steady Ann', 2801, '');
INSERT INTO 'tune' VALUES (7878, NULL, '2012-01-20 12:54:45.582308+00', 'Allison''s Jig', 1824, '');
INSERT INTO 'tune' VALUES (7879, NULL, '2012-01-20 12:54:45.585199+00', 'Muirs of Greywell, The', 1527, '');
INSERT INTO 'tune' VALUES (7880, NULL, '2012-01-20 12:54:45.58811+00', 'David Hall''s Compliments to the Rousseaus', 1534, '');
INSERT INTO 'tune' VALUES (7881, NULL, '2012-01-20 12:54:45.591022+00', 'Phoenix, The', 2836, '');
INSERT INTO 'tune' VALUES (7882, NULL, '2012-01-20 12:54:45.593916+00', 'Honeymoon Jig, The', 1551, '');
INSERT INTO 'tune' VALUES (7883, NULL, '2012-01-20 12:54:45.59682+00', 'Sair Fecht, A', 1505, '');
INSERT INTO 'tune' VALUES (7884, NULL, '2012-01-20 12:54:45.599727+00', 'Johnstone Jig, The', 1505, '');
INSERT INTO 'tune' VALUES (7885, NULL, '2012-01-20 12:54:45.602631+00', 'Dod and Mary Michie''s Jig', 2509, '');
INSERT INTO 'tune' VALUES (7886, NULL, '2012-01-20 12:54:45.605516+00', 'Currie''s Rambles', 9999, '');
INSERT INTO 'tune' VALUES (7887, NULL, '2012-01-20 12:54:45.608427+00', 'Countess of Seafield, The', 1748, '');
INSERT INTO 'tune' VALUES (7888, NULL, '2012-01-20 12:54:45.611354+00', 'William & Doris Stubbert', 1791, '');
INSERT INTO 'tune' VALUES (7889, NULL, '2012-01-20 12:54:45.614264+00', 'Mike Saunders Jig', 1633, '');
INSERT INTO 'tune' VALUES (7890, NULL, '2012-01-20 12:54:45.617186+00', 'Winning Ticket, The', 2238, '');
INSERT INTO 'tune' VALUES (7891, NULL, '2012-01-20 12:54:45.620084+00', 'Bee''s Knees, The', 2837, '');
INSERT INTO 'tune' VALUES (7892, NULL, '2012-01-20 12:54:45.622986+00', 'Mike''s Fancy', 1633, '');
INSERT INTO 'tune' VALUES (7893, NULL, '2012-01-20 12:54:45.625874+00', 'Camper Van, The', 1633, '');
INSERT INTO 'tune' VALUES (7894, NULL, '2012-01-20 12:54:45.62877+00', 'Oomlie''s Reel', 3058, '');
INSERT INTO 'tune' VALUES (7895, NULL, '2012-01-20 12:54:45.631671+00', 'Muckle Friday', 1505, '');
INSERT INTO 'tune' VALUES (7896, NULL, '2012-01-20 12:54:45.634567+00', 'Bobby, The', 1505, '');
INSERT INTO 'tune' VALUES (7897, NULL, '2012-01-20 12:54:45.637461+00', 'Lempit Cuddie', 1535, '');
INSERT INTO 'tune' VALUES (7898, NULL, '2012-01-20 12:54:45.640355+00', 'Jim Muir''s Reel', 1811, '');
INSERT INTO 'tune' VALUES (7899, NULL, '2012-01-20 12:54:45.643278+00', 'Rae''s Reel', 1557, '');
INSERT INTO 'tune' VALUES (7900, NULL, '2012-01-20 12:54:45.646186+00', 'Auld Resting Chair, Da', 1710, '');
INSERT INTO 'tune' VALUES (7901, NULL, '2012-01-20 12:54:45.649087+00', 'Mrs Mary Milne of Banchory', 2838, '');
INSERT INTO 'tune' VALUES (7902, NULL, '2012-01-20 12:54:45.651975+00', 'Howick SCD Club, The', 1572, '');
INSERT INTO 'tune' VALUES (7903, NULL, '2012-01-20 12:54:45.655505+00', 'Hurcheon, The', 1725, '');
INSERT INTO 'tune' VALUES (7904, NULL, '2012-01-20 12:54:45.658751+00', 'Lord Drighorn''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (7905, NULL, '2012-01-20 12:54:45.661843+00', 'Perth Races', 2839, '');
INSERT INTO 'tune' VALUES (7906, NULL, '2012-01-20 12:54:45.665231+00', 'Miss Charlotte Stirling''s Jig', 1749, '');
INSERT INTO 'tune' VALUES (7907, NULL, '2012-01-20 12:54:45.668159+00', 'Kathleen''s Jig', 1572, '');
INSERT INTO 'tune' VALUES (7908, NULL, '2012-01-20 12:54:45.671058+00', 'Goat ina a Boat, The', 1539, '');
INSERT INTO 'tune' VALUES (7909, NULL, '2012-01-20 12:54:45.673946+00', 'Tony and Sue', 1871, '');
INSERT INTO 'tune' VALUES (7910, NULL, '2012-01-20 12:54:45.676841+00', 'Miss Catherine''s Favourite', 2840, '');
INSERT INTO 'tune' VALUES (7911, NULL, '2012-01-20 12:54:45.679731+00', 'Ranting Robbie', 696, '');
INSERT INTO 'tune' VALUES (7912, NULL, '2012-01-20 12:54:45.682658+00', 'Corriehalloch Hornpipe', 1719, '');
INSERT INTO 'tune' VALUES (7913, NULL, '2012-01-20 12:54:45.685561+00', 'Peerie Abernethy', 1502, '');
INSERT INTO 'tune' VALUES (7914, NULL, '2012-01-20 12:54:45.688461+00', 'Rhoda McFadyen', 1554, '');
INSERT INTO 'tune' VALUES (7915, NULL, '2012-01-20 12:54:45.69136+00', 'Peggy''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (7916, NULL, '2012-01-20 12:54:45.694255+00', 'Pamela Hollis', 1764, '');
INSERT INTO 'tune' VALUES (7917, NULL, '2012-01-20 12:54:45.697145+00', 'Leslie Braes', 1764, '');
INSERT INTO 'tune' VALUES (7918, NULL, '2012-01-20 12:54:45.700033+00', 'Dan Lees Caman', 2842, '');
INSERT INTO 'tune' VALUES (7919, NULL, '2012-01-20 12:54:45.702926+00', 'Bill Ewan''s Reel', 2843, '');
INSERT INTO 'tune' VALUES (7920, NULL, '2012-01-20 12:54:45.705826+00', 'Caledonian March', 9999, '');
INSERT INTO 'tune' VALUES (7921, NULL, '2012-01-20 12:54:45.708722+00', 'Lt.Co. P.W. Forbes of Corse O.B.E.', 2800, '');
INSERT INTO 'tune' VALUES (7922, NULL, '2012-01-20 12:54:45.711622+00', 'Saint Monans', 1502, '');
INSERT INTO 'tune' VALUES (7923, NULL, '2012-01-20 12:54:45.714515+00', 'Gillburn Jig, The', 1554, '');
INSERT INTO 'tune' VALUES (7924, NULL, '2012-01-20 12:54:45.717422+00', 'Miss Casalegno''s Delight', 1502, '');
INSERT INTO 'tune' VALUES (7925, NULL, '2012-01-20 12:54:45.720332+00', 'Sebastian''s Birthday', 1502, '');
INSERT INTO 'tune' VALUES (7926, NULL, '2012-01-20 12:54:45.723248+00', 'Anna Mairi Lumsden', 1502, '');
INSERT INTO 'tune' VALUES (7928, NULL, '2012-01-20 12:54:45.729212+00', 'Fife Ness', 1764, '');
INSERT INTO 'tune' VALUES (7929, NULL, '2012-01-20 12:54:45.732132+00', 'Spooks of Cologne, The', 2848, '');
INSERT INTO 'tune' VALUES (7930, NULL, '2012-01-20 12:54:45.73502+00', 'MacPhedran''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (7931, NULL, '2012-01-20 12:54:45.737906+00', 'Mrs Ernest Allan', 1607, '');
INSERT INTO 'tune' VALUES (7932, NULL, '2012-01-20 12:54:45.740797+00', 'Hamish McIntosh', 1607, '');
INSERT INTO 'tune' VALUES (7933, NULL, '2012-01-20 12:54:45.743699+00', 'Dava Moor', 2854, '');
INSERT INTO 'tune' VALUES (7934, NULL, '2012-01-20 12:54:45.746674+00', 'Duthie Park', 165, '');
INSERT INTO 'tune' VALUES (7935, NULL, '2012-01-20 12:54:45.749588+00', 'Langstane Kirk', 1607, '');
INSERT INTO 'tune' VALUES (7936, NULL, '2012-01-20 12:54:45.752517+00', 'Beechwood', 2856, '');
INSERT INTO 'tune' VALUES (7937, NULL, '2012-01-20 12:54:45.755425+00', 'Gladys McDonald', 2857, '');
INSERT INTO 'tune' VALUES (7938, NULL, '2012-01-20 12:54:45.758314+00', 'Glencoe', 2857, '');
INSERT INTO 'tune' VALUES (7939, NULL, '2012-01-20 12:54:45.761212+00', 'Alice McLennan''s Strathspey', 2857, '');
INSERT INTO 'tune' VALUES (7940, NULL, '2012-01-20 12:54:45.764105+00', 'Earl and Countess of Haddo, The', 1607, '');
INSERT INTO 'tune' VALUES (7941, NULL, '2012-01-20 12:54:45.767011+00', 'Tollohill', 1538, '');
INSERT INTO 'tune' VALUES (7942, NULL, '2012-01-20 12:54:45.769898+00', 'Dry-stane Dyker, The', 1538, '');
INSERT INTO 'tune' VALUES (7943, NULL, '2012-01-20 12:54:45.772794+00', 'Corby Loch', 1538, '');
INSERT INTO 'tune' VALUES (7944, NULL, '2012-01-20 12:54:45.775684+00', 'Bonaly Burn', 1538, '');
INSERT INTO 'tune' VALUES (7945, NULL, '2012-01-20 12:54:45.778576+00', 'Flora MacDonald''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (7946, NULL, '2012-01-20 12:54:45.781462+00', 'Nighean bhuidhe bhoidheach', 9998, '');
INSERT INTO 'tune' VALUES (7947, NULL, '2012-01-20 12:54:45.784369+00', 'Larry Grogan', 9999, '');
INSERT INTO 'tune' VALUES (7949, NULL, '2012-01-20 12:54:45.790167+00', 'Mrs MacKenzie of Applecross', 1632, '');
INSERT INTO 'tune' VALUES (7950, NULL, '2012-01-20 12:54:45.793085+00', 'My Wife''s a Drunkard', 9999, '');
INSERT INTO 'tune' VALUES (7951, NULL, '2012-01-20 12:54:45.795985+00', 'Irish Hearts to the Ladies', 9999, '');
INSERT INTO 'tune' VALUES (7952, NULL, '2012-01-20 12:54:45.798888+00', 'Tracey MacKenzie''s Two-Step', 1511, '');
INSERT INTO 'tune' VALUES (7927, NULL, '2012-10-31 22:59:21.426728+00', 'John Anthony Ireland', 1502, 'AABB');
INSERT INTO 'tune' VALUES (7953, NULL, '2012-01-20 12:54:45.801779+00', 'Davin MacKenzie Applebee', 1511, '');
INSERT INTO 'tune' VALUES (7954, NULL, '2012-01-20 12:54:45.804679+00', 'Divertimento', 2820, '');
INSERT INTO 'tune' VALUES (7955, NULL, '2012-01-20 12:54:45.807574+00', 'Life Boat', 9999, '');
INSERT INTO 'tune' VALUES (7956, NULL, '2012-01-20 12:54:45.810454+00', 'Ohio', 9999, '');
INSERT INTO 'tune' VALUES (7957, NULL, '2012-01-20 12:54:45.813339+00', 'Valley of the Dry Bones', 1511, '');
INSERT INTO 'tune' VALUES (7958, NULL, '2012-01-20 12:54:45.816237+00', 'Cajun Fiddlin'' on the Bayou', 2653, '');
INSERT INTO 'tune' VALUES (7959, NULL, '2012-01-20 12:54:45.819133+00', 'Southern Melody', 9999, '');
INSERT INTO 'tune' VALUES (7960, NULL, '2012-01-20 12:54:45.822014+00', 'Foxey Donna', 2858, '');
INSERT INTO 'tune' VALUES (7962, NULL, '2012-01-20 12:54:45.827812+00', 'Mississippi Sawyer', 9999, '');
INSERT INTO 'tune' VALUES (7963, NULL, '2012-01-20 12:54:45.830708+00', 'No Corn on Tygart', 3738, '');
INSERT INTO 'tune' VALUES (7964, NULL, '2012-01-20 12:54:45.833594+00', 'Patsy MacDonald''s Reel', 2859, '');
INSERT INTO 'tune' VALUES (7965, NULL, '2012-01-20 12:54:45.836495+00', 'Why Not', 9998, '');
INSERT INTO 'tune' VALUES (7966, NULL, '2012-01-20 12:54:45.839402+00', 'Shambles, The', 1501, '');
INSERT INTO 'tune' VALUES (7967, NULL, '2012-01-20 12:54:45.842335+00', 'Dreaming', 2883, '');
INSERT INTO 'tune' VALUES (7968, NULL, '2012-01-20 12:54:45.845274+00', 'Mysteries of Knock, The', 9999, '');
INSERT INTO 'tune' VALUES (7969, NULL, '2012-01-20 12:54:45.848194+00', 'Miss Birgit Röhricht of Bielefeld', 228, '');
INSERT INTO 'tune' VALUES (7970, NULL, '2012-01-20 12:54:45.851103+00', 'Daunder in the Glen', 2898, '');
INSERT INTO 'tune' VALUES (7971, NULL, '2012-01-20 12:54:45.853999+00', 'Janeil Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (7972, NULL, '2012-01-20 12:54:45.856917+00', 'Jaunty Jack', 2898, '');
INSERT INTO 'tune' VALUES (7973, NULL, '2012-01-20 12:54:45.859816+00', 'Heather Bank Jig, The', 1526, '');
INSERT INTO 'tune' VALUES (7974, NULL, '2012-01-20 12:54:45.862712+00', 'Avis''s Fancy', 131, '');
INSERT INTO 'tune' VALUES (7975, NULL, '2012-01-20 12:54:45.865615+00', 'Brendan Bernard', 1808, '');
INSERT INTO 'tune' VALUES (7976, NULL, '2012-01-20 12:54:45.868532+00', 'Dunblane Capers', 2897, '');
INSERT INTO 'tune' VALUES (7977, NULL, '2012-01-20 12:54:45.871903+00', 'Heather Anne McClure', 391, '');
INSERT INTO 'tune' VALUES (7978, NULL, '2012-01-20 12:54:45.874846+00', 'Auld Brig, The', 2897, '');
INSERT INTO 'tune' VALUES (7979, NULL, '2012-01-20 12:54:45.877741+00', 'Ochlochy Park', 2897, '');
INSERT INTO 'tune' VALUES (7980, NULL, '2012-01-20 12:54:45.880644+00', 'Maggie & Jock', 1958, '');
INSERT INTO 'tune' VALUES (7981, NULL, '2012-01-20 12:54:45.883544+00', 'Bridge of Allan Capers', 2897, '');
INSERT INTO 'tune' VALUES (7982, NULL, '2012-01-20 12:54:45.886443+00', 'Gathering Stone', 2897, '');
INSERT INTO 'tune' VALUES (7983, NULL, '2012-01-20 12:54:45.889373+00', 'Potted Hough', 391, '');
INSERT INTO 'tune' VALUES (7984, NULL, '2012-01-20 12:54:45.892267+00', 'Cowane Centre, The', 1951, '');
INSERT INTO 'tune' VALUES (7985, NULL, '2012-01-20 12:54:45.895156+00', 'Borestone Standard, The', 1951, '');
INSERT INTO 'tune' VALUES (7986, NULL, '2012-01-20 12:54:45.898047+00', 'Fourways Roundabout', 2897, '');
INSERT INTO 'tune' VALUES (7987, NULL, '2012-01-20 12:54:45.900944+00', 'Ruby''s Jig', 2902, '');
INSERT INTO 'tune' VALUES (7988, NULL, '2012-01-20 12:54:45.903841+00', 'Hydro-Board''s Friend, The', 391, '');
INSERT INTO 'tune' VALUES (7989, NULL, '2012-01-20 12:54:45.906745+00', 'Kilted Runner, The', 9998, '');
INSERT INTO 'tune' VALUES (7990, NULL, '2012-01-20 12:54:45.909634+00', 'Darn Road, The', 2897, '');
INSERT INTO 'tune' VALUES (7991, NULL, '2012-01-20 12:54:45.91253+00', 'Nanette''s Fancy', 2897, '');
INSERT INTO 'tune' VALUES (7992, NULL, '2012-01-20 12:54:45.915421+00', 'Strathallan Jig, The', 1951, '');
INSERT INTO 'tune' VALUES (7993, NULL, '2012-01-20 12:54:45.918308+00', 'Black Boy, The', 1951, '');
INSERT INTO 'tune' VALUES (7994, NULL, '2012-01-20 12:54:45.921189+00', 'Trumpeter, The', 2897, '');
INSERT INTO 'tune' VALUES (7995, NULL, '2012-01-20 12:54:45.924081+00', 'Laird of Lemana, The', 391, '');
INSERT INTO 'tune' VALUES (7996, NULL, '2012-01-20 12:54:45.926999+00', 'Bonfire Reel, The', 2897, '');
INSERT INTO 'tune' VALUES (7997, NULL, '2012-01-20 12:54:45.929952+00', 'Mrs Mamie Dick', 1430, '');
INSERT INTO 'tune' VALUES (7998, NULL, '2012-01-20 12:54:45.932854+00', 'Maureen & Ian''s Farewell to Craigmount', 1679, '');
INSERT INTO 'tune' VALUES (7999, NULL, '2012-01-20 12:54:45.935754+00', 'Gosford House', 1679, '');
INSERT INTO 'tune' VALUES (8000, NULL, '2012-01-20 12:54:45.938632+00', 'Return of the Stone, The', 1704, '');
INSERT INTO 'tune' VALUES (8001, NULL, '2012-01-20 12:54:45.941517+00', 'Whale''s Jaw Bone, The', 1430, '');
INSERT INTO 'tune' VALUES (8002, NULL, '2012-01-20 12:54:45.944408+00', 'Red Biretta Reel', 2908, '');
INSERT INTO 'tune' VALUES (8003, NULL, '2012-01-20 12:54:45.957671+00', 'Bob and Helen Duff', 1595, '');
INSERT INTO 'tune' VALUES (8004, NULL, '2012-01-20 12:54:45.960696+00', 'Broughty Flittin''', 2914, '');
INSERT INTO 'tune' VALUES (8005, NULL, '2012-01-20 12:54:45.963605+00', 'Scots Brigade, The', 1572, '');
INSERT INTO 'tune' VALUES (8006, NULL, '2012-01-20 12:54:45.966505+00', 'Pauline Cathcart''s Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (8007, NULL, '2012-01-20 12:54:45.969458+00', 'Wonderful Time in the Warenar', 1502, '');
INSERT INTO 'tune' VALUES (8008, NULL, '2012-01-20 12:54:45.972397+00', 'Tom and Anja''s Silver Wedding', 1572, '');
INSERT INTO 'tune' VALUES (8009, NULL, '2012-01-20 12:54:45.975299+00', 'Life Begins at Fifty', 1572, '');
INSERT INTO 'tune' VALUES (8010, NULL, '2012-01-20 12:54:45.978183+00', 'Jarig Jetje', 9999, '');
INSERT INTO 'tune' VALUES (8011, NULL, '2012-01-20 12:54:45.98107+00', 'Aad''s Farewell to Delft', 1572, '');
INSERT INTO 'tune' VALUES (8012, NULL, '2012-01-20 12:54:45.98396+00', 'Bell-Founders, The', 1572, '');
INSERT INTO 'tune' VALUES (8014, NULL, '2012-01-20 12:54:45.989745+00', 'Jim & Isabelle Lawrie''s March', 9998, '');
INSERT INTO 'tune' VALUES (8015, NULL, '2012-01-20 12:54:45.992648+00', 'Maxina, The', 9998, '');
INSERT INTO 'tune' VALUES (8016, NULL, '2012-01-20 12:54:45.995536+00', 'Curly McRory', 1578, '');
INSERT INTO 'tune' VALUES (8017, NULL, '2012-01-20 12:54:45.998423+00', 'Louise''s Reel', 1582, '');
INSERT INTO 'tune' VALUES (8018, NULL, '2012-01-20 12:54:46.001308+00', 'Hobson''s Choice', 9998, '');
INSERT INTO 'tune' VALUES (8019, NULL, '2012-01-20 12:54:46.004201+00', 'Mrs Joan Russell', 1621, '');
INSERT INTO 'tune' VALUES (8020, NULL, '2012-01-20 12:54:46.007097+00', 'Whinbush, The', 1754, '');
INSERT INTO 'tune' VALUES (8022, NULL, '2012-01-20 12:54:46.012875+00', 'Dumfries Doglet, The', 1526, '');
INSERT INTO 'tune' VALUES (8023, '2003-03-21 23:00:00+00', '2012-01-20 12:54:46.01578+00', 'Bouncing Bustle, The', 2626, '');
INSERT INTO 'tune' VALUES (8024, NULL, '2012-01-20 12:54:46.018698+00', 'Kerry''s Fancy', 1585, '');
INSERT INTO 'tune' VALUES (8025, NULL, '2012-01-20 12:54:46.021591+00', 'Donald J MacDonald', 2389, '');
INSERT INTO 'tune' VALUES (8026, NULL, '2012-01-20 12:54:46.024484+00', 'Maureen''s Reel', 1770, '');
INSERT INTO 'tune' VALUES (8027, NULL, '2012-01-20 12:54:46.027376+00', 'Dinkie Dorian''s Reel', 2940, '');
INSERT INTO 'tune' VALUES (8028, NULL, '2012-01-20 12:54:46.030268+00', 'Young Uns, The', 1084, '');
INSERT INTO 'tune' VALUES (8029, NULL, '2012-01-20 12:54:46.03316+00', 'Other Way, Mother, The', 1084, '');
INSERT INTO 'tune' VALUES (8030, NULL, '2012-01-20 12:54:46.036048+00', 'Accidental Damage', 1084, '');
INSERT INTO 'tune' VALUES (8021, NULL, '2012-01-29 10:46:10.331141+00', 'Daffodil, The', 1815, '');
INSERT INTO 'tune' VALUES (8031, NULL, '2012-01-20 12:54:46.038949+00', 'Spot of Bother, A', 1084, '');
INSERT INTO 'tune' VALUES (8032, NULL, '2012-01-20 12:54:46.04187+00', 'Ynyslas', 2943, '');
INSERT INTO 'tune' VALUES (8033, NULL, '2012-01-20 12:54:46.044894+00', 'Young at Heart', 1084, '');
INSERT INTO 'tune' VALUES (8034, NULL, '2012-01-20 12:54:46.047813+00', 'A Morrison', 2946, '');
INSERT INTO 'tune' VALUES (8036, NULL, '2012-01-20 12:54:46.053777+00', 'Lauren Holmes Patrick', 1668, '');
INSERT INTO 'tune' VALUES (8037, NULL, '2012-01-20 12:54:46.056677+00', 'Cadger''s Brig', 1719, '');
INSERT INTO 'tune' VALUES (8038, NULL, '2012-01-20 12:54:46.059579+00', 'Coir an Lochan', 1735, '');
INSERT INTO 'tune' VALUES (8039, NULL, '2012-01-20 12:54:46.06248+00', 'Moira Sinclair', 1527, '');
INSERT INTO 'tune' VALUES (8040, NULL, '2012-01-20 12:54:46.065379+00', 'Mary of Argyle', 9999, '');
INSERT INTO 'tune' VALUES (8041, NULL, '2012-01-20 12:54:46.068294+00', 'Bobby Brown''s Jig', 2160, '');
INSERT INTO 'tune' VALUES (8042, NULL, '2012-01-20 12:54:46.071179+00', 'Mrs McKenzie', 9999, '');
INSERT INTO 'tune' VALUES (8043, NULL, '2012-01-20 12:54:46.074069+00', 'Reel for Di', 2856, '');
INSERT INTO 'tune' VALUES (8044, NULL, '2012-01-20 12:54:46.076957+00', 'Farewell to the Cottage', 2948, '');
INSERT INTO 'tune' VALUES (8045, NULL, '2012-01-20 12:54:46.079854+00', 'Fiddlin'' Round', 2961, '');
INSERT INTO 'tune' VALUES (8046, NULL, '2012-01-20 12:54:46.082747+00', 'Lady in Red', 2961, 'The Lady in Red is Muriel Johnstone');
INSERT INTO 'tune' VALUES (8047, NULL, '2012-01-20 12:54:46.085637+00', 'Queen Mary', 1567, '');
INSERT INTO 'tune' VALUES (8013, NULL, '2020-10-29 17:56:16.437924+00', 'Monty Lister''s Quickstep', 1555, '');
INSERT INTO 'tune' VALUES (8048, NULL, '2012-01-20 12:54:46.088532+00', 'Regards to Helen Frame', 1871, '');
INSERT INTO 'tune' VALUES (8049, NULL, '2012-01-20 12:54:46.091438+00', 'Helen Frame''s Jig', 1576, '');
INSERT INTO 'tune' VALUES (8050, NULL, '2012-01-20 12:54:46.094332+00', 'Miss Elizabeth Dewar', 1476, '');
INSERT INTO 'tune' VALUES (8051, NULL, '2012-01-20 12:54:46.097539+00', 'Miss Leslie of Saint Andrews', 1470, '');
INSERT INTO 'tune' VALUES (8052, NULL, '2012-01-20 12:54:46.10046+00', 'Hon Margaret Erskine, The', 1476, '');
INSERT INTO 'tune' VALUES (8053, NULL, '2012-01-20 12:54:46.103361+00', 'Miss Jane Gordon''s Reel', 1518, '');
INSERT INTO 'tune' VALUES (8054, NULL, '2012-01-20 12:54:46.106256+00', 'Theme from Long Journey Home', 2964, '');
INSERT INTO 'tune' VALUES (8055, NULL, '2012-01-20 12:54:46.109142+00', 'From My Childhood', 2965, '');
INSERT INTO 'tune' VALUES (8056, NULL, '2012-01-20 12:54:46.112072+00', 'Wee Kevin''s Marching Air', 2085, '');
INSERT INTO 'tune' VALUES (8057, NULL, '2012-01-20 12:54:46.114989+00', 'Biven''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (8058, NULL, '2012-01-20 12:54:46.117894+00', 'Fasten the Wig on Her', 9999, '');
INSERT INTO 'tune' VALUES (8059, NULL, '2012-01-20 12:54:46.121113+00', 'Sporting Boys, The', 9999, '');
INSERT INTO 'tune' VALUES (8060, NULL, '2012-01-20 12:54:46.12472+00', 'Gillespie''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (8061, NULL, '2012-01-20 12:54:46.128013+00', 'Whistling Mike', 9999, '');
INSERT INTO 'tune' VALUES (8062, NULL, '2012-01-20 12:54:46.130984+00', 'Foxie Mary', 9999, '');
INSERT INTO 'tune' VALUES (8063, NULL, '2012-01-20 12:54:46.133882+00', 'Riley''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (8064, NULL, '2012-01-20 12:54:46.136773+00', 'Seven Up', 9999, '');
INSERT INTO 'tune' VALUES (8065, NULL, '2012-01-20 12:54:46.139673+00', 'Laugh at Fate', 1512, '');
INSERT INTO 'tune' VALUES (8066, NULL, '2012-01-20 12:54:46.142585+00', 'Dublin Jig, The', 9999, '');
INSERT INTO 'tune' VALUES (8067, NULL, '2012-01-20 12:54:46.145483+00', 'Young Tim Murphy', 9999, '');
INSERT INTO 'tune' VALUES (8068, NULL, '2012-01-20 12:54:46.148377+00', 'Skim Milk', 9999, '');
INSERT INTO 'tune' VALUES (8069, NULL, '2012-01-20 12:54:46.15127+00', 'Miss Farquarson''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (8071, NULL, '2012-01-20 12:54:46.154161+00', 'Mrs Mure of Caldwell', 9999, '');
INSERT INTO 'tune' VALUES (8072, NULL, '2012-01-20 12:54:46.157055+00', 'Waking of the Fauld, The', 9999, '');
INSERT INTO 'tune' VALUES (8073, NULL, '2012-01-20 12:54:46.159982+00', 'Green Forever, The', 9999, '');
INSERT INTO 'tune' VALUES (8074, NULL, '2012-01-20 12:54:46.162887+00', 'Bow-Legged Tailor, The', 9999, '');
INSERT INTO 'tune' VALUES (8075, NULL, '2012-01-20 12:54:46.165776+00', 'Prince Charles''', 9999, '');
INSERT INTO 'tune' VALUES (8076, NULL, '2012-01-20 12:54:46.168681+00', 'Lark in the Morning', 9999, '');
INSERT INTO 'tune' VALUES (8077, NULL, '2012-01-20 12:54:46.171574+00', 'Killiechassie', 9999, '');
INSERT INTO 'tune' VALUES (8078, NULL, '2012-01-20 12:54:46.174467+00', 'Heather Hill', 1766, '');
INSERT INTO 'tune' VALUES (8079, NULL, '2012-01-20 12:54:46.177364+00', 'Donald Duncan Fraser', 2966, '');
INSERT INTO 'tune' VALUES (8080, NULL, '2012-01-20 12:54:46.180273+00', 'Gaelic Air, A', 1518, '');
INSERT INTO 'tune' VALUES (8081, NULL, '2012-01-20 12:54:46.183165+00', 'Spark''s Rant, The', 1732, '');
INSERT INTO 'tune' VALUES (8082, NULL, '2012-01-20 12:54:46.186055+00', 'Princess Augusta', 1518, '');
INSERT INTO 'tune' VALUES (8083, NULL, '2012-01-20 12:54:46.188947+00', 'Mr Young''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (8084, NULL, '2012-01-20 12:54:46.191835+00', 'Hon Miss H Elliot''s Reel, The', 1476, '');
INSERT INTO 'tune' VALUES (8085, NULL, '2012-01-20 12:54:46.194732+00', 'Braes of Cawdor, The', 9999, '');
INSERT INTO 'tune' VALUES (8086, NULL, '2012-01-20 12:54:46.197624+00', 'Mrs Laird of Strathmartin', 1401, '');
INSERT INTO 'tune' VALUES (8087, NULL, '2012-01-20 12:54:46.200525+00', 'House of Park, The', 1516, '');
INSERT INTO 'tune' VALUES (8088, NULL, '2012-01-20 12:54:46.203424+00', 'Medley', 9999, '');
INSERT INTO 'tune' VALUES (8089, NULL, '2012-01-20 12:54:46.206315+00', 'North Hunt Medley, The', 2142, '');
INSERT INTO 'tune' VALUES (8090, NULL, '2012-01-20 12:54:46.209197+00', 'Mrs Donaldson', 9999, '');
INSERT INTO 'tune' VALUES (8091, NULL, '2012-01-20 12:54:46.212087+00', 'Mr Halliday''s Compliments to Mrs Crockett', 9999, '');
INSERT INTO 'tune' VALUES (8092, NULL, '2012-01-20 12:54:46.214979+00', 'Hon Miss Sempill, The', 1519, '');
INSERT INTO 'tune' VALUES (8093, NULL, '2012-01-20 12:54:46.217864+00', 'Mr Reid''s Reel', 1470, '');
INSERT INTO 'tune' VALUES (8094, NULL, '2012-01-20 12:54:46.220758+00', 'Walter Kennedy''s Reel', 2646, '');
INSERT INTO 'tune' VALUES (8095, NULL, '2012-01-20 12:54:46.223656+00', 'Birnham Hall', 1748, '');
INSERT INTO 'tune' VALUES (8096, NULL, '2012-01-20 12:54:46.226554+00', 'Mr Robert Hunter''s Strathspey', 1476, '');
INSERT INTO 'tune' VALUES (8097, NULL, '2012-01-20 12:54:46.229443+00', 'Spell, The', 1518, '');
INSERT INTO 'tune' VALUES (8098, NULL, '2012-01-20 12:54:46.23233+00', 'Bonnie Lass o'' Fisherrow', 1781, '');
INSERT INTO 'tune' VALUES (8099, NULL, '2012-01-20 12:54:46.235219+00', 'Donald Dow''s Strathspey', 1518, '');
INSERT INTO 'tune' VALUES (8100, NULL, '2012-01-20 12:54:46.238102+00', 'Soft Horse Reel, The', 1271, '');
INSERT INTO 'tune' VALUES (8101, NULL, '2012-01-20 12:54:46.240998+00', 'Jim Moore''s Fancy', 1525, '');
INSERT INTO 'tune' VALUES (8102, NULL, '2012-01-20 12:54:46.243891+00', 'Sandy Nixon''s Jig', 1596, '');
INSERT INTO 'tune' VALUES (8103, NULL, '2012-01-20 12:54:46.246777+00', 'Elaine''s Jig', 1576, '');
INSERT INTO 'tune' VALUES (8104, NULL, '2012-01-20 12:54:46.249667+00', 'Jig for Janice', 1576, '');
INSERT INTO 'tune' VALUES (8105, NULL, '2012-01-20 12:54:46.252553+00', 'Stan Saunders of Dollar', 1668, '');
INSERT INTO 'tune' VALUES (8106, NULL, '2012-01-20 12:54:46.255524+00', 'Bieldside', 1910, '');
INSERT INTO 'tune' VALUES (8107, NULL, '2012-01-20 12:54:46.258426+00', 'Angus MacPherson of Inveran', 2338, '');
INSERT INTO 'tune' VALUES (8108, NULL, '2012-01-20 12:54:46.261319+00', 'Trip to Saint Kilda, A', 1613, '');
INSERT INTO 'tune' VALUES (8109, NULL, '2012-01-20 12:54:46.264209+00', 'Jessie Fleming''s Polka', 1576, '');
INSERT INTO 'tune' VALUES (8110, NULL, '2012-01-20 12:54:46.267107+00', 'To Absent Friends', 1296, '');
INSERT INTO 'tune' VALUES (8111, NULL, '2012-01-20 12:54:46.269994+00', 'Dumfries and District Ladies Country Club, The', 1613, '');
INSERT INTO 'tune' VALUES (8112, NULL, '2012-01-20 12:54:46.27289+00', 'Mr & Mrs Alex Hutchison''s Silver Wedding Two Step', 2912, '');
INSERT INTO 'tune' VALUES (8113, NULL, '2012-01-20 12:54:46.275786+00', 'Miss Alison Smith', 1613, '');
INSERT INTO 'tune' VALUES (8114, NULL, '2012-01-20 12:54:46.278685+00', 'Dave Lawson of North Mains of Liff', 1576, '');
INSERT INTO 'tune' VALUES (8115, NULL, '2012-01-20 12:54:46.281581+00', 'Coquette Polka, The', 2346, '');
INSERT INTO 'tune' VALUES (8116, NULL, '2012-01-20 12:54:46.284478+00', 'Joan''s Tune', 1613, '');
INSERT INTO 'tune' VALUES (8117, NULL, '2012-01-20 12:54:46.287397+00', 'Fascadale', 1613, '');
INSERT INTO 'tune' VALUES (8118, NULL, '2012-01-20 12:54:46.2903+00', 'Swordle Bay', 1613, '');
INSERT INTO 'tune' VALUES (8119, NULL, '2012-01-20 12:54:46.293207+00', 'Judith', 1613, '');
INSERT INTO 'tune' VALUES (8120, NULL, '2012-01-20 12:54:46.296122+00', 'Julia', 1613, '');
INSERT INTO 'tune' VALUES (8121, NULL, '2012-01-20 12:54:46.299004+00', 'Heights of Cassino', 1920, '');
INSERT INTO 'tune' VALUES (8122, NULL, '2012-01-20 12:54:46.301908+00', 'Geoff Dent''s Reel', 1576, '');
INSERT INTO 'tune' VALUES (8123, NULL, '2012-01-20 12:54:46.304801+00', 'Val Stannard''s Reel', 1576, '');
INSERT INTO 'tune' VALUES (8124, NULL, '2012-01-20 12:54:46.307702+00', 'Miss Jill Nixon', 1576, '');
INSERT INTO 'tune' VALUES (8125, NULL, '2012-01-20 12:54:46.31059+00', 'Shauna Flockhart', 1550, '');
INSERT INTO 'tune' VALUES (8126, NULL, '2012-01-20 12:54:46.31348+00', 'Gentle Hills of Knapdale, The', 1527, '');
INSERT INTO 'tune' VALUES (8127, NULL, '2012-01-20 12:54:46.316406+00', 'Skerries two-step, The', 1576, '');
INSERT INTO 'tune' VALUES (8128, NULL, '2012-01-20 12:54:46.319314+00', 'Archie McKinley', 2967, '');
INSERT INTO 'tune' VALUES (8129, NULL, '2012-01-20 12:54:46.322232+00', 'Rock on the Clyde, The', 9998, '');
INSERT INTO 'tune' VALUES (8130, NULL, '2012-01-20 12:54:46.325126+00', 'Bays of Bluehill, The', 9999, '');
INSERT INTO 'tune' VALUES (8131, NULL, '2012-01-20 12:54:46.328238+00', 'Findlay J MacDonald', 3058, '');
INSERT INTO 'tune' VALUES (8132, NULL, '2012-01-20 12:54:46.331154+00', 'Seamus MacNeil', 3058, '');
INSERT INTO 'tune' VALUES (8133, NULL, '2012-01-20 12:54:46.334046+00', 'Jim Ritchie''s Lilt', 3058, '');
INSERT INTO 'tune' VALUES (8134, NULL, '2012-01-20 12:54:46.336942+00', 'Marilynn Knight''s Delight', 1836, '');
INSERT INTO 'tune' VALUES (8135, NULL, '2012-01-20 12:54:46.339845+00', 'Ben Cruachan', 9999, '');
INSERT INTO 'tune' VALUES (8136, NULL, '2012-01-20 12:54:46.342741+00', 'Kilty Lads', 9999, '');
INSERT INTO 'tune' VALUES (8137, NULL, '2012-01-20 12:54:46.345624+00', 'Lochiel''s March', 9999, '');
INSERT INTO 'tune' VALUES (8138, NULL, '2012-01-20 12:54:46.348526+00', '93rds Farewell to Gibraltar', 9999, '');
INSERT INTO 'tune' VALUES (8139, NULL, '2012-01-20 12:54:46.351438+00', 'John Cheap the Chapman', 9998, '');
INSERT INTO 'tune' VALUES (8140, NULL, '2012-01-20 12:54:46.354329+00', 'Poor Ould Woman', 9998, '');
INSERT INTO 'tune' VALUES (8141, NULL, '2012-01-20 12:54:46.357215+00', 'Ryan''s Rant', 9998, '');
INSERT INTO 'tune' VALUES (8142, NULL, '2012-01-20 12:54:46.360114+00', 'Attwood', 9998, '');
INSERT INTO 'tune' VALUES (8143, NULL, '2012-01-20 12:54:46.363007+00', 'Locomotive Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (8144, NULL, '2012-01-20 12:54:46.365895+00', 'Royal Belfast', 9998, '');
INSERT INTO 'tune' VALUES (8145, NULL, '2012-01-20 12:54:46.368789+00', 'Thorp Haywood''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (8146, NULL, '2012-01-20 12:54:46.371678+00', 'Star Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (8147, NULL, '2012-01-20 12:54:46.374582+00', 'Washington Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (8148, NULL, '2012-01-20 12:54:46.37749+00', 'Cavan Buck', 9998, '');
INSERT INTO 'tune' VALUES (8149, NULL, '2012-01-20 12:54:46.380375+00', 'Mrs Casey', 9998, '');
INSERT INTO 'tune' VALUES (8150, NULL, '2012-01-20 12:54:46.383873+00', 'Rocky Road to Dublin', 9998, '');
INSERT INTO 'tune' VALUES (8151, NULL, '2012-01-20 12:54:46.386847+00', 'Sprig of Shillelah', 9998, '');
INSERT INTO 'tune' VALUES (8152, NULL, '2012-01-20 12:54:46.389745+00', 'Whistling Thief', 9998, '');
INSERT INTO 'tune' VALUES (8153, NULL, '2012-01-20 12:54:46.392639+00', 'Young May Moon', 9998, '');
INSERT INTO 'tune' VALUES (8154, NULL, '2012-01-20 12:54:46.395527+00', 'Jenny Nettles', 9999, '');
INSERT INTO 'tune' VALUES (8156, NULL, '2012-01-20 12:54:46.403427+00', 'Screech Owl Reel', 2977, '');
INSERT INTO 'tune' VALUES (8157, NULL, '2012-01-20 12:54:46.406346+00', 'Laburnum Arch at Airlie, The', 1646, '');
INSERT INTO 'tune' VALUES (8159, NULL, '2012-01-20 12:54:46.412141+00', 'Jim Hardie''s Jig', 1646, '');
INSERT INTO 'tune' VALUES (8160, NULL, '2012-01-20 12:54:46.415038+00', 'Billy Ford''s Bike', 1543, '');
INSERT INTO 'tune' VALUES (8161, NULL, '2012-01-20 12:54:46.417929+00', 'Bibby MacDonlad of Fasgadh', 1605, '');
INSERT INTO 'tune' VALUES (8162, NULL, '2012-01-20 12:54:46.420822+00', 'Pathhead Reel, The', 1646, '');
INSERT INTO 'tune' VALUES (8163, NULL, '2012-01-20 12:54:46.423725+00', 'Anda''s Front Door Toilet', 1634, '');
INSERT INTO 'tune' VALUES (8164, NULL, '2012-01-20 12:54:46.426623+00', 'Oor Norrie', 1585, '');
INSERT INTO 'tune' VALUES (8165, NULL, '2012-01-20 12:54:46.42951+00', 'Margaret Mitchell''s Reel', 1575, '');
INSERT INTO 'tune' VALUES (8166, NULL, '2012-01-20 12:54:46.432417+00', 'Strathclyde Police March On', 2978, '');
INSERT INTO 'tune' VALUES (8167, NULL, '2012-01-20 12:54:46.435319+00', 'Miss Caroline Sturges', 1653, '');
INSERT INTO 'tune' VALUES (8168, NULL, '2012-01-20 12:54:46.438214+00', 'Miss Shirley Andrews', 2979, '');
INSERT INTO 'tune' VALUES (8169, NULL, '2012-01-20 12:54:46.441363+00', 'Loretta''s Tune', 2768, '');
INSERT INTO 'tune' VALUES (8170, NULL, '2012-01-20 12:54:46.444459+00', 'Neil & Eileen Oxlade', 1621, '');
INSERT INTO 'tune' VALUES (8171, NULL, '2012-01-20 12:54:46.447509+00', 'Isabel Davidson Two-step', 1527, '');
INSERT INTO 'tune' VALUES (8172, NULL, '2012-01-20 12:54:46.450557+00', 'Heather Pass', 1594, '');
INSERT INTO 'tune' VALUES (8173, NULL, '2012-01-20 12:54:46.453601+00', 'Tammy Anderson', 1613, '');
INSERT INTO 'tune' VALUES (8174, NULL, '2012-01-20 12:54:46.456701+00', 'Willie Hunter''s Compliments to Dan R MacDonald', 1677, '');
INSERT INTO 'tune' VALUES (8175, NULL, '2012-01-20 12:54:46.459774+00', 'Devil''s Staircase, The', 1673, '');
INSERT INTO 'tune' VALUES (8176, NULL, '2012-01-20 12:54:46.462902+00', 'Humble Doddies', 1614, '');
INSERT INTO 'tune' VALUES (8177, NULL, '2012-01-20 12:54:46.465893+00', 'Miss Susan Inglis', 1607, '');
INSERT INTO 'tune' VALUES (8178, NULL, '2012-01-20 12:54:46.468815+00', 'Andrew Carnegie', 1572, '');
INSERT INTO 'tune' VALUES (8179, NULL, '2012-01-20 12:54:46.471724+00', 'Strathspey for Jane, A', 2914, '');
INSERT INTO 'tune' VALUES (8180, NULL, '2012-01-20 12:54:46.474621+00', 'Maple Leaf''s Compliments to the RNLI', 1692, '');
INSERT INTO 'tune' VALUES (8181, NULL, '2012-01-20 12:54:46.477526+00', 'Margaret Morrison', 2914, '');
INSERT INTO 'tune' VALUES (8183, NULL, '2012-01-20 12:54:46.483318+00', 'Seattle Landing', 1836, '');
INSERT INTO 'tune' VALUES (8184, NULL, '2012-01-20 12:54:46.486223+00', 'Trip to Aberlemno, A', 2914, '');
INSERT INTO 'tune' VALUES (8185, NULL, '2012-01-20 12:54:46.489115+00', 'Via Aberlemno', 2914, '');
INSERT INTO 'tune' VALUES (8186, NULL, '2012-01-20 12:54:46.492006+00', 'Tribute to Aberlemno, A', 2914, '');
INSERT INTO 'tune' VALUES (8187, NULL, '2012-01-20 12:54:46.494902+00', 'Avis Harrison''s Strathspey', 1456, '');
INSERT INTO 'tune' VALUES (8188, NULL, '2012-01-20 12:54:46.497786+00', 'Earl and Countess of Wessex, The', 1439, '');
INSERT INTO 'tune' VALUES (8189, NULL, '2012-01-20 12:54:46.500692+00', 'Bruce Frazer', 1590, '');
INSERT INTO 'tune' VALUES (8190, NULL, '2012-01-20 12:54:46.503591+00', 'Trip to Baveno, The', 1502, '');
INSERT INTO 'tune' VALUES (8191, NULL, '2012-01-20 12:54:46.506492+00', 'Miss Elizabeth Adair', 1554, '');
INSERT INTO 'tune' VALUES (8192, NULL, '2012-01-20 12:54:46.509385+00', 'Eathy Reel', 1539, '');
INSERT INTO 'tune' VALUES (8193, NULL, '2012-01-20 12:54:46.512274+00', 'Barbara''s Fancy', 1922, '');
INSERT INTO 'tune' VALUES (8194, NULL, '2012-01-20 12:54:46.515168+00', 'Carles of Kinross', 1764, '');
INSERT INTO 'tune' VALUES (8195, NULL, '2012-01-20 12:54:46.518055+00', 'Burgan''s Rant', 1764, '');
INSERT INTO 'tune' VALUES (8197, NULL, '2012-01-20 12:54:46.523906+00', 'Bill Black of Doune', 1613, '');
INSERT INTO 'tune' VALUES (8198, NULL, '2012-01-20 12:54:46.526997+00', 'Tom McNaught''s March', 1680, '');
INSERT INTO 'tune' VALUES (8199, NULL, '2012-01-20 12:54:46.529949+00', 'Loch Ryan', 1764, '');
INSERT INTO 'tune' VALUES (8200, NULL, '2012-01-20 12:54:46.532847+00', 'Mrs Mary Brandon', 1764, '');
INSERT INTO 'tune' VALUES (8201, NULL, '2012-01-20 12:54:46.535745+00', 'Miss Andrea Farquhar', 1764, '');
INSERT INTO 'tune' VALUES (8202, NULL, '2012-01-20 12:54:46.538641+00', 'Moira of Horsewells', 1502, '');
INSERT INTO 'tune' VALUES (8203, NULL, '2012-01-20 12:54:46.541531+00', 'In the Music Block', 1502, '');
INSERT INTO 'tune' VALUES (8204, NULL, '2012-01-20 12:54:46.544426+00', 'Hide Hill', 1502, '');
INSERT INTO 'tune' VALUES (8205, NULL, '2012-01-20 12:54:46.547337+00', 'Geneva Makes Three', 1502, '');
INSERT INTO 'tune' VALUES (8206, NULL, '2012-01-20 12:54:46.550228+00', 'Minor for Muriel', 9998, '');
INSERT INTO 'tune' VALUES (8207, NULL, '2012-01-20 12:54:46.553134+00', 'Golden Memories of Musselburgh', 1502, '');
INSERT INTO 'tune' VALUES (8208, NULL, '2012-01-20 12:54:46.556068+00', 'Montha''s Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (8209, NULL, '2012-01-20 12:54:46.558976+00', 'Brian Harry', 1502, '');
INSERT INTO 'tune' VALUES (8210, NULL, '2012-01-20 12:54:46.561868+00', 'Bonnie Lassie, O', 9999, '');
INSERT INTO 'tune' VALUES (8211, NULL, '2012-01-20 12:54:46.56476+00', 'Lorraine''s Fancy', 1531, '');
INSERT INTO 'tune' VALUES (8212, NULL, '2012-01-20 12:54:46.567671+00', 'Mordington House', 1401, '');
INSERT INTO 'tune' VALUES (8213, NULL, '2012-01-20 12:54:46.570565+00', 'Eric''s Puffer Train', 810, '');
INSERT INTO 'tune' VALUES (8214, NULL, '2012-01-20 12:54:46.573463+00', 'Pacemaker, The', 1717, '');
INSERT INTO 'tune' VALUES (8215, NULL, '2012-01-20 12:54:46.576354+00', 'White Heather', 9999, '');
INSERT INTO 'tune' VALUES (8216, NULL, '2012-01-20 12:54:46.579251+00', 'Dunvegan Castle', 9999, '');
INSERT INTO 'tune' VALUES (8217, NULL, '2012-01-20 12:54:46.582144+00', 'Sail Chanty', 9999, '');
INSERT INTO 'tune' VALUES (8218, NULL, '2012-01-20 12:54:46.58504+00', 'Suzanne ''s Jig', 2655, '');
INSERT INTO 'tune' VALUES (8219, NULL, '2012-01-20 12:54:46.587978+00', 'Meg o'' the Mill', 9999, '');
INSERT INTO 'tune' VALUES (8220, NULL, '2012-01-20 12:54:46.590913+00', 'Eliza Jane', 9999, '');
INSERT INTO 'tune' VALUES (8221, NULL, '2012-01-20 12:54:46.593808+00', 'Log Cabin', 9999, '');
INSERT INTO 'tune' VALUES (8222, NULL, '2012-01-20 12:54:46.596705+00', 'Roberta''s Waltz', 2392, '');
INSERT INTO 'tune' VALUES (8223, NULL, '2012-01-20 12:54:46.599617+00', 'Wisconsin Journey', 2392, '');
INSERT INTO 'tune' VALUES (8225, NULL, '2012-01-20 12:54:46.60543+00', 'Stan Chapman''s Jig', 1633, '');
INSERT INTO 'tune' VALUES (8226, NULL, '2012-01-20 12:54:46.608946+00', 'Mr Meacham', 1512, '');
INSERT INTO 'tune' VALUES (8227, NULL, '2012-01-20 12:54:46.611875+00', 'Perssons Drag', 2395, '');
INSERT INTO 'tune' VALUES (8228, NULL, '2012-01-20 12:54:46.614776+00', 'Dismissal Reel, The', 3093, '');
INSERT INTO 'tune' VALUES (8229, NULL, '2012-01-20 12:54:46.617678+00', 'Mikkel''s Jig', 1780, '');
INSERT INTO 'tune' VALUES (8230, NULL, '2012-01-20 12:54:46.620575+00', 'Ups and the Downs, The', 1780, '');
INSERT INTO 'tune' VALUES (8231, NULL, '2012-01-20 12:54:46.623472+00', 'McGarrity''s Bow', 1502, '');
INSERT INTO 'tune' VALUES (8232, NULL, '2012-01-20 12:54:46.626374+00', 'Monty and the Mouse', 2395, '');
INSERT INTO 'tune' VALUES (8233, NULL, '2012-01-20 12:54:46.629325+00', 'Balladrum House', 9999, '');
INSERT INTO 'tune' VALUES (8234, NULL, '2012-01-20 12:54:46.632232+00', 'Bertram''s Trip to Syracuse', 2221, '');
INSERT INTO 'tune' VALUES (8235, NULL, '2012-01-20 12:54:46.635132+00', 'Forres Country Dancers, The', 1586, '');
INSERT INTO 'tune' VALUES (8236, NULL, '2012-01-20 12:54:46.638019+00', 'Ass in the Graveyard, The', 3094, '');
INSERT INTO 'tune' VALUES (8237, NULL, '2012-01-20 12:54:46.640919+00', 'Three Cheers for Serendipity', 228, '');
INSERT INTO 'tune' VALUES (8238, NULL, '2012-01-20 12:54:46.64382+00', 'Mary Elizabeth Allan', 1981, '');
INSERT INTO 'tune' VALUES (8239, NULL, '2012-01-20 12:54:46.646726+00', 'Miss Kirsten McKay', 345, '');
INSERT INTO 'tune' VALUES (8240, NULL, '2012-01-20 12:54:46.649628+00', 'Auld Fiddler, The', 1726, '');
INSERT INTO 'tune' VALUES (8241, NULL, '2012-01-20 12:54:46.652528+00', 'Earl Mitton''s Breakdown', 3115, '');
INSERT INTO 'tune' VALUES (8242, NULL, '2012-01-20 12:54:46.655493+00', 'Crossing of Polensa Bay, The', 1679, '');
INSERT INTO 'tune' VALUES (8243, NULL, '2012-01-20 12:54:46.658736+00', 'Mrs Elspeth Anne McCabe', 1531, '');
INSERT INTO 'tune' VALUES (8244, NULL, '2012-01-20 12:54:46.661842+00', 'Lochalsh Reel, The', 1591, '');
INSERT INTO 'tune' VALUES (8245, NULL, '2012-01-20 12:54:46.664758+00', 'Breakish Postie, The', 1502, '');
INSERT INTO 'tune' VALUES (8246, NULL, '2012-01-20 12:54:46.667657+00', 'Cuir sa chiste mhoir mi', 9999, '');
INSERT INTO 'tune' VALUES (8247, NULL, '2012-01-20 12:54:46.670566+00', 'Miss Sarah Hunter', 2842, '');
INSERT INTO 'tune' VALUES (8248, NULL, '2012-01-20 12:54:46.673459+00', 'Cha toir Iain Mor an nighean dhomh', 9999, '');
INSERT INTO 'tune' VALUES (8249, NULL, '2012-01-20 12:54:46.676358+00', 'Bonnie Loops, The', 2801, '');
INSERT INTO 'tune' VALUES (8250, NULL, '2012-01-20 12:54:46.679248+00', 'Rhodesian Regiment, The', 3138, '');
INSERT INTO 'tune' VALUES (8251, NULL, '2012-01-20 12:54:46.68216+00', 'Jennifer Fletcher of Monaco', 1771, '');
INSERT INTO 'tune' VALUES (8252, NULL, '2012-01-20 12:54:46.68506+00', 'John Pottinger''s Compliments to Ronnie Cooper', 3141, '');
INSERT INTO 'tune' VALUES (8253, NULL, '2012-01-20 12:54:46.687959+00', 'Mrs Yvonne Burns of Blair Atholl', 1554, '');
INSERT INTO 'tune' VALUES (8254, NULL, '2012-01-20 12:54:46.69087+00', 'Mrs Agnes Crowe of Balmullo', 1554, '');
INSERT INTO 'tune' VALUES (8256, NULL, '2012-01-20 12:54:46.69665+00', 'Miss Megan Thomas', 316, '');
INSERT INTO 'tune' VALUES (8257, NULL, '2012-01-20 12:54:46.699552+00', 'Catherine Ann''s Strathspey', 316, '');
INSERT INTO 'tune' VALUES (8258, NULL, '2012-01-20 12:54:46.702443+00', 'Sarah Elizabeth Two Step, The', 316, '');
INSERT INTO 'tune' VALUES (8259, NULL, '2012-01-20 12:54:46.705359+00', 'Mr James S Foster', 1657, '');
INSERT INTO 'tune' VALUES (8260, NULL, '2012-01-20 12:54:46.708273+00', 'Alex T. Queen', 316, '');
INSERT INTO 'tune' VALUES (8261, NULL, '2012-01-20 12:54:46.711175+00', 'Deb the Leg', 316, '');
INSERT INTO 'tune' VALUES (8262, NULL, '2012-01-20 12:54:46.714067+00', 'Carleton Strathspey, The', 316, '');
INSERT INTO 'tune' VALUES (8263, NULL, '2012-01-20 12:54:46.716966+00', 'Miss Alison Queen', 316, '');
INSERT INTO 'tune' VALUES (8264, NULL, '2012-01-20 12:54:46.719859+00', 'Charlotte A Linsell', 1657, '');
INSERT INTO 'tune' VALUES (8265, NULL, '2012-01-20 12:54:46.72276+00', 'Miss Mary Douglas', 3031, '');
INSERT INTO 'tune' VALUES (8266, NULL, '2012-01-20 12:54:46.725653+00', 'Donegal Lassies', 3043, '');
INSERT INTO 'tune' VALUES (8375, NULL, '2012-01-20 12:54:47.043414+00', 'An Ceud', 1582, '');
INSERT INTO 'tune' VALUES (8196, NULL, '2021-08-09 08:52:38.029627+00', 'Walpole Cottage', 2487, '');
INSERT INTO 'tune' VALUES (8267, NULL, '2012-01-20 12:54:46.72864+00', 'David Rye''s Reel', 316, '');
INSERT INTO 'tune' VALUES (8268, NULL, '2012-01-20 12:54:46.73157+00', 'Irene''s Great Tits', 316, '');
INSERT INTO 'tune' VALUES (8269, NULL, '2012-01-20 12:54:46.734478+00', 'Pat McNulty''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (8270, NULL, '2012-01-20 12:54:46.737373+00', 'Andrew''s Tune', 9998, '');
INSERT INTO 'tune' VALUES (8271, NULL, '2012-01-20 12:54:46.740273+00', 'Dr Autgarten', 1502, '');
INSERT INTO 'tune' VALUES (8272, NULL, '2012-01-20 12:54:46.743164+00', 'Forfar 65', 9998, '');
INSERT INTO 'tune' VALUES (8273, NULL, '2012-01-20 12:54:46.746051+00', 'Roxburgh''s of New Zealand', 1657, '');
INSERT INTO 'tune' VALUES (8274, NULL, '2012-01-20 12:54:46.748999+00', 'Blarney Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (8275, NULL, '2012-01-20 12:54:46.751932+00', 'Pony Gallup, The', 9999, '');
INSERT INTO 'tune' VALUES (8276, NULL, '2012-01-20 12:54:46.754858+00', 'Archie McNab', 9999, '');
INSERT INTO 'tune' VALUES (8277, NULL, '2012-01-20 12:54:46.757754+00', 'Centre''s Bonnet', 9999, '');
INSERT INTO 'tune' VALUES (8278, NULL, '2012-01-20 12:54:46.76065+00', 'Welcome to Callum', 1808, '');
INSERT INTO 'tune' VALUES (8279, NULL, '2012-01-20 12:54:46.76355+00', 'Kelty Wind', 1808, '');
INSERT INTO 'tune' VALUES (8280, NULL, '2012-01-20 12:54:46.766448+00', 'Iain''s Kebab House', 1808, '');
INSERT INTO 'tune' VALUES (8281, NULL, '2012-01-20 12:54:46.769337+00', 'Curlywurly Reel', 1808, '');
INSERT INTO 'tune' VALUES (8282, NULL, '2012-01-20 12:54:46.772228+00', 'Falkirk Bairn, The', 1808, '');
INSERT INTO 'tune' VALUES (8283, NULL, '2012-01-20 12:54:46.775157+00', 'Jeanette & Bert Shand''s Strathspey', 1808, '');
INSERT INTO 'tune' VALUES (8284, NULL, '2012-01-20 12:54:46.778044+00', 'Old Manse, The', 2768, '');
INSERT INTO 'tune' VALUES (8285, NULL, '2012-01-20 12:54:46.780938+00', 'Donald Ridley''s Compliments to Jim Halcrow', 1593, '');
INSERT INTO 'tune' VALUES (8286, NULL, '2012-01-20 12:54:46.783849+00', 'Jim Clark''s Golden Touch', 2613, '');
INSERT INTO 'tune' VALUES (8287, NULL, '2012-01-20 12:54:46.786742+00', 'Astryd''s Peerie Tune', 1645, '');
INSERT INTO 'tune' VALUES (8288, NULL, '2012-01-20 12:54:46.789633+00', 'Tom''s Rocking Fiddle', 1808, '');
INSERT INTO 'tune' VALUES (8289, NULL, '2012-01-20 12:54:46.792524+00', 'Red Wine Reel', 1808, '');
INSERT INTO 'tune' VALUES (8290, NULL, '2012-01-20 12:54:46.795418+00', 'Billy''s Baldy Brushes', 1808, '');
INSERT INTO 'tune' VALUES (8291, NULL, '2012-01-20 12:54:46.79831+00', 'Life in the Fast Lane', 1808, '');
INSERT INTO 'tune' VALUES (8292, NULL, '2012-01-20 12:54:46.801197+00', 'Scunner, The', 1808, '');
INSERT INTO 'tune' VALUES (8293, NULL, '2012-01-20 12:54:46.804093+00', 'Miss Martin''s Strathspey', 2158, '');
INSERT INTO 'tune' VALUES (8294, NULL, '2012-01-20 12:54:46.806987+00', 'Compliments to Miss Martin', 2158, '');
INSERT INTO 'tune' VALUES (8295, NULL, '2012-01-20 12:54:46.809875+00', 'Miss Ailsa Marie Haining''s Reel', 1808, '');
INSERT INTO 'tune' VALUES (8296, NULL, '2012-01-20 12:54:46.812808+00', 'Rodeo, The', 1808, '');
INSERT INTO 'tune' VALUES (8297, NULL, '2012-01-20 12:54:46.815708+00', 'Pedro Robertson', 1808, '');
INSERT INTO 'tune' VALUES (8298, NULL, '2012-01-20 12:54:46.818601+00', 'John Sinclair-Younger of Ulbster', 2362, '');
INSERT INTO 'tune' VALUES (8299, NULL, '2012-01-20 12:54:46.821492+00', 'Gordon Shand''s Compliments to Ian Crichton', 1808, '');
INSERT INTO 'tune' VALUES (8300, NULL, '2012-01-20 12:54:46.824382+00', 'Nurse Mairi Graham''s Jig', 1507, '');
INSERT INTO 'tune' VALUES (8301, NULL, '2012-01-20 12:54:46.827268+00', 'Bonnie Lass of Gartly, The', 3144, '');
INSERT INTO 'tune' VALUES (8302, NULL, '2012-01-20 12:54:46.83016+00', 'E T Hornpipe, The', 3144, '');
INSERT INTO 'tune' VALUES (8303, NULL, '2012-01-20 12:54:46.833046+00', 'Jocky''s Treble Tops', 3145, '');
INSERT INTO 'tune' VALUES (8304, NULL, '2012-01-20 12:54:46.835986+00', 'Mrs Agnes Haining''s Strathspey', 1808, '');
INSERT INTO 'tune' VALUES (8412, NULL, '2012-01-20 12:54:47.15371+00', 'Munebroch', 1502, '');
INSERT INTO 'tune' VALUES (8305, NULL, '2012-01-20 12:54:46.838887+00', 'Memories of George Haining', 1808, '');
INSERT INTO 'tune' VALUES (8306, NULL, '2012-01-20 12:54:46.841779+00', 'Harry Shand of Inver', 1808, '');
INSERT INTO 'tune' VALUES (8307, NULL, '2012-01-20 12:54:46.844678+00', 'Bothwell Boy', 3146, '');
INSERT INTO 'tune' VALUES (8948, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.794429+00', 'Airgead', 1582, '');
INSERT INTO 'tune' VALUES (8308, NULL, '2012-01-20 12:54:46.847573+00', 'Irene Mclean of Duns', 1502, '');
INSERT INTO 'tune' VALUES (8309, NULL, '2012-01-20 12:54:46.850476+00', 'Colin Dewar''s Hornpipe', 1596, '');
INSERT INTO 'tune' VALUES (8311, NULL, '2012-01-20 12:54:46.856404+00', 'Happy Go Lucky Polka', 3147, '');
INSERT INTO 'tune' VALUES (8312, NULL, '2012-01-20 12:54:46.859309+00', 'Chas Reel, The', 1756, '');
INSERT INTO 'tune' VALUES (8313, NULL, '2012-01-20 12:54:46.862202+00', 'Rachael House', 1756, '');
INSERT INTO 'tune' VALUES (8314, NULL, '2012-01-20 12:54:46.865087+00', 'Rocking Horse, The', 1756, '');
INSERT INTO 'tune' VALUES (8315, NULL, '2012-01-20 12:54:46.867982+00', 'Lomond House', 1756, '');
INSERT INTO 'tune' VALUES (8317, NULL, '2012-01-20 12:54:46.874297+00', 'Master Graham Kindness', 1520, '');
INSERT INTO 'tune' VALUES (8318, NULL, '2012-01-20 12:54:46.877202+00', 'Seventy-Two Step, The', 1415, '');
INSERT INTO 'tune' VALUES (8319, NULL, '2012-01-20 12:54:46.880112+00', 'Mrs Hamilton of Auchencruive', 2054, '');
INSERT INTO 'tune' VALUES (8320, NULL, '2012-01-20 12:54:46.883013+00', 'Elrick''s Braes', 3148, '');
INSERT INTO 'tune' VALUES (8321, NULL, '2012-01-20 12:54:46.885907+00', 'Setting Sun, The', 1539, '');
INSERT INTO 'tune' VALUES (8323, NULL, '2012-01-20 12:54:46.891713+00', 'Iain MacPhail''s Compliments to the Cal Socs. of S. America', 1527, '');
INSERT INTO 'tune' VALUES (8324, NULL, '2012-01-20 12:54:46.894622+00', 'Jimmy Frew''s March to the 500th Anniversary Brazilian Games', 1527, '');
INSERT INTO 'tune' VALUES (8325, NULL, '2012-01-20 12:54:46.897533+00', 'Waves of Kintyre, The', 2214, '');
INSERT INTO 'tune' VALUES (8326, NULL, '2012-01-20 12:54:46.900427+00', 'Flower of the Hills', 9999, '');
INSERT INTO 'tune' VALUES (8327, NULL, '2012-01-20 12:54:46.903319+00', 'Doodlum Dhu', 9999, '');
INSERT INTO 'tune' VALUES (8328, NULL, '2012-01-20 12:54:46.906208+00', 'Dunadd', 9999, '');
INSERT INTO 'tune' VALUES (8329, NULL, '2012-01-20 12:54:46.909097+00', 'Lum Hat, The', 1553, '');
INSERT INTO 'tune' VALUES (8330, NULL, '2012-01-20 12:54:46.911991+00', 'Old Farmhouse', 1530, '');
INSERT INTO 'tune' VALUES (8331, NULL, '2012-01-20 12:54:46.915375+00', 'Piper''s Bonnet, The', 3149, '');
INSERT INTO 'tune' VALUES (8332, NULL, '2012-01-20 12:54:46.918381+00', 'Rest, The', 3150, '');
INSERT INTO 'tune' VALUES (8333, NULL, '2012-01-20 12:54:46.921284+00', 'Iain MacPhail''s Welcome to Brazil', 2266, '');
INSERT INTO 'tune' VALUES (8334, NULL, '2012-01-20 12:54:46.924191+00', 'Iain MacPhail''s Compliments to Ron Kerr', 1527, '');
INSERT INTO 'tune' VALUES (8335, NULL, '2012-01-20 12:54:46.927304+00', 'Blanche''s Reel', 3151, '');
INSERT INTO 'tune' VALUES (8336, NULL, '2012-01-20 12:54:46.930243+00', 'Glen Lyon', 9999, '');
INSERT INTO 'tune' VALUES (8338, NULL, '2012-01-20 12:54:46.936044+00', 'Miss Lauren Mason', 1591, '');
INSERT INTO 'tune' VALUES (8339, NULL, '2012-01-20 12:54:46.938949+00', 'Factor''s Breeks, The', 1811, '');
INSERT INTO 'tune' VALUES (8340, NULL, '2012-01-20 12:54:46.94184+00', 'Miss Sarah Gillies', 2842, '');
INSERT INTO 'tune' VALUES (8341, NULL, '2012-01-20 12:54:46.944731+00', 'Rathad Chaluim', 1769, '');
INSERT INTO 'tune' VALUES (8342, NULL, '2012-01-20 12:54:46.947622+00', 'Mhorag and Robert''s Wedding Day', 1668, '');
INSERT INTO 'tune' VALUES (8343, NULL, '2012-01-20 12:54:46.950518+00', 'Dick Gossip', 9999, '');
INSERT INTO 'tune' VALUES (8344, NULL, '2012-01-20 12:54:46.953406+00', 'Festival Reel', 1505, '');
INSERT INTO 'tune' VALUES (8345, NULL, '2012-01-20 12:54:46.956298+00', 'Little Roy''s Breakfast', 1602, '');
INSERT INTO 'tune' VALUES (8346, NULL, '2012-01-20 12:54:46.959208+00', 'Neil & Gillian''s Waltz', 9998, '');
INSERT INTO 'tune' VALUES (8347, NULL, '2012-01-20 12:54:46.962098+00', 'Mark & Sandra''s Wedding', 3155, '');
INSERT INTO 'tune' VALUES (8348, NULL, '2012-01-20 12:54:46.964989+00', '(unknown)', 9998, '');
INSERT INTO 'tune' VALUES (8349, NULL, '2012-01-20 12:54:46.967882+00', 'John''s Irish Air', 1808, '');
INSERT INTO 'tune' VALUES (8350, NULL, '2012-01-20 12:54:46.970779+00', 'Simon Thoumire''s Jig', 3146, '');
INSERT INTO 'tune' VALUES (8351, NULL, '2012-01-20 12:54:46.97366+00', 'Joe''s Tuxedo', 3146, '');
INSERT INTO 'tune' VALUES (8352, NULL, '2012-01-20 12:54:46.976551+00', 'Handsome Young Maidens, The', 3156, '');
INSERT INTO 'tune' VALUES (8353, NULL, '2012-01-20 12:54:46.979467+00', 'Celtic Metador, The', 3157, '');
INSERT INTO 'tune' VALUES (8354, NULL, '2012-01-20 12:54:46.982372+00', 'Yug Bay Skye', 3158, '');
INSERT INTO 'tune' VALUES (8355, NULL, '2012-01-20 12:54:46.985256+00', 'Titanic Fiddler, The', 1808, '');
INSERT INTO 'tune' VALUES (8356, NULL, '2012-01-20 12:54:46.988154+00', 'Harold''s Golfing Adventure', 1808, '');
INSERT INTO 'tune' VALUES (8357, NULL, '2012-01-20 12:54:46.991051+00', 'Seamus O''Sullivan''s Reel', 1808, '');
INSERT INTO 'tune' VALUES (8358, NULL, '2012-01-20 12:54:46.993934+00', 'Sully''s Geographical Rambles', 3159, '');
INSERT INTO 'tune' VALUES (8359, NULL, '2012-01-20 12:54:46.996828+00', 'Bobby Brown''s Alloa Ale', 3058, '');
INSERT INTO 'tune' VALUES (8361, NULL, '2012-01-20 12:54:47.002625+00', 'Bonny Hills of Stirkoke', 9999, '');
INSERT INTO 'tune' VALUES (8255, NULL, '2022-12-23 13:37:13.687439+00', 'White Wife, The', 10086, '');
INSERT INTO 'tune' VALUES (8362, NULL, '2012-01-20 12:54:47.00551+00', 'Hills of Mull, The', 1605, '');
INSERT INTO 'tune' VALUES (8363, NULL, '2012-01-20 12:54:47.008407+00', 'Cape Breton Return to Shetland, The', 1677, '');
INSERT INTO 'tune' VALUES (8364, NULL, '2012-01-20 12:54:47.011305+00', 'Daylesford Street March, The', 3161, '');
INSERT INTO 'tune' VALUES (8365, NULL, '2012-01-20 12:54:47.014207+00', 'Up to the Line', 3162, '');
INSERT INTO 'tune' VALUES (8366, NULL, '2012-01-20 12:54:47.017096+00', 'Camel''s Hump, The', 3146, '');
INSERT INTO 'tune' VALUES (8367, NULL, '2012-01-20 12:54:47.020081+00', 'Clare Jig, The', 9999, '');
INSERT INTO 'tune' VALUES (8368, NULL, '2012-01-20 12:54:47.023005+00', 'Trip to Kilkenny', 3146, '');
INSERT INTO 'tune' VALUES (8369, NULL, '2012-01-20 12:54:47.025911+00', 'Smeltzer''s Rant', 2208, '');
INSERT INTO 'tune' VALUES (8370, NULL, '2012-01-20 12:54:47.028867+00', 'Let''s All Give Three Cheers for The Sailor''s Bride', 1900, '');
INSERT INTO 'tune' VALUES (8371, NULL, '2012-01-20 12:54:47.031768+00', 'Ian Cruickshanks of Kirrie', 3163, '');
INSERT INTO 'tune' VALUES (8372, NULL, '2012-01-20 12:54:47.034668+00', 'Auchentorlie Street', 1415, '');
INSERT INTO 'tune' VALUES (8373, NULL, '2012-01-20 12:54:47.037561+00', 'Malcolm & Helen Brown''s Silver Wedding Anniversary Jig', 854, '');
INSERT INTO 'tune' VALUES (8374, NULL, '2012-01-20 12:54:47.040497+00', 'Not You Malcolm', 1582, '');
INSERT INTO 'tune' VALUES (8376, NULL, '2012-01-20 12:54:47.046303+00', 'Jean Martin', 1582, '');
INSERT INTO 'tune' VALUES (8377, NULL, '2012-01-20 12:54:47.049211+00', 'Brecon in March', 1439, '');
INSERT INTO 'tune' VALUES (8378, NULL, '2012-01-20 12:54:47.052106+00', 'Mrs Ina Collins', 1439, '');
INSERT INTO 'tune' VALUES (8379, NULL, '2012-01-20 12:54:47.055238+00', 'Bundle & Go', 1439, '');
INSERT INTO 'tune' VALUES (8380, NULL, '2012-01-20 12:54:47.058261+00', 'May Yarker''s Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (8381, NULL, '2012-01-20 12:54:47.061218+00', '''Corry''ographer, The', 1439, '');
INSERT INTO 'tune' VALUES (8382, NULL, '2012-01-20 12:54:47.064169+00', 'Invigilator, The', 1439, '');
INSERT INTO 'tune' VALUES (8383, NULL, '2012-01-20 12:54:47.06708+00', 'Bellshill Box Player, The', 1439, '');
INSERT INTO 'tune' VALUES (8384, NULL, '2012-01-20 12:54:47.069973+00', 'Halsway Anniversary', 1439, '');
INSERT INTO 'tune' VALUES (8385, NULL, '2012-01-20 12:54:47.072871+00', 'John Andrews'' Five Miles', 1439, '');
INSERT INTO 'tune' VALUES (8386, NULL, '2012-01-20 12:54:47.075766+00', 'Marilyn''s Hornpipe', 2961, '');
INSERT INTO 'tune' VALUES (8387, NULL, '2012-01-20 12:54:47.078929+00', 'Doug McConnell Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (8388, NULL, '2012-01-20 12:54:47.082202+00', 'Jig is Up, The', 1502, '');
INSERT INTO 'tune' VALUES (8389, NULL, '2012-01-20 12:54:47.08537+00', 'Catch Me if You Can', 2961, '');
INSERT INTO 'tune' VALUES (8390, NULL, '2012-01-20 12:54:47.088302+00', 'Cunning Red Fox Hornpipe', 2961, '');
INSERT INTO 'tune' VALUES (8391, NULL, '2012-01-20 12:54:47.091198+00', 'Debja''s Tune', 2961, '');
INSERT INTO 'tune' VALUES (8392, NULL, '2012-01-20 12:54:47.094088+00', 'Lorie''s Delight', 2961, '');
INSERT INTO 'tune' VALUES (8393, NULL, '2012-01-20 12:54:47.096981+00', 'Miller''s Crossing', 2961, '');
INSERT INTO 'tune' VALUES (8394, NULL, '2012-01-20 12:54:47.09988+00', 'Magic in the Forest', 2961, '');
INSERT INTO 'tune' VALUES (8395, NULL, '2012-01-20 12:54:47.10279+00', 'Rising Phoenix', 2961, '');
INSERT INTO 'tune' VALUES (8396, NULL, '2012-01-20 12:54:47.105683+00', 'Hallgerd the Beautiful', 2961, '');
INSERT INTO 'tune' VALUES (8397, NULL, '2012-01-20 12:54:47.10858+00', 'Miss Mary Margaret', 2961, '');
INSERT INTO 'tune' VALUES (8398, NULL, '2012-01-20 12:54:47.111481+00', 'Jig for Doug and Gloria, A', 2395, '');
INSERT INTO 'tune' VALUES (8399, NULL, '2012-01-20 12:54:47.114382+00', 'Pint o'' Ale', 2961, '');
INSERT INTO 'tune' VALUES (8400, NULL, '2012-01-20 12:54:47.11733+00', 'Old MacDonald Had a Farm', 9999, '');
INSERT INTO 'tune' VALUES (8401, NULL, '2012-01-20 12:54:47.120539+00', 'Mrs Margaret Byrne', 1591, '');
INSERT INTO 'tune' VALUES (8402, NULL, '2012-01-20 12:54:47.124188+00', 'Neil''s Maracas', 1660, '');
INSERT INTO 'tune' VALUES (8404, NULL, '2012-01-20 12:54:47.130513+00', 'Blackadder Water', 1502, '');
INSERT INTO 'tune' VALUES (8405, NULL, '2012-01-20 12:54:47.133424+00', 'Robertson''s of Braeside, The', 1502, '');
INSERT INTO 'tune' VALUES (8406, NULL, '2012-01-20 12:54:47.136325+00', 'Susan Skelton''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (8407, NULL, '2012-01-20 12:54:47.139218+00', 'Castlegate', 1502, '');
INSERT INTO 'tune' VALUES (8408, NULL, '2012-01-20 12:54:47.142115+00', 'Blackadder House', 1502, '');
INSERT INTO 'tune' VALUES (8409, NULL, '2012-01-20 12:54:47.145024+00', 'Allanbank', 1502, '');
INSERT INTO 'tune' VALUES (8410, NULL, '2012-01-20 12:54:47.147921+00', 'Dark Runs the Blackadder', 1502, '');
INSERT INTO 'tune' VALUES (8411, NULL, '2012-01-20 12:54:47.150814+00', 'Houstons of Boswall, The', 1502, '');
INSERT INTO 'tune' VALUES (13856, '2018-03-30 09:33:02.460649+00', '2018-12-11 18:16:36.319501+00', 'Georgia on My Mind', 11762, 'Tune arranged by Peter Campbell.');
INSERT INTO 'tune' VALUES (8413, NULL, '2012-01-20 12:54:47.156601+00', 'Eileen''s Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (8414, NULL, '2012-01-20 12:54:47.159517+00', 'Crazy Mixed-up Kid', 1502, '');
INSERT INTO 'tune' VALUES (8415, NULL, '2012-01-20 12:54:47.162419+00', 'Old Parliament House', 1502, '');
INSERT INTO 'tune' VALUES (8416, NULL, '2012-01-20 12:54:47.165324+00', 'Carol Palmer of Houston', 1502, '');
INSERT INTO 'tune' VALUES (8417, NULL, '2012-01-20 12:54:47.168208+00', 'Helen Thomson''s Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (8418, NULL, '2012-01-20 12:54:47.171105+00', 'Ewan Telford''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (8419, NULL, '2012-01-20 12:54:47.173991+00', 'Elke Baker', 1502, '');
INSERT INTO 'tune' VALUES (8420, NULL, '2012-01-20 12:54:47.176885+00', 'By the Way', 1502, '');
INSERT INTO 'tune' VALUES (8421, NULL, '2012-01-20 12:54:47.179791+00', 'Pitcalnie', 1502, '');
INSERT INTO 'tune' VALUES (8422, NULL, '2012-01-20 12:54:47.182697+00', 'Kirkcudbright', 1502, '');
INSERT INTO 'tune' VALUES (8423, NULL, '2012-01-20 12:54:47.185601+00', 'Peg Rae', 1502, '');
INSERT INTO 'tune' VALUES (8424, NULL, '2012-01-20 12:54:47.188496+00', 'Lassie Frae Glasgow, The', 1502, '');
INSERT INTO 'tune' VALUES (8425, NULL, '2012-01-20 12:54:47.191397+00', 'Becky''s Birthday Jig', 1502, '');
INSERT INTO 'tune' VALUES (8426, NULL, '2012-01-20 12:54:47.194285+00', 'Miss Montgomery of Glebe', 1502, '');
INSERT INTO 'tune' VALUES (8427, NULL, '2012-01-20 12:54:47.197167+00', 'Pistols, The', 1502, '');
INSERT INTO 'tune' VALUES (8428, NULL, '2012-01-20 12:54:47.200055+00', 'Carmen Ritchie', 1502, '');
INSERT INTO 'tune' VALUES (8429, NULL, '2012-01-20 12:54:47.202944+00', 'Galloping Granny, The', 1502, '');
INSERT INTO 'tune' VALUES (8430, NULL, '2012-01-20 12:54:47.205841+00', 'Outward Bound', 1502, '');
INSERT INTO 'tune' VALUES (8431, NULL, '2012-01-20 12:54:47.20875+00', 'Glenfinnan Viaduct, The', 1502, '');
INSERT INTO 'tune' VALUES (8432, NULL, '2012-01-20 12:54:47.211652+00', 'Rannoch Moor', 1502, '');
INSERT INTO 'tune' VALUES (8433, NULL, '2012-01-20 12:54:47.214541+00', 'Bridge of Orchy', 1502, '');
INSERT INTO 'tune' VALUES (8434, NULL, '2012-01-20 12:54:47.217432+00', 'Mac Cailin Mor', 1502, '');
INSERT INTO 'tune' VALUES (8435, NULL, '2012-01-20 12:54:47.220326+00', 'Nigel''s Fine Tune', 1502, '');
INSERT INTO 'tune' VALUES (8436, NULL, '2012-01-20 12:54:47.223214+00', 'Peter Francis Lumsden', 1502, '');
INSERT INTO 'tune' VALUES (8437, NULL, '2012-01-20 12:54:47.226111+00', 'Highland Welcome, A', 1502, '');
INSERT INTO 'tune' VALUES (8438, NULL, '2012-01-20 12:54:47.229+00', 'Lin Wood''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (8439, NULL, '2012-01-20 12:54:47.231902+00', 'Len Ackerman''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (8440, NULL, '2012-01-20 12:54:47.2348+00', 'What can a young Lassie do wi'' an auld Man', 9999, '');
INSERT INTO 'tune' VALUES (8441, NULL, '2012-01-20 12:54:47.237691+00', 'Abercorn', 1502, '');
INSERT INTO 'tune' VALUES (8442, NULL, '2012-01-20 12:54:47.240583+00', 'Mrs Jean Austin', 1502, '');
INSERT INTO 'tune' VALUES (8443, NULL, '2012-01-20 12:54:47.243473+00', 'Margaret Shaw', 1502, '');
INSERT INTO 'tune' VALUES (8444, NULL, '2012-01-20 12:54:47.246381+00', 'Gillian''s Air', 1502, '');
INSERT INTO 'tune' VALUES (8445, NULL, '2012-01-20 12:54:47.249261+00', 'Elizabeth Jane McLaren', 1502, '');
INSERT INTO 'tune' VALUES (8446, NULL, '2012-01-20 12:54:47.25215+00', 'Matthew Robert Stonehouse', 1502, '');
INSERT INTO 'tune' VALUES (8447, NULL, '2012-01-20 12:54:47.255042+00', 'Sheila Gardiner''s Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (8448, NULL, '2012-01-20 12:54:47.257933+00', 'Inmans of Glenallan, The', 1502, '');
INSERT INTO 'tune' VALUES (8449, NULL, '2012-01-20 12:54:47.260824+00', 'Keith of Kylin', 1502, '');
INSERT INTO 'tune' VALUES (8450, NULL, '2012-01-20 12:54:47.263757+00', 'Hamilton''s Girls', 1502, '');
INSERT INTO 'tune' VALUES (8451, NULL, '2012-01-20 12:54:47.266672+00', 'Rocking Horse, The', 1502, '');
INSERT INTO 'tune' VALUES (8452, NULL, '2012-01-20 12:54:47.269553+00', 'Carousel, The', 1502, '');
INSERT INTO 'tune' VALUES (13857, '2018-03-30 09:35:02.474712+00', '2018-03-30 09:35:02.474712+00', 'Ring, Ring, the Banjo', 2293, '');
INSERT INTO 'tune' VALUES (8454, NULL, '2012-01-20 12:54:47.275365+00', 'High Rig Hornpipe', 1502, '');
INSERT INTO 'tune' VALUES (8455, NULL, '2012-01-20 12:54:47.278257+00', 'Rice-a-Roni Hornpipe, The', 1502, '');
INSERT INTO 'tune' VALUES (8456, NULL, '2012-01-20 12:54:47.281144+00', 'Reel Fred DeMarse, The', 1502, '');
INSERT INTO 'tune' VALUES (8457, NULL, '2012-01-20 12:54:47.284034+00', 'Battlements, The', 1502, '');
INSERT INTO 'tune' VALUES (8458, NULL, '2012-01-20 12:54:47.286932+00', 'King''s Tower', 1502, '');
INSERT INTO 'tune' VALUES (8459, NULL, '2012-01-20 12:54:47.289827+00', 'WAR IX', 1502, '');
INSERT INTO 'tune' VALUES (8460, NULL, '2012-01-20 12:54:47.292737+00', 'Chieftain, The', 1502, '');
INSERT INTO 'tune' VALUES (8461, NULL, '2012-01-20 12:54:47.295632+00', 'Hole-in-One Hornpipe, The', 1502, '');
INSERT INTO 'tune' VALUES (8462, NULL, '2012-01-20 12:54:47.298534+00', 'Catherine Urquhart Easton', 1502, '');
INSERT INTO 'tune' VALUES (8463, NULL, '2012-01-20 12:54:47.301423+00', 'Trip to Pitlochry, A', 1502, '');
INSERT INTO 'tune' VALUES (8464, NULL, '2012-01-20 12:54:47.304317+00', 'Miss Audrey Benzie''s Reel', 1502, '');
INSERT INTO 'tune' VALUES (8465, NULL, '2012-01-20 12:54:47.307205+00', 'Arnside Knott', 9998, '');
INSERT INTO 'tune' VALUES (8466, NULL, '2012-01-20 12:54:47.310099+00', 'Lancaster Dancers', 9998, '');
INSERT INTO 'tune' VALUES (8467, NULL, '2012-01-20 12:54:47.313018+00', 'Betty Holmes', 9998, '');
INSERT INTO 'tune' VALUES (8468, NULL, '2012-01-20 12:54:47.315918+00', 'Pat Barker''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (8469, NULL, '2012-01-20 12:54:47.318829+00', 'Rio Reel', 9998, '');
INSERT INTO 'tune' VALUES (8470, NULL, '2012-01-20 12:54:47.321734+00', 'Willie Nichols Samberg', 9998, '');
INSERT INTO 'tune' VALUES (8472, NULL, '2012-01-20 12:54:47.327572+00', 'Lady Helen''s Jig, The', 3186, '');
INSERT INTO 'tune' VALUES (8473, NULL, '2012-01-20 12:54:47.330461+00', 'Ways in New Hall', 3187, '');
INSERT INTO 'tune' VALUES (8474, NULL, '2012-01-20 12:54:47.333363+00', 'Cotter Hoose, The', 1505, '');
INSERT INTO 'tune' VALUES (8475, NULL, '2012-01-20 12:54:47.336256+00', 'Janet''s Reel', 3189, '');
INSERT INTO 'tune' VALUES (8476, NULL, '2012-01-20 12:54:47.339158+00', 'Avalon Waltz, The', 345, '');
INSERT INTO 'tune' VALUES (8477, NULL, '2012-01-20 12:54:47.342051+00', 'Where the River Almond Flows', 1692, '');
INSERT INTO 'tune' VALUES (8478, NULL, '2012-01-20 12:54:47.344951+00', 'Granny Findlay''s Jig', 1811, '');
INSERT INTO 'tune' VALUES (8479, NULL, '2012-01-20 12:54:47.347881+00', 'Anne Hooper''s Complements to Charles Inglis', 2717, '');
INSERT INTO 'tune' VALUES (8481, NULL, '2012-01-20 12:54:47.353704+00', 'Jean Lumsden', 1805, '');
INSERT INTO 'tune' VALUES (8482, NULL, '2012-01-20 12:54:47.356599+00', 'Mrs Noriel Tarca', 1805, '');
INSERT INTO 'tune' VALUES (8483, NULL, '2012-01-20 12:54:47.359491+00', 'Sandy Dodd''s Welcome', 1805, '');
INSERT INTO 'tune' VALUES (8484, NULL, '2012-01-20 12:54:47.362387+00', 'Spider, The', 1465, '');
INSERT INTO 'tune' VALUES (8485, NULL, '2012-01-20 12:54:47.36527+00', 'Ferguson''s Folly', 3200, '');
INSERT INTO 'tune' VALUES (8486, NULL, '2012-01-20 12:54:47.368161+00', 'Snowdrops', 3201, '');
INSERT INTO 'tune' VALUES (8487, NULL, '2012-01-20 12:54:47.371062+00', 'Uphill', 1572, 'Original tune for the dance of the same name by Frans Ligtmans.



Copyright Deeay Music');
INSERT INTO 'tune' VALUES (8488, NULL, '2012-01-20 12:54:47.373964+00', 'Happy Birthday to Frans', 3201, '');
INSERT INTO 'tune' VALUES (8489, NULL, '2012-01-20 12:54:47.376862+00', 'Claire''s Quickstep', 3202, '');
INSERT INTO 'tune' VALUES (8490, NULL, '2012-01-20 12:54:47.379758+00', 'Flowers for Christine', 2848, '');
INSERT INTO 'tune' VALUES (8491, NULL, '2012-01-20 12:54:47.382657+00', 'Back on Track', 1445, '');
INSERT INTO 'tune' VALUES (8492, NULL, '2012-01-20 12:54:47.385545+00', 'Pearl of Brabant, The', 228, '');
INSERT INTO 'tune' VALUES (8494, NULL, '2012-01-20 12:54:47.391338+00', 'Newly Weds'' Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (8495, NULL, '2012-01-20 12:54:47.394228+00', 'There''s a Bug on Me', 9998, '');
INSERT INTO 'tune' VALUES (13899, '2018-06-09 21:31:54.413616+00', '2018-06-09 21:31:54.413616+00', 'Prince Edward Island Wedding', 9999, '');
INSERT INTO 'tune' VALUES (8497, NULL, '2012-01-20 12:54:47.400009+00', 'Port Townsend Jig, The', 3207, '');
INSERT INTO 'tune' VALUES (8498, NULL, '2012-01-20 12:54:47.402898+00', 'Clancy''s Salsa', 1612, '');
INSERT INTO 'tune' VALUES (8500, NULL, '2012-01-20 12:54:47.408667+00', 'Jimmy Ward''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (8471, NULL, '2013-02-27 13:10:01.617383+00', 'Show Me the Way to go Home', 10756, '');
INSERT INTO 'tune' VALUES (8501, NULL, '2012-01-20 12:54:47.411554+00', 'Jig in the Middle', 1673, '');
INSERT INTO 'tune' VALUES (8502, NULL, '2012-01-20 12:54:47.414482+00', 'Tapdancer, The', 1673, '');
INSERT INTO 'tune' VALUES (8503, NULL, '2012-01-20 12:54:47.417372+00', 'MacArthur Road', 9999, '');
INSERT INTO 'tune' VALUES (8504, NULL, '2012-01-20 12:54:47.430789+00', 'Vein, The', 3218, '');
INSERT INTO 'tune' VALUES (8505, NULL, '2012-01-20 12:54:47.433805+00', 'Mrs Charlotte Renton', 1596, '');
INSERT INTO 'tune' VALUES (8506, NULL, '2012-01-20 12:54:47.436771+00', 'Andy Lister''s Reel', 3189, '');
INSERT INTO 'tune' VALUES (8508, NULL, '2012-01-20 12:54:47.442576+00', 'Issy''s Moose', 3220, '');
INSERT INTO 'tune' VALUES (8509, NULL, '2012-01-20 12:54:47.445472+00', 'Graham Bell from Chirnside, near Duns in Berwickshire!!', 3221, '');
INSERT INTO 'tune' VALUES (8510, NULL, '2012-01-20 12:54:47.448374+00', 'Nethy Bridge', 2768, '');
INSERT INTO 'tune' VALUES (8511, NULL, '2012-01-20 12:54:47.451263+00', 'Lonan Jig, The', 1605, '');
INSERT INTO 'tune' VALUES (8512, NULL, '2012-01-20 12:54:47.454152+00', 'Hamish Johnston''s Jig', 1605, '');
INSERT INTO 'tune' VALUES (8513, NULL, '2012-01-20 12:54:47.457057+00', 'Piglet, The', 1591, '');
INSERT INTO 'tune' VALUES (8514, NULL, '2012-01-20 12:54:47.459955+00', 'Master Aaron Mason''s Reel', 1591, '');
INSERT INTO 'tune' VALUES (8515, NULL, '2012-01-20 12:54:47.462861+00', 'Allison''s Reel', 1591, '');
INSERT INTO 'tune' VALUES (8516, NULL, '2012-01-20 12:54:47.465749+00', 'Magga''s Jig', 3222, '');
INSERT INTO 'tune' VALUES (8517, NULL, '2012-01-20 12:54:47.468646+00', 'Max Ketchin''s Reel', 1660, '');
INSERT INTO 'tune' VALUES (8518, NULL, '2012-01-20 12:54:47.471542+00', 'Alasdair Fraser''s Compliments to Lorna Mitchell', 1782, '');
INSERT INTO 'tune' VALUES (8519, NULL, '2012-01-20 12:54:47.474429+00', 'Bootsy & Mindy', 1668, '');
INSERT INTO 'tune' VALUES (8520, NULL, '2012-01-20 12:54:47.477333+00', 'Hanging up the Hat and the Handcuffs', 1592, '');
INSERT INTO 'tune' VALUES (8480, NULL, '2016-04-17 21:31:33.18965+00', 'Eileen Black of Ottawa', 9998, '');
INSERT INTO 'tune' VALUES (8522, NULL, '2012-01-20 12:54:47.48312+00', 'Beamish Hornpipe, The', 3094, '');
INSERT INTO 'tune' VALUES (8523, NULL, '2012-01-20 12:54:47.485999+00', 'Bag of Plums, The', 3146, '');
INSERT INTO 'tune' VALUES (8524, NULL, '2012-01-20 12:54:47.48889+00', 'Bobby Crowe of Balmullo', 1677, '');
INSERT INTO 'tune' VALUES (8525, NULL, '2012-01-20 12:54:47.49179+00', 'Gordon''s Cockroaches', 1591, '');
INSERT INTO 'tune' VALUES (8526, NULL, '2012-01-20 12:54:47.494686+00', 'Bruce Shawyer''s Compliments to Muriel Johnstone', 345, '');
INSERT INTO 'tune' VALUES (8527, NULL, '2012-01-20 12:54:47.497579+00', 'Katie Robertson', 345, '');
INSERT INTO 'tune' VALUES (8528, NULL, '2012-01-20 12:54:47.50049+00', 'Penny''s Jig', 345, '');
INSERT INTO 'tune' VALUES (8529, NULL, '2012-01-20 12:54:47.503383+00', 'Minnie''s New Hat', 345, '');
INSERT INTO 'tune' VALUES (8530, NULL, '2012-01-20 12:54:47.506271+00', 'Miss Moira Grant McLoughlin', 345, '');
INSERT INTO 'tune' VALUES (8531, NULL, '2012-01-20 12:54:47.509164+00', 'Miss Heather Grant McLoughlin', 345, '');
INSERT INTO 'tune' VALUES (8532, NULL, '2012-01-20 12:54:47.51207+00', 'Up on Your Toes', 345, '');
INSERT INTO 'tune' VALUES (8533, NULL, '2012-01-20 12:54:47.514967+00', 'Now, Bend Your Knees', 345, '');
INSERT INTO 'tune' VALUES (8534, NULL, '2012-01-20 12:54:47.517858+00', 'Clune', 345, '');
INSERT INTO 'tune' VALUES (8535, NULL, '2012-01-20 12:54:47.520766+00', 'O''Sullivan of Killarney', 345, '');
INSERT INTO 'tune' VALUES (8536, NULL, '2012-01-20 12:54:47.5237+00', 'Duncan Keppie''s Visit', 345, '');
INSERT INTO 'tune' VALUES (8537, NULL, '2012-01-20 12:54:47.526618+00', 'Saint Andrews Day', 345, '');
INSERT INTO 'tune' VALUES (8538, NULL, '2012-01-20 12:54:47.529524+00', 'Tribute to Ian Peterson', 345, '');
INSERT INTO 'tune' VALUES (8539, NULL, '2012-01-20 12:54:47.532424+00', 'Tara', 345, '');
INSERT INTO 'tune' VALUES (8540, NULL, '2012-01-20 12:54:47.535328+00', 'Stewart Gillies'' Reel', 345, '');
INSERT INTO 'tune' VALUES (8541, NULL, '2012-01-20 12:54:47.538221+00', 'Mark Fuglem''s Departure for Calgary', 345, '');
INSERT INTO 'tune' VALUES (8542, NULL, '2012-01-20 12:54:47.541272+00', 'Play ABAB', 345, '');
INSERT INTO 'tune' VALUES (8543, NULL, '2012-01-20 12:54:47.54418+00', '3rd Birthday Reel', 345, '');
INSERT INTO 'tune' VALUES (8544, NULL, '2012-01-20 12:54:47.547082+00', 'Trains in Scotland', 345, '');
INSERT INTO 'tune' VALUES (8545, NULL, '2012-01-20 12:54:47.549966+00', 'Alexander Robertson Gourlay', 345, '');
INSERT INTO 'tune' VALUES (8546, NULL, '2012-01-20 12:54:47.552917+00', 'Ashlimore', 345, '');
INSERT INTO 'tune' VALUES (8547, NULL, '2012-01-20 12:54:47.555815+00', 'East End, The', 345, '');
INSERT INTO 'tune' VALUES (8548, NULL, '2012-01-20 12:54:47.558707+00', 'Reel of Corryvreckan, The', 345, '');
INSERT INTO 'tune' VALUES (8549, NULL, '2012-01-20 12:54:47.56161+00', 'Father''s Joy', 345, '');
INSERT INTO 'tune' VALUES (8550, NULL, '2012-01-20 12:54:47.564528+00', 'Mrs. MacIntyre of Boglily', 345, '');
INSERT INTO 'tune' VALUES (8551, NULL, '2012-01-20 12:54:47.567419+00', 'Talimod', 345, '');
INSERT INTO 'tune' VALUES (8552, NULL, '2012-01-20 12:54:47.570304+00', 'Two Scotts', 345, '');
INSERT INTO 'tune' VALUES (8553, NULL, '2012-01-20 12:54:47.573187+00', 'Coseritla''s Reel', 345, '');
INSERT INTO 'tune' VALUES (8554, NULL, '2012-01-20 12:54:47.576097+00', 'Pet''s Red Rose', 345, '');
INSERT INTO 'tune' VALUES (8507, NULL, '2012-06-17 14:39:37.855912+00', 'Andy Broon''s Reel', 3219, '');
INSERT INTO 'tune' VALUES (8521, NULL, '2012-06-17 14:48:08.816746+00', 'High Drive, The', 3129, '');
INSERT INTO 'tune' VALUES (8555, NULL, '2012-01-20 12:54:47.578988+00', 'Queen Mother, The', 345, '');
INSERT INTO 'tune' VALUES (8556, NULL, '2012-01-20 12:54:47.581942+00', 'Martin', 345, '');
INSERT INTO 'tune' VALUES (8557, NULL, '2012-01-20 12:54:47.584841+00', 'Noreen', 345, '');
INSERT INTO 'tune' VALUES (8558, NULL, '2012-01-20 12:54:47.587768+00', 'Bravo Warriers', 345, '');
INSERT INTO 'tune' VALUES (8559, NULL, '2012-01-20 12:54:47.590665+00', 'Lord George Gordon''s Strathspey', 345, '');
INSERT INTO 'tune' VALUES (8560, NULL, '2012-01-20 12:54:47.593556+00', 'Dyer''s Frolic, The', 345, '');
INSERT INTO 'tune' VALUES (8561, NULL, '2012-01-20 12:54:47.596448+00', 'Fraser''s Lament', 345, '');
INSERT INTO 'tune' VALUES (8562, NULL, '2012-01-20 12:54:47.599339+00', 'Blackhead Bay', 345, '');
INSERT INTO 'tune' VALUES (8563, NULL, '2012-01-20 12:54:47.602234+00', 'Source of the Nith, The', 345, '');
INSERT INTO 'tune' VALUES (8564, NULL, '2012-01-20 12:54:47.605137+00', 'Mel Briscoe', 345, '');
INSERT INTO 'tune' VALUES (8565, NULL, '2012-01-20 12:54:47.608087+00', 'Phil Graham', 345, '');
INSERT INTO 'tune' VALUES (8566, NULL, '2012-01-20 12:54:47.610988+00', 'General Practitioner, The', 345, '');
INSERT INTO 'tune' VALUES (8567, NULL, '2012-01-20 12:54:47.613878+00', 'Surgeon, The', 345, '');
INSERT INTO 'tune' VALUES (8568, NULL, '2012-01-20 12:54:47.616803+00', 'Hanley''s', 345, '');
INSERT INTO 'tune' VALUES (8569, NULL, '2012-01-20 12:54:47.619698+00', 'Tiger', 345, '');
INSERT INTO 'tune' VALUES (8570, NULL, '2012-01-20 12:54:47.622612+00', 'Benison', 345, '');
INSERT INTO 'tune' VALUES (8571, NULL, '2012-01-20 12:54:47.625497+00', 'September Waltz', 345, '');
INSERT INTO 'tune' VALUES (8572, NULL, '2012-01-20 12:54:47.628414+00', 'Good Ship, the Matthew, The', 345, '');
INSERT INTO 'tune' VALUES (8573, NULL, '2012-01-20 12:54:47.631316+00', 'Pinebuds in September', 345, '');
INSERT INTO 'tune' VALUES (8574, NULL, '2012-01-20 12:54:47.634209+00', 'Trip', 3232, '');
INSERT INTO 'tune' VALUES (8575, NULL, '2012-01-20 12:54:47.637103+00', 'To', 3232, '');
INSERT INTO 'tune' VALUES (8576, NULL, '2012-01-20 12:54:47.639988+00', 'Mal', 3232, '');
INSERT INTO 'tune' VALUES (8577, NULL, '2012-01-20 12:54:47.642907+00', 'Aria', 3232, '');
INSERT INTO 'tune' VALUES (8578, NULL, '2012-01-20 12:54:47.645791+00', 'Margaret''s Reel', 3232, '');
INSERT INTO 'tune' VALUES (8579, NULL, '2012-01-20 12:54:47.648683+00', 'Harry''s Fancy', 3232, '');
INSERT INTO 'tune' VALUES (8580, NULL, '2012-01-20 12:54:47.651584+00', 'Hunch Cuddy', 165, '');
INSERT INTO 'tune' VALUES (8581, NULL, '2012-01-20 12:54:47.654471+00', 'Step Lively', 165, '');
INSERT INTO 'tune' VALUES (8582, NULL, '2012-01-20 12:54:47.657356+00', 'Other ''45, The', 165, '');
INSERT INTO 'tune' VALUES (8583, NULL, '2012-01-20 12:54:47.660785+00', 'Chattanooga', 165, '');
INSERT INTO 'tune' VALUES (8584, NULL, '2012-01-20 12:54:47.663743+00', 'Tilquhillie', 165, '');
INSERT INTO 'tune' VALUES (8585, NULL, '2012-01-20 12:54:47.666672+00', 'Primrose and the Daffodil, The', 2362, '');
INSERT INTO 'tune' VALUES (8586, NULL, '2012-01-20 12:54:47.669566+00', 'Market Leys', 3248, '');
INSERT INTO 'tune' VALUES (8588, NULL, '2012-01-20 12:54:47.675365+00', 'Rae Wallace', 1525, '');
INSERT INTO 'tune' VALUES (8589, NULL, '2012-01-20 12:54:47.67826+00', 'Sparrow''s Hall', 2251, '');
INSERT INTO 'tune' VALUES (8590, NULL, '2012-01-20 12:54:47.681147+00', 'Gairsay', 9998, '');
INSERT INTO 'tune' VALUES (8591, NULL, '2012-01-20 12:54:47.684041+00', 'New Brighton Pier, The', 9998, '');
INSERT INTO 'tune' VALUES (8592, NULL, '2012-01-20 12:54:47.686936+00', 'Dancin'' Don', 3281, '');
INSERT INTO 'tune' VALUES (8593, NULL, '2012-01-20 12:54:47.689822+00', 'Strathspey for Noel', 1764, '');
INSERT INTO 'tune' VALUES (8594, NULL, '2012-01-20 12:54:47.692713+00', 'Dainty Duncan', 3282, '');
INSERT INTO 'tune' VALUES (8595, NULL, '2012-01-20 12:54:47.695609+00', 'Roddy''s 40th Birthday Celebration', 1593, '');
INSERT INTO 'tune' VALUES (8596, NULL, '2012-01-20 12:54:47.698515+00', 'Dancing in 2000', 1508, '');
INSERT INTO 'tune' VALUES (8597, NULL, '2012-01-20 12:54:47.701415+00', 'Uni-Romper''s Reel, The', 1725, '');
INSERT INTO 'tune' VALUES (8598, NULL, '2012-01-20 12:54:47.70431+00', 'Bonnie Dunoon', 1582, '');
INSERT INTO 'tune' VALUES (8599, NULL, '2012-01-20 12:54:47.707214+00', 'Judy''s Jig', 1534, '');
INSERT INTO 'tune' VALUES (8600, NULL, '2012-01-20 12:54:47.7101+00', 'Timothy Sennet', 316, '');
INSERT INTO 'tune' VALUES (8601, NULL, '2012-01-20 12:54:47.712993+00', 'Aussie Scotch Pom', 848, '');
INSERT INTO 'tune' VALUES (8602, NULL, '2012-01-20 12:54:47.715889+00', 'Forfar Hunt', 2170, '');
INSERT INTO 'tune' VALUES (8603, NULL, '2012-01-20 12:54:47.718791+00', 'Loch O''Forfar', 1904, '');
INSERT INTO 'tune' VALUES (8604, NULL, '2012-01-20 12:54:47.721682+00', 'Hooch-o-Ro Here-We-Go', 1904, '');
INSERT INTO 'tune' VALUES (8605, NULL, '2012-01-20 12:54:47.724572+00', 'Alistair Hardie', 1710, '');
INSERT INTO 'tune' VALUES (8606, NULL, '2012-01-20 12:54:47.727567+00', 'Ally''s Soond', 1710, '');
INSERT INTO 'tune' VALUES (8607, NULL, '2012-01-20 12:54:47.730477+00', 'Andrew Hughson', 1710, '');
INSERT INTO 'tune' VALUES (8608, NULL, '2012-01-20 12:54:47.733358+00', 'Alamootie, Da', 1710, '');
INSERT INTO 'tune' VALUES (8609, NULL, '2012-01-20 12:54:47.736253+00', 'Auld Peat Rod, Da', 1710, '');
INSERT INTO 'tune' VALUES (8610, NULL, '2012-01-20 12:54:47.739167+00', 'Barclay''s Hornpipe', 1710, '');
INSERT INTO 'tune' VALUES (8611, NULL, '2012-01-20 12:54:47.742051+00', 'Britannia Hornpipe, The', 1710, '');
INSERT INTO 'tune' VALUES (8612, NULL, '2012-01-20 12:54:47.744948+00', 'Come Awa In', 1710, '');
INSERT INTO 'tune' VALUES (8613, NULL, '2012-01-20 12:54:47.747943+00', 'David Manson of Quarff', 1710, '');
INSERT INTO 'tune' VALUES (8614, NULL, '2012-01-20 12:54:47.750865+00', 'Dawn''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (8615, NULL, '2012-01-20 12:54:47.753767+00', 'Fiona''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (8616, NULL, '2012-01-20 12:54:47.756663+00', 'Haa, Da', 1710, '');
INSERT INTO 'tune' VALUES (8617, NULL, '2012-01-20 12:54:47.759598+00', 'Jimmy Ritchie of Delgatie', 1710, '');
INSERT INTO 'tune' VALUES (8618, NULL, '2012-01-20 12:54:47.762497+00', 'Prsident''s Hornpipe', 1710, '');
INSERT INTO 'tune' VALUES (8619, NULL, '2012-01-20 12:54:47.765385+00', 'Magnie o'' da Daeks', 1710, '');
INSERT INTO 'tune' VALUES (8620, NULL, '2012-01-20 12:54:47.768282+00', 'Rod tae Eshaness, Da', 1710, '');
INSERT INTO 'tune' VALUES (8621, NULL, '2012-01-20 12:54:47.771171+00', 'Stirlins ida Lum', 1710, '');
INSERT INTO 'tune' VALUES (8622, NULL, '2012-01-20 12:54:47.774057+00', 'Moorit Lamb', 1710, '');
INSERT INTO 'tune' VALUES (8623, NULL, '2012-01-20 12:54:47.77695+00', 'Miss Betty Henderson', 1710, '');
INSERT INTO 'tune' VALUES (8624, NULL, '2012-01-20 12:54:47.779843+00', 'Violet Tulloch''s Hornpipe', 1710, '');
INSERT INTO 'tune' VALUES (8625, NULL, '2012-01-20 12:54:47.782751+00', 'Wir Linda''s Medley (S)', 1710, '');
INSERT INTO 'tune' VALUES (8626, NULL, '2012-01-20 12:54:47.785631+00', 'Wir Linda''s Medley (R)', 1710, '');
INSERT INTO 'tune' VALUES (8627, NULL, '2012-01-20 12:54:47.788527+00', 'Martin Yule', 1710, '');
INSERT INTO 'tune' VALUES (8628, NULL, '2012-01-20 12:54:47.791414+00', 'Meteor, The', 1710, '');
INSERT INTO 'tune' VALUES (8629, NULL, '2012-01-20 12:54:47.794304+00', 'Sweerie Box, Da', 1710, '');
INSERT INTO 'tune' VALUES (8630, NULL, '2012-01-20 12:54:47.797189+00', 'Tirrick Hornpipe, Da', 1710, '');
INSERT INTO 'tune' VALUES (8631, NULL, '2012-01-20 12:54:47.80008+00', 'Mimie''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (8632, NULL, '2012-01-20 12:54:47.80298+00', 'Artful Lady, The', 1710, '');
INSERT INTO 'tune' VALUES (8633, NULL, '2012-01-20 12:54:47.805867+00', 'Auld Gramophone, The', 1710, '');
INSERT INTO 'tune' VALUES (8634, NULL, '2012-01-20 12:54:47.808758+00', 'Blind Fiddler, Da', 1710, '');
INSERT INTO 'tune' VALUES (8635, NULL, '2012-01-20 12:54:47.811649+00', 'Bobby M Jamieson', 1710, '');
INSERT INTO 'tune' VALUES (8636, NULL, '2012-01-20 12:54:47.814536+00', 'Bobby Thomson', 1710, '');
INSERT INTO 'tune' VALUES (8637, NULL, '2012-01-20 12:54:47.817428+00', 'Buchan Memories', 1710, '');
INSERT INTO 'tune' VALUES (8638, NULL, '2012-01-20 12:54:47.820324+00', 'Burn O''Murrion, Da', 1710, '');
INSERT INTO 'tune' VALUES (8639, NULL, '2012-01-20 12:54:47.823215+00', 'Cappie Stane, Da', 1710, '');
INSERT INTO 'tune' VALUES (8640, NULL, '2012-01-20 12:54:47.826106+00', 'Cathie''s Hornpipe', 1710, '');
INSERT INTO 'tune' VALUES (8641, NULL, '2012-01-20 12:54:47.829046+00', 'Class of ''85, The', 1710, '');
INSERT INTO 'tune' VALUES (8642, NULL, '2012-01-20 12:54:47.831944+00', 'Clocks-Midder', 1710, '');
INSERT INTO 'tune' VALUES (8643, NULL, '2012-01-20 12:54:47.834845+00', 'Crook Baak, Da', 1710, '');
INSERT INTO 'tune' VALUES (8644, NULL, '2012-01-20 12:54:47.837735+00', 'Davie Tulloch', 1710, '');
INSERT INTO 'tune' VALUES (8645, NULL, '2012-01-20 12:54:47.840643+00', 'Jamie''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (8646, NULL, '2012-01-20 12:54:47.843531+00', 'Ian Collie''s Hornpipe', 1710, '');
INSERT INTO 'tune' VALUES (8647, NULL, '2012-01-20 12:54:47.846423+00', 'Hoversta Hornpipe', 1710, '');
INSERT INTO 'tune' VALUES (8648, NULL, '2012-01-20 12:54:47.849316+00', 'Docken Kishie, Da', 1710, '');
INSERT INTO 'tune' VALUES (8649, NULL, '2012-01-20 12:54:47.852203+00', 'Flying Grandma, Da', 1710, '');
INSERT INTO 'tune' VALUES (8650, NULL, '2012-01-20 12:54:47.855102+00', 'Friendly House, Da', 1710, '');
INSERT INTO 'tune' VALUES (8651, NULL, '2012-01-20 12:54:47.857983+00', 'Jean Pole''s Fancy', 1710, '');
INSERT INTO 'tune' VALUES (8652, NULL, '2012-01-20 12:54:47.860917+00', 'Jeanna', 1710, '');
INSERT INTO 'tune' VALUES (8653, NULL, '2012-01-20 12:54:47.863847+00', 'Jim Rodger''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (8654, NULL, '2012-01-20 12:54:47.866741+00', 'John Murdoch Henderson', 1710, '');
INSERT INTO 'tune' VALUES (8655, NULL, '2012-01-20 12:54:47.869634+00', 'Mike Hardcastle', 1710, '');
INSERT INTO 'tune' VALUES (8656, NULL, '2012-01-20 12:54:47.872944+00', 'Shetland''s Welcome to the Prince & Princess of Wales', 1710, '');
INSERT INTO 'tune' VALUES (8657, NULL, '2012-01-20 12:54:47.87589+00', 'Miss Annie Jessop', 1710, '');
INSERT INTO 'tune' VALUES (8658, NULL, '2012-01-20 12:54:47.878793+00', 'Miss Catriona MacDonald', 1710, '');
INSERT INTO 'tune' VALUES (8659, NULL, '2012-01-20 12:54:47.881685+00', 'Miss Erica Jolly''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (8660, NULL, '2012-01-20 12:54:47.884579+00', 'Miss Ingrid Elphinstone', 1710, '');
INSERT INTO 'tune' VALUES (8661, NULL, '2012-01-20 12:54:47.887479+00', 'Miss Jacqueline Sinclair', 1710, '');
INSERT INTO 'tune' VALUES (8662, NULL, '2012-01-20 12:54:47.890364+00', 'Miss Julie Dennison', 1710, '');
INSERT INTO 'tune' VALUES (8663, NULL, '2012-01-20 12:54:47.89329+00', 'Miss Kathleen Hogarth', 1710, '');
INSERT INTO 'tune' VALUES (8664, NULL, '2012-01-20 12:54:47.896203+00', 'Miss Mandy Tulloch', 1710, '');
INSERT INTO 'tune' VALUES (8665, NULL, '2012-01-20 12:54:47.899094+00', 'Miss Margaret Johnston''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (8666, NULL, '2012-01-20 12:54:47.901993+00', 'Miss Morag Williamson', 1710, '');
INSERT INTO 'tune' VALUES (8667, NULL, '2012-01-20 12:54:47.90489+00', 'Modest Genius, The', 1710, '');
INSERT INTO 'tune' VALUES (8668, NULL, '2012-01-20 12:54:47.907778+00', 'Mr John Irvine', 1710, '');
INSERT INTO 'tune' VALUES (8669, NULL, '2012-01-20 12:54:47.91067+00', 'Nancy Nicholson''s Tune', 1710, '');
INSERT INTO 'tune' VALUES (8670, NULL, '2012-01-20 12:54:47.913566+00', 'Nesting Fiddler, The', 1710, '');
INSERT INTO 'tune' VALUES (8671, NULL, '2012-01-20 12:54:47.916456+00', 'Norwick Wedding', 1710, '');
INSERT INTO 'tune' VALUES (8672, NULL, '2012-01-20 12:54:47.919345+00', 'Smith o'' Couster''s Fancy', 1710, '');
INSERT INTO 'tune' VALUES (8673, NULL, '2012-01-20 12:54:47.922236+00', 'Sumburgh Roost', 1710, '');
INSERT INTO 'tune' VALUES (8674, NULL, '2012-01-20 12:54:47.925123+00', 'Timothy''s Jig', 1710, '');
INSERT INTO 'tune' VALUES (8675, NULL, '2012-01-20 12:54:47.928161+00', 'Tom Anderson''s Compliments to Bob Crease', 1710, '');
INSERT INTO 'tune' VALUES (8676, NULL, '2012-01-20 12:54:47.931088+00', 'Tom Anderson''s Compliments to Prof. W Cramond', 1710, '');
INSERT INTO 'tune' VALUES (8677, NULL, '2012-01-20 12:54:47.933985+00', 'Trevor Hunter', 1710, '');
INSERT INTO 'tune' VALUES (8678, NULL, '2012-01-20 12:54:47.936896+00', 'Willie''s Lambhoose Lintel', 1710, '');
INSERT INTO 'tune' VALUES (8679, NULL, '2012-01-20 12:54:47.939814+00', 'Will''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (8680, NULL, '2012-01-20 12:54:47.942714+00', 'Cloddie Hall', 3289, '');
INSERT INTO 'tune' VALUES (8681, NULL, '2012-01-20 12:54:47.945609+00', 'Fiddle Teacher, Da', 3290, '');
INSERT INTO 'tune' VALUES (8682, NULL, '2012-01-20 12:54:47.948505+00', 'Tilly Plump', 9999, '');
INSERT INTO 'tune' VALUES (8683, NULL, '2012-01-20 12:54:47.951406+00', 'Anne Black', 1634, '');
INSERT INTO 'tune' VALUES (8684, NULL, '2012-01-20 12:54:47.954303+00', 'Willie Hunter''s Fiddle', 1634, '');
INSERT INTO 'tune' VALUES (8685, NULL, '2012-01-20 12:54:47.957208+00', 'Butterstone Braes', 1634, '');
INSERT INTO 'tune' VALUES (8686, NULL, '2012-01-20 12:54:47.960106+00', 'Long Road Home, The', 1634, '');
INSERT INTO 'tune' VALUES (8687, NULL, '2012-01-20 12:54:47.962999+00', 'Elma and Cecil', 1582, '');
INSERT INTO 'tune' VALUES (8688, NULL, '2012-01-20 12:54:47.965883+00', 'Gordon Greenlaw''s Reel', 1611, '');
INSERT INTO 'tune' VALUES (8689, NULL, '2012-01-20 12:54:47.968774+00', 'Stagshaw Bank', 1611, '');
INSERT INTO 'tune' VALUES (8690, NULL, '2012-01-20 12:54:47.97835+00', 'Boode''s Welcome, The', 1586, '');
INSERT INTO 'tune' VALUES (8691, NULL, '2012-01-20 12:54:47.981337+00', 'Dreggie Brae', 1586, '');
INSERT INTO 'tune' VALUES (8692, '2003-10-02 22:00:00+00', '2012-01-20 12:54:47.984253+00', 'Anne and Donald Jig, The', 3438, '');
INSERT INTO 'tune' VALUES (8693, NULL, '2012-01-20 12:54:47.98718+00', 'Edith MacPherson', 1586, '');
INSERT INTO 'tune' VALUES (8694, NULL, '2012-01-20 12:54:47.990062+00', 'Link', 1586, '');
INSERT INTO 'tune' VALUES (8695, NULL, '2012-01-20 12:54:47.992954+00', 'Morven''s Welcome', 1586, '');
INSERT INTO 'tune' VALUES (8696, NULL, '2012-01-20 12:54:47.995844+00', 'Rae Russell', 1586, '');
INSERT INTO 'tune' VALUES (8697, NULL, '2012-01-20 12:54:47.998735+00', 'Shelagh Sutherland', 1586, '');
INSERT INTO 'tune' VALUES (8698, NULL, '2012-01-20 12:54:48.001617+00', 'Victoria Strathspey, The', 1586, '');
INSERT INTO 'tune' VALUES (8699, NULL, '2012-01-20 12:54:48.004506+00', 'Willie James', 1586, '');
INSERT INTO 'tune' VALUES (8700, NULL, '2012-01-20 12:54:48.007393+00', 'Ernie''s reel', 1607, '');
INSERT INTO 'tune' VALUES (8701, NULL, '2012-01-20 12:54:48.010314+00', 'Mac''s Jig', 1607, '');
INSERT INTO 'tune' VALUES (8702, NULL, '2012-01-20 12:54:48.013209+00', 'Rab MacPhee', 1554, '');
INSERT INTO 'tune' VALUES (8703, NULL, '2012-01-20 12:54:48.016092+00', 'Reverend James Stewart', 1554, '');
INSERT INTO 'tune' VALUES (8704, NULL, '2012-01-20 12:54:48.01898+00', 'Wull White', 1554, '');
INSERT INTO 'tune' VALUES (8705, NULL, '2012-01-20 12:54:48.02187+00', 'Baker, The', 1512, '');
INSERT INTO 'tune' VALUES (8706, NULL, '2012-01-20 12:54:48.024769+00', 'Bob Williamson', 1512, '');
INSERT INTO 'tune' VALUES (8707, NULL, '2012-01-20 12:54:48.027658+00', 'Forfeit o'' da Ship, Da', 9998, '');
INSERT INTO 'tune' VALUES (8708, NULL, '2012-01-20 12:54:48.030549+00', 'Jenny''s Chickens', 9998, '');
INSERT INTO 'tune' VALUES (8709, NULL, '2012-01-20 12:54:48.033433+00', 'Aandown at da Bow', 9998, '');
INSERT INTO 'tune' VALUES (8710, NULL, '2012-01-20 12:54:48.036322+00', 'Lynne''s Reel', 3291, '');
INSERT INTO 'tune' VALUES (8711, NULL, '2012-01-20 12:54:48.039224+00', 'Nine Points of Roguery, The', 9998, '');
INSERT INTO 'tune' VALUES (8712, NULL, '2012-01-20 12:54:48.042108+00', 'Ode to Eli Bain', 3292, '');
INSERT INTO 'tune' VALUES (8713, NULL, '2012-01-20 12:54:48.044999+00', 'Red Ferret''s Fancy, The', 3293, '');
INSERT INTO 'tune' VALUES (8714, NULL, '2012-01-20 12:54:48.047897+00', 'Repeal the Poll Tax', 3294, '');
INSERT INTO 'tune' VALUES (8715, NULL, '2012-01-20 12:54:48.050798+00', 'Sarah Farley', 2392, '');
INSERT INTO 'tune' VALUES (8716, NULL, '2012-01-20 12:54:48.053676+00', 'Devil and the Dirk, The', 1512, '');
INSERT INTO 'tune' VALUES (8717, NULL, '2012-01-20 12:54:48.056666+00', 'Tam O'' Shanter', 249, '');
INSERT INTO 'tune' VALUES (8718, NULL, '2012-01-20 12:54:48.059572+00', 'Waters of Bannockburn, The', 837, '');
INSERT INTO 'tune' VALUES (8719, NULL, '2012-01-20 12:54:48.063172+00', 'Bowden Moor', 1490, '');
INSERT INTO 'tune' VALUES (8720, NULL, '2012-01-20 12:54:48.066133+00', 'Duke of Gloucester''s Visit to Inverness, The', 2362, '');
INSERT INTO 'tune' VALUES (8721, NULL, '2012-01-20 12:54:48.069033+00', 'Eildon Hills, The', 1490, '');
INSERT INTO 'tune' VALUES (8722, NULL, '2012-01-20 12:54:48.072833+00', 'Molly''s Reel', 1629, '');
INSERT INTO 'tune' VALUES (8723, NULL, '2012-01-20 12:54:48.076651+00', 'Mrs E F Clinkscale', 1490, '');
INSERT INTO 'tune' VALUES (8724, NULL, '2012-01-20 12:54:48.080463+00', 'Stuart''s Reel', 1629, '');
INSERT INTO 'tune' VALUES (8725, NULL, '2012-01-20 12:54:48.084277+00', 'Miss Barbara Bane of New Deer', 1522, '');
INSERT INTO 'tune' VALUES (8726, NULL, '2012-01-20 12:54:48.087772+00', 'Clyde Hornpipe', 1659, '');
INSERT INTO 'tune' VALUES (8727, NULL, '2012-01-20 12:54:48.090709+00', 'Meet Me on the Gowan Lee', 2933, '');
INSERT INTO 'tune' VALUES (8728, NULL, '2012-01-20 12:54:48.093596+00', 'Alastair MacAlastair', 9999, '');
INSERT INTO 'tune' VALUES (8729, NULL, '2012-01-20 12:54:48.096867+00', 'Andrew Manuel Harper', 2362, '');
INSERT INTO 'tune' VALUES (8730, NULL, '2012-01-20 12:54:48.099781+00', 'Atholl Highlanders Visit to Edinburgh 1971, The', 2362, '');
INSERT INTO 'tune' VALUES (8731, NULL, '2012-01-20 12:54:48.102676+00', 'Billy McMorran''s Crook', 2362, '');
INSERT INTO 'tune' VALUES (8733, NULL, '2012-01-20 12:54:48.108519+00', 'Dick and Ivy Sinclair of Edinburgh', 2362, '');
INSERT INTO 'tune' VALUES (8734, NULL, '2012-01-20 12:54:48.111501+00', 'In Memory of Rusky', 2362, '');
INSERT INTO 'tune' VALUES (8735, NULL, '2012-01-20 12:54:48.114565+00', 'John Gunn''s Anniversary', 2362, '');
INSERT INTO 'tune' VALUES (8736, NULL, '2012-01-20 12:54:48.117916+00', 'Manola''s Reel', 2362, '');
INSERT INTO 'tune' VALUES (8737, NULL, '2012-01-20 12:54:48.121753+00', 'Patches March', 2362, '');
INSERT INTO 'tune' VALUES (8738, NULL, '2012-01-20 12:54:48.126447+00', 'Ronald M Wink', 2362, '');
INSERT INTO 'tune' VALUES (8739, NULL, '2012-01-20 12:54:48.130557+00', 'Seven Stars, The', 2362, '');
INSERT INTO 'tune' VALUES (8740, NULL, '2012-01-20 12:54:48.134383+00', 'Watten''s Welcome to the Queen Mother', 2362, '');
INSERT INTO 'tune' VALUES (8741, NULL, '2012-01-20 12:54:48.138236+00', 'Alasdair Macleod''s Welcome to Edinburgh', 1527, '');
INSERT INTO 'tune' VALUES (8742, NULL, '2012-01-20 12:54:48.142074+00', 'Betty Milligan''s Wedding March', 1527, '');
INSERT INTO 'tune' VALUES (8743, NULL, '2012-01-20 12:54:48.145904+00', 'Doreen Davidson''s Welcome to Scotland', 1527, '');
INSERT INTO 'tune' VALUES (8744, NULL, '2012-01-20 12:54:48.149849+00', 'Iain MacPhail''s Compliments to Clan MacSporran', 1527, '');
INSERT INTO 'tune' VALUES (8745, NULL, '2012-01-20 12:54:48.153662+00', 'Miss Angela Campbell of Halkirk', 1527, '');
INSERT INTO 'tune' VALUES (8746, NULL, '2012-01-20 12:54:48.157479+00', 'Miss Caristiona MacLellan', 1527, '');
INSERT INTO 'tune' VALUES (8747, NULL, '2012-01-20 12:54:48.161292+00', 'Tailors of Allanton, The', 1502, '');
INSERT INTO 'tune' VALUES (8748, NULL, '2012-01-20 12:54:48.16514+00', 'Mrs Maitland of Rankeillor''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (8749, NULL, '2012-01-20 12:54:48.169141+00', 'Mrs Small of Dirnanean''s Jigg', 1495, '');
INSERT INTO 'tune' VALUES (8750, NULL, '2012-01-20 12:54:48.173042+00', 'Mrs Gwynne''s Fancy', 1495, '');
INSERT INTO 'tune' VALUES (8751, NULL, '2012-01-20 12:54:48.176855+00', 'Miss Campbell of Melford', 1517, '');
INSERT INTO 'tune' VALUES (8752, NULL, '2012-01-20 12:54:48.180651+00', 'Viv''s Baseball Cap', 2695, '');
INSERT INTO 'tune' VALUES (8753, NULL, '2012-01-20 12:54:48.184467+00', 'Reel for Dave Fleetwood', 3299, '');
INSERT INTO 'tune' VALUES (8754, NULL, '2012-01-20 12:54:48.188275+00', 'Mill House, The', 3300, '');
INSERT INTO 'tune' VALUES (8755, NULL, '2012-01-20 12:54:48.192154+00', 'Cranking Out', 1633, '');
INSERT INTO 'tune' VALUES (8756, NULL, '2012-01-20 12:54:48.195966+00', 'Fiddler''s Breakfast', 1633, '');
INSERT INTO 'tune' VALUES (8757, NULL, '2012-01-20 12:54:48.199775+00', 'Mr F. Garden Junior of Troup''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (8758, NULL, '2012-01-20 12:54:48.203585+00', 'Hogtie''s Reel', 1761, '');
INSERT INTO 'tune' VALUES (8759, NULL, '2012-01-20 12:54:48.207389+00', 'Legless in Lisburn', 3301, '');
INSERT INTO 'tune' VALUES (8760, NULL, '2012-01-20 12:54:48.211213+00', 'Hunter''s Bog', 1699, '');
INSERT INTO 'tune' VALUES (8761, NULL, '2012-01-20 12:54:48.215105+00', 'Farquhar and Hettie''s Waltz', 3302, '');
INSERT INTO 'tune' VALUES (8762, NULL, '2012-01-20 12:54:48.21892+00', 'Brackla Waltz, The', 1539, '');
INSERT INTO 'tune' VALUES (8763, NULL, '2012-01-20 12:54:48.222903+00', 'Sneug Water Waltz, The', 3303, '');
INSERT INTO 'tune' VALUES (8764, NULL, '2012-01-20 12:54:48.226716+00', 'O bonny Lass will ye ly in a Barrack', 9999, '');
INSERT INTO 'tune' VALUES (8765, NULL, '2012-01-20 12:54:48.230628+00', 'Royal Caledonian Hunt''s Delight, The', 3304, '');
INSERT INTO 'tune' VALUES (8766, NULL, '2012-01-20 12:54:48.234547+00', 'Pretty Dick''s Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (8767, NULL, '2012-01-20 12:54:48.238357+00', 'Soldier''s Hornpipe, The', 9998, '');
INSERT INTO 'tune' VALUES (8768, NULL, '2012-01-20 12:54:48.242442+00', 'Untitled Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (8769, NULL, '2012-01-20 12:54:48.246262+00', 'Margaret''s Ghost', 9998, '');
INSERT INTO 'tune' VALUES (8770, NULL, '2012-01-20 12:54:48.250067+00', 'Cumbernauld House', 9998, '');
INSERT INTO 'tune' VALUES (8771, NULL, '2012-01-20 12:54:48.254112+00', 'Black Eagle, The', 9998, '');
INSERT INTO 'tune' VALUES (8772, NULL, '2012-01-20 12:54:48.257937+00', 'Dust in the Lane', 9999, '');
INSERT INTO 'tune' VALUES (8773, NULL, '2012-01-20 12:54:48.261754+00', 'Cajun Chas - Wild Man of Rock', 3305, '');
INSERT INTO 'tune' VALUES (8774, NULL, '2012-01-20 12:54:48.265559+00', 'Fiddlin'' around', 9999, '');
INSERT INTO 'tune' VALUES (8775, NULL, '2012-01-20 12:54:48.26937+00', 'Davidson the Luthier', 3306, '');
INSERT INTO 'tune' VALUES (8776, NULL, '2012-01-20 12:54:48.273254+00', 'Colonel Upton''s Merry Conceit', 9999, '');
INSERT INTO 'tune' VALUES (8777, NULL, '2012-01-20 12:54:48.277094+00', 'Pas Doux', 1897, '');
INSERT INTO 'tune' VALUES (8778, NULL, '2012-01-20 12:54:48.280902+00', 'Mrs Laing''s Strathspey - Fochabers', 1516, '');
INSERT INTO 'tune' VALUES (8779, NULL, '2012-01-20 12:54:48.284834+00', 'Duchess of Bedford''s Strathspey, The', 1516, '');
INSERT INTO 'tune' VALUES (8780, NULL, '2012-01-20 12:54:48.28886+00', 'Miss Gordon of Lesmore''s Strathspey', 1695, '');
INSERT INTO 'tune' VALUES (8781, NULL, '2012-01-20 12:54:48.292591+00', 'Heights of the Alma, The', 1635, '');
INSERT INTO 'tune' VALUES (8782, NULL, '2012-01-20 12:54:48.295548+00', 'Lady Margaret Stewart', 1518, '');
INSERT INTO 'tune' VALUES (8783, NULL, '2012-01-20 12:54:48.298472+00', 'Cottar''s Wife, The', 9999, '');
INSERT INTO 'tune' VALUES (8784, NULL, '2012-01-20 12:54:48.301374+00', 'Loch Erroch Side', 1587, '');
INSERT INTO 'tune' VALUES (8786, NULL, '2012-01-20 12:54:48.307169+00', 'Lord Elcho''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (8787, NULL, '2012-01-20 12:54:48.310085+00', 'Mrs Farquharson (of Invercauld''s) Reel', 1519, '');
INSERT INTO 'tune' VALUES (8788, NULL, '2012-01-20 12:54:48.313025+00', 'Jack and Edna Walton', 1593, '');
INSERT INTO 'tune' VALUES (8789, NULL, '2012-01-20 12:54:48.315919+00', 'Georgie Finlay of St. Andrews', 1595, '');
INSERT INTO 'tune' VALUES (8790, NULL, '2012-01-20 12:54:48.318809+00', 'Willie Hunter''s Compliments to Hughie Hughson', 1677, '');
INSERT INTO 'tune' VALUES (8791, NULL, '2012-01-20 12:54:48.32171+00', 'Dawn Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (8792, NULL, '2012-01-20 12:54:48.32467+00', 'Miss Blyth Brewster', 1591, '');
INSERT INTO 'tune' VALUES (8793, NULL, '2012-01-20 12:54:48.327726+00', 'Miss Lynsey Dewar''s Strathspey', 1591, '');
INSERT INTO 'tune' VALUES (8794, NULL, '2012-01-20 12:54:48.330644+00', 'Malcolm Crowe of Balmullo', 1554, '');
INSERT INTO 'tune' VALUES (8795, NULL, '2012-01-20 12:54:48.33373+00', 'Lady Catherine Stewart', 9999, '');
INSERT INTO 'tune' VALUES (8796, NULL, '2012-01-20 12:54:48.336645+00', 'Donald Ridley''s Compliments to Willie Hunter', 1593, '');
INSERT INTO 'tune' VALUES (8798, NULL, '2012-01-20 12:54:48.342427+00', 'Woodlands', 1591, '');
INSERT INTO 'tune' VALUES (8800, NULL, '2012-01-20 12:54:48.348217+00', 'Down the Brae', 9998, '');
INSERT INTO 'tune' VALUES (8801, NULL, '2012-01-20 12:54:48.351134+00', 'God Save Ireland', 9999, '');
INSERT INTO 'tune' VALUES (8802, NULL, '2012-01-20 12:54:48.354032+00', 'Three Flowers, The', 9999, '');
INSERT INTO 'tune' VALUES (8803, NULL, '2012-01-20 12:54:48.35693+00', 'John Douglas of Dumfries', 1593, '');
INSERT INTO 'tune' VALUES (8804, NULL, '2012-01-20 12:54:48.359821+00', 'Charlie Murray', 1668, '');
INSERT INTO 'tune' VALUES (8805, NULL, '2012-01-20 12:54:48.362716+00', 'Mrs Jane Chapman', 1613, '');
INSERT INTO 'tune' VALUES (8806, NULL, '2012-01-20 12:54:48.365593+00', 'Ragtime Pipers', 1673, '');
INSERT INTO 'tune' VALUES (8807, NULL, '2012-01-20 12:54:48.368486+00', 'Peacock Reel, The', 1673, '');
INSERT INTO 'tune' VALUES (8808, NULL, '2012-01-20 12:54:48.37138+00', 'Noel Slagle', 1673, '');
INSERT INTO 'tune' VALUES (8809, NULL, '2012-01-20 12:54:48.374274+00', 'Pink Panther Theme', 10223, '');
INSERT INTO 'tune' VALUES (8810, NULL, '2012-01-20 12:54:48.377166+00', 'Morag Fairhead''s Strathspey', 1527, '');
INSERT INTO 'tune' VALUES (8811, NULL, '2012-01-20 12:54:48.38014+00', 'Memories of Andrew Rankine', 3311, '');
INSERT INTO 'tune' VALUES (8812, NULL, '2012-01-20 12:54:48.383049+00', 'Pat Houghton''s Strathspey', 1527, '');
INSERT INTO 'tune' VALUES (8813, NULL, '2012-01-20 12:54:48.385935+00', 'Miss Mackenzie''s Farewell', 9999, '');
INSERT INTO 'tune' VALUES (8815, NULL, '2012-01-20 12:54:48.39175+00', 'Virginia Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (8816, NULL, '2012-01-20 12:54:48.394638+00', 'Maids of Islay, The', 9999, '');
INSERT INTO 'tune' VALUES (8817, NULL, '2012-01-20 12:54:48.397526+00', 'Hawthorn Hedges', 9999, '');
INSERT INTO 'tune' VALUES (8818, NULL, '2012-01-20 12:54:48.400415+00', 'Green Garters', 9999, '');
INSERT INTO 'tune' VALUES (8819, NULL, '2012-01-20 12:54:48.403308+00', 'Murtough Molloy', 9999, '');
INSERT INTO 'tune' VALUES (8820, NULL, '2012-01-20 12:54:48.406199+00', 'Happy and Light', 9999, '');
INSERT INTO 'tune' VALUES (8821, NULL, '2012-01-20 12:54:48.409088+00', 'Village Festival, The', 9999, '');
INSERT INTO 'tune' VALUES (8822, NULL, '2012-01-20 12:54:48.411967+00', 'Our Dread Monarch', 9999, '');
INSERT INTO 'tune' VALUES (8823, NULL, '2012-01-20 12:54:48.414851+00', 'Air From Light Cavalry', 9999, '');
INSERT INTO 'tune' VALUES (8824, NULL, '2012-01-20 12:54:48.417733+00', 'MacLauchlane''s Scots Measure', 9999, '');
INSERT INTO 'tune' VALUES (8825, NULL, '2012-01-20 12:54:48.42063+00', 'Mrs Andy Campbell''s Scotch Measure', 9999, '');
INSERT INTO 'tune' VALUES (8826, NULL, '2012-01-20 12:54:48.423513+00', 'Gordon Stewart Forbes'' Favourite', 9999, '');
INSERT INTO 'tune' VALUES (8827, NULL, '2012-01-20 12:54:48.426398+00', 'Bog of Rannes, The', 9999, '');
INSERT INTO 'tune' VALUES (8828, NULL, '2012-01-20 12:54:48.42929+00', 'Stuart Forbes of Shielburn', 1527, '');
INSERT INTO 'tune' VALUES (8829, NULL, '2012-01-20 12:54:48.432202+00', 'Charles Macpherson Bisset of Aberdeen', 1527, '');
INSERT INTO 'tune' VALUES (8830, NULL, '2012-01-20 12:54:48.435096+00', 'Alastair Forbes of Craigievar', 1527, '');
INSERT INTO 'tune' VALUES (8831, NULL, '2012-01-20 12:54:48.43798+00', 'Miss Ross of Elgin''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (8832, NULL, '2012-01-20 12:54:48.440875+00', 'Mrs Colonel Forbes'' Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (13858, '2018-03-30 09:35:17.638226+00', '2018-03-30 09:35:17.638226+00', 'Hard Times', 2293, '');
INSERT INTO 'tune' VALUES (8834, NULL, '2012-01-20 12:54:48.446662+00', 'Miss Young of Banff''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (8835, NULL, '2012-01-20 12:54:48.449571+00', 'Mrs Mary Grant MacInnes of Danderleith', 9999, '');
INSERT INTO 'tune' VALUES (8836, NULL, '2012-01-20 12:54:48.452464+00', 'Lord Alexander Russell''s Jig', 1516, '');
INSERT INTO 'tune' VALUES (8837, NULL, '2012-01-20 12:54:48.455357+00', 'Miss Charlotte Ann Lowe', 9999, '');
INSERT INTO 'tune' VALUES (8838, NULL, '2012-01-20 12:54:48.458244+00', 'Antarctica Bound', 1502, '');
INSERT INTO 'tune' VALUES (8839, NULL, '2012-01-20 12:54:48.461135+00', 'Scotia Sea', 1502, '');
INSERT INTO 'tune' VALUES (8840, NULL, '2012-01-20 12:54:48.464024+00', 'Aileen''s Reel', 1501, '');
INSERT INTO 'tune' VALUES (8841, NULL, '2012-01-20 12:54:48.466909+00', 'Royal Scottish Geographical Society, The', 1502, '');
INSERT INTO 'tune' VALUES (8842, NULL, '2012-01-20 12:54:48.469794+00', 'Brimham Rocks', 1501, '');
INSERT INTO 'tune' VALUES (9262, NULL, '2012-01-20 12:54:49.797058+00', 'Croughly', 1516, '');
INSERT INTO 'tune' VALUES (8843, NULL, '2012-01-20 12:54:48.47269+00', 'Revies'' Retreat, The', 1501, '');
INSERT INTO 'tune' VALUES (8844, NULL, '2012-01-20 12:54:48.475576+00', 'Coats Land', 1502, '');
INSERT INTO 'tune' VALUES (8845, NULL, '2012-01-20 12:54:48.478465+00', 'Lad o'' Pairts, A', 1554, '');
INSERT INTO 'tune' VALUES (8846, NULL, '2012-01-20 12:54:48.48139+00', 'Bruce''s Men', 1502, '');
INSERT INTO 'tune' VALUES (8848, NULL, '2012-01-20 12:54:48.487178+00', 'Auld Hip Joint, The', 1501, '');
INSERT INTO 'tune' VALUES (8849, NULL, '2012-01-20 12:54:48.490065+00', 'Speirs Bruce - The Pole Star', 1502, '');
INSERT INTO 'tune' VALUES (8850, NULL, '2012-01-20 12:54:48.492953+00', 'Miss Trotter of Castlelaw''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (8852, NULL, '2012-01-20 12:54:48.498739+00', 'William Speirs Bruce', 3320, '');
INSERT INTO 'tune' VALUES (8853, NULL, '2012-01-20 12:54:48.501629+00', 'Gilbert of the Antarctic', 3320, '');
INSERT INTO 'tune' VALUES (8854, NULL, '2012-01-20 12:54:48.504525+00', 'My Home Town', 1700, '');
INSERT INTO 'tune' VALUES (8855, NULL, '2012-01-20 12:54:48.507422+00', 'Highland Brigade at Magersfontein, The', 1700, '');
INSERT INTO 'tune' VALUES (8856, NULL, '2012-01-20 12:54:48.510314+00', 'South', 3322, '');
INSERT INTO 'tune' VALUES (8857, NULL, '2012-01-20 12:54:48.513204+00', 'Eric''s Cuckoo', 2197, '');
INSERT INTO 'tune' VALUES (8858, NULL, '2012-01-20 12:54:48.516091+00', 'Carola Tress', 2197, '');
INSERT INTO 'tune' VALUES (8859, NULL, '2012-01-20 12:54:48.518991+00', 'Major D. Manson at Clachantrusal', 2283, '');
INSERT INTO 'tune' VALUES (8860, NULL, '2012-01-20 12:54:48.521884+00', 'Maids of the Shieling', 9999, '');
INSERT INTO 'tune' VALUES (8861, NULL, '2012-01-20 12:54:48.524802+00', 'MacLean of Pennycross', 9998, '');
INSERT INTO 'tune' VALUES (8862, NULL, '2012-01-20 12:54:48.527882+00', 'Edinburgh Volunteers March, The', 9998, '');
INSERT INTO 'tune' VALUES (8863, NULL, '2012-01-20 12:54:48.530838+00', 'Dearest My Own One', 1871, '');
INSERT INTO 'tune' VALUES (8864, NULL, '2012-01-20 12:54:48.533736+00', 'Farewell to the Maidens', 9999, '');
INSERT INTO 'tune' VALUES (8865, NULL, '2012-01-20 12:54:48.536649+00', 'Leaving Waternish', 9999, '');
INSERT INTO 'tune' VALUES (8866, NULL, '2012-01-20 12:54:48.539542+00', 'John Morrison', 9998, '');
INSERT INTO 'tune' VALUES (8867, NULL, '2012-01-20 12:54:48.542429+00', 'Albert Williams', 2197, '');
INSERT INTO 'tune' VALUES (8868, NULL, '2012-01-20 12:54:48.545317+00', 'Stephen''s Strathspey', 2197, '');
INSERT INTO 'tune' VALUES (8869, NULL, '2012-01-20 12:54:48.548229+00', 'Stephen''s Reel', 2197, '');
INSERT INTO 'tune' VALUES (8870, NULL, '2012-01-20 12:54:48.551164+00', 'Clann na Breattanich', 2197, '');
INSERT INTO 'tune' VALUES (8871, NULL, '2012-01-20 12:54:48.554047+00', 'Ian Williams', 2197, '');
INSERT INTO 'tune' VALUES (8872, NULL, '2012-01-20 12:54:48.55694+00', 'Colin Johnston', 2197, '');
INSERT INTO 'tune' VALUES (8873, NULL, '2012-01-20 12:54:48.559842+00', 'Widdershins', 2197, '');
INSERT INTO 'tune' VALUES (8874, NULL, '2012-01-20 12:54:48.56275+00', 'Lovat''s Restoration', 9999, '');
INSERT INTO 'tune' VALUES (8875, NULL, '2012-01-20 12:54:48.56564+00', 'Forty Years Together', 3328, '');
INSERT INTO 'tune' VALUES (8876, NULL, '2012-01-20 12:54:48.568527+00', 'Banks of Inverness', 9998, '');
INSERT INTO 'tune' VALUES (8877, NULL, '2012-01-20 12:54:48.571419+00', 'Campbell''s Farewell', 9999, '');
INSERT INTO 'tune' VALUES (8878, NULL, '2012-01-20 12:54:48.574324+00', 'Standards, The', 1829, '');
INSERT INTO 'tune' VALUES (8879, NULL, '2012-01-20 12:54:48.577214+00', 'Have a Drink With Me', 9999, '');
INSERT INTO 'tune' VALUES (8880, NULL, '2012-01-20 12:54:48.580532+00', 'Young Invercauld''s', 9999, '');
INSERT INTO 'tune' VALUES (8881, NULL, '2012-01-20 12:54:48.583431+00', 'Appin House', 9999, '');
INSERT INTO 'tune' VALUES (8882, NULL, '2012-01-20 12:54:48.586349+00', 'Bonnie Beatons, The', 1829, '');
INSERT INTO 'tune' VALUES (8883, NULL, '2012-01-20 12:54:48.589261+00', 'Pete & Lori''s Wedding', 1829, '');
INSERT INTO 'tune' VALUES (8884, NULL, '2012-01-20 12:54:48.5922+00', 'Hey to the Camp', 9999, '');
INSERT INTO 'tune' VALUES (8885, NULL, '2012-01-20 12:54:48.595104+00', 'Song for Sheryl, A', 1763, '');
INSERT INTO 'tune' VALUES (8886, NULL, '2012-01-20 12:54:48.597992+00', 'David''s Air', 1829, '');
INSERT INTO 'tune' VALUES (8887, NULL, '2012-01-20 12:54:48.600885+00', 'Rorate Coeli', 9999, '');
INSERT INTO 'tune' VALUES (8888, NULL, '2012-01-20 12:54:48.603774+00', 'Long for Thy Virginitie, I', 9999, '');
INSERT INTO 'tune' VALUES (8889, NULL, '2012-01-20 12:54:48.606691+00', 'Traveling West', 3204, '');
INSERT INTO 'tune' VALUES (8890, '2003-04-03 22:00:00+00', '2012-01-20 12:54:48.609587+00', 'Eilean Dubh', 2392, '');
INSERT INTO 'tune' VALUES (8891, NULL, '2012-01-20 12:54:48.612509+00', 'Spirit of the House', 3284, '');
INSERT INTO 'tune' VALUES (8892, NULL, '2012-01-20 12:54:48.6154+00', 'Outskirts, The', 1829, '');
INSERT INTO 'tune' VALUES (8893, NULL, '2012-01-20 12:54:48.618305+00', 'Ramblewood Hornpipe', 1763, '');
INSERT INTO 'tune' VALUES (8894, NULL, '2012-01-20 12:54:48.621202+00', 'Hang Fire', 9999, '');
INSERT INTO 'tune' VALUES (8895, NULL, '2012-01-20 12:54:48.624095+00', 'Fiona Miller''s', 1829, '');
INSERT INTO 'tune' VALUES (8896, NULL, '2012-01-20 12:54:48.626989+00', 'Sandy Buchanan''s', 9999, '');
INSERT INTO 'tune' VALUES (8897, NULL, '2012-01-20 12:54:48.629876+00', 'Warlocks, The', 2380, '');
INSERT INTO 'tune' VALUES (8898, NULL, '2012-01-20 12:54:48.632803+00', 'S'' ann an Ile', 9999, '');
INSERT INTO 'tune' VALUES (8899, NULL, '2012-01-20 12:54:48.635707+00', 'Chatterin'' Teeth', 1539, '');
INSERT INTO 'tune' VALUES (8900, NULL, '2012-01-20 12:54:48.638596+00', 'Pull the Arms of the Clock', 1829, '');
INSERT INTO 'tune' VALUES (8901, NULL, '2012-01-20 12:54:48.641518+00', 'Waiting for Jim', 1763, '');
INSERT INTO 'tune' VALUES (8902, '2003-03-19 23:00:00+00', '2012-01-20 12:54:48.64445+00', 'Silver in Cyprus', 3332, '');
INSERT INTO 'tune' VALUES (8903, '2003-04-15 22:00:00+00', '2012-01-20 12:54:48.647392+00', 'Nunspeet Strathspey, The', 1582, '');
INSERT INTO 'tune' VALUES (8904, '2003-04-21 22:00:00+00', '2012-01-20 12:54:48.650315+00', 'Auld Music Maister, The', 1635, '');
INSERT INTO 'tune' VALUES (8905, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.65324+00', 'Reel For Anita, A', 1582, '');
INSERT INTO 'tune' VALUES (8799, NULL, '2023-02-28 14:51:33.05752+00', 'Sleeping Warrior, The', 1575, '');
INSERT INTO 'tune' VALUES (8906, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.656164+00', 'Mrs Helen Frame', 1582, '');
INSERT INTO 'tune' VALUES (8907, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.659596+00', 'Burnell 2000', 1582, '');
INSERT INTO 'tune' VALUES (8908, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.662587+00', 'Kennedy Gardens', 1582, '');
INSERT INTO 'tune' VALUES (8909, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.665926+00', 'Matthew''s Reel', 1582, '');
INSERT INTO 'tune' VALUES (8910, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.669062+00', 'Crosbie Reel, The', 1582, '');
INSERT INTO 'tune' VALUES (8911, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.672296+00', 'Jenny Green', 1582, '');
INSERT INTO 'tune' VALUES (8912, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.675609+00', 'Tribute to Mrs Christine Mair, A', 1582, '');
INSERT INTO 'tune' VALUES (8913, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.678791+00', 'Eileen Williams Reel', 1582, '');
INSERT INTO 'tune' VALUES (8914, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.681963+00', 'Malcolm''s Birthday Reel', 1582, '');
INSERT INTO 'tune' VALUES (8915, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.685136+00', 'Hoversta Reel', 1582, '');
INSERT INTO 'tune' VALUES (8916, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.688446+00', 'Bob & Ann Smith', 1582, '');
INSERT INTO 'tune' VALUES (8917, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.691754+00', 'Bourtree, The', 1582, '');
INSERT INTO 'tune' VALUES (8918, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.695013+00', 'Christine Cummins Reel', 1582, '');
INSERT INTO 'tune' VALUES (8919, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.698146+00', 'Mick & Susan Madigan', 1582, '');
INSERT INTO 'tune' VALUES (8920, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.701302+00', 'AGM Capers', 1582, '');
INSERT INTO 'tune' VALUES (8921, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.704426+00', 'Miss Amy Geddes', 1582, '');
INSERT INTO 'tune' VALUES (8922, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.707918+00', 'Old Rock, Da', 1582, '');
INSERT INTO 'tune' VALUES (8923, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.711616+00', 'Hertstane, Da', 1582, '');
INSERT INTO 'tune' VALUES (8924, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.715192+00', 'Susan Ayland''s Reel', 1582, '');
INSERT INTO 'tune' VALUES (8925, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.718692+00', 'MaryEllen''s reel', 1582, '');
INSERT INTO 'tune' VALUES (8926, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.722214+00', 'Shelagh Dempsey', 1582, '');
INSERT INTO 'tune' VALUES (8927, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.725705+00', 'Joyce''s Parallel Sideshuffle', 1582, '');
INSERT INTO 'tune' VALUES (8928, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.729458+00', 'Scraping of Shovels, The', 1582, '');
INSERT INTO 'tune' VALUES (8929, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.733031+00', 'Golden Wedding Tribute, A', 1582, '');
INSERT INTO 'tune' VALUES (8930, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.736513+00', 'Elspeth Gray', 1582, '');
INSERT INTO 'tune' VALUES (8931, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.739988+00', 'Browns of York, The', 1582, '');
INSERT INTO 'tune' VALUES (8932, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.74343+00', 'Kerrow Drive', 1582, '');
INSERT INTO 'tune' VALUES (8933, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.747082+00', 'Lyndsey Brown', 1582, '');
INSERT INTO 'tune' VALUES (8934, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.750615+00', 'Christina France', 1582, '');
INSERT INTO 'tune' VALUES (8935, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.754138+00', 'Pat''s Tribute to Duncan Brown', 1582, '');
INSERT INTO 'tune' VALUES (8936, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.757649+00', 'Else Hartzberg', 1582, '');
INSERT INTO 'tune' VALUES (8937, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.761167+00', 'Mr Arnold Grime', 1582, '');
INSERT INTO 'tune' VALUES (8938, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.764688+00', 'September in Seattle', 1582, '');
INSERT INTO 'tune' VALUES (8939, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.768146+00', 'Lugging the Lamp', 1582, '');
INSERT INTO 'tune' VALUES (8940, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.7711+00', 'Stephen G Dorey', 1582, '');
INSERT INTO 'tune' VALUES (8941, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.774011+00', 'Flight to Foula', 1582, '');
INSERT INTO 'tune' VALUES (8942, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.776932+00', 'Mr & Mrs Bruce Frazer', 1582, '');
INSERT INTO 'tune' VALUES (8943, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.779849+00', 'All for Wendy', 1582, '');
INSERT INTO 'tune' VALUES (8944, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.782764+00', 'Rockfield Jig', 1582, '');
INSERT INTO 'tune' VALUES (8945, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.78568+00', 'Barbara & Robert McOwen', 1582, '');
INSERT INTO 'tune' VALUES (8946, '2003-10-30 23:00:00+00', '2012-01-20 12:54:48.788598+00', 'Party Tent, The', 1445, '');
INSERT INTO 'tune' VALUES (8947, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.791519+00', 'Kerrowside', 1582, '');
INSERT INTO 'tune' VALUES (8949, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.797343+00', 'Debbie Lees', 1582, '');
INSERT INTO 'tune' VALUES (8950, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.800267+00', 'Eileen & June at HQ', 1582, '');
INSERT INTO 'tune' VALUES (8951, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.803175+00', 'New Fledgling, The', 1582, '');
INSERT INTO 'tune' VALUES (9051, NULL, '2019-01-21 23:45:24.120943+00', 'Miss Nicola Jack', 3359, '');
INSERT INTO 'tune' VALUES (8953, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.809028+00', 'South Street', 1582, '');
INSERT INTO 'tune' VALUES (8954, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.811944+00', 'Mr Ray Bennett', 1582, '');
INSERT INTO 'tune' VALUES (8955, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.814861+00', 'Carbery Strathspey, The', 1582, '');
INSERT INTO 'tune' VALUES (8956, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.817778+00', 'Summer 1999', 1582, '');
INSERT INTO 'tune' VALUES (8957, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.820913+00', 'Wallace Strathspey, The', 1582, '');
INSERT INTO 'tune' VALUES (8958, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.823868+00', 'For Alex and Kate', 1582, '');
INSERT INTO 'tune' VALUES (8959, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.826817+00', 'Rona''s Celebration', 1582, '');
INSERT INTO 'tune' VALUES (8960, '2003-10-30 23:00:00+00', '2012-01-20 12:54:48.829737+00', 'Eppelwoi', 1445, '');
INSERT INTO 'tune' VALUES (8961, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.832659+00', 'Miss Jean Sim', 1582, '');
INSERT INTO 'tune' VALUES (8962, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.835593+00', 'Pat''s Tribute to Roy & Tim Willingale', 1582, '');
INSERT INTO 'tune' VALUES (8963, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.838516+00', 'Little Flugga Polka', 1582, '');
INSERT INTO 'tune' VALUES (8964, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.841435+00', 'Healy''s Polka, The', 1582, '');
INSERT INTO 'tune' VALUES (8965, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.844386+00', 'Sound Reflection', 1582, '');
INSERT INTO 'tune' VALUES (8966, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.847313+00', 'Andrew''s Warm-up', 1582, '');
INSERT INTO 'tune' VALUES (8967, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.850237+00', 'Crowcombe and Stogumber', 2977, '');
INSERT INTO 'tune' VALUES (8968, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.853151+00', 'Avril Quarrie', 389, '');
INSERT INTO 'tune' VALUES (8969, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.85612+00', 'Gramercy Park Reel', 3341, '');
INSERT INTO 'tune' VALUES (8970, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.85914+00', 'Balra Strathspey', 3341, '');
INSERT INTO 'tune' VALUES (8971, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.862062+00', 'With a Bow and Curtsey', 3341, '');
INSERT INTO 'tune' VALUES (8972, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.864989+00', 'Inukshuk', 401, '');
INSERT INTO 'tune' VALUES (8973, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.868155+00', 'My Left Thumb', 401, '');
INSERT INTO 'tune' VALUES (8974, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.872443+00', 'Miss Jane Muirhead of Dunsmuir', 401, '');
INSERT INTO 'tune' VALUES (8975, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.876024+00', 'Sunday Afternoon Jig', 3341, '');
INSERT INTO 'tune' VALUES (8976, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.879177+00', 'Sylvan Strathspey, The', 389, '');
INSERT INTO 'tune' VALUES (8977, '2003-05-04 22:00:00+00', '2012-01-20 12:54:48.882208+00', 'Sweet John''s Waltz', 3341, '');
INSERT INTO 'tune' VALUES (8978, '2003-05-06 22:00:00+00', '2012-01-20 12:54:48.88519+00', 'Out of the Doldrums Again', 1582, '');
INSERT INTO 'tune' VALUES (8979, '2003-05-06 22:00:00+00', '2012-01-20 12:54:48.888183+00', 'Mrs Mary Murray', 1582, '');
INSERT INTO 'tune' VALUES (8980, '2003-05-06 22:00:00+00', '2012-01-20 12:54:48.89119+00', 'October Wedding', 1582, '');
INSERT INTO 'tune' VALUES (8981, '2003-05-06 22:00:00+00', '2012-01-20 12:54:48.89425+00', 'Pipers of Oban, The', 1582, '');
INSERT INTO 'tune' VALUES (8982, '2003-05-06 22:00:00+00', '2012-01-20 12:54:48.897264+00', 'Boundaries of Scotland, The', 1582, '');
INSERT INTO 'tune' VALUES (8983, '2003-05-06 22:00:00+00', '2012-01-20 12:54:48.900304+00', 'Medley for Marilyn, A', 1582, '');
INSERT INTO 'tune' VALUES (8984, '2003-05-10 22:00:00+00', '2012-01-20 12:54:48.903325+00', 'Flying Haggis, The', 1673, '');
INSERT INTO 'tune' VALUES (8985, '2003-05-10 22:00:00+00', '2012-01-20 12:54:48.906362+00', 'Beeswing Village', 3346, '');
INSERT INTO 'tune' VALUES (8986, '2003-05-10 22:00:00+00', '2012-01-20 12:54:48.909388+00', 'Thorncliffe', 1582, '');
INSERT INTO 'tune' VALUES (8987, '2003-05-14 22:00:00+00', '2012-01-20 12:54:48.914988+00', 'Elmwood Strathspey, The', 3348, '');
INSERT INTO 'tune' VALUES (8988, '2003-05-14 22:00:00+00', '2012-01-20 12:54:48.918125+00', 'Saint Bride''s Jig', 3348, '');
INSERT INTO 'tune' VALUES (8989, '2003-06-11 22:00:00+00', '2012-01-20 12:54:48.92114+00', 'Dance Then', 1582, '');
INSERT INTO 'tune' VALUES (8990, '2003-06-11 22:00:00+00', '2012-01-20 12:54:48.92419+00', 'Dorothy Miles', 1582, '10-bar phrases');
INSERT INTO 'tune' VALUES (8991, '2003-06-11 22:00:00+00', '2012-01-20 12:54:48.927391+00', 'Ivy''s Jig', 1582, '10-bar phrases');
INSERT INTO 'tune' VALUES (8992, '2003-06-11 22:00:00+00', '2012-01-20 12:54:48.930676+00', 'Janet Connell', 1582, '10-bar phrases');
INSERT INTO 'tune' VALUES (8993, '2003-06-11 22:00:00+00', '2012-01-20 12:54:48.9338+00', 'Keep Counting', 1582, '10-bar phrases');
INSERT INTO 'tune' VALUES (8994, '2003-06-11 22:00:00+00', '2012-01-20 12:54:48.936825+00', 'Ivy''s Reel', 1582, '');
INSERT INTO 'tune' VALUES (8995, '2003-06-11 22:00:00+00', '2012-01-20 12:54:48.939838+00', 'Ladies First', 1582, '');
INSERT INTO 'tune' VALUES (8996, '2003-06-11 22:00:00+00', '2012-01-20 12:54:48.942839+00', 'Ready To Move!', 1643, '');
INSERT INTO 'tune' VALUES (8997, '2003-06-16 22:00:00+00', '2012-01-20 12:54:48.945833+00', 'Alan Paterson of Berne', 1631, '');
INSERT INTO 'tune' VALUES (8998, '2003-06-26 22:00:00+00', '2012-01-20 12:54:48.950929+00', 'Scotland''s Golden Years', 1527, '');
INSERT INTO 'tune' VALUES (8999, '2003-06-26 22:00:00+00', '2012-01-20 12:54:48.953939+00', 'Lady Elizabeth Bowes-Lyon of Strathmore', 1527, '');
INSERT INTO 'tune' VALUES (9000, '2003-06-26 22:00:00+00', '2012-01-20 12:54:48.957019+00', 'Royal Leith Reel', 1527, '');
INSERT INTO 'tune' VALUES (9001, '2003-06-26 22:00:00+00', '2012-01-20 12:54:48.960138+00', 'Sir Hew Dalrymple Bart.', 9999, '');
INSERT INTO 'tune' VALUES (9002, '2003-06-26 22:00:00+00', '2012-01-20 12:54:48.963366+00', 'Quickstep', 9999, '');
INSERT INTO 'tune' VALUES (9003, '2003-06-26 22:00:00+00', '2012-01-20 12:54:48.96632+00', 'Lady Elizabeth''s Air', 2946, '');
INSERT INTO 'tune' VALUES (9004, '2003-06-26 22:00:00+00', '2012-01-20 12:54:48.979427+00', 'Farewell to Longannet', 3186, '');
INSERT INTO 'tune' VALUES (9005, '2003-06-26 22:00:00+00', '2012-01-20 12:54:48.982544+00', 'Dr James Hamilton''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (9006, '2003-06-26 22:00:00+00', '2012-01-20 12:54:48.985509+00', 'Den Burn, The', 3186, '');
INSERT INTO 'tune' VALUES (9007, '2003-06-26 22:00:00+00', '2012-01-20 12:54:48.988453+00', 'Middies Brae', 1804, '');
INSERT INTO 'tune' VALUES (9008, NULL, '2012-01-20 12:54:48.991378+00', 'Levantine''s Barrel', 9999, '');
INSERT INTO 'tune' VALUES (9009, NULL, '2012-01-20 12:54:48.994278+00', 'William Taylor''s Table Top Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (9011, NULL, '2012-01-20 12:54:49.000099+00', 'Weaver has a Daughter', 9998, '');
INSERT INTO 'tune' VALUES (9012, NULL, '2012-01-20 12:54:49.002997+00', 'Fort Worden Sunset', 2977, '');
INSERT INTO 'tune' VALUES (9013, NULL, '2012-01-20 12:54:49.005881+00', 'Denise''s Waltz', 2977, '');
INSERT INTO 'tune' VALUES (9014, NULL, '2012-01-20 12:54:49.008773+00', 'Hard is my Fate', 2142, '');
INSERT INTO 'tune' VALUES (9015, NULL, '2012-01-20 12:54:49.011671+00', 'Rob Donn Mackay the Poet', 3356, '');
INSERT INTO 'tune' VALUES (9016, NULL, '2012-01-20 12:54:49.01456+00', 'Cape North Jig', 9998, '');
INSERT INTO 'tune' VALUES (9017, NULL, '2012-01-20 12:54:49.017446+00', 'Miss Katie Hall''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (9018, NULL, '2012-01-20 12:54:49.020341+00', 'Rod''s Birthday', 1773, '');
INSERT INTO 'tune' VALUES (9019, NULL, '2012-01-20 12:54:49.023231+00', 'Mull Rant', 9998, '');
INSERT INTO 'tune' VALUES (9020, NULL, '2012-01-20 12:54:49.026146+00', 'They Stole My Wife from Me', 9998, '');
INSERT INTO 'tune' VALUES (9021, NULL, '2012-01-20 12:54:49.029036+00', 'Coire an Lachan', 9998, '');
INSERT INTO 'tune' VALUES (9022, NULL, '2012-01-20 12:54:49.031925+00', 'Bonnie at Morn', 9998, '');
INSERT INTO 'tune' VALUES (9023, '2003-10-30 23:00:00+00', '2012-01-20 12:54:49.034829+00', 'Tartan Dove, The', 1445, '');
INSERT INTO 'tune' VALUES (9024, '2003-07-06 22:00:00+00', '2012-01-20 12:54:49.037775+00', 'Blue and White Quilt, The', 1502, '');
INSERT INTO 'tune' VALUES (9025, '2003-07-06 22:00:00+00', '2012-01-20 12:54:49.040739+00', 'Miss Catherine Gray', 1501, '');
INSERT INTO 'tune' VALUES (9026, '2003-07-06 22:00:00+00', '2012-01-20 12:54:49.043664+00', 'Susan & Alan Carr', 1502, '');
INSERT INTO 'tune' VALUES (9027, '2003-07-06 22:00:00+00', '2012-01-20 12:54:49.046591+00', 'Evelyn''s Dance', 1596, '');
INSERT INTO 'tune' VALUES (9028, '2003-07-06 22:00:00+00', '2012-01-20 12:54:49.049505+00', 'Lochgilphead', 1506, '');
INSERT INTO 'tune' VALUES (9029, '2003-07-06 22:00:00+00', '2012-01-20 12:54:49.052425+00', 'Dick Cowen''s Favourite', 1593, '');
INSERT INTO 'tune' VALUES (9030, NULL, '2012-01-20 12:54:49.05534+00', 'Deirdre Ann', 1646, '');
INSERT INTO 'tune' VALUES (9031, NULL, '2012-01-20 12:54:49.058235+00', 'Hamish''s Farewell to Prospect Farm', 9998, '');
INSERT INTO 'tune' VALUES (9032, NULL, '2012-01-20 12:54:49.061191+00', 'Weary Willie''s Reel', 1578, '');
INSERT INTO 'tune' VALUES (9033, NULL, '2012-01-20 12:54:49.064082+00', 'Mary Mackenzie''s Delight', 9998, '');
INSERT INTO 'tune' VALUES (9034, NULL, '2012-01-20 12:54:49.066981+00', 'Cynicus', 9998, '');
INSERT INTO 'tune' VALUES (9035, NULL, '2012-01-20 12:54:49.069891+00', 'Cathie and Jim Lambie', 1634, '');
INSERT INTO 'tune' VALUES (9036, NULL, '2012-01-20 12:54:49.072807+00', 'Mill o'' Tiftie''s Annie, The', 9998, '');
INSERT INTO 'tune' VALUES (9037, NULL, '2012-01-20 12:54:49.075704+00', 'Upperhill', 9998, '');
INSERT INTO 'tune' VALUES (9038, NULL, '2012-01-20 12:54:49.078595+00', 'Lynne''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (9039, NULL, '2012-01-20 12:54:49.081486+00', 'Grace Morrison of Borve', 1634, '');
INSERT INTO 'tune' VALUES (9041, NULL, '2012-01-20 12:54:49.087596+00', 'T C''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (9042, NULL, '2012-01-20 12:54:49.090488+00', 'Rosemary Henry', 9998, '');
INSERT INTO 'tune' VALUES (9043, NULL, '2012-01-20 12:54:49.093373+00', 'Wellington Street', 1526, '');
INSERT INTO 'tune' VALUES (9044, NULL, '2012-01-20 12:54:49.096268+00', 'Mrs Ashworth''s Strathspey', 3359, '');
INSERT INTO 'tune' VALUES (9045, NULL, '2012-01-20 12:54:49.099163+00', 'One For Neve', 1793, '');
INSERT INTO 'tune' VALUES (9046, NULL, '2012-01-20 12:54:49.102047+00', 'Dunfermline Abbey', 1526, '');
INSERT INTO 'tune' VALUES (9047, NULL, '2012-01-20 12:54:49.104945+00', 'Daniel''s Reel', 3359, '');
INSERT INTO 'tune' VALUES (9048, NULL, '2012-01-20 12:54:49.107859+00', 'Shoogly Bridge, The', 3360, '');
INSERT INTO 'tune' VALUES (9049, NULL, '2012-01-20 12:54:49.110747+00', 'Robert Pithie', 3361, '');
INSERT INTO 'tune' VALUES (9050, NULL, '2012-01-20 12:54:49.113626+00', 'Ruth & George O''Connor''s Strathspey', 1793, '');
INSERT INTO 'tune' VALUES (9052, NULL, '2012-01-20 12:54:49.119739+00', 'Leicester Assembly, The', 2898, '');
INSERT INTO 'tune' VALUES (9053, NULL, '2012-01-20 12:54:49.12326+00', 'Bonnyrigg Chase, The', 3058, '');
INSERT INTO 'tune' VALUES (9054, NULL, '2012-01-20 12:54:49.126493+00', 'Shetland Bus, The', 1735, '');
INSERT INTO 'tune' VALUES (9055, NULL, '2012-01-20 12:54:49.130395+00', 'Silver Targe, The', 1793, '');
INSERT INTO 'tune' VALUES (9056, NULL, '2012-01-20 12:54:49.133558+00', 'Three J''s, The', 2898, '');
INSERT INTO 'tune' VALUES (9057, NULL, '2012-01-20 12:54:49.136476+00', 'Wee Highland Toes', 9998, '');
INSERT INTO 'tune' VALUES (9058, NULL, '2012-01-20 12:54:49.139378+00', 'David Cunningham''s Compliments to Graham Berry', 1793, '');
INSERT INTO 'tune' VALUES (9059, NULL, '2012-01-20 12:54:49.142284+00', 'Margaret''s Fancy', 1554, '');
INSERT INTO 'tune' VALUES (9060, NULL, '2012-01-20 12:54:49.145174+00', 'Minstrel Boy, The', 3363, '');
INSERT INTO 'tune' VALUES (9061, '2005-02-01 23:00:00+00', '2012-01-20 12:54:49.14815+00', 'Jinglebells Country Dance, The', 3187, '');
INSERT INTO 'tune' VALUES (9062, NULL, '2012-01-20 12:54:49.1511+00', 'Lothian Lasses', 9998, '');
INSERT INTO 'tune' VALUES (9063, NULL, '2012-01-20 12:54:49.153993+00', 'Loch Earn', 1518, '');
INSERT INTO 'tune' VALUES (9064, NULL, '2012-01-20 12:54:49.1569+00', 'Caillach Liath Rasar', 9998, '');
INSERT INTO 'tune' VALUES (9065, NULL, '2012-01-20 12:54:49.159836+00', 'Nuptial Knot, The', 2142, '');
INSERT INTO 'tune' VALUES (9066, NULL, '2012-01-20 12:54:49.162742+00', 'Source of Spey', 9998, '');
INSERT INTO 'tune' VALUES (9067, NULL, '2012-01-20 12:54:49.165632+00', 'Marchioness of Cornwallis, The', 1516, '');
INSERT INTO 'tune' VALUES (9068, NULL, '2012-01-20 12:54:49.168529+00', 'Peter Grey', 1512, '');
INSERT INTO 'tune' VALUES (9069, NULL, '2012-01-20 12:54:49.171431+00', 'Sandy Grant', 1512, '');
INSERT INTO 'tune' VALUES (9070, NULL, '2012-01-20 12:54:49.174334+00', 'Miss Admiral Gordon', 1516, '');
INSERT INTO 'tune' VALUES (9071, NULL, '2012-01-20 12:54:49.177231+00', 'Niel Gow''s Lament for his Second Wife', 9998, '');
INSERT INTO 'tune' VALUES (9072, '2003-10-30 23:00:00+00', '2012-01-20 12:54:49.180147+00', 'RR 19', 1445, '');
INSERT INTO 'tune' VALUES (9073, '2003-10-30 23:00:00+00', '2012-01-20 12:54:49.183068+00', 'Brunswick Hussars, The', 1445, '');
INSERT INTO 'tune' VALUES (9074, '2003-10-30 23:00:00+00', '2012-01-20 12:54:49.185981+00', 'Houseboat, The', 1445, '');
INSERT INTO 'tune' VALUES (9075, '2003-10-30 23:00:00+00', '2012-01-20 12:54:49.188909+00', 'Verl Girl, The', 1445, '');
INSERT INTO 'tune' VALUES (9076, '2003-10-30 23:00:00+00', '2012-01-20 12:54:49.191825+00', 'Railwayman, The', 1445, '');
INSERT INTO 'tune' VALUES (9077, '2003-10-30 23:00:00+00', '2012-01-20 12:54:49.194747+00', 'Gent Strathspey', 1445, '');
INSERT INTO 'tune' VALUES (9078, '2003-10-30 23:00:00+00', '2012-01-20 12:54:49.197661+00', 'Kikikasa Jig, The', 1445, '');
INSERT INTO 'tune' VALUES (9079, '2003-10-30 23:00:00+00', '2012-01-20 12:54:49.200586+00', 'Whenever the Ten Shall Meet', 1445, '');
INSERT INTO 'tune' VALUES (9080, '2003-10-30 23:00:00+00', '2012-01-20 12:54:49.203509+00', 'River Blackwater, The', 1445, '');
INSERT INTO 'tune' VALUES (9081, '2003-10-31 23:00:00+00', '2012-01-20 12:54:49.206425+00', 'Ross Meor', 9998, '');
INSERT INTO 'tune' VALUES (9082, '2003-11-10 23:00:00+00', '2012-01-20 12:54:49.209664+00', 'Anst''er Ludgin'', The', 3396, '');
INSERT INTO 'tune' VALUES (9083, '2003-11-10 23:00:00+00', '2012-01-20 12:54:49.212655+00', 'Chalmers Hall', 3397, '');
INSERT INTO 'tune' VALUES (9084, '2003-11-11 23:00:00+00', '2012-01-20 12:54:49.21559+00', 'Double ''H'' Jig', 3398, '');
INSERT INTO 'tune' VALUES (9085, '2003-11-11 23:00:00+00', '2012-01-20 12:54:49.218516+00', 'Robert Atkinson''s Reel', 2667, '');
INSERT INTO 'tune' VALUES (9086, '2003-11-11 23:00:00+00', '2012-01-20 12:54:49.221431+00', 'Freddie Atkinson''s Reel', 2667, '');
INSERT INTO 'tune' VALUES (9087, '2003-11-11 23:00:00+00', '2012-01-20 12:54:49.224353+00', 'Walking the Dog', 1508, '');
INSERT INTO 'tune' VALUES (9088, '2003-11-11 23:00:00+00', '2012-01-20 12:54:49.227277+00', 'Peters Reel', 1643, '');
INSERT INTO 'tune' VALUES (9089, '2003-11-11 23:00:00+00', '2012-01-20 12:54:49.230212+00', 'Harbour City Reel', 1643, '');
INSERT INTO 'tune' VALUES (9090, '2003-11-11 23:00:00+00', '2012-01-20 12:54:49.233138+00', 'Meg Ryan', 3397, '');
INSERT INTO 'tune' VALUES (9091, '2003-11-11 23:00:00+00', '2012-01-20 12:54:49.236056+00', 'Round the Cross', 3397, '');
INSERT INTO 'tune' VALUES (9092, '2003-11-11 23:00:00+00', '2012-01-20 12:54:49.238981+00', 'Up the Kirkgate', 3397, '');
INSERT INTO 'tune' VALUES (9093, '2003-11-11 23:00:00+00', '2012-01-20 12:54:49.241899+00', 'Black Bitch, The', 3397, '');
INSERT INTO 'tune' VALUES (9094, '2003-11-11 23:00:00+00', '2012-01-20 12:54:49.244818+00', 'Autumn Days', 3398, '');
INSERT INTO 'tune' VALUES (9095, '2003-11-11 23:00:00+00', '2012-01-20 12:54:49.247744+00', 'Uisge Beathe', 3398, '');
INSERT INTO 'tune' VALUES (9096, '2003-11-11 23:00:00+00', '2012-01-20 12:54:49.250721+00', 'Diggens Boys', 3396, '');
INSERT INTO 'tune' VALUES (9098, NULL, '2012-01-20 12:54:49.256526+00', 'Jim Lindsay''s Jig', 3154, '');
INSERT INTO 'tune' VALUES (9100, NULL, '2012-01-20 12:54:49.262323+00', 'Auld Meal Mill, The', 9999, '');
INSERT INTO 'tune' VALUES (9101, NULL, '2012-01-20 12:54:49.265228+00', 'Stuart McHardy of Milngavie', 1743, '');
INSERT INTO 'tune' VALUES (9102, NULL, '2012-01-20 12:54:49.268144+00', 'Wilson ''s Lightshaw Glen', 1603, '');
INSERT INTO 'tune' VALUES (9103, NULL, '2012-01-20 12:54:49.271061+00', 'By Logan''s Streams', 9999, '');
INSERT INTO 'tune' VALUES (9104, NULL, '2012-01-20 12:54:49.273954+00', 'James Grant Thomson', 1603, '');
INSERT INTO 'tune' VALUES (9105, NULL, '2012-01-20 12:54:49.276852+00', 'Alasdair Peter Thomson', 1603, '');
INSERT INTO 'tune' VALUES (9106, NULL, '2012-01-20 12:54:49.279739+00', 'Tibbie''s Brig', 1603, '');
INSERT INTO 'tune' VALUES (9107, NULL, '2012-01-20 12:54:49.282633+00', 'Duke of Rothesay, The', 1527, '');
INSERT INTO 'tune' VALUES (9108, NULL, '2012-01-20 12:54:49.285526+00', 'HRH the Princess Royal', 1527, '');
INSERT INTO 'tune' VALUES (9109, NULL, '2012-01-20 12:54:49.288446+00', 'Royal Edinburgh, The', 1527, '');
INSERT INTO 'tune' VALUES (9110, NULL, '2012-01-20 12:54:49.291373+00', 'Mary MacPhail of Dailachairn', 1527, '');
INSERT INTO 'tune' VALUES (9111, NULL, '2012-01-20 12:54:49.294279+00', 'Miss Rosemary Gordon-Harvey', 1527, '');
INSERT INTO 'tune' VALUES (9112, NULL, '2012-01-20 12:54:49.297174+00', 'Miss Murray of Dail Bhreagha', 1527, '');
INSERT INTO 'tune' VALUES (9114, NULL, '2012-01-20 12:54:49.302973+00', 'Miss Claire Boulton', 1527, '');
INSERT INTO 'tune' VALUES (9115, NULL, '2012-01-20 12:54:49.305854+00', 'Anna Viola Robertson', 1527, '');
INSERT INTO 'tune' VALUES (9116, NULL, '2012-01-20 12:54:49.30875+00', 'Thomas Mansfield Robertson', 1527, '');
INSERT INTO 'tune' VALUES (9117, NULL, '2012-01-20 12:54:49.311644+00', 'Donald Todd - of Leith', 1527, '');
INSERT INTO 'tune' VALUES (9118, NULL, '2012-01-20 12:54:49.31453+00', 'James Leask - of Lerwick', 1527, '');
INSERT INTO 'tune' VALUES (9120, NULL, '2012-01-20 12:54:49.320313+00', 'Slumbering Minstrel, The', 9999, '');
INSERT INTO 'tune' VALUES (9121, NULL, '2012-01-20 12:54:49.323195+00', 'Snowy Breasted Pearl, The', 3401, '');
INSERT INTO 'tune' VALUES (9122, NULL, '2012-01-20 12:54:49.326082+00', 'Harp That Once through Tara''s Halls, The', 9999, '');
INSERT INTO 'tune' VALUES (9123, NULL, '2012-01-20 12:54:49.329196+00', 'Maureen Rutherford''s Reel', 1527, '');
INSERT INTO 'tune' VALUES (9124, NULL, '2012-01-20 12:54:49.33222+00', 'Peter MacFarlane''s Reel', 1527, '');
INSERT INTO 'tune' VALUES (9125, NULL, '2012-01-20 12:54:49.335131+00', 'Maude MacFarlane''s Reel', 1527, '');
INSERT INTO 'tune' VALUES (9127, NULL, '2012-01-20 12:54:49.340911+00', 'Miss Irene Scott''s Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (9128, NULL, '2012-01-20 12:54:49.343805+00', 'Iain MacPhail''s Compliments to John and Sheila Tanner', 1527, '');
INSERT INTO 'tune' VALUES (9129, NULL, '2012-01-20 12:54:49.346695+00', 'Veila Tait - of Lerwick', 1527, '');
INSERT INTO 'tune' VALUES (9130, NULL, '2012-01-20 12:54:49.349598+00', 'Iain MacPhail''s Compliments to Grant and Wilma Hardie', 1527, '');
INSERT INTO 'tune' VALUES (9131, NULL, '2012-01-20 12:54:49.352511+00', 'Black Hoe, The', 9999, '');
INSERT INTO 'tune' VALUES (9132, NULL, '2012-01-20 12:54:49.355406+00', 'Mrs Joey Porter''s Jig - of Tarbert', 1527, '');
INSERT INTO 'tune' VALUES (9133, NULL, '2012-01-20 12:54:49.358296+00', 'Lily MacPhail''s Frolic', 1527, '');
INSERT INTO 'tune' VALUES (9134, NULL, '2012-01-20 12:54:49.361175+00', 'Miss Marion Campbell, Kilberry Castle', 1527, '');
INSERT INTO 'tune' VALUES (9135, NULL, '2012-01-20 12:54:49.364071+00', 'Chamberlain, The', 9998, '');
INSERT INTO 'tune' VALUES (9136, NULL, '2012-01-20 12:54:49.366966+00', 'Fyrefly', 2961, '');
INSERT INTO 'tune' VALUES (9137, NULL, '2012-01-20 12:54:49.369856+00', 'Wee Dram, A', 2961, '');
INSERT INTO 'tune' VALUES (9138, '2003-11-23 23:00:00+00', '2012-01-20 12:54:49.372763+00', 'Deby''s Tune', 2961, '');
INSERT INTO 'tune' VALUES (9139, '2003-11-23 23:00:00+00', '2012-01-20 12:54:49.376485+00', 'Distant Shores of Eire', 2961, '');
INSERT INTO 'tune' VALUES (9140, '2003-11-23 23:00:00+00', '2012-01-20 12:54:49.379444+00', 'Rose By Any Other, A', 2961, '');
INSERT INTO 'tune' VALUES (9141, '2003-11-23 23:00:00+00', '2012-01-20 12:54:49.382382+00', 'Willow', 2961, '');
INSERT INTO 'tune' VALUES (9142, '2003-11-23 23:00:00+00', '2012-01-20 12:54:49.385302+00', 'Piper Tigger', 2961, '');
INSERT INTO 'tune' VALUES (9143, '2003-11-23 23:00:00+00', '2012-01-20 12:54:49.388238+00', 'Bonnie Green Tunic', 2961, '');
INSERT INTO 'tune' VALUES (9144, '2003-11-23 23:00:00+00', '2012-01-20 12:54:49.399035+00', 'In a Pinch', 2961, '');
INSERT INTO 'tune' VALUES (9145, '2003-11-23 23:00:00+00', '2012-01-20 12:54:49.402962+00', 'Dragon''s Tale', 2961, '');
INSERT INTO 'tune' VALUES (9146, '2003-11-23 23:00:00+00', '2012-01-20 12:54:49.406829+00', 'Silence of the Selkie', 2961, '');
INSERT INTO 'tune' VALUES (9147, NULL, '2012-01-20 12:54:49.410903+00', 'Primrose Lasses', 9999, '');
INSERT INTO 'tune' VALUES (9148, NULL, '2012-01-20 12:54:49.414796+00', 'Stanford Class Strathspey, The', 2395, '');
INSERT INTO 'tune' VALUES (9149, NULL, '2012-01-20 12:54:49.419679+00', 'Pear Tree, The', 9998, '');
INSERT INTO 'tune' VALUES (9150, NULL, '2012-01-20 12:54:49.423525+00', 'High Level Bridge', 9998, '');
INSERT INTO 'tune' VALUES (9151, NULL, '2012-01-20 12:54:49.42747+00', 'Cape Breton', 9998, '');
INSERT INTO 'tune' VALUES (9152, NULL, '2012-01-20 12:54:49.431299+00', 'Favorite Castletone Connors', 9998, '');
INSERT INTO 'tune' VALUES (9153, '2003-11-23 23:00:00+00', '2012-01-20 12:54:49.43514+00', 'DBG', 2961, '');
INSERT INTO 'tune' VALUES (9154, NULL, '2012-01-20 12:54:49.439136+00', 'George Abercrombe', 9998, '');
INSERT INTO 'tune' VALUES (9155, NULL, '2012-01-20 12:54:49.443134+00', 'Mr George Morrison', 9998, '');
INSERT INTO 'tune' VALUES (9156, NULL, '2012-01-20 12:54:49.446958+00', 'Willow Tears', 2961, '');
INSERT INTO 'tune' VALUES (9267, NULL, '2012-01-20 12:54:49.811507+00', 'Roy Goldring', 1502, '');
INSERT INTO 'tune' VALUES (9157, '2003-12-02 23:00:00+00', '2012-01-20 12:54:49.450988+00', 'Auld Koofie', 3405, '');
INSERT INTO 'tune' VALUES (9159, '2003-12-02 23:00:00+00', '2012-01-20 12:54:49.458955+00', 'Canmore Reel', 1578, '');
INSERT INTO 'tune' VALUES (9160, '2003-12-02 23:00:00+00', '2012-01-20 12:54:49.462806+00', 'Fiona''s Jig', 1657, '');
INSERT INTO 'tune' VALUES (9161, '2003-12-02 23:00:00+00', '2012-01-20 12:54:49.466644+00', 'John Connon of Dufftown', 2856, '');
INSERT INTO 'tune' VALUES (9162, '2003-12-08 23:00:00+00', '2012-01-20 12:54:49.470474+00', 'Callum''s Road', 1769, '');
INSERT INTO 'tune' VALUES (9163, '2003-12-08 23:00:00+00', '2012-01-20 12:54:49.474306+00', 'Mrs Norah Dunn''s Jig', 645, '');
INSERT INTO 'tune' VALUES (9164, NULL, '2012-01-20 12:54:49.478231+00', 'Tide Comes In, The', 1625, '');
INSERT INTO 'tune' VALUES (9165, NULL, '2012-01-20 12:54:49.482036+00', 'Major James Munro', 1519, '');
INSERT INTO 'tune' VALUES (9166, NULL, '2012-01-20 12:54:49.485854+00', 'Keep it Up', 9999, '');
INSERT INTO 'tune' VALUES (9168, NULL, '2012-01-20 12:54:49.493588+00', 'In Memoriam Mary Kay', 2977, '');
INSERT INTO 'tune' VALUES (9169, NULL, '2012-01-20 12:54:49.497536+00', 'Fermoy Lasses', 9999, '');
INSERT INTO 'tune' VALUES (9172, NULL, '2012-01-20 12:54:49.508967+00', 'Larach Alasdair', 9999, '');
INSERT INTO 'tune' VALUES (9173, NULL, '2012-01-20 12:54:49.512795+00', 'Cold Quarry Jig', 2977, '');
INSERT INTO 'tune' VALUES (9174, NULL, '2012-01-20 12:54:49.516601+00', 'Daybreak', 2977, '');
INSERT INTO 'tune' VALUES (9175, NULL, '2012-01-20 12:54:49.520496+00', 'Bonnie Ann', 1635, '');
INSERT INTO 'tune' VALUES (9176, NULL, '2012-01-20 12:54:49.524306+00', 'Homes of Donegal', 9999, '');
INSERT INTO 'tune' VALUES (9177, NULL, '2012-01-20 12:54:49.528142+00', 'Dr James Donaldson', 1623, '');
INSERT INTO 'tune' VALUES (9178, NULL, '2012-01-20 12:54:49.53248+00', 'Wee Man from Skye, The', 1564, '');
INSERT INTO 'tune' VALUES (9179, NULL, '2012-01-20 12:54:49.536429+00', 'Finlay MacRae', 1761, '');
INSERT INTO 'tune' VALUES (9180, NULL, '2012-01-20 12:54:49.540394+00', 'Duncan Johnstone', 1564, '');
INSERT INTO 'tune' VALUES (9181, NULL, '2012-01-20 12:54:49.544204+00', 'Miss Marie Fielding', 1501, '');
INSERT INTO 'tune' VALUES (9182, NULL, '2012-01-20 12:54:49.548018+00', 'Miss Audrey McKenzie', 1507, '');
INSERT INTO 'tune' VALUES (9183, NULL, '2012-01-20 12:54:49.551892+00', 'Two Mile Bridge, The', 9999, '');
INSERT INTO 'tune' VALUES (9184, NULL, '2012-01-20 12:54:49.555696+00', 'Man who Broke the Bank at Monte Carlo, The', 3404, '');
INSERT INTO 'tune' VALUES (9185, NULL, '2012-01-20 12:54:49.559678+00', 'Mademoiselle from Armentieres', 3407, '');
INSERT INTO 'tune' VALUES (9186, NULL, '2012-01-20 12:54:49.563681+00', 'Who''s Your Lady Friend?', 3408, '');
INSERT INTO 'tune' VALUES (9167, NULL, '2012-04-03 20:37:51.249617+00', 'Beneath the Willow', 2977, 'composed 2000');
INSERT INTO 'tune' VALUES (9188, NULL, '2012-01-20 12:54:49.5715+00', 'Maid of the House, The', 9999, '');
INSERT INTO 'tune' VALUES (9189, NULL, '2012-01-20 12:54:49.575319+00', 'Dinny o''Brien''s', 9999, '');
INSERT INTO 'tune' VALUES (9190, NULL, '2012-01-20 12:54:49.579201+00', 'Temple Hill', 9999, '');
INSERT INTO 'tune' VALUES (9191, NULL, '2012-01-20 12:54:49.583026+00', 'Marchioness of Tullibardine', 1928, '');
INSERT INTO 'tune' VALUES (9192, NULL, '2012-01-20 12:54:49.586844+00', 'Donald MacLellan of Rothesay', 1564, '');
INSERT INTO 'tune' VALUES (9193, NULL, '2012-01-20 12:54:49.590916+00', 'Mermaid, The', 9999, '');
INSERT INTO 'tune' VALUES (9194, NULL, '2012-01-20 12:54:49.594737+00', 'Fair Haired One, The', 9999, '');
INSERT INTO 'tune' VALUES (9195, NULL, '2012-01-20 12:54:49.598623+00', 'Marie MacLean''s Reel', 1766, '');
INSERT INTO 'tune' VALUES (9196, NULL, '2012-01-20 12:54:49.602454+00', 'Glen Trool', 1668, '');
INSERT INTO 'tune' VALUES (9197, NULL, '2012-01-20 12:54:49.606581+00', 'Joan Macfarlane''s', 3419, '');
INSERT INTO 'tune' VALUES (9198, NULL, '2012-01-20 12:54:49.609791+00', 'Jack Macfarlane''s', 3419, '');
INSERT INTO 'tune' VALUES (9199, NULL, '2012-01-20 12:54:49.612708+00', 'Paul Plummer', 1713, '');
INSERT INTO 'tune' VALUES (9200, NULL, '2012-01-20 12:54:49.615645+00', 'Lost Keys, The', 3419, '');
INSERT INTO 'tune' VALUES (9201, NULL, '2012-01-20 12:54:49.618539+00', 'Alistair Aitkenhead', 1713, '');
INSERT INTO 'tune' VALUES (9202, NULL, '2012-01-20 12:54:49.621421+00', 'Philippe Rousseau', 1713, '');
INSERT INTO 'tune' VALUES (9203, NULL, '2012-01-20 12:54:49.624309+00', 'Eugene Burden', 1713, '');
INSERT INTO 'tune' VALUES (9204, NULL, '2012-01-20 12:54:49.627196+00', 'Folwells, The', 1713, '');
INSERT INTO 'tune' VALUES (9205, NULL, '2012-01-20 12:54:49.630072+00', 'Clan Farquharson', 1713, '');
INSERT INTO 'tune' VALUES (9206, NULL, '2012-01-20 12:54:49.632964+00', 'Castle Campbell', 1713, '');
INSERT INTO 'tune' VALUES (9207, NULL, '2012-01-20 12:54:49.635847+00', 'Sandy Nixon', 1713, '');
INSERT INTO 'tune' VALUES (9208, NULL, '2012-01-20 12:54:49.638739+00', 'Dripping Hat, The', 3419, '');
INSERT INTO 'tune' VALUES (9209, NULL, '2012-01-20 12:54:49.641624+00', 'Atoll Lowlanders, The', 3419, '');
INSERT INTO 'tune' VALUES (9210, NULL, '2012-01-20 12:54:49.64452+00', 'Malcolm''s Strathspey', 1713, '');
INSERT INTO 'tune' VALUES (9211, NULL, '2012-01-20 12:54:49.647405+00', 'Jim & Jessie''s Golden Wedding', 1713, '');
INSERT INTO 'tune' VALUES (9212, NULL, '2012-01-20 12:54:49.650293+00', 'Jim''s Pipes', 1713, '');
INSERT INTO 'tune' VALUES (9213, NULL, '2012-01-20 12:54:49.653172+00', 'Frosty Window, The', 3419, '');
INSERT INTO 'tune' VALUES (9214, NULL, '2012-01-20 12:54:49.656053+00', 'Clogs in the Snow', 3419, '');
INSERT INTO 'tune' VALUES (9215, NULL, '2012-01-20 12:54:49.659439+00', 'Braes o'' Nose', 3419, '');
INSERT INTO 'tune' VALUES (9216, NULL, '2012-01-20 12:54:49.662409+00', 'Whiteleaf Cross', 3419, '');
INSERT INTO 'tune' VALUES (9217, NULL, '2012-01-20 12:54:49.665292+00', 'Magic Waltz', 3419, '');
INSERT INTO 'tune' VALUES (9218, NULL, '2012-01-20 12:54:49.668183+00', 'Tobin''s Halibut', 3419, '');
INSERT INTO 'tune' VALUES (9219, NULL, '2012-01-20 12:54:49.671096+00', 'June''s Reel', 1713, '');
INSERT INTO 'tune' VALUES (9220, NULL, '2012-01-20 12:54:49.673997+00', 'North Country', 3419, '');
INSERT INTO 'tune' VALUES (9221, NULL, '2012-01-20 12:54:49.676883+00', 'Trip to Castine', 3419, '');
INSERT INTO 'tune' VALUES (9222, NULL, '2012-01-20 12:54:49.679768+00', 'Black Summer Rain', 3419, '');
INSERT INTO 'tune' VALUES (9223, NULL, '2012-01-20 12:54:49.682658+00', 'Penobscot Bay Jig', 3419, '');
INSERT INTO 'tune' VALUES (9224, NULL, '2012-01-20 12:54:49.685547+00', 'Dawn''s Lullaby', 1713, '');
INSERT INTO 'tune' VALUES (9158, '2003-12-02 23:00:00+00', '2022-12-21 22:21:31.953494+00', 'Inchmacoble', 1578, '');
INSERT INTO 'tune' VALUES (9119, NULL, '2023-01-30 18:08:42.617137+00', 'Katie Shaw''s Reel', 1527, '');
INSERT INTO 'tune' VALUES (9225, NULL, '2012-01-20 12:54:49.688436+00', 'Chiltern Sunrise', 3419, '');
INSERT INTO 'tune' VALUES (9226, NULL, '2012-01-20 12:54:49.691317+00', 'Gaerse Dun', 3419, '');
INSERT INTO 'tune' VALUES (9227, NULL, '2012-01-20 12:54:49.694198+00', 'Bruce Frazer', 1713, '');
INSERT INTO 'tune' VALUES (9228, NULL, '2012-01-20 12:54:49.697083+00', 'Half Pint Polka', 3419, '');
INSERT INTO 'tune' VALUES (9229, NULL, '2012-01-20 12:54:49.699968+00', 'Tracy Orwin', 3419, '');
INSERT INTO 'tune' VALUES (9230, NULL, '2012-01-20 12:54:49.702858+00', 'Phil Rydin', 3419, '');
INSERT INTO 'tune' VALUES (9231, NULL, '2012-01-20 12:54:49.705775+00', 'Peter Macfarlane', 1713, '');
INSERT INTO 'tune' VALUES (9232, NULL, '2012-01-20 12:54:49.708667+00', 'Karl''s Jig', 1713, '');
INSERT INTO 'tune' VALUES (9233, NULL, '2012-01-20 12:54:49.711552+00', 'Calm Before the Storm', 3419, '');
INSERT INTO 'tune' VALUES (9234, NULL, '2012-01-20 12:54:49.714435+00', 'Miss Sharon Miller', 3419, '');
INSERT INTO 'tune' VALUES (9235, NULL, '2012-01-20 12:54:49.717314+00', 'Dave''s Hooley', 3419, '');
INSERT INTO 'tune' VALUES (9236, NULL, '2012-01-20 12:54:49.720202+00', 'Beauchamp Reel', 3419, '');
INSERT INTO 'tune' VALUES (9237, NULL, '2012-01-20 12:54:49.723172+00', 'Malcolm''s Delight', 3419, '');
INSERT INTO 'tune' VALUES (9238, NULL, '2012-01-20 12:54:49.726054+00', 'To Keith', 1713, '');
INSERT INTO 'tune' VALUES (9239, '2004-02-13 23:00:00+00', '2012-01-20 12:54:49.729169+00', 'Prince William''s Welcome', 1793, '');
INSERT INTO 'tune' VALUES (9240, '2004-02-13 23:00:00+00', '2012-01-20 12:54:49.732187+00', 'Fresh Prince, The', 1793, '');
INSERT INTO 'tune' VALUES (9241, '2004-03-07 23:00:00+00', '2012-01-20 12:54:49.735104+00', 'Golden Knot, The', 1508, '');
INSERT INTO 'tune' VALUES (9242, '2004-04-01 22:00:00+00', '2012-01-20 12:54:49.738024+00', 'Slainthe Mhor', 1042, '');
INSERT INTO 'tune' VALUES (9243, '2004-04-01 22:00:00+00', '2012-01-20 12:54:49.740974+00', 'Give Hands in Friendship', 1042, '');
INSERT INTO 'tune' VALUES (9244, '2004-04-01 22:00:00+00', '2012-01-20 12:54:49.74391+00', 'Jess Ingram''s Strathspey', 1042, '');
INSERT INTO 'tune' VALUES (9245, '2004-04-01 22:00:00+00', '2012-01-20 12:54:49.74692+00', 'Lynne Scott''s Strathspey', 1042, '');
INSERT INTO 'tune' VALUES (9246, '2004-04-01 22:00:00+00', '2012-01-20 12:54:49.749851+00', 'Camberley Jig, 2003, The', 1042, '');
INSERT INTO 'tune' VALUES (9247, '2004-04-01 22:00:00+00', '2012-01-20 12:54:49.752759+00', 'Short and Sweet', 1042, '');
INSERT INTO 'tune' VALUES (9249, NULL, '2012-01-20 12:54:49.758583+00', 'Elspeth Gray', 1502, '');
INSERT INTO 'tune' VALUES (9250, NULL, '2012-01-20 12:54:49.761474+00', 'Mrs John Moore''s Delight', 9998, '');
INSERT INTO 'tune' VALUES (9251, NULL, '2012-01-20 12:54:49.764364+00', 'Burn o''Weindia Little, Da', 9998, '');
INSERT INTO 'tune' VALUES (9252, NULL, '2012-01-20 12:54:49.768014+00', 'From Minor to Major', 1502, '');
INSERT INTO 'tune' VALUES (9253, NULL, '2012-01-20 12:54:49.770924+00', 'Lido Palace, The', 1502, '');
INSERT INTO 'tune' VALUES (9254, NULL, '2012-01-20 12:54:49.773805+00', 'Jig in F by Archibald Duff of Aberdeen', 9999, '');
INSERT INTO 'tune' VALUES (9255, '2004-04-27 22:00:00+00', '2012-01-20 12:54:49.776718+00', 'Jig in Bb by Archibald Duff of Aberdeen', 9999, '');
INSERT INTO 'tune' VALUES (9257, NULL, '2012-01-20 12:54:49.782511+00', 'Irn Bru', 1502, '');
INSERT INTO 'tune' VALUES (9258, NULL, '2012-01-20 12:54:49.78545+00', 'Muriel Johnstone''s Reel', 1603, '');
INSERT INTO 'tune' VALUES (9259, NULL, '2012-01-20 12:54:49.78839+00', 'Embroiderer''s Jig, The', 1502, '');
INSERT INTO 'tune' VALUES (9260, NULL, '2012-01-20 12:54:49.791294+00', 'Majic at the Piano', 3436, '');
INSERT INTO 'tune' VALUES (9261, NULL, '2012-01-20 12:54:49.794176+00', 'Karen''s Reel', 1633, '');
INSERT INTO 'tune' VALUES (9170, NULL, '2014-11-09 00:01:44.866965+00', 'Laird of MacIntosh', 9999, '');
INSERT INTO 'tune' VALUES (9263, NULL, '2012-01-20 12:54:49.799946+00', 'Mr Adam Robertson''s Favourite', 3437, '');
INSERT INTO 'tune' VALUES (9264, NULL, '2012-01-20 12:54:49.802835+00', 'Miss Mary Neill', 1543, '');
INSERT INTO 'tune' VALUES (9265, NULL, '2012-01-20 12:54:49.805715+00', 'Mrs Margaret Johnston''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (9266, NULL, '2012-01-20 12:54:49.808607+00', 'Crichtons'', Gowan New Deer', 1750, '');
INSERT INTO 'tune' VALUES (9268, NULL, '2012-01-20 12:54:49.8144+00', 'Ben Hiant', 3436, '');
INSERT INTO 'tune' VALUES (9269, NULL, '2012-01-20 12:54:49.817286+00', 'James F Dickie', 1750, '');
INSERT INTO 'tune' VALUES (9270, NULL, '2012-01-20 12:54:49.82019+00', 'Miss MacDowal Grant''s Strathspey - of Ardnilly', 1516, '');
INSERT INTO 'tune' VALUES (9271, NULL, '2012-01-20 12:54:49.823091+00', 'Richer''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (9272, NULL, '2012-01-20 12:54:49.825967+00', 'Oh, Were I on Parnassus Hill', 9999, '');
INSERT INTO 'tune' VALUES (9273, NULL, '2012-01-20 12:54:49.828866+00', 'Lochnagar', 10477, '');
INSERT INTO 'tune' VALUES (9274, NULL, '2012-01-20 12:54:49.831763+00', 'Gavin J Hamilton''s', 1512, '');
INSERT INTO 'tune' VALUES (9275, NULL, '2012-01-20 12:54:49.834651+00', 'Miss Maria Dundas', 9999, '');
INSERT INTO 'tune' VALUES (9276, NULL, '2012-01-20 12:54:49.837534+00', 'Brodag Aig McCornish', 9999, '');
INSERT INTO 'tune' VALUES (9277, '2004-08-03 22:00:00+00', '2012-01-20 12:54:49.84043+00', 'Ruby for Phyllis, A', 1899, '');
INSERT INTO 'tune' VALUES (9278, NULL, '2012-01-20 12:54:49.843336+00', 'Jackie and Edna Welton', 1593, '');
INSERT INTO 'tune' VALUES (9279, NULL, '2012-01-20 12:54:49.846228+00', 'Discovery Quay', 9998, '');
INSERT INTO 'tune' VALUES (9280, NULL, '2012-01-20 12:54:49.849121+00', 'Patricia Milne''s Jig', 1725, '');
INSERT INTO 'tune' VALUES (9281, NULL, '2012-01-20 12:54:49.852006+00', 'Florence MacLean of Ardholm', 2768, '');
INSERT INTO 'tune' VALUES (9282, NULL, '2012-01-20 12:54:49.854903+00', 'Leith List, The', 1538, '');
INSERT INTO 'tune' VALUES (9283, NULL, '2012-01-20 12:54:49.857787+00', 'John Cass', 1725, '');
INSERT INTO 'tune' VALUES (9284, NULL, '2012-01-20 12:54:49.860676+00', 'Peter Forbes', 1804, '');
INSERT INTO 'tune' VALUES (9285, NULL, '2012-01-20 12:54:49.863548+00', 'Castledykes Reel', 1668, '');
INSERT INTO 'tune' VALUES (9286, NULL, '2012-01-20 12:54:49.866436+00', 'Crathes Castle', 1554, '');
INSERT INTO 'tune' VALUES (9287, NULL, '2012-01-20 12:54:49.869348+00', 'Margaret Morrison', 9998, '');
INSERT INTO 'tune' VALUES (9288, NULL, '2012-01-20 12:54:49.872742+00', 'Harperrig', 9998, '');
INSERT INTO 'tune' VALUES (9290, NULL, '2012-01-20 12:54:49.87856+00', 'Midsteeple, The', 1668, '');
INSERT INTO 'tune' VALUES (9291, NULL, '2012-01-20 12:54:49.881449+00', 'May-Day Hornpipe, The', 3442, '');
INSERT INTO 'tune' VALUES (9292, NULL, '2012-01-20 12:54:49.884341+00', 'Shilla and the Top Cloud, The', 3296, '');
INSERT INTO 'tune' VALUES (9293, NULL, '2012-01-20 12:54:49.887233+00', 'Anderson''s Alley-Seoul', 3296, '');
INSERT INTO 'tune' VALUES (9294, NULL, '2012-01-20 12:54:49.890144+00', 'George Aitchison', 1634, '');
INSERT INTO 'tune' VALUES (9295, NULL, '2012-01-20 12:54:49.893036+00', 'Dave Provan''s Fancy', 1596, '');
INSERT INTO 'tune' VALUES (9296, NULL, '2012-01-20 12:54:49.895931+00', 'Irish Set Dance Tune', 9999, '');
INSERT INTO 'tune' VALUES (9297, NULL, '2012-01-20 12:54:49.898815+00', 'Jolly Beggar', 9999, '');
INSERT INTO 'tune' VALUES (9298, NULL, '2012-01-20 12:54:49.901689+00', 'Heron''s Rock', 1596, '');
INSERT INTO 'tune' VALUES (9299, NULL, '2012-01-20 12:54:49.904711+00', 'Braes of Glenturrote', 1749, '');
INSERT INTO 'tune' VALUES (9300, NULL, '2012-01-20 12:54:49.908411+00', 'Mrs Margaret Saunder''s Jig', 1596, '');
INSERT INTO 'tune' VALUES (9301, '2005-02-01 23:00:00+00', '2012-01-20 12:54:49.912279+00', 'Daffodils, The', 3187, '');
INSERT INTO 'tune' VALUES (9302, NULL, '2012-01-20 12:54:49.916314+00', 'Oh! I do like to be Beside the Seaside', 9999, '');
INSERT INTO 'tune' VALUES (9303, NULL, '2012-01-20 12:54:49.920141+00', 'Life on the Ocean Wave', 3451, '');
INSERT INTO 'tune' VALUES (9304, NULL, '2012-01-20 12:54:49.92398+00', 'All the Nice Girls Love a sailor', 9999, '');
INSERT INTO 'tune' VALUES (9305, NULL, '2012-01-20 12:54:49.928022+00', 'Shanahan''s Rambles', 9999, '');
INSERT INTO 'tune' VALUES (9306, NULL, '2012-01-20 12:54:49.931839+00', 'Hatter from Nenagh, The', 9999, '');
INSERT INTO 'tune' VALUES (9307, NULL, '2012-01-20 12:54:49.935631+00', 'Catholic Boy', 9999, '');
INSERT INTO 'tune' VALUES (9308, NULL, '2012-01-20 12:54:49.939434+00', 'Hurry the Jig', 9999, '');
INSERT INTO 'tune' VALUES (9309, NULL, '2012-01-20 12:54:49.943236+00', 'Bimid Ag ol', 9999, '');
INSERT INTO 'tune' VALUES (9311, NULL, '2012-01-20 12:54:49.951004+00', 'Tommy Peoples', 9999, '');
INSERT INTO 'tune' VALUES (9312, NULL, '2012-01-20 12:54:49.954821+00', 'Rolling Wave', 9999, '');
INSERT INTO 'tune' VALUES (9313, '2004-09-10 22:00:00+00', '2012-01-20 12:54:49.958657+00', 'Katy and Andrew''s Wedding Jig', 3452, '');
INSERT INTO 'tune' VALUES (9314, NULL, '2012-01-20 12:54:49.962474+00', 'Arthur Muise', 1633, '');
INSERT INTO 'tune' VALUES (9315, NULL, '2012-01-20 12:54:49.966264+00', 'Marcel Aucoin', 1633, '');
INSERT INTO 'tune' VALUES (9316, NULL, '2012-01-20 12:54:49.970049+00', 'Level Pegging', 1502, '');
INSERT INTO 'tune' VALUES (9317, NULL, '2012-01-20 12:54:49.973853+00', 'Skimpy Reel, The', 1502, '');
INSERT INTO 'tune' VALUES (9318, NULL, '2012-01-20 12:54:49.977645+00', 'Meg''s Mount', 1502, '');
INSERT INTO 'tune' VALUES (9319, NULL, '2012-01-20 12:54:49.981442+00', 'Knockdhu Reel, The', 1539, '');
INSERT INTO 'tune' VALUES (9320, NULL, '2012-01-20 12:54:49.985234+00', 'Ben Nevis', 9999, '');
INSERT INTO 'tune' VALUES (9321, NULL, '2012-01-20 12:54:49.989031+00', 'Molly Rankin''s Reel', 3421, '');
INSERT INTO 'tune' VALUES (9322, NULL, '2012-01-20 12:54:49.992834+00', 'Jig for the Jappys', 1502, '');
INSERT INTO 'tune' VALUES (9323, NULL, '2012-01-20 12:54:49.99664+00', 'Jig of High Jenks', 1502, '');
INSERT INTO 'tune' VALUES (9324, NULL, '2012-01-20 12:54:50.000454+00', 'Imelda''s Rival', 1502, '');
INSERT INTO 'tune' VALUES (9325, NULL, '2012-01-20 12:54:50.004262+00', 'Lang Tyme Mairrit', 1502, '');
INSERT INTO 'tune' VALUES (9326, NULL, '2012-01-20 12:54:50.008057+00', 'Bonnie Kate of Edinburgh', 9999, '');
INSERT INTO 'tune' VALUES (9327, NULL, '2012-01-20 12:54:50.011862+00', 'Andy Clark of Crieff', 2842, '');
INSERT INTO 'tune' VALUES (9330, NULL, '2012-01-20 12:54:50.023245+00', 'Astronaut, The', 3455, '');
INSERT INTO 'tune' VALUES (9331, NULL, '2012-01-20 12:54:50.027049+00', 'Scollay Boys'' Jig, The', 1711, '');
INSERT INTO 'tune' VALUES (9333, NULL, '2012-01-20 12:54:50.034688+00', 'Bonnie Lass', 9999, '');
INSERT INTO 'tune' VALUES (9334, NULL, '2012-01-20 12:54:50.038505+00', 'Willie Taylor''s Fiddle', 3456, '');
INSERT INTO 'tune' VALUES (9335, NULL, '2012-01-20 12:54:50.042319+00', 'Long-Handled Broom, The', 1576, '');
INSERT INTO 'tune' VALUES (9336, '2005-02-01 23:00:00+00', '2012-01-20 12:54:50.046142+00', 'Water Cresses', 3187, '');
INSERT INTO 'tune' VALUES (9289, NULL, '2022-08-06 15:23:28.579055+00', 'Goggleyed Prawn, The', 1543, '');
INSERT INTO 'tune' VALUES (9337, NULL, '2022-12-19 18:11:31.278235+00', 'Da Sixty Fathom Reel', 3457, '');
INSERT INTO 'tune' VALUES (9338, NULL, '2012-01-20 12:54:50.053763+00', 'Gowl Close', 3452, '');
INSERT INTO 'tune' VALUES (9339, NULL, '2012-01-20 12:54:50.057568+00', 'Nungate Bridge, The', 3452, '');
INSERT INTO 'tune' VALUES (9340, NULL, '2012-01-20 12:54:50.061362+00', 'Twa Haughs, The', 3452, '');
INSERT INTO 'tune' VALUES (9343, NULL, '2012-01-20 12:54:50.072753+00', 'Gypsy Piper, The', 9999, '');
INSERT INTO 'tune' VALUES (9344, NULL, '2012-01-20 12:54:50.076558+00', 'Montmorris', 9999, '');
INSERT INTO 'tune' VALUES (9345, NULL, '2012-01-20 12:54:50.080372+00', 'Merry Soldier, The', 9999, '');
INSERT INTO 'tune' VALUES (9256, NULL, '2021-12-03 21:02:59.376125+00', 'Reuben Butler', 9999, '');
INSERT INTO 'tune' VALUES (9332, '2006-09-03 22:00:00+00', '2012-04-03 20:37:02.294876+00', 'Dave Wiesler''s Compliments to Stella Fogg', 2977, 'composed 2004');
INSERT INTO 'tune' VALUES (9346, NULL, '2012-01-20 12:54:50.084189+00', 'Jack Lattin', 9999, '');
INSERT INTO 'tune' VALUES (9347, NULL, '2012-01-20 12:54:50.088026+00', 'Little Bag of Potatoes', 9999, '');
INSERT INTO 'tune' VALUES (9348, NULL, '2012-01-20 12:54:50.091834+00', 'Strachur', 9999, '');
INSERT INTO 'tune' VALUES (9349, NULL, '2012-01-20 12:54:50.096003+00', 'Mrs Forbes', 9999, '');
INSERT INTO 'tune' VALUES (9350, NULL, '2012-01-20 12:54:50.099823+00', 'Brig o'' Tilt, The', 9999, '');
INSERT INTO 'tune' VALUES (9351, NULL, '2012-01-20 12:54:50.103631+00', 'Miss Edmonstone of Newton', 9999, '');
INSERT INTO 'tune' VALUES (9352, NULL, '2012-01-20 12:54:50.107416+00', 'Kenneth James MacLeod', 1652, '');
INSERT INTO 'tune' VALUES (9353, NULL, '2012-01-20 12:54:50.111216+00', 'Auld Rob Morris', 9999, '');
INSERT INTO 'tune' VALUES (9354, NULL, '2012-01-20 12:54:50.115047+00', 'Mrs Ferguson of Raith''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (9355, NULL, '2012-01-20 12:54:50.118864+00', 'Colonel Fraser of Knocky', 9999, '');
INSERT INTO 'tune' VALUES (9356, NULL, '2012-01-20 12:54:50.12331+00', 'Flaxdresser, The', 9999, '');
INSERT INTO 'tune' VALUES (9357, NULL, '2012-01-20 12:54:50.127417+00', 'Humours of Whiskey, The', 9999, '');
INSERT INTO 'tune' VALUES (9359, NULL, '2012-01-20 12:54:50.13511+00', 'Joe Kennedy''s Jig', 1522, '');
INSERT INTO 'tune' VALUES (9360, '2004-10-31 23:00:00+00', '2012-01-20 12:54:50.139108+00', 'Provost of Falkirk, The', 1522, '');
INSERT INTO 'tune' VALUES (9361, NULL, '2012-01-20 12:54:50.142945+00', 'Cheviot Hills, The', 1464, '');
INSERT INTO 'tune' VALUES (9362, NULL, '2012-01-20 12:54:50.146756+00', 'Regina Stubbert', 1791, '');
INSERT INTO 'tune' VALUES (9363, NULL, '2012-01-20 12:54:50.150556+00', 'Peter Poirier''s', 1791, '');
INSERT INTO 'tune' VALUES (9364, NULL, '2012-01-20 12:54:50.154359+00', 'Ivor Scollay of Barravoe', 1677, '');
INSERT INTO 'tune' VALUES (9365, NULL, '2012-01-20 12:54:50.158151+00', 'Roving Moggy, The', 1593, '');
INSERT INTO 'tune' VALUES (9366, NULL, '2012-01-20 12:54:50.161946+00', 'Tribute to Ian Parsons', 1593, '');
INSERT INTO 'tune' VALUES (9367, NULL, '2012-01-20 12:54:50.165788+00', 'Nancy''s Jig', 1593, '');
INSERT INTO 'tune' VALUES (9368, NULL, '2012-01-20 12:54:50.169593+00', 'Mr & Mrs Jim Scott of Otterburn', 1593, '');
INSERT INTO 'tune' VALUES (9369, NULL, '2012-01-20 12:54:50.173402+00', 'Russ Taylor', 1533, '');
INSERT INTO 'tune' VALUES (9370, NULL, '2012-01-20 12:54:50.177198+00', 'Tommy McTague', 1533, '');
INSERT INTO 'tune' VALUES (9371, NULL, '2012-01-20 12:54:50.181093+00', '10th Highland Regiment Crossing the Rhine', 1426, '');
INSERT INTO 'tune' VALUES (9372, NULL, '2012-01-20 12:54:50.184902+00', 'Warwick''s Lord', 9998, '');
INSERT INTO 'tune' VALUES (9374, NULL, '2012-01-20 12:54:50.192493+00', 'Wedding March', 3460, '');
INSERT INTO 'tune' VALUES (9375, NULL, '2012-01-20 12:54:50.196294+00', 'Nightmare Song, The', 1900, '');
INSERT INTO 'tune' VALUES (9376, '2004-10-31 23:00:00+00', '2012-01-20 12:54:50.200114+00', 'Earl Gray', 1512, '');
INSERT INTO 'tune' VALUES (9310, NULL, '2016-10-09 01:50:21.168828+00', 'New House', 3450, '');
INSERT INTO 'tune' VALUES (9377, NULL, '2012-01-20 12:54:50.203931+00', 'Ardvasar Blacksmith, The', 3463, '');
INSERT INTO 'tune' VALUES (9378, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.207735+00', 'Allie Anderson''s Strathspey', 1714, '');
INSERT INTO 'tune' VALUES (9379, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.211572+00', 'Winston''s Joy', 2743, '');
INSERT INTO 'tune' VALUES (9380, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.215403+00', 'Sandy Webster''s', 3465, '');
INSERT INTO 'tune' VALUES (9381, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.219244+00', 'Rena Mulholland', 2743, '');
INSERT INTO 'tune' VALUES (9383, NULL, '2012-01-20 12:54:50.22689+00', 'Going Round in Circles', 3465, '');
INSERT INTO 'tune' VALUES (9384, NULL, '2012-01-20 12:54:50.230685+00', 'Grace Brown', 2286, '');
INSERT INTO 'tune' VALUES (9385, NULL, '2012-01-20 12:54:50.234477+00', 'Alex Menzies', 9999, '');
INSERT INTO 'tune' VALUES (9386, NULL, '2012-01-20 12:54:50.238261+00', 'Lynne Brook', 2743, '');
INSERT INTO 'tune' VALUES (9387, NULL, '2012-01-20 12:54:50.242046+00', 'Autumn Glow', 2743, '');
INSERT INTO 'tune' VALUES (9388, NULL, '2012-01-20 12:54:50.245847+00', 'Doves, The', 3465, '');
INSERT INTO 'tune' VALUES (9389, NULL, '2012-01-20 12:54:50.249645+00', 'Ian and Dorothy Auld', 2743, '');
INSERT INTO 'tune' VALUES (9390, NULL, '2012-01-20 12:54:50.253441+00', 'Becky''s Jig', 2801, '');
INSERT INTO 'tune' VALUES (9391, NULL, '2012-01-20 12:54:50.257237+00', 'On the Way Home', 2801, '');
INSERT INTO 'tune' VALUES (9392, NULL, '2012-01-20 12:54:50.261038+00', 'Trip to Glasgow', 2743, '');
INSERT INTO 'tune' VALUES (9393, NULL, '2012-01-20 12:54:50.26483+00', 'Miss Susan Inglis', 2743, '');
INSERT INTO 'tune' VALUES (9394, NULL, '2012-01-20 12:54:50.268632+00', 'Happy Hilton Days', 2743, '');
INSERT INTO 'tune' VALUES (9395, NULL, '2012-01-20 12:54:50.272434+00', 'Heart of Home', 2743, '');
INSERT INTO 'tune' VALUES (9396, NULL, '2012-01-20 12:54:50.276222+00', 'Norman Runge', 1555, '');
INSERT INTO 'tune' VALUES (9397, NULL, '2012-01-20 12:54:50.28002+00', 'Mark and Clare', 2743, '');
INSERT INTO 'tune' VALUES (9398, NULL, '2012-01-20 12:54:50.283822+00', 'Red Ayre', 1710, '');
INSERT INTO 'tune' VALUES (9399, NULL, '2012-01-20 12:54:50.28763+00', 'Nicola''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (9400, NULL, '2012-01-20 12:54:50.291452+00', 'Christopher Fraser', 2743, '');
INSERT INTO 'tune' VALUES (9401, NULL, '2012-01-20 12:54:50.295253+00', 'Bonnie Charlie', 1512, '');
INSERT INTO 'tune' VALUES (9402, NULL, '2012-01-20 12:54:50.299062+00', 'James Christie', 9999, '');
INSERT INTO 'tune' VALUES (9403, NULL, '2012-01-20 12:54:50.302855+00', 'Ben', 2743, '');
INSERT INTO 'tune' VALUES (9404, NULL, '2012-01-20 12:54:50.306647+00', 'Welcome Sarah', 2743, '');
INSERT INTO 'tune' VALUES (9405, NULL, '2012-01-20 12:54:50.310465+00', 'Ghillie, The', 3465, '');
INSERT INTO 'tune' VALUES (9406, NULL, '2012-01-20 12:54:50.314274+00', 'Otter''s Stone, The', 3465, '');
INSERT INTO 'tune' VALUES (9407, NULL, '2012-01-20 12:54:50.318076+00', 'River Brann, The', 3465, '');
INSERT INTO 'tune' VALUES (9408, NULL, '2012-01-20 12:54:50.321871+00', 'Nicola''s Strathspey', 2743, '');
INSERT INTO 'tune' VALUES (9409, NULL, '2012-01-20 12:54:50.325677+00', 'James Dunbar of Kincardine', 3466, '');
INSERT INTO 'tune' VALUES (9410, NULL, '2012-01-20 12:54:50.329658+00', 'Bob and Doreen McKerron', 3465, '');
INSERT INTO 'tune' VALUES (9411, NULL, '2012-01-20 12:54:50.333466+00', 'Alford Weaver, The', 1512, '');
INSERT INTO 'tune' VALUES (9412, NULL, '2012-01-20 12:54:50.337323+00', 'Charles Sutherland', 1750, '');
INSERT INTO 'tune' VALUES (9413, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.341148+00', 'Fine Day in Spring, A', 3201, '');
INSERT INTO 'tune' VALUES (9414, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.344988+00', 'Swinging Spring', 1445, '');
INSERT INTO 'tune' VALUES (9415, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.348818+00', 'Greening of the Woods, The', 1445, '');
INSERT INTO 'tune' VALUES (9416, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.352645+00', 'Antje''s Jig', 1445, '');
INSERT INTO 'tune' VALUES (9417, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.356469+00', 'Birds and the Isles, The', 1445, '');
INSERT INTO 'tune' VALUES (9418, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.360321+00', 'Guides of Cracow, The', 1445, '');
INSERT INTO 'tune' VALUES (9419, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.364151+00', 'Old Abbey, The', 1445, '');
INSERT INTO 'tune' VALUES (9420, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.367992+00', 'Missed Steak, The', 1445, '');
INSERT INTO 'tune' VALUES (9421, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.371824+00', 'Castle on the Hill, The', 1445, '');
INSERT INTO 'tune' VALUES (9422, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.37565+00', 'View from the Hall, The', 1445, '');
INSERT INTO 'tune' VALUES (9423, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.379483+00', 'Meeting Friends at Rad', 1445, '');
INSERT INTO 'tune' VALUES (9424, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.383318+00', 'Brown Eyed Lassie, The', 1445, '');
INSERT INTO 'tune' VALUES (9425, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.38715+00', 'Caffeine Reel, The', 1445, '');
INSERT INTO 'tune' VALUES (9426, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.390982+00', 'Earl Robert', 1445, '');
INSERT INTO 'tune' VALUES (9427, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.394822+00', 'Highland Fun', 1445, '');
INSERT INTO 'tune' VALUES (9428, '2004-11-01 23:00:00+00', '2012-01-20 12:54:50.398658+00', 'Band Steward, The', 1445, '');
INSERT INTO 'tune' VALUES (9429, NULL, '2012-01-20 12:54:50.402477+00', 'Cherish the Ladies', 9999, '');
INSERT INTO 'tune' VALUES (9430, NULL, '2012-01-20 12:54:50.406293+00', 'Old Mill Wheel, The', 1920, '');
INSERT INTO 'tune' VALUES (9431, NULL, '2012-01-20 12:54:50.410164+00', 'Janet Donaldson', 1623, '');
INSERT INTO 'tune' VALUES (9432, NULL, '2012-01-20 12:54:50.413957+00', 'Bonnie Muir', 3467, '');
INSERT INTO 'tune' VALUES (9433, NULL, '2012-01-20 12:54:50.417751+00', 'Hoose in the Wa'', The', 1920, '');
INSERT INTO 'tune' VALUES (9434, NULL, '2012-01-20 12:54:50.421535+00', 'Miss Gordon of Rafford', 1930, '');
INSERT INTO 'tune' VALUES (9435, '2004-11-04 23:00:00+00', '2012-01-20 12:54:50.425346+00', 'Jan''s Jig', 1793, '');
INSERT INTO 'tune' VALUES (9436, '2004-11-16 23:00:00+00', '2012-01-20 12:54:50.429245+00', 'Dvorna', 1502, '');
INSERT INTO 'tune' VALUES (9437, '2004-11-16 23:00:00+00', '2012-01-20 12:54:50.433102+00', 'Pease Bridge', 1401, 'Attributed to »Abr. Mackintosh« in The Glen Collection.');
INSERT INTO 'tune' VALUES (9438, '2004-11-16 23:00:00+00', '2012-01-20 12:54:50.436945+00', 'First Edition, The', 401, '');
INSERT INTO 'tune' VALUES (9439, '2004-11-16 23:00:00+00', '2012-01-20 12:54:50.440779+00', 'Rascal Fair', 2392, '');
INSERT INTO 'tune' VALUES (9440, '2004-11-16 23:00:00+00', '2012-01-20 12:54:50.444613+00', 'Redwoods', 389, '');
INSERT INTO 'tune' VALUES (9441, '2004-11-16 23:00:00+00', '2012-01-20 12:54:50.448461+00', 'Comunn Dannsaidh, An', 401, '');
INSERT INTO 'tune' VALUES (9442, '2004-11-16 23:00:00+00', '2012-01-20 12:54:50.452291+00', 'Saint Ola', 389, '');
INSERT INTO 'tune' VALUES (9443, '2004-11-16 23:00:00+00', '2012-01-20 12:54:50.456138+00', 'Timepiece', 389, '');
INSERT INTO 'tune' VALUES (9444, '2004-11-16 23:00:00+00', '2012-01-20 12:54:50.45998+00', 'Uhlingers, The', 390, '');
INSERT INTO 'tune' VALUES (9445, '2004-11-17 23:00:00+00', '2012-01-20 12:54:50.463805+00', 'Give Me Your Hand', 3470, '');
INSERT INTO 'tune' VALUES (9446, '2004-11-17 23:00:00+00', '2012-01-20 12:54:50.467631+00', 'Countess of Dalhousie', 1903, '');
INSERT INTO 'tune' VALUES (9447, '2004-11-22 23:00:00+00', '2012-01-20 12:54:50.471469+00', 'Colin Coull of Buckie', 3186, '');
INSERT INTO 'tune' VALUES (9448, '2004-11-23 23:00:00+00', '2012-01-20 12:54:50.475299+00', 'Turn Turtle', 1084, '');
INSERT INTO 'tune' VALUES (9449, '2004-11-23 23:00:00+00', '2012-01-20 12:54:50.479129+00', 'Barwhin Point', 1824, '');
INSERT INTO 'tune' VALUES (9450, '2004-11-23 23:00:00+00', '2012-01-20 12:54:50.483005+00', 'Glasson Rock', 1824, '');
INSERT INTO 'tune' VALUES (9451, '2004-11-23 23:00:00+00', '2012-01-20 12:54:50.486835+00', 'Bonny Water, The', 1084, '');
INSERT INTO 'tune' VALUES (9452, '2004-11-23 23:00:00+00', '2012-01-20 12:54:50.49067+00', 'Fair Puggled', 1084, '');
INSERT INTO 'tune' VALUES (9453, '2004-11-23 23:00:00+00', '2012-01-20 12:54:50.494502+00', '3 Westside Gardens', 1824, '');
INSERT INTO 'tune' VALUES (9454, '2004-11-24 23:00:00+00', '2012-01-20 12:54:50.498332+00', 'Doric Mannie, The', 1591, '');
INSERT INTO 'tune' VALUES (9455, NULL, '2012-01-20 12:54:50.502158+00', 'Pardeburg', 9999, '');
INSERT INTO 'tune' VALUES (9456, NULL, '2012-01-20 12:54:50.50595+00', 'Drumsheugh', 9999, '');
INSERT INTO 'tune' VALUES (9457, NULL, '2012-01-20 12:54:50.509748+00', 'Croall''s Strathspey', 1512, '');
INSERT INTO 'tune' VALUES (9458, NULL, '2012-01-20 12:54:50.513657+00', 'James MacInnes, Esq', 1518, '');
INSERT INTO 'tune' VALUES (9460, NULL, '2012-01-20 12:54:50.521263+00', 'Mr Donaldson', 9999, '');
INSERT INTO 'tune' VALUES (9461, NULL, '2012-01-20 12:54:50.525102+00', 'Hopscotch', 1439, '');
INSERT INTO 'tune' VALUES (9462, '2004-12-06 23:00:00+00', '2012-01-20 12:54:50.529069+00', 'Old Snuff Mill Bridge, The', 1439, '');
INSERT INTO 'tune' VALUES (9463, '2004-12-06 23:00:00+00', '2012-01-20 12:54:50.532898+00', 'Trip to New Zealand, A', 1439, '');
INSERT INTO 'tune' VALUES (9464, '2004-12-07 23:00:00+00', '2012-01-20 12:54:50.53673+00', 'Lochindorb', 1539, '');
INSERT INTO 'tune' VALUES (9465, NULL, '2012-01-20 12:54:50.540565+00', 'On wi'' the Tartan', 9999, '');
INSERT INTO 'tune' VALUES (9466, NULL, '2012-01-20 12:54:50.54436+00', 'Skyeman''s Jig, The', 9999, '');
INSERT INTO 'tune' VALUES (9467, NULL, '2012-01-20 12:54:50.548171+00', 'Kingussie Shinty Club', 3485, '');
INSERT INTO 'tune' VALUES (9468, NULL, '2012-01-20 12:54:50.551969+00', 'Henri''s Ornpipe', 1780, '');
INSERT INTO 'tune' VALUES (9469, NULL, '2012-01-20 12:54:50.555769+00', 'Mrs Imbrie''s Feast', 1780, '');
INSERT INTO 'tune' VALUES (9470, NULL, '2012-01-20 12:54:50.559556+00', 'Ms Kurnick''s Hornpipe', 1780, '');
INSERT INTO 'tune' VALUES (9471, NULL, '2012-01-20 12:54:50.563353+00', 'Little Judique', 9999, '');
INSERT INTO 'tune' VALUES (9472, NULL, '2012-01-20 12:54:50.567145+00', 'She''s too Fat for Me', 9999, '');
INSERT INTO 'tune' VALUES (9473, NULL, '2012-01-20 12:54:50.570947+00', 'Saint Lawrence Jig', 9999, '');
INSERT INTO 'tune' VALUES (9474, NULL, '2012-01-20 12:54:50.574752+00', 'Wren Polka, The', 9998, '');
INSERT INTO 'tune' VALUES (9475, NULL, '2012-01-20 12:54:50.578542+00', 'Connecticut March', 3486, '');
INSERT INTO 'tune' VALUES (9476, NULL, '2012-01-20 12:54:50.582332+00', 'Tank, The', 9999, '');
INSERT INTO 'tune' VALUES (9477, NULL, '2012-01-20 12:54:50.586149+00', 'Saturday Night Breakdown', 9999, '');
INSERT INTO 'tune' VALUES (9478, NULL, '2012-01-20 12:54:50.589946+00', 'Monaltrie''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (9479, NULL, '2012-01-20 12:54:50.593741+00', 'John Taylor''s Pyjamas', 2221, '');
INSERT INTO 'tune' VALUES (9480, '2004-12-08 23:00:00+00', '2012-01-20 12:54:50.59756+00', 'Strathspey for the Black Watch', 1591, '');
INSERT INTO 'tune' VALUES (9481, '2004-12-08 23:00:00+00', '2012-01-20 12:54:50.601396+00', 'Witches Craig', 1591, '');
INSERT INTO 'tune' VALUES (9482, '2004-12-08 23:00:00+00', '2012-01-20 12:54:50.605222+00', 'Cardean', 2208, '');
INSERT INTO 'tune' VALUES (9483, '2004-12-08 23:00:00+00', '2012-01-20 12:54:50.609066+00', 'Hamish Renton', 1596, '');
INSERT INTO 'tune' VALUES (9485, '2004-12-08 23:00:00+00', '2012-01-20 12:54:50.616742+00', 'Kerrs Pink', 1505, '');
INSERT INTO 'tune' VALUES (9486, NULL, '2012-01-20 12:54:50.620604+00', 'Temperance Reel, The', 9998, '');
INSERT INTO 'tune' VALUES (9487, NULL, '2012-01-20 12:54:50.624408+00', 'Dunmore Lassies', 9998, '');
INSERT INTO 'tune' VALUES (9488, NULL, '2012-01-20 12:54:50.628192+00', 'Coates Hall', 3493, '');
INSERT INTO 'tune' VALUES (9489, NULL, '2012-01-20 12:54:50.631984+00', 'Stoney Point', 9999, '');
INSERT INTO 'tune' VALUES (9490, NULL, '2012-01-20 12:54:50.635847+00', 'South Shore, The', 1625, '');
INSERT INTO 'tune' VALUES (9491, NULL, '2012-01-20 12:54:50.639679+00', 'Salt River', 9999, '');
INSERT INTO 'tune' VALUES (9492, NULL, '2012-01-20 12:54:50.643495+00', 'Wagoner', 9999, '');
INSERT INTO 'tune' VALUES (9493, NULL, '2012-01-20 12:54:50.647303+00', 'New Tyne Bridge, The', 9999, '');
INSERT INTO 'tune' VALUES (9494, NULL, '2012-01-20 12:54:50.651104+00', 'Màr o'' Cheanaich', 9999, '');
INSERT INTO 'tune' VALUES (9495, NULL, '2012-01-20 12:54:50.654915+00', 'Marie''s Wedding', 9999, '');
INSERT INTO 'tune' VALUES (9496, NULL, '2012-01-20 12:54:50.659141+00', 'Planxty Fanny Power', 1882, '');
INSERT INTO 'tune' VALUES (9497, NULL, '2012-01-20 12:54:50.662981+00', 'Banks of Lochiel', 9998, '');
INSERT INTO 'tune' VALUES (9498, NULL, '2012-01-20 12:54:50.66678+00', 'Lough Gill, The', 9998, '');
INSERT INTO 'tune' VALUES (9499, NULL, '2012-01-20 12:54:50.670585+00', 'Full Rigged Ship, Da', 9998, '');
INSERT INTO 'tune' VALUES (9500, NULL, '2012-01-20 12:54:50.674393+00', 'Off to California', 9998, '');
INSERT INTO 'tune' VALUES (9501, NULL, '2012-01-20 12:54:50.678188+00', 'Matelot, The', 9998, '');
INSERT INTO 'tune' VALUES (9502, NULL, '2012-01-20 12:54:50.681977+00', 'Munster Buttermilk', 9998, '');
INSERT INTO 'tune' VALUES (9503, NULL, '2012-01-20 12:54:50.685801+00', 'Grahaemsie Jig', 9998, '');
INSERT INTO 'tune' VALUES (9504, NULL, '2012-01-20 12:54:50.700597+00', 'Sweet Helseyside', 9998, '');
INSERT INTO 'tune' VALUES (9506, NULL, '2012-01-20 12:54:50.708368+00', 'Robert Smith', 1966, '');
INSERT INTO 'tune' VALUES (9507, NULL, '2012-01-20 12:54:50.712186+00', 'Johnny Wilmot''s Fiddles', 3497, '');
INSERT INTO 'tune' VALUES (9508, NULL, '2012-01-20 12:54:50.716013+00', 'Lady Bromes', 1519, '');
INSERT INTO 'tune' VALUES (9509, NULL, '2012-01-20 12:54:50.719991+00', 'Sally Hunter of Thurston', 1517, '');
INSERT INTO 'tune' VALUES (9510, NULL, '2012-01-20 12:54:50.724001+00', 'Sandy McIntyre''s Trip to Boston', 2126, '');
INSERT INTO 'tune' VALUES (9511, NULL, '2012-01-20 12:54:50.727817+00', 'Flogging Reel, The', 9998, '');
INSERT INTO 'tune' VALUES (9512, NULL, '2012-01-20 12:54:50.731642+00', 'Frank''s Reel', 3146, '');
INSERT INTO 'tune' VALUES (9513, '2005-01-10 23:00:00+00', '2012-01-20 12:54:50.73703+00', 'Knock, The', 479, '');
INSERT INTO 'tune' VALUES (9514, '2005-01-12 23:00:00+00', '2012-01-20 12:54:50.740889+00', 'Calum Donaldson', 1623, '');
INSERT INTO 'tune' VALUES (9515, NULL, '2012-01-20 12:54:50.744718+00', 'Joe Ramwell''s Reel', 1575, '');
INSERT INTO 'tune' VALUES (9516, NULL, '2012-01-20 12:54:50.748643+00', 'Celtic Steps', 10167, '');
INSERT INTO 'tune' VALUES (9517, NULL, '2012-01-20 12:54:50.752433+00', 'Oor Ain Fireside', 9998, '');
INSERT INTO 'tune' VALUES (13859, '2018-03-30 09:36:58.041457+00', '2018-03-30 09:37:02.445814+00', 'Year of Jubilo', 11615, '');
INSERT INTO 'tune' VALUES (9520, NULL, '2012-01-20 12:54:50.763864+00', 'On Galway Bay', 1608, '');
INSERT INTO 'tune' VALUES (9521, NULL, '2012-01-20 12:54:50.767665+00', 'Runnrig', 9998, '');
INSERT INTO 'tune' VALUES (9522, NULL, '2012-01-20 12:54:50.771504+00', 'Kirkbrae', 1596, '');
INSERT INTO 'tune' VALUES (9523, NULL, '2012-01-20 12:54:50.77531+00', 'Evelyn''s Strathspey', 1596, '');
INSERT INTO 'tune' VALUES (9524, NULL, '2012-01-20 12:54:50.779107+00', 'Mrs Carter of Lincluden', 9998, '');
INSERT INTO 'tune' VALUES (9525, NULL, '2012-01-20 12:54:50.782915+00', 'Henry Robson''s Button Box', 1593, '');
INSERT INTO 'tune' VALUES (9526, NULL, '2012-01-20 12:54:50.786721+00', 'Joe Ramwell''s Strathspey', 1596, '');
INSERT INTO 'tune' VALUES (9527, NULL, '2012-01-20 12:54:50.790531+00', 'Hazel Grieg''s', 1575, '');
INSERT INTO 'tune' VALUES (9528, NULL, '2012-01-20 12:54:50.794336+00', 'Lovely Cumbria', 1596, '');
INSERT INTO 'tune' VALUES (9529, NULL, '2012-01-20 12:54:50.798136+00', 'Uniform 242', 1575, '');
INSERT INTO 'tune' VALUES (9530, NULL, '2012-01-20 12:54:50.801934+00', 'Bunji''s Dilemma', 2404, '');
INSERT INTO 'tune' VALUES (9531, NULL, '2012-01-20 12:54:50.805736+00', 'Mouth of the Tobique', 9998, '');
INSERT INTO 'tune' VALUES (9533, NULL, '2012-01-20 12:54:50.813332+00', 'Road to Banff', 10253, '');
INSERT INTO 'tune' VALUES (9534, NULL, '2012-01-20 12:54:50.817134+00', 'Howard''s Way', 9998, '');
INSERT INTO 'tune' VALUES (9535, NULL, '2012-01-20 12:54:50.820929+00', 'Riding Down from Bangor', 9998, '');
INSERT INTO 'tune' VALUES (9536, '2005-02-01 23:00:00+00', '2012-01-20 12:54:50.824752+00', 'Through the Arches of Roses', 3187, '');
INSERT INTO 'tune' VALUES (9537, NULL, '2012-01-20 12:54:50.828581+00', 'Anda Campbell''s March', 1591, '');
INSERT INTO 'tune' VALUES (9538, NULL, '2012-01-20 12:54:50.832375+00', 'Scotland the Brave', 2006, '');
INSERT INTO 'tune' VALUES (9539, '2005-02-23 23:00:00+00', '2012-01-20 12:54:50.83621+00', 'Creag Dhu', 1836, '');
INSERT INTO 'tune' VALUES (9540, '2005-02-23 23:00:00+00', '2012-01-20 12:54:50.840048+00', 'John Walton''s Birthday', 1836, '');
INSERT INTO 'tune' VALUES (9541, '2005-02-23 23:00:00+00', '2012-01-20 12:54:50.843876+00', 'Jones Falls', 1836, '');
INSERT INTO 'tune' VALUES (9542, '2005-02-23 23:00:00+00', '2012-01-20 12:54:50.84771+00', 'Rosemary Baird''s Farewell to Prince George', 1836, '');
INSERT INTO 'tune' VALUES (9543, NULL, '2012-01-20 12:54:50.851529+00', 'Spital of Glenshee, The', 1836, '');
INSERT INTO 'tune' VALUES (9544, NULL, '2012-01-20 12:54:50.855336+00', 'Letty Moodie', 1836, '');
INSERT INTO 'tune' VALUES (9545, NULL, '2012-01-20 12:54:50.859132+00', 'Border Cities Jig, The', 1836, '');
INSERT INTO 'tune' VALUES (9546, NULL, '2012-01-20 12:54:50.862937+00', 'Tayside Place', 1836, '');
INSERT INTO 'tune' VALUES (9548, NULL, '2012-01-20 12:54:50.871343+00', 'Candidate''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (9549, NULL, '2012-01-20 12:54:50.875183+00', 'Dominie''s Tawse, The', 1836, '');
INSERT INTO 'tune' VALUES (9550, NULL, '2012-01-20 12:54:50.879012+00', 'Robert MIllar of Toronto', 1836, '');
INSERT INTO 'tune' VALUES (9551, NULL, '2012-01-20 12:54:50.882945+00', 'Carillon', 1836, '');
INSERT INTO 'tune' VALUES (9552, NULL, '2012-01-20 12:54:50.886762+00', 'Major Mackie', 9999, '');
INSERT INTO 'tune' VALUES (9553, NULL, '2012-01-20 12:54:50.890569+00', 'Pumpkin Man', 9998, '');
INSERT INTO 'tune' VALUES (9554, NULL, '2012-01-20 12:54:50.894379+00', 'Duncairn', 1836, '');
INSERT INTO 'tune' VALUES (9555, NULL, '2012-01-20 12:54:50.898175+00', 'Castle Menzies', 1836, '');
INSERT INTO 'tune' VALUES (9505, NULL, '2012-06-17 15:10:08.671541+00', 'Spin-N-Glo', 3207, '');
INSERT INTO 'tune' VALUES (9519, NULL, '2012-08-31 20:37:44.960504+00', 'Gordon Simpson''s Jig', 1613, 'Composer''s name spelled as "Ian"');
INSERT INTO 'tune' VALUES (9556, NULL, '2012-01-20 12:54:50.901966+00', 'Matsushima', 1836, '');
INSERT INTO 'tune' VALUES (9878, NULL, '2012-01-20 12:54:52.142187+00', 'Call, The', 9999, '');
INSERT INTO 'tune' VALUES (9557, NULL, '2012-01-20 12:54:50.905813+00', 'Pitcarnie Hornpipe', 1836, '');
INSERT INTO 'tune' VALUES (9558, NULL, '2012-01-20 12:54:50.90969+00', 'Fay''s Frolic', 1836, '');
INSERT INTO 'tune' VALUES (9559, NULL, '2012-01-20 12:54:50.913506+00', 'My Aberfeldy', 1836, '');
INSERT INTO 'tune' VALUES (9560, NULL, '2012-01-20 12:54:50.91778+00', 'Bonnie Loch Leven', 9999, '');
INSERT INTO 'tune' VALUES (9561, '2005-02-23 23:00:00+00', '2012-01-20 12:54:50.921588+00', 'Susan McKinnell', 1862, '');
INSERT INTO 'tune' VALUES (9547, NULL, '2021-02-18 04:37:29.162743+00', 'Yamato Hornpipe', 1836, '');
INSERT INTO 'tune' VALUES (9562, '2005-02-23 23:00:00+00', '2012-01-20 12:54:50.925428+00', 'Chicago Trio', 3511, '');
INSERT INTO 'tune' VALUES (9563, '2005-03-02 23:00:00+00', '2012-01-20 12:54:50.929289+00', 'Molinos, Los', 1508, '');
INSERT INTO 'tune' VALUES (9564, '2005-03-02 23:00:00+00', '2012-01-20 12:54:50.933128+00', 'Olive Tree, The', 1508, '');
INSERT INTO 'tune' VALUES (9565, '2005-03-22 23:00:00+00', '2012-01-20 12:54:50.936962+00', 'Isabella Richardson''s Reel', 1603, '');
INSERT INTO 'tune' VALUES (9566, NULL, '2012-01-20 12:54:50.940802+00', 'Gilsland''s Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (9567, NULL, '2012-01-20 12:54:50.944635+00', 'Cotillon', 9998, '');
INSERT INTO 'tune' VALUES (9568, NULL, '2012-01-20 12:54:50.948439+00', 'House of Achluncart, a reel, The', 1516, '');
INSERT INTO 'tune' VALUES (9569, NULL, '2012-01-20 12:54:50.952248+00', 'Mrs Young of Cornhills', 9998, '');
INSERT INTO 'tune' VALUES (9570, NULL, '2012-01-20 12:54:50.956044+00', 'Quickstep', 1519, '');
INSERT INTO 'tune' VALUES (9571, NULL, '2012-01-20 12:54:50.959842+00', 'John Small''s Minuet', 9998, '');
INSERT INTO 'tune' VALUES (9572, NULL, '2012-01-20 12:54:50.963642+00', 'Charming Phyllis - a minuet', 9998, '');
INSERT INTO 'tune' VALUES (9573, NULL, '2012-01-20 12:54:50.967449+00', 'Pavilion Waltz, The', 9999, '');
INSERT INTO 'tune' VALUES (9574, NULL, '2012-01-20 12:54:50.971248+00', 'Miss Barrett''s Waltz', 9998, '');
INSERT INTO 'tune' VALUES (9575, NULL, '2012-01-20 12:54:50.97505+00', 'Old Scottish Waltz, The', 9998, '');
INSERT INTO 'tune' VALUES (9576, NULL, '2012-01-20 12:54:50.978845+00', 'Mr Webster', 9998, '');
INSERT INTO 'tune' VALUES (9577, NULL, '2012-01-20 12:54:50.982639+00', 'Recovery, The', 9999, '');
INSERT INTO 'tune' VALUES (9578, NULL, '2012-01-20 12:54:50.986433+00', 'Keith-O', 9998, '');
INSERT INTO 'tune' VALUES (9579, NULL, '2012-01-20 12:54:50.990242+00', 'Hamish''s Jess', 9998, '');
INSERT INTO 'tune' VALUES (9580, NULL, '2012-01-20 12:54:50.994035+00', 'Wilma Brown''s Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (9582, NULL, '2012-01-20 12:54:51.001644+00', 'Cairn Table', 9998, '');
INSERT INTO 'tune' VALUES (9583, NULL, '2012-01-20 12:54:51.005435+00', 'Middlefield Law', 9998, '');
INSERT INTO 'tune' VALUES (9584, '2005-04-06 22:00:00+00', '2012-01-20 12:54:51.009262+00', 'Sandy Nixon''s Compliments to Dave and Judy Hall', 1576, '');
INSERT INTO 'tune' VALUES (9585, '2005-04-06 22:00:00+00', '2012-01-20 12:54:51.013105+00', 'Wivenhoe Waves', 3535, '');
INSERT INTO 'tune' VALUES (9586, '2005-04-13 22:00:00+00', '2012-01-20 12:54:51.016939+00', 'Dan Blackwood', 3220, '');
INSERT INTO 'tune' VALUES (9587, '2005-04-25 22:00:00+00', '2012-01-20 12:54:51.02078+00', 'Maple Dancing', 3465, '');
INSERT INTO 'tune' VALUES (9588, NULL, '2012-01-20 12:54:51.024611+00', 'Miss Margaret Grant', 9999, '');
INSERT INTO 'tune' VALUES (9589, NULL, '2012-01-20 12:54:51.028426+00', 'Liberton Pipe Band', 2225, '');
INSERT INTO 'tune' VALUES (9590, NULL, '2012-01-20 12:54:51.032239+00', 'Betty Fitchet''s Wedding', 1558, '');
INSERT INTO 'tune' VALUES (9592, NULL, '2012-01-20 12:54:51.039871+00', 'Brydie''s Polka', 1558, '');
INSERT INTO 'tune' VALUES (9593, '2005-05-16 22:00:00+00', '2012-01-20 12:54:51.043682+00', 'Dunbeath Strath', 3609, '');
INSERT INTO 'tune' VALUES (9594, '2005-05-16 22:00:00+00', '2012-01-20 12:54:51.047524+00', 'Reiss Sands', 3609, '');
INSERT INTO 'tune' VALUES (9595, '2005-05-17 22:00:00+00', '2012-01-20 12:54:51.051352+00', 'Noss Head', 3609, '');
INSERT INTO 'tune' VALUES (9596, '2005-05-17 22:00:00+00', '2012-01-20 12:54:51.055189+00', 'Rosebank House', 3609, '');
INSERT INTO 'tune' VALUES (9597, '2005-06-19 22:00:00+00', '2012-01-20 12:54:51.059028+00', 'Sir Henry Daniel of Gooch', 2768, '');
INSERT INTO 'tune' VALUES (9598, '2005-06-26 22:00:00+00', '2012-01-20 12:54:51.06286+00', 'Puget Sound Shores', 1457, '');
INSERT INTO 'tune' VALUES (9599, '2005-06-26 22:00:00+00', '2012-01-20 12:54:51.066694+00', 'Hello, Goodbye', 3611, '');
INSERT INTO 'tune' VALUES (9601, '2005-06-26 22:00:00+00', '2012-01-20 12:54:51.074365+00', 'Mary Wattum''s Reel', 3612, '');
INSERT INTO 'tune' VALUES (9602, '2005-06-26 22:00:00+00', '2012-01-20 12:54:51.078195+00', 'Miss Anderson''s Jig', 3612, '');
INSERT INTO 'tune' VALUES (9603, '2005-06-26 22:00:00+00', '2012-01-20 12:54:51.082027+00', 'Mount Seymour Strathspey', 3613, '');
INSERT INTO 'tune' VALUES (9604, '2005-06-26 22:00:00+00', '2012-01-20 12:54:51.086151+00', 'Nellie''s Jig', 3612, '');
INSERT INTO 'tune' VALUES (9605, '2005-06-26 22:00:00+00', '2012-01-20 12:54:51.089975+00', 'Nessie''s Neuk', 3614, '');
INSERT INTO 'tune' VALUES (9606, '2005-06-26 22:00:00+00', '2012-01-20 12:54:51.093891+00', 'People''s Princess, The', 3612, '');
INSERT INTO 'tune' VALUES (9607, '2005-06-26 22:00:00+00', '2012-01-20 12:54:51.097731+00', 'Computer Breakdown, The', 3611, '');
INSERT INTO 'tune' VALUES (9608, '2005-06-26 22:00:00+00', '2012-01-20 12:54:51.101601+00', 'June Gow', 1764, '');
INSERT INTO 'tune' VALUES (9609, '2005-06-26 22:00:00+00', '2012-01-20 12:54:51.105436+00', 'Taking the Tickets', 3611, '');
INSERT INTO 'tune' VALUES (9610, NULL, '2012-01-20 12:54:51.109251+00', 'Kindie Burn, The', 1538, '');
INSERT INTO 'tune' VALUES (9611, NULL, '2012-01-20 12:54:51.113055+00', 'Ladylea Hill', 1538, '');
INSERT INTO 'tune' VALUES (9612, NULL, '2012-01-20 12:54:51.116904+00', 'Gruesome Twosome', 1508, '');
INSERT INTO 'tune' VALUES (9613, NULL, '2012-01-20 12:54:51.120708+00', 'Silver Walk', 3052, '');
INSERT INTO 'tune' VALUES (9614, NULL, '2012-01-20 12:54:51.125291+00', 'Stuart''s Strathspey', 2768, '');
INSERT INTO 'tune' VALUES (9615, NULL, '2012-01-20 12:54:51.129318+00', 'Luke''s Welcome', 2768, '');
INSERT INTO 'tune' VALUES (9616, NULL, '2012-01-20 12:54:51.133128+00', 'House of Bruar Reel', 2768, '');
INSERT INTO 'tune' VALUES (9617, NULL, '2012-01-20 12:54:51.136925+00', 'Sitting in a Toy Train', 2768, '');
INSERT INTO 'tune' VALUES (9618, NULL, '2012-01-20 12:54:51.140753+00', 'Fortification Jig, The', 2768, '');
INSERT INTO 'tune' VALUES (9619, NULL, '2012-01-20 12:54:51.144568+00', 'Helma Urquhart''s Fancy', 2768, '');
INSERT INTO 'tune' VALUES (9620, NULL, '2012-01-20 12:54:51.148356+00', 'Loupin'' Lasagne', 2768, '');
INSERT INTO 'tune' VALUES (9621, '2006-02-15 23:00:00+00', '2012-01-20 12:54:51.152173+00', 'Love''s Young Dream', 9999, '');
INSERT INTO 'tune' VALUES (9622, '2005-07-03 22:00:00+00', '2012-01-20 12:54:51.156012+00', 'Ha! Ha! The Wooin'' O'' It', 9999, '');
INSERT INTO 'tune' VALUES (9623, '2005-07-03 22:00:00+00', '2012-01-20 12:54:51.159845+00', 'Birches, Crieff, The', 1607, '');
INSERT INTO 'tune' VALUES (9624, NULL, '2012-01-20 12:54:51.163715+00', 'Castle in the Air', 9999, '');
INSERT INTO 'tune' VALUES (9625, NULL, '2012-01-20 12:54:51.167515+00', 'Waltz for Zoe', 3620, '');
INSERT INTO 'tune' VALUES (9626, NULL, '2012-01-20 12:54:51.171321+00', 'Lord Torpichen''s Favourite', 9998, '');
INSERT INTO 'tune' VALUES (9627, NULL, '2012-01-20 12:54:51.175255+00', 'Bells of Jessie Street, The', 1579, '');
INSERT INTO 'tune' VALUES (9628, NULL, '2012-01-20 12:54:51.17914+00', 'Howkin'' Tatties', 1725, '');
INSERT INTO 'tune' VALUES (9629, NULL, '2012-01-20 12:54:51.183011+00', 'Jig for Isobelle, A', 1578, '');
INSERT INTO 'tune' VALUES (9630, NULL, '2012-01-20 12:54:51.186837+00', 'Well of Deeview', 1770, '');
INSERT INTO 'tune' VALUES (9631, NULL, '2012-01-20 12:54:51.190693+00', 'Miss Menzies of Culdoves', 9999, '');
INSERT INTO 'tune' VALUES (9632, NULL, '2012-01-20 12:54:51.196946+00', 'Mr & Mrs McGinn''s Welcome to Minigaff', 3623, '');
INSERT INTO 'tune' VALUES (9633, NULL, '2012-01-20 12:54:51.200862+00', 'Stuart Anderson', 1871, '');
INSERT INTO 'tune' VALUES (9634, NULL, '2012-01-20 12:54:51.2047+00', 'Findony Garden', 2266, '');
INSERT INTO 'tune' VALUES (9635, NULL, '2012-01-20 12:54:51.208501+00', 'Sweetheart Abbey', 1668, '');
INSERT INTO 'tune' VALUES (9636, NULL, '2012-01-20 12:54:51.212314+00', 'Mrs Ian Powrie', 3624, '');
INSERT INTO 'tune' VALUES (9637, '2005-08-29 22:00:00+00', '2012-01-20 12:54:51.216147+00', 'Falkirk Millennium Wheel', 9998, '');
INSERT INTO 'tune' VALUES (9638, '2005-09-01 22:00:00+00', '2012-01-20 12:54:51.219981+00', 'Avis Harrison''s Strathspey', 1596, '');
INSERT INTO 'tune' VALUES (9639, '2005-09-01 22:00:00+00', '2012-01-20 12:54:51.223828+00', 'Ivy and George King', 316, '');
INSERT INTO 'tune' VALUES (9640, '2005-09-04 22:00:00+00', '2012-01-20 12:54:51.227665+00', 'Mary Queen''s Strathspey', 316, '');
INSERT INTO 'tune' VALUES (9641, '2005-09-04 22:00:00+00', '2012-01-20 12:54:51.232153+00', 'Miss Anne Bradburn', 316, '');
INSERT INTO 'tune' VALUES (9642, '2005-09-04 22:00:00+00', '2012-01-20 12:54:51.235994+00', 'Radyr Welcome', 316, '');
INSERT INTO 'tune' VALUES (9643, '2005-09-24 22:00:00+00', '2012-01-20 12:54:51.239838+00', 'Odin Bay', 1580, '2005.  Bonskeid Music Ltd.');
INSERT INTO 'tune' VALUES (9644, '2005-09-24 22:00:00+00', '2012-01-20 12:54:51.243685+00', 'Bay of Holland', 1580, '2005.  Bonskeid Music Ltd.');
INSERT INTO 'tune' VALUES (9645, '2005-10-09 22:00:00+00', '2012-01-20 12:54:51.247525+00', 'Jean Martin of Aberdeen', 1502, '');
INSERT INTO 'tune' VALUES (9646, '2005-10-23 22:00:00+00', '2012-01-20 12:54:51.251357+00', 'Miss Rhoda MacDonald Stays at Home', 1759, '');
INSERT INTO 'tune' VALUES (9647, '2005-11-01 23:00:00+00', '2012-01-20 12:54:51.255195+00', 'Redwood Arbor', 2961, '');
INSERT INTO 'tune' VALUES (9648, '2005-11-01 23:00:00+00', '2012-01-20 12:54:51.259046+00', 'Dragon Tale', 2961, '');
INSERT INTO 'tune' VALUES (9649, '2005-11-01 23:00:00+00', '2012-01-20 12:54:51.263521+00', 'Dragonfly', 2961, '');
INSERT INTO 'tune' VALUES (9650, '2005-11-01 23:00:00+00', '2012-01-20 12:54:51.267506+00', 'Downey of Wellington', 2961, '');
INSERT INTO 'tune' VALUES (9651, '2005-11-01 23:00:00+00', '2012-01-20 12:54:51.271346+00', 'Ben Lomond Hornpipe', 2961, '');
INSERT INTO 'tune' VALUES (9652, '2005-11-01 23:00:00+00', '2012-01-20 12:54:51.275191+00', 'Isle of the Selkie', 2961, '');
INSERT INTO 'tune' VALUES (9653, '2005-11-01 23:00:00+00', '2012-01-20 12:54:51.279026+00', 'Aura', 2961, '');
INSERT INTO 'tune' VALUES (9654, '2005-11-01 23:00:00+00', '2012-01-20 12:54:51.282876+00', 'Golden Threads', 2961, '');
INSERT INTO 'tune' VALUES (9655, '2005-11-01 23:00:00+00', '2012-01-20 12:54:51.286717+00', 'Isle of the Selkie Waltz', 2961, '');
INSERT INTO 'tune' VALUES (9656, '2005-11-01 23:00:00+00', '2012-01-20 12:54:51.290578+00', 'Bonnie Colleen', 2961, '');
INSERT INTO 'tune' VALUES (9658, '2005-12-02 23:00:00+00', '2012-01-20 12:54:51.298276+00', 'Scottish Spirit, The', 1508, '');
INSERT INTO 'tune' VALUES (9660, NULL, '2012-01-20 12:54:51.30589+00', 'Lindsay Ross''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (9661, NULL, '2012-01-20 12:54:51.30969+00', 'Prince of Wales'' Jig, The', 9999, '');
INSERT INTO 'tune' VALUES (9662, NULL, '2012-01-20 12:54:51.313494+00', 'Scotstoun West', 1659, '');
INSERT INTO 'tune' VALUES (9663, NULL, '2012-01-20 12:54:51.31729+00', 'Lis Thomas''s Birthday', 9998, '');
INSERT INTO 'tune' VALUES (9664, NULL, '2012-01-20 12:54:51.321157+00', 'Matthew Robertson''s Hornpipe', 1899, '');
INSERT INTO 'tune' VALUES (9665, NULL, '2012-01-20 12:54:51.325006+00', 'Quaich, The', 1505, '');
INSERT INTO 'tune' VALUES (9666, NULL, '2012-01-20 12:54:51.328984+00', 'Colonel Baillie of Leys', 9999, '');
INSERT INTO 'tune' VALUES (9667, NULL, '2012-01-20 12:54:51.332794+00', 'George Wark', 1522, '');
INSERT INTO 'tune' VALUES (9668, NULL, '2012-01-20 12:54:51.336632+00', 'Brinkworth', 1543, '');
INSERT INTO 'tune' VALUES (9669, NULL, '2012-01-20 12:54:51.340527+00', 'Jaz Jig, The', 2744, '');
INSERT INTO 'tune' VALUES (9670, NULL, '2012-01-20 12:54:51.344336+00', 'Miss Judith Peterson', 1613, '');
INSERT INTO 'tune' VALUES (9671, NULL, '2012-01-20 12:54:51.348144+00', 'Gordon Jamieson''s Compliments to James Leask', 130, '');
INSERT INTO 'tune' VALUES (9672, NULL, '2012-01-20 12:54:51.351941+00', 'Pat''s Reel', 1677, '');
INSERT INTO 'tune' VALUES (9673, NULL, '2012-01-20 12:54:51.355753+00', 'Mike & Jenny Shaw''s Ruby Wedding', 1525, '');
INSERT INTO 'tune' VALUES (9674, NULL, '2012-01-20 12:54:51.359551+00', 'Jessie''s Whip', 3448, '');
INSERT INTO 'tune' VALUES (9675, NULL, '2012-01-20 12:54:51.36336+00', 'Farmer''s Ingle, The', 3615, '');
INSERT INTO 'tune' VALUES (9676, NULL, '2012-01-20 12:54:51.367169+00', 'Megan Andante', 1502, '');
INSERT INTO 'tune' VALUES (9677, NULL, '2012-01-20 12:54:51.37096+00', 'Mary''s Practice Scones', 3220, '');
INSERT INTO 'tune' VALUES (9678, NULL, '2012-01-20 12:54:51.374756+00', 'Jane Kerr''s Jig', 1575, '');
INSERT INTO 'tune' VALUES (9679, NULL, '2012-01-20 12:54:51.378544+00', 'Braes of Dunvegan, The', 9999, '');
INSERT INTO 'tune' VALUES (9680, NULL, '2012-01-20 12:54:51.382681+00', 'Famous Baravan, The', 3129, '');
INSERT INTO 'tune' VALUES (9681, NULL, '2012-01-20 12:54:51.386563+00', 'Pump it Out', 2656, '');
INSERT INTO 'tune' VALUES (9682, NULL, '2012-01-20 12:54:51.39036+00', 'Tam''s Rocking Fiddle', 1808, '');
INSERT INTO 'tune' VALUES (9684, NULL, '2012-01-20 12:54:51.397935+00', 'Alison Foss''s Strathspey', 1437, '');
INSERT INTO 'tune' VALUES (9685, '2006-02-15 23:00:00+00', '2012-01-20 12:54:51.401753+00', 'Wha''s at the Window', 9999, '');
INSERT INTO 'tune' VALUES (9686, NULL, '2012-01-20 12:54:51.405567+00', 'Pamela', 1437, '');
INSERT INTO 'tune' VALUES (9687, NULL, '2012-01-20 12:54:51.409373+00', 'David Grant Muir', 1437, '');
INSERT INTO 'tune' VALUES (9659, NULL, '2014-08-25 10:47:06.922052+00', 'Kilberry Ball, The', 10686, '');
INSERT INTO 'tune' VALUES (9688, NULL, '2012-01-20 12:54:51.413174+00', 'Jackie Johnstone''s Fancy', 1437, '');
INSERT INTO 'tune' VALUES (9689, NULL, '2012-01-20 12:54:51.416984+00', 'Mrs Jean Anderson''s Strathspey', 1437, '');
INSERT INTO 'tune' VALUES (9690, NULL, '2012-01-20 12:54:51.420781+00', 'Bill Little''s Fancy', 1437, '');
INSERT INTO 'tune' VALUES (9691, NULL, '2012-01-20 12:54:51.424588+00', 'Mrs A.S. Campbell''s Fancy', 1437, '');
INSERT INTO 'tune' VALUES (9692, NULL, '2012-01-20 12:54:51.428395+00', 'Mrs Alex Fraser''s Frolic', 1437, '');
INSERT INTO 'tune' VALUES (9693, '2006-02-15 23:00:00+00', '2012-01-20 12:54:51.432254+00', 'P/M David Kay', 1437, '');
INSERT INTO 'tune' VALUES (9694, '2006-02-16 23:00:00+00', '2012-01-20 12:54:51.436091+00', 'Captain Pryce Gordon', 1519, '');
INSERT INTO 'tune' VALUES (9695, '2006-02-16 23:00:00+00', '2012-01-20 12:54:51.439927+00', 'Babblin'' Brook, The', 1593, '');
INSERT INTO 'tune' VALUES (9696, '2006-02-16 23:00:00+00', '2012-01-20 12:54:51.443757+00', 'Jig for Archie', 1575, '');
INSERT INTO 'tune' VALUES (9697, '2006-02-16 23:00:00+00', '2012-01-20 12:54:51.447589+00', 'Maunby Reel, The', 1582, '');
INSERT INTO 'tune' VALUES (9698, '2006-02-16 23:00:00+00', '2012-01-20 12:54:51.45143+00', 'Paul & Wendy Ridley', 1593, '');
INSERT INTO 'tune' VALUES (9699, '2006-02-16 23:00:00+00', '2012-01-20 12:54:51.455276+00', 'Eddie Jackson', 1593, '');
INSERT INTO 'tune' VALUES (9700, '2006-02-16 23:00:00+00', '2012-01-20 12:54:51.459115+00', 'Old Fruitmarket, The', 3622, '');
INSERT INTO 'tune' VALUES (9701, '2006-02-16 23:00:00+00', '2012-01-20 12:54:51.462949+00', 'Jig for Annie', 1575, '');
INSERT INTO 'tune' VALUES (9702, '2006-02-16 23:00:00+00', '2012-01-20 12:54:51.466785+00', 'Golden Jubilee Reel 2, The', 1502, '');
INSERT INTO 'tune' VALUES (9703, NULL, '2012-01-20 12:54:51.470615+00', 'Charles Ogden''s Jig', 1501, '');
INSERT INTO 'tune' VALUES (9704, NULL, '2012-01-20 12:54:51.474418+00', 'Threshing Mill, The', 1501, '');
INSERT INTO 'tune' VALUES (9705, '2006-02-16 23:00:00+00', '2012-01-20 12:54:51.478291+00', 'Lesley and Bruce McLaren', 1579, '');
INSERT INTO 'tune' VALUES (9706, NULL, '2012-01-20 12:54:51.482401+00', 'Bobby Graham Esq', 1593, '');
INSERT INTO 'tune' VALUES (9707, NULL, '2012-01-20 12:54:51.486209+00', 'Reel for Shanus', 2253, '');
INSERT INTO 'tune' VALUES (9708, NULL, '2012-01-20 12:54:51.490066+00', 'Reel for Eilidh Shaw', 3654, '');
INSERT INTO 'tune' VALUES (9709, '2006-02-16 23:00:00+00', '2012-01-20 12:54:51.493881+00', 'Davey Masson', 1505, '');
INSERT INTO 'tune' VALUES (9710, NULL, '2012-01-20 12:54:51.497708+00', 'Pittencrieff Park', 3615, '');
INSERT INTO 'tune' VALUES (9711, NULL, '2012-01-20 12:54:51.501513+00', 'Loch Achray', 1610, '');
INSERT INTO 'tune' VALUES (9712, NULL, '2012-01-20 12:54:51.505312+00', 'Greig Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (9713, NULL, '2012-01-20 12:54:51.509112+00', 'Pall Mall', 9999, '');
INSERT INTO 'tune' VALUES (13860, '2018-03-30 09:38:34.195495+00', '2018-03-30 09:38:34.195495+00', 'I wish I was in Dixie', 11616, '');
INSERT INTO 'tune' VALUES (9715, NULL, '2012-01-20 12:54:51.51677+00', 'Miss Irene Whyte''s Strathspey', 2768, '');
INSERT INTO 'tune' VALUES (9716, NULL, '2012-01-20 12:54:51.520588+00', 'Fiddler''s Benefit', 2768, '');
INSERT INTO 'tune' VALUES (9717, NULL, '2012-01-20 12:54:51.524425+00', 'Issy''s Strathspey', 2768, '');
INSERT INTO 'tune' VALUES (9718, NULL, '2012-01-20 12:54:51.528334+00', 'Pantoch Way', 3655, '');
INSERT INTO 'tune' VALUES (9719, NULL, '2012-01-20 12:54:51.532128+00', 'Katrina', 2768, '');
INSERT INTO 'tune' VALUES (9721, NULL, '2012-01-20 12:54:51.539714+00', 'Derrick''s Jig', 3655, '');
INSERT INTO 'tune' VALUES (9723, NULL, '2012-01-20 12:54:51.547314+00', 'Elizabeth Miller''s Jig', 1764, '');
INSERT INTO 'tune' VALUES (9724, NULL, '2012-01-20 12:54:51.551526+00', 'Leslie Dunn', 3656, '');
INSERT INTO 'tune' VALUES (9725, NULL, '2012-01-20 12:54:51.555338+00', 'Boys of the Freugh', 1668, '');
INSERT INTO 'tune' VALUES (9726, NULL, '2012-01-20 12:54:51.559134+00', 'Jean McDonald MacLeod', 1543, '');
INSERT INTO 'tune' VALUES (9727, NULL, '2012-01-20 12:54:51.562933+00', 'Georgina Porter''s Jig', 2768, '');
INSERT INTO 'tune' VALUES (9728, NULL, '2012-01-20 12:54:51.566728+00', 'Jan''s Hornpipe', 1505, '');
INSERT INTO 'tune' VALUES (9729, NULL, '2012-01-20 12:54:51.570529+00', 'Alberta Experience', 1505, '');
INSERT INTO 'tune' VALUES (9730, NULL, '2012-01-20 12:54:51.574326+00', 'Debbie Anne''s Reel', 1645, '');
INSERT INTO 'tune' VALUES (9731, NULL, '2012-01-20 12:54:51.578137+00', 'Commodore, The', 1505, '');
INSERT INTO 'tune' VALUES (9732, NULL, '2012-01-20 12:54:51.581928+00', 'Glasgow Hare, The', 9999, '');
INSERT INTO 'tune' VALUES (9733, NULL, '2012-01-20 12:54:51.585729+00', 'Isla Neuk', 1804, '');
INSERT INTO 'tune' VALUES (9734, NULL, '2012-01-20 12:54:51.589559+00', 'Miss White''s Jig', 2612, '');
INSERT INTO 'tune' VALUES (9735, NULL, '2012-01-20 12:54:51.59337+00', 'Mr Peter Duff''s Favourite', 2613, '');
INSERT INTO 'tune' VALUES (9736, NULL, '2012-01-20 12:54:51.597187+00', 'Miss Graham of Park', 9998, '');
INSERT INTO 'tune' VALUES (9737, NULL, '2012-01-20 12:54:51.600995+00', 'Glen Esk', 2914, '');
INSERT INTO 'tune' VALUES (9738, NULL, '2012-01-20 12:54:51.604812+00', 'Jimmy Blue of Forgandenny', 1554, '');
INSERT INTO 'tune' VALUES (9739, NULL, '2012-01-20 12:54:51.608662+00', 'Mrs MacLean of Drummondsfold', 1554, '');
INSERT INTO 'tune' VALUES (9740, NULL, '2012-01-20 12:54:51.612479+00', 'Father Kelly''s Reel', 3657, '');
INSERT INTO 'tune' VALUES (9741, '2006-02-21 23:00:00+00', '2012-01-20 12:54:51.616299+00', 'Anda Campbell''s Frolic', 1591, '');
INSERT INTO 'tune' VALUES (9742, '2006-02-22 23:00:00+00', '2012-01-20 12:54:51.620131+00', 'Lauren''s Reel', 2914, '');
INSERT INTO 'tune' VALUES (9743, '2006-02-22 23:00:00+00', '2012-01-20 12:54:51.62396+00', 'Jig for Bette, A', 2914, '');
INSERT INTO 'tune' VALUES (9744, '2006-02-22 23:00:00+00', '2012-01-20 12:54:51.627811+00', 'Lady in a Shawl, The', 2914, '');
INSERT INTO 'tune' VALUES (9745, '2006-02-22 23:00:00+00', '2012-01-20 12:54:51.631653+00', 'Mrs Helen Atkinson of Brechin', 2914, '');
INSERT INTO 'tune' VALUES (9746, '2006-02-23 23:00:00+00', '2012-01-20 12:54:51.635485+00', 'Una''s Reel', 2914, '');
INSERT INTO 'tune' VALUES (9747, '2006-03-07 23:00:00+00', '2012-01-20 12:54:51.639327+00', 'Saint Columba''s Jig', 1526, '');
INSERT INTO 'tune' VALUES (9748, NULL, '2012-01-20 12:54:51.643146+00', 'Mr Stewart Junior of Carnock''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (9749, NULL, '2012-01-20 12:54:51.646963+00', 'Alex MacArthur of Biggar', 1554, '');
INSERT INTO 'tune' VALUES (9750, NULL, '2012-01-20 12:54:51.650773+00', 'Corstorphine Road', 3620, '');
INSERT INTO 'tune' VALUES (9752, NULL, '2012-01-20 12:54:51.658726+00', 'Arran Hills, The', 1603, '');
INSERT INTO 'tune' VALUES (9753, NULL, '2012-01-20 12:54:51.662654+00', 'Smokey Sausages', 3620, '');
INSERT INTO 'tune' VALUES (9754, NULL, '2012-01-20 12:54:51.666462+00', 'Ten Pound Cheque, The', 3620, '');
INSERT INTO 'tune' VALUES (9755, NULL, '2012-01-20 12:54:51.67027+00', 'Horse''s Well, The', 1907, '');
INSERT INTO 'tune' VALUES (9756, NULL, '2012-01-20 12:54:51.674064+00', 'Burn o'' Skaw, The', 9998, '');
INSERT INTO 'tune' VALUES (9757, NULL, '2012-01-20 12:54:51.677862+00', 'Strong Tea', 1554, '');
INSERT INTO 'tune' VALUES (9758, NULL, '2012-01-20 12:54:51.681664+00', 'Da Vinci Jig', 1983, '');
INSERT INTO 'tune' VALUES (9761, NULL, '2012-01-20 12:54:51.693165+00', 'Desert March, The', 1913, '');
INSERT INTO 'tune' VALUES (9762, NULL, '2012-01-20 12:54:51.696979+00', 'Starin'' Oot the Windae', 9998, '');
INSERT INTO 'tune' VALUES (9764, NULL, '2012-01-20 12:54:51.704582+00', 'Crossing to Jura', 9998, '');
INSERT INTO 'tune' VALUES (9765, NULL, '2012-01-20 12:54:51.708385+00', 'Walter Street', 9999, '');
INSERT INTO 'tune' VALUES (9766, NULL, '2012-01-20 12:54:51.712186+00', 'To the Ladies', 9999, '');
INSERT INTO 'tune' VALUES (9767, NULL, '2012-01-20 12:54:51.715986+00', 'New Strathspey', 1512, '');
INSERT INTO 'tune' VALUES (9768, NULL, '2012-01-20 12:54:51.719797+00', 'Johnny Gibb o'' Cushetneuk', 1512, '');
INSERT INTO 'tune' VALUES (9769, '2006-04-02 22:00:00+00', '2012-01-20 12:54:51.723617+00', 'Dark Mourne', 3672, '');
INSERT INTO 'tune' VALUES (9770, '2006-04-02 22:00:00+00', '2012-01-20 12:54:51.727478+00', 'Gap Range', 3672, '');
INSERT INTO 'tune' VALUES (9771, NULL, '2012-01-20 12:54:51.731299+00', 'Jappy''s Grand March, The', 2085, '');
INSERT INTO 'tune' VALUES (9772, NULL, '2012-01-20 12:54:51.735115+00', 'Inter-Continental Gathering Toronto, The', 2258, '');
INSERT INTO 'tune' VALUES (9773, NULL, '2012-01-20 12:54:51.738927+00', 'Hill 212', 3675, '');
INSERT INTO 'tune' VALUES (9759, NULL, '2022-12-19 17:40:53.842936+00', 'Ian and Joan McKenzie''s Strathspey', 1527, '');
INSERT INTO 'tune' VALUES (9774, NULL, '2012-01-20 12:54:51.742733+00', 'My Gentle Milkmaid', 9999, '');
INSERT INTO 'tune' VALUES (9775, NULL, '2012-01-20 12:54:51.746611+00', 'Weary With You All The Day', 9999, '');
INSERT INTO 'tune' VALUES (10196, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.396084+00', 'Zola', 1591, '');
INSERT INTO 'tune' VALUES (9776, NULL, '2012-01-20 12:54:51.750449+00', 'Maid at the Well, The', 9999, '');
INSERT INTO 'tune' VALUES (9777, NULL, '2012-01-20 12:54:51.754251+00', 'You''re Welcome Jimmy Shand', 3676, '');
INSERT INTO 'tune' VALUES (9778, NULL, '2012-01-20 12:54:51.758051+00', 'Scotsman''s Secret, The', 3677, '');
INSERT INTO 'tune' VALUES (9779, NULL, '2012-01-20 12:54:51.761853+00', 'Glengary''s Dirk', 9999, '');
INSERT INTO 'tune' VALUES (9780, NULL, '2012-01-20 12:54:51.765669+00', 'Captain Robertson Ludes', 9999, '');
INSERT INTO 'tune' VALUES (9781, NULL, '2012-01-20 12:54:51.769481+00', 'Mrs R Donaldson', 9999, '');
INSERT INTO 'tune' VALUES (9782, NULL, '2012-01-20 12:54:51.773294+00', 'Miss Crawford''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (9783, NULL, '2012-01-20 12:54:51.777156+00', 'Endearing Young Charms', 9999, '');
INSERT INTO 'tune' VALUES (9784, NULL, '2012-01-20 12:54:51.781051+00', 'Mr Bell Esq.', 2085, '');
INSERT INTO 'tune' VALUES (9785, NULL, '2012-01-20 12:54:51.784861+00', 'Big Barney', 9999, '');
INSERT INTO 'tune' VALUES (9786, NULL, '2012-01-20 12:54:51.788678+00', 'Brown-Eyed Kate', 9999, '');
INSERT INTO 'tune' VALUES (9787, NULL, '2012-01-20 12:54:51.792482+00', 'Three a Penny', 9999, '');
INSERT INTO 'tune' VALUES (9788, NULL, '2012-01-20 12:54:51.796282+00', 'Fiddler''s Contest, The', 9999, '');
INSERT INTO 'tune' VALUES (9789, NULL, '2012-01-20 12:54:51.800092+00', 'Bobby''s Strange Wee Jig', 2085, '');
INSERT INTO 'tune' VALUES (9790, NULL, '2012-01-20 12:54:51.803893+00', 'Kitty Come Over', 9999, '');
INSERT INTO 'tune' VALUES (9791, NULL, '2012-01-20 12:54:51.807685+00', 'Boys of Coomanore, The', 9999, '');
INSERT INTO 'tune' VALUES (9792, NULL, '2012-01-20 12:54:51.811486+00', 'Tongs by the Fire, The', 9999, '');
INSERT INTO 'tune' VALUES (9793, NULL, '2012-01-20 12:54:51.815286+00', 'Val and Gertrude Henderson', 2054, '');
INSERT INTO 'tune' VALUES (9794, NULL, '2012-01-20 12:54:51.819097+00', 'Hynd''s Wee Cabin', 1512, '');
INSERT INTO 'tune' VALUES (9795, NULL, '2012-01-20 12:54:51.822901+00', 'My Lovely Miss Muffet', 2085, '');
INSERT INTO 'tune' VALUES (9796, NULL, '2012-01-20 12:54:51.826704+00', 'Move Up to Me', 9999, '');
INSERT INTO 'tune' VALUES (9797, NULL, '2012-01-20 12:54:51.830556+00', 'Dunderave', 9999, '');
INSERT INTO 'tune' VALUES (9798, NULL, '2012-01-20 12:54:51.834365+00', 'Loch Duich', 9999, '');
INSERT INTO 'tune' VALUES (9799, NULL, '2012-01-20 12:54:51.838171+00', 'Carles wi'' the Breeks, The', 9999, '');
INSERT INTO 'tune' VALUES (9800, '2006-04-27 22:00:00+00', '2012-01-20 12:54:51.841992+00', 'Reel of FIre, The', 1437, '');
INSERT INTO 'tune' VALUES (9801, '2006-05-11 22:00:00+00', '2012-01-20 12:54:51.845825+00', 'Come Along and Dance', 1445, '');
INSERT INTO 'tune' VALUES (9802, '2006-05-11 22:00:00+00', '2012-01-20 12:54:51.84967+00', 'Kay and Keith Dixon', 1445, '');
INSERT INTO 'tune' VALUES (9803, '2006-05-11 22:00:00+00', '2012-01-20 12:54:51.853503+00', 'Crafty Fisher, The', 1445, '');
INSERT INTO 'tune' VALUES (13738, '2017-11-10 16:46:23.676366+00', '2017-11-10 16:46:23.676366+00', 'For Ann', 2054, '');
INSERT INTO 'tune' VALUES (9804, '2006-05-11 22:00:00+00', '2012-01-20 12:54:51.857411+00', 'Sound Technician, The', 1445, '');
INSERT INTO 'tune' VALUES (9805, '2006-05-11 22:00:00+00', '2012-01-20 12:54:51.861261+00', 'Joanna''s Reel', 1445, '');
INSERT INTO 'tune' VALUES (9806, '2006-05-11 22:00:00+00', '2012-01-20 12:54:51.865098+00', 'Compiments to Martina', 1445, '');
INSERT INTO 'tune' VALUES (9807, '2006-05-11 22:00:00+00', '2012-01-20 12:54:51.868936+00', 'Halfway to Silver', 1445, '');
INSERT INTO 'tune' VALUES (9808, '2006-05-11 22:00:00+00', '2012-01-20 12:54:51.873213+00', 'Road to Achiltibuie, The', 1445, '');
INSERT INTO 'tune' VALUES (9809, '2006-05-11 22:00:00+00', '2012-01-20 12:54:51.877051+00', 'Sheena''s Fiddle', 1445, '');
INSERT INTO 'tune' VALUES (9810, '2006-05-11 22:00:00+00', '2012-01-20 12:54:51.880982+00', 'Slightly Inebriated', 1445, '');
INSERT INTO 'tune' VALUES (9811, '2006-05-11 22:00:00+00', '2012-01-20 12:54:51.884869+00', 'Off to Gretna', 1445, '');
INSERT INTO 'tune' VALUES (9812, '2006-05-11 22:00:00+00', '2012-01-20 12:54:51.888724+00', 'Rivella Reel, The', 1445, '');
INSERT INTO 'tune' VALUES (9813, '2006-05-11 22:00:00+00', '2012-01-20 12:54:51.892561+00', 'Gigue from Suite 3 BWV 1068', 3680, '');
INSERT INTO 'tune' VALUES (9814, '2006-05-11 22:00:00+00', '2012-01-20 12:54:51.896399+00', 'Dorsetshire Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (9815, NULL, '2012-01-20 12:54:51.90022+00', 'Johnston''s Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (9816, '2006-05-21 22:00:00+00', '2012-01-20 12:54:51.904036+00', 'Mr & Mrs Derek Cochrane', 3683, '');
INSERT INTO 'tune' VALUES (9817, '2006-05-21 22:00:00+00', '2012-01-20 12:54:51.907865+00', 'Hazel Hall of Tayport', 3683, '');
INSERT INTO 'tune' VALUES (9818, '2006-05-21 22:00:00+00', '2012-01-20 12:54:51.911701+00', 'Harry Hall of Tayport', 3683, '');
INSERT INTO 'tune' VALUES (9819, '2006-05-21 22:00:00+00', '2012-01-20 12:54:51.915546+00', 'Fiona Mackie''s Jig', 3683, '');
INSERT INTO 'tune' VALUES (9820, '2006-05-21 22:00:00+00', '2012-01-20 12:54:51.919488+00', 'Andrea Strath, The', 3683, '');
INSERT INTO 'tune' VALUES (9821, '2006-05-21 22:00:00+00', '2012-01-20 12:54:51.923316+00', 'Fiona Paulin''s Bairns', 3683, '');
INSERT INTO 'tune' VALUES (9822, '2006-05-21 22:00:00+00', '2012-01-20 12:54:51.927234+00', 'Jim Healy Jig, The', 3683, '');
INSERT INTO 'tune' VALUES (9823, '2006-05-21 22:00:00+00', '2012-01-20 12:54:51.931061+00', 'Tom McLeod''s Strathspey', 3683, '');
INSERT INTO 'tune' VALUES (9824, '2006-05-21 22:00:00+00', '2012-01-20 12:54:51.934881+00', 'Mary Currie''s Marryat Dances', 3683, '');
INSERT INTO 'tune' VALUES (9825, '2006-05-21 22:00:00+00', '2012-01-20 12:54:51.938721+00', 'Shirley Mackie''s Jig', 3683, '');
INSERT INTO 'tune' VALUES (9826, '2006-05-21 22:00:00+00', '2012-01-20 12:54:51.942548+00', 'Tribute to Luke Brady', 3684, '');
INSERT INTO 'tune' VALUES (9827, NULL, '2012-01-20 12:54:51.946359+00', 'Reel de Skieurs', 9998, '');
INSERT INTO 'tune' VALUES (9828, NULL, '2012-01-20 12:54:51.950157+00', 'Ann Fraser MacKenzie', 3058, '');
INSERT INTO 'tune' VALUES (13861, '2018-03-31 10:55:57.563595+00', '2018-03-31 10:55:57.563595+00', 'Dhu Lock Cottage', 11617, '');
INSERT INTO 'tune' VALUES (9831, NULL, '2012-01-20 12:54:51.961559+00', 'Donald', 9998, '');
INSERT INTO 'tune' VALUES (9833, NULL, '2012-01-20 12:54:51.969172+00', 'Rosin the Bow', 9999, '');
INSERT INTO 'tune' VALUES (9835, NULL, '2012-01-20 12:54:51.976784+00', 'Fiona Whitton''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (9836, NULL, '2012-01-20 12:54:51.980585+00', 'Dancing Master, The', 9998, '');
INSERT INTO 'tune' VALUES (9837, NULL, '2012-01-20 12:54:51.984384+00', 'M''Hat Blew Aff', 10250, '');
INSERT INTO 'tune' VALUES (9838, NULL, '2012-01-20 12:54:51.988187+00', 'Technique Teacher, The', 9998, '');
INSERT INTO 'tune' VALUES (9839, '2006-05-31 22:00:00+00', '2012-01-20 12:54:51.992007+00', 'Mrs Davidson of Cantray', 9999, '');
INSERT INTO 'tune' VALUES (9840, '2006-06-15 22:00:00+00', '2012-01-20 12:54:51.995846+00', 'Welcome Hame the Ploughman', 1764, '');
INSERT INTO 'tune' VALUES (9841, '2006-06-16 22:00:00+00', '2012-01-20 12:54:51.999676+00', 'Jack Stalker''s Compliments to Jessie Bain', 1679, '');
INSERT INTO 'tune' VALUES (9842, '2006-06-16 22:00:00+00', '2012-01-20 12:54:52.003521+00', 'Travelling to America', 2856, '');
INSERT INTO 'tune' VALUES (9843, '2006-06-16 22:00:00+00', '2012-01-20 12:54:52.007463+00', 'Modley House', 1586, '');
INSERT INTO 'tune' VALUES (9844, '2006-06-16 22:00:00+00', '2012-01-20 12:54:52.011306+00', 'Glenrothes, The', 1586, '');
INSERT INTO 'tune' VALUES (9845, '2006-06-16 22:00:00+00', '2012-01-20 12:54:52.015153+00', 'Walter and Betty Rutherford', 1626, '');
INSERT INTO 'tune' VALUES (9846, '2006-06-16 22:00:00+00', '2012-01-20 12:54:52.018993+00', 'Tripitup Troupe, The', 1572, '');
INSERT INTO 'tune' VALUES (9847, '2006-06-25 22:00:00+00', '2012-01-20 12:54:52.02283+00', 'Eileen Watt', 1502, '');
INSERT INTO 'tune' VALUES (9848, NULL, '2012-01-20 12:54:52.026658+00', 'Evondale', 1725, '');
INSERT INTO 'tune' VALUES (9849, NULL, '2012-01-20 12:54:52.030455+00', 'Craigieford', 2948, '');
INSERT INTO 'tune' VALUES (9850, NULL, '2012-01-20 12:54:52.034253+00', 'Skibereen', 9999, '');
INSERT INTO 'tune' VALUES (9851, NULL, '2012-01-20 12:54:52.038042+00', 'Signal Fires', 9999, '');
INSERT INTO 'tune' VALUES (9852, NULL, '2012-01-20 12:54:52.041863+00', 'Delicate Wee Cratur', 1796, '');
INSERT INTO 'tune' VALUES (9853, NULL, '2012-01-20 12:54:52.045678+00', 'Miss Grace Hay''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (9855, NULL, '2012-01-20 12:54:52.053287+00', 'Miss Fay Sharp', 1576, '');
INSERT INTO 'tune' VALUES (9856, NULL, '2012-01-20 12:54:52.057096+00', 'Durness Reel', 9999, '');
INSERT INTO 'tune' VALUES (9857, NULL, '2012-01-20 12:54:52.060911+00', 'One For The Record', 3692, '');
INSERT INTO 'tune' VALUES (9858, NULL, '2012-01-20 12:54:52.064727+00', 'Tom & Joyce Dewar', 1591, '');
INSERT INTO 'tune' VALUES (9859, NULL, '2012-01-20 12:54:52.068527+00', 'Doonbank Reel, The', 1575, '');
INSERT INTO 'tune' VALUES (9860, NULL, '2012-01-20 12:54:52.072333+00', 'Westfield Strathspey', 1668, '');
INSERT INTO 'tune' VALUES (9832, NULL, '2012-02-06 11:25:29.622625+00', 'Peter Flett of Tarabuckle', 2516, '');
INSERT INTO 'tune' VALUES (9829, NULL, '2013-01-06 17:18:58.806102+00', 'Currie Bridge', 1538, '');
INSERT INTO 'tune' VALUES (9861, NULL, '2012-01-20 12:54:52.076131+00', 'Bob Comrie the Hen Man', 1591, '');
INSERT INTO 'tune' VALUES (9862, NULL, '2012-01-20 12:54:52.079962+00', 'Carolyn''s Jig', 1835, '');
INSERT INTO 'tune' VALUES (9864, NULL, '2012-01-20 12:54:52.087574+00', 'Scott & Kara Haggart', 1591, '');
INSERT INTO 'tune' VALUES (9865, NULL, '2012-01-20 12:54:52.091368+00', 'Granny Brewster''s Reel', 1591, '');
INSERT INTO 'tune' VALUES (9866, NULL, '2012-01-20 12:54:52.09551+00', 'Bryan Gear''s Reel', 3693, '');
INSERT INTO 'tune' VALUES (9867, NULL, '2012-01-20 12:54:52.099329+00', 'Lorna''s Reel', 1677, '');
INSERT INTO 'tune' VALUES (9868, NULL, '2012-01-20 12:54:52.103129+00', 'Welcome Home Duncan', 1605, '');
INSERT INTO 'tune' VALUES (9869, '2006-07-27 22:00:00+00', '2012-01-20 12:54:52.106946+00', 'Clare''s Dance', 1582, '');
INSERT INTO 'tune' VALUES (9870, '2006-08-24 22:00:00+00', '2012-01-20 12:54:52.110792+00', 'Peddie Johnnie', 9998, '');
INSERT INTO 'tune' VALUES (9871, '2006-08-24 22:00:00+00', '2012-01-20 12:54:52.114655+00', 'Bridge of Canny', 9998, '');
INSERT INTO 'tune' VALUES (9872, NULL, '2012-01-20 12:54:52.118477+00', 'Iain and Kathleen''s Silver Wedding', 3701, '');
INSERT INTO 'tune' VALUES (9873, NULL, '2012-01-20 12:54:52.12277+00', 'Morag''s Spicy Rum', 3701, '');
INSERT INTO 'tune' VALUES (9874, NULL, '2012-01-20 12:54:52.126931+00', 'Iain MacPhail''s Welcome to Shetland', 1645, '');
INSERT INTO 'tune' VALUES (9875, NULL, '2012-01-20 12:54:52.130782+00', 'Rock Valley', 3702, '');
INSERT INTO 'tune' VALUES (9876, NULL, '2012-01-20 12:54:52.134588+00', 'Just a Jig', 1660, '');
INSERT INTO 'tune' VALUES (9877, NULL, '2012-01-20 12:54:52.138389+00', 'Captain McGuire', 9999, '');
INSERT INTO 'tune' VALUES (9863, NULL, '2022-12-23 13:36:10.295064+00', 'Auld Man, Da', 10086, '');
INSERT INTO 'tune' VALUES (9879, NULL, '2012-01-20 12:54:52.145982+00', 'Silver Wedding Waltz', 1554, '');
INSERT INTO 'tune' VALUES (9880, NULL, '2012-01-20 12:54:52.149771+00', 'Carla''s Spicy Pizza', 1590, '');
INSERT INTO 'tune' VALUES (3665, NULL, '2013-09-29 21:24:06.366088+00', 'Buccleuch', 781, '');
INSERT INTO 'tune' VALUES (9882, NULL, '2012-01-20 12:54:52.157381+00', 'Miss Judith Robertson of Thame', 9998, '');
INSERT INTO 'tune' VALUES (9883, NULL, '2012-01-20 12:54:52.161189+00', 'Ian Muir''s Compliments to Ann Dix', 1590, '');
INSERT INTO 'tune' VALUES (9884, '2006-09-12 22:00:00+00', '2012-01-20 12:54:52.165054+00', 'Petit Chat Celtique, Le', 2961, '');
INSERT INTO 'tune' VALUES (9885, '2006-09-12 22:00:00+00', '2012-01-20 12:54:52.168908+00', 'Alphadoddle', 2961, '');
INSERT INTO 'tune' VALUES (9886, '2006-09-12 22:00:00+00', '2012-01-20 12:54:52.172741+00', 'Borders, The', 2961, '');
INSERT INTO 'tune' VALUES (9887, '2006-09-12 22:00:00+00', '2012-01-20 12:54:52.176578+00', 'Fyrefly Jig', 2961, '');
INSERT INTO 'tune' VALUES (9888, '2006-09-12 22:00:00+00', '2012-01-20 12:54:52.18041+00', 'Teinntean', 2961, '');
INSERT INTO 'tune' VALUES (9889, '2006-09-12 22:00:00+00', '2012-01-20 12:54:52.184266+00', 'Gigue du Chat, La', 2961, '');
INSERT INTO 'tune' VALUES (9890, '2006-09-12 22:00:00+00', '2012-01-20 12:54:52.188103+00', 'Harp Strings', 2961, '');
INSERT INTO 'tune' VALUES (9891, '2006-09-12 22:00:00+00', '2012-01-20 12:54:52.19193+00', 'Belle Femme de Bretagne', 2961, '');
INSERT INTO 'tune' VALUES (9892, '2006-09-12 22:00:00+00', '2012-01-20 12:54:52.195762+00', 'Urram', 2961, '');
INSERT INTO 'tune' VALUES (9893, '2006-09-12 22:00:00+00', '2012-01-20 12:54:52.199597+00', 'Kata', 2961, '');
INSERT INTO 'tune' VALUES (9894, '2006-09-12 22:00:00+00', '2012-01-20 12:54:52.203443+00', 'Downey of Wellington, NZ', 2961, '');
INSERT INTO 'tune' VALUES (9896, '2006-09-12 22:00:00+00', '2012-01-20 12:54:52.211109+00', 'Spinning Tails', 2961, '');
INSERT INTO 'tune' VALUES (9897, '2006-09-13 22:00:00+00', '2012-01-20 12:54:52.214932+00', 'Baiser de Chocolat, Un', 2961, '');
INSERT INTO 'tune' VALUES (9898, NULL, '2012-01-20 12:54:52.218738+00', 'Kangaroo Paw, The', 3220, '');
INSERT INTO 'tune' VALUES (10005, NULL, '2012-01-20 12:54:52.639656+00', 'Sandra''s Air', 2768, '');
INSERT INTO 'tune' VALUES (9899, NULL, '2012-01-20 12:54:52.222536+00', 'Smith''s Black Beauty', 1808, '');
INSERT INTO 'tune' VALUES (9900, NULL, '2012-01-20 12:54:52.226344+00', 'Tam''s Mandolin Magic', 1808, '');
INSERT INTO 'tune' VALUES (9901, NULL, '2012-01-20 12:54:52.230146+00', 'Speed Hump', 3220, '');
INSERT INTO 'tune' VALUES (9902, NULL, '2012-01-20 12:54:52.233932+00', 'Log Splitters Jig, The', 1761, '');
INSERT INTO 'tune' VALUES (9903, NULL, '2012-01-20 12:54:52.237806+00', 'Dundreggan Jig', 1808, '');
INSERT INTO 'tune' VALUES (9904, NULL, '2012-01-20 12:54:52.241605+00', 'Christine''s Fancy', 3220, '');
INSERT INTO 'tune' VALUES (9905, NULL, '2012-01-20 12:54:52.245413+00', 'Wriggling Rag Worm, The', 1938, '');
INSERT INTO 'tune' VALUES (9906, NULL, '2012-01-20 12:54:52.249204+00', 'M.V. Reel, The', 1938, '');
INSERT INTO 'tune' VALUES (9908, NULL, '2012-01-20 12:54:52.256794+00', 'Corsick Hill', 3710, '');
INSERT INTO 'tune' VALUES (9909, NULL, '2012-01-20 12:54:52.260598+00', 'Maggie''s Reel', 1623, '');
INSERT INTO 'tune' VALUES (9910, NULL, '2012-01-20 12:54:52.264396+00', 'Fraser Pattullo''s Jig', 1811, '');
INSERT INTO 'tune' VALUES (9911, NULL, '2012-01-20 12:54:52.268203+00', 'Kilberry Jig', 1527, '');
INSERT INTO 'tune' VALUES (9912, NULL, '2012-01-20 12:54:52.272008+00', 'Ann Naismith''s Strathspey', 3220, '');
INSERT INTO 'tune' VALUES (9895, '2006-09-12 22:00:00+00', '2012-09-28 13:39:32.512873+00', 'Tuilidh', 2961, '');
INSERT INTO 'tune' VALUES (9913, NULL, '2012-01-20 12:54:52.275815+00', 'Pamela Rose Grant', 1782, '');
INSERT INTO 'tune' VALUES (9914, NULL, '2012-01-20 12:54:52.279705+00', 'Partners in Time', 1878, '');
INSERT INTO 'tune' VALUES (9915, NULL, '2012-01-20 12:54:52.283516+00', 'Going to the Well for a Drink of Water', 9999, '');
INSERT INTO 'tune' VALUES (9916, NULL, '2012-01-20 12:54:52.287325+00', 'Nelson Mandela''s Welcome to the City of Glasgow', 2509, '');
INSERT INTO 'tune' VALUES (9917, NULL, '2012-01-20 12:54:52.291155+00', 'Aunt Mary''s Canadian Jig', 9999, '');
INSERT INTO 'tune' VALUES (9918, NULL, '2012-01-20 12:54:52.294964+00', 'Dilbert''s Jig', 1765, '');
INSERT INTO 'tune' VALUES (9919, NULL, '2012-01-20 12:54:52.298767+00', 'Alasdair MacAlister', 9998, '');
INSERT INTO 'tune' VALUES (9920, NULL, '2012-01-20 12:54:52.302576+00', 'Ruffians Rant', 9999, '');
INSERT INTO 'tune' VALUES (9921, NULL, '2012-01-20 12:54:52.306381+00', 'Mr Patrick Duff''s Favourite', 1928, '');
INSERT INTO 'tune' VALUES (9922, NULL, '2012-01-20 12:54:52.310288+00', 'Bridge of Bamore', 9999, '');
INSERT INTO 'tune' VALUES (9923, NULL, '2012-01-20 12:54:52.314087+00', 'Rise Ye Lazy Lubber', 9999, '');
INSERT INTO 'tune' VALUES (9925, NULL, '2012-01-20 12:54:52.3217+00', 'Catherine''s Waltz', 1763, '');
INSERT INTO 'tune' VALUES (9926, NULL, '2012-01-20 12:54:52.325501+00', 'Lessley House Quickstep', 1695, '');
INSERT INTO 'tune' VALUES (9927, NULL, '2012-01-20 12:54:52.329405+00', 'Miss Johnstone of Lathrisk', 1519, '');
INSERT INTO 'tune' VALUES (9928, NULL, '2012-01-20 12:54:52.333207+00', 'Lady Louisa Gordon', 1519, '');
INSERT INTO 'tune' VALUES (9929, NULL, '2012-01-20 12:54:52.337006+00', 'Lord John Scott', 1516, '');
INSERT INTO 'tune' VALUES (9930, NULL, '2012-01-20 12:54:52.340821+00', 'Euan S Reid of Newburgh', 3716, '');
INSERT INTO 'tune' VALUES (9931, NULL, '2012-01-20 12:54:52.344689+00', 'Hop Scotch', 1836, '');
INSERT INTO 'tune' VALUES (9932, NULL, '2012-01-20 12:54:52.348489+00', 'Peter & Doreen Chiasson', 1791, '');
INSERT INTO 'tune' VALUES (9933, NULL, '2012-01-20 12:54:52.35229+00', 'Craig''s 21st', 2768, '');
INSERT INTO 'tune' VALUES (9934, NULL, '2012-01-20 12:54:52.356105+00', 'Memories of Gordon', 2768, '');
INSERT INTO 'tune' VALUES (9935, NULL, '2012-01-20 12:54:52.359907+00', 'Callum Reid of Connel', 3716, '');
INSERT INTO 'tune' VALUES (9936, NULL, '2012-01-20 12:54:52.363704+00', 'Ishbell''s Reel', 3186, '');
INSERT INTO 'tune' VALUES (9937, NULL, '2012-01-20 12:54:52.367495+00', 'Rib Tickler, The', 3186, '');
INSERT INTO 'tune' VALUES (9938, NULL, '2012-01-20 12:54:52.371303+00', 'Links Reel, The', 3186, '');
INSERT INTO 'tune' VALUES (9939, NULL, '2012-01-20 12:54:52.375118+00', 'Clay Pigeon Boxer, The', 1507, '');
INSERT INTO 'tune' VALUES (9940, NULL, '2012-01-20 12:54:52.378922+00', 'Dixon Quads, The', 1508, '');
INSERT INTO 'tune' VALUES (9941, NULL, '2012-01-20 12:54:52.382714+00', 'Grumpy Gentleman, The', 1508, '');
INSERT INTO 'tune' VALUES (9942, NULL, '2012-01-20 12:54:52.386502+00', 'Floosie''s Reel', 1508, '');
INSERT INTO 'tune' VALUES (9943, NULL, '2012-01-20 12:54:52.390301+00', 'Lady Clare', 9999, '');
INSERT INTO 'tune' VALUES (9944, NULL, '2012-01-20 12:54:52.39409+00', 'Spring Fever', 1836, '');
INSERT INTO 'tune' VALUES (9945, NULL, '2012-01-20 12:54:52.397876+00', 'Pay as You Go', 9999, '');
INSERT INTO 'tune' VALUES (9947, '2006-10-19 22:00:00+00', '2012-01-20 12:54:52.405531+00', 'Cary Cemeteries, The', 3383, '');
INSERT INTO 'tune' VALUES (9948, '2006-10-19 22:00:00+00', '2012-01-20 12:54:52.409373+00', 'Graceful Young Woman, The', 3383, '');
INSERT INTO 'tune' VALUES (9949, '2006-10-19 22:00:00+00', '2012-01-20 12:54:52.413203+00', 'Corriejukit', 3383, '');
INSERT INTO 'tune' VALUES (9950, '2006-10-19 22:00:00+00', '2012-01-20 12:54:52.417037+00', 'Dance Gypsies', 3383, '');
INSERT INTO 'tune' VALUES (9951, '2006-10-19 22:00:00+00', '2012-01-20 12:54:52.420864+00', 'Jarnovich''s Reel', 1934, '');
INSERT INTO 'tune' VALUES (9952, '2006-10-19 22:00:00+00', '2012-01-20 12:54:52.424702+00', 'Irish in the Rain', 3383, '');
INSERT INTO 'tune' VALUES (9953, '2006-10-19 22:00:00+00', '2012-01-20 12:54:52.428537+00', 'My Cary Valentine', 3383, '');
INSERT INTO 'tune' VALUES (9954, '2006-10-19 22:00:00+00', '2012-01-20 12:54:52.432392+00', 'Sylvan Lake', 3383, '');
INSERT INTO 'tune' VALUES (9955, '2006-10-19 22:00:00+00', '2012-01-20 12:54:52.436233+00', 'Falls of Moira, The', 3383, '');
INSERT INTO 'tune' VALUES (9956, '2006-10-20 22:00:00+00', '2012-01-20 12:54:52.440064+00', 'Thistle turns Silver, The', 3383, '');
INSERT INTO 'tune' VALUES (9957, '2006-10-22 22:00:00+00', '2012-01-20 12:54:52.443898+00', 'Tulips from Amsterdam', 9998, '');
INSERT INTO 'tune' VALUES (9958, NULL, '2012-01-20 12:54:52.44771+00', 'Sunshine''s Wedding', 1501, '');
INSERT INTO 'tune' VALUES (9959, NULL, '2012-01-20 12:54:52.451512+00', 'Val & John Morris'' Jig', 1501, '');
INSERT INTO 'tune' VALUES (9960, NULL, '2012-01-20 12:54:52.45532+00', 'Menstrie Burn', 1533, '');
INSERT INTO 'tune' VALUES (9961, NULL, '2012-01-20 12:54:52.45911+00', 'Declan Walsh''s Jig', 1501, '');
INSERT INTO 'tune' VALUES (9962, NULL, '2012-01-20 12:54:52.462943+00', 'Alex Smith''s Reel', 1501, '');
INSERT INTO 'tune' VALUES (9963, NULL, '2012-01-20 12:54:52.466823+00', 'Rattagan Ridge', 3725, '');
INSERT INTO 'tune' VALUES (9964, NULL, '2012-01-20 12:54:52.470627+00', 'Egg and the Fiddle', 1673, '');
INSERT INTO 'tune' VALUES (9965, NULL, '2012-01-20 12:54:52.474454+00', 'Twa Sharps'' Reel', 1501, '');
INSERT INTO 'tune' VALUES (9966, '2006-10-26 22:00:00+00', '2012-01-20 12:54:52.478269+00', 'Clitheroe Castle', 316, '');
INSERT INTO 'tune' VALUES (9967, '2006-10-30 23:00:00+00', '2012-01-20 12:54:52.482107+00', 'Susie Langdon Kass', 1502, '');
INSERT INTO 'tune' VALUES (9968, '2006-10-31 23:00:00+00', '2012-01-20 12:54:52.485939+00', 'Farewell to Tchernobyle', 3104, '');
INSERT INTO 'tune' VALUES (9969, '2006-10-31 23:00:00+00', '2012-01-20 12:54:52.48977+00', 'Woody Woodpecker, The', 1593, '');
INSERT INTO 'tune' VALUES (9970, '2006-11-01 23:00:00+00', '2012-01-20 12:54:52.493596+00', 'Night We Reversed the Curse, The', 3722, '');
INSERT INTO 'tune' VALUES (9971, '2006-11-01 23:00:00+00', '2012-01-20 12:54:52.497427+00', 'Just a Lark', 3333, '');
INSERT INTO 'tune' VALUES (9972, '2006-11-02 23:00:00+00', '2012-01-20 12:54:52.501271+00', 'Demure Annie', 3282, '');
INSERT INTO 'tune' VALUES (9973, '2006-11-05 23:00:00+00', '2012-01-20 12:54:52.505095+00', 'Temple House', 9999, '');
INSERT INTO 'tune' VALUES (9974, '2006-11-10 23:00:00+00', '2012-01-20 12:54:52.508929+00', 'Miss Wright of Durham', 3727, '');
INSERT INTO 'tune' VALUES (9975, '2006-11-10 23:00:00+00', '2012-01-20 12:54:52.5128+00', 'Last Minute Reel', 3731, '');
INSERT INTO 'tune' VALUES (9976, '2006-11-10 23:00:00+00', '2012-01-20 12:54:52.516612+00', 'Just Jane', 3731, '');
INSERT INTO 'tune' VALUES (9977, '2006-11-10 23:00:00+00', '2012-01-20 12:54:52.520426+00', 'Dr Pete', 3731, '');
INSERT INTO 'tune' VALUES (9978, '2006-11-19 23:00:00+00', '2012-01-20 12:54:52.524283+00', 'Simple Gifts', 9998, '');
INSERT INTO 'tune' VALUES (9979, '2006-11-22 23:00:00+00', '2012-01-20 12:54:52.528276+00', 'Hyperactive Reel, The', 3737, '');
INSERT INTO 'tune' VALUES (9980, '2006-11-26 23:00:00+00', '2012-01-20 12:54:52.532119+00', 'Cuckoo Reel', 9999, '');
INSERT INTO 'tune' VALUES (9981, NULL, '2012-01-20 12:54:52.536047+00', 'Brig on the Waves', 1511, '');
INSERT INTO 'tune' VALUES (9982, NULL, '2012-01-20 12:54:52.539879+00', 'Day We Went to Rothesay, O, The', 9999, '');
INSERT INTO 'tune' VALUES (9983, NULL, '2012-01-20 12:54:52.543728+00', 'Pint of Derby, A', 9999, '');
INSERT INTO 'tune' VALUES (9924, NULL, '2022-11-01 12:10:44.644121+00', 'I Winna Gae to Bed until I''m Married', 9999, '');
INSERT INTO 'tune' VALUES (9984, NULL, '2012-01-20 12:54:52.547604+00', 'Woman of the House', 9999, '');
INSERT INTO 'tune' VALUES (9985, NULL, '2012-01-20 12:54:52.551477+00', 'Reel, The', 2820, '');
INSERT INTO 'tune' VALUES (9986, NULL, '2012-01-20 12:54:52.555492+00', 'Stirling Races', 1517, '');
INSERT INTO 'tune' VALUES (9987, NULL, '2012-01-20 12:54:52.559311+00', 'Prince Regent''s Medley', 1517, '');
INSERT INTO 'tune' VALUES (9988, NULL, '2012-01-20 12:54:52.563134+00', 'Donald MacLean', 3138, '');
INSERT INTO 'tune' VALUES (9989, NULL, '2012-01-20 12:54:52.566966+00', 'P/M Brent Blanchard''s Purdy Pink Band Shoes', 3739, '');
INSERT INTO 'tune' VALUES (9990, NULL, '2012-01-20 12:54:52.570798+00', 'Hamish and the Darius Dragon', 3740, '');
INSERT INTO 'tune' VALUES (9991, NULL, '2012-01-20 12:54:52.57478+00', '''Round Cnaidhl Loch', 3741, '');
INSERT INTO 'tune' VALUES (9992, NULL, '2012-01-20 12:54:52.578612+00', 'March of the Martians', 3742, '');
INSERT INTO 'tune' VALUES (9993, NULL, '2012-01-20 12:54:52.582483+00', 'Ulster Blossom', 9999, '');
INSERT INTO 'tune' VALUES (9994, NULL, '2012-01-20 12:54:52.586346+00', 'Over the Waterfall', 9999, '');
INSERT INTO 'tune' VALUES (9996, NULL, '2012-01-20 12:54:52.594173+00', 'Katrina''s Jig', 1590, '');
INSERT INTO 'tune' VALUES (9997, NULL, '2012-01-20 12:54:52.597984+00', 'Beryl Summers', 1543, '');
INSERT INTO 'tune' VALUES (9998, NULL, '2012-01-20 12:54:52.601839+00', 'Amstel Court', 1508, '');
INSERT INTO 'tune' VALUES (9999, NULL, '2012-01-20 12:54:52.605672+00', 'A l''Avenir', 1631, '');
INSERT INTO 'tune' VALUES (10000, NULL, '2012-01-20 12:54:52.609517+00', 'Cameron Gordon Jones', 2768, '');
INSERT INTO 'tune' VALUES (10001, NULL, '2012-01-20 12:54:52.613517+00', 'Kirkview House', 1508, '');
INSERT INTO 'tune' VALUES (10002, NULL, '2012-01-20 12:54:52.617338+00', 'David Ferguson''s Strathspey', 1593, '');
INSERT INTO 'tune' VALUES (10003, NULL, '2012-01-20 12:54:52.621224+00', 'Sean O''Neill''s Reel', 1527, '');
INSERT INTO 'tune' VALUES (10006, NULL, '2012-01-20 12:54:52.643646+00', 'Montmartre', 2523, '');
INSERT INTO 'tune' VALUES (10007, NULL, '2012-01-20 12:54:52.647627+00', 'Port Appin', 1527, '');
INSERT INTO 'tune' VALUES (10008, NULL, '2012-01-20 12:54:52.651597+00', 'Trip to Yarmouth', 1439, '');
INSERT INTO 'tune' VALUES (10009, NULL, '2012-01-20 12:54:52.655596+00', 'Lindsay MacDonald''s Jig', 2768, '');
INSERT INTO 'tune' VALUES (10010, NULL, '2012-01-20 12:54:52.660192+00', 'Shepherd''s Bridge, The', 2523, '');
INSERT INTO 'tune' VALUES (10011, NULL, '2012-01-20 12:54:52.664119+00', 'Shinkansen', 1534, '');
INSERT INTO 'tune' VALUES (10012, NULL, '2012-01-20 12:54:52.667986+00', 'Hjerdafeld', 1724, '');
INSERT INTO 'tune' VALUES (10013, NULL, '2012-01-20 12:54:52.671825+00', 'Tammie Norie Jig', 1508, '');
INSERT INTO 'tune' VALUES (10014, NULL, '2012-01-20 12:54:52.675661+00', 'Salute to Ann Dix', 1439, '');
INSERT INTO 'tune' VALUES (10015, '2006-12-12 23:00:00+00', '2012-01-20 12:54:52.679654+00', 'Saitama Strathspey, The', 1582, '');
INSERT INTO 'tune' VALUES (10016, '2006-12-15 23:00:00+00', '2012-01-20 12:54:52.683535+00', 'Miss Judy Robertson of Little Rock', 1502, '');
INSERT INTO 'tune' VALUES (10017, NULL, '2012-01-20 12:54:52.687395+00', 'Dornoch Highland Gathering', 3748, '');
INSERT INTO 'tune' VALUES (10018, NULL, '2012-01-20 12:54:52.691272+00', 'Double Rise', 1761, '');
INSERT INTO 'tune' VALUES (10019, NULL, '2012-01-20 12:54:52.695193+00', 'Invercauld''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (10020, NULL, '2012-01-20 12:54:52.699206+00', 'Marquis of Huntly New Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (10021, NULL, '2012-01-20 12:54:52.703054+00', 'Highland Diamond', 1598, '');
INSERT INTO 'tune' VALUES (10022, NULL, '2012-01-20 12:54:52.706911+00', 'Highland Society of Scotland, The', 1748, '');
INSERT INTO 'tune' VALUES (10023, NULL, '2012-01-20 12:54:52.71073+00', 'Lonach Highlanders, The', 1748, '');
INSERT INTO 'tune' VALUES (10024, NULL, '2012-01-20 12:54:52.714545+00', 'Birks of Delhandy, The', 1748, '');
INSERT INTO 'tune' VALUES (10025, '2006-12-17 23:00:00+00', '2012-01-20 12:54:52.718494+00', 'Courting Couple, The', 2801, '');
INSERT INTO 'tune' VALUES (10026, '2007-01-02 23:00:00+00', '2012-01-20 12:54:52.72235+00', 'Nora Sutherland''s Strathspey', 1582, '');
INSERT INTO 'tune' VALUES (10027, '2007-01-03 23:00:00+00', '2012-01-20 12:54:52.726225+00', 'Susie''s March', 1846, '');
INSERT INTO 'tune' VALUES (10028, NULL, '2012-01-20 12:54:52.730082+00', 'In Continental Mood', 3752, '');
INSERT INTO 'tune' VALUES (10029, NULL, '2012-01-20 12:54:52.733978+00', 'Flatworld', 3752, '');
INSERT INTO 'tune' VALUES (10030, NULL, '2012-01-20 12:54:52.737867+00', 'Al, Katy and Kipling', 9998, '');
INSERT INTO 'tune' VALUES (10031, NULL, '2012-01-20 12:54:52.741695+00', 'Professor, The', 1846, '');
INSERT INTO 'tune' VALUES (10032, NULL, '2012-01-20 12:54:52.745515+00', 'Alex Gray', 1846, '');
INSERT INTO 'tune' VALUES (10033, NULL, '2012-01-20 12:54:52.749457+00', 'Chris Ronald''s Strathspey', 1846, '');
INSERT INTO 'tune' VALUES (10034, NULL, '2012-01-20 12:54:52.753424+00', 'Jon and Holly', 1846, '');
INSERT INTO 'tune' VALUES (10035, NULL, '2012-01-20 12:54:52.757284+00', 'Malangen Jig', 1846, '');
INSERT INTO 'tune' VALUES (10036, NULL, '2012-01-20 12:54:52.761104+00', 'Laird of Brodie', 2142, '');
INSERT INTO 'tune' VALUES (10037, NULL, '2012-01-20 12:54:52.764998+00', 'Well may Charlie Wear the Crown', 2142, '');
INSERT INTO 'tune' VALUES (10038, NULL, '2012-01-20 12:54:52.768824+00', 'Villa Frognaes', 1846, '');
INSERT INTO 'tune' VALUES (10039, NULL, '2012-01-20 12:54:52.772761+00', 'James Gray''s Strathspey', 1596, '');
INSERT INTO 'tune' VALUES (10040, NULL, '2012-01-20 12:54:52.776599+00', 'Granny''s Delight', 1846, '');
INSERT INTO 'tune' VALUES (10041, NULL, '2012-01-20 12:54:52.780465+00', 'Sally Hunter of Thurston''s Jig', 1518, '');
INSERT INTO 'tune' VALUES (10042, NULL, '2012-01-20 12:54:52.784441+00', 'Mermaid''s Song', 9998, '');
INSERT INTO 'tune' VALUES (10043, NULL, '2012-01-20 12:54:52.788296+00', 'Mrs Grant of Laggan', 9999, '');
INSERT INTO 'tune' VALUES (10044, '2007-01-11 23:00:00+00', '2012-01-20 12:54:52.792216+00', 'For Kaoru', 2692, '');
INSERT INTO 'tune' VALUES (13862, '2018-03-31 10:56:24.81649+00', '2018-03-31 10:56:24.81649+00', 'Argyll Arms Ceilidh', 1608, '');
INSERT INTO 'tune' VALUES (10046, '2007-01-28 23:00:00+00', '2012-01-20 12:54:52.799945+00', 'Willberg Reel, The', 1502, '');
INSERT INTO 'tune' VALUES (10047, '2007-02-01 23:00:00+00', '2012-01-20 12:54:52.80387+00', 'Teacher''s Choice, The', 9998, '');
INSERT INTO 'tune' VALUES (10048, '2007-02-20 23:00:00+00', '2012-01-20 12:54:52.807717+00', 'Anna MacBean', 1444, '');
INSERT INTO 'tune' VALUES (10049, '2007-03-13 23:00:00+00', '2012-01-20 12:54:52.811564+00', 'Mull Fair, The', 9999, '');
INSERT INTO 'tune' VALUES (10050, '2007-07-22 22:00:00+00', '2012-01-20 12:54:52.815414+00', 'Firebolt, The', 228, '');
INSERT INTO 'tune' VALUES (10051, '2007-07-26 22:00:00+00', '2012-01-20 12:54:52.819259+00', 'And Again', 2801, '');
INSERT INTO 'tune' VALUES (10053, '2007-08-15 22:00:00+00', '2012-01-20 12:54:52.82701+00', 'Trip to Lorient', 1508, '');
INSERT INTO 'tune' VALUES (10054, '2007-08-15 22:00:00+00', '2012-01-20 12:54:52.830854+00', 'Reel for Rhona', 1508, '');
INSERT INTO 'tune' VALUES (10055, NULL, '2012-01-20 12:54:52.834689+00', 'Miss Rowan Davies', 1761, '');
INSERT INTO 'tune' VALUES (10056, '2007-09-03 22:00:00+00', '2012-01-20 12:54:52.838606+00', 'Alison Robertson''s Rantings', 1770, '');
INSERT INTO 'tune' VALUES (10057, '2007-09-03 22:00:00+00', '2012-01-20 12:54:52.842544+00', 'Owl and the Hourglass, The', 1360, '');
INSERT INTO 'tune' VALUES (10058, NULL, '2012-01-20 12:54:52.846387+00', 'Collessie Hall', 2589, '');
INSERT INTO 'tune' VALUES (10059, NULL, '2012-01-20 12:54:52.850191+00', 'Sandra Blue''s Reel', 1554, '');
INSERT INTO 'tune' VALUES (10060, NULL, '2012-01-20 12:54:52.85401+00', 'Station House, The', 2589, '');
INSERT INTO 'tune' VALUES (10061, NULL, '2012-01-20 12:54:52.857836+00', 'Debbie', 2569, '');
INSERT INTO 'tune' VALUES (10062, NULL, '2012-01-20 12:54:52.861659+00', 'Lomond View', 2589, '');
INSERT INTO 'tune' VALUES (10063, NULL, '2012-01-20 12:54:52.865473+00', 'Byers Road, The', 3058, '');
INSERT INTO 'tune' VALUES (10064, NULL, '2012-01-20 12:54:52.869291+00', 'Broken Wipers, The', 1554, '');
INSERT INTO 'tune' VALUES (10065, '2007-09-05 22:00:00+00', '2012-01-20 12:54:52.873531+00', 'Bridge Castle Reel', 9998, '');
INSERT INTO 'tune' VALUES (10066, '2007-09-05 22:00:00+00', '2012-01-20 12:54:52.877843+00', 'Bothwell Brig', 9998, '');
INSERT INTO 'tune' VALUES (10067, '2007-09-05 22:00:00+00', '2012-01-20 12:54:52.881696+00', 'Lorn Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (10069, '2007-09-11 22:00:00+00', '2012-01-20 12:54:52.889422+00', 'Phantom Piper, The', 9998, '');
INSERT INTO 'tune' VALUES (10070, '2007-09-11 22:00:00+00', '2012-01-20 12:54:52.893283+00', 'Salute to Summer', 9998, '');
INSERT INTO 'tune' VALUES (10071, '2007-09-11 22:00:00+00', '2012-01-20 12:54:52.897141+00', 'Bonnie Kate of Aberdeen', 9998, '');
INSERT INTO 'tune' VALUES (10072, '2007-09-11 22:00:00+00', '2012-01-20 12:54:52.901096+00', 'Solway Reel, The', 9998, '');
INSERT INTO 'tune' VALUES (10073, '2007-09-11 22:00:00+00', '2012-01-20 12:54:52.904939+00', 'Winding Nith, The', 9998, '');
INSERT INTO 'tune' VALUES (10074, NULL, '2012-01-20 12:54:52.908794+00', 'Bessie Bell''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (10075, NULL, '2012-01-20 12:54:52.912612+00', 'Ding Dong Merrily on High', 9998, '');
INSERT INTO 'tune' VALUES (10076, NULL, '2012-01-20 12:54:52.917032+00', 'Go tell it on the Mountain', 9998, '');
INSERT INTO 'tune' VALUES (10077, NULL, '2012-01-20 12:54:52.920949+00', 'Good King Wenceslas', 9998, '');
INSERT INTO 'tune' VALUES (10078, NULL, '2012-01-20 12:54:52.924812+00', 'Happy Christmas (War is Over)', 3786, '');
INSERT INTO 'tune' VALUES (10079, NULL, '2012-01-20 12:54:52.928812+00', 'Mistletoe and Wine', 3785, '');
INSERT INTO 'tune' VALUES (10080, NULL, '2012-01-20 12:54:52.932625+00', 'Caroling, Caroling', 3787, '');
INSERT INTO 'tune' VALUES (10081, NULL, '2012-01-20 12:54:52.936442+00', 'In Dulci Jubilo', 9998, '');
INSERT INTO 'tune' VALUES (10083, NULL, '2012-01-20 12:54:52.944102+00', 'Sussex Carol', 9998, '');
INSERT INTO 'tune' VALUES (10084, NULL, '2012-01-20 12:54:52.947931+00', 'O Little Town of Bethlehem', 9998, '');
INSERT INTO 'tune' VALUES (10087, NULL, '2012-01-20 12:54:52.959543+00', 'In The Bleak Midwinter', 3789, '');
INSERT INTO 'tune' VALUES (10088, NULL, '2012-01-20 12:54:52.963373+00', 'Christmas in July', 1634, '');
INSERT INTO 'tune' VALUES (10089, NULL, '2012-01-20 12:54:52.96719+00', 'Holly, The', 9998, '');
INSERT INTO 'tune' VALUES (10090, NULL, '2012-01-20 12:54:52.970999+00', 'Christmas Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (10091, NULL, '2012-01-20 12:54:52.974904+00', 'Kate Broadwood''s Christmas Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (10092, NULL, '2012-01-20 12:54:52.978727+00', 'We Wish You a Merry Christmas', 9998, '');
INSERT INTO 'tune' VALUES (10093, NULL, '2012-01-20 12:54:52.982548+00', 'Holly and the Ivy, The', 9998, '');
INSERT INTO 'tune' VALUES (10094, NULL, '2012-01-20 12:54:52.986358+00', 'Shepherd''s Carol, The', 9998, '');
INSERT INTO 'tune' VALUES (10095, NULL, '2012-01-20 12:54:52.990184+00', 'Zither Carol', 9998, '');
INSERT INTO 'tune' VALUES (10096, NULL, '2012-01-20 12:54:52.993986+00', 'First Noel, The', 9998, '');
INSERT INTO 'tune' VALUES (10097, NULL, '2012-01-20 12:54:52.997793+00', 'Sleigh Ride', 3790, '');
INSERT INTO 'tune' VALUES (10098, NULL, '2012-01-20 12:54:53.001614+00', 'When Santa Got Stuck up the Chimney', 3791, '');
INSERT INTO 'tune' VALUES (10099, NULL, '2012-01-20 12:54:53.00543+00', 'Dance of the Snowman', 3792, '');
INSERT INTO 'tune' VALUES (10100, NULL, '2012-01-20 12:54:53.009251+00', 'All I Want for Christmas', 3793, '');
INSERT INTO 'tune' VALUES (10101, NULL, '2012-01-20 12:54:53.013081+00', 'Winter Wonderland', 3794, '');
INSERT INTO 'tune' VALUES (10102, NULL, '2012-01-20 12:54:53.016907+00', 'Christmas Song, The', 3795, '');
INSERT INTO 'tune' VALUES (10103, NULL, '2012-01-20 12:54:53.020779+00', 'Christmas Dream', 3796, '');
INSERT INTO 'tune' VALUES (10104, NULL, '2012-01-20 12:54:53.024594+00', 'Stop the Cavalry', 3797, '');
INSERT INTO 'tune' VALUES (10105, NULL, '2012-01-20 12:54:53.028457+00', 'Merry Christmas, A', 9998, '');
INSERT INTO 'tune' VALUES (10106, NULL, '2012-01-20 12:54:53.032279+00', 'Day Before Christmas, The', 9998, '');
INSERT INTO 'tune' VALUES (10107, NULL, '2012-01-20 12:54:53.036168+00', 'Green Holly Bush Jig, The', 3798, '');
INSERT INTO 'tune' VALUES (10108, NULL, '2012-01-20 12:54:53.040036+00', 'Ducks Die at Christmas', 9998, '');
INSERT INTO 'tune' VALUES (10109, NULL, '2012-01-20 12:54:53.043867+00', 'Christmas Jig, The', 9998, '');
INSERT INTO 'tune' VALUES (10110, NULL, '2012-01-20 12:54:53.048056+00', 'All Around the Christmas Tree', 9998, '');
INSERT INTO 'tune' VALUES (10111, NULL, '2012-01-20 12:54:53.052204+00', 'Christmas in Kinsale', 3799, '');
INSERT INTO 'tune' VALUES (10112, NULL, '2012-01-20 12:54:53.056096+00', 'Marshmallow World, A', 3800, '');
INSERT INTO 'tune' VALUES (10113, NULL, '2012-01-20 12:54:53.059984+00', 'Jingle Bell Rock', 3801, '');
INSERT INTO 'tune' VALUES (10115, NULL, '2012-01-20 12:54:53.068292+00', 'Away in a Manger', 9998, '');
INSERT INTO 'tune' VALUES (10116, NULL, '2012-01-20 12:54:53.072205+00', 'Here Comes Santa Claus', 3802, '');
INSERT INTO 'tune' VALUES (10117, NULL, '2012-01-20 12:54:53.076095+00', 'Let it Snow', 3803, '');
INSERT INTO 'tune' VALUES (10118, NULL, '2012-01-20 12:54:53.080178+00', 'Where Did my Snowman Go?', 3804, '');
INSERT INTO 'tune' VALUES (10119, NULL, '2012-01-20 12:54:53.084801+00', 'Santa Claus is Coming to Town', 3805, '');
INSERT INTO 'tune' VALUES (10121, NULL, '2016-12-14 22:14:09.265913+00', 'Rudolph the Red Nosed Reindeer', 3807, '');
INSERT INTO 'tune' VALUES (10086, NULL, '2016-12-14 22:56:53.752865+00', 'See Amid the Winter Snow', 3788, '');
INSERT INTO 'tune' VALUES (10085, NULL, '2016-12-14 22:31:12.111628+00', 'It Came Upon the Midnight Clear', 9998, '');
INSERT INTO 'tune' VALUES (10082, NULL, '2016-12-14 23:14:25.708807+00', 'We Three Kings', 9998, '');
INSERT INTO 'tune' VALUES (10114, NULL, '2016-12-14 23:23:43.851881+00', 'Silent Night', 11435, '');
INSERT INTO 'tune' VALUES (10120, NULL, '2017-07-28 03:54:05.11051+00', 'Frosty the Snowman', 3806, '');
INSERT INTO 'tune' VALUES (10122, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.096829+00', 'Kathleen McAdam''s Jig', 2395, '');
INSERT INTO 'tune' VALUES (10123, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.100871+00', 'Kerfunten', 10001, '');
INSERT INTO 'tune' VALUES (10124, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.104898+00', 'Roaring Barmaid, The', 10002, '');
INSERT INTO 'tune' VALUES (10125, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.108885+00', 'Anna Mae''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (10126, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.112903+00', 'Whirlwind, The', 2395, '');
INSERT INTO 'tune' VALUES (10127, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.116958+00', 'O''Beirne''s', 9999, '');
INSERT INTO 'tune' VALUES (10128, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.120991+00', 'Gu Siorruidh Gun Ainm', 10003, '');
INSERT INTO 'tune' VALUES (10130, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.129745+00', 'James Lomath', 1773, '');
INSERT INTO 'tune' VALUES (10131, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.133765+00', 'Dillon Brown', 9999, '');
INSERT INTO 'tune' VALUES (10132, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.137783+00', 'Master McDermot''s', 9999, '');
INSERT INTO 'tune' VALUES (10133, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.141969+00', 'Teresita Waltz', 10005, '');
INSERT INTO 'tune' VALUES (10135, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.150244+00', 'Reel de Montebello', 10006, '');
INSERT INTO 'tune' VALUES (10136, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.154171+00', 'Whitefish in the Rapids', 9999, '');
INSERT INTO 'tune' VALUES (10137, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.158389+00', 'Rose Villa Strathspey', 1745, '');
INSERT INTO 'tune' VALUES (10138, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.162488+00', 'Avril Quarrie''s Strathspey', 2395, '');
INSERT INTO 'tune' VALUES (10139, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.167316+00', 'Arms Dealer''s Daughter, The', 10007, '');
INSERT INTO 'tune' VALUES (10140, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.171542+00', 'Black Watch''s Farewell to Bareilly, The', 9999, '');
INSERT INTO 'tune' VALUES (10141, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.175656+00', 'Waterloo March', 9999, '');
INSERT INTO 'tune' VALUES (10142, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.179749+00', 'Mrs. McInroy of Lude', 9999, '');
INSERT INTO 'tune' VALUES (10143, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.183886+00', 'Greta Young of Gourock', 10009, '');
INSERT INTO 'tune' VALUES (10144, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.188016+00', 'Jig of the Clan Beag', 10010, '');
INSERT INTO 'tune' VALUES (10145, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.1921+00', 'Waste', 10011, '');
INSERT INTO 'tune' VALUES (10146, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.196195+00', 'Monozygotic Phenomenon', 10012, '');
INSERT INTO 'tune' VALUES (10147, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.200636+00', 'Unseasonal Rain', 10009, '');
INSERT INTO 'tune' VALUES (10149, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.208811+00', 'Bee''s Knees, The', 10014, '');
INSERT INTO 'tune' VALUES (10151, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.217102+00', 'Montréal Anniversary Jig', 10012, '');
INSERT INTO 'tune' VALUES (10152, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.226791+00', 'Ulrike''s Inspiration', 10012, '');
INSERT INTO 'tune' VALUES (10153, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.230648+00', 'New Year''s Day', 9999, '');
INSERT INTO 'tune' VALUES (10155, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.238326+00', 'Glenbucket Lodge', 9999, '');
INSERT INTO 'tune' VALUES (10156, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.242235+00', 'Chanter Song', 9999, '');
INSERT INTO 'tune' VALUES (10157, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.246111+00', 'C''est à ton tour', 10012, '');
INSERT INTO 'tune' VALUES (10158, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.249924+00', 'True Thomas', 10009, '');
INSERT INTO 'tune' VALUES (10159, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.253745+00', 'Peveril Lasses', 10015, '');
INSERT INTO 'tune' VALUES (10160, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.257587+00', 'Reel du Marché Jean-Talon', 10009, '');
INSERT INTO 'tune' VALUES (10161, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.261424+00', 'Terrebonne', 9999, '');
INSERT INTO 'tune' VALUES (10162, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.265258+00', 'Gabriel and Diana', 10012, '');
INSERT INTO 'tune' VALUES (10163, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.269082+00', 'Duchess of Manchester''s New Strathspey, The', 1519, '');
INSERT INTO 'tune' VALUES (10164, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.272924+00', 'Muse Cottage Revisited', 1502, '');
INSERT INTO 'tune' VALUES (10165, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.276759+00', 'Still Going Strong', 1502, '');
INSERT INTO 'tune' VALUES (10166, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.280598+00', 'Knockando House', 1516, '');
INSERT INTO 'tune' VALUES (10167, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.284438+00', 'Bonnie Prince Charlie', 9999, '');
INSERT INTO 'tune' VALUES (10168, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.288342+00', 'McLean''s Pipes', 9999, '');
INSERT INTO 'tune' VALUES (10169, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.292207+00', 'Mrs Ferguson of Reath', 1518, '');
INSERT INTO 'tune' VALUES (10170, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.296049+00', 'Mrs Houston of Rosehall', 1518, '');
INSERT INTO 'tune' VALUES (10171, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.299885+00', 'Mrs Henry Lumsden of Tillwhilly''s Strathspey', 1516, '');
INSERT INTO 'tune' VALUES (10172, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.303741+00', 'Lady Heriet Georgina Hamilton', 1516, '');
INSERT INTO 'tune' VALUES (10173, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.307578+00', 'Grenoside', 1502, '');
INSERT INTO 'tune' VALUES (10174, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.311419+00', 'Walking Backwards', 1502, '');
INSERT INTO 'tune' VALUES (10175, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.315254+00', 'Slip of the Tongue', 3436, '');
INSERT INTO 'tune' VALUES (10176, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.319093+00', 'Versatility', 3436, '');
INSERT INTO 'tune' VALUES (10177, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.322923+00', 'Hand for Mairi, A', 1502, '');
INSERT INTO 'tune' VALUES (10178, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.32679+00', 'Loch Ruthven', 2142, '');
INSERT INTO 'tune' VALUES (10179, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.33063+00', 'Bonny Ann', 9999, '');
INSERT INTO 'tune' VALUES (10180, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.334464+00', 'Mo Dhuthchas', 9999, '');
INSERT INTO 'tune' VALUES (13863, '2018-03-31 10:59:52.83448+00', '2018-03-31 10:59:52.83448+00', 'Mrs Colquhoun Grant', 1934, '');
INSERT INTO 'tune' VALUES (10182, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.342128+00', 'Mrs George Stewart''s Strathspey', 1807, '');
INSERT INTO 'tune' VALUES (10183, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.346051+00', 'Winday City, The', 2842, '');
INSERT INTO 'tune' VALUES (10184, '2009-08-02 22:00:00+00', '2012-01-20 12:54:53.349939+00', 'Goat Island Reel, The', 2842, '');
INSERT INTO 'tune' VALUES (10185, '2009-10-17 22:00:00+00', '2012-01-20 12:54:53.353771+00', 'Mrs Muir McKenzie', 1747, '');
INSERT INTO 'tune' VALUES (10186, '2009-10-17 22:00:00+00', '2012-01-20 12:54:53.357606+00', 'Hon. Miss Jessie Ruthven''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (10187, '2009-10-17 22:00:00+00', '2012-01-20 12:54:53.36144+00', 'Mrs. Lieut. Morison''s Fancy', 1939, '');
INSERT INTO 'tune' VALUES (10188, '2009-10-17 22:00:00+00', '2012-01-20 12:54:53.36528+00', 'Fiona MacDonald''s Jig', 1596, '');
INSERT INTO 'tune' VALUES (10189, '2009-10-17 22:00:00+00', '2012-01-20 12:54:53.369111+00', 'Sweet Nell of Glencarse', 1554, '');
INSERT INTO 'tune' VALUES (10190, '2009-10-17 22:00:00+00', '2012-01-20 12:54:53.37294+00', 'Whisky For Breakfast', 9999, '');
INSERT INTO 'tune' VALUES (10192, '2009-10-17 22:00:00+00', '2012-01-20 12:54:53.380718+00', 'Mrs Rait''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (10193, '2009-10-17 22:00:00+00', '2012-01-20 12:54:53.384559+00', 'David Fellowes of Innistrynich', 1596, '');
INSERT INTO 'tune' VALUES (10194, '2009-10-17 22:00:00+00', '2012-01-20 12:54:53.388388+00', 'Miss Emma Fellowes', 1596, '');
INSERT INTO 'tune' VALUES (10195, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.392223+00', 'Duchess of Buccleuch, The', 1517, 'This is not to be confused with the tune, »The Duchess of Buccleuch«, by William Marshall.');
INSERT INTO 'tune' VALUES (10134, '2009-08-02 22:00:00+00', '2021-09-23 20:42:54.797995+00', 'Linda Henderson of Alamo, California', 2395, '');
INSERT INTO 'tune' VALUES (10197, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.399923+00', 'Rope Splicer''s Jig, The', 3186, '');
INSERT INTO 'tune' VALUES (10198, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.403771+00', 'Wallace Monument, The', 1591, '');
INSERT INTO 'tune' VALUES (10199, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.407604+00', 'Coffee Bothy, The', 1591, '');
INSERT INTO 'tune' VALUES (10200, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.411449+00', 'Willie Robertson', 3186, '');
INSERT INTO 'tune' VALUES (10201, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.415286+00', 'Stuck in the Snow', 1578, '');
INSERT INTO 'tune' VALUES (10202, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.419203+00', 'Lismore Ferryman, The', 1596, '');
INSERT INTO 'tune' VALUES (10203, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.423043+00', 'Muriel''s Reel', 10017, '');
INSERT INTO 'tune' VALUES (10204, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.426878+00', 'Joss & Joyce Mitchelson', 1593, '');
INSERT INTO 'tune' VALUES (10205, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.430742+00', 'Nicol McLaren O'' Blair''s Jig', 1596, '');
INSERT INTO 'tune' VALUES (10206, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.434574+00', 'Margaret Holmes'' Jig', 1596, '');
INSERT INTO 'tune' VALUES (10207, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.438411+00', 'Ann Anderson''s Strathspey', 1591, '');
INSERT INTO 'tune' VALUES (10208, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.442246+00', 'Tink''s Delight', 1593, '');
INSERT INTO 'tune' VALUES (10209, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.446129+00', 'Myat''s Reel', 1591, '');
INSERT INTO 'tune' VALUES (10210, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.449957+00', 'Inga''s Reel', 3693, '');
INSERT INTO 'tune' VALUES (10211, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.453791+00', 'Miss Sharpe''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (10212, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.457622+00', 'Lappie Dub, The', 1578, '');
INSERT INTO 'tune' VALUES (10213, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.46145+00', 'Becky Hunter''s Reel', 10016, '');
INSERT INTO 'tune' VALUES (10214, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.465282+00', 'Stephen McCallum of Bunessan', 10016, '');
INSERT INTO 'tune' VALUES (10215, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.4691+00', 'Sonny Martin', 9998, '');
INSERT INTO 'tune' VALUES (10216, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.472927+00', 'Miss Farquharson of Invercauld', 1516, '');
INSERT INTO 'tune' VALUES (10217, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.476766+00', 'Paxton House', 1502, '');
INSERT INTO 'tune' VALUES (10218, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.480698+00', 'Northern Lasses', 9999, '');
INSERT INTO 'tune' VALUES (10219, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.484538+00', 'Appropriate Dipstick, The', 10021, '');
INSERT INTO 'tune' VALUES (10221, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.492207+00', 'Scotch Mary', 9999, '');
INSERT INTO 'tune' VALUES (10222, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.496038+00', 'MacDonald''s', 9999, '');
INSERT INTO 'tune' VALUES (10223, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.499869+00', 'Evite Gabriel', 9999, '');
INSERT INTO 'tune' VALUES (10224, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.503703+00', 'Ronde des Voyageurs', 9999, '');
INSERT INTO 'tune' VALUES (10225, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.507543+00', 'Reel Antoinette', 9999, '');
INSERT INTO 'tune' VALUES (10226, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.511374+00', 'Cate Gray', 1846, '');
INSERT INTO 'tune' VALUES (10227, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.515218+00', 'Horsbrough', 9999, '');
INSERT INTO 'tune' VALUES (10228, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.519047+00', 'Rob Roy MacGregor', 9999, '');
INSERT INTO 'tune' VALUES (10229, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.522905+00', 'Lady Helen Wedderburn', 9999, '');
INSERT INTO 'tune' VALUES (10230, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.526864+00', 'June Jig', 10024, '');
INSERT INTO 'tune' VALUES (10231, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.530714+00', 'PM Donald Maclean of Lewis', 9999, '');
INSERT INTO 'tune' VALUES (10232, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.534542+00', 'Billy the Barber', 9999, '');
INSERT INTO 'tune' VALUES (10233, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.538424+00', 'Miss Mary Garden of Troup''s', 9999, '');
INSERT INTO 'tune' VALUES (10234, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.542278+00', 'Lady Elizabeth Montague', 9999, '');
INSERT INTO 'tune' VALUES (10235, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.546107+00', 'A.G. Wilkins', 9999, '');
INSERT INTO 'tune' VALUES (10236, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.549939+00', 'Gin I Had A Bonnie Lass', 9999, '');
INSERT INTO 'tune' VALUES (10237, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.553766+00', 'Fosgail an Dorus', 9999, '');
INSERT INTO 'tune' VALUES (10238, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.557606+00', 'Sheepskin Beeswax', 9999, '');
INSERT INTO 'tune' VALUES (10239, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.561442+00', 'Lachlan Dhu', 9999, '');
INSERT INTO 'tune' VALUES (10240, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.565291+00', 'St Andrews'' Flight', 10025, '');
INSERT INTO 'tune' VALUES (10241, '2009-10-18 22:00:00+00', '2012-01-20 12:54:53.56913+00', 'Lament for the Cut Finger', 10026, '');
INSERT INTO 'tune' VALUES (10242, '2009-10-24 22:00:00+00', '2012-01-20 12:54:53.57297+00', 'Maid of Craigmaddie, The', 1517, '');
INSERT INTO 'tune' VALUES (10243, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.576792+00', 'Corbies Wing, The', 1623, '');
INSERT INTO 'tune' VALUES (10244, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.581022+00', 'Mrs Grace Tait', 1766, '');
INSERT INTO 'tune' VALUES (10245, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.586159+00', 'Da Kirks', 10031, '');
INSERT INTO 'tune' VALUES (10246, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.59002+00', 'Da Beachcomber', 10031, '');
INSERT INTO 'tune' VALUES (10247, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.593883+00', 'Callum Dewar''s Reel', 1591, '');
INSERT INTO 'tune' VALUES (10248, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.597887+00', 'Tannadice', 1796, '');
INSERT INTO 'tune' VALUES (10250, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.605687+00', 'Munster Bacon', 9999, '');
INSERT INTO 'tune' VALUES (10251, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.609582+00', 'Basket of Turf, The', 9999, '');
INSERT INTO 'tune' VALUES (10252, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.613417+00', 'Paddy''s Resource', 9999, '');
INSERT INTO 'tune' VALUES (10253, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.617243+00', 'Early Dark', 1591, '');
INSERT INTO 'tune' VALUES (10254, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.621168+00', 'Miss Ellie', 1591, '');
INSERT INTO 'tune' VALUES (10255, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.624995+00', 'Poppy Leaf, The', 9999, '');
INSERT INTO 'tune' VALUES (10256, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.628836+00', 'Robert Spence of Langton Hall', 1533, '');
INSERT INTO 'tune' VALUES (10257, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.632662+00', 'Da Burn O'' Finnigarth', 10033, '');
INSERT INTO 'tune' VALUES (10259, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.640356+00', 'Da Coarn Heuk', 1805, '');
INSERT INTO 'tune' VALUES (10261, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.648054+00', 'Peter D Scollay', 10031, '');
INSERT INTO 'tune' VALUES (10263, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.655728+00', 'Judi Nicolson', 1591, '');
INSERT INTO 'tune' VALUES (10264, '2009-11-02 23:00:00+00', '2012-01-20 12:54:53.660026+00', 'Jig for Laura, A', 1591, '');
INSERT INTO 'tune' VALUES (10265, '2009-11-03 23:00:00+00', '2012-01-20 12:54:53.663887+00', 'Ms Elspeth Gray', 3683, '');
INSERT INTO 'tune' VALUES (10266, '2009-11-03 23:00:00+00', '2012-01-20 12:54:53.667725+00', 'Hello, Kate Speaking', 3683, '');
INSERT INTO 'tune' VALUES (10267, '2009-11-03 23:00:00+00', '2012-01-20 12:54:53.671562+00', 'Jill Petri''s Jig', 3683, '');
INSERT INTO 'tune' VALUES (10268, '2009-11-03 23:00:00+00', '2012-01-20 12:54:53.675404+00', 'Tribute to Robert MacKay, A', 3683, '');
INSERT INTO 'tune' VALUES (10269, '2009-11-03 23:00:00+00', '2012-01-20 12:54:53.679246+00', 'Angela Young', 3683, '');
INSERT INTO 'tune' VALUES (10270, '2009-11-03 23:00:00+00', '2012-01-20 12:54:53.683087+00', 'Ruby Slippers, The', 3683, '');
INSERT INTO 'tune' VALUES (10271, '2009-11-03 23:00:00+00', '2012-01-20 12:54:53.686909+00', 'Rachel''s Rant', 3683, '');
INSERT INTO 'tune' VALUES (10272, '2009-11-03 23:00:00+00', '2012-01-20 12:54:53.690741+00', 'Girls from Oakland, The', 3683, '');
INSERT INTO 'tune' VALUES (10273, '2009-11-03 23:00:00+00', '2012-01-20 12:54:53.69457+00', 'Examiner, The', 3683, '');
INSERT INTO 'tune' VALUES (10274, '2009-11-03 23:00:00+00', '2012-01-20 12:54:53.69841+00', 'Brian the Laundry Boy', 1626, '');
INSERT INTO 'tune' VALUES (10275, '2009-11-03 23:00:00+00', '2012-01-20 12:54:53.702245+00', 'Angela''s Strathspey', 3683, '');
INSERT INTO 'tune' VALUES (10276, '2009-11-03 23:00:00+00', '2012-01-20 12:54:53.706085+00', 'Luke Brady''s compliments to the Majician', 3683, '');
INSERT INTO 'tune' VALUES (10249, '2009-11-02 23:00:00+00', '2013-01-06 13:10:28.897016+00', 'Jim Halcrow''s Reel', 1668, '');
INSERT INTO 'tune' VALUES (10277, '2009-11-03 23:00:00+00', '2012-01-20 12:54:53.709916+00', 'Lad fae Dundee, The', 1502, '');
INSERT INTO 'tune' VALUES (10279, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.717599+00', 'Brig o'' Feugh, The', 1512, '');
INSERT INTO 'tune' VALUES (10280, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.721436+00', 'Glengate', 1505, '');
INSERT INTO 'tune' VALUES (10281, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.725264+00', 'Mr Davidson of Netherly', 1505, '');
INSERT INTO 'tune' VALUES (10284, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.736897+00', 'Major Alves'' Reel', 1519, '');
INSERT INTO 'tune' VALUES (10285, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.74073+00', 'Session Clerk, The', 10036, '');
INSERT INTO 'tune' VALUES (10286, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.74457+00', 'Ann and John McLean''s Silver Wedding Jig', 1543, '');
INSERT INTO 'tune' VALUES (10287, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.748526+00', 'Aberdeen Hunt, The', 9998, '');
INSERT INTO 'tune' VALUES (10288, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.752368+00', 'Galloway Braes', 1606, '');
INSERT INTO 'tune' VALUES (10289, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.75621+00', 'Lord John Campbell', 10504, '');
INSERT INTO 'tune' VALUES (10290, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.760047+00', 'Barber of Bunessan, The', 10038, '');
INSERT INTO 'tune' VALUES (10291, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.763871+00', 'Liz Kane', 2689, '');
INSERT INTO 'tune' VALUES (13864, '2018-03-31 11:01:07.450579+00', '2018-03-31 11:01:07.450579+00', 'Sir James Grant', 1807, '');
INSERT INTO 'tune' VALUES (10293, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.771535+00', 'Bobby Crowe''s Strathspey', 3186, '');
INSERT INTO 'tune' VALUES (10295, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.775371+00', 'Wee Todd', 1533, '');
INSERT INTO 'tune' VALUES (10296, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.779194+00', 'Gent, The', 3683, '');
INSERT INTO 'tune' VALUES (10297, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.783056+00', 'George Scroggie of Lochee', 3683, '');
INSERT INTO 'tune' VALUES (10298, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.78689+00', 'Grandad''s Accordion Band', 3683, '');
INSERT INTO 'tune' VALUES (10299, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.79077+00', 'Musical Legacy, A', 3683, '');
INSERT INTO 'tune' VALUES (10260, '2009-11-02 23:00:00+00', '2022-12-23 13:37:03.001936+00', 'Shetland''s Peerie Ponies', 10086, '');
INSERT INTO 'tune' VALUES (10300, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.794605+00', 'Frank''s Classique', 1687, '');
INSERT INTO 'tune' VALUES (10301, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.79844+00', 'Mo Rutherford''s Jig', 3683, '');
INSERT INTO 'tune' VALUES (10303, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.806124+00', 'Fiona Whitton''s Jig', 1777, '');
INSERT INTO 'tune' VALUES (10304, '2009-11-04 23:00:00+00', '2012-01-20 12:54:53.809954+00', 'Jim''s Jig', 1777, '');
INSERT INTO 'tune' VALUES (10306, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.817644+00', 'Miss Nicola Gray', 1501, '');
INSERT INTO 'tune' VALUES (10307, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.821584+00', 'Sair Head, A', 1501, '');
INSERT INTO 'tune' VALUES (10308, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.825426+00', 'Globetrottin''', 1501, '');
INSERT INTO 'tune' VALUES (10282, '2009-11-04 23:00:00+00', '2014-11-18 00:57:35.613955+00', 'Lt Howard Douglas'' Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (10283, '2009-11-04 23:00:00+00', '2014-11-18 00:59:00.893922+00', 'Miss Menzies of Culdair''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (10309, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.829265+00', 'Wetherby Jig, The', 1501, '');
INSERT INTO 'tune' VALUES (10310, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.833095+00', 'Jolly Companions', 9999, '');
INSERT INTO 'tune' VALUES (10311, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.837009+00', 'Shootin'' the Breeze', 1501, '');
INSERT INTO 'tune' VALUES (10312, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.840839+00', 'Devil''s Elbow, The', 1836, '');
INSERT INTO 'tune' VALUES (10313, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.844659+00', 'Nakano Hornpipe', 1836, '');
INSERT INTO 'tune' VALUES (10314, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.848492+00', 'Bluebell Reel', 1836, '');
INSERT INTO 'tune' VALUES (10315, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.852333+00', 'Spring Chicken', 1836, '');
INSERT INTO 'tune' VALUES (10316, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.863552+00', 'Hugh Brown SSPE', 1836, '');
INSERT INTO 'tune' VALUES (10317, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.870585+00', 'On the Moraine', 1836, '');
INSERT INTO 'tune' VALUES (10318, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.874564+00', 'Celebration Reel', 1836, '');
INSERT INTO 'tune' VALUES (10220, '2009-10-18 22:00:00+00', '2019-04-10 22:20:06.935547+00', 'Fille Sage, La', 9999, '');
INSERT INTO 'tune' VALUES (10319, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.878655+00', 'Ballingluig', 1836, '');
INSERT INTO 'tune' VALUES (10320, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.882557+00', 'Sakura', 9999, '');
INSERT INTO 'tune' VALUES (10321, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.886589+00', 'Hana', 10174, '');
INSERT INTO 'tune' VALUES (10322, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.891033+00', 'Koinobori', 10358, '');
INSERT INTO 'tune' VALUES (10323, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.895086+00', 'Kiku', 1836, '');
INSERT INTO 'tune' VALUES (10324, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.899042+00', 'Sun on Schiehallion', 1836, '');
INSERT INTO 'tune' VALUES (10325, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.902901+00', 'Hiro''s High Cuts', 1836, '');
INSERT INTO 'tune' VALUES (10326, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.907014+00', 'Ginger Snaps', 1836, '');
INSERT INTO 'tune' VALUES (10327, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.910868+00', 'Gathering Bluebells', 1836, '');
INSERT INTO 'tune' VALUES (10328, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.914718+00', 'Lady of Tokai', 1836, '');
INSERT INTO 'tune' VALUES (10329, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.918663+00', 'MacDonald of the Eastern Isles', 10040, '');
INSERT INTO 'tune' VALUES (10330, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.922523+00', 'Froggy Pond, The', 1836, '');
INSERT INTO 'tune' VALUES (10331, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.926398+00', 'Carillon Bleu', 1836, '');
INSERT INTO 'tune' VALUES (10332, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.930255+00', 'Sea Change', 1836, '');
INSERT INTO 'tune' VALUES (10333, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.934101+00', 'To Be a Wind', 1836, '');
INSERT INTO 'tune' VALUES (10334, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.938029+00', 'Hello! Hello! Who''s Your Lady Friend?', 10041, '');
INSERT INTO 'tune' VALUES (10335, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.941878+00', 'Miss Heather', 10042, '');
INSERT INTO 'tune' VALUES (10336, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.945731+00', 'Jack Fisher''s Delight', 9999, '');
INSERT INTO 'tune' VALUES (10337, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.949593+00', 'Locomotive, The', 9999, '');
INSERT INTO 'tune' VALUES (10339, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.957294+00', 'McNab of McNab', 1520, '');
INSERT INTO 'tune' VALUES (10340, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.961225+00', 'Glenjura Jig, The', 9999, '');
INSERT INTO 'tune' VALUES (10341, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.965256+00', 'Bothar Mor Go Slingeach, An', 9999, '');
INSERT INTO 'tune' VALUES (10342, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.969117+00', 'Bill''s New Fiddle', 1538, '');
INSERT INTO 'tune' VALUES (10343, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.972961+00', 'Thelma''s Favourite', 1645, '');
INSERT INTO 'tune' VALUES (10344, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.976806+00', 'Thompson''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (10345, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.980741+00', 'Finlay J Powrie', 1551, '');
INSERT INTO 'tune' VALUES (10346, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.984607+00', 'Miss Sarah Louise Little', 10044, '');
INSERT INTO 'tune' VALUES (10347, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.988458+00', 'Rusty Claymore, The', 9998, '');
INSERT INTO 'tune' VALUES (10348, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.992299+00', 'Mrs Elizabeth Rutherford of Moranbank', 1687, '');
INSERT INTO 'tune' VALUES (10349, '2009-11-05 23:00:00+00', '2012-01-20 12:54:53.996138+00', 'In Memory of Angus Shaw B.E.M.', 3655, '');
INSERT INTO 'tune' VALUES (10350, '2009-11-05 23:00:00+00', '2012-01-20 12:54:54.000049+00', 'Auld Planti Crub, Da', 1710, '');
INSERT INTO 'tune' VALUES (10351, '2009-11-05 23:00:00+00', '2012-01-20 12:54:54.003935+00', 'Pam''s Magic Harmonies', 2948, '');
INSERT INTO 'tune' VALUES (10352, '2009-11-05 23:00:00+00', '2012-01-20 12:54:54.007776+00', 'Ode to Dr Lindsey Thomson', 2856, '');
INSERT INTO 'tune' VALUES (10353, '2009-11-05 23:00:00+00', '2012-01-20 12:54:54.011626+00', 'Miss Mairead MacBeath of the Isle of Skye', 10045, '');
INSERT INTO 'tune' VALUES (10354, '2009-11-05 23:00:00+00', '2012-01-20 12:54:54.015477+00', 'Steven Nicolson', 1677, '');
INSERT INTO 'tune' VALUES (10355, '2009-11-05 23:00:00+00', '2012-01-20 12:54:54.020329+00', 'Carolan''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (10356, '2009-11-05 23:00:00+00', '2012-01-20 12:54:54.024318+00', 'Church Street', 9999, '');
INSERT INTO 'tune' VALUES (10357, '2009-11-06 23:00:00+00', '2012-01-20 12:54:54.028674+00', 'Kenny Thomson''s Reel', 1575, '');
INSERT INTO 'tune' VALUES (10359, '2009-11-06 23:00:00+00', '2012-01-20 12:54:54.036525+00', 'Leila Powrie''s Strathspey', 1554, '');
INSERT INTO 'tune' VALUES (10360, '2009-11-06 23:00:00+00', '2012-01-20 12:54:54.040384+00', 'Morning Moon', 1786, '');
INSERT INTO 'tune' VALUES (10361, '2009-11-06 23:00:00+00', '2012-01-20 12:54:54.044323+00', 'Colin Burns', 1724, '');
INSERT INTO 'tune' VALUES (10362, '2009-11-06 23:00:00+00', '2012-01-20 12:54:54.048161+00', 'Saxavord', 1710, '');
INSERT INTO 'tune' VALUES (10363, '2009-11-06 23:00:00+00', '2012-01-20 12:54:54.052017+00', 'Alisdair Graeme Sneden', 1621, '');
INSERT INTO 'tune' VALUES (10364, '2009-11-06 23:00:00+00', '2012-01-20 12:54:54.055874+00', 'Jack Daniel''s Reel', 3421, '');
INSERT INTO 'tune' VALUES (10365, '2009-11-06 23:00:00+00', '2012-01-20 12:54:54.059756+00', 'Sanda''s Jig', 1608, '');
INSERT INTO 'tune' VALUES (10366, '2009-11-06 23:00:00+00', '2012-01-20 12:54:54.063808+00', 'Crucifield', 1724, '');
INSERT INTO 'tune' VALUES (10367, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.067666+00', 'Myra''s Strathspey', 1539, '');
INSERT INTO 'tune' VALUES (13865, '2018-03-31 11:06:36.779903+00', '2018-03-31 11:06:36.779903+00', 'Afton Pa Solvik', 11618, '');
INSERT INTO 'tune' VALUES (10369, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.075565+00', 'Granny Kate', 2266, '');
INSERT INTO 'tune' VALUES (10370, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.079406+00', 'Centennial Highway Reel, The', 10049, '');
INSERT INTO 'tune' VALUES (10371, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.083363+00', 'Clay Pigeon Shooter, The', 9998, '');
INSERT INTO 'tune' VALUES (10372, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.087231+00', 'Miss Emma Kain', 10048, '');
INSERT INTO 'tune' VALUES (10373, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.091057+00', 'Jack''s Road', 10048, '');
INSERT INTO 'tune' VALUES (10374, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.09501+00', 'Renstry Hall', 10048, '');
INSERT INTO 'tune' VALUES (10375, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.099036+00', 'Lary Smith''s Welcome to Scotland', 10048, '');
INSERT INTO 'tune' VALUES (10376, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.102881+00', 'Carnalea', 10048, '');
INSERT INTO 'tune' VALUES (10377, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.106806+00', 'Miss Jennifer Stewart', 10048, '');
INSERT INTO 'tune' VALUES (10378, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.11065+00', 'Lady Charlotte Campbell''s Medley', 1519, '');
INSERT INTO 'tune' VALUES (10379, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.114492+00', 'Broken Pencil, The', 10048, '');
INSERT INTO 'tune' VALUES (10380, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.11838+00', 'Ian Muir''s Reel', 10048, '');
INSERT INTO 'tune' VALUES (10381, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.122292+00', 'Cupar Burns Club', 10048, '');
INSERT INTO 'tune' VALUES (10382, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.126228+00', 'Andrew C Smith', 10048, '');
INSERT INTO 'tune' VALUES (10383, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.130072+00', 'Barr Tree, The', 10048, '');
INSERT INTO 'tune' VALUES (10384, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.13389+00', 'William J M Young', 10048, '');
INSERT INTO 'tune' VALUES (10386, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.141779+00', 'Blue Braes', 10048, '');
INSERT INTO 'tune' VALUES (10387, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.145732+00', 'Farewell to Kampala', 10048, '');
INSERT INTO 'tune' VALUES (10388, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.149572+00', 'Laurie McKillop', 10050, '');
INSERT INTO 'tune' VALUES (10389, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.153413+00', 'Marie MacLeod', 1811, '');
INSERT INTO 'tune' VALUES (10390, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.15727+00', 'Split Breeks, The', 10051, '');
INSERT INTO 'tune' VALUES (10391, '2009-11-07 23:00:00+00', '2012-01-20 12:54:54.161104+00', 'Invertrossachs House', 3053, '');
INSERT INTO 'tune' VALUES (10392, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.165027+00', 'Ron Monk''s Twiddly Fingers', 10052, '');
INSERT INTO 'tune' VALUES (10393, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.168953+00', 'Morayshire Lassie, The', 1512, '');
INSERT INTO 'tune' VALUES (10394, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.172805+00', 'Lang, Lang Syne, The', 1512, '');
INSERT INTO 'tune' VALUES (10395, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.176648+00', 'Silver Star Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (10396, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.180502+00', 'Sailor''s Hornpipe, A', 9999, '');
INSERT INTO 'tune' VALUES (10397, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.184431+00', 'Babie''s Schottishe', 1512, '');
INSERT INTO 'tune' VALUES (10398, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.18828+00', 'Stewart Tartan', 9999, '');
INSERT INTO 'tune' VALUES (10399, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.192134+00', 'Sutherland Salute', 2961, '');
INSERT INTO 'tune' VALUES (10400, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.195977+00', 'Freddles'' Frolick', 2965, '');
INSERT INTO 'tune' VALUES (10401, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.199819+00', 'My Wee Bouncy Lisa', 2085, '');
INSERT INTO 'tune' VALUES (10402, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.203669+00', 'Kevy''s Wee Tune', 2965, '');
INSERT INTO 'tune' VALUES (10403, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.207608+00', 'TAC Tune, The', 1511, '');
INSERT INTO 'tune' VALUES (10404, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.211457+00', 'Fond Memories', 2054, '');
INSERT INTO 'tune' VALUES (10405, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.215331+00', 'Methven Castle Reel', 10053, '');
INSERT INTO 'tune' VALUES (10406, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.219939+00', 'Captain McCallum''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (10407, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.22382+00', 'Brown Maid, The', 9999, '');
INSERT INTO 'tune' VALUES (10408, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.227771+00', 'Primrose Girl', 9999, '');
INSERT INTO 'tune' VALUES (10409, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.231937+00', 'Miss Caroline Campbell', 10054, '');
INSERT INTO 'tune' VALUES (10410, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.235996+00', 'Johnie Steel', 10055, '');
INSERT INTO 'tune' VALUES (10411, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.239855+00', 'Sweet Memories of Ardler', 1512, '');
INSERT INTO 'tune' VALUES (10412, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.243701+00', 'St. Clair''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (10413, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.247647+00', 'Willaim MacConnell''s Strathspey', 10056, '');
INSERT INTO 'tune' VALUES (10414, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.251685+00', 'Miss K B Crichton', 1507, '');
INSERT INTO 'tune' VALUES (13866, '2018-03-31 11:08:51.735062+00', '2018-03-31 11:08:51.735062+00', 'Lewis and Harris Piping Society', 1507, '');
INSERT INTO 'tune' VALUES (10416, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.259417+00', 'East Point, PEI', 10057, '');
INSERT INTO 'tune' VALUES (10417, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.263262+00', 'Lady Caroline Elizabeth''s Strathspey', 10056, '');
INSERT INTO 'tune' VALUES (10418, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.267322+00', 'Leslie', 9999, '');
INSERT INTO 'tune' VALUES (10420, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.275276+00', 'Leeze Me', 1899, '');
INSERT INTO 'tune' VALUES (10421, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.27911+00', 'Lost Boatman, The', 9999, '');
INSERT INTO 'tune' VALUES (10422, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.283178+00', 'Sunset on Largo Bay', 1558, '');
INSERT INTO 'tune' VALUES (10423, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.287055+00', 'Murdo''s Wedding', 1704, '');
INSERT INTO 'tune' VALUES (10424, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.291028+00', 'Mr Thomas Forbes', 1512, '');
INSERT INTO 'tune' VALUES (10425, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.294945+00', 'Dianne''s Delight', 10058, '');
INSERT INTO 'tune' VALUES (10426, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.298799+00', 'Bonnie Shira Glen', 1659, '');
INSERT INTO 'tune' VALUES (10427, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.302647+00', 'Days That Are Gone', 1505, '');
INSERT INTO 'tune' VALUES (10428, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.30649+00', 'Captain R. G. Duke RN', 1910, '');
INSERT INTO 'tune' VALUES (10429, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.310453+00', 'Twine Weel the Plaiden', 9999, '');
INSERT INTO 'tune' VALUES (10431, '2009-11-08 23:00:00+00', '2012-01-20 12:54:54.318145+00', 'To the Laird', 1899, '');
INSERT INTO 'tune' VALUES (10432, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.321979+00', 'Raggy Morrison''s', 1538, '');
INSERT INTO 'tune' VALUES (10433, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.325822+00', 'Ferry to the Islands, The', 10059, '');
INSERT INTO 'tune' VALUES (10434, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.329763+00', 'Fourth of February, The', 9999, '');
INSERT INTO 'tune' VALUES (10435, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.333794+00', 'Tune for Derek, A', 1793, '');
INSERT INTO 'tune' VALUES (10437, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.341695+00', 'Drookit Donald', 1501, '');
INSERT INTO 'tune' VALUES (10438, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.345552+00', 'Bonnybridge', 9999, '');
INSERT INTO 'tune' VALUES (10439, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.349478+00', 'Humours of Ennistymon', 9999, '');
INSERT INTO 'tune' VALUES (10440, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.353336+00', 'Dept Collector, The', 10060, '');
INSERT INTO 'tune' VALUES (10441, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.357354+00', 'Horseburgh Ford', 10061, '');
INSERT INTO 'tune' VALUES (10442, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.361191+00', 'Bishophill Reel, The', 1558, '');
INSERT INTO 'tune' VALUES (10443, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.365042+00', 'Myra Russell''s Fancy', 1558, '');
INSERT INTO 'tune' VALUES (10444, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.368899+00', 'Kenneth MacFadyn''s Reel', 1558, '');
INSERT INTO 'tune' VALUES (10445, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.372827+00', 'Izzy''s Jig', 10031, '');
INSERT INTO 'tune' VALUES (10446, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.376681+00', 'Miss Jean Paterson''s Jig', 1668, '');
INSERT INTO 'tune' VALUES (10447, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.380526+00', 'Mrs Stewart''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (10448, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.38438+00', 'Morning Star, The', 9999, '');
INSERT INTO 'tune' VALUES (10449, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.388228+00', 'Da Braeview Boy', 10031, '');
INSERT INTO 'tune' VALUES (10450, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.392068+00', 'Dan Piltick Waand', 1710, '');
INSERT INTO 'tune' VALUES (10451, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.397124+00', 'Book of Rights, The', 9999, '');
INSERT INTO 'tune' VALUES (10452, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.400971+00', 'Galloping O'' Hagan', 9999, '');
INSERT INTO 'tune' VALUES (10453, '2009-11-10 23:00:00+00', '2012-01-20 12:54:54.404812+00', 'Mrs Betty Blake', 3186, '');
INSERT INTO 'tune' VALUES (10454, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.408662+00', 'Royal Scot, The', 1591, '');
INSERT INTO 'tune' VALUES (10455, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.412517+00', 'Wishworthy', 2595, '');
INSERT INTO 'tune' VALUES (10456, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.416449+00', 'Birthday Girl', 1591, '');
INSERT INTO 'tune' VALUES (10457, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.420289+00', 'Lucy Strachan''s Reel', 10016, '');
INSERT INTO 'tune' VALUES (10458, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.424143+00', 'Bonny Baby Lynsey', 1507, '');
INSERT INTO 'tune' VALUES (10459, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.427992+00', 'Shetland Gathering, The', 1591, '');
INSERT INTO 'tune' VALUES (10460, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.432113+00', 'Hen and the Turkey, The', 10062, '');
INSERT INTO 'tune' VALUES (10461, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.436116+00', 'Paddy Cumming''s Hornpipe', 1596, '');
INSERT INTO 'tune' VALUES (10463, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.439973+00', 'Homecoming 2009, The', 1591, '');
INSERT INTO 'tune' VALUES (10464, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.443817+00', 'Kenny Wilson''s Reel', 1596, '');
INSERT INTO 'tune' VALUES (10465, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.447657+00', 'Graham Renton''s Hornpipe', 1596, '');
INSERT INTO 'tune' VALUES (10466, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.451503+00', 'Jennie'' Reel', 1591, '');
INSERT INTO 'tune' VALUES (10467, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.455438+00', 'Dutch Girls, The', 1878, '');
INSERT INTO 'tune' VALUES (10469, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.463161+00', 'Inverness Highland Ball, The', 1591, '');
INSERT INTO 'tune' VALUES (10471, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.470882+00', 'Drumadoon Bay', 1596, '');
INSERT INTO 'tune' VALUES (10472, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.474775+00', 'Phil Cunningham''s Reel', 3219, '');
INSERT INTO 'tune' VALUES (10474, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.482505+00', 'Jimmy Lindsay''s Reel', 1770, '');
INSERT INTO 'tune' VALUES (10475, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.486353+00', 'Master Jack Mather', 1591, '');
INSERT INTO 'tune' VALUES (10476, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.490192+00', 'Macintyre Hornpipe, The', 2768, '');
INSERT INTO 'tune' VALUES (10477, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.494043+00', 'Jimmy Kelly''s Hornpipe', 1596, '');
INSERT INTO 'tune' VALUES (10478, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.497974+00', 'Dick Daniel''s Hornpipe', 1596, '');
INSERT INTO 'tune' VALUES (10480, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.501812+00', 'Anne Chesterman''s Reel', 1591, '');
INSERT INTO 'tune' VALUES (10481, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.505871+00', 'Donaldsons of Denholm, The', 1501, '');
INSERT INTO 'tune' VALUES (10482, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.509722+00', 'Maggie Bisset''s Reel', 1668, '');
INSERT INTO 'tune' VALUES (10483, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.51356+00', 'Skatie Shore Strathspey', 1558, '');
INSERT INTO 'tune' VALUES (10484, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.517651+00', 'Lady Anne Shand', 1558, '');
INSERT INTO 'tune' VALUES (10485, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.52159+00', 'Sir Robert''s Strathspey', 1558, '');
INSERT INTO 'tune' VALUES (10486, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.525633+00', 'Rob Sargent''s Reel', 1591, '');
INSERT INTO 'tune' VALUES (10487, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.529488+00', 'Bubba''s Reel', 10064, '');
INSERT INTO 'tune' VALUES (10488, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.533343+00', 'Craggie Hornpipe, The', 1591, '');
INSERT INTO 'tune' VALUES (10489, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.539313+00', 'Sunshine, The', 9999, '');
INSERT INTO 'tune' VALUES (10490, '2009-11-15 23:00:00+00', '2012-01-20 12:54:54.543189+00', 'Lake Peter Jig', 10066, '');
INSERT INTO 'tune' VALUES (10491, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.547243+00', 'Glenfarclas', 2531, '');
INSERT INTO 'tune' VALUES (10493, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.555022+00', 'Mrs Muir MacKenzie''s Delight', 2839, '');
INSERT INTO 'tune' VALUES (10494, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.558999+00', 'Strathconan', 1591, '');
INSERT INTO 'tune' VALUES (10496, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.566916+00', 'Mrs Ferguson of Raith', 1695, '');
INSERT INTO 'tune' VALUES (10497, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.570761+00', 'Reith''s Clarinet', 1512, '');
INSERT INTO 'tune' VALUES (10498, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.574814+00', 'Mrs J Rose', 1946, '');
INSERT INTO 'tune' VALUES (10499, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.578787+00', 'Fireworks', 10068, '');
INSERT INTO 'tune' VALUES (10500, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.582821+00', 'Donald Stewart the Piper', 9999, '');
INSERT INTO 'tune' VALUES (10501, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.586836+00', 'Belles of St Mary''s, The', 2768, '');
INSERT INTO 'tune' VALUES (10502, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.590681+00', 'Nancy Rennie''s Strathspey', 1507, '');
INSERT INTO 'tune' VALUES (10503, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.59453+00', 'Bonny Broom, The', 9999, '');
INSERT INTO 'tune' VALUES (10504, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.598449+00', 'Mary Munro', 1596, '');
INSERT INTO 'tune' VALUES (13867, '2018-03-31 11:14:21.744795+00', '2018-03-31 11:15:31.076317+00', 'Lament for Red Iain', 11619, '');
INSERT INTO 'tune' VALUES (10506, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.606174+00', 'Bellfield Park', 1591, '');
INSERT INTO 'tune' VALUES (10507, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.620398+00', 'Shira''s Jig', 1551, '');
INSERT INTO 'tune' VALUES (10508, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.623487+00', 'Rita''s Birthday Jig', 3655, '');
INSERT INTO 'tune' VALUES (10419, '2009-11-08 23:00:00+00', '2013-08-19 12:00:20.594688+00', 'Messenger, The', 9999, '');
INSERT INTO 'tune' VALUES (10510, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.629332+00', 'Linklater Reel, The', 1586, '');
INSERT INTO 'tune' VALUES (10511, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.632265+00', 'Haulin'' the Ropes', 1596, '');
INSERT INTO 'tune' VALUES (10512, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.635187+00', 'Marco''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (10513, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.638106+00', 'John Johnston''s Strathspey', 1596, '');
INSERT INTO 'tune' VALUES (10514, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.641038+00', 'Tulloch Castle', 9999, '');
INSERT INTO 'tune' VALUES (10515, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.643973+00', 'Miss Isobel Clark''s Favourite', 2613, '');
INSERT INTO 'tune' VALUES (10516, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.646895+00', 'Brodick Ferry', 1538, '');
INSERT INTO 'tune' VALUES (10517, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.649809+00', 'Meiklejohn Reel, The', 1586, '');
INSERT INTO 'tune' VALUES (10518, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.652726+00', 'Loch Earn', 9999, '');
INSERT INTO 'tune' VALUES (10519, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.655649+00', 'Peggy''s Dumpling', 9999, '');
INSERT INTO 'tune' VALUES (10520, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.659003+00', 'Da Wattle o''t', 9999, '');
INSERT INTO 'tune' VALUES (4130, NULL, '2018-06-09 21:43:00.814938+00', 'Mo Mhairi Mhin Meall-Shuileach', 9999, '');
INSERT INTO 'tune' VALUES (10521, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.663079+00', 'Up the Ben and Doon Again', 1586, '');
INSERT INTO 'tune' VALUES (10522, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.665998+00', 'Jimmy Jardine', 1586, '');
INSERT INTO 'tune' VALUES (10523, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.668917+00', 'Glengarry''s Dirk', 10069, '');
INSERT INTO 'tune' VALUES (10524, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.671842+00', 'Kirsteen MacCorquodale', 1582, '');
INSERT INTO 'tune' VALUES (10525, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.674754+00', 'Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (10526, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.677673+00', 'Falcon Square', 2768, '');
INSERT INTO 'tune' VALUES (10527, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.680595+00', 'Gullet''s Brae', 1786, '');
INSERT INTO 'tune' VALUES (10528, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.683516+00', 'Kinara', 1516, '');
INSERT INTO 'tune' VALUES (10529, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.686429+00', 'River Ness, The', 1591, '');
INSERT INTO 'tune' VALUES (10530, '2009-11-16 23:00:00+00', '2012-01-20 12:54:54.689343+00', 'Cockle Gatherer, The', 9999, '');
INSERT INTO 'tune' VALUES (10531, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.692255+00', 'Deluge, The', 2977, '');
INSERT INTO 'tune' VALUES (13868, '2018-03-31 11:14:54.964825+00', '2018-03-31 11:14:54.964825+00', 'Durness Highland Gathering, The', 10941, '');
INSERT INTO 'tune' VALUES (10533, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.698081+00', 'Lady Isabella Wemyss''s Strathspey', 1516, '');
INSERT INTO 'tune' VALUES (10534, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.700993+00', 'Green Dragon''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (10535, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.703916+00', 'Easter Hornpipe', 2977, '');
INSERT INTO 'tune' VALUES (10536, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.706903+00', 'Full Fathom Five', 2977, '');
INSERT INTO 'tune' VALUES (10537, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.70982+00', 'Black Cloak, The', 2977, '');
INSERT INTO 'tune' VALUES (10538, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.712736+00', 'East of Afton Mountain', 2977, '');
INSERT INTO 'tune' VALUES (10539, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.715659+00', 'We Are Devils', 2977, '');
INSERT INTO 'tune' VALUES (10540, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.718583+00', 'Monsters in the Cellar', 2977, '');
INSERT INTO 'tune' VALUES (10541, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.721506+00', 'Phantom of the Operetta', 2977, '');
INSERT INTO 'tune' VALUES (10542, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.724436+00', 'Nighean Dubh Alasdair', 9999, '');
INSERT INTO 'tune' VALUES (10543, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.727592+00', 'Last Ten Minutes, The', 2977, '');
INSERT INTO 'tune' VALUES (10544, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.730541+00', 'Rothiemurcus Rant', 9999, '');
INSERT INTO 'tune' VALUES (10545, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.733457+00', 'Okinawa Reunion', 2977, '');
INSERT INTO 'tune' VALUES (10546, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.736379+00', 'Sound of Iona Strathspey, The', 9999, '');
INSERT INTO 'tune' VALUES (10547, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.739373+00', 'Andrew Wallace''s Reel', 1626, '');
INSERT INTO 'tune' VALUES (10548, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.742369+00', 'Golden Shores Reel, The', 1796, '');
INSERT INTO 'tune' VALUES (10549, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.745283+00', 'Miss B A Nairn', 1556, '');
INSERT INTO 'tune' VALUES (10551, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.751268+00', 'Stewart and Kathleen Walker', 1525, '');
INSERT INTO 'tune' VALUES (10552, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.754187+00', 'Bannet Stane, The', 1555, '');
INSERT INTO 'tune' VALUES (10553, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.757095+00', 'Canadian Four Step', 9999, '');
INSERT INTO 'tune' VALUES (10554, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.76002+00', 'United Distillers'' Strathspey, The', 1594, '');
INSERT INTO 'tune' VALUES (10555, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.762933+00', 'Euna Scott Reel, The', 1594, '');
INSERT INTO 'tune' VALUES (10556, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.765856+00', 'Alex McPhee''s Auld Fiddle', 1554, '');
INSERT INTO 'tune' VALUES (10558, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.771691+00', 'Geordie, Geordie Stop the Cairt', 10072, '');
INSERT INTO 'tune' VALUES (10559, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.774617+00', 'Geoff and Joan Desborough', 1590, '');
INSERT INTO 'tune' VALUES (10560, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.777528+00', 'Blair Athole', 9999, '');
INSERT INTO 'tune' VALUES (10561, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.780439+00', 'Mrs Norman McKeigan', 1766, '');
INSERT INTO 'tune' VALUES (10563, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.786282+00', 'Tribute to Rena, A', 1594, '');
INSERT INTO 'tune' VALUES (10564, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.789202+00', 'Margaret Morrison', 10073, '');
INSERT INTO 'tune' VALUES (10565, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.792124+00', 'Provost Spink and his Lady''s Welcome to the Grange', 10074, '');
INSERT INTO 'tune' VALUES (10566, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.795044+00', 'Gerry Fraser''s Jig', 1606, '');
INSERT INTO 'tune' VALUES (10567, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.797956+00', 'Just Mo', 1582, '');
INSERT INTO 'tune' VALUES (10568, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.800911+00', 'Walter Rutherford', 3186, '');
INSERT INTO 'tune' VALUES (10571, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.809681+00', 'Ian Cathcart''s Reel', 10038, '');
INSERT INTO 'tune' VALUES (10572, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.813073+00', 'Mackenzie''s Farewell to Sutherland', 9999, '');
INSERT INTO 'tune' VALUES (10573, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.816014+00', 'Sarah Elizabeth', 1502, '');
INSERT INTO 'tune' VALUES (10575, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.821886+00', 'One For All', 1502, '');
INSERT INTO 'tune' VALUES (10576, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.824891+00', 'Two For One', 1502, '');
INSERT INTO 'tune' VALUES (10577, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.827824+00', 'Berwick Braveheart, The', 1502, '');
INSERT INTO 'tune' VALUES (10578, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.83076+00', 'Auchtertool Volunteers Quickstep', 9999, '');
INSERT INTO 'tune' VALUES (10580, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.836642+00', 'Miss Jean Donaldson''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (10582, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.84249+00', 'Judith Peterson', 1613, '');
INSERT INTO 'tune' VALUES (10583, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.845401+00', 'Bouncing the Bairn', 1815, '');
INSERT INTO 'tune' VALUES (10584, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.848324+00', 'Tom Elliot', 1558, '');
INSERT INTO 'tune' VALUES (10586, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.851258+00', 'I''m Pedalin'' Doon Hill', 1508, '');
INSERT INTO 'tune' VALUES (10587, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.854174+00', 'Smithy''s Black Beauty', 1808, '');
INSERT INTO 'tune' VALUES (10588, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.857088+00', 'Rachel Wilton''s Delight', 1502, '');
INSERT INTO 'tune' VALUES (10589, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.860007+00', 'Ferguson Frolics', 1502, '');
INSERT INTO 'tune' VALUES (10590, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.862923+00', 'Bill Craib', 3058, '');
INSERT INTO 'tune' VALUES (10591, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.865839+00', 'Debbie Ann''s Reel', 10077, '');
INSERT INTO 'tune' VALUES (10592, '2009-11-17 23:00:00+00', '2012-01-20 12:54:54.868764+00', 'Bibby McDonald of Fasgadh', 10078, '');
INSERT INTO 'tune' VALUES (10593, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.872154+00', 'Steve''s Train to the Moon', 10080, '');
INSERT INTO 'tune' VALUES (10594, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.875117+00', 'Adrian''s', 10080, '');
INSERT INTO 'tune' VALUES (10595, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.878044+00', 'Express from Rotterdam', 10080, '');
INSERT INTO 'tune' VALUES (10596, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.880965+00', 'Long Island Jig, The', 1673, '');
INSERT INTO 'tune' VALUES (10597, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.883888+00', 'Our Wee Man', 1808, '');
INSERT INTO 'tune' VALUES (10598, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.886817+00', 'Bride''s Strathspey, The', 10081, '');
INSERT INTO 'tune' VALUES (10599, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.889729+00', 'Memories of Bert Murray', 1808, '');
INSERT INTO 'tune' VALUES (10600, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.892643+00', 'Last Straw, The', 10082, '');
INSERT INTO 'tune' VALUES (10601, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.895561+00', 'Wullie Stewart O'' Lauder', 10083, '');
INSERT INTO 'tune' VALUES (10602, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.898486+00', 'Alison Smith''s Strathspey', 1808, '');
INSERT INTO 'tune' VALUES (5327, NULL, '2014-08-24 15:07:16.395694+00', 'Gold and Silver', 2491, '');
INSERT INTO 'tune' VALUES (10604, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.904316+00', 'Nurse Mary Graham''s Jig', 1507, '');
INSERT INTO 'tune' VALUES (10605, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.907234+00', 'Rab Smilie''s Jig', 10074, '');
INSERT INTO 'tune' VALUES (10606, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.910163+00', 'Quiet One, The', 1605, '');
INSERT INTO 'tune' VALUES (10579, '2009-11-17 23:00:00+00', '2014-11-09 00:10:12.182388+00', 'Ian & Betty''s Jig', 2842, '');
INSERT INTO 'tune' VALUES (10607, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.913093+00', 'Christine the Bash', 2085, '');
INSERT INTO 'tune' VALUES (10608, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.916597+00', 'Jennifer Hamilton', 1808, '');
INSERT INTO 'tune' VALUES (10609, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.919659+00', 'Farewell to Kelty', 1808, '');
INSERT INTO 'tune' VALUES (10612, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.928725+00', 'Levenwick Beach', 3655, '');
INSERT INTO 'tune' VALUES (10613, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.931681+00', 'Song Without Words', 1539, '');
INSERT INTO 'tune' VALUES (10614, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.9346+00', 'Cynthia', 10084, '');
INSERT INTO 'tune' VALUES (10615, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.937523+00', 'Alasdair Fraser''s Welcome to the Academy', 10083, '');
INSERT INTO 'tune' VALUES (10616, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.940601+00', 'Bibby MacDonald of Fasgadh', 1605, '');
INSERT INTO 'tune' VALUES (10617, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.943533+00', 'Old Pioneer, The', 1580, '');
INSERT INTO 'tune' VALUES (10619, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.949383+00', 'Mr Kobayashi''s Strathspey', 1808, '');
INSERT INTO 'tune' VALUES (10620, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.952312+00', 'Jackie Clark''s Jig', 1525, '');
INSERT INTO 'tune' VALUES (10550, '2009-11-17 23:00:00+00', '2018-10-06 13:55:54.858768+00', 'Marie McLeod', 1811, '');
INSERT INTO 'tune' VALUES (10621, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.955232+00', 'Susan Martin''s Welcome to the Island of Barbados', 3145, '');
INSERT INTO 'tune' VALUES (10622, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.958148+00', 'Wee Drippin'' Roast, The', 3145, '');
INSERT INTO 'tune' VALUES (10624, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.963974+00', 'Let there be Drams', 3146, '');
INSERT INTO 'tune' VALUES (10625, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.966889+00', 'Lynn''s Reel', 2208, '');
INSERT INTO 'tune' VALUES (10626, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.969867+00', 'Miss Sharon McCusker', 3146, '');
INSERT INTO 'tune' VALUES (10627, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.972818+00', 'Ian Collie''s Reel', 1558, '');
INSERT INTO 'tune' VALUES (10628, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.975742+00', 'Peter''s Reel (No 4)', 10083, '');
INSERT INTO 'tune' VALUES (10629, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.97868+00', 'Nigel Stivla', 10086, '');
INSERT INTO 'tune' VALUES (10630, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.98159+00', 'Brodag Ain Mcomish', 9999, '');
INSERT INTO 'tune' VALUES (10631, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.984518+00', 'Barbara L Macdonald', 1507, '');
INSERT INTO 'tune' VALUES (10632, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.987451+00', 'Trip to Ballymena', 10087, '');
INSERT INTO 'tune' VALUES (10633, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.990399+00', 'Kelsey''s Wee Reel', 10088, '');
INSERT INTO 'tune' VALUES (10635, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.996359+00', 'Inverquharity Castle Strathspey', 2841, '');
INSERT INTO 'tune' VALUES (10636, '2009-11-20 23:00:00+00', '2012-01-20 12:54:54.999309+00', 'Garthland House Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (10637, '2009-11-20 23:00:00+00', '2012-01-20 12:54:55.002223+00', 'Aboyne Castle', 9999, '');
INSERT INTO 'tune' VALUES (10638, '2009-11-20 23:00:00+00', '2012-01-20 12:54:55.005139+00', 'Duke of Gordon''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (10639, '2009-11-20 23:00:00+00', '2012-01-20 12:54:55.00811+00', 'Shake a Leg', 3146, '');
INSERT INTO 'tune' VALUES (10640, '2009-11-20 23:00:00+00', '2012-01-20 12:54:55.011046+00', 'Tom McKerron''s Reel', 2661, '');
INSERT INTO 'tune' VALUES (10641, '2009-11-20 23:00:00+00', '2012-01-20 12:54:55.013956+00', 'Billy Maguire''s Box', 1505, '');
INSERT INTO 'tune' VALUES (10642, '2009-11-20 23:00:00+00', '2012-01-20 12:54:55.016879+00', 'Jas. F Dickie''s Delight', 1750, '');
INSERT INTO 'tune' VALUES (10645, '2009-11-20 23:00:00+00', '2012-01-20 12:54:55.025642+00', 'Ronnie Maclellan', 1791, '');
INSERT INTO 'tune' VALUES (10646, '2009-11-20 23:00:00+00', '2012-01-20 12:54:55.028564+00', 'Tom Paine''s Strathspey', 3146, '');
INSERT INTO 'tune' VALUES (10649, '2009-11-20 23:00:00+00', '2012-01-20 12:54:55.037341+00', 'Nancy Barrowman''s Fancy', 3186, '');
INSERT INTO 'tune' VALUES (10650, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.040295+00', 'City of Belfast, The', 3220, '');
INSERT INTO 'tune' VALUES (10652, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.046149+00', 'Ladies from Kildare', 9999, '');
INSERT INTO 'tune' VALUES (10653, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.049065+00', 'Peggy Spouse', 3220, '');
INSERT INTO 'tune' VALUES (10654, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.052173+00', 'Marjory Watson''s Strathspey', 3220, '');
INSERT INTO 'tune' VALUES (10655, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.055258+00', 'Fiona''s Valentine', 3220, '');
INSERT INTO 'tune' VALUES (10656, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.058329+00', 'Tripping up the Stairs', 9999, '');
INSERT INTO 'tune' VALUES (10657, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.061399+00', 'Gander in the Pratie Hole, The', 9999, '');
INSERT INTO 'tune' VALUES (10658, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.064516+00', 'Paddy Clancy''s', 9999, '');
INSERT INTO 'tune' VALUES (10659, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.067698+00', 'Diamond for Belfast, A', 3220, '');
INSERT INTO 'tune' VALUES (10660, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.070792+00', 'Compiler''s Jig', 1673, '');
INSERT INTO 'tune' VALUES (10661, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.073962+00', 'Jeely Pond', 3186, '');
INSERT INTO 'tune' VALUES (10662, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.077067+00', 'Addie Harper''s Jig', 3052, '');
INSERT INTO 'tune' VALUES (10663, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.080132+00', 'J2', 3220, '');
INSERT INTO 'tune' VALUES (10666, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.090498+00', 'Malcolm Macaskill', 1605, '');
INSERT INTO 'tune' VALUES (10667, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.094478+00', 'Soup Dragon, The', 3129, '');
INSERT INTO 'tune' VALUES (10668, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.098556+00', 'Rory Gallacher', 3129, '');
INSERT INTO 'tune' VALUES (10669, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.102528+00', 'Alex''s Haircut', 3129, '');
INSERT INTO 'tune' VALUES (10670, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.10643+00', 'Moray Firth Hornpipe, The', 1502, '');
INSERT INTO 'tune' VALUES (10671, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.11028+00', 'K''nockers Jig, The', 1502, '');
INSERT INTO 'tune' VALUES (10672, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.114903+00', '5th of July', 1502, '');
INSERT INTO 'tune' VALUES (10673, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.118909+00', 'Aye Afloat', 1502, '');
INSERT INTO 'tune' VALUES (10675, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.127249+00', 'Doon the Brae', 1502, '');
INSERT INTO 'tune' VALUES (10676, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.131133+00', 'Port Hill Strathspey, The', 1502, '');
INSERT INTO 'tune' VALUES (10677, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.136013+00', 'Port Hill Reel, The', 1502, '');
INSERT INTO 'tune' VALUES (10678, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.140012+00', 'Sheltered Cove, The', 1502, '');
INSERT INTO 'tune' VALUES (10679, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.143896+00', 'Cadger''s Roadie, The', 1502, '');
INSERT INTO 'tune' VALUES (10680, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.147772+00', 'Judy''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (10681, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.15167+00', 'J.B. Jig, The', 1502, '');
INSERT INTO 'tune' VALUES (10682, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.155563+00', 'Flagstaff and Cairn, The', 1502, '');
INSERT INTO 'tune' VALUES (10684, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.163312+00', 'Marianna''s Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (10685, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.167261+00', 'Three Creeks Shore, The', 1502, '');
INSERT INTO 'tune' VALUES (10686, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.172078+00', 'Bow Fiddle Strathspey, The', 1502, '');
INSERT INTO 'tune' VALUES (10687, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.175994+00', 'Bow Fiddle Reel, The', 1502, '');
INSERT INTO 'tune' VALUES (10688, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.179838+00', 'Whale''s Moo, The', 1502, '');
INSERT INTO 'tune' VALUES (10689, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.183723+00', 'Lindsay''s Classic', 1502, '');
INSERT INTO 'tune' VALUES (10690, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.187568+00', 'Vienna Reel, The', 1502, '');
INSERT INTO 'tune' VALUES (10691, '2009-11-21 23:00:00+00', '2012-01-20 12:54:55.191408+00', 'Jenny''s Well', 1502, '');
INSERT INTO 'tune' VALUES (10692, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.195249+00', 'Campbeltown Loch', 9999, '');
INSERT INTO 'tune' VALUES (10693, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.199093+00', 'Trumpet Polka, The', 10089, '');
INSERT INTO 'tune' VALUES (10694, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.202928+00', 'Hame, Hame, Hame', 9999, '');
INSERT INTO 'tune' VALUES (10695, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.206905+00', 'My Heart''s Desire', 10090, '');
INSERT INTO 'tune' VALUES (10696, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.210768+00', 'My Darling Anna', 10091, '');
INSERT INTO 'tune' VALUES (10697, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.2146+00', 'Tender Dairymaid, The', 9999, '');
INSERT INTO 'tune' VALUES (10698, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.218673+00', 'She is My Daisy', 9998, '');
INSERT INTO 'tune' VALUES (10699, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.222512+00', 'Jig of Elurs', 9999, '');
INSERT INTO 'tune' VALUES (10700, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.226349+00', 'Slieve Russell', 9999, '');
INSERT INTO 'tune' VALUES (10701, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.230209+00', 'Miss Margaret McLachlan', 9999, '');
INSERT INTO 'tune' VALUES (10702, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.234055+00', 'Cheticamp Reel', 9999, '');
INSERT INTO 'tune' VALUES (10703, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.237892+00', 'Reel of Limoilou', 9999, '');
INSERT INTO 'tune' VALUES (10704, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.241722+00', 'Easter Broomhouse', 3710, '');
INSERT INTO 'tune' VALUES (10705, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.245561+00', 'Master Ben Dorkin of Stag Hill', 1590, '');
INSERT INTO 'tune' VALUES (10634, '2009-11-20 23:00:00+00', '2020-06-17 19:21:25.956115+00', 'G Shand''s Compliments to Robert Mathieson', 1808, '');
INSERT INTO 'tune' VALUES (10664, '2009-11-21 23:00:00+00', '2021-10-25 10:34:41.263102+00', 'Iain Peterson', 1596, 'Possible duplicate of <<ddt:Iain Peterson''s Reel#2064>>?');
INSERT INTO 'tune' VALUES (10674, '2009-11-21 23:00:00+00', '2021-11-25 07:36:18.340791+00', 'Heid o'' the Brae, The', 1502, '');
INSERT INTO 'tune' VALUES (10706, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.249384+00', 'Da Nippon Grund', 9999, '');
INSERT INTO 'tune' VALUES (10707, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.253216+00', 'Square da Mizzen', 9999, '');
INSERT INTO 'tune' VALUES (10708, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.25705+00', 'Up an Doon da Harbour', 9999, '');
INSERT INTO 'tune' VALUES (10709, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.260877+00', 'Busta', 9999, '');
INSERT INTO 'tune' VALUES (10710, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.264714+00', 'Barry Burn, The', 810, '');
INSERT INTO 'tune' VALUES (10711, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.268545+00', 'Leck, The', 1591, '');
INSERT INTO 'tune' VALUES (10611, '2009-11-20 23:00:00+00', '2022-12-26 18:24:49.207489+00', '79th''s Farewell to Gibraltar, The', 2595, '');
INSERT INTO 'tune' VALUES (10712, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.272389+00', 'Ross Angus', 1576, '');
INSERT INTO 'tune' VALUES (10713, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.276224+00', 'Kevin McGlynn', 1543, '');
INSERT INTO 'tune' VALUES (10714, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.28005+00', 'Miss Emily Smith''s Favourite', 10092, '');
INSERT INTO 'tune' VALUES (10715, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.283882+00', 'Mr Robert Scott of Turin', 10093, '');
INSERT INTO 'tune' VALUES (10716, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.287715+00', 'Scots Guards Departure for Egypt', 10094, '');
INSERT INTO 'tune' VALUES (10717, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.29157+00', 'Scots Guards Farewell to Sharjah', 2738, '');
INSERT INTO 'tune' VALUES (10718, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.295408+00', 'Hamelincourt', 1699, '');
INSERT INTO 'tune' VALUES (10719, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.299245+00', 'Carnoustie Scottish Country Dance Club', 1576, '');
INSERT INTO 'tune' VALUES (13900, '2018-06-09 21:45:36.291091+00', '2018-06-09 21:45:36.291091+00', 'Marry Me Now', 9999, '');
INSERT INTO 'tune' VALUES (10720, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.303085+00', 'Arran Jumper, The', 1578, '');
INSERT INTO 'tune' VALUES (10721, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.306916+00', 'Gairie Burn, The', 1578, '');
INSERT INTO 'tune' VALUES (10722, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.310754+00', 'Ian Nicolson''s Reel', 10016, '');
INSERT INTO 'tune' VALUES (10723, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.314577+00', 'Delaney''s Donkey', 1727, '');
INSERT INTO 'tune' VALUES (10724, '2009-11-22 23:00:00+00', '2012-01-20 12:54:55.318404+00', 'Jock McInroy', 1646, '');
INSERT INTO 'tune' VALUES (10726, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.326203+00', 'Ada Johnstone''s Fancy', 1668, '');
INSERT INTO 'tune' VALUES (10727, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.330137+00', 'Jack''s Life', 2400, '');
INSERT INTO 'tune' VALUES (10728, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.333974+00', 'Allie''s Reel', 10096, '');
INSERT INTO 'tune' VALUES (10729, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.337815+00', 'Ballochdule', 1538, '');
INSERT INTO 'tune' VALUES (10730, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.341649+00', 'Aylesbury Fiddle Rally Anniversary March', 1631, '');
INSERT INTO 'tune' VALUES (10731, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.345488+00', 'Pop the Question', 10097, '');
INSERT INTO 'tune' VALUES (10732, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.349315+00', 'Auntie''s Jig', 1631, '');
INSERT INTO 'tune' VALUES (10733, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.353145+00', 'Marching Through Georgia', 9999, '');
INSERT INTO 'tune' VALUES (10734, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.356982+00', 'Rollstone Mountain', 2400, '');
INSERT INTO 'tune' VALUES (10735, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.360827+00', 'Honey Harbour Two-Step', 9999, '');
INSERT INTO 'tune' VALUES (10736, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.364664+00', 'Poppy Fields Strathspey', 1631, '');
INSERT INTO 'tune' VALUES (10737, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.368497+00', 'Golden Memories', 1811, '');
INSERT INTO 'tune' VALUES (10738, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.372327+00', 'Furrows End, The', 1811, '');
INSERT INTO 'tune' VALUES (10739, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.376154+00', 'Reel Lindbergh', 10098, '');
INSERT INTO 'tune' VALUES (10740, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.379984+00', 'Reel des Esquimaux', 10099, '');
INSERT INTO 'tune' VALUES (10741, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.383823+00', 'Reel Maisonneuve', 10100, '');
INSERT INTO 'tune' VALUES (10742, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.387658+00', 'Friendly Visit', 9999, '');
INSERT INTO 'tune' VALUES (10743, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.391489+00', 'Buggy Ride Jig', 9999, '');
INSERT INTO 'tune' VALUES (10744, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.395319+00', 'Wurlitzer Special', 10097, '');
INSERT INTO 'tune' VALUES (10745, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.399146+00', 'Glen Mallan', 3296, '');
INSERT INTO 'tune' VALUES (10746, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.402987+00', 'Johnnie''s Jig', 3052, '');
INSERT INTO 'tune' VALUES (10747, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.406829+00', 'Half a World Away', 1631, '');
INSERT INTO 'tune' VALUES (10748, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.410677+00', 'Moving Up', 1631, '');
INSERT INTO 'tune' VALUES (10750, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.418358+00', 'Miss Clementina Loughan', 9999, '');
INSERT INTO 'tune' VALUES (10752, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.426032+00', 'Canbusdoon', 1603, '');
INSERT INTO 'tune' VALUES (10753, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.429864+00', 'Rose Acre', 9999, '');
INSERT INTO 'tune' VALUES (10754, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.433768+00', 'Sandra', 1603, '');
INSERT INTO 'tune' VALUES (10756, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.441509+00', 'Jill Simson of Chapelhill', 1522, '');
INSERT INTO 'tune' VALUES (10757, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.445344+00', 'Hazel Twig, The', 1538, '');
INSERT INTO 'tune' VALUES (10758, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.449189+00', 'Wearie We''ve Been', 9999, '');
INSERT INTO 'tune' VALUES (10759, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.453034+00', 'Ballochduie', 1538, '');
INSERT INTO 'tune' VALUES (10760, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.456873+00', 'Ann & Tam Leggat', 1554, '');
INSERT INTO 'tune' VALUES (10761, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.460693+00', 'Bobby Colgan''s Reel', 1554, '');
INSERT INTO 'tune' VALUES (10762, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.464535+00', 'Jemimaville Jig', 1538, '');
INSERT INTO 'tune' VALUES (10763, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.468377+00', 'Jean Hamilton''s Strathspey', 10103, '');
INSERT INTO 'tune' VALUES (10764, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.472214+00', 'Mary & Lloyd Augustus', 10103, '');
INSERT INTO 'tune' VALUES (10765, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.476055+00', 'He''s O''er the Hills and Far Away', 9999, '');
INSERT INTO 'tune' VALUES (10766, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.47989+00', 'Wee Robert', 1554, '');
INSERT INTO 'tune' VALUES (10770, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.495224+00', 'Carol', 1576, '');
INSERT INTO 'tune' VALUES (10772, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.502898+00', 'Troy''s Wedding', 1672, '');
INSERT INTO 'tune' VALUES (10773, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.506727+00', 'Thief of Lochaber, The', 3296, '');
INSERT INTO 'tune' VALUES (10774, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.510579+00', 'Walrus, The', 1673, '');
INSERT INTO 'tune' VALUES (10775, '2009-11-23 23:00:00+00', '2012-01-20 12:54:55.51441+00', 'Jig for Garry, A', 3220, '');
INSERT INTO 'tune' VALUES (10776, '2009-11-26 23:00:00+00', '2012-01-20 12:54:55.518225+00', 'Carnegie''s Welcome to Scotland', 9999, '');
INSERT INTO 'tune' VALUES (10777, '2009-11-26 23:00:00+00', '2012-01-20 12:54:55.522081+00', 'Frolic, The', 9999, '');
INSERT INTO 'tune' VALUES (10778, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.525912+00', 'Robbie''s Farewell', 10106, '');
INSERT INTO 'tune' VALUES (10779, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.529948+00', 'Colonel McLean of Ardgour', 1700, '');
INSERT INTO 'tune' VALUES (10780, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.533784+00', 'Margaret Manson', 1724, '');
INSERT INTO 'tune' VALUES (10781, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.537611+00', 'Old Comrades', 9998, '');
INSERT INTO 'tune' VALUES (10782, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.541447+00', 'Sandy Carr', 10017, '');
INSERT INTO 'tune' VALUES (10783, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.545281+00', 'Kirkhill', 2951, '');
INSERT INTO 'tune' VALUES (10784, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.549111+00', 'Ann & Rab Martin of Ballintuim', 10105, '');
INSERT INTO 'tune' VALUES (10785, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.552956+00', 'On the Mark', 9999, '');
INSERT INTO 'tune' VALUES (10786, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.556788+00', 'Sullivan', 10107, '');
INSERT INTO 'tune' VALUES (10787, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.560618+00', 'Market Town, The', 9999, '');
INSERT INTO 'tune' VALUES (10788, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.564439+00', 'Buttermilk Mary', 9999, '');
INSERT INTO 'tune' VALUES (10789, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.568272+00', 'Jimmy Shand Polka, The', 1558, '');
INSERT INTO 'tune' VALUES (10790, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.572094+00', 'I Want to be Happy', 9998, '');
INSERT INTO 'tune' VALUES (10791, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.575929+00', 'Whispering', 9998, '');
INSERT INTO 'tune' VALUES (10792, '2009-11-28 23:00:00+00', '2012-01-20 12:54:55.579764+00', 'Don Guillemette Hoedown', 10107, '');
INSERT INTO 'tune' VALUES (10793, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.583599+00', 'On Thin Ice', 1836, '');
INSERT INTO 'tune' VALUES (10794, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.587457+00', 'Masako', 1836, '');
INSERT INTO 'tune' VALUES (10795, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.591288+00', 'Tartan Lady, The', 1836, '');
INSERT INTO 'tune' VALUES (10796, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.595138+00', 'Yukio''s Reel', 1836, '');
INSERT INTO 'tune' VALUES (10797, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.598981+00', 'Monkey Puzzle Tree, The', 1836, '');
INSERT INTO 'tune' VALUES (10798, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.602815+00', 'Twin Towns Reel, The', 1836, '');
INSERT INTO 'tune' VALUES (10799, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.606646+00', 'Brigadier, The', 1836, '');
INSERT INTO 'tune' VALUES (10800, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.610484+00', 'Alliston Spring', 1836, '');
INSERT INTO 'tune' VALUES (10801, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.614309+00', 'English Mountain', 1836, '');
INSERT INTO 'tune' VALUES (10802, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.618291+00', 'Strulach, The', 1836, '');
INSERT INTO 'tune' VALUES (10803, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.622129+00', 'Breaking Away', 1836, '');
INSERT INTO 'tune' VALUES (10804, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.625953+00', 'Dr. William Orovan', 1836, '');
INSERT INTO 'tune' VALUES (10805, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.629796+00', 'John Moffatt Middleton', 1836, '');
INSERT INTO 'tune' VALUES (10749, '2009-11-23 23:00:00+00', '2020-01-25 22:30:51.109875+00', 'Ben Wilson''s Fairwell to Troloss', 10101, 'The original SCDDB entry has "Fairwell" though a web search suggests "Farewell" is more likely. This has been added as an alias.');
INSERT INTO 'tune' VALUES (10806, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.633639+00', 'Blistering Fingers', 9999, '');
INSERT INTO 'tune' VALUES (10807, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.637472+00', 'Balintore', 9999, '');
INSERT INTO 'tune' VALUES (10808, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.641306+00', 'Alex McDonald Fort William', 9999, '');
INSERT INTO 'tune' VALUES (10810, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.648968+00', 'Dairy Maid, The', 9999, '');
INSERT INTO 'tune' VALUES (10811, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.652799+00', 'Brennan''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (10812, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.656644+00', 'Blaikie''s Back Yard', 9999, '');
INSERT INTO 'tune' VALUES (10813, '2009-11-29 23:00:00+00', '2012-01-20 12:54:55.660532+00', 'Baby Brat', 9999, '');
INSERT INTO 'tune' VALUES (10814, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.664469+00', 'Ottowa Reel', 9999, '');
INSERT INTO 'tune' VALUES (10815, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.668305+00', 'Fluff on the Carpet', 9999, '');
INSERT INTO 'tune' VALUES (10816, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.672145+00', 'Lawson''s Strathspey', 1512, '');
INSERT INTO 'tune' VALUES (10817, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.675969+00', 'Canadian Capers', 9999, '');
INSERT INTO 'tune' VALUES (10818, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.679817+00', 'Nimble Fingers', 1750, '');
INSERT INTO 'tune' VALUES (10819, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.683649+00', 'Cumberland Rant', 9999, '');
INSERT INTO 'tune' VALUES (10820, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.687479+00', 'Bob McQuillan''s', 3219, '');
INSERT INTO 'tune' VALUES (10821, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.691312+00', 'Dance o'' da Shetland Puffins', 2253, '');
INSERT INTO 'tune' VALUES (10822, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.695155+00', 'Bellevue', 1535, '');
INSERT INTO 'tune' VALUES (10824, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.702861+00', 'Fiona Leask''s Waltz', 2253, '');
INSERT INTO 'tune' VALUES (10825, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.706701+00', 'Oot Ower Lounge, Da', 2253, '');
INSERT INTO 'tune' VALUES (10826, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.71053+00', 'Don Farquhar o'' Hoswick', 2253, '');
INSERT INTO 'tune' VALUES (10827, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.714375+00', 'Rob Smith''s Wedding', 1645, '');
INSERT INTO 'tune' VALUES (10828, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.718212+00', 'Jarl Squad 2003''s Compliments to Towie & District Pipe Band', 2253, '');
INSERT INTO 'tune' VALUES (10829, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.722054+00', 'Olaf Sitricson', 2253, '');
INSERT INTO 'tune' VALUES (10830, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.725878+00', 'Magnus and Dot''s Wedding', 10110, '');
INSERT INTO 'tune' VALUES (10831, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.729859+00', 'Thorvald Thoreffon''s March', 2253, '');
INSERT INTO 'tune' VALUES (10832, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.733689+00', 'Mousa Broch', 2253, '');
INSERT INTO 'tune' VALUES (10833, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.737522+00', 'Lennie Smith of Heylor', 10111, '');
INSERT INTO 'tune' VALUES (10834, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.741362+00', 'Passing Places', 10112, '');
INSERT INTO 'tune' VALUES (10835, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.745222+00', 'Show Jig, The', 10113, '');
INSERT INTO 'tune' VALUES (10836, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.749166+00', 'Shetland Fisherman''s Backstep, The', 1645, '');
INSERT INTO 'tune' VALUES (10837, '2009-11-30 23:00:00+00', '2012-01-20 12:54:55.753006+00', 'Da Fustra', 9999, '');
INSERT INTO 'tune' VALUES (10838, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.756827+00', 'Jack''s Humour', 1526, '');
INSERT INTO 'tune' VALUES (10839, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.760661+00', 'Piper and the Dancer, The', 1526, '');
INSERT INTO 'tune' VALUES (10840, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.764504+00', 'Bob & Wendy''s Ruby Strathspey', 1526, '');
INSERT INTO 'tune' VALUES (10842, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.772163+00', 'Jenny''s Magic Touch', 1526, '');
INSERT INTO 'tune' VALUES (10843, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.775999+00', 'Crossing Borders', 10115, '');
INSERT INTO 'tune' VALUES (10844, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.779841+00', 'Bells of Greenhill, The', 1526, '');
INSERT INTO 'tune' VALUES (10845, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.783663+00', 'Quarryman''s Jig, The', 1538, '');
INSERT INTO 'tune' VALUES (10846, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.787492+00', 'John Beldon''s Twostep', 9999, '');
INSERT INTO 'tune' VALUES (10847, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.791341+00', 'Charleytown Twostep', 9999, '');
INSERT INTO 'tune' VALUES (10848, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.795168+00', 'Joy of the Dance, The', 9999, '');
INSERT INTO 'tune' VALUES (10849, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.799003+00', 'Memories of Brecon', 1526, '');
INSERT INTO 'tune' VALUES (10850, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.802824+00', 'Toast to the Harveys, A', 1526, '');
INSERT INTO 'tune' VALUES (10851, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.806652+00', 'Katz Jig', 10116, '');
INSERT INTO 'tune' VALUES (10852, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.810483+00', 'Morecambe Strathspey', 1526, '');
INSERT INTO 'tune' VALUES (10853, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.81431+00', 'Broadway, The', 1526, '');
INSERT INTO 'tune' VALUES (10854, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.818138+00', 'Winter Gardens, The', 1526, '');
INSERT INTO 'tune' VALUES (10855, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.821958+00', 'Stone Jetty, The', 1526, '');
INSERT INTO 'tune' VALUES (10856, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.825785+00', 'David Jones Locker', 1526, '');
INSERT INTO 'tune' VALUES (13870, '2018-03-31 11:18:14.717606+00', '2018-03-31 11:18:14.717606+00', 'Brown Haired Maid, The', 3296, '');
INSERT INTO 'tune' VALUES (10858, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.833461+00', 'Dulcie''s Party', 1526, '');
INSERT INTO 'tune' VALUES (10859, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.837274+00', 'Tea with Sylvia', 1526, '');
INSERT INTO 'tune' VALUES (10860, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.8411+00', 'Appleby Horse Fair', 1526, '');
INSERT INTO 'tune' VALUES (10861, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.844938+00', 'Sir Stamford Raffles', 1526, '');
INSERT INTO 'tune' VALUES (10862, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.848768+00', 'Rockside Welcome', 1526, '');
INSERT INTO 'tune' VALUES (10863, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.852596+00', 'Kenneth''s Helping Hand', 1526, '');
INSERT INTO 'tune' VALUES (10865, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.860265+00', 'Gentle Annie''s Irish Stew', 2234, '');
INSERT INTO 'tune' VALUES (10867, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.86795+00', 'Silver Salver, The', 9999, '');
INSERT INTO 'tune' VALUES (10868, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.872234+00', 'Countess of Rothes''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (10869, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.876094+00', 'Abercombies, The', 1591, '');
INSERT INTO 'tune' VALUES (10870, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.879982+00', 'Miss Jacquelynn Stuart''s Reel', 1591, '');
INSERT INTO 'tune' VALUES (10871, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.883821+00', 'Palmette Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (10872, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.887655+00', 'Remembrance of Dublin', 9999, '');
INSERT INTO 'tune' VALUES (10873, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.891574+00', 'Mrs Farquharson of Inveraray', 1695, '');
INSERT INTO 'tune' VALUES (10874, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.895431+00', 'Strawberry Jam', 10016, '');
INSERT INTO 'tune' VALUES (10875, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.899274+00', 'Mrs Jay Robertson''s Hornpipe', 1591, '');
INSERT INTO 'tune' VALUES (10876, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.903122+00', 'Mr McColl''s Hornpipe', 1591, '');
INSERT INTO 'tune' VALUES (10877, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.906946+00', 'Kingston Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (10878, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.910783+00', 'St Pierre Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (10879, '2009-12-01 23:00:00+00', '2012-01-20 12:54:55.914609+00', 'Tribute to the Black Watch', 1591, '');
INSERT INTO 'tune' VALUES (10880, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.918435+00', 'Conor''s Ceilidh', 10118, '');
INSERT INTO 'tune' VALUES (10881, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.922263+00', 'Sheffield Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (10882, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.926209+00', 'Scott Erin Reel, The', 1857, '');
INSERT INTO 'tune' VALUES (10883, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.930117+00', 'Lord and the Duke, The', 10118, '');
INSERT INTO 'tune' VALUES (10884, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.933943+00', 'Bernard and Barbara Harris', 10118, '');
INSERT INTO 'tune' VALUES (10885, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.93778+00', 'Sanny Speirs', 1441, '');
INSERT INTO 'tune' VALUES (10887, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.945447+00', 'John Barleycorn', 9999, '');
INSERT INTO 'tune' VALUES (10888, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.949277+00', 'Duncan''s Tale', 9998, '');
INSERT INTO 'tune' VALUES (10889, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.953127+00', 'Sparrow in the Sycamore', 10120, '');
INSERT INTO 'tune' VALUES (10890, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.956959+00', 'Keith Lowden', 10017, '');
INSERT INTO 'tune' VALUES (10891, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.960784+00', 'Hedgepig', 10120, '');
INSERT INTO 'tune' VALUES (10892, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.964614+00', 'Geordie Snorter, The', 316, '');
INSERT INTO 'tune' VALUES (10893, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.968456+00', 'Miss Anna James', 316, '');
INSERT INTO 'tune' VALUES (10894, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.972294+00', 'D.P.B.', 10118, '');
INSERT INTO 'tune' VALUES (10895, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.976128+00', 'Guernsey Scottish Association, The', 10118, '');
INSERT INTO 'tune' VALUES (10896, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.979971+00', 'Kerrera Polka', 3058, '');
INSERT INTO 'tune' VALUES (10897, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.983804+00', 'Sandy''s Shetland Stag Week', 2253, '');
INSERT INTO 'tune' VALUES (10898, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.987642+00', 'Port Na Coite', 10124, '');
INSERT INTO 'tune' VALUES (10899, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.991478+00', 'Hill at Lochiel, The', 9999, '');
INSERT INTO 'tune' VALUES (10900, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.995315+00', 'Alan C Beaton of Tobermory', 3058, '');
INSERT INTO 'tune' VALUES (10901, '2009-12-02 23:00:00+00', '2012-01-20 12:54:55.999154+00', 'I See Mull', 9999, '');
INSERT INTO 'tune' VALUES (10902, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.002987+00', 'Fiona Ferguson', 9999, '');
INSERT INTO 'tune' VALUES (10903, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.006821+00', 'Donegal Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (10904, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.01065+00', 'Templehouse Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (10866, '2009-12-01 23:00:00+00', '2020-08-05 22:37:27.552896+00', 'Sir J.M. Barrie of Thrums', 2208, '');
INSERT INTO 'tune' VALUES (10809, '2009-11-29 23:00:00+00', '2021-10-17 10:13:16.159926+00', 'Doc Boyd''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (10905, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.014493+00', 'Bantry Bay', 9999, '');
INSERT INTO 'tune' VALUES (10906, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.018332+00', 'Galway Bay', 9999, '');
INSERT INTO 'tune' VALUES (10907, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.022171+00', 'Redford Cottage', 10125, '');
INSERT INTO 'tune' VALUES (10908, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.026002+00', 'Ben Ghuilean', 10126, '');
INSERT INTO 'tune' VALUES (10909, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.029853+00', 'Tour of Mull', 1605, '');
INSERT INTO 'tune' VALUES (10910, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.033698+00', 'Welcome to the Mull Musiic Festival', 1605, '');
INSERT INTO 'tune' VALUES (10911, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.037542+00', 'Tobermory Reel, The', 1605, '');
INSERT INTO 'tune' VALUES (10912, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.041418+00', 'Joshua James', 10127, '');
INSERT INTO 'tune' VALUES (10913, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.045355+00', 'Charles Anderson', 1910, '');
INSERT INTO 'tune' VALUES (10914, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.049193+00', 'Troy''s Wedding', 9999, '');
INSERT INTO 'tune' VALUES (10915, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.053028+00', 'Oysterman, The', 1605, '');
INSERT INTO 'tune' VALUES (10916, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.056851+00', 'Sheffield Dancers, The', 10118, '');
INSERT INTO 'tune' VALUES (10917, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.060766+00', 'There was a Lad (was born in Kyle)', 9999, '');
INSERT INTO 'tune' VALUES (10918, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.064605+00', 'Dingle, The', 10118, '');
INSERT INTO 'tune' VALUES (10920, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.072262+00', 'Still on Probation', 10118, '');
INSERT INTO 'tune' VALUES (10921, '2009-12-02 23:00:00+00', '2012-01-20 12:54:56.076093+00', 'Ian Powrie''s March O''er the Midden', 9998, '');
INSERT INTO 'tune' VALUES (10922, '2009-12-06 23:00:00+00', '2012-01-20 12:54:56.07994+00', 'Bunker Hill', 9999, '');
INSERT INTO 'tune' VALUES (10923, '2009-12-06 23:00:00+00', '2012-01-20 12:54:56.083778+00', 'Argyll Square, The', 9998, '');
INSERT INTO 'tune' VALUES (10924, '2009-12-06 23:00:00+00', '2012-01-20 12:54:56.087617+00', 'Jerry Slate', 9998, '');
INSERT INTO 'tune' VALUES (10925, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.091448+00', 'O''Keane''s March', 9999, '');
INSERT INTO 'tune' VALUES (10926, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.095638+00', 'Whither Shall I wander', 9999, '');
INSERT INTO 'tune' VALUES (10927, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.099494+00', 'Kildare Waltz', 10130, '');
INSERT INTO 'tune' VALUES (10928, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.103321+00', 'Keith Anderson'' Two-Step, The', 1590, '');
INSERT INTO 'tune' VALUES (10929, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.107153+00', 'Hush! Here Comes a Whizz Bang', 10131, '');
INSERT INTO 'tune' VALUES (10930, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.111043+00', 'On Sunday I walk out with a Soldier', 10132, '');
INSERT INTO 'tune' VALUES (10931, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.122303+00', 'It''s A Long Way to Tipperary', 10133, '');
INSERT INTO 'tune' VALUES (10932, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.126095+00', 'Glenshee Skiers, The', 1538, '');
INSERT INTO 'tune' VALUES (10933, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.130102+00', 'South Georgia Whaling Song', 9999, '');
INSERT INTO 'tune' VALUES (10934, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.133964+00', 'Grant''s Canadian Polka', 1621, '');
INSERT INTO 'tune' VALUES (10935, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.138969+00', 'Master Alexander Forbes of Woodley', 1590, '');
INSERT INTO 'tune' VALUES (10936, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.142859+00', 'Buck Fever Rag', 10134, '');
INSERT INTO 'tune' VALUES (10937, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.146738+00', 'Woman in Black, The', 1590, '');
INSERT INTO 'tune' VALUES (10938, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.150729+00', 'Bowin'' the Strings', 2653, '');
INSERT INTO 'tune' VALUES (10939, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.154564+00', 'Snedesglarn', 10135, '');
INSERT INTO 'tune' VALUES (10940, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.158472+00', 'Dunphy''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (10941, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.163928+00', 'Reluctant Piper, The', 9999, '');
INSERT INTO 'tune' VALUES (10942, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.166941+00', 'Millicen''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (10943, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.169953+00', 'Sarah and Dave''s Wedding', 10136, '');
INSERT INTO 'tune' VALUES (10944, '2009-12-09 23:00:00+00', '2012-01-20 12:54:56.173507+00', 'Kitty''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (10945, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.176458+00', 'Admiral Levison Gower', 9999, '');
INSERT INTO 'tune' VALUES (10946, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.179384+00', 'Gobie O'', The', 9999, '');
INSERT INTO 'tune' VALUES (10947, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.182344+00', 'Birnam Wood', 1974, '');
INSERT INTO 'tune' VALUES (10948, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.185293+00', 'Traditional Polka', 9999, '');
INSERT INTO 'tune' VALUES (10949, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.188216+00', 'Miss Stronach of Marnoch''s Strathspey', 10138, '');
INSERT INTO 'tune' VALUES (10950, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.191222+00', 'Myosotis', 10137, '');
INSERT INTO 'tune' VALUES (10951, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.19415+00', 'Dugald MacColl''s Farewell to France', 1694, '');
INSERT INTO 'tune' VALUES (10952, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.197073+00', 'Crags o'' Lundie, The', 2319, '');
INSERT INTO 'tune' VALUES (10953, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.199991+00', 'Mrs Jean MacGregor', 10139, '');
INSERT INTO 'tune' VALUES (10954, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.202925+00', 'Bessie''s Hill', 1668, '');
INSERT INTO 'tune' VALUES (10955, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.205849+00', 'Ryan J. McLaren', 10140, '');
INSERT INTO 'tune' VALUES (10956, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.208775+00', 'Miss Maria Stewart', 9999, '');
INSERT INTO 'tune' VALUES (10957, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.211769+00', 'Mark R. McLaren', 10140, '');
INSERT INTO 'tune' VALUES (10958, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.214701+00', 'Bill Ewan''s Strathspey', 2208, '');
INSERT INTO 'tune' VALUES (10959, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.217623+00', 'Johnny Murray''s Rant', 2208, '');
INSERT INTO 'tune' VALUES (10960, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.2209+00', 'Fiona Elizabeth Eckersley', 1657, '');
INSERT INTO 'tune' VALUES (10961, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.224113+00', 'Northmuir Jig', 10140, '');
INSERT INTO 'tune' VALUES (10962, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.227071+00', 'Mrs Dorothy Donaldson', 10140, '');
INSERT INTO 'tune' VALUES (10963, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.22999+00', 'Jim Smith''s Jig', 10140, '');
INSERT INTO 'tune' VALUES (10964, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.233023+00', 'Ian MacCallum''s Jig', 2208, '');
INSERT INTO 'tune' VALUES (10965, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.235951+00', 'Square of Glamis', 2208, '');
INSERT INTO 'tune' VALUES (10966, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.239361+00', 'John Martin''s Strathspey', 2208, '');
INSERT INTO 'tune' VALUES (10967, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.24234+00', 'Fiddler''s Relief', 2208, '');
INSERT INTO 'tune' VALUES (10968, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.245262+00', 'Mrs Curran''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (10969, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.248185+00', 'Barbara Dorothy Russell''s Strathspey', 2208, '');
INSERT INTO 'tune' VALUES (10970, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.251175+00', 'All the Way to Galway', 9999, '');
INSERT INTO 'tune' VALUES (10971, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.254132+00', 'Wired Up to the Moon', 2208, '');
INSERT INTO 'tune' VALUES (10972, '2009-12-16 23:00:00+00', '2012-01-20 12:54:56.257094+00', 'Willie Hay', 9999, '');
INSERT INTO 'tune' VALUES (10973, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.260029+00', 'Skyline of Skye, The', 9999, '');
INSERT INTO 'tune' VALUES (10975, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.265867+00', 'Goodnight, Joy Be Wi'' You', 9999, '');
INSERT INTO 'tune' VALUES (10976, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.269093+00', 'De''ils Awa'', The', 9999, '');
INSERT INTO 'tune' VALUES (10977, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.27209+00', 'Hamlet', 9999, '');
INSERT INTO 'tune' VALUES (10979, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.277941+00', 'Links of Love, The', 9999, '');
INSERT INTO 'tune' VALUES (10981, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.283783+00', 'K.O.S. Bies, The', 9999, '');
INSERT INTO 'tune' VALUES (10982, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.286708+00', 'H.L.I., The', 9999, '');
INSERT INTO 'tune' VALUES (10983, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.289622+00', 'Argyll and Sutherland Highlanders, The', 9999, '');
INSERT INTO 'tune' VALUES (10984, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.293828+00', 'Black Watch, The', 9999, '');
INSERT INTO 'tune' VALUES (10985, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.296823+00', 'Jeannie McColl', 9999, '');
INSERT INTO 'tune' VALUES (10986, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.299756+00', 'Bonnie Boy', 9999, '');
INSERT INTO 'tune' VALUES (10988, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.305608+00', 'My Irish Jaunting Car', 9999, '');
INSERT INTO 'tune' VALUES (10989, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.308545+00', 'Sean''s Air', 9999, '');
INSERT INTO 'tune' VALUES (10990, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.311469+00', 'Hills of Perth, The', 9999, '');
INSERT INTO 'tune' VALUES (10991, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.314504+00', 'Cailin Mo Ruin-sa', 9999, '');
INSERT INTO 'tune' VALUES (10992, '2009-12-22 23:00:00+00', '2012-01-20 12:54:56.317432+00', 'Miss Johnstone''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (10994, '2009-12-27 23:00:00+00', '2012-01-20 12:54:56.323285+00', 'Ye Jacobites By Name', 9999, '');
INSERT INTO 'tune' VALUES (10996, '2009-12-27 23:00:00+00', '2012-01-20 12:54:56.329152+00', 'And Oh! For Ane and Twenty Tam', 9999, '');
INSERT INTO 'tune' VALUES (10997, '2009-12-27 23:00:00+00', '2012-01-20 12:54:56.332079+00', 'Lassie wi the Lint White Locks', 9999, '');
INSERT INTO 'tune' VALUES (10999, '2009-12-27 23:00:00+00', '2012-01-20 12:54:56.338069+00', 'Flow Gently Sweet Afton', 9999, '');
INSERT INTO 'tune' VALUES (11000, '2009-12-27 23:00:00+00', '2012-01-20 12:54:56.340984+00', 'Miss Angela Johnston', 3220, '');
INSERT INTO 'tune' VALUES (11001, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.343913+00', 'Mary Young and Fair', 2142, '');
INSERT INTO 'tune' VALUES (11002, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.346837+00', 'House of New, The', 1516, '');
INSERT INTO 'tune' VALUES (11003, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.349774+00', 'Mrs J Bishop''s Strathspey', 1516, '');
INSERT INTO 'tune' VALUES (11004, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.352688+00', 'Faroe Rum', 9999, '');
INSERT INTO 'tune' VALUES (11005, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.355826+00', 'Jamie Roy', 9999, '');
INSERT INTO 'tune' VALUES (11006, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.358951+00', 'Sandy''s Farm Steading', 9999, '');
INSERT INTO 'tune' VALUES (11007, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.36192+00', 'Shains o'' the Pocky, The', 1512, '');
INSERT INTO 'tune' VALUES (11008, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.375482+00', 'Kincaldrum', 1790, '');
INSERT INTO 'tune' VALUES (11009, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.379602+00', 'Clanranald', 1790, '');
INSERT INTO 'tune' VALUES (11010, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.383441+00', 'Bonnie Birks of Balmoral', 1632, '');
INSERT INTO 'tune' VALUES (11011, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.387275+00', 'Miss Farquahar of Invercauld''s Jig', 1695, '');
INSERT INTO 'tune' VALUES (11012, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.391107+00', 'Mrs Farquarson''s Jigg', 1695, '');
INSERT INTO 'tune' VALUES (11013, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.394919+00', 'Lady Susan Gordon''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (11014, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.397985+00', 'Miss Murray''s Reel', 1495, '');
INSERT INTO 'tune' VALUES (10974, '2009-12-22 23:00:00+00', '2022-12-08 23:50:47.544231+00', 'Mo Cailleag Fhein', 12218, '');
INSERT INTO 'tune' VALUES (10995, '2009-12-27 23:00:00+00', '2023-01-30 18:06:37.098688+00', 'When Wild War''s Deadly Blast Was Blawn', 9999, '');
INSERT INTO 'tune' VALUES (11015, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.400918+00', 'Shutter''s Hornpipe', 10149, '');
INSERT INTO 'tune' VALUES (11016, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.403846+00', 'Turnpike Gate', 10150, '');
INSERT INTO 'tune' VALUES (11017, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.406769+00', 'Mistake, The', 10149, '');
INSERT INTO 'tune' VALUES (11018, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.409693+00', 'Mid Way, The', 10149, '');
INSERT INTO 'tune' VALUES (11019, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.412609+00', 'Cumberland Nelly', 9999, '');
INSERT INTO 'tune' VALUES (11021, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.418603+00', 'Boy Fae Da Bid', 10151, '');
INSERT INTO 'tune' VALUES (11022, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.421688+00', 'Bulgarian Reel', 2661, '');
INSERT INTO 'tune' VALUES (11023, '2010-01-19 23:00:00+00', '2012-01-20 12:54:56.424623+00', 'Bancroft Crofters, The', 2661, '');
INSERT INTO 'tune' VALUES (11024, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.427544+00', 'Turnpike, The', 9999, '');
INSERT INTO 'tune' VALUES (11025, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.430478+00', 'Glen Mavis Two-Step, The', 1576, '');
INSERT INTO 'tune' VALUES (11026, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.433397+00', 'Gordon and Dianne''s Wedding March', 10039, '');
INSERT INTO 'tune' VALUES (11027, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.436523+00', 'Tune for Ron', 1656, '');
INSERT INTO 'tune' VALUES (11028, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.439711+00', 'Annan British Legion Pipe Band, The', 10152, '');
INSERT INTO 'tune' VALUES (11029, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.442666+00', 'Valentine''s Waltz', 10111, '');
INSERT INTO 'tune' VALUES (11030, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.445581+00', 'Waar Blade, The', 10111, '');
INSERT INTO 'tune' VALUES (11031, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.448499+00', 'Andy''s Jig', 10153, '');
INSERT INTO 'tune' VALUES (11032, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.451429+00', 'Cameron Highlanders, The', 2859, '');
INSERT INTO 'tune' VALUES (11033, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.454357+00', 'Yodelling Piper, The', 1596, '');
INSERT INTO 'tune' VALUES (11034, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.457272+00', 'Catherine MacDonald''s Polka', 1550, '');
INSERT INTO 'tune' VALUES (11035, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.460341+00', 'GSP', 1576, '');
INSERT INTO 'tune' VALUES (11036, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.463425+00', 'Allan Johnstone', 1527, '');
INSERT INTO 'tune' VALUES (11037, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.466381+00', 'Nordlandsidyll', 10154, '');
INSERT INTO 'tune' VALUES (11038, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.469303+00', 'Auchtermuchty Gala March', 1558, '');
INSERT INTO 'tune' VALUES (11039, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.472443+00', 'Waltz for Kirsty', 1576, '');
INSERT INTO 'tune' VALUES (11040, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.475539+00', 'Shallow Fish Reel, The', 2253, '');
INSERT INTO 'tune' VALUES (11041, '2010-01-25 23:00:00+00', '2012-01-20 12:54:56.478773+00', 'Ethel''s Hangover', 1603, '');
INSERT INTO 'tune' VALUES (11042, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.48177+00', 'Edwin Flaws of Wyre', 1580, '');
INSERT INTO 'tune' VALUES (11043, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.484698+00', 'Commander David Stogdon RNLI', 1580, '');
INSERT INTO 'tune' VALUES (11044, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.487628+00', 'Finnish Waltz, The', 9999, '');
INSERT INTO 'tune' VALUES (11045, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.490551+00', 'Blasted Man, The', 1580, '');
INSERT INTO 'tune' VALUES (11046, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.493651+00', 'Pipe Major Willie Gray''s Farewell to the City of Glasgow Police', 10060, 'May or may not be the same as <<ddt:Pipe Major William Gray''s Farewell to Cowal>>, which is also purportedly by one J. MacDonald. Can somebody who is into pipe tunes check this out?');
INSERT INTO 'tune' VALUES (11047, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.496619+00', 'Meigle Smiddy, The', 1580, '');
INSERT INTO 'tune' VALUES (11048, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.499653+00', 'Far Away in Australia', 9999, '');
INSERT INTO 'tune' VALUES (11049, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.502601+00', 'Norwegian Waltz', 9999, '');
INSERT INTO 'tune' VALUES (11050, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.505507+00', 'Pull Down The Blind', 9999, '');
INSERT INTO 'tune' VALUES (11051, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.508457+00', 'McKinley''s March', 10156, '');
INSERT INTO 'tune' VALUES (11052, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.511389+00', 'Ingram''s 35', 1580, '');
INSERT INTO 'tune' VALUES (11053, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.51431+00', 'Polkan Går', 9999, '');
INSERT INTO 'tune' VALUES (11054, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.517218+00', 'Greenlandic Tune', 1580, '');
INSERT INTO 'tune' VALUES (11055, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.52025+00', 'You Married My Daughter', 9999, '');
INSERT INTO 'tune' VALUES (11056, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.523191+00', 'Captain Murdo Kennedy', 1580, '');
INSERT INTO 'tune' VALUES (11057, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.526379+00', 'Captain Alec Morrison', 1580, '');
INSERT INTO 'tune' VALUES (11058, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.529363+00', 'Watsons of Park Stile, The', 1580, '');
INSERT INTO 'tune' VALUES (11059, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.532288+00', 'Robsons of Rayheugh, The', 1580, '');
INSERT INTO 'tune' VALUES (11060, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.535198+00', 'Murrays of Rothbury, The', 1580, '');
INSERT INTO 'tune' VALUES (11061, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.538116+00', 'American Reel', 9999, '');
INSERT INTO 'tune' VALUES (11062, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.54239+00', 'Veleta, The', 458, '');
INSERT INTO 'tune' VALUES (11063, '2010-02-10 23:00:00+00', '2012-01-20 12:54:56.545352+00', 'Mount Auburn', 1580, '');
INSERT INTO 'tune' VALUES (11064, '2010-02-13 23:00:00+00', '2012-01-20 12:54:56.548276+00', 'My Love is out', 9999, '');
INSERT INTO 'tune' VALUES (11065, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.551273+00', 'Welcome to Ayr', 1591, '');
INSERT INTO 'tune' VALUES (11066, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.554218+00', 'Meadowbank Jig', 10160, '');
INSERT INTO 'tune' VALUES (11067, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.557138+00', 'St Ninian''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (11068, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.560062+00', 'Craigie Hall', 9999, '');
INSERT INTO 'tune' VALUES (11069, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.562982+00', 'Road to Girvan, The', 10159, '');
INSERT INTO 'tune' VALUES (11070, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.566008+00', 'Derskelpin''s Lass', 1603, '');
INSERT INTO 'tune' VALUES (11071, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.568927+00', 'Back o'' the Lake', 3798, '');
INSERT INTO 'tune' VALUES (11072, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.571852+00', 'Flinton Fiddle Club', 3798, '');
INSERT INTO 'tune' VALUES (11073, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.574769+00', 'Harwey Jig, The', 9999, '');
INSERT INTO 'tune' VALUES (11074, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.577711+00', 'Kitty Cat, The', 3798, '');
INSERT INTO 'tune' VALUES (11075, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.580821+00', 'Helen MacKinnon Frame', 1502, '');
INSERT INTO 'tune' VALUES (11076, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.583971+00', 'Isle of Beauty', 9999, '');
INSERT INTO 'tune' VALUES (11077, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.586965+00', 'Donside', 9999, '');
INSERT INTO 'tune' VALUES (11078, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.589907+00', 'Braes o'' Mar', 9999, '');
INSERT INTO 'tune' VALUES (11079, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.592833+00', 'Newton Shore', 1408, '');
INSERT INTO 'tune' VALUES (11080, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.595757+00', 'Lady of the Lake', 3798, '');
INSERT INTO 'tune' VALUES (11081, '2010-04-14 22:00:00+00', '2012-01-20 12:54:56.598816+00', 'Reel de Jeunes Maries', 9999, '');
INSERT INTO 'tune' VALUES (11082, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.601775+00', 'Fear a Chog Ard Angus McKelvie', 10161, '');
INSERT INTO 'tune' VALUES (11083, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.604768+00', 'Two Mile Brig', 9999, '');
INSERT INTO 'tune' VALUES (11084, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.607741+00', 'Eriskay Lilt Jig', 3052, '');
INSERT INTO 'tune' VALUES (11085, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.610674+00', 'Fisherman''s Jig, The', 10161, '');
INSERT INTO 'tune' VALUES (11086, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.613583+00', 'We''d Rather Be Here', 10162, '');
INSERT INTO 'tune' VALUES (11087, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.616503+00', 'MacDougall, McNab and MacKay', 9999, '');
INSERT INTO 'tune' VALUES (11088, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.619577+00', 'Here''s to the Hills', 9999, '');
INSERT INTO 'tune' VALUES (11089, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.622693+00', 'One for the Road', 9999, '');
INSERT INTO 'tune' VALUES (11090, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.625755+00', 'Mary of Bhaile Chro', 9999, '');
INSERT INTO 'tune' VALUES (11091, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.628702+00', 'For Thee I Sigh', 9999, '');
INSERT INTO 'tune' VALUES (11092, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.63163+00', 'Donald Ban of Kyles Flodda', 10163, '');
INSERT INTO 'tune' VALUES (11093, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.634556+00', 'Goldfinch, The', 9999, '');
INSERT INTO 'tune' VALUES (11094, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.637472+00', 'O'' Redigan''s', 9999, '');
INSERT INTO 'tune' VALUES (11095, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.640748+00', 'Farewell to Ballinascorney', 9999, '');
INSERT INTO 'tune' VALUES (11096, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.643696+00', 'Donald MacKay of Upper Barvas', 10164, '');
INSERT INTO 'tune' VALUES (11097, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.646731+00', 'Mr & Mrs Robert Henderson of Cullivoe', 1811, '');
INSERT INTO 'tune' VALUES (11098, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.649667+00', 'Rait Castle', 1539, '');
INSERT INTO 'tune' VALUES (11099, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.652593+00', 'Bays of Harris, The', 10163, '');
INSERT INTO 'tune' VALUES (11100, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.655518+00', 'Willie & Bertha''s Boston', 10110, '');
INSERT INTO 'tune' VALUES (11101, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.658869+00', 'Kenny Allan', 10165, '');
INSERT INTO 'tune' VALUES (11102, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.66192+00', 'Bill Wilkie MBE', 1668, '');
INSERT INTO 'tune' VALUES (11103, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.664849+00', 'Old Joe', 9999, '');
INSERT INTO 'tune' VALUES (11104, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.668157+00', 'Bottle Eyes', 10080, '');
INSERT INTO 'tune' VALUES (11105, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.671099+00', 'Dubai Desert Dance, The', 10080, '');
INSERT INTO 'tune' VALUES (11106, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.674024+00', 'Hamilton''s Nutsack', 3094, '');
INSERT INTO 'tune' VALUES (11107, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.676933+00', 'Chasing Shawdows', 10166, '');
INSERT INTO 'tune' VALUES (11108, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.679909+00', 'Reeled off Wood', 10080, '');
INSERT INTO 'tune' VALUES (11109, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.683034+00', 'Henderson''s Reel', 1673, '');
INSERT INTO 'tune' VALUES (11110, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.685968+00', 'March for Morvern May, A', 2362, '');
INSERT INTO 'tune' VALUES (11111, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.688956+00', 'Blue Danube, The', 10169, '');
INSERT INTO 'tune' VALUES (11112, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.691891+00', 'Donauwellen', 10170, '');
INSERT INTO 'tune' VALUES (11113, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.695144+00', 'Skater''s Waltz, The', 10171, '');
INSERT INTO 'tune' VALUES (11114, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.698111+00', 'Johnny Gillies''s Barn', 1426, '');
INSERT INTO 'tune' VALUES (11115, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.701033+00', 'Dancing on the Sands', 9999, '');
INSERT INTO 'tune' VALUES (11116, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.703955+00', 'On the Spree', 9999, '');
INSERT INTO 'tune' VALUES (11117, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.706993+00', 'Janet''s Wedding', 9999, '');
INSERT INTO 'tune' VALUES (11118, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.709937+00', 'Ginga Whinga, The', 10172, '');
INSERT INTO 'tune' VALUES (11119, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.712854+00', 'Aly''s Ginger Cake Experience', 10172, '');
INSERT INTO 'tune' VALUES (11120, '2010-05-29 22:00:00+00', '2012-01-20 12:54:56.71578+00', 'Don the Drone Tuner', 10172, '');
INSERT INTO 'tune' VALUES (11121, '2010-05-30 22:00:00+00', '2012-01-20 12:54:56.7187+00', 'June Clover', 9999, '');
INSERT INTO 'tune' VALUES (11123, '2010-05-30 22:00:00+00', '2012-01-20 12:54:56.724527+00', 'Tribute to late Mrs Shepherd, A', 2407, '');
INSERT INTO 'tune' VALUES (11124, '2010-05-30 22:00:00+00', '2012-01-20 12:54:56.727467+00', 'Kitaguni no Haru/ The North in Springtime', 10175, '');
INSERT INTO 'tune' VALUES (11125, '2010-05-30 22:00:00+00', '2012-01-20 12:54:56.730508+00', 'Sara', 1606, '');
INSERT INTO 'tune' VALUES (11127, '2010-05-30 22:00:00+00', '2012-01-20 12:54:56.736388+00', 'Colonel is a Lady, The', 1556, '');
INSERT INTO 'tune' VALUES (11128, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.739307+00', 'Old Grey Mare, The', 9999, '');
INSERT INTO 'tune' VALUES (11129, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.742219+00', 'Ragman''s Ball, The', 9999, '');
INSERT INTO 'tune' VALUES (11130, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.745615+00', 'Maid of the Sweet Brown Knowe, The', 9999, '');
INSERT INTO 'tune' VALUES (11131, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.748719+00', 'Whitehall', 9999, '');
INSERT INTO 'tune' VALUES (11132, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.751791+00', 'Price of my Pig, The', 9999, '');
INSERT INTO 'tune' VALUES (11133, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.754728+00', 'Fergie MacDonald''s Jig', 1507, '');
INSERT INTO 'tune' VALUES (11134, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.757654+00', 'Once in a While', 10178, '');
INSERT INTO 'tune' VALUES (11135, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.760799+00', 'For All We Know', 10179, '');
INSERT INTO 'tune' VALUES (11136, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.76374+00', 'Loch Seridain', 1605, '');
INSERT INTO 'tune' VALUES (11137, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.766662+00', 'Be-Aest Da Hill', 10180, '');
INSERT INTO 'tune' VALUES (11138, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.769658+00', 'Da Seggie Burn', 10180, '');
INSERT INTO 'tune' VALUES (11139, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.772615+00', 'Da Quarrie Boys', 10180, '');
INSERT INTO 'tune' VALUES (11140, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.775538+00', 'Jim and Muriel Smith''s Ruby Wedding Waltz', 10140, '');
INSERT INTO 'tune' VALUES (11141, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.778465+00', 'Fairways', 2516, '');
INSERT INTO 'tune' VALUES (11142, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.781382+00', 'I''ll Always Be in Love With You', 10181, '');
INSERT INTO 'tune' VALUES (11143, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.784301+00', 'Dream Lover', 10182, '');
INSERT INTO 'tune' VALUES (11144, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.787211+00', 'Scalpaidh', 9999, '');
INSERT INTO 'tune' VALUES (11145, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.790236+00', 'General Hunt''s Welcome to the Queen''s Own Highlanders', 9999, '');
INSERT INTO 'tune' VALUES (11146, '2010-06-01 22:00:00+00', '2012-01-20 12:54:56.793188+00', 'Auchterhouse Pipe Band, The', 1611, '');
INSERT INTO 'tune' VALUES (11147, '2010-06-07 22:00:00+00', '2012-01-20 12:54:56.796122+00', 'Miss Elsbeth Campbell', 9999, '');
INSERT INTO 'tune' VALUES (11148, '2010-06-07 22:00:00+00', '2012-01-20 12:54:56.799047+00', 'Thoughts of Burns', 9999, '');
INSERT INTO 'tune' VALUES (11149, '2010-06-07 22:00:00+00', '2012-01-20 12:54:56.801961+00', 'Auld Reekie Schottische, The', 9999, '');
INSERT INTO 'tune' VALUES (11150, '2010-06-07 22:00:00+00', '2012-01-20 12:54:56.804889+00', 'KOSB''s Farewell to Meirut', 9999, '');
INSERT INTO 'tune' VALUES (11151, '2010-06-07 22:00:00+00', '2012-01-20 12:54:56.807826+00', 'Brigadier-General Ronald Cheape of Tiroran', 9999, '');
INSERT INTO 'tune' VALUES (11152, '2010-06-07 22:00:00+00', '2012-01-20 12:54:56.81085+00', 'My Mother Told Me', 9999, '');
INSERT INTO 'tune' VALUES (11153, '2010-06-07 22:00:00+00', '2012-01-20 12:54:56.813779+00', 'Ataireachd Ard, An', 9999, '');
INSERT INTO 'tune' VALUES (11154, '2010-06-07 22:00:00+00', '2012-01-20 12:54:56.816689+00', 'King Robert the Bruce', 1512, '');
INSERT INTO 'tune' VALUES (11156, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.822531+00', 'Viewforth', 10184, '');
INSERT INTO 'tune' VALUES (11157, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.825446+00', 'JJ''s Reel', 1508, '');
INSERT INTO 'tune' VALUES (11158, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.82837+00', 'Grassmarket Reel, The', 1846, '');
INSERT INTO 'tune' VALUES (11159, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.831352+00', 'Mr Grant of Rothiemurchus', 1519, '');
INSERT INTO 'tune' VALUES (11160, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.834373+00', 'Baillie Blackwood''s Strathspey', 1554, '');
INSERT INTO 'tune' VALUES (11161, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.837353+00', 'Tanwick Ha''', 1710, '');
INSERT INTO 'tune' VALUES (11162, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.840627+00', 'Salute to Betty Pow', 1626, '');
INSERT INTO 'tune' VALUES (11163, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.843579+00', 'Betty Anderson', 120, '');
INSERT INTO 'tune' VALUES (11164, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.846497+00', 'Herrickside', 1626, '');
INSERT INTO 'tune' VALUES (11165, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.849408+00', 'Don Taylor''s Strathspey', 2768, '');
INSERT INTO 'tune' VALUES (11166, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.852432+00', 'Linn Pot, The', 1804, '');
INSERT INTO 'tune' VALUES (11167, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.855368+00', 'Mrs Janet Ellis', 1554, '');
INSERT INTO 'tune' VALUES (11168, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.858282+00', 'Reunion, The', 1706, '');
INSERT INTO 'tune' VALUES (11169, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.861188+00', 'Na Garbh Chriochan', 2842, '');
INSERT INTO 'tune' VALUES (11170, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.864112+00', 'Jiggy Tiggy', 3436, '');
INSERT INTO 'tune' VALUES (11171, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.867233+00', 'Gwen''s Passed', 3436, '');
INSERT INTO 'tune' VALUES (11172, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.870188+00', 'Graham''s Reel', 1706, '');
INSERT INTO 'tune' VALUES (11173, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.873394+00', 'Cheap Meal', 9999, '');
INSERT INTO 'tune' VALUES (11174, '2010-08-07 22:00:00+00', '2012-01-20 12:54:56.876362+00', 'Auchindoun Castle', 1748, '');
INSERT INTO 'tune' VALUES (11175, '2010-08-08 22:00:00+00', '2012-01-20 12:54:56.879302+00', 'Christine M Phillips', 3220, '');
INSERT INTO 'tune' VALUES (11176, '2010-08-08 22:00:00+00', '2012-01-20 12:54:56.882248+00', 'Morag''s Ceilidh', 3052, '');
INSERT INTO 'tune' VALUES (11177, '2010-08-08 22:00:00+00', '2012-01-20 12:54:56.885178+00', 'Barbara''s Strathspey', 3511, '');
INSERT INTO 'tune' VALUES (11178, '2010-08-08 22:00:00+00', '2012-01-20 12:54:56.888111+00', 'Bonnie Glenfarclas', 2856, '');
INSERT INTO 'tune' VALUES (11179, '2010-08-08 22:00:00+00', '2012-01-20 12:54:56.891036+00', 'James McInnes, Esq, Dandaleith', 1807, '');
INSERT INTO 'tune' VALUES (11180, '2010-08-08 22:00:00+00', '2012-01-20 12:54:56.894094+00', 'Miss Barbara Hay''s Favourite', 1519, '');
INSERT INTO 'tune' VALUES (11181, '2010-08-08 22:00:00+00', '2012-01-20 12:54:56.89703+00', 'Halden''s Reel', 3693, '');
INSERT INTO 'tune' VALUES (11182, '2010-08-08 22:00:00+00', '2012-01-20 12:54:56.899955+00', 'Waves of the Sound, The', 3693, '');
INSERT INTO 'tune' VALUES (11183, '2010-08-08 22:00:00+00', '2012-01-20 12:54:56.902882+00', 'Turn of the Tide, The', 1539, '');
INSERT INTO 'tune' VALUES (11184, '2010-08-08 22:00:00+00', '2012-01-20 12:54:56.905797+00', 'Blackwood Jig', 2191, '');
INSERT INTO 'tune' VALUES (11185, '2010-08-08 22:00:00+00', '2012-01-20 12:54:56.90871+00', 'Meteorite, The', 3186, '');
INSERT INTO 'tune' VALUES (11186, '2010-08-29 22:00:00+00', '2012-01-20 12:54:56.911624+00', 'Monkridge Lassies', 9999, '');
INSERT INTO 'tune' VALUES (11187, '2010-08-29 22:00:00+00', '2012-01-20 12:54:56.914777+00', 'Wyoming Lullaby', 9999, '');
INSERT INTO 'tune' VALUES (11188, '2010-08-29 22:00:00+00', '2012-01-20 12:54:56.917795+00', 'Miss Alice S.R. MacLennan', 9999, '');
INSERT INTO 'tune' VALUES (11189, '2010-08-29 22:00:00+00', '2012-01-20 12:54:56.920878+00', 'Queen Mary Waltz', 1567, '');
INSERT INTO 'tune' VALUES (11190, '2010-08-29 22:00:00+00', '2012-01-20 12:54:56.923846+00', 'Hesitation Waltz', 145, '');
INSERT INTO 'tune' VALUES (11191, '2010-08-31 22:00:00+00', '2012-01-20 12:54:56.926792+00', 'Happy Hours', 9999, '');
INSERT INTO 'tune' VALUES (11192, '2010-08-31 22:00:00+00', '2012-01-20 12:54:56.92972+00', 'When I Look Back to Bonnie Aberdeen', 9999, '');
INSERT INTO 'tune' VALUES (11193, '2010-08-31 22:00:00+00', '2012-01-20 12:54:56.932645+00', 'Listening Waltz, The', 10187, '');
INSERT INTO 'tune' VALUES (11194, '2010-08-31 22:00:00+00', '2012-01-20 12:54:56.935656+00', 'Can I Sleep in Your Barn', 9999, '');
INSERT INTO 'tune' VALUES (11195, '2010-08-31 22:00:00+00', '2012-01-20 12:54:56.938597+00', 'Hand Me Down My Walking Cane', 9999, '');
INSERT INTO 'tune' VALUES (11196, '2010-08-31 22:00:00+00', '2012-01-20 12:54:56.941518+00', 'Call to Banff', 9999, '');
INSERT INTO 'tune' VALUES (11197, '2010-08-31 22:00:00+00', '2012-01-20 12:54:56.944436+00', 'Stone Outside Dan Murphy''s Door, The', 9999, '');
INSERT INTO 'tune' VALUES (11198, '2010-08-31 22:00:00+00', '2012-01-20 12:54:56.94736+00', 'Lancashire Clogs', 10189, '');
INSERT INTO 'tune' VALUES (11199, '2010-08-31 22:00:00+00', '2012-01-20 12:54:56.950452+00', 'Paddy O'' Carroll', 9999, '');
INSERT INTO 'tune' VALUES (11200, '2010-08-31 22:00:00+00', '2012-01-20 12:54:56.953393+00', 'L'' Entrainante Valse', 9999, '');
INSERT INTO 'tune' VALUES (11201, '2010-08-31 22:00:00+00', '2012-01-20 12:54:56.957558+00', 'Auld Brig o''Ayr, The', 9999, '');
INSERT INTO 'tune' VALUES (11202, '2010-08-31 22:00:00+00', '2012-01-20 12:54:56.960496+00', 'Willie McLennan', 9999, '');
INSERT INTO 'tune' VALUES (11203, '2010-09-02 22:00:00+00', '2012-01-20 12:54:56.963416+00', 'Tin Gee-gee', 9999, '');
INSERT INTO 'tune' VALUES (11204, '2010-09-02 22:00:00+00', '2012-01-20 12:54:56.96652+00', 'North Sea Tune, The', 9999, '');
INSERT INTO 'tune' VALUES (11205, '2010-09-02 22:00:00+00', '2012-01-20 12:54:56.969525+00', 'Kaela''s Peerie Tune', 1645, '');
INSERT INTO 'tune' VALUES (11206, '2010-09-02 22:00:00+00', '2012-01-20 12:54:56.972478+00', 'Pumpkin''s Fancy', 3094, '');
INSERT INTO 'tune' VALUES (11207, '2010-09-02 22:00:00+00', '2012-01-20 12:54:56.975412+00', 'Cold Frosty Morning', 9999, '');
INSERT INTO 'tune' VALUES (11208, '2010-09-02 22:00:00+00', '2012-01-20 12:54:56.978443+00', 'Panhandle Swing', 9999, '');
INSERT INTO 'tune' VALUES (11209, '2010-09-02 22:00:00+00', '2012-01-20 12:54:56.981521+00', 'Sandy River Belles', 9999, '');
INSERT INTO 'tune' VALUES (11210, '2010-09-02 22:00:00+00', '2012-01-20 12:54:56.984473+00', 'Rope Waltz, The', 9999, '');
INSERT INTO 'tune' VALUES (11211, '2010-09-02 22:00:00+00', '2012-01-20 12:54:56.987414+00', 'Snowflake Breakdown', 10195, '');
INSERT INTO 'tune' VALUES (11212, '2010-09-02 22:00:00+00', '2012-01-20 12:54:56.990335+00', 'Shelburne Reel', 10196, '');
INSERT INTO 'tune' VALUES (11213, '2010-09-02 22:00:00+00', '2012-01-20 12:54:56.993241+00', 'Weaving of the Tartan, The', 10192, '');
INSERT INTO 'tune' VALUES (11214, '2010-09-02 22:00:00+00', '2012-01-20 12:54:56.996167+00', 'Phyllis Locke''s Strathspey', 3419, '');
INSERT INTO 'tune' VALUES (11215, '2010-09-02 22:00:00+00', '2012-01-20 12:54:56.999219+00', 'Stay a Little Longer', 9999, '');
INSERT INTO 'tune' VALUES (11216, '2010-09-02 22:00:00+00', '2012-01-20 12:54:57.00215+00', 'I Wish They''d Do It Now', 10197, '');
INSERT INTO 'tune' VALUES (11217, '2010-09-02 22:00:00+00', '2012-01-20 12:54:57.00506+00', 'Ho Ree Ho Ro', 10199, '');
INSERT INTO 'tune' VALUES (11218, '2010-09-02 22:00:00+00', '2012-01-20 12:54:57.007986+00', 'Joy of My Heart', 1927, '');
INSERT INTO 'tune' VALUES (11219, '2010-09-02 22:00:00+00', '2012-01-20 12:54:57.011098+00', 'Haki''s Polka', 1710, '');
INSERT INTO 'tune' VALUES (11220, '2010-09-02 22:00:00+00', '2012-01-20 12:54:57.014069+00', 'Miss Delia Graham''s Polka', 10198, '');
INSERT INTO 'tune' VALUES (11221, '2010-09-02 22:00:00+00', '2012-01-20 12:54:57.018073+00', 'House in Rose Valley', 1271, '');
INSERT INTO 'tune' VALUES (11222, '2010-09-02 22:00:00+00', '2012-01-20 12:54:57.02125+00', 'Plains of Normandy, The', 9998, '');
INSERT INTO 'tune' VALUES (11223, '2010-09-03 22:00:00+00', '2012-01-20 12:54:57.024334+00', 'Quendale Bay', 1761, '');
INSERT INTO 'tune' VALUES (11224, '2010-09-03 22:00:00+00', '2012-01-20 12:54:57.02727+00', 'Hamish''s Tune', 1533, '');
INSERT INTO 'tune' VALUES (11225, '2010-09-03 22:00:00+00', '2012-01-20 12:54:57.030205+00', 'Happy Fiddler, The', 1898, '');
INSERT INTO 'tune' VALUES (11226, '2010-09-03 22:00:00+00', '2012-01-20 12:54:57.033133+00', 'Cracked Fiddle, The', 1898, '');
INSERT INTO 'tune' VALUES (11227, '2010-09-03 22:00:00+00', '2012-01-20 12:54:57.036072+00', 'Loch Ruan', 10201, '');
INSERT INTO 'tune' VALUES (11229, '2010-09-03 22:00:00+00', '2012-01-20 12:54:57.043056+00', 'Professor Donald McIntyre', 10202, '');
INSERT INTO 'tune' VALUES (11230, '2010-09-03 22:00:00+00', '2012-01-20 12:54:57.045982+00', 'Doune Lodge Two Step, The', 1613, '');
INSERT INTO 'tune' VALUES (11231, '2010-09-03 22:00:00+00', '2012-01-20 12:54:57.049126+00', 'Come Back to Erin', 10203, '');
INSERT INTO 'tune' VALUES (11232, '2010-09-03 22:00:00+00', '2012-01-20 12:54:57.052485+00', 'Stornoway Jig, The', 3052, '');
INSERT INTO 'tune' VALUES (11233, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.055456+00', 'Jina''s Waltz', 2965, '');
INSERT INTO 'tune' VALUES (11234, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.058728+00', 'Kinneil House', 10205, '');
INSERT INTO 'tune' VALUES (11235, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.062051+00', 'My Friend Kev', 2965, '');
INSERT INTO 'tune' VALUES (11236, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.06498+00', 'Jig for Tony and Betty, A', 1675, '');
INSERT INTO 'tune' VALUES (11237, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.068185+00', 'Aidan McMeeking of Surrey', 10056, '');
INSERT INTO 'tune' VALUES (11238, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.071144+00', 'Andrew and Mairi Collins', 2965, '');
INSERT INTO 'tune' VALUES (11239, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.07407+00', 'Da Bonnie Polka', 9999, '');
INSERT INTO 'tune' VALUES (11240, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.077185+00', 'Stan Hamilton''s Compliments to Peter & Mary Rae', 2054, '');
INSERT INTO 'tune' VALUES (11241, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.080314+00', 'Teresa and Rob Lockhart', 2965, '');
INSERT INTO 'tune' VALUES (11242, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.083313+00', 'Duncan McGillivray', 10206, '');
INSERT INTO 'tune' VALUES (11243, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.086244+00', 'Miss Carol Ross of Dundas', 2965, '');
INSERT INTO 'tune' VALUES (11244, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.08915+00', 'Family Ties', 2965, '');
INSERT INTO 'tune' VALUES (11245, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.09207+00', 'Big Boab', 2965, '');
INSERT INTO 'tune' VALUES (11246, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.094994+00', 'Stella Star', 2965, '');
INSERT INTO 'tune' VALUES (11247, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.097908+00', 'My Aunty Jean', 2965, '');
INSERT INTO 'tune' VALUES (11248, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.100929+00', 'Boozin'' with David', 2965, '');
INSERT INTO 'tune' VALUES (11249, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.103859+00', 'Michelle Depledge of Preston', 2965, '');
INSERT INTO 'tune' VALUES (11250, '2010-09-05 22:00:00+00', '2012-01-20 12:54:57.106781+00', 'Miss Clair Brandt', 10207, '');
INSERT INTO 'tune' VALUES (11251, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.109885+00', 'Stonehaven March, The', 9999, '');
INSERT INTO 'tune' VALUES (11252, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.112835+00', 'Magnister Voe', 1710, '');
INSERT INTO 'tune' VALUES (11253, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.11578+00', 'Alasdair MacLeod', 10211, '');
INSERT INTO 'tune' VALUES (11254, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.118729+00', 'Mrs John MacColl', 1694, '');
INSERT INTO 'tune' VALUES (11255, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.121786+00', 'Lisa', 10106, '');
INSERT INTO 'tune' VALUES (11256, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.124725+00', 'Four Winds, The', 10106, '');
INSERT INTO 'tune' VALUES (11257, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.127753+00', 'Atholl Highlanders'' March to the Braemar Gathering', 10213, '');
INSERT INTO 'tune' VALUES (11258, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.131204+00', 'Old Grey Goose, The', 9999, '');
INSERT INTO 'tune' VALUES (11259, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.134298+00', 'When You and I Were Young, Maggie', 10215, '');
INSERT INTO 'tune' VALUES (11260, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.137448+00', 'Nether Bailey, The', 1621, '');
INSERT INTO 'tune' VALUES (11261, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.140494+00', 'Orfasay', 10031, '');
INSERT INTO 'tune' VALUES (11262, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.143621+00', 'Studland Strathspey', 3186, '');
INSERT INTO 'tune' VALUES (11263, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.146581+00', 'Theme from Dallas', 10217, '');
INSERT INTO 'tune' VALUES (11264, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.149507+00', 'California Here I Come', 10218, '');
INSERT INTO 'tune' VALUES (11265, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.15243+00', 'Swannee', 10219, '');
INSERT INTO 'tune' VALUES (11266, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.155355+00', 'Zippidee Doo Dah', 10220, '');
INSERT INTO 'tune' VALUES (11267, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.15828+00', 'Ordinary Copper, An', 10221, '');
INSERT INTO 'tune' VALUES (11268, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.16135+00', 'Humoresque', 10222, '');
INSERT INTO 'tune' VALUES (11269, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.164299+00', 'Mary MacKechnie', 1621, '');
INSERT INTO 'tune' VALUES (11270, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.167259+00', 'Two Highland Lads', 10224, '');
INSERT INTO 'tune' VALUES (11271, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.170208+00', 'Oh Dr Finlay', 1883, '');
INSERT INTO 'tune' VALUES (11272, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.17344+00', 'Archie MacKechnie', 1621, '');
INSERT INTO 'tune' VALUES (11273, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.176449+00', 'Cecil''s Forty Years', 10225, '');
INSERT INTO 'tune' VALUES (11274, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.179387+00', 'Lannigan''s Ball', 9999, '');
INSERT INTO 'tune' VALUES (11275, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.182421+00', 'Bressay Light, The', 1621, '');
INSERT INTO 'tune' VALUES (11276, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.185383+00', 'Ian S Robertson', 1710, '');
INSERT INTO 'tune' VALUES (11277, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.188356+00', 'Land for All Seasons, A', 10226, '');
INSERT INTO 'tune' VALUES (11278, '2010-09-15 22:00:00+00', '2012-01-20 12:54:57.191293+00', 'Hard Rock Reel', 3186, '');
INSERT INTO 'tune' VALUES (11279, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.194215+00', 'Miss Cherryl E Lawrie', 1543, '');
INSERT INTO 'tune' VALUES (11280, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.197138+00', 'Brig o'' Cally', 2085, '');
INSERT INTO 'tune' VALUES (11281, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.200099+00', 'Tam''s Crackers', 10227, '');
INSERT INTO 'tune' VALUES (11282, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.20316+00', 'Angel''s Share, The', 1673, '');
INSERT INTO 'tune' VALUES (11283, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.206101+00', 'Just Wilma', 1621, '');
INSERT INTO 'tune' VALUES (11284, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.209016+00', 'Island I Left, The', 9999, '');
INSERT INTO 'tune' VALUES (11285, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.211939+00', 'John MacColl''s Farewell to the Scottish Horse', 1694, '');
INSERT INTO 'tune' VALUES (11287, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.21781+00', 'Colonel Bogey', 10230, '');
INSERT INTO 'tune' VALUES (11288, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.221067+00', 'My Old Man', 2543, '');
INSERT INTO 'tune' VALUES (11289, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.224292+00', 'Home Safe', 1621, '');
INSERT INTO 'tune' VALUES (11290, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.227268+00', 'Colin and Marion Thomson', 3282, '');
INSERT INTO 'tune' VALUES (11291, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.230205+00', 'Donna''s Waltz', 1761, '');
INSERT INTO 'tune' VALUES (11292, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.233351+00', 'Keithick Lodge Two Step', 1621, '');
INSERT INTO 'tune' VALUES (11293, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.236282+00', 'Robert and Judith Whitehead', 2912, '');
INSERT INTO 'tune' VALUES (11294, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.239244+00', 'Paul Martin''s March', 10231, '');
INSERT INTO 'tune' VALUES (11295, '2010-09-16 22:00:00+00', '2012-01-20 12:54:57.242174+00', 'Reine du Carnivales', 9999, '');
INSERT INTO 'tune' VALUES (11296, '2010-09-18 22:00:00+00', '2012-01-20 12:54:57.245231+00', 'España - Spanish Rhapsody', 10232, '');
INSERT INTO 'tune' VALUES (11297, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.248177+00', 'Ardgour Ferry', 1700, '');
INSERT INTO 'tune' VALUES (11299, '2010-09-20 22:00:00+00', '2021-09-11 16:35:51.623868+00', 'David Ross', 1755, '');
INSERT INTO 'tune' VALUES (11300, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.256944+00', 'Mrs Margaret Macaskill', 2406, '');
INSERT INTO 'tune' VALUES (11301, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.260064+00', 'Isla MacLeod', 10234, '');
INSERT INTO 'tune' VALUES (11302, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.263059+00', 'Circle of the Ocean', 2332, '');
INSERT INTO 'tune' VALUES (11303, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.266377+00', 'Lovely Island', 9999, '');
INSERT INTO 'tune' VALUES (11304, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.269521+00', 'Rita''s Rant', 1623, '');
INSERT INTO 'tune' VALUES (11305, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.272457+00', 'Leaving Lunga', 10236, '');
INSERT INTO 'tune' VALUES (11306, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.275388+00', 'Lorna', 9998, '');
INSERT INTO 'tune' VALUES (11307, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.27832+00', 'Kildonan', 1910, '');
INSERT INTO 'tune' VALUES (11308, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.281358+00', 'Laggan Stockman, The', 1811, '');
INSERT INTO 'tune' VALUES (11309, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.28456+00', 'Bold Robert Emmett', 10235, '');
INSERT INTO 'tune' VALUES (11310, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.287527+00', 'Joe Forster''s Jig', 1522, '');
INSERT INTO 'tune' VALUES (11311, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.290563+00', 'Kathy Campbell''s Reel', 316, '');
INSERT INTO 'tune' VALUES (11312, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.293518+00', 'Tanaig Thu air a Bhata, An', 1621, '');
INSERT INTO 'tune' VALUES (11313, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.296445+00', 'Tha Awali Callies (Bahrain)', 1621, '');
INSERT INTO 'tune' VALUES (11314, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.299367+00', 'Pitkeathly Wells', 1621, '');
INSERT INTO 'tune' VALUES (11315, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.302284+00', 'Mary Mew''s Jig', 316, '');
INSERT INTO 'tune' VALUES (11316, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.305322+00', 'Aberdeen Festival Strathspey', 1782, '');
INSERT INTO 'tune' VALUES (11317, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.30844+00', 'By Invitation', 2266, '');
INSERT INTO 'tune' VALUES (11318, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.311441+00', 'Jude''s Forte', 1621, '');
INSERT INTO 'tune' VALUES (11319, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.314362+00', 'Sandra''s Hornpipe', 1621, '');
INSERT INTO 'tune' VALUES (11320, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.317276+00', 'Ken and Lavinia''s Ruby', 316, '');
INSERT INTO 'tune' VALUES (11321, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.320202+00', 'Carleton Jig, The', 2266, '');
INSERT INTO 'tune' VALUES (11323, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.326194+00', 'JillwithaJ', 2266, '');
INSERT INTO 'tune' VALUES (11324, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.329123+00', 'One for Tom', 2266, '');
INSERT INTO 'tune' VALUES (11325, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.332136+00', 'Lament for Jack Miller', 1811, '');
INSERT INTO 'tune' VALUES (11326, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.33522+00', 'Love o'' the Isles, The', 1677, '');
INSERT INTO 'tune' VALUES (11327, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.338179+00', 'Wee Highland Laddie, The', 9999, '');
INSERT INTO 'tune' VALUES (11328, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.341256+00', 'Ribblesdale Strathspey, The', 316, '');
INSERT INTO 'tune' VALUES (11329, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.344232+00', 'Mrs Francis', 1554, '');
INSERT INTO 'tune' VALUES (11330, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.347275+00', 'Frank and June Hewitson', 316, '');
INSERT INTO 'tune' VALUES (11331, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.350206+00', 'George McKelvie', 1554, '');
INSERT INTO 'tune' VALUES (11332, '2010-09-20 22:00:00+00', '2012-01-20 12:54:57.353116+00', 'Don and Dee''s Reel', 316, '');
INSERT INTO 'tune' VALUES (11334, '2010-10-05 22:00:00+00', '2012-01-20 12:54:57.358964+00', 'Bayholme', 1920, '');
INSERT INTO 'tune' VALUES (11335, '2010-10-05 22:00:00+00', '2012-01-20 12:54:57.361877+00', 'Major Hamill, M.B.E.', 10246, '');
INSERT INTO 'tune' VALUES (11336, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.365011+00', 'Pilot Officer T Forbes', 2168, '');
INSERT INTO 'tune' VALUES (11337, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.368076+00', 'Clashmaden', 2168, '');
INSERT INTO 'tune' VALUES (11338, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.37102+00', 'Mrs Alisdair Colquhoun''s Reel', 2168, '');
INSERT INTO 'tune' VALUES (11339, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.373938+00', 'Gordon Peattie''s Farewell to Brunei', 2168, '');
INSERT INTO 'tune' VALUES (11340, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.376863+00', 'Ron Watson''s Two-Step', 2168, '');
INSERT INTO 'tune' VALUES (11341, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.379791+00', 'Etienne Gerard Gallop', 2168, '');
INSERT INTO 'tune' VALUES (11342, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.382709+00', 'Lac de Chalain', 2168, '');
INSERT INTO 'tune' VALUES (11343, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.385788+00', 'Meaux sur Marne', 2168, '');
INSERT INTO 'tune' VALUES (11346, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.394691+00', 'Craigievar Castle', 2168, '');
INSERT INTO 'tune' VALUES (11347, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.397602+00', 'Earls of Rothes', 2168, '');
INSERT INTO 'tune' VALUES (11348, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.400693+00', 'John and Sheila Tanner', 1527, '');
INSERT INTO 'tune' VALUES (11349, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.403684+00', 'Ms Bronislawa Szczygiel', 2168, '');
INSERT INTO 'tune' VALUES (11350, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.406708+00', 'Epping Forest Scottish Association', 2168, '');
INSERT INTO 'tune' VALUES (11351, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.409673+00', 'Fifty Dram Reel', 2168, '');
INSERT INTO 'tune' VALUES (11353, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.415503+00', 'Auld Mortlach Kirk', 2168, '');
INSERT INTO 'tune' VALUES (11354, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.418426+00', 'Allt Dhu', 2168, '');
INSERT INTO 'tune' VALUES (11355, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.42134+00', 'Spinnaker, The', 2168, '');
INSERT INTO 'tune' VALUES (11356, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.424257+00', 'Mrs Lawmon of Southsea', 2168, '');
INSERT INTO 'tune' VALUES (11357, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.427247+00', 'Mr and Mrs Grimmer''s Jig', 2168, '');
INSERT INTO 'tune' VALUES (11358, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.430228+00', 'Dr Sousa of Madeira', 2168, '');
INSERT INTO 'tune' VALUES (11359, '2010-10-07 22:00:00+00', '2012-01-20 12:54:57.433151+00', 'McCrorie''s Stack of Wood', 2168, '');
INSERT INTO 'tune' VALUES (11360, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.436188+00', 'Uncle Dave''s Jig', 1811, '');
INSERT INTO 'tune' VALUES (11361, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.439129+00', 'Mary Black Jig, The', 10250, '');
INSERT INTO 'tune' VALUES (11362, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.442321+00', 'Jig for Holly, A', 10250, '');
INSERT INTO 'tune' VALUES (11363, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.445303+00', 'Morna''s Jig', 10251, '');
INSERT INTO 'tune' VALUES (11364, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.448348+00', 'Craigton Jig', 10252, '');
INSERT INTO 'tune' VALUES (11365, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.451319+00', 'Gx.Lx.Cx.', 3683, '');
INSERT INTO 'tune' VALUES (11366, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.454242+00', 'Carm Oliver''s', 1602, '');
INSERT INTO 'tune' VALUES (11367, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.457167+00', 'Marco''s Reel', 2689, '');
INSERT INTO 'tune' VALUES (11368, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.460125+00', 'Jim Connor''s Welcome to Grand Central Station', 2689, '');
INSERT INTO 'tune' VALUES (11369, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.463043+00', 'Trip to Shanghai', 2689, '');
INSERT INTO 'tune' VALUES (11370, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.465965+00', 'Reel for George, A', 1582, '');
INSERT INTO 'tune' VALUES (11371, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.469341+00', 'Royal Road to Fotheringay, The', 1657, '');
INSERT INTO 'tune' VALUES (11372, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.472412+00', 'Left Footed Fiddler, The', 1657, '');
INSERT INTO 'tune' VALUES (11373, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.475349+00', 'Strawberry Fair', 9999, '');
INSERT INTO 'tune' VALUES (11374, '2010-10-08 22:00:00+00', '2012-01-20 12:54:57.478274+00', 'Blow Away the Morning Dew', 9999, '');
INSERT INTO 'tune' VALUES (13869, '2018-03-31 11:17:23.892651+00', '2018-03-31 11:18:36.303178+00', 'Hugh Alexander Lowe of Three', 11620, '');
INSERT INTO 'tune' VALUES (11376, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.484118+00', 'Davina''s Reel', 1591, '');
INSERT INTO 'tune' VALUES (11378, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.491031+00', 'Hamefarers Dance Band, The', 1677, '');
INSERT INTO 'tune' VALUES (11379, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.494217+00', 'Mrs Lilly Christie', 1426, '');
INSERT INTO 'tune' VALUES (11380, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.49715+00', 'Junior''s Waltz', 10257, '');
INSERT INTO 'tune' VALUES (11381, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.500078+00', 'Raemona', 10258, '');
INSERT INTO 'tune' VALUES (11382, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.503006+00', 'Kathy''s Waltz', 10259, '');
INSERT INTO 'tune' VALUES (11383, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.505918+00', 'Barns Ness Reel, The', 3710, '');
INSERT INTO 'tune' VALUES (11384, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.508844+00', 'Yasmin Sara', 10016, '');
INSERT INTO 'tune' VALUES (11385, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.511883+00', 'When the Swallows Have Gone', 10260, '');
INSERT INTO 'tune' VALUES (11386, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.514846+00', 'Jeannie S Grant''s Jig', 1807, '');
INSERT INTO 'tune' VALUES (11387, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.517825+00', 'Midnight Ferry, The', 1591, '');
INSERT INTO 'tune' VALUES (11389, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.523685+00', 'O''Connell Street', 1668, '');
INSERT INTO 'tune' VALUES (11390, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.526728+00', 'Master Jake Laing', 1591, '');
INSERT INTO 'tune' VALUES (11391, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.529686+00', 'Miss Barbara Stewart', 1845, '');
INSERT INTO 'tune' VALUES (11392, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.532724+00', 'Mill of Laggan, The', 1516, '');
INSERT INTO 'tune' VALUES (11393, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.535704+00', 'Mowing the Hay', 1904, '');
INSERT INTO 'tune' VALUES (11394, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.538629+00', 'Beales on Wheels', 1501, '');
INSERT INTO 'tune' VALUES (11395, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.541572+00', 'Anne Sheach', 1591, '');
INSERT INTO 'tune' VALUES (11396, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.544496+00', 'Stirling University', 1710, '');
INSERT INTO 'tune' VALUES (11397, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.547418+00', 'Andrina''s Jig', 10086, '');
INSERT INTO 'tune' VALUES (11398, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.550399+00', 'Broken Sofa, The', 9999, '');
INSERT INTO 'tune' VALUES (11352, '2010-10-07 22:00:00+00', '2021-02-20 12:40:29.169406+00', 'Rose Waddell of Dunure', 1527, '');
INSERT INTO 'tune' VALUES (11344, '2010-10-07 22:00:00+00', '2021-08-16 15:39:37.376426+00', 'Braes of Enzie, The', 2168, '');
INSERT INTO 'tune' VALUES (11345, '2010-10-07 22:00:00+00', '2021-08-17 08:51:49.588828+00', 'Bill Forbes''s Strathspey', 2168, '');
INSERT INTO 'tune' VALUES (11399, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.553431+00', 'Miss Jane Grant, Lynmore', 1516, '');
INSERT INTO 'tune' VALUES (11400, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.556365+00', 'Jimmy Robertson', 1581, '');
INSERT INTO 'tune' VALUES (11401, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.559292+00', 'Dragger''s Reel, The', 10261, '');
INSERT INTO 'tune' VALUES (11402, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.562369+00', 'Roadside Reel', 10086, '');
INSERT INTO 'tune' VALUES (11403, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.565301+00', 'Starcase Reel, The', 1539, '');
INSERT INTO 'tune' VALUES (11404, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.568215+00', 'Hunter''s House, The', 10262, '');
INSERT INTO 'tune' VALUES (11405, '2010-10-13 22:00:00+00', '2012-01-20 12:54:57.571138+00', 'Blackthorn Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (11406, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.574326+00', 'Lonely in the Bothy', 9999, '');
INSERT INTO 'tune' VALUES (11407, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.577252+00', 'Banks of the Roses, The', 9999, '');
INSERT INTO 'tune' VALUES (11408, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.580178+00', 'Donald Ridley', 1668, '');
INSERT INTO 'tune' VALUES (11410, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.586047+00', 'Marlene Mitchell of Bardmony', 1401, '');
INSERT INTO 'tune' VALUES (11411, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.588994+00', 'Jim Thomson''s Cairtie', 10264, '');
INSERT INTO 'tune' VALUES (11412, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.592012+00', 'Cowboy''s Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (11413, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.594972+00', 'Marrister', 1645, '');
INSERT INTO 'tune' VALUES (11414, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.597891+00', 'Dream Lover', 1811, '');
INSERT INTO 'tune' VALUES (11415, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.600808+00', 'Bryan Gear', 1593, '');
INSERT INTO 'tune' VALUES (11416, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.603761+00', 'All of Me', 10265, '');
INSERT INTO 'tune' VALUES (11417, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.606679+00', 'Somebody Loves Me', 10266, '');
INSERT INTO 'tune' VALUES (11418, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.609589+00', 'Green Forrest Jig, The', 9999, '');
INSERT INTO 'tune' VALUES (11419, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.612511+00', 'Boys of Ballymote, The', 9999, '');
INSERT INTO 'tune' VALUES (11420, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.615568+00', 'Tom Flannigan''s Wager', 9999, '');
INSERT INTO 'tune' VALUES (11421, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.618654+00', 'Carraroe, The', 9999, '');
INSERT INTO 'tune' VALUES (11422, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.621589+00', 'Piper''s Prayer, The', 9999, '');
INSERT INTO 'tune' VALUES (11424, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.627599+00', 'Dandy Todd''s Half Century', 1811, '');
INSERT INTO 'tune' VALUES (11425, '2010-10-15 22:00:00+00', '2012-01-20 12:54:57.630535+00', 'Flappers, The', 1567, '');
INSERT INTO 'tune' VALUES (11426, '2010-10-16 22:00:00+00', '2012-01-20 12:54:57.633543+00', 'Molly O''Morgan', 9999, '');
INSERT INTO 'tune' VALUES (11427, '2010-10-16 22:00:00+00', '2012-01-20 12:54:57.636486+00', 'Maggie Murphy''s Home', 9999, '');
INSERT INTO 'tune' VALUES (11428, '2010-10-18 22:00:00+00', '2012-01-20 12:54:57.63941+00', 'Waltz for Kath', 10038, '');
INSERT INTO 'tune' VALUES (11429, '2010-10-18 22:00:00+00', '2012-01-20 12:54:57.64232+00', 'Tango Musette', 10269, '');
INSERT INTO 'tune' VALUES (11430, '2010-10-18 22:00:00+00', '2012-01-20 12:54:57.645231+00', 'Arlene Bowie', 10270, '');
INSERT INTO 'tune' VALUES (11431, '2010-10-18 22:00:00+00', '2012-01-20 12:54:57.648155+00', 'Rita Duncan', 10270, '');
INSERT INTO 'tune' VALUES (11433, '2010-10-18 22:00:00+00', '2012-01-20 12:54:57.654104+00', 'I''m Gettin'' Sentimental Over You', 10271, '');
INSERT INTO 'tune' VALUES (11434, '2010-10-18 22:00:00+00', '2012-01-20 12:54:57.657048+00', 'Roddie Wright''s Jig', 3052, '');
INSERT INTO 'tune' VALUES (11435, '2010-10-18 22:00:00+00', '2012-01-20 12:54:57.660538+00', 'Reunion Reel, The', 3052, '');
INSERT INTO 'tune' VALUES (11436, '2010-10-18 22:00:00+00', '2012-01-20 12:54:57.663494+00', 'Sharron Colvin''s Waltz', 1811, '');
INSERT INTO 'tune' VALUES (11437, '2010-10-19 22:00:00+00', '2012-01-20 12:54:57.666779+00', 'Silver Wings Polka, The', 1598, '');
INSERT INTO 'tune' VALUES (11438, '2010-10-19 22:00:00+00', '2012-01-20 12:54:57.669792+00', 'Traditional Airs', 9998, '');
INSERT INTO 'tune' VALUES (11439, '2010-10-19 22:00:00+00', '2012-01-20 12:54:57.672723+00', 'Gleniffer Polka, The', 1533, '');
INSERT INTO 'tune' VALUES (11441, '2010-10-26 22:00:00+00', '2012-01-20 12:54:57.678846+00', 'Month of May', 9999, '');
INSERT INTO 'tune' VALUES (11442, '2010-10-26 22:00:00+00', '2012-01-20 12:54:57.681765+00', 'O''er the Drills', 9999, '');
INSERT INTO 'tune' VALUES (11443, '2010-10-26 22:00:00+00', '2012-01-20 12:54:57.684683+00', 'Scottish Waltz, A', 1927, '');
INSERT INTO 'tune' VALUES (11444, '2010-10-26 22:00:00+00', '2012-01-20 12:54:57.68761+00', 'Castle in the Glen, The', 9999, '');
INSERT INTO 'tune' VALUES (11447, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.696506+00', 'Inglis Hutchison of Dalkeith', 10278, '');
INSERT INTO 'tune' VALUES (11448, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.699479+00', 'Sherriff A.C. McPherson of the Glasgow Highland Club', 10165, '');
INSERT INTO 'tune' VALUES (11449, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.702436+00', 'Billy & Alice Hutton''s Ruby Wedding', 3220, '');
INSERT INTO 'tune' VALUES (11450, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.705361+00', 'Charness Waltz', 1605, '');
INSERT INTO 'tune' VALUES (11451, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.7083+00', 'Douchie McCalum''s Farewell to Scotland', 1660, '');
INSERT INTO 'tune' VALUES (11452, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.711225+00', 'Aimee Mae', 1808, '');
INSERT INTO 'tune' VALUES (11453, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.714213+00', 'Summer Sunset', 10279, '');
INSERT INTO 'tune' VALUES (11455, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.720155+00', 'Young Octagenarian, The', 3220, '');
INSERT INTO 'tune' VALUES (11456, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.723081+00', 'Never on Sunday', 10280, '');
INSERT INTO 'tune' VALUES (11457, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.726165+00', 'Kiss Me Honey Honey', 10281, '');
INSERT INTO 'tune' VALUES (11458, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.729227+00', 'Highlander Gordon Pirie', 3186, '');
INSERT INTO 'tune' VALUES (11459, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.732204+00', 'Banks of the Lea', 9999, '');
INSERT INTO 'tune' VALUES (11460, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.735143+00', 'Drums of Fife', 1567, '');
INSERT INTO 'tune' VALUES (11461, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.738554+00', 'Lovats Reel', 9999, '');
INSERT INTO 'tune' VALUES (11462, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.741575+00', 'My Friend Gill', 3220, '');
INSERT INTO 'tune' VALUES (11463, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.744522+00', 'Zephyr LK394', 10282, '');
INSERT INTO 'tune' VALUES (11464, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.747464+00', 'Jimmy and Amy Henderson', 1777, '');
INSERT INTO 'tune' VALUES (11465, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.750696+00', 'Too Ra Loo Ra Loo Ral', 10283, '');
INSERT INTO 'tune' VALUES (11466, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.753663+00', 'Ove Joensen', 10077, '');
INSERT INTO 'tune' VALUES (11467, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.756702+00', 'Autumn Leaves', 10284, '');
INSERT INTO 'tune' VALUES (11468, '2010-10-27 22:00:00+00', '2012-01-20 12:54:57.759779+00', 'Roxburgh Tower', 10061, '');
INSERT INTO 'tune' VALUES (11469, '2010-11-07 23:00:00+00', '2012-01-20 12:54:57.762718+00', 'Karin Schnabl of Rechberg', 1502, '');
INSERT INTO 'tune' VALUES (11470, '2010-11-10 23:00:00+00', '2012-01-20 12:54:57.765698+00', 'Vienna''s Farewell to the MacGregors', 10286, '');
INSERT INTO 'tune' VALUES (11471, '2010-11-10 23:00:00+00', '2012-01-20 12:54:57.768672+00', 'From Michigan to California', 1502, '');
INSERT INTO 'tune' VALUES (11472, '2010-11-10 23:00:00+00', '2012-01-20 12:54:57.771617+00', 'Strathspey for Susi Mayr, A', 1502, '');
INSERT INTO 'tune' VALUES (11473, '2010-11-10 23:00:00+00', '2012-01-20 12:54:57.774549+00', 'Delnabo', 9999, '');
INSERT INTO 'tune' VALUES (11474, '2010-11-10 23:00:00+00', '2012-01-20 12:54:57.777579+00', 'Davie Knick Knack', 9999, '');
INSERT INTO 'tune' VALUES (11476, '2011-02-17 23:00:00+00', '2012-01-20 12:54:57.783465+00', 'Wrigley''s Reel', 1633, '');
INSERT INTO 'tune' VALUES (11477, '2011-02-17 23:00:00+00', '2012-01-20 12:54:57.786396+00', 'Reel Number Six', 9999, '');
INSERT INTO 'tune' VALUES (11478, '2011-02-17 23:00:00+00', '2012-01-20 12:54:57.789311+00', 'Sheep in the Mountains', 1596, '');
INSERT INTO 'tune' VALUES (11479, '2011-02-17 23:00:00+00', '2012-01-20 12:54:57.792244+00', 'Helmand Highlanders, The', 10305, '');
INSERT INTO 'tune' VALUES (11480, '2011-02-17 23:00:00+00', '2012-01-20 12:54:57.795165+00', 'David Brandon', 1764, '');
INSERT INTO 'tune' VALUES (11481, '2011-02-17 23:00:00+00', '2012-01-20 12:54:57.798177+00', 'Heron, The', 1898, '');
INSERT INTO 'tune' VALUES (11482, '2011-02-17 23:00:00+00', '2012-01-20 12:54:57.80113+00', 'Glenborradale Jig', 1523, '');
INSERT INTO 'tune' VALUES (11483, '2011-02-17 23:00:00+00', '2012-01-20 12:54:57.80406+00', 'Fraser McGlynn Junior', 1613, '');
INSERT INTO 'tune' VALUES (11484, '2011-02-17 23:00:00+00', '2012-01-20 12:54:57.80699+00', 'Hotchkiss Hotchpotch', 1726, '');
INSERT INTO 'tune' VALUES (11485, '2011-02-17 23:00:00+00', '2012-01-20 12:54:57.809908+00', 'Keeper of Delight', 10302, '');
INSERT INTO 'tune' VALUES (11486, '2011-02-17 23:00:00+00', '2012-01-20 12:54:57.812825+00', 'Patti Kusturoks Reel', 10303, '');
INSERT INTO 'tune' VALUES (11487, '2011-02-17 23:00:00+00', '2012-01-20 12:54:57.815741+00', 'Duchess Reel, The', 10304, '');
INSERT INTO 'tune' VALUES (11488, '2011-02-17 23:00:00+00', '2012-01-20 12:54:57.81879+00', 'Big Birl, The', 1673, '');
INSERT INTO 'tune' VALUES (11489, '2011-03-09 23:00:00+00', '2012-01-20 12:54:57.82173+00', 'Ibbotson''s Rant', 10308, '');
INSERT INTO 'tune' VALUES (11490, '2011-03-21 23:00:00+00', '2012-01-20 12:54:57.824652+00', 'Mary McConnell Campbell', 10315, '');
INSERT INTO 'tune' VALUES (11492, '2011-04-25 22:00:00+00', '2012-01-20 12:54:57.827584+00', 'Gus''s Reel', 1591, '');
INSERT INTO 'tune' VALUES (11493, '2011-04-25 22:00:00+00', '2012-01-20 12:54:57.830508+00', 'Maria Leask', 1591, '');
INSERT INTO 'tune' VALUES (11494, '2011-04-25 22:00:00+00', '2012-01-20 12:54:57.833437+00', 'Jack Aloft', 3296, '');
INSERT INTO 'tune' VALUES (11496, '2011-04-25 22:00:00+00', '2012-01-20 12:54:57.839382+00', 'Hevelyne Road', 1591, '');
INSERT INTO 'tune' VALUES (11497, '2011-04-25 22:00:00+00', '2012-01-20 12:54:57.842314+00', 'Inverinate House', 9999, '');
INSERT INTO 'tune' VALUES (11500, '2011-06-08 22:00:00+00', '2012-01-20 12:54:57.855226+00', 'Kerr''s Hornpipe No 1', 9999, '');
INSERT INTO 'tune' VALUES (11501, '2011-06-08 22:00:00+00', '2012-01-20 12:54:57.85817+00', 'Kerr''s Hornpipe No 2', 9999, '');
INSERT INTO 'tune' VALUES (11502, '2011-06-08 22:00:00+00', '2012-01-20 12:54:57.861214+00', 'Graham Takes Lead On This One', 9999, '');
INSERT INTO 'tune' VALUES (11503, '2011-06-08 22:00:00+00', '2012-01-20 12:54:57.864191+00', 'Willfjord', 9999, '');
INSERT INTO 'tune' VALUES (11504, '2011-06-13 22:00:00+00', '2012-01-20 12:54:57.867566+00', 'Bruce Frazer''s Jig', 1590, '');
INSERT INTO 'tune' VALUES (11423, '2010-10-15 22:00:00+00', '2020-05-22 22:03:51.585242+00', 'Troops March, The', 9999, '');
INSERT INTO 'tune' VALUES (11505, '2011-06-13 22:00:00+00', '2012-01-20 12:54:57.870656+00', 'Grants of Millbank, The', 10334, '');
INSERT INTO 'tune' VALUES (11506, '2011-06-13 22:00:00+00', '2012-01-20 12:54:57.873653+00', 'Ian Muir''s compliments to the late Ron Watson', 1590, '');
INSERT INTO 'tune' VALUES (11507, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.876593+00', 'Bill Geddes of Spey Bay', 2168, '');
INSERT INTO 'tune' VALUES (11508, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.879522+00', 'Kintbury Breakfast, The', 10335, '');
INSERT INTO 'tune' VALUES (11509, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.89577+00', 'Michael Browne of Burntisland', 10337, '');
INSERT INTO 'tune' VALUES (11510, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.899686+00', 'Bill Morris of Bressay', 1590, '');
INSERT INTO 'tune' VALUES (11499, '2011-05-05 22:00:00+00', '2018-04-09 00:18:06.785115+00', 'Hope', 3179, '');
INSERT INTO 'tune' VALUES (11445, '2010-10-27 22:00:00+00', '2018-11-15 00:21:18.435982+00', 'Nellie the Elephant', 11745, '');
INSERT INTO 'tune' VALUES (11511, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.903671+00', 'Valerie Frazer', 1590, '');
INSERT INTO 'tune' VALUES (11512, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.907522+00', 'Matchmaker, The', 10339, '');
INSERT INTO 'tune' VALUES (11514, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.915235+00', 'Auld Air', 9999, '');
INSERT INTO 'tune' VALUES (11515, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.919254+00', 'Kate''s Internet Connection', 1590, '');
INSERT INTO 'tune' VALUES (11516, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.923237+00', 'John Armstrong', 1590, '');
INSERT INTO 'tune' VALUES (11517, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.927099+00', 'Glen Cottage (Hindhead)', 10339, '');
INSERT INTO 'tune' VALUES (11518, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.930956+00', 'Back Peddlin'' Mudguard', 2550, '');
INSERT INTO 'tune' VALUES (11815, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.973413+00', 'Orkney', 10520, '');
INSERT INTO 'tune' VALUES (11495, '2011-04-25 22:00:00+00', '2022-12-23 13:36:39.854728+00', 'Hay''s Place', 10086, '');
INSERT INTO 'tune' VALUES (11432, '2010-10-18 22:00:00+00', '2022-12-26 21:44:25.291717+00', 'Braes of Brecklet, The', 12248, '');
INSERT INTO 'tune' VALUES (11519, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.934807+00', 'Da Fairy Reel', 9999, '');
INSERT INTO 'tune' VALUES (11520, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.938645+00', 'Colgrave Sound', 10340, '');
INSERT INTO 'tune' VALUES (11521, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.942637+00', 'Love of My Live, The', 1590, '');
INSERT INTO 'tune' VALUES (11522, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.946503+00', 'Diamond Girls, The', 1596, '');
INSERT INTO 'tune' VALUES (11524, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.954284+00', 'Legendary Anthony Cassidy, The', 10136, '');
INSERT INTO 'tune' VALUES (11525, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.958134+00', 'Duncan and Karen''s Wedding', 10106, '');
INSERT INTO 'tune' VALUES (11526, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.96334+00', 'Marina', 10342, '');
INSERT INTO 'tune' VALUES (11527, '2011-06-14 22:00:00+00', '2012-01-20 12:54:57.967237+00', 'Sarah''s Song', 1761, '');
INSERT INTO 'tune' VALUES (11528, '2011-06-25 22:00:00+00', '2012-01-20 12:54:57.97109+00', 'Snouts and Ears', 9999, '');
INSERT INTO 'tune' VALUES (11529, '2011-06-26 22:00:00+00', '2012-01-20 12:54:57.974954+00', 'Dragon Whispers', 2961, '');
INSERT INTO 'tune' VALUES (11530, '2011-06-26 22:00:00+00', '2012-01-20 12:54:57.978801+00', 'Dancing with D', 2961, '');
INSERT INTO 'tune' VALUES (11531, '2011-06-26 22:00:00+00', '2012-01-20 12:54:57.982764+00', 'Dancing with Fyre', 2961, '');
INSERT INTO 'tune' VALUES (11532, '2011-06-26 22:00:00+00', '2012-01-20 12:54:57.986617+00', 'Dragon''s Lair', 2961, '');
INSERT INTO 'tune' VALUES (11533, '2011-06-26 22:00:00+00', '2012-01-20 12:54:57.990465+00', 'Elgin Strathspey', 2961, '');
INSERT INTO 'tune' VALUES (11534, '2011-06-26 22:00:00+00', '2012-01-20 12:54:57.994333+00', 'Voyage Home', 2961, '');
INSERT INTO 'tune' VALUES (11535, '2011-06-26 22:00:00+00', '2012-01-20 12:54:57.998199+00', 'Dancing Tabby, The', 2961, '');
INSERT INTO 'tune' VALUES (11536, '2011-06-26 22:00:00+00', '2012-01-20 12:54:58.002045+00', 'Caile Cridhe Dubh', 2961, '');
INSERT INTO 'tune' VALUES (11537, '2011-06-26 22:00:00+00', '2012-01-20 12:54:58.00603+00', 'For the Love of a Tigger', 2961, '');
INSERT INTO 'tune' VALUES (11538, '2011-06-26 22:00:00+00', '2012-01-20 12:54:58.009864+00', 'Wee Stane Hoose', 2961, '');
INSERT INTO 'tune' VALUES (11539, '2011-06-27 22:00:00+00', '2012-01-20 12:54:58.01371+00', 'Cat & Pony Jig, The', 228, '');
INSERT INTO 'tune' VALUES (11540, '2011-06-27 22:00:00+00', '2012-01-20 12:54:58.01755+00', 'All Ducks In A Row', 228, '');
INSERT INTO 'tune' VALUES (11541, '2011-06-27 22:00:00+00', '2012-01-20 12:54:58.021404+00', 'Shanghai Traveller, The', 228, '');
INSERT INTO 'tune' VALUES (11542, '2011-06-27 22:00:00+00', '2012-01-20 12:54:58.025376+00', 'Miriam & Georg Gesele''s Strathspey', 228, '');
INSERT INTO 'tune' VALUES (11543, '2011-06-27 22:00:00+00', '2012-01-20 12:54:58.029224+00', 'Big J''s Strathspey', 228, '');
INSERT INTO 'tune' VALUES (11544, '2011-06-27 22:00:00+00', '2012-01-20 12:54:58.033079+00', 'Love & Laughter', 228, '');
INSERT INTO 'tune' VALUES (11545, '2011-06-27 22:00:00+00', '2012-01-20 12:54:58.037009+00', 'Rechberg Castle', 228, '');
INSERT INTO 'tune' VALUES (11546, '2011-06-27 22:00:00+00', '2012-01-20 12:54:58.040851+00', 'Waltz for Jack', 228, '');
INSERT INTO 'tune' VALUES (11547, '2011-06-28 22:00:00+00', '2012-01-20 12:54:58.044935+00', 'Hawaiian War Chant', 9998, '');
INSERT INTO 'tune' VALUES (11548, '2011-06-28 22:00:00+00', '2012-01-20 12:54:58.04879+00', 'Old Hag You Have Killed Me', 9999, '');
INSERT INTO 'tune' VALUES (11549, '2011-07-04 22:00:00+00', '2012-01-20 12:54:58.05265+00', 'Faith', 2786, '');
INSERT INTO 'tune' VALUES (11550, '2011-07-04 22:00:00+00', '2012-01-20 12:54:58.056598+00', 'Hope', 2786, '');
INSERT INTO 'tune' VALUES (11551, '2011-07-04 22:00:00+00', '2012-01-20 12:54:58.060509+00', 'Love', 2786, '');
INSERT INTO 'tune' VALUES (11556, '2011-07-11 22:00:00+00', '2012-01-20 12:54:58.081006+00', 'Tarbert Strathspey, The', 2251, '');
INSERT INTO 'tune' VALUES (11557, '2011-07-11 22:00:00+00', '2012-01-20 12:54:58.084303+00', 'Mairi Bain''s Wedding', 9999, 'Credited as »Old Gaelic Air« in »Graded & Social Dances 3«');
INSERT INTO 'tune' VALUES (11562, '2011-08-04 22:00:00+00', '2012-01-20 12:54:58.10166+00', 'Patty''s Strathspey', 1836, '');
INSERT INTO 'tune' VALUES (11563, '2011-08-18 22:00:00+00', '2012-01-20 12:54:58.104607+00', 'Southbrae', 1659, '');
INSERT INTO 'tune' VALUES (11565, '2011-08-21 22:00:00+00', '2012-01-20 12:54:58.110475+00', 'Sunshine', 1582, '');
INSERT INTO 'tune' VALUES (11567, '2011-08-21 22:00:00+00', '2012-01-20 12:54:58.116369+00', 'Second Carbery Reel, The', 1582, '');
INSERT INTO 'tune' VALUES (13871, '2018-03-31 11:23:13.420652+00', '2018-03-31 11:23:13.420652+00', 'Golden Eagle, The', 11621, '');
INSERT INTO 'tune' VALUES (11569, '2011-08-21 22:00:00+00', '2012-01-20 12:54:58.122254+00', 'Jubilation', 1582, '');
INSERT INTO 'tune' VALUES (11570, '2011-08-21 22:00:00+00', '2012-01-20 12:54:58.125252+00', 'Merrily danced the bride', 1582, '');
INSERT INTO 'tune' VALUES (11571, '2011-08-21 22:00:00+00', '2012-01-20 12:54:58.128256+00', 'Just Regula', 1582, '');
INSERT INTO 'tune' VALUES (11572, '2011-08-21 22:00:00+00', '2012-01-20 12:54:58.131461+00', 'Rona''s Celebration', 1582, '');
INSERT INTO 'tune' VALUES (11573, '2011-08-21 22:00:00+00', '2012-01-20 12:54:58.13453+00', 'South of the Border', 1582, '');
INSERT INTO 'tune' VALUES (11574, '2011-08-21 22:00:00+00', '2012-01-20 12:54:58.137732+00', 'Badenoch Strathspey', 1582, '');
INSERT INTO 'tune' VALUES (11575, '2011-08-21 22:00:00+00', '2012-01-20 12:54:58.140722+00', 'Bournemouth Strathspey, The', 1582, '');
INSERT INTO 'tune' VALUES (11576, '2011-08-21 22:00:00+00', '2012-01-20 12:54:58.143663+00', 'Leslie & Margaret Robson', 1582, '');
INSERT INTO 'tune' VALUES (11577, '2011-08-21 22:00:00+00', '2012-01-20 12:54:58.146604+00', 'Mr Frank Oliver', 1582, '');
INSERT INTO 'tune' VALUES (11579, '2011-08-21 22:00:00+00', '2012-01-20 12:54:58.152481+00', 'Kennedy Gardens', 1582, '');
INSERT INTO 'tune' VALUES (11580, '2011-08-21 22:00:00+00', '2012-01-20 12:54:58.155417+00', 'Black and Whire', 10386, '');
INSERT INTO 'tune' VALUES (13901, '2018-06-09 21:50:52.602128+00', '2018-06-09 21:50:52.602128+00', 'Suas Leis a'' Bhagalais', 9999, '');
INSERT INTO 'tune' VALUES (11582, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.161278+00', 'Our Mary', 2202, '');
INSERT INTO 'tune' VALUES (11583, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.164202+00', 'Rob''s Really Buzzin''', 10398, '');
INSERT INTO 'tune' VALUES (11584, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.167133+00', 'Put the brakes on!', 10398, '');
INSERT INTO 'tune' VALUES (11564, '2011-08-18 22:00:00+00', '2013-08-19 12:00:23.552964+00', 'Tugboat Hornpipe, The', 1659, '');
INSERT INTO 'tune' VALUES (11585, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.17009+00', 'Where are you off to tonight, Barbara?', 10398, '');
INSERT INTO 'tune' VALUES (11586, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.173319+00', 'Yes, Barbara!', 10398, '');
INSERT INTO 'tune' VALUES (11587, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.176622+00', 'Fourscore, furthermore!', 10398, '');
INSERT INTO 'tune' VALUES (11588, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.179611+00', 'Ye did us proud!', 10398, '');
INSERT INTO 'tune' VALUES (11589, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.182557+00', 'Above Rubies and Gold', 10398, '');
INSERT INTO 'tune' VALUES (11590, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.185489+00', 'Nora''s not Batty', 10398, '');
INSERT INTO 'tune' VALUES (11591, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.18843+00', 'Helen''s a Pussy Cat', 10398, '');
INSERT INTO 'tune' VALUES (11561, '2011-07-14 22:00:00+00', '2012-09-07 10:19:46.433464+00', '"Any Good Hornpipe" (author''s statement)', 10653, 'This can be entered in the "Tune" field when the author of a Hornpipe dance explicitly leaves the choice of a tune to the reader.');
INSERT INTO 'tune' VALUES (11554, '2011-07-09 22:00:00+00', '2012-09-07 10:22:24.592303+00', '"Any Good Reel" (author''s statement)', 10653, 'This can be entered in the "Tune" field when the author of a Reel explicitly leaves the choice of a tune to the reader.');
INSERT INTO 'tune' VALUES (11555, '2011-07-09 22:00:00+00', '2012-09-07 10:22:50.259777+00', '"Any Good Strathspey" (author''s statement)', 10653, 'This can be entered in the "Tune" field when the author of a Strathspey explicitly leaves the choice of a tune to the reader.');
INSERT INTO 'tune' VALUES (11559, '2011-07-13 22:00:00+00', '2012-09-16 21:52:49.319007+00', '"Any Suitable Medley" (author''s statement)', 10653, 'This can be entered in the "Tune" field when the author of a Medley explicitly leaves the choice of a tune to the reader.');
INSERT INTO 'tune' VALUES (11592, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.191378+00', 'Birchinlea', 10401, '');
INSERT INTO 'tune' VALUES (11593, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.194312+00', 'King''s Tree, The', 10401, '');
INSERT INTO 'tune' VALUES (11594, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.197235+00', 'Slippery Stones', 10401, '');
INSERT INTO 'tune' VALUES (11595, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.200161+00', 'Geordie Diamond, The', 1725, '');
INSERT INTO 'tune' VALUES (11596, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.203079+00', 'Newcastle Festival Reel', 1725, '');
INSERT INTO 'tune' VALUES (11597, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.206021+00', 'John Cass''s Reel', 1725, '');
INSERT INTO 'tune' VALUES (11598, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.208957+00', 'Wingrove', 1725, '');
INSERT INTO 'tune' VALUES (11599, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.21189+00', 'Sally Salveson''s Jig', 1725, '');
INSERT INTO 'tune' VALUES (11600, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.214826+00', 'Maureen Barlow Strathspey, The', 1725, '');
INSERT INTO 'tune' VALUES (11601, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.217755+00', 'Maureen Barlow Reel, The', 1725, '');
INSERT INTO 'tune' VALUES (11602, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.221015+00', 'John Ferguson''s Swat', 1725, '');
INSERT INTO 'tune' VALUES (11603, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.224256+00', 'Pam Scott''s Strathspey', 1725, '');
INSERT INTO 'tune' VALUES (11604, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.227305+00', 'Tyneside Ceilidh, The', 1725, '');
INSERT INTO 'tune' VALUES (11605, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.23024+00', 'St Chad''s Strathspey', 1725, '');
INSERT INTO 'tune' VALUES (11606, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.233183+00', 'Keys, The', 2807, '');
INSERT INTO 'tune' VALUES (11607, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.236127+00', 'Kathryn Tickell''s Strathspey', 2608, '');
INSERT INTO 'tune' VALUES (11609, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.239058+00', 'Lord and Lady Ridley of Blagdon', 1725, '');
INSERT INTO 'tune' VALUES (11624, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.283094+00', 'Simple Gifts', 10405, '');
INSERT INTO 'tune' VALUES (11618, '2011-08-22 22:00:00+00', '2012-11-07 10:58:09.36783+00', 'Barbara''s Strathspey', 2197, '');
INSERT INTO 'tune' VALUES (11621, '2011-08-22 22:00:00+00', '2019-06-15 12:58:39.467058+00', 'An Te Liath', 3179, '');
INSERT INTO 'tune' VALUES (11644, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.342223+00', 'Roy Goldring of Ilkley', 1502, '');
INSERT INTO 'tune' VALUES (11646, '2011-08-22 22:00:00+00', '2012-01-20 12:54:58.348079+00', 'Windswept Moors, The', 1502, '');
INSERT INTO 'tune' VALUES (11648, '2011-08-24 22:00:00+00', '2012-01-20 12:54:58.353925+00', 'Donna''s Delight', 10418, '');
INSERT INTO 'tune' VALUES (11651, '2011-08-24 22:00:00+00', '2012-01-20 12:54:58.362722+00', 'Jill''s Gentle Jig', 389, '');
INSERT INTO 'tune' VALUES (11653, '2011-08-24 22:00:00+00', '2012-01-20 12:54:58.368578+00', 'Mr Murphy''s Bicycle', 10418, '');
INSERT INTO 'tune' VALUES (11657, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.380283+00', 'Changeling, The', 389, '');
INSERT INTO 'tune' VALUES (11659, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.386117+00', 'Cross Links', 389, '');
INSERT INTO 'tune' VALUES (11661, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.391993+00', 'Fort Worden''s Pearl', 401, '');
INSERT INTO 'tune' VALUES (11662, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.394938+00', 'MacDonald''s Ball, The', 389, '');
INSERT INTO 'tune' VALUES (11663, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.397867+00', 'Maitland to Manchester', 389, '');
INSERT INTO 'tune' VALUES (11664, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.400787+00', 'Grange Hall, The', 1502, '');
INSERT INTO 'tune' VALUES (11665, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.40372+00', 'Old and Dangerous', 389, '');
INSERT INTO 'tune' VALUES (11666, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.406664+00', 'Pugwash and Tatamagouche', 401, '');
INSERT INTO 'tune' VALUES (11667, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.409581+00', 'Shetland Shepherdess, The', 401, '');
INSERT INTO 'tune' VALUES (11668, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.412516+00', 'Through the Streets of Prague', 389, '');
INSERT INTO 'tune' VALUES (11669, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.415448+00', 'Whimsy', 389, '');
INSERT INTO 'tune' VALUES (11670, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.418378+00', 'O tell me o''wind and rain', 9998, '');
INSERT INTO 'tune' VALUES (11560, '2011-07-13 22:00:00+00', '2014-11-05 21:44:12.534558+00', 'Shevock, The', 2692, 'Music copyright © James Stevenson-Mathews



First published in ''The Tin Woodman and other dances'', Scotia Dance and Music Publishers

');
INSERT INTO 'tune' VALUES (11671, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.421301+00', 'Julia Rattray Carapanos', 10432, '');
INSERT INTO 'tune' VALUES (11672, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.424221+00', 'Miss Melanie Howard', 10432, '');
INSERT INTO 'tune' VALUES (11673, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.427132+00', 'NWSD Hornpipe, The', 10432, '');
INSERT INTO 'tune' VALUES (11675, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.432995+00', 'Peter Knapman''s Jig', 1596, '');
INSERT INTO 'tune' VALUES (11676, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.436091+00', 'Mrs Sandra Donnet', 217, '');
INSERT INTO 'tune' VALUES (11677, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.439722+00', 'Iain Stuart''s Strathspey', 1596, '');
INSERT INTO 'tune' VALUES (11678, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.443592+00', 'John and Joan Young of New Kilpatrick', 10445, '');
INSERT INTO 'tune' VALUES (11679, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.447458+00', 'Duncan''s Reel', 2576, '');
INSERT INTO 'tune' VALUES (11680, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.451311+00', 'Christopher Sanders'' Jig', 1596, '');
INSERT INTO 'tune' VALUES (11681, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.455166+00', 'Margaret Sanders'' Jig', 1596, '');
INSERT INTO 'tune' VALUES (11682, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.459015+00', 'Joyce Carmichael''s Strathspey', 1596, '');
INSERT INTO 'tune' VALUES (11683, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.462876+00', 'Homage to Bill Jack', 10447, '');
INSERT INTO 'tune' VALUES (11685, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.47058+00', 'Save the Children', 1817, '');
INSERT INTO 'tune' VALUES (11686, '2011-08-25 22:00:00+00', '2012-01-20 12:54:58.474422+00', 'Innocents, The', 1817, '');
INSERT INTO 'tune' VALUES (11688, '2011-08-26 22:00:00+00', '2012-01-20 12:54:58.482122+00', 'Peter Johnson''s Strathspey', 948, '');
INSERT INTO 'tune' VALUES (11689, '2011-08-26 22:00:00+00', '2012-01-20 12:54:58.485963+00', 'Manifold Maniac, The', 948, '');
INSERT INTO 'tune' VALUES (11655, '2011-08-25 22:00:00+00', '2012-07-15 21:12:43.595301+00', 'Aberdeen Hunt', 1695, 'Robert Petrie Collection I, 1790');
INSERT INTO 'tune' VALUES (11690, '2011-08-26 22:00:00+00', '2012-01-20 12:54:58.489799+00', 'Tune for Don, A', 948, '');
INSERT INTO 'tune' VALUES (11691, '2011-08-26 22:00:00+00', '2012-01-20 12:54:58.493709+00', 'Eagle Stone, The', 948, '');
INSERT INTO 'tune' VALUES (11692, '2011-08-26 22:00:00+00', '2012-01-20 12:54:58.497551+00', 'Michael''s Rock', 948, '');
INSERT INTO 'tune' VALUES (11693, '2011-08-26 22:00:00+00', '2012-01-20 12:54:58.501403+00', 'Malcolm''s Reel', 948, '');
INSERT INTO 'tune' VALUES (11694, '2011-08-26 22:00:00+00', '2012-01-20 12:54:58.505242+00', 'Narrowdale', 948, '');
INSERT INTO 'tune' VALUES (11695, '2011-08-26 22:00:00+00', '2012-01-20 12:54:58.509084+00', 'Dancing Piper, The', 10458, '');
INSERT INTO 'tune' VALUES (11697, '2011-08-26 22:00:00+00', '2012-01-20 12:54:58.516777+00', 'Saddler''s Daughter, The', 2085, '');
INSERT INTO 'tune' VALUES (11698, '2011-08-26 22:00:00+00', '2012-01-20 12:54:58.520625+00', 'Wendy of Appin', 3612, '');
INSERT INTO 'tune' VALUES (11699, '2011-08-26 22:00:00+00', '2012-01-20 12:54:58.524495+00', 'Joan MacArthur', 1457, '');
INSERT INTO 'tune' VALUES (11700, '2011-08-26 22:00:00+00', '2012-01-20 12:54:58.528345+00', 'Andrew MacArthur', 1457, '');
INSERT INTO 'tune' VALUES (11701, '2011-09-14 22:00:00+00', '2012-01-20 12:54:58.532526+00', 'Smiths Farewell to Shetland, The', 1724, '');
INSERT INTO 'tune' VALUES (11702, '2011-09-14 22:00:00+00', '2012-01-20 12:54:58.536384+00', 'Queens Bridge, The', 9999, '');
INSERT INTO 'tune' VALUES (11630, '2011-08-22 22:00:00+00', '2018-04-07 07:20:54.624544+00', 'Anniversary Jig, The', 3179, '');
INSERT INTO 'tune' VALUES (11620, '2011-08-22 22:00:00+00', '2018-04-07 07:24:18.527938+00', 'Autumn Song, An', 3179, '');
INSERT INTO 'tune' VALUES (11611, '2011-08-22 22:00:00+00', '2018-04-07 23:24:13.572204+00', 'Many Happy Hours', 3179, '');
INSERT INTO 'tune' VALUES (11610, '2011-08-22 22:00:00+00', '2018-04-07 06:59:43.679399+00', '35 Years and Counting', 3179, '');
INSERT INTO 'tune' VALUES (11612, '2011-08-22 22:00:00+00', '2018-04-07 23:44:07.873253+00', 'Mountain Air', 3179, '');
INSERT INTO 'tune' VALUES (11613, '2011-08-22 22:00:00+00', '2018-04-07 23:47:39.965521+00', 'Faerie Garden, The', 3179, '');
INSERT INTO 'tune' VALUES (11614, '2011-08-22 22:00:00+00', '2018-04-07 23:49:55.592755+00', 'Green Meadows', 3179, '');
INSERT INTO 'tune' VALUES (11615, '2011-08-22 22:00:00+00', '2018-04-07 23:55:35.215824+00', 'Helen Brown of Dunnington', 3179, '');
INSERT INTO 'tune' VALUES (11636, '2011-08-22 22:00:00+00', '2018-04-08 08:10:29.186094+00', 'Rainbow Nation', 3179, '');
INSERT INTO 'tune' VALUES (11628, '2011-08-22 22:00:00+00', '2018-04-08 08:15:40.560618+00', 'To Life', 3179, '');
INSERT INTO 'tune' VALUES (11641, '2011-08-22 22:00:00+00', '2018-04-08 08:20:20.894974+00', 'To Have and To Hold', 3179, '');
INSERT INTO 'tune' VALUES (11616, '2011-08-22 22:00:00+00', '2018-04-08 08:23:11.442299+00', 'Echoes of Strathglass', 3179, '');
INSERT INTO 'tune' VALUES (11617, '2011-08-22 22:00:00+00', '2018-04-08 08:31:24.087761+00', 'Elegant Gentleman, The', 3179, '');
INSERT INTO 'tune' VALUES (11634, '2011-08-22 22:00:00+00', '2018-04-08 08:37:16.013816+00', 'Scottish Fantasy, A', 3179, '');
INSERT INTO 'tune' VALUES (11637, '2011-08-22 22:00:00+00', '2018-04-08 08:47:56.531093+00', 'Reel for St Columba''s Church', 3179, '');
INSERT INTO 'tune' VALUES (11626, '2011-08-22 22:00:00+00', '2018-04-08 10:28:11.335773+00', 'Touching the Heart', 3179, '');
INSERT INTO 'tune' VALUES (11642, '2011-08-22 22:00:00+00', '2018-04-08 10:32:55.665418+00', 'Toast to Tobie, A', 3179, '');
INSERT INTO 'tune' VALUES (11622, '2011-08-22 22:00:00+00', '2018-04-09 00:45:03.798128+00', 'Irene''s Piece', 3179, '');
INSERT INTO 'tune' VALUES (11638, '2011-08-22 22:00:00+00', '2018-04-09 00:28:39.158318+00', 'Cook Dauth''s Strathspey', 3179, '');
INSERT INTO 'tune' VALUES (11635, '2011-08-22 22:00:00+00', '2018-04-09 05:34:41.436814+00', 'Draoideachd Mhuriel', 3179, '');
INSERT INTO 'tune' VALUES (11632, '2011-08-22 22:00:00+00', '2018-04-09 05:41:27.09052+00', 'Driving Home', 3179, '');
INSERT INTO 'tune' VALUES (11629, '2011-08-22 22:00:00+00', '2018-04-09 05:44:00.882924+00', 'Election Day', 3179, '');
INSERT INTO 'tune' VALUES (11627, '2011-08-22 22:00:00+00', '2018-04-09 05:46:57.84297+00', 'Examiners'' Jig, The', 3179, '');
INSERT INTO 'tune' VALUES (11631, '2011-08-22 22:00:00+00', '2018-04-10 09:09:05.663789+00', 'Love and Sunbeams', 3179, '');
INSERT INTO 'tune' VALUES (11619, '2011-08-22 22:00:00+00', '2018-04-09 09:25:37.104059+00', 'Fiddler''s Fare', 3179, '');
INSERT INTO 'tune' VALUES (11639, '2011-08-22 22:00:00+00', '2018-04-10 09:11:14.285642+00', 'Lyn''s Hornpipe', 3179, '');
INSERT INTO 'tune' VALUES (11625, '2011-08-22 22:00:00+00', '2018-04-10 09:12:53.287772+00', 'Malcolm Brown of Dunnington', 3179, '');
INSERT INTO 'tune' VALUES (11645, '2011-08-22 22:00:00+00', '2018-04-10 09:29:40.752733+00', 'Misty Mountain Reel', 3179, '');
INSERT INTO 'tune' VALUES (11654, '2011-08-24 22:00:00+00', '2020-01-03 21:29:24.940652+00', 'Rachel and Neil''s Reel', 11645, '');
INSERT INTO 'tune' VALUES (11633, '2011-08-22 22:00:00+00', '2018-04-10 10:29:59.759869+00', 'Mrs Margo Monteith', 3179, '');
INSERT INTO 'tune' VALUES (11674, '2011-08-25 22:00:00+00', '2019-09-17 00:02:49.246934+00', 'Compliments to Claudette Sigg', 10432, '');
INSERT INTO 'tune' VALUES (11703, '2011-09-14 22:00:00+00', '2012-01-20 12:54:58.540231+00', 'Man of Kettle', 1910, '');
INSERT INTO 'tune' VALUES (11704, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.544093+00', 'Stuart and Kenny Thomson', 10103, '');
INSERT INTO 'tune' VALUES (11705, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.54794+00', 'Spider''s Web, The', 1898, '');
INSERT INTO 'tune' VALUES (11706, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.551782+00', 'Hoddum House', 9999, '');
INSERT INTO 'tune' VALUES (11707, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.555634+00', 'Mrs Brooke', 2346, '');
INSERT INTO 'tune' VALUES (11708, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.559479+00', 'Ruth''s Reel', 10481, '');
INSERT INTO 'tune' VALUES (11709, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.563333+00', 'Horn Concerto', 2399, '');
INSERT INTO 'tune' VALUES (11710, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.567181+00', 'Finiculi Finicula', 10479, '');
INSERT INTO 'tune' VALUES (11711, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.571035+00', 'Mexican Hat Dance, The', 10480, '');
INSERT INTO 'tune' VALUES (11712, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.57488+00', 'Mr Jack Bishop', 10482, '');
INSERT INTO 'tune' VALUES (11713, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.578739+00', 'Brighills', 3186, '');
INSERT INTO 'tune' VALUES (11714, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.582624+00', 'Centenary Jewel, The', 1761, '');
INSERT INTO 'tune' VALUES (11715, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.586487+00', 'Mrs Moyra Sutherland', 2768, '');
INSERT INTO 'tune' VALUES (11716, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.590342+00', 'Miss Z Loughman', 10483, '');
INSERT INTO 'tune' VALUES (11717, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.59419+00', 'Peter''s Jig', 10484, '');
INSERT INTO 'tune' VALUES (11718, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.598043+00', 'Sam''s Sugar Bush Jig', 10485, '');
INSERT INTO 'tune' VALUES (11719, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.601885+00', 'Rusty Nail, The', 10486, '');
INSERT INTO 'tune' VALUES (11721, '2011-09-21 22:00:00+00', '2012-01-20 12:54:58.609579+00', 'Brogan''s Cove Jig', 10488, '');
INSERT INTO 'tune' VALUES (11816, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.977246+00', 'Ernie''s Impact', 10521, '');
INSERT INTO 'tune' VALUES (11817, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.981095+00', 'Mr and Mrs J Duncan''s Golden Wedding 2000', 3129, '');
INSERT INTO 'tune' VALUES (11818, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.984957+00', 'New Millstead, The', 1811, '');
INSERT INTO 'tune' VALUES (11722, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.613437+00', 'Palm in the Pavement, the', 2848, 'One day durng the 2002 Summer School in St. Andrews, walking to class one morning Bernie noticed the clear palm-print in the freshly laid concrete pavement.  Probably made by someone with a very similar sense of humour to his own.  That is how the tune got its name.');
INSERT INTO 'tune' VALUES (11723, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.617318+00', 'Autumn Rose', 1445, '');
INSERT INTO 'tune' VALUES (11724, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.621176+00', 'Birthday in Prague', 1445, '');
INSERT INTO 'tune' VALUES (11725, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.625024+00', 'Douglas of Aruba', 1445, '');
INSERT INTO 'tune' VALUES (11726, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.628872+00', 'Edwin Werner''s Reel', 1445, '');
INSERT INTO 'tune' VALUES (11727, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.632778+00', 'Piper''s Knot, The', 1445, '');
INSERT INTO 'tune' VALUES (11728, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.636706+00', 'Girls from Edinburgh, The', 1445, '');
INSERT INTO 'tune' VALUES (11729, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.640559+00', 'Hurray for Two!', 1445, '');
INSERT INTO 'tune' VALUES (11730, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.644403+00', 'Jigging Along', 1445, '');
INSERT INTO 'tune' VALUES (11731, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.648254+00', 'Cheerful Duck, The', 1445, '');
INSERT INTO 'tune' VALUES (11732, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.652112+00', 'Roosendaal Pot, The', 2848, '');
INSERT INTO 'tune' VALUES (11733, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.655975+00', 'Eindhoven Pot, The', 1445, '');
INSERT INTO 'tune' VALUES (11734, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.659875+00', 'Firefly Jig, The', 1445, '');
INSERT INTO 'tune' VALUES (11735, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.663738+00', 'Mammoth Hunter''s Reel, The', 1445, 'In the first part of the tune the mammoth hunter is playing his little flute, and in the second part the mammoth, attracted by the sound of the flute, is slowly and noisily coming nearer and nearer.');
INSERT INTO 'tune' VALUES (11736, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.667683+00', 'Eindhoven Thistles, The', 1445, '');
INSERT INTO 'tune' VALUES (11737, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.671535+00', 'Bristling Thistle, The', 1445, '');
INSERT INTO 'tune' VALUES (11738, '2011-10-15 22:00:00+00', '2012-01-20 12:54:58.675378+00', 'Purple Brush, A', 1445, '');
INSERT INTO 'tune' VALUES (11739, '2011-10-26 22:00:00+00', '2012-01-20 12:54:58.679221+00', 'Giants of Foundland', 2523, '');
INSERT INTO 'tune' VALUES (11740, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.683088+00', 'Jour de Quarantième', 1511, '');
INSERT INTO 'tune' VALUES (11741, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.686965+00', 'Bargeman''s Blisters', 9999, '');
INSERT INTO 'tune' VALUES (11742, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.690812+00', 'Gathering, The', 3129, '');
INSERT INTO 'tune' VALUES (11743, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.694668+00', 'Neil on the Floor', 1782, '');
INSERT INTO 'tune' VALUES (11744, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.698517+00', 'Thorndike''s Dream', 2724, '');
INSERT INTO 'tune' VALUES (11745, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.702363+00', 'Hogmanay Engagement', 10315, '');
INSERT INTO 'tune' VALUES (11746, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.706205+00', 'Dr Gregory Grant', 10502, '');
INSERT INTO 'tune' VALUES (11748, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.713892+00', 'Canadian Club, The', 3207, '');
INSERT INTO 'tune' VALUES (11749, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.717726+00', 'New Stove, The', 3207, '');
INSERT INTO 'tune' VALUES (11750, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.721566+00', 'Union Street', 2238, '');
INSERT INTO 'tune' VALUES (11751, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.725417+00', 'Pressed for Time', 3129, '');
INSERT INTO 'tune' VALUES (11752, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.729252+00', 'Ken Allan''s Clog', 2724, '');
INSERT INTO 'tune' VALUES (11753, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.733407+00', 'Flying Squirrel Hornpipe', 2724, '');
INSERT INTO 'tune' VALUES (11754, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.737253+00', 'Piper Doon', 9999, '');
INSERT INTO 'tune' VALUES (11755, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.741117+00', 'Christina', 1782, '');
INSERT INTO 'tune' VALUES (11756, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.744981+00', 'My Land', 9999, '');
INSERT INTO 'tune' VALUES (11757, '2011-11-02 23:00:00+00', '2012-01-20 12:54:58.748933+00', 'Colin''s Cattle', 9999, '');
INSERT INTO 'tune' VALUES (11758, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.752769+00', 'Miss Jeanetta McColl', 316, '');
INSERT INTO 'tune' VALUES (11760, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.760475+00', 'Miss Stewart of Physgill''s Favourite', 1517, '');
INSERT INTO 'tune' VALUES (11761, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.764325+00', 'Charlie Hardie', 1512, '');
INSERT INTO 'tune' VALUES (11762, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.768172+00', 'Hoptoun House', 9999, '');
INSERT INTO 'tune' VALUES (11763, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.772025+00', 'Boyne Water, The', 9999, '');
INSERT INTO 'tune' VALUES (11764, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.775872+00', 'Panel Mine', 2126, '');
INSERT INTO 'tune' VALUES (11765, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.779719+00', 'Long Water, The', 10505, '');
INSERT INTO 'tune' VALUES (11766, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.783563+00', 'Jock''s Fiddle', 10506, '');
INSERT INTO 'tune' VALUES (11767, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.787404+00', 'Mrs Murray of Abercarny', 10507, '');
INSERT INTO 'tune' VALUES (11768, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.791255+00', 'Merry Making, The', 9999, '');
INSERT INTO 'tune' VALUES (11769, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.795111+00', 'Catch and Kiss the Romp', 9999, '');
INSERT INTO 'tune' VALUES (11770, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.798957+00', 'Scotty Fitzgerald''s Jig', 10508, '');
INSERT INTO 'tune' VALUES (11771, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.802822+00', 'Fiddlers Three', 9998, '');
INSERT INTO 'tune' VALUES (11772, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.806666+00', 'John Donald Cameron', 2126, '');
INSERT INTO 'tune' VALUES (11773, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.810505+00', 'Fingal''s Weeping', 9999, '');
INSERT INTO 'tune' VALUES (11774, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.814358+00', 'Miss Maxwell', 1845, '');
INSERT INTO 'tune' VALUES (11775, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.818202+00', 'Bob Macintosh', 10509, '');
INSERT INTO 'tune' VALUES (11776, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.822058+00', 'Harbourview Jig, The', 2126, '');
INSERT INTO 'tune' VALUES (11777, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.825886+00', 'Duke of Atholl''s Forest Lodge, Glen Tilt, The', 1587, '');
INSERT INTO 'tune' VALUES (11778, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.829731+00', 'Invereys Rant', 1781, '');
INSERT INTO 'tune' VALUES (11780, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.837424+00', 'Mist on the Mountain', 717, '');
INSERT INTO 'tune' VALUES (11781, '2011-11-03 23:00:00+00', '2012-01-20 12:54:58.84127+00', 'San Francisco Branch Polka, The', 1773, '');
INSERT INTO 'tune' VALUES (11782, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.845118+00', 'In Praise of Isla', 9999, '');
INSERT INTO 'tune' VALUES (11783, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.848969+00', 'Blue Bonnets over the Border', 9999, '');
INSERT INTO 'tune' VALUES (11784, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.852861+00', 'Miss Margaret Brander', 1607, '');
INSERT INTO 'tune' VALUES (11785, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.85672+00', 'Miss Muriel Hadden', 1607, '');
INSERT INTO 'tune' VALUES (11786, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.860601+00', 'Earl of Erroll, The', 9999, '');
INSERT INTO 'tune' VALUES (11787, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.864532+00', '23rd Countess of Erroll, The', 10514, '');
INSERT INTO 'tune' VALUES (11788, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.868389+00', 'Last Measure Prince Charlie danced with Flora, The', 9999, '');
INSERT INTO 'tune' VALUES (11789, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.872682+00', 'Graces, The', 9999, '');
INSERT INTO 'tune' VALUES (11790, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.876544+00', 'Flora Cruikshank of Peterhead', 1607, '');
INSERT INTO 'tune' VALUES (11791, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.880394+00', 'Jean', 1607, '');
INSERT INTO 'tune' VALUES (11792, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.884242+00', 'English Lassie, An', 1607, '');
INSERT INTO 'tune' VALUES (11793, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.888084+00', 'King of Sweden, The', 9999, '');
INSERT INTO 'tune' VALUES (11794, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.891928+00', 'Miss Muriel Hadden', 1607, '');
INSERT INTO 'tune' VALUES (11795, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.895782+00', 'Gentle Maid, The', 9999, '');
INSERT INTO 'tune' VALUES (11796, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.899632+00', 'Madge - or Farewell to Scotland', 1512, '');
INSERT INTO 'tune' VALUES (11797, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.903475+00', 'Island Spinning Song', 9999, '');
INSERT INTO 'tune' VALUES (11798, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.907319+00', 'Rattlin'' Roarin'' Willie', 9999, '');
INSERT INTO 'tune' VALUES (11799, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.91117+00', 'Misses Grant of Monymusk, The', 9999, '');
INSERT INTO 'tune' VALUES (11800, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.915477+00', 'Pas de Trois for the Misses Glennie', 9999, '');
INSERT INTO 'tune' VALUES (11801, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.919346+00', 'Birks o'' Abergeldie, The', 9999, '');
INSERT INTO 'tune' VALUES (11802, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.923198+00', 'Village Maid, The', 9999, '');
INSERT INTO 'tune' VALUES (11803, '2011-11-04 23:00:00+00', '2012-01-20 12:54:58.927053+00', 'Don''t Leave Me Alone', 9999, '');
INSERT INTO 'tune' VALUES (11804, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.931146+00', 'Gillies'' Taxis', 1761, '');
INSERT INTO 'tune' VALUES (11805, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.93501+00', 'Lieutenant Colonel D.J.S. Murray', 10518, '');
INSERT INTO 'tune' VALUES (11806, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.93886+00', 'Ruby, The', 1761, '');
INSERT INTO 'tune' VALUES (11807, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.942715+00', 'Brian Syminton', 2656, '');
INSERT INTO 'tune' VALUES (11808, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.946542+00', 'Kiwi Pipers, The', 1811, '');
INSERT INTO 'tune' VALUES (11809, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.950383+00', 'Gretna Accordion and Fiddle Club 30th Anniversary', 1593, '');
INSERT INTO 'tune' VALUES (11810, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.954225+00', 'Duncan Johnstone', 1910, '');
INSERT INTO 'tune' VALUES (11811, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.958067+00', 'Tourist, The', 10519, '');
INSERT INTO 'tune' VALUES (11812, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.961894+00', 'Alistair''s 60th', 1591, '');
INSERT INTO 'tune' VALUES (11813, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.965737+00', 'Incorporation, The', 1673, '');
INSERT INTO 'tune' VALUES (11814, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.969582+00', 'How Can You Buy Killarney', 9999, '');
INSERT INTO 'tune' VALUES (11819, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.988807+00', 'Inner Guard', 1673, '');
INSERT INTO 'tune' VALUES (11820, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.992662+00', 'Douglas Adamson Polka, The', 1605, '');
INSERT INTO 'tune' VALUES (11821, '2011-11-17 23:00:00+00', '2012-01-20 12:54:58.996508+00', 'Dennis Morrison "The Master"', 1591, '');
INSERT INTO 'tune' VALUES (11822, '2011-11-17 23:00:00+00', '2012-01-20 12:54:59.000355+00', 'Marian Anderson''s Compliments to Peggy and Les MacKintosh', 3220, '');
INSERT INTO 'tune' VALUES (11823, '2011-11-17 23:00:00+00', '2012-01-20 12:54:59.004213+00', 'J.D. Peace of Shoreside', 10522, '');
INSERT INTO 'tune' VALUES (11824, '2011-11-17 23:00:00+00', '2012-01-20 12:54:59.008048+00', 'Farewell to Darling Harbour', 3220, '');
INSERT INTO 'tune' VALUES (11825, '2011-11-17 23:00:00+00', '2012-01-20 12:54:59.011936+00', 'Return to the Brandy Wine', 10523, '');
INSERT INTO 'tune' VALUES (11827, '2011-11-17 23:00:00+00', '2012-01-20 12:54:59.019622+00', 'Ally Bally', 9999, '');
INSERT INTO 'tune' VALUES (11828, '2011-11-17 23:00:00+00', '2012-01-20 12:54:59.023485+00', 'Thunderhead', 10524, '');
INSERT INTO 'tune' VALUES (11829, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.027333+00', 'Ubhaidh Abhaidh', 9999, '');
INSERT INTO 'tune' VALUES (11830, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.03117+00', 'Fear A Phige', 9999, '');
INSERT INTO 'tune' VALUES (11831, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.03505+00', 'Sorrento Thoughts', 10526, '');
INSERT INTO 'tune' VALUES (11832, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.038911+00', 'Joe Mann''s Farewell to Leichester City Police', 1533, '');
INSERT INTO 'tune' VALUES (11833, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.042763+00', 'Leaving Uist', 9999, '');
INSERT INTO 'tune' VALUES (11834, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.046601+00', 'Fair One''s Wedding, The', 9999, '');
INSERT INTO 'tune' VALUES (11835, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.050439+00', 'Cullen Bay', 1795, '');
INSERT INTO 'tune' VALUES (11836, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.054287+00', 'Lily MacNally MacNair', 503, '');
INSERT INTO 'tune' VALUES (11837, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.058122+00', 'Highland Wedding, The', 2209, '');
INSERT INTO 'tune' VALUES (11838, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.061958+00', 'Willie and Bertha''s Two-step', 10110, '');
INSERT INTO 'tune' VALUES (11839, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.065804+00', 'Inside Oot Eater, The', 2253, '');
INSERT INTO 'tune' VALUES (11840, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.069655+00', 'Brydon Morrison''s Reel', 2253, '');
INSERT INTO 'tune' VALUES (11841, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.073495+00', 'Mickie And Jimmy', 1551, '');
INSERT INTO 'tune' VALUES (11842, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.077344+00', 'Those Magnificent Men In Their', 10528, '');
INSERT INTO 'tune' VALUES (11843, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.081186+00', 'On the Crest of a Wave', 10529, '');
INSERT INTO 'tune' VALUES (11844, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.085327+00', 'Zip-A-Dee-Doo-Dah', 10530, '');
INSERT INTO 'tune' VALUES (11846, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.093135+00', 'Tranebergvalsen', 10154, '');
INSERT INTO 'tune' VALUES (11849, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.104661+00', 'Miss Susan Maclean', 1605, '');
INSERT INTO 'tune' VALUES (11850, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.108509+00', 'When You And I Were Young Maggie', 10532, '');
INSERT INTO 'tune' VALUES (11851, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.112355+00', 'Mrs Stewart''s Jig Of Bombay', 9999, '');
INSERT INTO 'tune' VALUES (11852, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.116243+00', 'Rosewood', 9999, '');
INSERT INTO 'tune' VALUES (11856, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.132849+00', 'Tangerine', 9999, '');
INSERT INTO 'tune' VALUES (11857, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.140385+00', 'Debbie "M" Jig', 2569, '');
INSERT INTO 'tune' VALUES (11859, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.15036+00', 'Paddy McDonald''s Leather Breeks', 9999, '');
INSERT INTO 'tune' VALUES (11860, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.154373+00', 'Oh Dear What Can The Matter Be?', 9999, '');
INSERT INTO 'tune' VALUES (11861, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.1583+00', 'My Bonnie', 9999, '');
INSERT INTO 'tune' VALUES (11862, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.162196+00', 'Mrs McPherson Of Clunie', 9999, '');
INSERT INTO 'tune' VALUES (11864, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.169904+00', 'Chinatown, My Chinatown', 10534, '');
INSERT INTO 'tune' VALUES (11865, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.17505+00', 'David Henry''s March', 2253, '');
INSERT INTO 'tune' VALUES (11866, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.179366+00', 'Johan Elizabeth Jamieson''s Favourite', 130, '');
INSERT INTO 'tune' VALUES (11867, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.183288+00', 'Moarfield Waltz, The', 130, '');
INSERT INTO 'tune' VALUES (11868, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.187948+00', 'Hills of Biggar, The', 10536, '');
INSERT INTO 'tune' VALUES (11869, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.191845+00', 'Miss Aimee Scott', 2253, '');
INSERT INTO 'tune' VALUES (11870, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.195751+00', 'Skerry Song', 10535, '');
INSERT INTO 'tune' VALUES (11871, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.199617+00', 'Bannocks an'' Bursteen an'' Brunnies', 10535, '');
INSERT INTO 'tune' VALUES (11872, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.203499+00', 'Wir Lavin d''Day', 10535, '');
INSERT INTO 'tune' VALUES (11873, '2011-11-25 23:00:00+00', '2012-01-20 12:54:59.20743+00', 'Beautiful Bountiful Day', 10535, '');
INSERT INTO 'tune' VALUES (11874, '2011-11-25 23:00:00+00', '2012-01-20 12:55:00.932488+00', 'Harald Maddadsson''s Two Step', 2253, '');
INSERT INTO 'tune' VALUES (11875, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.936369+00', 'Simmer Dim', 1786, '');
INSERT INTO 'tune' VALUES (11876, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.940216+00', 'Shetland Bus, The', 1623, '');
INSERT INTO 'tune' VALUES (11877, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.944065+00', 'Uncle Magnie''s Reel', 2253, '');
INSERT INTO 'tune' VALUES (11879, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.951814+00', 'Blind Man''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (11880, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.95566+00', 'Blackberry Blossom', 9999, '');
INSERT INTO 'tune' VALUES (11881, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.959506+00', 'Ellabister Burn, Da', 10538, '');
INSERT INTO 'tune' VALUES (11882, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.963347+00', 'Long Tailed Mouse, The', 10538, '');
INSERT INTO 'tune' VALUES (11883, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.967193+00', 'Queen of the North', 1786, '');
INSERT INTO 'tune' VALUES (11884, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.971043+00', 'Postman Pat', 10539, '');
INSERT INTO 'tune' VALUES (11885, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.974865+00', 'Shalder''s Ayre', 10538, '');
INSERT INTO 'tune' VALUES (11886, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.978708+00', 'Billy Wilson''s Clog', 9999, '');
INSERT INTO 'tune' VALUES (11887, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.982548+00', 'Minstrel''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (11888, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.986401+00', 'North Sea Hornpipe', 1786, '');
INSERT INTO 'tune' VALUES (11889, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.990233+00', 'Bixter Boys, Da', 1786, '');
INSERT INTO 'tune' VALUES (11890, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.99407+00', 'Burns Lane Boys', 1786, '');
INSERT INTO 'tune' VALUES (11891, '2011-11-26 23:00:00+00', '2012-01-20 12:55:00.9979+00', 'Gulberwick Bay', 10540, '');
INSERT INTO 'tune' VALUES (11892, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.001729+00', 'Belle Meres Waltz', 1761, '');
INSERT INTO 'tune' VALUES (11853, '2011-11-25 23:00:00+00', '2020-01-20 22:30:58.9576+00', 'Kiwi Reel', 1677, '');
INSERT INTO 'tune' VALUES (11893, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.005574+00', 'Waltz for Heather', 10542, '');
INSERT INTO 'tune' VALUES (11894, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.00942+00', 'Bridesmaids Waltz, The', 10542, '');
INSERT INTO 'tune' VALUES (11895, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.013266+00', 'Tam Reid''s Ceilidh', 1505, '');
INSERT INTO 'tune' VALUES (11896, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.017115+00', 'Mclnally''s Mandolin', 10543, '');
INSERT INTO 'tune' VALUES (11897, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.020954+00', 'Eion Graeme Tosh', 10544, '');
INSERT INTO 'tune' VALUES (11898, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.024805+00', 'Struan William David Gowck', 10542, '');
INSERT INTO 'tune' VALUES (11899, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.028662+00', 'Out The Buckhorn Way', 2569, '');
INSERT INTO 'tune' VALUES (11900, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.032495+00', 'Joys of Quebec, The', 9999, '');
INSERT INTO 'tune' VALUES (11901, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.036348+00', 'Finlay Scott Carnegie', 10542, '');
INSERT INTO 'tune' VALUES (11902, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.040224+00', 'Philalys Reel', 3052, '');
INSERT INTO 'tune' VALUES (11903, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.044073+00', 'Liam Carnegie''s March', 10542, '');
INSERT INTO 'tune' VALUES (11904, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.047912+00', 'Battle of Nechtansmere, The', 10545, '');
INSERT INTO 'tune' VALUES (11905, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.05175+00', 'Miss Thomson''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (11906, '2011-11-26 23:00:00+00', '2012-01-20 12:55:01.055602+00', 'Bearsden Fiddlers', 1817, '');
INSERT INTO 'tune' VALUES (11907, '2011-11-27 23:00:00+00', '2012-01-20 12:55:01.059436+00', 'Penholme', 9998, '');
INSERT INTO 'tune' VALUES (11908, '2011-11-27 23:00:00+00', '2012-01-20 12:55:01.063283+00', 'George Clark''s Caber', 1550, '');
INSERT INTO 'tune' VALUES (11909, '2011-11-27 23:00:00+00', '2012-01-20 12:55:01.067137+00', 'Tayside Pipers Society', 9998, '');
INSERT INTO 'tune' VALUES (11910, '2011-11-27 23:00:00+00', '2012-01-20 12:55:01.071082+00', 'Eilidh Mhairi', 1543, '');
INSERT INTO 'tune' VALUES (11912, '2011-11-27 23:00:00+00', '2012-01-20 12:55:01.078781+00', 'Boulevogue', 9999, '');
INSERT INTO 'tune' VALUES (11913, '2011-11-28 23:00:00+00', '2012-01-20 12:55:01.082905+00', 'Mistress Jameson''s Favourite', 9999, '');
INSERT INTO 'tune' VALUES (11914, '2011-11-28 23:00:00+00', '2012-01-20 12:55:01.086778+00', 'Braddoch Banner', 9998, '');
INSERT INTO 'tune' VALUES (11915, '2011-11-28 23:00:00+00', '2012-01-20 12:55:01.09061+00', 'Terribus', 9999, '');
INSERT INTO 'tune' VALUES (11916, '2011-11-29 23:00:00+00', '2012-01-20 12:55:01.094461+00', 'Father O''Flynn', 10550, '');
INSERT INTO 'tune' VALUES (11917, '2011-11-29 23:00:00+00', '2012-01-20 12:55:01.098304+00', 'Riding on a Load of Hay', 9999, '');
INSERT INTO 'tune' VALUES (11918, '2011-11-29 23:00:00+00', '2012-01-20 12:55:01.102139+00', 'Straglass House', 9999, '');
INSERT INTO 'tune' VALUES (11919, '2011-11-29 23:00:00+00', '2012-01-20 12:55:01.105985+00', 'Done At Last!', 3612, '');
INSERT INTO 'tune' VALUES (11920, '2011-11-29 23:00:00+00', '2012-01-20 12:55:01.109818+00', 'Heroes of Ortona', 9998, '');
INSERT INTO 'tune' VALUES (11826, '2011-11-17 23:00:00+00', '2022-12-08 23:03:39.575252+00', 'Dusty Windowsills', 12217, '');
INSERT INTO 'tune' VALUES (11911, '2011-11-27 23:00:00+00', '2023-01-05 13:01:45.236949+00', 'Pipe Major George Ross''s Farewell to the Black Watch', 12248, '');
INSERT INTO 'tune' VALUES (11921, '2011-11-29 23:00:00+00', '2012-01-20 12:55:01.113678+00', 'Gleann Baile Chaoil', 9999, '');
INSERT INTO 'tune' VALUES (11922, '2011-11-29 23:00:00+00', '2012-01-20 12:55:01.117536+00', 'South Hall', 1700, '');
INSERT INTO 'tune' VALUES (11923, '2011-11-29 23:00:00+00', '2012-01-20 12:55:01.121396+00', 'Banff Bay', 1515, '');
INSERT INTO 'tune' VALUES (11924, '2011-11-29 23:00:00+00', '2012-01-20 12:55:01.125255+00', 'Andrew MacKay of Drumbeg', 10552, '');
INSERT INTO 'tune' VALUES (11925, '2011-11-29 23:00:00+00', '2012-01-20 12:55:01.1291+00', 'Ribhinn Og, A', 9999, '');
INSERT INTO 'tune' VALUES (11926, '2011-11-29 23:00:00+00', '2012-01-20 12:55:01.133269+00', 'Te Bhan', 9999, '');
INSERT INTO 'tune' VALUES (11927, '2011-11-29 23:00:00+00', '2012-01-20 12:55:01.137116+00', 'Balaich An lasgaich', 9999, '');
INSERT INTO 'tune' VALUES (11928, '2011-11-29 23:00:00+00', '2012-01-20 12:55:01.140963+00', 'Mo Cailin Donn', 9999, '');
INSERT INTO 'tune' VALUES (11929, '2011-12-01 23:00:00+00', '2012-01-20 12:55:01.145351+00', 'Steven''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (11931, '2011-12-01 23:00:00+00', '2012-01-20 12:55:01.170253+00', 'Miss Shona Scott', 10553, '');
INSERT INTO 'tune' VALUES (11933, '2011-12-01 23:00:00+00', '2012-01-20 12:55:01.178324+00', 'Memories of Willie Snaith Waltz', 1558, '');
INSERT INTO 'tune' VALUES (11934, '2011-12-02 23:00:00+00', '2012-01-20 12:55:01.182974+00', 'Scallaway Voe', 1623, '');
INSERT INTO 'tune' VALUES (11935, '2011-12-02 23:00:00+00', '2012-01-20 12:55:01.186939+00', 'Godfred Crovan''s Galley', 3150, '');
INSERT INTO 'tune' VALUES (11936, '2011-12-02 23:00:00+00', '2012-01-20 12:55:01.190796+00', 'Torosay Castle', 9999, '');
INSERT INTO 'tune' VALUES (13872, '2018-03-31 11:33:27.063759+00', '2018-03-31 11:33:27.063759+00', 'Far An robe mi ''n raoir', 9999, '');
INSERT INTO 'tune' VALUES (11938, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.198522+00', 'Tailor''s Wedding', 9999, '');
INSERT INTO 'tune' VALUES (11939, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.202416+00', 'Contented Wi'' Little', 9999, '');
INSERT INTO 'tune' VALUES (11940, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.206299+00', 'MacGregor of Rora', 9999, '');
INSERT INTO 'tune' VALUES (11941, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.210162+00', 'Jim and Flora Best of Cardross', 3163, '');
INSERT INTO 'tune' VALUES (11942, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.214053+00', 'Lambs on the Green Hills, The', 9999, '');
INSERT INTO 'tune' VALUES (11943, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.21795+00', 'Be Sud An Duinne Truagh Mi', 9999, '');
INSERT INTO 'tune' VALUES (11944, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.221828+00', 'Granny Duncan', 9999, '');
INSERT INTO 'tune' VALUES (11945, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.225822+00', 'Donnie and Eileen Campbell''s Jig', 3163, '');
INSERT INTO 'tune' VALUES (11946, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.230247+00', 'Molly of the Golden Locks', 9999, '');
INSERT INTO 'tune' VALUES (11947, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.234205+00', 'Far An Og Rinn Mi Mireadh', 10556, '');
INSERT INTO 'tune' VALUES (11948, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.238061+00', 'Tom an t-Searreach', 9999, '');
INSERT INTO 'tune' VALUES (11949, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.241902+00', 'Memories of Dr John Angus Smith', 3163, '');
INSERT INTO 'tune' VALUES (11950, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.245751+00', 'Bloody Fields Of Flanders', 1700, '');
INSERT INTO 'tune' VALUES (11951, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.249606+00', 'Hebridean Heroes In Flanders, The', 3163, '');
INSERT INTO 'tune' VALUES (11952, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.253451+00', 'Archie Beag', 10557, '');
INSERT INTO 'tune' VALUES (11953, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.257293+00', 'Jean McLean', 10558, '');
INSERT INTO 'tune' VALUES (11955, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.264966+00', 'Highland Air', 3163, '');
INSERT INTO 'tune' VALUES (11932, '2011-12-01 23:00:00+00', '2014-08-05 15:32:38.171725+00', 'Dantesque Polka', 10554, '');
INSERT INTO 'tune' VALUES (11956, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.268805+00', 'Angus Alexander Meldrum', 1507, '');
INSERT INTO 'tune' VALUES (11957, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.272638+00', 'Master Cameron Mathieson Brown', 1507, '');
INSERT INTO 'tune' VALUES (11958, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.27648+00', 'Rory''s Reel', 1507, '');
INSERT INTO 'tune' VALUES (11959, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.280332+00', 'Humours of Castle Lyons', 9999, '');
INSERT INTO 'tune' VALUES (11960, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.284176+00', 'Accordion Polka', 10559, '');
INSERT INTO 'tune' VALUES (11961, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.288019+00', 'Dr MacInnes Fancy', 9999, '');
INSERT INTO 'tune' VALUES (11962, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.291896+00', 'Farewell My Love', 10560, '');
INSERT INTO 'tune' VALUES (11964, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.299584+00', 'Pat and Derek of Tandem Band', 3163, '');
INSERT INTO 'tune' VALUES (11965, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.303409+00', 'Flora Anne McNab', 3163, '');
INSERT INTO 'tune' VALUES (11966, '2011-12-05 23:00:00+00', '2012-01-20 12:55:01.307267+00', 'John Morrison of Assynt House', 10561, '');
INSERT INTO 'tune' VALUES (11967, '2011-12-06 23:00:00+00', '2012-01-20 12:55:01.311114+00', 'Auld Quarry', 9999, '');
INSERT INTO 'tune' VALUES (11968, '2011-12-06 23:00:00+00', '2012-01-20 12:55:01.314969+00', 'Cameron Highlanders, The', 9999, '');
INSERT INTO 'tune' VALUES (11969, '2011-12-06 23:00:00+00', '2012-01-20 12:55:01.318802+00', 'Take Me Back to Dear Old Blighty', 9999, '');
INSERT INTO 'tune' VALUES (11970, '2011-12-06 23:00:00+00', '2012-01-20 12:55:01.322656+00', 'O My Jack MacKay', 9998, '');
INSERT INTO 'tune' VALUES (11971, '2011-12-06 23:00:00+00', '2012-01-20 12:55:01.326499+00', 'Shufflin'' Samuel', 1567, '');
INSERT INTO 'tune' VALUES (11972, '2011-12-07 23:00:00+00', '2012-01-20 12:55:01.332401+00', 'Donald, Where''s Your Trousers', 9998, '');
INSERT INTO 'tune' VALUES (11973, '2011-12-07 23:00:00+00', '2012-01-20 12:55:01.337261+00', 'Winster Gallop', 9999, '');
INSERT INTO 'tune' VALUES (11974, '2011-12-07 23:00:00+00', '2012-01-20 12:55:01.341115+00', 'Boanie Tammie Scollay', 9999, '');
INSERT INTO 'tune' VALUES (11930, '2011-12-01 23:00:00+00', '2012-02-06 10:46:27.569871+00', 'Jimmy Shand''s 50th Recording Year', 1811, '');
INSERT INTO 'tune' VALUES (11963, '2011-12-05 23:00:00+00', '2013-02-03 14:28:26.346321+00', 'Follow My Highland Soldier', 9999, '');
INSERT INTO 'tune' VALUES (11975, '2011-12-07 23:00:00+00', '2012-01-20 12:55:01.345229+00', 'Gatherin'' o'' the Gunns', 1512, '');
INSERT INTO 'tune' VALUES (11976, '2011-12-07 23:00:00+00', '2012-01-20 12:55:01.349089+00', 'Aubey Foley''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (11977, '2011-12-07 23:00:00+00', '2012-01-20 12:55:01.352955+00', 'Bentleys of Berkley, The', 10570, '');
INSERT INTO 'tune' VALUES (11978, '2011-12-07 23:00:00+00', '2012-01-20 12:55:01.356813+00', 'Gary in the Golden State', 3484, '');
INSERT INTO 'tune' VALUES (11979, '2011-12-07 23:00:00+00', '2012-01-20 12:55:01.360649+00', 'Aird Ranter', 10571, '');
INSERT INTO 'tune' VALUES (11980, '2011-12-07 23:00:00+00', '2012-01-20 12:55:01.364494+00', 'Archie''s Waltz', 10570, '');
INSERT INTO 'tune' VALUES (11981, '2011-12-07 23:00:00+00', '2012-01-20 12:55:01.368366+00', 'Marion MacLean of Eoligarry', 10572, '');
INSERT INTO 'tune' VALUES (11982, '2011-12-08 23:00:00+00', '2012-01-20 12:55:01.372205+00', 'Jennifer''s Reel', 2763, '');
INSERT INTO 'tune' VALUES (11984, '2011-12-12 23:00:00+00', '2012-01-20 12:55:01.379981+00', 'Rosie Tickling Trout', 2392, '');
INSERT INTO 'tune' VALUES (11985, '2011-12-12 23:00:00+00', '2012-01-20 12:55:01.383832+00', 'Short Apron', 9999, 'Information and ABC representation at the URL above');
INSERT INTO 'tune' VALUES (11986, '2011-12-13 23:00:00+00', '2012-01-20 12:55:01.390313+00', 'Auchindrain', 10577, '');
INSERT INTO 'tune' VALUES (11987, '2011-12-14 23:00:00+00', '2012-01-20 12:55:01.394167+00', 'Mountain Mist', 1814, 'Source: mentioned for the dance Lairds'' Diamond on http://blog.lib.umn.edu/ldfs/8x32/2008_11.html');
INSERT INTO 'tune' VALUES (11988, '2011-12-15 23:00:00+00', '2012-01-20 12:55:01.398034+00', 'Laird Jim''s 60th', 10584, 'mentioned in http://blog.lib.umn.edu/ldfs/8x32/2010_02.html');
INSERT INTO 'tune' VALUES (12586, '2013-08-02 19:30:21.420133+00', '2013-08-02 19:30:21.420133+00', 'Lord Ramsey', 9999, '');
INSERT INTO 'tune' VALUES (11990, '2011-12-16 23:00:00+00', '2012-01-20 12:55:01.408383+00', 'Devil in the Dishwasher, The', 10587, '"This unnamed tune was being played at a dance camp, just about the time the reports began to filter out of the kitchen that all was not well with the refrigerator and the dishwasher. This of course suggested a tune name, but ''Devil in the Kitchen'' was already taken, so.. ."');
INSERT INTO 'tune' VALUES (11991, '2011-12-16 23:00:00+00', '2012-01-20 12:55:01.412272+00', 'Marge in Motion', 3281, '');
INSERT INTO 'tune' VALUES (11992, '2011-12-16 23:00:00+00', '2012-01-20 12:55:01.416122+00', 'McCornack Hall', 10587, '''In honor of former band mates Kevin and Eileen McCormack, and their tiny living room nearly filled with an upright piano, where we rehearsed numerous Scottish ball programs.');
INSERT INTO 'tune' VALUES (11993, '2011-12-16 23:00:00+00', '2012-01-20 12:55:01.419991+00', 'Pedalling to Plummer', 10587, '');
INSERT INTO 'tune' VALUES (11994, '2011-12-17 23:00:00+00', '2012-01-20 12:55:01.423835+00', 'Morlan Fancy', 3617, '');
INSERT INTO 'tune' VALUES (11995, '2011-12-22 23:00:00+00', '2012-01-20 12:55:01.427683+00', 'Angela Michel''s Farewell to Frankfurt', 228, '');
INSERT INTO 'tune' VALUES (11996, '2012-01-06 23:00:00+00', '2012-01-20 12:55:01.431522+00', 'Hairst Meen, The', 1725, '');
INSERT INTO 'tune' VALUES (11997, '2012-01-06 23:00:00+00', '2012-01-20 12:55:01.435373+00', 'Donald Ridley''s Compliments to Ian Peterson', 1593, '');
INSERT INTO 'tune' VALUES (11998, '2012-01-06 23:00:00+00', '2012-01-20 12:55:01.43933+00', 'Ian Wilson''s Reel', 1593, '');
INSERT INTO 'tune' VALUES (11999, '2012-01-06 23:00:00+00', '2012-01-20 12:55:01.44318+00', 'Isobel MacDonald', 1543, '');
INSERT INTO 'tune' VALUES (12524, '2013-04-07 19:25:29.570333+00', '2013-04-07 19:25:29.570339+00', 'Dorothy Capstick''s Reel', 1596, '');
INSERT INTO 'tune' VALUES (12525, '2013-04-07 19:51:10.817167+00', '2013-04-07 19:51:10.817172+00', 'Anne Thorn''s Strathspey', 1596, 'Source: e-mail from Anne Thorn');
INSERT INTO 'tune' VALUES (12526, '2013-04-07 19:59:59.728269+00', '2013-04-07 19:59:59.728274+00', 'Helensburgh Hornpipe', 1596, '');
INSERT INTO 'tune' VALUES (12527, '2013-04-07 20:00:37.9808+00', '2013-04-07 20:00:37.980806+00', 'Commodore Hornpipe', 1596, '');
INSERT INTO 'tune' VALUES (12528, '2013-04-07 20:13:21.516298+00', '2013-04-07 20:13:21.516303+00', 'Dancing Thorns, The', 1596, '');
INSERT INTO 'tune' VALUES (2252, NULL, '2013-04-07 20:24:13.084458+00', 'Heather Dewar''s Strathspey', 1596, '');
INSERT INTO 'tune' VALUES (8732, NULL, '2013-04-10 09:03:22.142686+00', 'Colvins of Heatherdene, The', 2362, '');
INSERT INTO 'tune' VALUES (9657, '2005-11-18 23:00:00+00', '2013-04-10 09:03:35.788392+00', 'Peter Hastings'' Chocolate Mousse', 1576, '');
INSERT INTO 'tune' VALUES (12520, '2013-03-14 10:06:55.666798+00', '2023-02-28 14:30:03.920274+00', 'Pond Farm', 1590, '');
INSERT INTO 'tune' VALUES (12518, '2013-03-14 09:58:57.309467+00', '2023-02-28 14:30:23.727109+00', 'Lamp Black Lizzie', 1590, '');
INSERT INTO 'tune' VALUES (12530, '2013-04-29 13:47:58.63381+00', '2013-04-29 13:47:58.633815+00', 'Happy Smile', 10780, '');
INSERT INTO 'tune' VALUES (12531, '2013-04-29 13:52:31.944952+00', '2013-04-29 13:52:31.944958+00', 'Ma Tsu Ri (Festival)', 2786, '');
INSERT INTO 'tune' VALUES (12532, '2013-04-29 13:54:56.36935+00', '2013-04-29 13:54:56.369355+00', 'On the Toe', 2786, '');
INSERT INTO 'tune' VALUES (12533, '2013-04-29 13:58:44.811458+00', '2013-04-29 18:28:13.350367+00', 'Morning Jyu', 1527, '');
INSERT INTO 'tune' VALUES (859, NULL, '2013-05-17 15:11:49.414913+00', 'Kilt, The', 1437, '');
INSERT INTO 'tune' VALUES (2458, NULL, '2013-05-28 09:43:52.575918+00', 'John Murray of Lochee', 1540, '');
INSERT INTO 'tune' VALUES (12534, '2013-05-30 16:10:12.006633+00', '2013-05-30 16:10:12.006639+00', '"Any Good Medley" (author''s statement)', 10653, 'This can be entered in the "Tune" field when the author of a Medley explicitly leaves the choice of a tune to the reader.');
INSERT INTO 'tune' VALUES (5563, NULL, '2013-06-13 16:24:20.104579+00', 'William Ritchie Esq.', 1521, '');
INSERT INTO 'tune' VALUES (12535, '2013-06-20 14:27:42.988922+00', '2013-06-20 14:29:02.801949+00', 'Take Wing', 10652, '');
INSERT INTO 'tune' VALUES (9010, NULL, '2013-06-14 12:14:24.40332+00', 'Mrs Oswald''s Favourite Reel', 1519, '');
INSERT INTO 'tune' VALUES (12538, '2013-06-21 07:02:32.660549+00', '2013-06-21 07:02:32.660556+00', 'Gregor''s Reel', 1846, '');
INSERT INTO 'tune' VALUES (12539, '2013-06-21 07:05:19.55179+00', '2013-06-21 07:05:19.551797+00', 'Witch Wood', 1846, '');
INSERT INTO 'tune' VALUES (12540, '2013-06-21 07:06:08.253546+00', '2013-06-21 07:06:08.253553+00', 'Margo''s Way', 1846, '');
INSERT INTO 'tune' VALUES (12541, '2013-06-21 07:06:55.102383+00', '2013-06-21 07:06:55.10239+00', 'Patrick Chamoin''s Strathspey', 1846, '');
INSERT INTO 'tune' VALUES (12536, '2013-06-21 06:59:52.532896+00', '2013-06-21 07:11:09.489733+00', 'Spring Fling, The', 1846, '');
INSERT INTO 'tune' VALUES (12537, '2013-06-21 07:01:21.908491+00', '2013-06-21 07:11:51.86845+00', 'Hermitage Wedding, The', 1846, '');
INSERT INTO 'tune' VALUES (12543, '2013-06-21 07:15:18.708845+00', '2013-06-21 07:15:18.708853+00', 'Charlie Stanton', 1846, '');
INSERT INTO 'tune' VALUES (12544, '2013-06-21 07:15:46.768855+00', '2013-06-21 07:15:46.768862+00', 'Ellis Stanton', 1846, '');
INSERT INTO 'tune' VALUES (12545, '2013-06-21 07:16:47.948827+00', '2013-06-21 07:16:47.948834+00', 'Tavish Gray', 1846, '');
INSERT INTO 'tune' VALUES (12546, '2013-06-21 07:19:24.092771+00', '2013-06-21 07:19:24.092779+00', 'Luscombes of Colorado, The', 1846, '');
INSERT INTO 'tune' VALUES (12547, '2013-06-21 07:19:55.452373+00', '2013-06-21 07:19:55.452379+00', 'Miss Jamie Berg', 1846, '');
INSERT INTO 'tune' VALUES (12548, '2013-06-21 07:20:33.358046+00', '2013-06-21 07:20:33.358052+00', 'Luise and Kjell', 1846, '');
INSERT INTO 'tune' VALUES (12550, '2013-06-21 07:27:43.665875+00', '2013-06-21 07:27:43.665881+00', 'Dance for Joy!', 1846, '');
INSERT INTO 'tune' VALUES (12522, '2013-03-16 13:34:00.815688+00', '2013-08-19 12:00:20.102337+00', 'Girls from Oakbank, The', 3683, '');
INSERT INTO 'tune' VALUES (12523, '2013-03-16 13:37:05.363695+00', '2013-08-19 12:00:23.489169+00', 'Swan and the Tay, The', 1626, '');
INSERT INTO 'tune' VALUES (12551, '2013-06-21 07:28:34.179217+00', '2013-06-21 07:28:34.179223+00', 'Phill''s Big Squeeze', 1846, '');
INSERT INTO 'tune' VALUES (12552, '2013-06-21 07:29:22.835689+00', '2013-06-21 07:29:22.835697+00', 'Andrew J. Lyon', 1846, '');
INSERT INTO 'tune' VALUES (12553, '2013-06-21 07:31:00.98616+00', '2013-06-21 07:31:00.986168+00', 'Green Ginger Jig', 1846, '');
INSERT INTO 'tune' VALUES (12554, '2013-06-21 07:31:42.819365+00', '2013-06-21 07:31:42.819371+00', 'Pete Clark of Birnam', 1846, '');
INSERT INTO 'tune' VALUES (12555, '2013-06-21 07:32:23.419959+00', '2013-06-21 07:32:23.419965+00', 'Keith B. Smith', 1846, '');
INSERT INTO 'tune' VALUES (12556, '2013-06-21 07:33:05.275002+00', '2013-06-21 07:33:05.275009+00', 'Calum''s Jig', 1846, '');
INSERT INTO 'tune' VALUES (12557, '2013-06-21 07:36:12.619744+00', '2013-06-21 07:36:12.619751+00', 'Susie Petrov', 1846, '');
INSERT INTO 'tune' VALUES (12558, '2013-06-21 07:37:08.942764+00', '2013-06-21 07:37:08.942771+00', 'Alice Murphy', 1846, '');
INSERT INTO 'tune' VALUES (12559, '2013-06-21 07:37:49.817728+00', '2013-06-21 07:37:49.817735+00', 'Sendai Dancers, The', 1846, '');
INSERT INTO 'tune' VALUES (12560, '2013-06-21 07:38:54.996685+00', '2013-06-21 07:38:54.996692+00', 'Northern Lights and Melting Snow', 1846, '');
INSERT INTO 'tune' VALUES (12561, '2013-06-21 07:39:37.326058+00', '2013-06-21 07:39:37.326065+00', 'Mary Kate Adami-Sampson', 1846, '');
INSERT INTO 'tune' VALUES (12562, '2013-06-21 07:40:41.940691+00', '2013-06-21 07:40:41.940698+00', 'Mathematicians'' Canon, The', 1846, '');
INSERT INTO 'tune' VALUES (12563, '2013-06-21 07:41:21.502274+00', '2013-06-21 07:41:21.502281+00', 'Jelly Roll, The', 1846, '');
INSERT INTO 'tune' VALUES (12566, '2013-07-03 18:41:00.419424+00', '2013-07-03 18:41:00.41943+00', 'Jig for Heather', 1871, '');
INSERT INTO 'tune' VALUES (13873, '2018-04-02 15:34:12.864715+00', '2018-04-07 23:21:58.204419+00', 'Wheel of Fortune', 3179, '');
INSERT INTO 'tune' VALUES (12569, '2013-07-03 19:17:47.456467+00', '2013-07-03 19:17:47.456473+00', 'Woodside', 1770, '');
INSERT INTO 'tune' VALUES (12570, '2013-07-03 22:13:20.335412+00', '2013-07-03 22:13:20.335419+00', 'RSCDS at 90', 1508, '');
INSERT INTO 'tune' VALUES (12571, '2013-07-03 22:23:50.146406+00', '2013-07-03 22:23:50.146412+00', 'Howard''s', 9999, 'In Joseph Lowe''s Collection.');
INSERT INTO 'tune' VALUES (12572, '2013-07-03 22:28:24.95197+00', '2013-07-03 22:28:24.951976+00', 'McLarin''s', 9999, '');
INSERT INTO 'tune' VALUES (503, NULL, '2013-07-21 14:06:13.342313+00', 'Far Frae Hame', 9999, '');
INSERT INTO 'tune' VALUES (12573, '2013-07-23 18:10:56.677242+00', '2013-07-23 18:10:56.677248+00', 'John Bowie Dickson', 1402, '');
INSERT INTO 'tune' VALUES (12574, '2013-07-23 18:13:35.276585+00', '2013-07-23 18:13:35.27659+00', 'Three Millstones, The', 3396, 'Roger Malton in collaboration with John Bowie Dickson');
INSERT INTO 'tune' VALUES (12575, '2013-07-23 18:14:54.779135+00', '2013-07-23 18:14:54.779141+00', 'Johnny Dickson''s Hornpipe', 1402, '');
INSERT INTO 'tune' VALUES (12576, '2013-07-23 18:17:07.256098+00', '2013-07-23 18:17:07.256104+00', 'Dicksons'' Strathspey, The', 1402, '');
INSERT INTO 'tune' VALUES (9097, NULL, '2013-07-24 09:09:00.314977+00', 'James Dunbar Esq. M.D.', 1554, '');
INSERT INTO 'tune' VALUES (3433, NULL, '2013-07-31 14:57:24.153425+00', 'Bonnie Lass o'' Fyvie, The', 9999, '');
INSERT INTO 'tune' VALUES (12542, '2013-06-21 07:14:31.755446+00', '2019-06-04 15:34:24.553588+00', 'Gábor and Szilvi of Budapest', 1846, '');
INSERT INTO 'tune' VALUES (3502, NULL, '2013-07-31 17:18:47.988227+00', 'Burning Sands of Egypt', 1700, 'http://www.tunearch.org/wiki/Burning_Sands_of_Egypt_%28The%29');
INSERT INTO 'tune' VALUES (12577, '2013-07-31 20:21:58.999633+00', '2013-07-31 20:21:58.999633+00', 'Forty Below', 10813, '');
INSERT INTO 'tune' VALUES (2240, NULL, '2013-08-01 10:06:10.647889+00', 'Greenwoodside', 9999, 'Both spellings are used');
INSERT INTO 'tune' VALUES (12581, '2013-08-02 19:10:14.529364+00', '2013-08-02 19:10:14.529364+00', 'Doug Cargill''s Reel', 1501, '');
INSERT INTO 'tune' VALUES (12582, '2013-08-02 19:13:50.209248+00', '2013-08-02 19:13:50.209248+00', 'Sicklinghall', 1501, '');
INSERT INTO 'tune' VALUES (12583, '2013-08-02 19:20:01.734149+00', '2013-08-02 19:20:01.734149+00', 'Thoopmuir Court', 1501, '');
INSERT INTO 'tune' VALUES (12584, '2013-08-02 19:21:58.101161+00', '2013-08-02 19:21:58.101161+00', 'Nesfield View', 1501, '');
INSERT INTO 'tune' VALUES (12568, '2013-07-03 19:12:08.160047+00', '2016-11-27 12:06:51.119783+00', 'Cornmill Court', 1575, '');
INSERT INTO 'tune' VALUES (13902, '2018-06-09 22:06:33.861588+00', '2018-06-09 22:06:33.861588+00', 'Brooks Maggot', 9999, '');
INSERT INTO 'tune' VALUES (11989, '2011-12-16 23:00:00+00', '2018-10-30 17:19:41.332063+00', 'Of Meetings and Partings', 3179, '');
INSERT INTO 'tune' VALUES (12585, '2013-08-02 19:24:01.290581+00', '2013-08-02 19:24:01.290581+00', 'Nifty Ninety', 1501, '');
INSERT INTO 'tune' VALUES (12587, '2013-08-02 19:34:53.831638+00', '2013-08-02 19:34:53.831638+00', 'Traveller''s Joy', 1501, '');
INSERT INTO 'tune' VALUES (7058, NULL, '2013-08-05 09:55:15.379992+00', 'Alick C MacGregor', 1699, '');
INSERT INTO 'tune' VALUES (6275, NULL, '2013-08-05 10:57:49.339857+00', 'James Young', 1548, '');
INSERT INTO 'tune' VALUES (6149, NULL, '2013-08-05 11:14:01.269204+00', 'Benmore', 1700, '');
INSERT INTO 'tune' VALUES (6860, NULL, '2013-08-05 11:16:46.558068+00', 'Taking of Beaumont Hamel', 1700, '');
INSERT INTO 'tune' VALUES (12588, '2013-08-06 13:54:47.207942+00', '2013-08-06 13:54:47.207942+00', 'Louise and Kjell', 1846, '');
INSERT INTO 'tune' VALUES (12590, '2013-08-06 14:18:39.837515+00', '2013-08-06 14:18:39.837515+00', 'Random Jig, The', 1625, '');
INSERT INTO 'tune' VALUES (12591, '2013-08-06 14:29:30.250503+00', '2013-08-06 14:29:30.250503+00', 'Lys i Mørketida', 1846, '');
INSERT INTO 'tune' VALUES (4702, NULL, '2013-08-06 17:42:06.55194+00', 'Mr Douglas of Springwood Park', 10784, 'See issue 244 where Anselm points out that this tune was devised by Alexander Givan, and that "Cropie''s Strathspey" is an alias for this tune.');
INSERT INTO 'tune' VALUES (576, NULL, '2013-08-10 23:54:23.903188+00', 'Gillan''s Reel', 1818, '');
INSERT INTO 'tune' VALUES (37, NULL, '2013-08-13 09:47:40.921407+00', 'Prince Charlie''s Welcome to the Isle of Skye', 9999, '');
INSERT INTO 'tune' VALUES (12097, '2012-06-07 06:41:39.81558+00', '2013-08-19 11:59:19.16639+00', 'Measure of Merlot, A', 2523, 'Mentioned by Brian Pierson as the suggested  tune for "Lena''s Kitchen", but no source given.');
INSERT INTO 'tune' VALUES (12261, '2012-12-28 14:29:22.552488+00', '2013-08-19 11:59:19.189326+00', 'Trip to York, A', 1711, '');
INSERT INTO 'tune' VALUES (12073, '2012-05-04 19:12:54.254673+00', '2013-08-19 12:00:19.758312+00', 'Anglins of Ottawa, The', 1502, '');
INSERT INTO 'tune' VALUES (12056, '2012-05-04 19:01:20.405956+00', '2013-08-19 12:00:19.783295+00', 'Auld Alliance, The', 1502, '');
INSERT INTO 'tune' VALUES (12580, '2013-08-02 16:11:48.645838+00', '2013-08-19 12:00:19.824118+00', 'Boatie Rows, The', 10817, '');
INSERT INTO 'tune' VALUES (12529, '2013-04-29 13:43:22.92129+00', '2013-08-19 12:00:19.86162+00', 'Braiding Reel, The', 2786, '');
INSERT INTO 'tune' VALUES (12064, '2012-05-04 19:07:53.881386+00', '2013-08-19 12:00:19.900318+00', 'Buckie Loon, The', 1502, '');
INSERT INTO 'tune' VALUES (12075, '2012-05-04 19:14:03.610599+00', '2013-08-19 12:00:19.939544+00', 'Clockwork Comic, The', 1502, '');
INSERT INTO 'tune' VALUES (12216, '2012-10-18 14:28:33.263787+00', '2013-08-19 12:00:20.001538+00', 'Coachman''s Whip, The', 9999, '');
INSERT INTO 'tune' VALUES (11552, '2011-07-09 22:00:00+00', '2013-08-19 12:00:20.162159+00', 'Golden Celebration Jig, The', 10128, 'Named in the dance of this name in the 6th Carnforth Collection by Derek Haynes.  No information on where this tune was published or recorded.');
INSERT INTO 'tune' VALUES (12205, '2012-10-02 09:45:41.161475+00', '2013-08-19 12:00:20.242026+00', 'Grapevine, The', 10661, '');
INSERT INTO 'tune' VALUES (12066, '2012-05-04 19:08:55.753982+00', '2013-08-19 12:00:20.351509+00', 'Hyperbaric Hornpipe, The', 1502, '');
INSERT INTO 'tune' VALUES (12067, '2012-05-04 19:09:27.072228+00', '2013-08-19 12:00:20.556847+00', 'Maxwells of Rutherglen, The', 1502, '');
INSERT INTO 'tune' VALUES (12521, '2013-03-14 10:12:23.394795+00', '2023-02-28 14:29:39.761667+00', 'Saltburn Lass, The', 1590, '');
INSERT INTO 'tune' VALUES (12517, '2013-03-14 09:40:38.358695+00', '2023-02-28 14:30:43.783458+00', 'Horse-Drawn Barge, The', 1590, '');
INSERT INTO 'tune' VALUES (11446, '2010-10-27 22:00:00+00', '2013-08-19 12:00:21.726059+00', 'Runaway Train, The', 9999, '');
INSERT INTO 'tune' VALUES (12593, '2013-08-29 10:29:08.562487+00', '2013-08-29 10:29:08.562487+00', 'Jean Armour Burns Brown', 3189, '"The music was found in the Frank Gilruth Collection dated 1911"');
INSERT INTO 'tune' VALUES (12048, '2012-05-04 18:54:43.82153+00', '2013-08-19 12:00:22.015469+00', 'Sandbox Sailors, The', 1502, '');
INSERT INTO 'tune' VALUES (12061, '2012-05-04 19:05:37.605114+00', '2013-08-19 12:00:22.576122+00', 'Submariner''s Jig, The', 1502, '');
INSERT INTO 'tune' VALUES (12592, '2013-08-20 12:01:56.348958+00', '2013-08-20 12:01:56.348958+00', 'Jean Noble of Lossiemouth', 2085, 'Composed: July 2007



This tune was written especially for Jean Noble''s winning 50th Anniversary Signature Dance: Mrs Hamilton of Eaglemount. The dance is dedicated to beloved SCD teacher, Jean Hamilton, hence the name. The deviser and namesake of the tune is also a beloved SCD teacher. (Bobby Brown)');
INSERT INTO 'tune' VALUES (12594, '2013-08-29 10:31:39.690301+00', '2013-08-29 10:31:39.690301+00', 'Wimpling Nith, The', 3189, '"The music was found in the Frank Gilruth Collection dated 1911"');
INSERT INTO 'tune' VALUES (12595, '2013-08-29 10:36:32.856263+00', '2013-08-29 12:44:20.901444+00', 'Tam O'' Shanter', 1668, 'Jig 32 bars. 29/10/1964. Copyright Ian Holmes / Marian Music');
INSERT INTO 'tune' VALUES (12596, '2013-09-11 19:13:28.145973+00', '2013-09-11 19:13:28.145973+00', 'Pipe Major Jimmy McGregor', 1684, '');
INSERT INTO 'tune' VALUES (12597, '2013-09-11 19:14:34.147351+00', '2013-09-11 19:14:34.147351+00', 'Butler of Glen Avenue, The', 3159, '');
INSERT INTO 'tune' VALUES (12598, '2013-09-11 19:19:38.525474+00', '2013-09-11 19:19:38.525474+00', 'Campbell Hunter', 1808, '');
INSERT INTO 'tune' VALUES (12599, '2013-09-11 19:20:30.217099+00', '2013-09-11 19:20:30.217099+00', 'John Carswell', 1808, '');
INSERT INTO 'tune' VALUES (12600, '2013-09-11 19:21:17.562358+00', '2013-09-11 19:21:17.562358+00', 'Duncan MacKenzie', 1808, '');
INSERT INTO 'tune' VALUES (12601, '2013-09-11 19:30:36.342752+00', '2013-09-11 19:30:36.342752+00', 'Attic Studio, The', 10849, '');
INSERT INTO 'tune' VALUES (12602, '2013-09-11 19:33:48.926084+00', '2013-09-11 19:33:48.926084+00', 'Leona''s Reel', 10184, '');
INSERT INTO 'tune' VALUES (939, NULL, '2018-04-03 10:00:31.249931+00', 'Lamb Skinnet', 9999, 'For some details about the source and meaning of the name, see the dance of the same name.');
INSERT INTO 'tune' VALUES (12604, '2013-09-11 19:50:14.108122+00', '2013-09-11 19:50:14.108122+00', 'Keil View House', 1808, '');
INSERT INTO 'tune' VALUES (12605, '2013-09-11 19:51:08.454974+00', '2013-09-11 19:51:08.454974+00', 'Maid of Glencoul, The', 1808, '');
INSERT INTO 'tune' VALUES (12606, '2013-09-11 19:54:02.3191+00', '2013-09-11 19:54:02.3191+00', 'Glory Days (The Wasps)', 1808, '');
INSERT INTO 'tune' VALUES (12578, '2013-08-02 15:49:40.81958+00', '2014-04-21 19:51:00.027498+00', 'Across the Line', 10813, '');
INSERT INTO 'tune' VALUES (239, NULL, '2014-08-19 07:39:44.834684+00', 'Campbeltown Kiltie Ball', 1700, '');
INSERT INTO 'tune' VALUES (12607, '2013-09-11 19:59:49.326207+00', '2013-09-11 19:59:49.326207+00', 'Alastair and Annie''s Cottage', 10850, '');
INSERT INTO 'tune' VALUES (12608, '2013-09-11 20:02:44.165959+00', '2013-09-11 20:02:44.165959+00', 'Missing Sign Post, The', 10520, '');
INSERT INTO 'tune' VALUES (12609, '2013-09-11 20:46:49.616289+00', '2013-09-11 20:46:49.616289+00', 'A. McKinney', 9999, '');
INSERT INTO 'tune' VALUES (12611, '2013-09-11 20:48:38.285017+00', '2013-09-11 20:48:38.285017+00', 'Tea and Toast', 1808, '');
INSERT INTO 'tune' VALUES (12612, '2013-09-11 21:17:26.263338+00', '2013-09-11 21:17:26.263338+00', 'Leaving Rum', 10851, '');
INSERT INTO 'tune' VALUES (12613, '2013-09-11 21:41:24.738101+00', '2013-09-11 21:41:24.738101+00', 'Father Michael''s', 1912, '');
INSERT INTO 'tune' VALUES (12614, '2013-09-11 21:42:17.115947+00', '2013-09-11 21:42:17.115947+00', 'Kansas City', 10571, '');
INSERT INTO 'tune' VALUES (12615, '2013-09-11 21:46:19.435282+00', '2013-09-11 21:46:19.435282+00', 'Glories of ''The Star'', The', 1512, '');
INSERT INTO 'tune' VALUES (12616, '2013-09-11 21:54:26.108043+00', '2013-09-11 21:54:26.108043+00', 'Salvation Reel, The', 10852, '');
INSERT INTO 'tune' VALUES (12617, '2013-09-11 21:55:26.979021+00', '2013-09-11 21:55:26.979021+00', 'Harsh February, The', 1761, '');
INSERT INTO 'tune' VALUES (2577, NULL, '2013-09-11 22:00:22.789081+00', 'Miss Campbell of Saddell''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (2308, NULL, '2013-09-12 22:41:56.81189+00', 'Inveresk House', 9999, 'Nathaniel Gow according to Tweeddale Collection 4');
INSERT INTO 'tune' VALUES (12618, '2013-09-12 23:01:57.584139+00', '2013-09-12 23:01:57.584139+00', 'James Gray''s Compliments to Ms. Petrov', 1846, '');
INSERT INTO 'tune' VALUES (12663, '2013-10-29 02:52:07.275104+00', '2013-10-29 02:52:07.275104+00', 'Forrest Hill Road', 3220, '');
INSERT INTO 'tune' VALUES (12619, '2013-09-18 08:17:05.45006+00', '2013-09-18 08:17:05.45006+00', 'Torf''s Tune', 1502, '');
INSERT INTO 'tune' VALUES (12620, '2013-09-20 15:22:51.533172+00', '2013-09-20 15:22:51.533172+00', 'San Antonio Rose', 9998, '');
INSERT INTO 'tune' VALUES (12621, '2013-09-20 15:39:09.877031+00', '2013-09-20 15:39:09.877031+00', 'Innisfree', 9998, '');
INSERT INTO 'tune' VALUES (12564, '2013-06-21 07:41:59.482412+00', '2013-09-25 21:33:26.254235+00', 'Salut les Bolduc', 1846, 'Alias spelling is found in the Tweeddale Collection 4, but is a typo according to James Gray.');
INSERT INTO 'tune' VALUES (1129, NULL, '2018-04-03 20:36:56.212733+00', 'MacLauchlane''s Scotch Measure', 9999, '');
INSERT INTO 'tune' VALUES (12622, '2013-09-28 22:04:23.198935+00', '2013-09-28 22:04:23.198935+00', 'Holly''s Big Day', 10012, 'Name tune for "Polly''s Big Day"');
INSERT INTO 'tune' VALUES (12624, '2013-09-28 23:46:34.208589+00', '2013-09-28 23:46:34.208589+00', 'Kiss The Lass Ye Like Best', 9999, '');
INSERT INTO 'tune' VALUES (12625, '2013-09-28 23:48:59.276211+00', '2013-09-28 23:48:59.276211+00', 'Ferguson''s Fancy', 1511, '');
INSERT INTO 'tune' VALUES (12626, '2013-09-28 23:51:05.523868+00', '2013-09-28 23:51:05.523868+00', 'Tracey Mackenzie''s Jig', 1836, '');
INSERT INTO 'tune' VALUES (12627, '2013-09-28 23:54:41.273566+00', '2013-09-28 23:54:41.273566+00', 'Bogannach, The', 1517, 'from the Gow Collection');
INSERT INTO 'tune' VALUES (12628, '2013-09-28 23:59:02.275328+00', '2013-09-28 23:59:02.275328+00', 'Butcher''s Apron, The', 2145, '');
INSERT INTO 'tune' VALUES (12629, '2013-09-29 00:00:30.598901+00', '2013-09-29 00:00:30.598901+00', 'Fiona Miller', 2724, '');
INSERT INTO 'tune' VALUES (12630, '2013-09-29 00:13:48.339565+00', '2013-09-29 00:13:48.339565+00', 'Swarthmore Swing', 2692, '');
INSERT INTO 'tune' VALUES (12631, '2013-09-29 00:15:57.054474+00', '2013-09-29 00:15:57.054474+00', 'Dunnideer Jig', 2692, '');
INSERT INTO 'tune' VALUES (12632, '2013-09-29 00:17:43.380562+00', '2013-09-29 00:17:43.380562+00', 'Milton Strathspey, The', 2692, '');
INSERT INTO 'tune' VALUES (12633, '2013-09-29 00:20:25.170695+00', '2013-09-29 00:20:25.170695+00', 'Strathspey In C Major, Op. 7', 2692, '');
INSERT INTO 'tune' VALUES (12634, '2013-09-29 00:21:57.303925+00', '2013-09-29 00:21:57.303925+00', 'Memorial Strathspey, The', 2692, '');
INSERT INTO 'tune' VALUES (12635, '2013-09-29 00:23:59.865488+00', '2013-09-29 00:23:59.865488+00', 'Old Salt Strathspey, The', 2692, '');
INSERT INTO 'tune' VALUES (12636, '2013-09-29 00:25:27.065071+00', '2013-09-29 00:25:27.065071+00', 'New Scotland Dancers'' Strathspey, The', 2692, '');
INSERT INTO 'tune' VALUES (12610, '2013-09-11 20:47:58.363799+00', '2017-02-13 12:06:40.807382+00', 'Melanie Murphy', 2160, '');
INSERT INTO 'tune' VALUES (12665, '2013-10-31 15:08:36.617772+00', '2018-04-08 08:54:09.035699+00', 'Winter', 3179, '');
INSERT INTO 'tune' VALUES (12637, '2013-09-29 00:26:53.055709+00', '2013-09-29 00:26:53.055709+00', 'Scotia Dance', 2692, '');
INSERT INTO 'tune' VALUES (12638, '2013-09-29 00:28:27.128906+00', '2013-09-29 00:28:27.128906+00', 'Reel for May-Day, A', 2692, '');
INSERT INTO 'tune' VALUES (875, NULL, '2013-09-29 21:23:21.80106+00', 'Nairobi Reel, The', 781, 'Thanks to Iain Gent, for the name of the composer and the correct tune title.');
INSERT INTO 'tune' VALUES (3646, NULL, '2013-09-29 22:06:17.922069+00', 'Dark Island, The', 10865, 'Thanks to Iain Gent for the following information:



Original title was "Dr Mackay''s Fareweel to Creagory".

The Tune was then used for BBC production called "the Dark Island".

');
INSERT INTO 'tune' VALUES (12641, '2013-10-14 22:16:21.661888+00', '2013-10-14 22:16:21.661888+00', 'Shirley''s Jig', 1626, '');
INSERT INTO 'tune' VALUES (12642, '2013-10-29 01:29:19.712595+00', '2013-10-29 01:29:19.712595+00', 'Falling Maple Leaf, The', 3220, '');
INSERT INTO 'tune' VALUES (12644, '2013-10-29 01:38:51.941189+00', '2013-10-29 01:38:51.941189+00', 'Bab''s Jig', 3220, '');
INSERT INTO 'tune' VALUES (12645, '2013-10-29 01:46:42.953704+00', '2013-10-29 01:46:42.953704+00', 'Paddy On The Railroad', 9999, '');
INSERT INTO 'tune' VALUES (12646, '2013-10-29 01:50:12.005021+00', '2013-10-29 01:50:12.005021+00', 'Windlestrae Ceilidh, The', 2523, '');
INSERT INTO 'tune' VALUES (12688, '2013-10-31 15:38:17.456434+00', '2018-04-07 07:03:02.431274+00', 'Airs in July', 3179, '');
INSERT INTO 'tune' VALUES (12648, '2013-10-29 01:56:51.11189+00', '2013-10-29 01:56:51.11189+00', 'Ian McLeod', 2661, '');
INSERT INTO 'tune' VALUES (12649, '2013-10-29 02:00:22.361912+00', '2013-10-29 02:00:22.361912+00', 'Mrs Alison Millar', 10652, '');
INSERT INTO 'tune' VALUES (12650, '2013-10-29 02:01:13.864868+00', '2013-10-29 02:01:13.864868+00', 'Canal En Octobre, Le', 9999, 'French Traditional');
INSERT INTO 'tune' VALUES (12651, '2013-10-29 02:02:25.359808+00', '2013-10-29 02:02:25.359808+00', 'Holacombe Brake', 10891, '');
INSERT INTO 'tune' VALUES (12652, '2013-10-29 02:06:25.381515+00', '2013-10-29 02:06:25.381515+00', 'Lammas Fair', 10652, '');
INSERT INTO 'tune' VALUES (12654, '2013-10-29 02:09:25.06393+00', '2013-10-29 02:09:25.06393+00', 'Findlay Hits The Bottle', 10892, '');
INSERT INTO 'tune' VALUES (12655, '2013-10-29 02:23:37.205316+00', '2013-10-29 02:23:37.205316+00', 'Flail, The', 9999, '');
INSERT INTO 'tune' VALUES (12656, '2013-10-29 02:24:25.528266+00', '2013-10-29 02:24:25.528266+00', 'Crabs In The Skillet', 9999, '');
INSERT INTO 'tune' VALUES (12657, '2013-10-29 02:38:53.558785+00', '2013-10-29 02:38:53.558785+00', 'Moment Musical No 3', 10893, '');
INSERT INTO 'tune' VALUES (12659, '2013-10-29 02:44:35.188193+00', '2013-10-29 02:44:35.188193+00', 'Hava Nagila', 9999, 'Jewish Traditional');
INSERT INTO 'tune' VALUES (12660, '2013-10-29 02:45:16.396651+00', '2013-10-29 02:45:16.396651+00', 'Rondo Alla Turca', 2399, '');
INSERT INTO 'tune' VALUES (12661, '2013-10-29 02:49:33.259147+00', '2013-10-29 02:49:33.259147+00', 'Barry & Doreen''s Continental Capers', 3220, '');
INSERT INTO 'tune' VALUES (12662, '2013-10-29 02:51:18.352502+00', '2013-10-29 02:51:18.352502+00', 'Toast To The Mousies', 3436, '');
INSERT INTO 'tune' VALUES (12667, '2013-10-31 15:11:27.8955+00', '2013-10-31 15:11:27.8955+00', 'Link Him Doddie', 9999, '');
INSERT INTO 'tune' VALUES (12669, '2013-10-31 15:13:55.529301+00', '2018-04-07 23:06:56.879014+00', 'Betty''s Bay Reel', 3179, '');
INSERT INTO 'tune' VALUES (12692, '2013-10-31 16:25:50.437091+00', '2013-10-31 16:25:50.437091+00', 'Miss Ross''s Strathspey', 1518, '');
INSERT INTO 'tune' VALUES (11954, '2011-12-05 23:00:00+00', '2013-11-03 07:28:23.929756+00', 'Renfrewshire Militia', 2406, '');
INSERT INTO 'tune' VALUES (12693, '2013-11-12 19:24:13.986834+00', '2013-11-12 19:24:13.986834+00', 'Stroppy Struan', 1938, '');
INSERT INTO 'tune' VALUES (8322, NULL, '2013-11-26 17:07:22.660724+00', 'Caton Capers', 1555, '');
INSERT INTO 'tune' VALUES (9532, NULL, '2013-11-26 17:08:25.132173+00', 'Stuart & Kathleen Walker', 1525, '');
INSERT INTO 'tune' VALUES (12694, '2013-11-27 02:51:00.257434+00', '2013-11-27 02:51:00.257434+00', 'Leslie & Margaret Robson', 1582, '');
INSERT INTO 'tune' VALUES (12738, '2014-02-06 14:08:54.339891+00', '2014-02-06 14:08:54.339891+00', 'Marian Anderson of Whitsome', 10914, '');
INSERT INTO 'tune' VALUES (12739, '2014-02-06 14:10:22.649637+00', '2014-02-06 14:10:22.649637+00', 'Lachie & Isabel MacLeod, Portree', 10914, '');
INSERT INTO 'tune' VALUES (12740, '2014-02-06 14:26:55.443164+00', '2014-02-06 14:26:55.443164+00', 'Pibroch MacKenzie''s Farewell', 1762, '');
INSERT INTO 'tune' VALUES (5535, NULL, '2013-12-03 11:11:57.883702+00', 'Return from India', 9999, 'This tune exists in two versions, one published in <<ddpub:Merrie Melodies, 1st Collection|Kerr''s Collection of Merry Melodies>> and one popular in Cape Breton and published, e.g., in <<ddpub:Jerry Holland''s Collection of Fiddle Tunes>>. The most notable difference between the two is that the A part of the Cape Breton version corresponds to the B part of the Kerr''s version and vice versa.



Most if not all of the recordings of this tune are of the Cape Breton version.');
INSERT INTO 'tune' VALUES (12695, '2013-12-07 20:39:45.89808+00', '2013-12-07 20:39:45.89808+00', 'Maria''s Return', 1502, '');
INSERT INTO 'tune' VALUES (12696, '2013-12-07 20:41:12.545269+00', '2013-12-07 20:41:12.545269+00', 'Beadhead Woolly Bugger, The', 1502, '');
INSERT INTO 'tune' VALUES (12697, '2013-12-07 20:42:20.449867+00', '2013-12-07 20:42:20.449867+00', 'Avril''s Hornpipe', 1502, '');
INSERT INTO 'tune' VALUES (12698, '2013-12-07 20:46:19.091957+00', '2013-12-07 20:46:19.091957+00', 'Drunken Friday', 9999, '');
INSERT INTO 'tune' VALUES (12699, '2013-12-07 20:51:08.860141+00', '2013-12-07 20:51:08.860141+00', 'Dr David Quarrie', 1502, '');
INSERT INTO 'tune' VALUES (12700, '2013-12-07 21:00:57.036735+00', '2013-12-07 21:00:57.036735+00', 'Stag''s Leap', 1502, '');
INSERT INTO 'tune' VALUES (12701, '2013-12-07 21:03:31.803942+00', '2013-12-07 21:03:31.803942+00', 'Ride the Wind (Tatsu-Do)', 1502, '');
INSERT INTO 'tune' VALUES (12702, '2013-12-07 21:08:20.508801+00', '2013-12-07 21:08:20.508801+00', 'Grandparents Strathspey, The', 1502, '');
INSERT INTO 'tune' VALUES (12703, '2013-12-07 21:09:21.803201+00', '2013-12-07 21:09:21.803201+00', 'Lang Road to Urquhart Castle', 1502, '');
INSERT INTO 'tune' VALUES (12704, '2013-12-07 21:12:19.750875+00', '2013-12-07 21:12:19.750875+00', 'Wee Somethin'', A', 1502, '');
INSERT INTO 'tune' VALUES (12705, '2013-12-07 21:17:42.663176+00', '2013-12-07 21:17:42.663176+00', 'Salute to Sandy Gallamore', 1502, '');
INSERT INTO 'tune' VALUES (12706, '2013-12-07 21:18:48.300939+00', '2013-12-07 21:18:48.300939+00', 'Merrymaking, The', 9999, '');
INSERT INTO 'tune' VALUES (12707, '2013-12-07 21:22:18.587883+00', '2013-12-07 21:22:18.587883+00', 'Fozzie''s Flute', 1502, '');
INSERT INTO 'tune' VALUES (12708, '2013-12-07 21:25:47.592882+00', '2013-12-07 21:25:47.592882+00', 'Birnam Station', 1502, '');
INSERT INTO 'tune' VALUES (12709, '2013-12-07 21:29:12.144899+00', '2013-12-07 21:29:12.144899+00', 'Elegy for Bennett', 2977, '');
INSERT INTO 'tune' VALUES (2056, NULL, '2013-12-09 02:26:46.70851+00', 'F W McCondray', 1502, '');
INSERT INTO 'tune' VALUES (12711, '2013-12-10 19:24:41.668138+00', '2013-12-10 19:24:41.668138+00', 'Torphins Lassie', 1439, '');
INSERT INTO 'tune' VALUES (12712, '2013-12-19 10:59:41.240763+00', '2013-12-19 10:59:41.240763+00', 'Audrey and Robin', 3220, '');
INSERT INTO 'tune' VALUES (12713, '2013-12-19 11:01:00.521347+00', '2013-12-19 11:01:00.521347+00', 'Mary Howard''s Strathspey', 3220, '');
INSERT INTO 'tune' VALUES (12714, '2013-12-19 11:02:06.919132+00', '2013-12-19 11:02:06.919132+00', 'Abe''s Jig', 3220, 'composed January 2012');
INSERT INTO 'tune' VALUES (12715, '2013-12-19 11:03:42.157525+00', '2013-12-19 11:03:42.157525+00', 'Cinderella Reel, The', 10908, '');
INSERT INTO 'tune' VALUES (12716, '2013-12-19 11:04:52.300014+00', '2013-12-19 11:04:52.300014+00', 'Strathkarri', 3220, 'composed January 2013');
INSERT INTO 'tune' VALUES (12653, '2013-10-29 02:07:21.427468+00', '2015-06-19 11:48:47.926298+00', 'Jig o'' Beer', 3129, '');
INSERT INTO 'tune' VALUES (12643, '2013-10-29 01:38:07.842262+00', '2015-09-05 21:09:29.627009+00', 'Brenda & Jenny''s Jig', 3220, '');
INSERT INTO 'tune' VALUES (10993, '2009-12-22 23:00:00+00', '2015-09-05 21:25:02.239723+00', 'Deil Amangst the Tailors', 9999, '');
INSERT INTO 'tune' VALUES (12686, '2013-10-31 15:35:30.042269+00', '2018-04-09 05:31:57.239082+00', 'Crowns and Diamonds', 3179, '');
INSERT INTO 'tune' VALUES (12671, '2013-10-31 15:15:49.424027+00', '2018-04-10 08:59:11.637865+00', 'Liebet''s Snake Dance', 3179, '');
INSERT INTO 'tune' VALUES (12675, '2013-10-31 15:21:00.467952+00', '2016-09-09 09:28:57.891708+00', 'Bridge of Inver, The', 1937, '');
INSERT INTO 'tune' VALUES (12683, '2013-10-31 15:29:17.742031+00', '2018-04-08 08:07:13.208693+00', 'Blooms a Twirling', 3179, '');
INSERT INTO 'tune' VALUES (12668, '2013-10-31 15:12:53.624196+00', '2018-04-06 09:18:42.820494+00', 'Accomplished', 3179, '');
INSERT INTO 'tune' VALUES (12689, '2013-10-31 15:39:25.960559+00', '2018-04-08 08:58:00.691103+00', 'Walking on Clouds', 3179, '');
INSERT INTO 'tune' VALUES (12690, '2013-10-31 15:40:13.254775+00', '2018-04-08 10:16:53.473315+00', 'Inspiration', 3179, '');
INSERT INTO 'tune' VALUES (12666, '2013-10-31 15:09:44.462982+00', '2018-04-08 10:19:38.86426+00', 'Visitors from York', 3179, '');
INSERT INTO 'tune' VALUES (12673, '2013-10-31 15:17:16.011369+00', '2018-04-08 10:30:23.752364+00', 'Ray and Kay Harris', 3179, '');
INSERT INTO 'tune' VALUES (12677, '2013-10-31 15:23:11.858525+00', '2018-04-09 00:09:50.409888+00', 'Bridal Jig, The', 3179, '');
INSERT INTO 'tune' VALUES (12676, '2013-10-31 15:21:46.03681+00', '2018-04-09 09:39:14.952582+00', 'Helen and Jean', 3179, '');
INSERT INTO 'tune' VALUES (12687, '2013-10-31 15:37:16.432306+00', '2018-04-09 13:16:57.890527+00', 'I''ll Be Your Shadow', 3179, '');
INSERT INTO 'tune' VALUES (12672, '2013-10-31 15:16:28.633091+00', '2018-04-10 07:43:07.735953+00', 'Longing', 3179, '');
INSERT INTO 'tune' VALUES (12685, '2013-10-31 15:34:34.623212+00', '2018-04-10 08:22:54.926858+00', 'Leapfrog', 3179, '');
INSERT INTO 'tune' VALUES (12678, '2013-10-31 15:24:07.063439+00', '2018-04-10 08:41:47.064121+00', 'Ladies Ebony and Ivory, The', 3179, '');
INSERT INTO 'tune' VALUES (12682, '2013-10-31 15:27:49.926679+00', '2018-04-10 09:15:58.039778+00', 'Master Duncan Nelson', 3179, '');
INSERT INTO 'tune' VALUES (12680, '2013-10-31 15:26:02.526516+00', '2018-04-10 11:44:16.119119+00', 'Opposites Attract', 3179, '');
INSERT INTO 'tune' VALUES (12681, '2013-10-31 15:26:57.437037+00', '2018-04-10 11:47:31.823433+00', 'Pretoria''s Farewell to Maria', 3179, '');
INSERT INTO 'tune' VALUES (12684, '2013-10-31 15:32:39.978216+00', '2018-04-10 11:55:34.95536+00', 'Of Butterflies and Rainbows', 3179, '');
INSERT INTO 'tune' VALUES (12674, '2013-10-31 15:18:42.028739+00', '2018-04-10 12:22:51.486469+00', 'Niel van der Watt''s Strathspey', 3179, '');
INSERT INTO 'tune' VALUES (13903, '2018-06-09 22:07:53.885193+00', '2018-06-09 22:07:53.885193+00', 'Miss Buchanan of Cambusmore', 9999, '');
INSERT INTO 'tune' VALUES (13911, '2018-06-09 22:46:02.659559+00', '2018-06-09 22:46:02.659559+00', 'Ballalika Tuning', 3436, '');
INSERT INTO 'tune' VALUES (12717, '2013-12-19 11:05:39.723769+00', '2013-12-19 11:05:39.723769+00', 'Torridon Cross, The', 3220, 'composed July 2013');
INSERT INTO 'tune' VALUES (12718, '2013-12-19 15:57:21.439317+00', '2013-12-19 15:57:21.439317+00', 'Anne & Gillies Crichton''s Silver Wedding March', 10892, '');
INSERT INTO 'tune' VALUES (12719, '2013-12-19 15:59:11.062242+00', '2013-12-19 15:59:11.062242+00', 'Elsie & Eric Goodfellow''s Pearl Anniversary March', 10892, '');
INSERT INTO 'tune' VALUES (12721, '2013-12-19 16:14:06.344188+00', '2013-12-19 16:14:06.344188+00', 'Marian Anderson''s Compliments to Frances Grant', 3220, '');
INSERT INTO 'tune' VALUES (12723, '2013-12-19 16:36:05.096044+00', '2013-12-19 16:36:05.096044+00', 'Cameroni''s Jigaroni', 10063, '');
INSERT INTO 'tune' VALUES (12724, '2013-12-19 16:37:47.602894+00', '2013-12-19 16:37:47.602894+00', 'McCallum''s Irish Jig', 1596, '');
INSERT INTO 'tune' VALUES (12725, '2013-12-19 16:38:30.541602+00', '2013-12-19 16:38:30.541602+00', 'Junction 16', 2160, '');
INSERT INTO 'tune' VALUES (12726, '2013-12-19 16:46:04.759143+00', '2013-12-19 16:46:04.759143+00', 'Sapphire Scottish Dancers, The', 3436, '');
INSERT INTO 'tune' VALUES (12727, '2013-12-19 16:50:21.625652+00', '2013-12-19 16:50:21.625652+00', 'Bruce and Isobel''s Wedding Day', 1646, '');
INSERT INTO 'tune' VALUES (12728, '2013-12-19 16:54:35.620767+00', '2013-12-19 16:54:35.620767+00', 'Forest Hill Road', 3220, '');
INSERT INTO 'tune' VALUES (12729, '2013-12-19 17:02:51.32734+00', '2013-12-19 17:02:51.32734+00', 'Oban Weekends', 3220, '');
INSERT INTO 'tune' VALUES (12730, '2013-12-19 17:03:55.408433+00', '2013-12-19 17:03:55.408433+00', 'Janet Forbes-Walker''s Jig', 3220, '');
INSERT INTO 'tune' VALUES (12731, '2013-12-19 17:07:14.955584+00', '2013-12-19 17:07:14.955584+00', 'Colin Brown''s Reel', 10892, '');
INSERT INTO 'tune' VALUES (12732, '2013-12-19 17:19:18.288829+00', '2013-12-19 17:19:18.288829+00', 'Doctor Quarrie''s Birthday', 1502, '');
INSERT INTO 'tune' VALUES (12733, '2013-12-19 17:23:10.716021+00', '2013-12-19 17:23:10.716021+00', 'John Holt''s Reel', 1596, '');
INSERT INTO 'tune' VALUES (12734, '2013-12-19 17:23:59.798408+00', '2013-12-19 17:23:59.798408+00', 'Carfrae', 3710, '');
INSERT INTO 'tune' VALUES (12735, '2013-12-19 17:26:42.75903+00', '2013-12-19 17:26:42.75903+00', 'Waltz for Kirsty', 3220, '');
INSERT INTO 'tune' VALUES (12736, '2013-12-19 17:27:36.918114+00', '2013-12-19 17:27:36.918114+00', 'Mary''s Waltz', 1808, '');
INSERT INTO 'tune' VALUES (12162, '2012-06-12 22:20:27.149646+00', '2014-01-05 15:13:27.87269+00', 'Tricia Lodge Two Step, The', 1596, '');
INSERT INTO 'tune' VALUES (12737, '2014-02-04 09:36:52.169678+00', '2014-02-04 09:36:52.169678+00', 'Traditional Reel (for ›Fire in the Rye‹)', 9999, 'Source unknown');
INSERT INTO 'tune' VALUES (12741, '2014-02-06 14:32:44.618001+00', '2014-02-06 14:32:44.618001+00', 'Marjorie and Richard McLauchlin', 2294, '');
INSERT INTO 'tune' VALUES (12742, '2014-02-06 14:36:30.507568+00', '2014-02-06 14:36:30.507568+00', 'Mull Holiday', 1605, '');
INSERT INTO 'tune' VALUES (12745, '2014-02-06 14:44:33.121726+00', '2014-02-06 14:44:33.121726+00', 'Rowen''s Waltz', 1605, '');
INSERT INTO 'tune' VALUES (12746, '2014-02-06 14:46:01.069809+00', '2014-02-06 14:46:01.069809+00', 'Aidan''s Waltz', 1605, '');
INSERT INTO 'tune' VALUES (12747, '2014-02-06 15:54:29.195221+00', '2014-02-06 15:54:29.195221+00', 'Londonderry Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (12749, '2014-02-06 17:49:17.504696+00', '2014-02-06 17:49:17.504696+00', 'Mr Alexander Lawson', 1748, '');
INSERT INTO 'tune' VALUES (12750, '2014-02-06 17:51:18.062245+00', '2014-02-06 17:51:18.062245+00', 'Lady Elva MacAskill', 1502, '');
INSERT INTO 'tune' VALUES (12751, '2014-02-06 17:56:49.950787+00', '2014-02-06 17:56:49.950787+00', 'Dr Gordon Stables'' Reel', 1512, '');
INSERT INTO 'tune' VALUES (12752, '2014-02-06 17:57:53.256938+00', '2014-02-06 17:57:53.256938+00', 'Open the Bottle', 1502, '');
INSERT INTO 'tune' VALUES (12753, '2014-02-06 18:06:54.169229+00', '2014-02-06 18:06:54.169229+00', 'Becky Taylor''s Audacity', 10916, '');
INSERT INTO 'tune' VALUES (12754, '2014-02-06 18:11:27.775238+00', '2014-02-06 18:11:27.775238+00', 'Waukin of the Fauld, The', 9999, '');
INSERT INTO 'tune' VALUES (12755, '2014-02-06 18:12:48.32461+00', '2014-02-06 18:12:48.32461+00', 'Smailholm Tower', 1502, '');
INSERT INTO 'tune' VALUES (12756, '2014-02-06 18:18:49.837561+00', '2014-02-06 18:18:49.837561+00', 'Dalneigh Lasses', 2768, '');
INSERT INTO 'tune' VALUES (12757, '2014-02-06 18:20:29.318773+00', '2014-02-06 18:20:29.318773+00', 'Carolla''s Tolt', 1502, '');
INSERT INTO 'tune' VALUES (12758, '2014-02-06 18:24:51.982567+00', '2014-02-06 18:24:51.982567+00', 'Joe Buchan', 1502, '');
INSERT INTO 'tune' VALUES (12759, '2014-02-06 18:31:49.793196+00', '2014-02-06 18:31:49.793196+00', 'Marianne Taylor', 1502, '');
INSERT INTO 'tune' VALUES (12760, '2014-02-06 18:32:31.840664+00', '2014-02-06 18:32:31.840664+00', 'Mole, The', 1502, '');
INSERT INTO 'tune' VALUES (12761, '2014-02-06 18:39:40.762283+00', '2014-02-06 18:39:40.762283+00', 'Torf''s "Choon"', 1502, '');
INSERT INTO 'tune' VALUES (12762, '2014-02-06 18:47:50.139956+00', '2014-02-06 18:47:50.139956+00', 'Cabbage and Ribs', 10756, '');
INSERT INTO 'tune' VALUES (12764, '2014-02-06 18:59:13.254061+00', '2014-02-06 18:59:13.254061+00', 'Betty Cameron of Muckhart', 1613, '');
INSERT INTO 'tune' VALUES (12765, '2014-02-06 19:00:57.121233+00', '2014-02-06 19:00:57.121233+00', 'Alistair MacLeod', 10211, '');
INSERT INTO 'tune' VALUES (12766, '2014-02-06 19:05:29.703094+00', '2014-02-06 19:05:29.703094+00', 'Jim Lindsay''s Reel', 1502, '');
INSERT INTO 'tune' VALUES (12767, '2014-02-06 19:06:27.516349+00', '2014-02-06 19:06:27.516349+00', 'Ken''s Way', 1502, '');
INSERT INTO 'tune' VALUES (12768, '2014-02-07 08:45:29.126278+00', '2014-02-07 08:45:29.126278+00', 'It''s a Dry Cold', 10813, '');
INSERT INTO 'tune' VALUES (12769, '2014-02-07 08:47:33.767377+00', '2014-02-07 08:47:33.767377+00', 'Crown Point', 9999, '');
INSERT INTO 'tune' VALUES (12770, '2014-02-09 17:12:31.151363+00', '2014-02-09 17:12:31.151363+00', 'Alternating Original Tune', 1575, '');
INSERT INTO 'tune' VALUES (12771, '2014-02-09 17:15:41.630972+00', '2014-02-09 17:15:41.630972+00', 'Miss Campbell of Saddell', 1598, '');
INSERT INTO 'tune' VALUES (12772, '2014-02-09 17:20:34.636859+00', '2014-02-09 17:20:34.636859+00', 'Jig for Ethel', 1871, '');
INSERT INTO 'tune' VALUES (12773, '2014-02-09 17:21:16.923963+00', '2014-02-09 17:21:16.923963+00', 'Advance and Retire', 1871, '');
INSERT INTO 'tune' VALUES (12774, '2014-02-09 17:29:59.203101+00', '2014-02-09 17:29:59.203101+00', 'Jenny''s Delight', 1575, '');
INSERT INTO 'tune' VALUES (12776, '2014-02-09 17:56:25.326433+00', '2014-02-09 17:56:25.326433+00', 'Tribute to Glasgow', 1596, '');
INSERT INTO 'tune' VALUES (12777, '2014-02-09 17:58:07.755392+00', '2014-02-09 17:58:07.755392+00', 'Low Backed Car, The', 9999, '');
INSERT INTO 'tune' VALUES (12778, '2014-02-09 18:01:14.102902+00', '2014-02-09 18:01:14.102902+00', 'Welcome to Glasgow', 1575, '');
INSERT INTO 'tune' VALUES (12779, '2014-02-09 18:02:16.293433+00', '2014-02-09 18:02:16.293433+00', 'Ross Strathspey, The', 1575, '');
INSERT INTO 'tune' VALUES (12780, '2014-02-09 18:03:10.682849+00', '2014-02-09 18:03:10.682849+00', 'Lady Isle', 1575, '');
INSERT INTO 'tune' VALUES (12781, '2014-02-14 14:50:44.188716+00', '2014-02-14 14:50:44.188716+00', 'Semple''s Day in Vilamoura', 1575, '');
INSERT INTO 'tune' VALUES (12782, '2014-02-14 15:13:42.772976+00', '2014-02-14 15:13:42.772976+00', 'Leaving the Boat at Portree', 9999, '');
INSERT INTO 'tune' VALUES (12783, '2014-02-14 15:15:14.878058+00', '2014-02-14 15:15:14.878058+00', 'Mull of the Mountains', 9999, '');
INSERT INTO 'tune' VALUES (12784, '2014-02-14 15:20:29.149656+00', '2014-02-14 15:20:29.149656+00', 'Highland Walking Song', 9999, '');
INSERT INTO 'tune' VALUES (12785, '2014-02-14 15:26:08.787329+00', '2014-02-14 15:26:08.787329+00', 'Miss C M Hall', 9999, '');
INSERT INTO 'tune' VALUES (12786, '2014-02-14 15:34:14.992579+00', '2014-02-14 15:34:14.992579+00', 'Arran View', 1415, '');
INSERT INTO 'tune' VALUES (12787, '2014-02-14 15:46:26.411527+00', '2014-02-14 15:46:26.411527+00', 'Manchester Caledonian Society', 9999, '');
INSERT INTO 'tune' VALUES (12788, '2014-02-14 16:03:20.107154+00', '2014-02-14 16:03:20.107154+00', 'Rae''s Classic', 10077, '');
INSERT INTO 'tune' VALUES (12789, '2014-02-15 13:27:17.273337+00', '2014-02-15 13:27:17.273337+00', 'Slalom Skiier, The', 9998, '');
INSERT INTO 'tune' VALUES (12790, '2014-02-15 13:47:26.856067+00', '2014-02-15 13:47:26.856067+00', 'Trevor Howard''s Reel', 1575, '');
INSERT INTO 'tune' VALUES (12791, '2014-02-15 13:49:48.064466+00', '2014-02-15 13:49:48.064466+00', 'Trip to Herves', 9998, '');
INSERT INTO 'tune' VALUES (12792, '2014-02-15 14:02:55.060846+00', '2014-02-15 14:02:55.060846+00', 'Pack Up Your Troubles', 9998, '');
INSERT INTO 'tune' VALUES (12793, '2014-02-15 14:04:51.58033+00', '2014-02-15 14:04:51.58033+00', 'Roll out the Barrel', 9999, '');
INSERT INTO 'tune' VALUES (12796, '2014-02-15 18:45:02.426453+00', '2014-02-15 18:45:02.426453+00', 'Robert Rae Frew of Annbank', 10103, '');
INSERT INTO 'tune' VALUES (12797, '2014-02-15 18:45:51.111023+00', '2014-02-15 18:45:51.111023+00', 'Peter and Mary''s Erin Barn Dance', 10103, '');
INSERT INTO 'tune' VALUES (12798, '2014-02-15 18:46:29.464686+00', '2014-02-15 18:46:29.464686+00', 'Mother Bell', 10103, '');
INSERT INTO 'tune' VALUES (12799, '2014-02-15 18:47:09.903963+00', '2014-02-15 18:47:09.903963+00', 'Jim and Julie''s Jig', 10103, '');
INSERT INTO 'tune' VALUES (12800, '2014-02-15 18:48:02.209757+00', '2014-02-15 18:48:02.209757+00', 'Sandy Bain of Pitlochry', 10103, '');
INSERT INTO 'tune' VALUES (12801, '2014-02-15 18:48:35.85628+00', '2014-02-15 18:48:35.85628+00', 'Somerset Park', 10103, '');
INSERT INTO 'tune' VALUES (7713, NULL, '2014-02-20 23:22:50.505593+00', 'Kay and Sören Hinrichs', 228, '');
INSERT INTO 'tune' VALUES (12856, '2014-03-16 14:44:36.781483+00', '2014-03-16 14:44:36.781483+00', 'Peter Marshall''s Hornpipe', 1527, '');
INSERT INTO 'tune' VALUES (12857, '2014-03-16 14:49:48.415216+00', '2014-03-16 14:49:48.415216+00', 'Taeko Tamura''s Strathspey', 1527, '');
INSERT INTO 'tune' VALUES (12803, '2014-03-10 01:06:31.380192+00', '2014-03-10 01:06:31.380192+00', 'Arthur Street', 1643, '');
INSERT INTO 'tune' VALUES (5986, NULL, '2014-03-10 07:04:17.668154+00', 'Whiskey in the Jar', 9999, '');
INSERT INTO 'tune' VALUES (12804, '2014-03-10 07:22:57.934097+00', '2014-03-10 07:22:57.934097+00', 'Phil''s Pony', 9999, '');
INSERT INTO 'tune' VALUES (2724, NULL, '2014-03-10 07:49:37.923549+00', 'O''Donnal Abu', 9999, '');
INSERT INTO 'tune' VALUES (12805, '2014-03-10 07:52:58.667144+00', '2014-03-10 07:52:58.667144+00', 'St. Pat''s Centenary March', 9999, 'Check needed: could this be the same as "Centenary March"?  Eric 140310');
INSERT INTO 'tune' VALUES (12806, '2014-03-10 07:56:46.115981+00', '2014-03-10 07:56:46.115981+00', 'Wonder, The', 9999, '');
INSERT INTO 'tune' VALUES (12807, '2014-03-10 08:14:44.326303+00', '2014-03-10 08:14:44.326303+00', 'Repaz Band, The', 10918, '');
INSERT INTO 'tune' VALUES (14004, '2019-02-01 16:14:31.060622+00', '2019-02-01 16:14:31.060622+00', 'Susana', 1836, '');
INSERT INTO 'tune' VALUES (12809, '2014-03-10 08:30:01.554174+00', '2014-03-10 08:30:01.554174+00', 'Mairsland Two-Step', 1558, '');
INSERT INTO 'tune' VALUES (12810, '2014-03-13 15:34:07.104657+00', '2014-03-13 15:34:07.104657+00', 'Twixmas Hornpipe', 1526, '');
INSERT INTO 'tune' VALUES (12811, '2014-03-13 15:35:20.256645+00', '2014-03-13 15:35:20.256645+00', 'George''s Hornpipe', 1526, '');
INSERT INTO 'tune' VALUES (12812, '2014-03-13 15:36:38.332335+00', '2014-03-13 15:36:38.332335+00', 'Inglenook, The', 1526, '');
INSERT INTO 'tune' VALUES (12813, '2014-03-13 15:37:18.709404+00', '2014-03-13 15:37:18.709404+00', 'Tequila Reel', 1526, '');
INSERT INTO 'tune' VALUES (12744, '2014-02-06 14:41:21.416392+00', '2016-09-09 09:22:41.132029+00', 'Branch Salute, The', 1673, '');
INSERT INTO 'tune' VALUES (12720, '2013-12-19 16:05:01.467296+00', '2016-09-09 09:26:15.887858+00', 'Pitlochry High School Centenary, The', 3129, '');
INSERT INTO 'tune' VALUES (12743, '2014-02-06 14:40:07.732017+00', '2016-09-09 09:26:33.124127+00', 'Pipe Major''s March to Strathallan, The', 1673, '');
INSERT INTO 'tune' VALUES (14005, '2019-02-19 15:14:05.263092+00', '2019-02-19 15:14:05.263092+00', 'A439', 11781, '');
INSERT INTO 'tune' VALUES (12814, '2014-03-13 15:46:19.366363+00', '2014-03-13 15:46:19.366363+00', 'Hullichan Jig', 9999, '');
INSERT INTO 'tune' VALUES (12815, '2014-03-13 15:53:28.904757+00', '2014-03-13 15:53:28.904757+00', 'Jenny''s Strathspey', 1526, '');
INSERT INTO 'tune' VALUES (12816, '2014-03-13 16:00:15.078113+00', '2014-03-13 16:00:15.078113+00', 'Auspicious Piper, The', 1526, '');
INSERT INTO 'tune' VALUES (12817, '2014-03-13 16:01:14.890661+00', '2014-03-13 16:01:14.890661+00', 'Piper''s Birthday, The', 1526, '');
INSERT INTO 'tune' VALUES (12818, '2014-03-13 16:02:12.374438+00', '2014-03-13 16:02:12.374438+00', 'Pie-Eyed Piper, The', 1526, '');
INSERT INTO 'tune' VALUES (12819, '2014-03-13 16:05:51.62457+00', '2014-03-13 16:05:51.62457+00', 'Friday the Thirteenth', 1526, '');
INSERT INTO 'tune' VALUES (12820, '2014-03-13 16:14:54.963086+00', '2014-03-13 16:14:54.963086+00', 'Kenneth & Fiona''s Ruby Strathspey', 1526, '');
INSERT INTO 'tune' VALUES (12821, '2014-03-13 16:16:02.727507+00', '2014-03-13 16:16:02.727507+00', 'Crooked Spire, The', 1526, '');
INSERT INTO 'tune' VALUES (12822, '2014-03-13 17:22:54.109428+00', '2014-03-13 17:22:54.109428+00', 'Earl of St Andrews, The', 1526, '');
INSERT INTO 'tune' VALUES (12823, '2014-03-13 17:24:07.708683+00', '2014-03-13 17:24:07.708683+00', 'Banks of the Tay', 1526, '');
INSERT INTO 'tune' VALUES (12824, '2014-03-13 17:24:46.676924+00', '2014-03-13 17:24:46.676924+00', 'Cupar Lasses', 1526, '');
INSERT INTO 'tune' VALUES (12826, '2014-03-13 17:34:05.380067+00', '2014-03-13 17:34:05.380067+00', 'Brough Castle', 1526, '');
INSERT INTO 'tune' VALUES (12827, '2014-03-13 17:34:50.206534+00', '2014-03-13 17:34:50.206534+00', 'Chesterfield Rainbow, The', 1526, '');
INSERT INTO 'tune' VALUES (12828, '2014-03-13 17:48:00.3163+00', '2014-03-13 17:48:00.3163+00', '76 Trombones', 10919, '');
INSERT INTO 'tune' VALUES (12829, '2014-03-13 17:50:38.783863+00', '2014-03-13 17:50:38.783863+00', 'Dover Ruby', 1526, '');
INSERT INTO 'tune' VALUES (12830, '2014-03-13 17:51:28.48738+00', '2014-03-13 17:51:28.48738+00', 'Cookhill Hornpipe', 1526, '');
INSERT INTO 'tune' VALUES (12831, '2014-03-13 17:52:15.036777+00', '2014-03-13 17:52:15.036777+00', 'Hog Roast, The', 1526, '');
INSERT INTO 'tune' VALUES (12832, '2014-03-13 17:57:29.376343+00', '2014-03-13 17:57:29.376343+00', 'Keavil House', 1526, '');
INSERT INTO 'tune' VALUES (12833, '2014-03-13 17:58:21.952768+00', '2014-03-13 17:58:21.952768+00', 'Wintry Wood, The', 1526, '');
INSERT INTO 'tune' VALUES (12834, '2014-03-13 18:06:56.41289+00', '2014-03-13 18:06:56.41289+00', 'Roy''s Reel', 810, '');
INSERT INTO 'tune' VALUES (12835, '2014-03-13 18:08:00.635987+00', '2014-03-13 18:08:00.635987+00', 'Moment of Madness, A', 1526, '');
INSERT INTO 'tune' VALUES (12836, '2014-03-14 15:29:30.939296+00', '2014-03-14 15:29:30.939296+00', 'Junpier Jig', 1538, '');
INSERT INTO 'tune' VALUES (12837, '2014-03-14 15:30:34.562499+00', '2014-03-14 15:30:34.562499+00', 'Miss Faya Mather', 3683, '');
INSERT INTO 'tune' VALUES (12838, '2014-03-14 16:05:50.496248+00', '2014-03-14 16:05:50.496248+00', 'O'' Sullivan''s No.1', 2160, '');
INSERT INTO 'tune' VALUES (12839, '2014-03-14 16:07:23.629534+00', '2014-03-14 16:07:23.629534+00', 'Tongadale Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (12840, '2014-03-16 11:06:24.365982+00', '2014-03-16 11:06:24.365982+00', 'Burnside', 9998, '');
INSERT INTO 'tune' VALUES (12841, '2014-03-16 11:11:24.877708+00', '2014-03-16 11:11:24.877708+00', 'Glenogle', 9998, '');
INSERT INTO 'tune' VALUES (12842, '2014-03-16 11:12:50.459434+00', '2014-03-16 11:12:50.459434+00', 'Miller, The', 2244, '');
INSERT INTO 'tune' VALUES (12843, '2014-03-16 11:32:56.857035+00', '2014-03-16 11:32:56.857035+00', 'Rachael Rae', 445, '');
INSERT INTO 'tune' VALUES (12845, '2014-03-16 11:45:51.284568+00', '2014-03-16 11:45:51.284568+00', 'Sultan Steamboat, The', 10921, '');
INSERT INTO 'tune' VALUES (12846, '2014-03-16 11:53:14.938373+00', '2014-03-16 11:53:14.938373+00', 'Jim Lockie''s Jig', 1609, '');
INSERT INTO 'tune' VALUES (12847, '2014-03-16 11:54:36.63359+00', '2014-03-16 11:54:36.63359+00', 'Rose in the Heather, The', 9998, '');
INSERT INTO 'tune' VALUES (12848, '2014-03-16 12:01:21.394571+00', '2014-03-16 12:01:21.394571+00', 'Old Drove Road, The', 3493, '');
INSERT INTO 'tune' VALUES (12849, '2014-03-16 12:06:24.945531+00', '2014-03-16 12:06:24.945531+00', 'Fiddler''s Rally, The', 10922, '');
INSERT INTO 'tune' VALUES (12850, '2014-03-16 12:12:25.763825+00', '2014-03-16 12:12:25.763825+00', 'Wise Maid', 9998, '');
INSERT INTO 'tune' VALUES (12851, '2014-03-16 12:15:03.895703+00', '2014-03-16 12:15:03.895703+00', 'Cloudy Craggs', 10923, '');
INSERT INTO 'tune' VALUES (12852, '2014-03-16 12:23:17.968242+00', '2014-03-16 12:23:17.968242+00', 'Rockery', 1700, '');
INSERT INTO 'tune' VALUES (12853, '2014-03-16 14:37:30.275984+00', '2014-03-16 14:37:30.275984+00', 'Sukiyaki', 10924, '');
INSERT INTO 'tune' VALUES (12854, '2014-03-16 14:39:05.237692+00', '2014-03-16 14:39:05.237692+00', 'Miyoko''s Welcome to Scotland', 1527, '');
INSERT INTO 'tune' VALUES (12858, '2014-03-16 15:01:02.772031+00', '2014-03-16 15:01:02.772031+00', 'Back o'' Catterfearn', 9999, '');
INSERT INTO 'tune' VALUES (12859, '2014-03-16 15:08:10.95724+00', '2014-03-16 15:08:10.95724+00', 'Kilberry Brig', 1527, '');
INSERT INTO 'tune' VALUES (12860, '2014-03-16 15:11:31.602093+00', '2014-03-16 15:11:31.602093+00', 'Mayumi Nagamine''s Jig', 1527, '');
INSERT INTO 'tune' VALUES (12861, '2014-03-16 15:17:32.658083+00', '2014-03-16 15:17:32.658083+00', 'Hiroko Kokai''s Strathspey', 1527, '');
INSERT INTO 'tune' VALUES (12862, '2014-03-16 15:21:19.015625+00', '2014-03-16 15:21:19.015625+00', 'Kaoru Hoshino''s Jig', 1527, '');
INSERT INTO 'tune' VALUES (12863, '2014-03-16 15:31:33.662785+00', '2014-03-16 15:31:33.662785+00', 'Moon over the Ruined Castle', 10925, '');
INSERT INTO 'tune' VALUES (12864, '2014-03-16 15:34:35.159735+00', '2014-03-16 15:34:35.159735+00', 'Autumn Midnight', 10926, '');
INSERT INTO 'tune' VALUES (12865, '2014-03-16 15:36:53.566595+00', '2014-03-16 15:36:53.566595+00', 'Light, The', 9999, '');
INSERT INTO 'tune' VALUES (12866, '2014-03-16 15:41:34.439712+00', '2014-03-16 15:41:34.439712+00', 'Skiing Song', 10927, '');
INSERT INTO 'tune' VALUES (12867, '2014-03-16 15:44:19.764879+00', '2014-03-16 15:44:19.764879+00', 'Autumn in a Village', 10928, '');
INSERT INTO 'tune' VALUES (12868, '2014-03-16 15:47:11.158585+00', '2014-03-16 15:47:11.158585+00', 'Small Stream in the Spring, The', 10929, '');
INSERT INTO 'tune' VALUES (12795, '2014-02-15 14:08:34.55112+00', '2014-09-16 08:48:52.724808+00', 'When the Saints Go Marching In', 9999, '');
INSERT INTO 'tune' VALUES (12869, '2014-03-16 15:51:31.231341+00', '2014-03-16 15:51:31.231341+00', 'Momoyo Suzuki''s Jig', 1527, '');
INSERT INTO 'tune' VALUES (12870, '2014-03-16 15:52:39.301453+00', '2014-03-16 15:52:39.301453+00', 'Gordon and Fiona Cairns', 1527, '');
INSERT INTO 'tune' VALUES (12871, '2014-03-16 15:53:48.235632+00', '2014-03-16 15:53:48.235632+00', 'Alexander Johnston', 1527, '');
INSERT INTO 'tune' VALUES (12872, '2014-03-16 15:59:11.698453+00', '2014-03-16 15:59:11.698453+00', 'Miss Smith''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (12873, '2014-03-16 16:05:02.605032+00', '2014-03-16 16:05:02.605032+00', 'Coliseum Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (12875, '2014-03-17 23:29:45.156961+00', '2014-03-17 23:29:45.156961+00', 'Bonny Lass of Balalntrae', 9999, '');
INSERT INTO 'tune' VALUES (12876, '2014-03-17 23:33:25.20364+00', '2014-03-17 23:33:25.20364+00', 'Riding the Wave', 2717, '');
INSERT INTO 'tune' VALUES (12877, '2014-03-19 08:50:11.472555+00', '2014-03-19 08:50:11.472555+00', 'Angus McQueen of Uist', 1817, '');
INSERT INTO 'tune' VALUES (12878, '2014-03-19 09:04:53.794265+00', '2014-03-19 09:04:53.794265+00', 'Master Erskine J Shand', 1558, '');
INSERT INTO 'tune' VALUES (12879, '2014-03-19 09:13:34.598225+00', '2014-03-19 09:13:34.598225+00', 'Lily of Ardmore', 1558, '');
INSERT INTO 'tune' VALUES (12880, '2014-03-19 09:34:32.557594+00', '2014-03-19 09:34:32.557594+00', 'Shean Trews', 9999, '');
INSERT INTO 'tune' VALUES (12881, '2014-03-19 09:35:22.57311+00', '2014-03-19 09:35:22.57311+00', 'Lottie and Chattie', 9999, '');
INSERT INTO 'tune' VALUES (12882, '2014-03-19 10:24:11.430648+00', '2014-03-19 10:24:11.430648+00', 'Fire in the Hearth', 1580, '');
INSERT INTO 'tune' VALUES (12883, '2014-03-19 10:39:12.26591+00', '2014-03-19 10:39:12.26591+00', 'Ceud Mile Failte', 9999, '');
INSERT INTO 'tune' VALUES (12884, '2014-03-19 10:45:32.190691+00', '2014-03-19 10:45:32.190691+00', 'Eamonn Gilmartin''s Eclipse', 1817, '');
INSERT INTO 'tune' VALUES (12885, '2014-03-19 10:47:50.967859+00', '2014-03-19 10:47:50.967859+00', 'Girl with the Bewitching Eyes', 1817, '');
INSERT INTO 'tune' VALUES (12886, '2014-03-19 10:56:24.648162+00', '2014-03-19 10:56:24.648162+00', 'Variations on Willafjord', 9998, '');
INSERT INTO 'tune' VALUES (12887, '2014-03-19 11:01:03.789549+00', '2014-03-19 11:01:03.789549+00', 'Stronsay Wedding, The', 9999, '');
INSERT INTO 'tune' VALUES (12888, '2014-03-19 11:04:22.561529+00', '2014-03-19 11:04:22.561529+00', 'Reel of Kildinguie', 9999, '');
INSERT INTO 'tune' VALUES (9187, NULL, '2014-03-19 22:37:15.758021+00', 'Lass of Ballintra, The', 9999, 'For "Khaosan Reel"; the suggested tune is spelled "The Lass of Ballantrae"; it was assumed that this is the tune that was meant.');
INSERT INTO 'tune' VALUES (12889, '2014-03-20 15:03:42.396413+00', '2014-03-20 15:03:42.396413+00', 'Curly-Haired Lass', 389, '');
INSERT INTO 'tune' VALUES (12890, '2014-03-25 15:41:19.766284+00', '2014-03-25 15:41:19.766284+00', 'Bye Bye Blues', 10935, '');
INSERT INTO 'tune' VALUES (12891, '2014-03-26 14:22:15.611743+00', '2014-03-26 14:22:15.611743+00', 'Farmers Jubilee', 9999, '');
INSERT INTO 'tune' VALUES (12892, '2014-03-26 14:26:12.511457+00', '2014-03-26 14:26:12.511457+00', 'Silent Wedding', 10937, '');
INSERT INTO 'tune' VALUES (12893, '2014-03-26 15:02:49.152923+00', '2014-03-26 15:02:49.152923+00', 'Tommy Macdonald of Barquillean', 10938, '');
INSERT INTO 'tune' VALUES (12894, '2014-03-26 15:19:51.724331+00', '2014-03-26 15:19:51.724331+00', 'Margo MacBeth of Nairnside', 10937, '');
INSERT INTO 'tune' VALUES (12895, '2014-03-26 15:24:51.372173+00', '2014-03-26 15:24:51.372173+00', 'Ronnie Douglas''s Compliments to Morris Grant', 10939, '');
INSERT INTO 'tune' VALUES (12896, '2014-03-26 15:29:43.029531+00', '2014-03-26 15:29:43.029531+00', 'Whisky Your the Devil', 9999, '');
INSERT INTO 'tune' VALUES (12897, '2014-03-26 15:33:38.108899+00', '2014-03-26 15:33:38.108899+00', 'George MacBeth the Doll 80th Birthday', 10937, '');
INSERT INTO 'tune' VALUES (12899, '2014-03-26 15:59:16.798998+00', '2014-03-26 15:59:16.798998+00', 'Donald''s Joyce (Choice)', 10941, '');
INSERT INTO 'tune' VALUES (12900, '2014-03-26 16:00:48.54361+00', '2014-03-26 16:00:48.54361+00', 'Catherne Mackays Button Box Gathering', 10941, '');
INSERT INTO 'tune' VALUES (12901, '2014-03-26 16:02:29.939548+00', '2014-03-26 16:02:29.939548+00', 'Jock Stephen''s Visit to Redwood', 10939, '');
INSERT INTO 'tune' VALUES (12902, '2014-03-26 16:05:47.097957+00', '2014-03-26 16:05:47.097957+00', 'Swarthouse Primroses', 10937, '');
INSERT INTO 'tune' VALUES (12904, '2014-03-26 16:15:12.883881+00', '2014-03-26 16:15:12.883881+00', 'Broken Branches', 10937, '');
INSERT INTO 'tune' VALUES (12905, '2014-03-26 16:20:14.325417+00', '2014-03-26 16:20:14.325417+00', 'Primrose Valley', 10937, '');
INSERT INTO 'tune' VALUES (12906, '2014-03-26 16:21:14.441091+00', '2014-03-26 16:21:14.441091+00', 'Road to Applecross', 10937, '');
INSERT INTO 'tune' VALUES (12907, '2014-03-26 16:24:24.178826+00', '2014-03-26 16:24:24.178826+00', 'Sandy MacLennan', 10941, '');
INSERT INTO 'tune' VALUES (12908, '2014-03-26 16:25:44.580698+00', '2014-03-26 16:25:44.580698+00', 'Ronald MacNicol Esq', 10941, '');
INSERT INTO 'tune' VALUES (12909, '2014-03-26 16:27:53.434605+00', '2014-03-26 16:29:56.318854+00', 'Roddie Ross of Brora', 10941, '');
INSERT INTO 'tune' VALUES (13876, '2018-04-06 07:17:20.007072+00', '2018-04-06 10:45:28.001477+00', 'Rosenberg Hill', 3179, '');
INSERT INTO 'tune' VALUES (12912, '2014-03-27 13:06:36.875973+00', '2014-03-27 13:06:36.875973+00', 'An t-Eilean Muilleach', 9999, '');
INSERT INTO 'tune' VALUES (12913, '2014-03-27 13:08:34.364723+00', '2014-03-27 13:08:34.364723+00', 'Muile Nam Fuar-bheann', 9999, '');
INSERT INTO 'tune' VALUES (12914, '2014-03-27 13:10:35.601376+00', '2014-03-27 13:10:35.601376+00', 'Maighdeanan Na h-Airigh', 9999, '');
INSERT INTO 'tune' VALUES (10385, '2009-11-07 23:00:00+00', '2014-04-01 07:25:40.757796+00', 'Men from Inveraray, The', 1507, '');
INSERT INTO 'tune' VALUES (3038, NULL, '2014-04-02 20:02:33.845288+00', 'Tune for Glendale, A', 1633, '');
INSERT INTO 'tune' VALUES (12915, '2014-04-08 14:22:00.499993+00', '2014-04-08 14:22:00.499993+00', 'Miss Anne''s Jig', 1773, 'February 1984');
INSERT INTO 'tune' VALUES (12916, '2014-04-14 21:29:56.281736+00', '2014-04-14 21:29:56.281736+00', 'Glamorous in Red', 3683, '');
INSERT INTO 'tune' VALUES (12917, '2014-04-25 09:58:19.448147+00', '2014-04-25 09:58:19.448147+00', 'Miss Adye', 9999, '');
INSERT INTO 'tune' VALUES (12918, '2014-04-25 10:00:47.768368+00', '2014-04-25 10:00:47.768368+00', 'Glen Livet', 9999, '');
INSERT INTO 'tune' VALUES (12919, '2014-04-29 13:30:53.313208+00', '2014-04-29 13:30:53.313208+00', 'Mary Gow', 9999, '');
INSERT INTO 'tune' VALUES (12920, '2014-04-29 13:31:52.972231+00', '2014-04-29 13:31:52.972231+00', 'Ballater Lassies', 9999, '');
INSERT INTO 'tune' VALUES (12921, '2014-04-29 13:54:01.759166+00', '2014-04-29 13:54:01.759166+00', 'Cearketton', 9999, '');
INSERT INTO 'tune' VALUES (12922, '2014-04-29 14:58:29.333318+00', '2014-04-29 14:58:29.333318+00', 'Blair''s Hornpipe', 1659, '');
INSERT INTO 'tune' VALUES (12923, '2014-04-29 15:02:49.497383+00', '2014-04-29 15:02:49.497383+00', 'Colin Blair', 1659, '');
INSERT INTO 'tune' VALUES (12924, '2014-04-29 15:36:05.774805+00', '2014-04-29 15:36:05.774805+00', 'Glen Finlas', 9998, '');
INSERT INTO 'tune' VALUES (12925, '2014-04-29 17:14:26.049912+00', '2014-04-29 17:14:26.049912+00', 'Lads of Bonnie Scotland, The', 9999, '');
INSERT INTO 'tune' VALUES (12927, '2014-05-09 09:27:35.336744+00', '2014-05-09 09:27:35.336744+00', 'Clydeside Reel, The', 3683, '');
INSERT INTO 'tune' VALUES (12930, '2014-05-09 22:57:08.751863+00', '2014-05-09 22:57:08.751863+00', 'New Year Wedding', 10056, '');
INSERT INTO 'tune' VALUES (12931, '2014-05-09 22:57:55.019338+00', '2014-05-09 22:57:55.019338+00', 'Fields of Torridon', 10056, '');
INSERT INTO 'tune' VALUES (12932, '2014-05-09 22:58:40.664432+00', '2014-05-09 22:58:40.664432+00', 'Frosty Morn, A', 10056, '');
INSERT INTO 'tune' VALUES (12934, '2014-05-09 23:04:45.6691+00', '2014-05-09 23:04:45.6691+00', 'Young Francis Mooney', 9999, '');
INSERT INTO 'tune' VALUES (12940, '2014-05-10 00:00:21.468662+00', '2014-05-10 00:00:21.468662+00', 'Tribute to Bill Wood', 2054, '');
INSERT INTO 'tune' VALUES (12941, '2014-05-10 00:03:05.745861+00', '2014-05-10 00:03:05.745861+00', 'Young Meg', 9999, '');
INSERT INTO 'tune' VALUES (12942, '2014-05-10 00:06:40.546389+00', '2014-05-10 00:06:40.546389+00', 'Frances Carol Brown', 2085, '');
INSERT INTO 'tune' VALUES (13658, '2017-10-10 12:36:55.729736+00', '2018-04-07 07:05:05.037485+00', 'All together now', 11521, '');
INSERT INTO 'tune' VALUES (12944, '2014-05-10 00:11:31.42246+00', '2014-05-10 00:11:31.42246+00', 'Darby the Driver', 9999, '');
INSERT INTO 'tune' VALUES (12946, '2014-05-10 00:17:52.412359+00', '2014-05-10 00:17:52.412359+00', 'Hoi Song, The', 9999, '');
INSERT INTO 'tune' VALUES (12947, '2014-05-10 00:20:06.439575+00', '2014-05-10 00:20:06.439575+00', 'Lament for Bobby Brown', 1502, '');
INSERT INTO 'tune' VALUES (12948, '2014-05-10 00:23:22.535019+00', '2014-05-10 00:23:22.535019+00', 'Lost In the Mist of Time', 10960, '');
INSERT INTO 'tune' VALUES (11640, '2011-08-22 22:00:00+00', '2018-04-07 23:10:56.314196+00', 'Beanntan an Dragoin', 3179, '');
INSERT INTO 'tune' VALUES (12949, '2014-05-30 15:31:05.976015+00', '2014-05-30 15:38:27.501513+00', 'Dowie Dens o'' Yarrow', 9999, 'Old ballad/Child 214');
INSERT INTO 'tune' VALUES (12950, '2014-06-09 13:14:24.680455+00', '2014-06-09 13:35:39.743496+00', 'Bar''s Lullaby', 3459, '2013');
INSERT INTO 'tune' VALUES (12951, '2014-06-09 20:21:42.018353+00', '2014-06-09 20:21:42.018353+00', 'Kay Senior', 2197, '');
INSERT INTO 'tune' VALUES (12658, '2013-10-29 02:43:36.244074+00', '2014-07-11 10:49:10.493528+00', 'Tetris Musica', 9999, 'This tune will be familiar to Westerners from the Nintendo Gameboy version of the well-known <<http://en.wikipedia.org/wiki/Tetris#Music|Tetris>> video game, to a point where people

will think of it as »the Tetris tune«. It is based on

a 19th-century Russian folk song called »Коробейники« (»Korobeiniki«).



The incorrect »Kobobeiniki« romanisation occurs on the Marian Anderson CD, <<dda:Sunday Class Dance Book 1>>.');
INSERT INTO 'tune' VALUES (12928, '2014-05-09 21:42:33.6707+00', '2022-12-19 19:39:49.203844+00', 'Jig Away', 2257, '');
INSERT INTO 'tune' VALUES (12926, '2014-05-09 09:21:30.620935+00', '2022-12-31 17:42:44.654726+00', 'Radical Road, The', 1527, '');
INSERT INTO 'tune' VALUES (12953, '2014-07-11 12:48:36.695179+00', '2014-07-11 12:48:36.695179+00', 'Ballinbreich', 10972, '');
INSERT INTO 'tune' VALUES (12954, '2014-07-11 12:54:29.936164+00', '2014-07-11 12:54:29.936164+00', 'John Cass''s Jig', 3220, '');
INSERT INTO 'tune' VALUES (12956, '2014-07-11 12:58:13.49761+00', '2014-07-11 12:58:13.49761+00', 'Mr Busby Maitland', 1517, '');
INSERT INTO 'tune' VALUES (12957, '2014-07-11 13:03:37.837097+00', '2014-07-11 13:03:37.837097+00', 'Miss Ommannay''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (5819, NULL, '2014-07-30 13:58:12.172115+00', 'Gairloch', 10977, '');
INSERT INTO 'tune' VALUES (12958, '2014-07-30 14:12:12.470499+00', '2014-07-30 14:12:12.470499+00', 'Jim MacLeod''s Visit to Balmoral', 1531, '');
INSERT INTO 'tune' VALUES (12959, '2014-07-30 14:19:56.212536+00', '2014-07-30 14:19:56.212536+00', 'Highland President, The', 1512, '');
INSERT INTO 'tune' VALUES (12960, '2014-07-30 14:34:37.632255+00', '2014-07-30 14:34:37.632255+00', 'Sir Thomas Wardle of Western Australia', 1551, '');
INSERT INTO 'tune' VALUES (12961, '2014-07-30 14:38:51.565658+00', '2014-07-30 14:38:51.565658+00', 'Shianbank Two-Step, The', 10978, '');
INSERT INTO 'tune' VALUES (12962, '2014-08-11 14:58:15.318033+00', '2014-08-11 14:58:15.318033+00', 'Nimble Finger', 1554, '');
INSERT INTO 'tune' VALUES (12963, '2014-08-11 14:58:44.79699+00', '2014-08-11 14:58:44.79699+00', 'Archie Duncan', 1554, '');
INSERT INTO 'tune' VALUES (12964, '2014-08-11 15:11:51.1131+00', '2014-08-11 15:11:51.1131+00', 'West-End Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (12965, '2014-08-11 15:12:15.213602+00', '2014-08-11 15:12:15.213602+00', 'Fay''s Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (12966, '2014-08-11 15:21:50.609791+00', '2014-08-11 15:21:50.609791+00', 'Mrs Carol Clancy', 3186, '');
INSERT INTO 'tune' VALUES (12968, '2014-08-11 15:25:33.136574+00', '2014-08-11 15:25:33.136574+00', 'Dun Ibrig', 10980, '');
INSERT INTO 'tune' VALUES (12969, '2014-08-11 15:26:27.358236+00', '2014-08-11 15:26:27.358236+00', 'Merry Maiden, The', 9999, '');
INSERT INTO 'tune' VALUES (12970, '2014-08-11 15:26:56.260401+00', '2014-08-11 15:26:56.260401+00', 'Gudgeon of Maurice''s Car', 9999, '');
INSERT INTO 'tune' VALUES (12971, '2014-08-11 22:08:50.239045+00', '2014-08-11 22:08:50.239045+00', 'Out on the Ocean', 9999, '');
INSERT INTO 'tune' VALUES (2683, NULL, '2014-08-11 22:21:49.850589+00', 'Mrs Margaret Holmes', 1668, '');
INSERT INTO 'tune' VALUES (1814, NULL, '2014-08-11 22:29:47.121455+00', 'Wife She Brewed It, The', 9999, '');
INSERT INTO 'tune' VALUES (12973, '2014-08-19 07:15:42.421424+00', '2014-08-19 07:15:42.421424+00', 'To Mary in Heaven', 9999, 'Lyrics by Robert Burns.');
INSERT INTO 'tune' VALUES (12974, '2014-08-19 07:18:11.404101+00', '2014-08-19 07:18:11.404101+00', 'Wee Toon Clark, The', 9999, '');
INSERT INTO 'tune' VALUES (12975, '2014-08-19 07:20:20.592996+00', '2014-08-19 07:20:20.592996+00', 'Heilan'' Chorus, The', 9999, '');
INSERT INTO 'tune' VALUES (12976, '2014-08-19 07:27:47.503751+00', '2014-08-19 07:27:47.503751+00', 'God Bless the Prince of Wales', 10983, 'Composed in 1862 on the occasion of the wedding of the future Edward VII to Alexandra of Denmark. See <<http://en.wikipedia.org/wiki/God_Bless_the_Prince_of_Wales|Wikipedia>> entry for lyrics.');
INSERT INTO 'tune' VALUES (12977, '2014-08-19 07:29:50.959919+00', '2014-08-19 07:29:50.959919+00', 'Aghalee Heroes', 9999, 'See <<http://en.wikipedia.org/wiki/Aghalee|this Wikipedia page>> for background.');
INSERT INTO 'tune' VALUES (12978, '2014-08-19 07:30:33.945349+00', '2014-08-19 07:30:33.945349+00', 'Lily O'', The', 9999, '');
INSERT INTO 'tune' VALUES (12979, '2014-08-19 07:34:11.531735+00', '2014-08-19 07:34:11.531735+00', 'Columbia, The Gem of the Ocean', 10984, '');
INSERT INTO 'tune' VALUES (833, NULL, '2014-08-19 07:49:23.962365+00', 'Kafoozalum', 9999, '');
INSERT INTO 'tune' VALUES (1832, NULL, '2014-08-19 07:55:21.530582+00', 'Willie''s gaen tae Melville Castle', 9999, '');
INSERT INTO 'tune' VALUES (12981, '2014-08-19 07:58:37.784413+00', '2014-08-19 07:58:37.784413+00', 'Doon in the Wee Room', 9999, 'Lyrics by Daniel McLaughlin.');
INSERT INTO 'tune' VALUES (12982, '2014-08-19 08:02:50.408913+00', '2014-08-19 08:02:50.408913+00', 'Highland Lad, A', 9999, 'Lyrics by Robert Burns.');
INSERT INTO 'tune' VALUES (1066, NULL, '2014-08-19 08:04:03.447751+00', 'Man''s a Man for A'' That, A', 9999, '');
INSERT INTO 'tune' VALUES (12983, '2014-08-19 08:30:10.529359+00', '2014-08-19 08:30:10.529359+00', 'It''s a Fine Thing to Sing', 1663, '');
INSERT INTO 'tune' VALUES (12984, '2014-08-19 08:32:26.315653+00', '2014-08-19 08:32:26.315653+00', 'Fou the Noo', 1663, '');
INSERT INTO 'tune' VALUES (12985, '2014-08-19 08:36:24.705351+00', '2014-08-19 08:36:24.705351+00', 'Highland Mary', 9999, '');
INSERT INTO 'tune' VALUES (12935, '2014-05-09 23:05:42.297745+00', '2015-09-05 21:12:17.236663+00', 'Grandfather''s Pet', 9999, '');
INSERT INTO 'tune' VALUES (12939, '2014-05-09 23:58:03.597125+00', '2015-09-05 21:13:25.350504+00', 'Laird Brown''s Strathspey', 2054, '');
INSERT INTO 'tune' VALUES (12936, '2014-05-09 23:08:12.260503+00', '2015-09-05 21:13:50.80425+00', 'Lilibet''s Strathspey', 2965, '');
INSERT INTO 'tune' VALUES (12938, '2014-05-09 23:57:01.152748+00', '2015-09-05 21:23:20.075223+00', 'Tigh''n Duin', 9999, '');
INSERT INTO 'tune' VALUES (12945, '2014-05-10 00:14:44.014498+00', '2015-09-05 21:23:29.952615+00', 'Lass O''Patties Mill, The', 9999, '');
INSERT INTO 'tune' VALUES (12937, '2014-05-09 23:47:58.906835+00', '2015-09-05 21:23:42.430825+00', 'Duffers'' Reel, The', 2054, '');
INSERT INTO 'tune' VALUES (12196, '2012-07-22 13:52:11.340135+00', '2018-04-07 23:31:37.505886+00', 'Strathspey in Cyberspace', 3179, '');
INSERT INTO 'tune' VALUES (13650, '2017-10-10 12:29:51.485303+00', '2018-04-08 10:25:16.956393+00', 'Urisa''s Strathspey', 3179, 'For my friend, Urisa');
INSERT INTO 'tune' VALUES (361, NULL, '2019-03-11 10:30:23.968219+00', 'Dagmar''s Fancy', 228, '');
INSERT INTO 'tune' VALUES (12952, '2014-06-23 09:43:32.45568+00', '2019-03-11 10:24:27.1687+00', 'Daphne Scobie', 228, '');
INSERT INTO 'tune' VALUES (2728, NULL, '2014-08-19 08:37:31.151371+00', 'When the King Comes Over the Water', 9999, '');
INSERT INTO 'tune' VALUES (730, NULL, '2014-08-19 08:46:40.605766+00', 'I Lo''e nae a Laddie but Ane', 9999, '');
INSERT INTO 'tune' VALUES (624, NULL, '2014-08-19 08:50:29.571303+00', 'Green Grow the Rashes', 9999, '');
INSERT INTO 'tune' VALUES (4331, NULL, '2014-08-19 08:53:44.185396+00', 'My Big Kilmarnock Bunnet', 9999, '');
INSERT INTO 'tune' VALUES (2789, NULL, '2014-08-19 08:55:04.282023+00', 'Reason Noo'' I Wear the Kilt, The', 1664, '');
INSERT INTO 'tune' VALUES (12986, '2014-08-19 09:04:53.032542+00', '2014-08-19 09:04:53.032542+00', 'Jelly Piece Song, The', 10986, '');
INSERT INTO 'tune' VALUES (12987, '2014-08-19 09:09:40.603775+00', '2014-08-19 09:09:40.603775+00', 'O'' Whistle and I''ll Come To You', 2164, 'Lyrics by Robert Burns.');
INSERT INTO 'tune' VALUES (12988, '2014-08-19 09:13:00.083588+00', '2014-08-19 09:13:00.083588+00', 'Dolly''s Braes', 10987, '');
INSERT INTO 'tune' VALUES (12990, '2014-08-23 09:44:43.837832+00', '2014-08-23 09:44:43.837832+00', 'Reznicks'' Rant, The', 10432, '');
INSERT INTO 'tune' VALUES (7844, NULL, '2014-08-24 13:23:37.277588+00', 'Bugle Call Two-step, The', 1567, '');
INSERT INTO 'tune' VALUES (3267, NULL, '2014-08-24 15:39:48.952541+00', 'Misses Gordon of Rafford, The', 1930, '');
INSERT INTO 'tune' VALUES (4854, NULL, '2014-08-24 15:45:39.770908+00', 'Mrs Gordon of Rafford', 1930, 'Title should be: The Misses Gorden of Rafford');
INSERT INTO 'tune' VALUES (12991, '2014-08-26 16:50:07.34914+00', '2014-08-26 16:50:07.34914+00', 'Seafarer, The', 3620, '');
INSERT INTO 'tune' VALUES (12997, '2014-09-16 08:37:46.887751+00', '2014-09-16 08:37:46.887751+00', 'Miss Grace Bowie', 1598, '');
INSERT INTO 'tune' VALUES (12998, '2014-09-16 09:35:08.221304+00', '2014-09-16 09:35:08.221304+00', 'Nell MacMillan of Balmaha', 10198, 'The reference on Ian Muir''s ”SCD Vol. 3” gives “D McCallum”. Whether this is actually Duncan McCallum should be verified.

#CHECKME');
INSERT INTO 'tune' VALUES (2297, NULL, '2014-09-16 09:41:19.642977+00', 'Iain MacPhail''s Compliments to the Late Gordon Jamieson', 1527, '');
INSERT INTO 'tune' VALUES (128, NULL, '2014-09-16 14:49:57.815176+00', 'Blooms of Bon Accord, The', 1512, 'This tune is the same as “Blooms of Bon Accord” – see J. Scott Skinner,

_The Scottish Violinist_, p.32, where it is called “Cockers Roses”.



Cockers Roses (without the apostrophe) is apparently a gardening company

of considerable standing in Aberdeen. According to the company''s web

site (http://www.roses.uk.com/history.cfm) it was established in 1840,

so it is reasonable to assume that Skinner, who came from the area, was

familiar with it.');
INSERT INTO 'tune' VALUES (12999, '2014-09-29 13:47:34.697361+00', '2014-09-29 13:47:34.697361+00', 'Sarah and John', 2197, '');
INSERT INTO 'tune' VALUES (13000, '2014-10-01 23:45:43.629328+00', '2014-10-01 23:45:43.629328+00', 'Governor''s House', 1502, '');
INSERT INTO 'tune' VALUES (1195, NULL, '2014-10-02 00:04:05.922637+00', 'Miss Jane Douglas', 1519, 'The tunes "Miss Douglas''s Strathspey", "Miss Douglas" and "Miss Ann Douglas" are possibly identical.');
INSERT INTO 'tune' VALUES (13002, '2014-10-02 00:46:42.930951+00', '2014-10-02 00:46:42.930951+00', 'Alastair Wood''s Compliments to Stanley Wilkie', 3452, '');
INSERT INTO 'tune' VALUES (13003, '2014-10-02 00:48:08.986338+00', '2014-10-02 00:48:08.986338+00', 'Miss Jean Tully of Fochabers', 1402, '');
INSERT INTO 'tune' VALUES (7537, NULL, '2014-11-01 00:42:22.912968+00', 'Islay Ranters'' Reel, The', 2661, '');
INSERT INTO 'tune' VALUES (3132, NULL, '2014-11-18 00:35:37.343189+00', 'Captain Peterson of Melby', 1535, '');
INSERT INTO 'tune' VALUES (13004, '2014-10-02 00:48:50.634847+00', '2014-10-02 00:48:50.634847+00', 'Elaine Davies of Isleworth', 11014, '');
INSERT INTO 'tune' VALUES (13005, '2014-10-02 00:50:17.894845+00', '2014-10-02 00:50:17.894845+00', 'John Renton''s "Rolls"', 1402, '');
INSERT INTO 'tune' VALUES (13006, '2014-10-02 00:52:09.880151+00', '2014-10-02 00:52:09.880151+00', 'Pink Triangle, The', 11016, '');
INSERT INTO 'tune' VALUES (13007, '2014-10-02 00:57:48.381322+00', '2014-10-02 00:57:48.381322+00', '2014 Games, The', 1938, '');
INSERT INTO 'tune' VALUES (13008, '2014-10-02 00:58:47.635914+00', '2014-10-02 00:58:47.635914+00', 'Bob Grant''s Reel', 2743, '');
INSERT INTO 'tune' VALUES (5855, NULL, '2014-10-02 01:23:44.724615+00', 'Miss Douglas''s Strathspey', 1519, 'The tunes "Miss Douglas''s Strathspey", "Miss Douglas" and "Miss Ann Douglas" are possibly identical.');
INSERT INTO 'tune' VALUES (13009, '2014-10-04 01:21:13.338408+00', '2014-10-04 01:21:13.338408+00', 'Irish Girl', 9999, '');
INSERT INTO 'tune' VALUES (13010, '2014-10-04 02:56:05.891499+00', '2014-10-04 02:56:05.891499+00', 'Mull and Back', 1938, '');
INSERT INTO 'tune' VALUES (13011, '2014-10-04 02:57:53.324429+00', '2014-10-04 02:57:53.324429+00', 'Mr James Trotter', 9999, '');
INSERT INTO 'tune' VALUES (1373, NULL, '2022-12-17 21:19:22.632042+00', 'Low Down in the Broom', 9999, 'Robert Burns'' poem "A Red, Red Rose" aka "(Oh) My Love is like a Red, Red Rose" is sung to this tune.');
INSERT INTO 'tune' VALUES (12929, '2014-05-09 21:43:44.552444+00', '2022-12-19 19:39:31.682815+00', 'Farmer''s Barn Dance, The', 2257, '');
INSERT INTO 'tune' VALUES (13012, '2014-10-04 03:06:52.578986+00', '2014-10-04 03:06:52.578986+00', 'Caerlaverock Jig, The', 1531, '');
INSERT INTO 'tune' VALUES (13013, '2014-10-04 03:07:31.202265+00', '2014-10-04 03:07:31.202265+00', 'Jim Anderson''s Delight', 1531, '');
INSERT INTO 'tune' VALUES (13014, '2014-10-04 03:16:10.957782+00', '2014-10-04 03:16:10.957782+00', 'Bobby Colgan''s Delight', 1554, '');
INSERT INTO 'tune' VALUES (13015, '2014-10-04 03:17:02.191054+00', '2014-10-04 03:17:02.191054+00', 'Bobby Colgan', 3058, '');
INSERT INTO 'tune' VALUES (13016, '2014-10-04 03:20:13.357933+00', '2014-10-04 03:20:13.357933+00', 'Mr H G Abel''s Fancy', 1652, '');
INSERT INTO 'tune' VALUES (13035, '2014-11-14 10:01:45.730831+00', '2014-11-14 10:01:45.730831+00', 'Scarborough Castle', 1508, '');
INSERT INTO 'tune' VALUES (13017, '2014-10-06 22:47:06.00064+00', '2014-10-06 23:24:22.008463+00', 'Ann Prior', 2197, 'The tune is published with the dance "A Dance for Ann" at the <<http://bridportscottishdancers.org.uk/pages/localdances.htm|local dances>> page of the <<http://bridportscottishdancers.org.uk|Bridport Scottish Dancers>>.');
INSERT INTO 'tune' VALUES (13018, '2014-10-06 23:00:21.483208+00', '2014-10-07 07:47:41.411646+00', 'Tony Meadley''s Bus Pass', 11022, '

');
INSERT INTO 'tune' VALUES (3120, NULL, '2014-11-01 00:26:54.283369+00', 'Stormont Lads', 9999, '');
INSERT INTO 'tune' VALUES (2055, NULL, '2014-11-01 00:35:20.327719+00', 'Colonel Hamilton''s Delight', 2382, '');
INSERT INTO 'tune' VALUES (6764, NULL, '2014-11-01 02:21:38.408262+00', 'Tullochgorum', 9999, 'RSCDS Book 8 states "Bremner''s Reels 1757 and earlier" as the source.');
INSERT INTO 'tune' VALUES (1732, NULL, '2014-11-01 02:46:07.823979+00', 'Ton, The', 1458, 'The CD for RSCDS Book 8 states James Aird as the composer.');
INSERT INTO 'tune' VALUES (13019, '2014-11-02 21:07:08.565936+00', '2014-11-02 21:09:10.64609+00', 'Highland Shortbread', 3436, '');
INSERT INTO 'tune' VALUES (13020, '2014-11-02 21:17:13.361302+00', '2014-11-02 21:17:13.361302+00', 'Mishap at the 13th Hole', 1502, '');
INSERT INTO 'tune' VALUES (13023, '2014-11-02 21:35:19.682772+00', '2014-11-02 21:35:19.682772+00', 'Cortes Gardens', 1512, '');
INSERT INTO 'tune' VALUES (13036, '2014-11-14 10:03:25.309026+00', '2014-11-14 10:03:25.309026+00', 'Me only Jo an'' Dearie, O', 9999, '');
INSERT INTO 'tune' VALUES (13025, '2014-11-02 21:48:50.883987+00', '2014-11-02 21:48:50.883987+00', 'RossKay Gold, The', 3614, '');
INSERT INTO 'tune' VALUES (7596, NULL, '2014-11-05 16:18:13.324165+00', 'Tax-Man''s Gone, The', 2692, '');
INSERT INTO 'tune' VALUES (7268, NULL, '2014-11-06 17:20:06.199644+00', '93rd at Modder River', 10686, 'The composer of the tune, Robert Meldrum, was Pipe Major of the 93rd Highlanders in the 1870ies.');
INSERT INTO 'tune' VALUES (13026, '2014-11-06 17:21:43.363631+00', '2014-11-06 17:21:43.363631+00', 'Miss Katie Ness of Kinnyside', 10686, '');
INSERT INTO 'tune' VALUES (13027, '2014-11-06 17:22:16.590728+00', '2014-11-06 17:22:16.590728+00', 'Lonach Lasses', 10686, '');
INSERT INTO 'tune' VALUES (13028, '2014-11-06 17:22:44.981804+00', '2014-11-06 17:22:44.981804+00', 'Lillie Long-Wade''s Welcome to Inverness', 10686, '');
INSERT INTO 'tune' VALUES (13029, '2014-11-06 17:23:31.955459+00', '2014-11-06 17:23:31.955459+00', 'Glencuil Cottage', 10686, '');
INSERT INTO 'tune' VALUES (13030, '2014-11-06 17:24:00.794685+00', '2014-11-06 17:24:00.794685+00', 'Corriechoillie''s Leaving Lochaber', 10686, '');
INSERT INTO 'tune' VALUES (13031, '2014-11-06 23:28:41.580639+00', '2014-11-06 23:28:41.580639+00', 'Bruntley Reel, The', 2843, '');
INSERT INTO 'tune' VALUES (13645, '2017-10-10 12:25:15.889739+00', '2018-04-09 00:07:37.481143+00', 'Blow the South-Easter', 3179, 'In Betty''s Bay the year 2009 was blown in by a fresh South-Easterly wind');
INSERT INTO 'tune' VALUES (8360, NULL, '2014-11-08 21:50:39.800222+00', 'These are my Mountains', 11031, 'Jimmy Copeland composed the song in 1966 for the song competition.');
INSERT INTO 'tune' VALUES (13111, '2015-02-26 13:15:26.372556+00', '2015-02-26 13:15:26.372556+00', 'L J Ginger', 1621, '');
INSERT INTO 'tune' VALUES (13112, '2015-02-26 14:21:34.008394+00', '2015-02-26 14:21:34.008394+00', 'Silver Castle Reel, The', 1951, '');
INSERT INTO 'tune' VALUES (13032, '2014-11-06 23:30:24.52263+00', '2015-09-05 21:12:52.51072+00', 'Ian''s Reel', 2843, 'This tune was composed by John Crawford for his friend and bandleader Ian McCallum.');
INSERT INTO 'tune' VALUES (12992, '2014-09-10 23:51:12.374308+00', '2016-09-09 09:24:19.292043+00', 'Victoria Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (13033, '2014-11-13 21:02:00.595312+00', '2016-09-09 09:25:24.855978+00', 'Tattie Cellar, The', 1501, '');
INSERT INTO 'tune' VALUES (12994, '2014-09-10 23:52:27.834169+00', '2016-09-09 09:28:01.250143+00', 'Constitution Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (11286, '2010-09-16 22:00:00+00', '2017-09-04 21:32:59.4674+00', 'Do-Re-Mi', 10229, 'From *The Sound of Music*.');
INSERT INTO 'tune' VALUES (13905, '2018-06-09 22:13:40.283076+00', '2018-06-09 22:13:40.283076+00', 'Mr Mervyn Short', 1502, '');
INSERT INTO 'tune' VALUES (13910, '2018-06-09 22:42:58.361651+00', '2018-06-09 22:43:34.270882+00', 'Delusion of Adequacy', 3436, '');
INSERT INTO 'tune' VALUES (13909, '2018-06-09 22:41:29.012384+00', '2018-06-09 22:44:23.770942+00', 'Druimnich', 3436, '');
INSERT INTO 'tune' VALUES (13021, '2014-11-02 21:22:12.600823+00', '2018-10-30 17:21:25.940043+00', 'Maj. Clark Cavin USMC', 3614, '');
INSERT INTO 'tune' VALUES (13022, '2014-11-02 21:26:03.428657+00', '2018-10-30 17:21:50.254174+00', 'Islay Rant', 2661, '');
INSERT INTO 'tune' VALUES (403, NULL, '2014-11-08 23:35:38.035816+00', 'Doon the Burn, Davie Lad', 2642, 'According to The Ottawa Journal (Ottawa, Canada) from Tuesday, December 1, 1925, <<http://www.newspapers.com/newspage/46536513/|page 15>> the tune was composed by James Hook.');
INSERT INTO 'tune' VALUES (3111, NULL, '2014-11-09 00:04:40.177537+00', 'Fiddler play the Light Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (7961, NULL, '2014-11-09 00:15:04.939863+00', 'Lady Catherine Pelham''s', 1519, '');
INSERT INTO 'tune' VALUES (435, NULL, '2014-11-11 01:38:42.984128+00', 'Duchess of Buccleuch, The', 1516, 'Pronounced »Buck-LOO«.



This tune is erroneously credited to Niel Gow in RSCDS book 26 and (probably taking it from there) »Originally Ours«. It does appear in one of William Marshall''s tune collections. Unlike the Gows, William

Marshall, a contemporary of Niel''s, was not especially known for pinching other people''s tunes and passing them off as his own. (One wonders why Niel Gow stooped to such chicanery as he was quite capable of coming up with reasonable tunes all on his own.)



The »Gow Collection« edited by Richard Carlin has a tune called »The Duchess of Buccleuch« which is different from this one and credited to *Nathaniel* Gow (not Niel).');
INSERT INTO 'tune' VALUES (13037, '2014-11-14 10:06:48.594869+00', '2014-11-14 10:06:48.594869+00', 'Kingdom, The', 1501, '');
INSERT INTO 'tune' VALUES (13039, '2014-11-14 10:08:16.234589+00', '2014-11-14 10:08:16.234589+00', 'High Pressure', 1501, '');
INSERT INTO 'tune' VALUES (13040, '2014-11-14 10:08:49.307299+00', '2014-11-14 10:08:49.307299+00', 'Ali''s Rusty Nails', 1501, '');
INSERT INTO 'tune' VALUES (13041, '2014-11-14 10:11:42.130896+00', '2014-11-14 10:11:42.130896+00', 'Garey Cottage', 9999, '');
INSERT INTO 'tune' VALUES (13042, '2014-11-14 10:15:06.301838+00', '2014-11-14 10:15:06.301838+00', 'Crowbutts Fire', 3109, '');
INSERT INTO 'tune' VALUES (13043, '2014-11-14 10:34:05.962967+00', '2014-11-14 10:34:05.962967+00', 'Drumdelgie', 9999, '');
INSERT INTO 'tune' VALUES (7293, NULL, '2014-11-17 00:59:12.353932+00', 'George Carrick (Fiddler)', 1593, '');
INSERT INTO 'tune' VALUES (9854, NULL, '2014-11-17 01:10:07.064265+00', 'Gordon R Kears', 1601, '');
INSERT INTO 'tune' VALUES (12664, '2013-10-31 15:07:35.620959+00', '2018-04-09 00:15:25.481448+00', 'City of Christchurch, The', 3179, '');
INSERT INTO 'tune' VALUES (75, NULL, '2014-11-22 22:20:56.623807+00', 'Awa'', Whigs, Awa''', 9998, '');
INSERT INTO 'tune' VALUES (7002, NULL, '2014-11-22 22:23:24.295125+00', 'Buchan Ploo''man', 2511, '');
INSERT INTO 'tune' VALUES (118, NULL, '2014-12-08 22:03:56.098278+00', 'Birds at the Fairy Fulling', 9999, 'traditional tune from St Kilda');
INSERT INTO 'tune' VALUES (12898, '2014-03-26 15:41:30.608091+00', '2014-12-09 00:58:33.284663+00', 'Marjory Duffields Jig', 1679, '');
INSERT INTO 'tune' VALUES (1204, NULL, '2014-12-23 15:55:09.621515+00', 'Miss Jessie Dalrymple''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (13044, '2015-01-01 17:41:39.123287+00', '2015-01-01 17:41:39.123287+00', 'Drew & Eleanor', 1679, '');
INSERT INTO 'tune' VALUES (13095, '2015-02-05 13:11:03.72617+00', '2015-02-05 13:11:03.72617+00', 'Chouxplattler', 11067, '');
INSERT INTO 'tune' VALUES (13046, '2015-01-08 14:53:15.851991+00', '2015-01-08 14:53:15.851991+00', 'Nightingale Castle', 10587, '');
INSERT INTO 'tune' VALUES (13047, '2015-01-08 14:57:55.745783+00', '2015-01-08 14:57:55.745783+00', 'Miss Rosie''s Favourite', 10587, '');
INSERT INTO 'tune' VALUES (13048, '2015-01-08 15:11:57.072814+00', '2015-01-08 15:11:57.072814+00', 'Brian''s Birthday Reel', 11039, '');
INSERT INTO 'tune' VALUES (13045, '2015-01-08 14:45:33.768059+00', '2015-01-08 15:12:40.54837+00', 'Committee Strathspey, The', 11040, '');
INSERT INTO 'tune' VALUES (13049, '2015-01-08 15:19:45.94305+00', '2015-01-08 15:19:45.94305+00', 'Lissa''s Strathspey', 11039, '');
INSERT INTO 'tune' VALUES (13050, '2015-01-08 15:26:31.77913+00', '2015-01-08 15:26:31.77913+00', 'Reel Life', 11039, '');
INSERT INTO 'tune' VALUES (13051, '2015-01-08 15:33:58.430536+00', '2015-01-08 15:33:58.430536+00', 'Shortest Day, The', 10587, '');
INSERT INTO 'tune' VALUES (13052, '2015-01-08 15:40:57.126932+00', '2015-01-08 15:40:57.126932+00', 'Waltz for Stacey and Brian', 11039, '');
INSERT INTO 'tune' VALUES (13053, '2015-01-11 18:41:12.683984+00', '2015-01-11 18:41:12.683984+00', 'Day We Went to Arran, The', 11043, '');
INSERT INTO 'tune' VALUES (13054, '2015-01-11 19:07:34.682809+00', '2015-01-11 19:07:34.682809+00', 'Stornoway Bay', 1910, '');
INSERT INTO 'tune' VALUES (13055, '2015-01-18 12:22:13.041+00', '2015-01-18 12:22:13.041+00', 'Lars Jarenfors', 1582, '');
INSERT INTO 'tune' VALUES (13056, '2015-01-18 12:29:47.298388+00', '2015-01-18 12:29:47.298388+00', 'Wayward Sea, The', 1582, '');
INSERT INTO 'tune' VALUES (13057, '2015-01-18 12:44:35.292717+00', '2015-01-18 12:57:53.239892+00', 'Budapest Bus, The', 1582, '');
INSERT INTO 'tune' VALUES (13058, '2015-01-18 12:58:30.158007+00', '2015-01-18 12:58:30.158007+00', 'Jim''s Reel', 1582, '');
INSERT INTO 'tune' VALUES (13059, '2015-01-18 13:06:07.291236+00', '2015-01-18 13:06:07.291236+00', 'Clan Gathering, The', 1582, '');
INSERT INTO 'tune' VALUES (13060, '2015-01-18 13:13:22.298882+00', '2015-01-18 13:13:22.298882+00', 'Ice Cream and Chopsticks', 1582, '');
INSERT INTO 'tune' VALUES (13061, '2015-01-18 13:31:59.406555+00', '2015-01-18 13:31:59.406555+00', 'Tune for Lauren, A', 1582, '');
INSERT INTO 'tune' VALUES (13062, '2015-01-18 13:37:08.854196+00', '2015-01-18 13:37:08.854196+00', 'Linda''s Jig', 1582, '');
INSERT INTO 'tune' VALUES (13063, '2015-01-18 13:44:36.816831+00', '2015-01-18 13:44:36.816831+00', 'Margaret Martin of North Berwick', 1582, '');
INSERT INTO 'tune' VALUES (13064, '2015-01-18 13:51:01.798266+00', '2015-01-18 13:51:01.798266+00', 'Tune for Matthew, A', 1582, '');
INSERT INTO 'tune' VALUES (13065, '2015-01-18 13:58:47.749687+00', '2015-01-18 13:58:47.749687+00', 'William & Shellagh Whyte', 1582, '');
INSERT INTO 'tune' VALUES (13066, '2015-01-18 14:03:14.183399+00', '2015-01-18 14:03:14.183399+00', 'Nadine''s Celebration', 1582, '');
INSERT INTO 'tune' VALUES (13068, '2015-01-18 14:12:41.774541+00', '2015-01-18 14:12:41.774541+00', 'Nigel Nicholson', 1582, '');
INSERT INTO 'tune' VALUES (13069, '2015-01-18 14:39:09.853181+00', '2015-01-18 14:39:09.853181+00', 'Famille Orgeret, La', 1582, '');
INSERT INTO 'tune' VALUES (13070, '2015-01-18 14:39:52.367297+00', '2015-01-18 14:39:52.367297+00', 'Reelin'' in Gleize', 1582, '');
INSERT INTO 'tune' VALUES (13071, '2015-01-18 15:05:41.18995+00', '2015-01-18 15:06:30.413325+00', 'Brodie Castle', 1582, '');
INSERT INTO 'tune' VALUES (13072, '2015-01-18 15:13:27.871904+00', '2015-01-18 15:13:27.871904+00', 'Strath of the Spey, The', 1582, '');
INSERT INTO 'tune' VALUES (13073, '2015-01-18 15:37:40.169383+00', '2015-01-18 15:37:40.169383+00', 'Delphine Garden', 11046, '');
INSERT INTO 'tune' VALUES (13074, '2015-01-18 15:44:19.36666+00', '2015-01-18 15:44:19.36666+00', 'Easy Way, The', 1582, '');
INSERT INTO 'tune' VALUES (13075, '2015-01-18 15:52:16.821461+00', '2015-01-18 15:52:16.821461+00', 'Southward Bound', 1582, '');
INSERT INTO 'tune' VALUES (13076, '2015-01-18 16:00:53.814734+00', '2015-01-18 16:00:53.814734+00', 'Stuck in the Broomielaw', 1582, '');
INSERT INTO 'tune' VALUES (13078, '2015-01-18 16:34:56.73276+00', '2015-01-18 16:34:56.73276+00', 'Valerie''s Strathspey', 1582, '');
INSERT INTO 'tune' VALUES (13079, '2015-01-18 16:35:57.438568+00', '2015-01-18 16:35:57.438568+00', 'For Dodi and Diethe', 1582, '');
INSERT INTO 'tune' VALUES (13077, '2015-01-18 16:05:23.463835+00', '2015-01-18 16:48:42.405291+00', 'March in Pitlochry', 1582, '');
INSERT INTO 'tune' VALUES (13080, '2015-01-18 16:50:10.192924+00', '2015-01-18 16:50:10.192924+00', 'Mr Jack Stalker', 1582, '');
INSERT INTO 'tune' VALUES (13081, '2015-01-18 16:52:04.110625+00', '2015-01-18 16:52:04.110625+00', 'Nadine''s Two-Step', 1582, '');
INSERT INTO 'tune' VALUES (13082, '2015-01-18 16:53:32.353617+00', '2015-01-18 16:53:32.353617+00', 'Billie McMillan''s Two-Step', 1582, '');
INSERT INTO 'tune' VALUES (13083, '2015-01-29 13:10:43.804163+00', '2015-01-29 13:11:00.83125+00', 'Jade-Bath Two Step, The', 11050, '');
INSERT INTO 'tune' VALUES (13084, '2015-01-31 17:49:25.675321+00', '2015-01-31 17:49:25.675321+00', 'Mrs Valerie Griffiths', 1551, '');
INSERT INTO 'tune' VALUES (13085, '2015-02-01 14:53:33.791043+00', '2015-02-01 14:53:33.791043+00', 'Sissy''s Reel', 2965, '');
INSERT INTO 'tune' VALUES (13086, '2015-02-03 16:58:48.700001+00', '2015-02-03 16:58:48.700001+00', 'Garden Country, The', 1430, '');
INSERT INTO 'tune' VALUES (13087, '2015-02-03 17:08:57.332561+00', '2015-02-03 17:08:57.332561+00', 'Gullane Bay', 2667, '');
INSERT INTO 'tune' VALUES (13088, '2015-02-03 17:10:09.367463+00', '2015-02-03 17:10:09.367463+00', 'Monreith Bay', 2667, '');
INSERT INTO 'tune' VALUES (13089, '2015-02-03 17:15:19.775774+00', '2015-02-03 17:15:19.775774+00', 'Memories of Hugh Roberts', 1679, '');
INSERT INTO 'tune' VALUES (13090, '2015-02-03 17:23:19.078244+00', '2015-02-03 17:23:39.238973+00', 'Diving Gannets', 11060, '');
INSERT INTO 'tune' VALUES (13091, '2015-02-03 17:38:52.784021+00', '2015-02-03 17:38:52.784021+00', 'Merchiston', 3442, '');
INSERT INTO 'tune' VALUES (13092, '2015-02-03 18:08:44.932287+00', '2015-02-03 18:08:44.932287+00', 'Mrs June Scott', 1582, '');
INSERT INTO 'tune' VALUES (13093, '2015-02-03 18:17:24.363804+00', '2015-02-03 18:17:24.363804+00', 'Nora Pride', 1938, '');
INSERT INTO 'tune' VALUES (13094, '2015-02-05 12:56:09.476293+00', '2015-02-05 12:56:09.476293+00', 'Upman Park Road', 1502, '');
INSERT INTO 'tune' VALUES (13097, '2015-02-05 13:24:35.381124+00', '2015-02-05 13:24:35.381124+00', 'Vienna Express', 11067, '');
INSERT INTO 'tune' VALUES (13098, '2015-02-06 13:30:22.451514+00', '2015-02-06 13:30:22.451514+00', 'Chasing the Eclipse', 1502, '');
INSERT INTO 'tune' VALUES (13099, '2015-02-08 16:51:47.940319+00', '2015-02-08 16:51:47.940319+00', 'Bonnie Clyde', 1502, '');
INSERT INTO 'tune' VALUES (13100, '2015-02-08 17:05:57.495612+00', '2015-02-08 17:05:57.495612+00', 'Mrs Stella Fogg', 1502, '');
INSERT INTO 'tune' VALUES (13101, '2015-02-08 17:17:45.091006+00', '2015-02-08 17:17:45.091006+00', 'Gourock Reel, The', 1502, '');
INSERT INTO 'tune' VALUES (13102, '2015-02-09 14:48:30.998285+00', '2015-02-09 14:48:30.998285+00', 'Crowded Hall, The', 1643, '');
INSERT INTO 'tune' VALUES (13103, '2015-02-14 17:48:03.514904+00', '2015-02-14 17:48:03.514904+00', 'Port Singil', 11080, '');
INSERT INTO 'tune' VALUES (5653, NULL, '2015-02-17 11:40:49.194548+00', 'Susie Petrov''s Compliments to Prokofiev', 1054, '');
INSERT INTO 'tune' VALUES (13105, '2015-02-20 15:02:53.367042+00', '2015-02-20 15:02:53.367042+00', 'Golden Ring, The', 2085, '');
INSERT INTO 'tune' VALUES (13106, '2015-02-21 13:12:09.473462+00', '2015-02-21 13:12:09.473462+00', 'Dub Fortenberry the Dancer', 3614, '');
INSERT INTO 'tune' VALUES (13107, '2015-02-21 14:02:46.475255+00', '2015-02-21 14:02:46.475255+00', 'Marvelous Margaret', 10813, 'devised for The Windsor Medley by Cheryl Dunin

16J/16S/16R

');
INSERT INTO 'tune' VALUES (13108, '2015-02-22 23:21:08.161609+00', '2015-02-22 23:21:08.161609+00', 'Stephen''s Web', 1631, '');
INSERT INTO 'tune' VALUES (13109, '2015-02-24 14:39:21.475518+00', '2015-02-24 14:39:21.475518+00', 'Gleneagles Gold', 1502, '');
INSERT INTO 'tune' VALUES (13110, '2015-02-24 14:50:46.005775+00', '2015-02-24 14:50:46.005775+00', 'VFO''s Compliments to Gleneagles on Their 50th Anniversary, The', 3612, '');
INSERT INTO 'tune' VALUES (13104, '2015-02-14 18:00:50.697436+00', '2017-11-02 17:16:06.0905+00', 'Tripping up the High Street', 1582, '');
INSERT INTO 'tune' VALUES (13067, '2015-01-18 14:05:35.271732+00', '2017-11-02 17:32:42.528854+00', 'Lakeside Reel', 1582, '');
INSERT INTO 'tune' VALUES (13113, '2015-02-26 14:42:12.594744+00', '2015-02-26 14:42:12.594744+00', 'James and Elspeth Walker''s Strathspey', 11101, '');
INSERT INTO 'tune' VALUES (12647, '2013-10-29 01:50:49.481424+00', '2015-02-26 15:05:03.56838+00', 'Janet''s Cuppa', 3220, '');
INSERT INTO 'tune' VALUES (13114, '2015-02-27 10:20:00.772784+00', '2015-02-27 10:20:00.772784+00', 'Sanderson Reel, The', 11104, '');
INSERT INTO 'tune' VALUES (13115, '2015-02-27 10:42:19.179918+00', '2015-02-27 10:42:19.179918+00', 'Dean Tavern, The', 2744, '');
INSERT INTO 'tune' VALUES (13116, '2015-02-27 11:00:20.155188+00', '2015-02-27 11:00:20.155188+00', 'Mrs McKinven''s Strathspey', 2421, '');
INSERT INTO 'tune' VALUES (2675, NULL, '2015-02-27 11:28:18.351374+00', 'Mrs Ilene Cowan', 1585, '');
INSERT INTO 'tune' VALUES (13117, '2015-02-27 11:52:36.539096+00', '2015-02-27 11:52:36.539096+00', 'Trip to Ramsey', 2744, '');
INSERT INTO 'tune' VALUES (13118, '2015-02-27 12:04:49.56699+00', '2015-02-27 12:04:49.56699+00', 'Twa Meenit Hornpipe', 2744, '');
INSERT INTO 'tune' VALUES (13119, '2015-02-27 12:17:33.634883+00', '2015-02-27 12:17:33.634883+00', 'Valleys and Rivers of Ettrick and Yarrow', 3220, '');
INSERT INTO 'tune' VALUES (13120, '2015-02-27 12:42:37.060204+00', '2015-02-27 12:42:37.060204+00', 'Sundays at Gattonside', 11104, '');
INSERT INTO 'tune' VALUES (13121, '2015-02-27 12:49:45.535438+00', '2015-02-27 12:49:45.535438+00', 'Newcastleton Music Festival Silver Jubilee 1995', 1593, '');
INSERT INTO 'tune' VALUES (13122, '2015-02-27 12:59:50.755432+00', '2015-02-27 12:59:50.755432+00', 'Winding Road to Blainslie, The', 3398, '');
INSERT INTO 'tune' VALUES (11623, '2011-08-22 22:00:00+00', '2018-04-09 09:28:02.741722+00', 'Friends for Reel', 3179, '');
INSERT INTO 'tune' VALUES (3873, NULL, '2015-03-19 06:53:27.895685+00', 'Jack''s Fiddle', 1981, '');
INSERT INTO 'tune' VALUES (13123, '2015-03-24 11:28:26.137829+00', '2015-03-24 11:28:26.137829+00', 'Bill Morgan''s Fancy', 1898, '');
INSERT INTO 'tune' VALUES (312, NULL, '2015-03-24 11:57:26.418247+00', 'Come Let Us Dance and Sing', 9999, '');
INSERT INTO 'tune' VALUES (6047, NULL, '2015-03-24 12:10:10.047365+00', '72nd Highlanders Gathering, 1901', 2212, '');
INSERT INTO 'tune' VALUES (1967, NULL, '2015-03-24 12:21:35.523939+00', 'Camptown Races', 2293, '');
INSERT INTO 'tune' VALUES (2862, NULL, '2015-03-24 12:23:13.350362+00', 'So I''m off with the Good St Nicholas Boat', 1512, '');
INSERT INTO 'tune' VALUES (13124, '2015-03-24 12:25:28.667267+00', '2015-03-24 12:25:28.667267+00', 'Picheuchar Jig, The', 3615, '');
INSERT INTO 'tune' VALUES (6945, NULL, '2015-03-24 12:26:33.624675+00', 'Little Burnt Potato, The', 1698, '');
INSERT INTO 'tune' VALUES (2995, NULL, '2015-03-24 12:31:14.588981+00', 'Wind that Shakes the Piggery, The', 1522, '');
INSERT INTO 'tune' VALUES (13125, '2015-04-08 15:03:39.630255+00', '2015-04-08 15:03:39.630255+00', 'Bridesmen and Groomsmaids', 2801, '');
INSERT INTO 'tune' VALUES (13126, '2015-04-12 15:49:02.275952+00', '2015-04-12 15:49:02.275952+00', 'It''s Reel Life', 2801, '');
INSERT INTO 'tune' VALUES (13127, '2015-04-12 15:59:15.075556+00', '2015-04-12 15:59:15.075556+00', 'Tobias Hünger', 2801, '');
INSERT INTO 'tune' VALUES (13128, '2015-04-12 16:40:37.421553+00', '2015-04-12 16:40:37.421553+00', 'Fairy Pools of Skye, The', 2801, '');
INSERT INTO 'tune' VALUES (13129, '2015-04-20 13:19:23.963432+00', '2015-04-20 13:19:23.963432+00', 'Ward''s Brae', 9999, '');
INSERT INTO 'tune' VALUES (13906, '2018-06-09 22:22:12.923932+00', '2018-06-09 22:22:12.923932+00', 'Jerry Holland''s Tight Black Shirt', 1502, '');
INSERT INTO 'tune' VALUES (13130, '2015-04-20 13:26:14.622365+00', '2015-04-20 13:28:04.997122+00', 'Moss Park', 1590, '');
INSERT INTO 'tune' VALUES (13131, '2015-04-20 13:29:46.043641+00', '2015-04-20 13:29:46.043641+00', 'Ian Muir''s Compliments to Colin Dewar', 1590, '');
INSERT INTO 'tune' VALUES (6148, NULL, '2015-04-23 09:40:35.351222+00', 'Gall Ruadh', 11123, '');
INSERT INTO 'tune' VALUES (3915, NULL, '2015-04-23 09:41:41.401975+00', 'Highland Brigade at Tel-el-Kebir, The', 11124, '');
INSERT INTO 'tune' VALUES (13132, '2015-05-04 13:08:17.089082+00', '2015-05-04 13:08:17.089082+00', 'Evans Hornpipe', 9999, '');
INSERT INTO 'tune' VALUES (13133, '2015-05-06 13:33:45.815095+00', '2015-05-06 13:33:45.815095+00', 'Master Crowley''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (13134, '2015-05-14 09:22:29.082786+00', '2015-05-14 09:22:29.082786+00', 'Fat Mountain', 10523, '');
INSERT INTO 'tune' VALUES (2804, NULL, '2015-05-14 10:00:05.902694+00', 'Miss Thompson''s Reel', 9999, '');
INSERT INTO 'tune' VALUES (13135, '2015-05-31 14:05:45.062994+00', '2015-05-31 14:05:45.062994+00', 'Hurricane, The', 9999, '');
INSERT INTO 'tune' VALUES (13136, '2015-05-31 14:14:03.236106+00', '2015-05-31 14:14:03.236106+00', 'Hills of Kowloon, The', 9999, '');
INSERT INTO 'tune' VALUES (13137, '2015-06-02 11:51:10.350942+00', '2015-06-02 11:51:10.350942+00', 'Eileen''s Jig', 11137, '');
INSERT INTO 'tune' VALUES (13138, '2015-06-02 12:00:06.384839+00', '2015-06-02 12:00:06.384839+00', 'Broom o'' the Cowdenknowes, The', 165, '');
INSERT INTO 'tune' VALUES (9830, NULL, '2015-06-02 12:02:33.923568+00', 'Rosemount Reel', 1572, '');
INSERT INTO 'tune' VALUES (13139, '2015-06-02 13:12:05.826749+00', '2015-06-02 13:12:05.826749+00', 'Banchory Strathspey', 165, '');
INSERT INTO 'tune' VALUES (13140, '2015-06-02 13:17:03.996003+00', '2015-06-02 13:17:03.996003+00', 'Pot Still, The', 165, '');
INSERT INTO 'tune' VALUES (13141, '2015-06-02 13:41:29.402391+00', '2015-06-02 13:41:29.402391+00', 'Little Brown Jug', 11138, '');
INSERT INTO 'tune' VALUES (8496, NULL, '2015-06-02 13:43:47.286842+00', 'Come Landlord Fill the Flowing Bowl', 9999, '');
INSERT INTO 'tune' VALUES (13142, '2015-06-02 14:17:40.554906+00', '2015-06-02 14:17:40.554906+00', 'MacFarlane O'' the Sproats', 9999, '');
INSERT INTO 'tune' VALUES (13143, '2015-06-02 14:45:45.245955+00', '2015-06-02 14:45:45.245955+00', 'Kirkton Muir', 165, '');
INSERT INTO 'tune' VALUES (13144, '2015-06-12 08:46:12.984582+00', '2015-06-12 08:46:12.984582+00', 'Tutor, The', 3281, 'For <<ddp:Ron Wallace>>.');
INSERT INTO 'tune' VALUES (13145, '2015-06-19 10:42:38.509168+00', '2015-06-19 10:42:38.509168+00', 'Blackberry Festival Footrace, The', 11143, '');
INSERT INTO 'tune' VALUES (13146, '2015-06-19 10:46:08.063227+00', '2015-06-19 10:46:08.063227+00', 'Frank Gilruth', 1818, '');
INSERT INTO 'tune' VALUES (13147, '2015-06-19 10:46:54.718088+00', '2015-06-19 10:46:54.718088+00', 'Valley of the Moon Reel', 1782, '');
INSERT INTO 'tune' VALUES (13148, '2015-06-19 10:48:26.302828+00', '2015-06-19 10:48:26.302828+00', 'Taybank Shenanigans', 11144, '');
INSERT INTO 'tune' VALUES (13149, '2015-06-19 10:53:57.00451+00', '2015-06-19 10:53:57.00451+00', 'Champaign Jig Goes To Columbia, The', 9998, '');
INSERT INTO 'tune' VALUES (13150, '2015-06-19 10:58:52.908589+00', '2015-06-19 10:58:52.908589+00', 'Pat and Al''s Jig', 11145, '');
INSERT INTO 'tune' VALUES (13151, '2015-06-19 11:02:00.143548+00', '2015-06-19 11:02:00.143548+00', 'Dr. Stocker''s Hornpipe', 1575, '');
INSERT INTO 'tune' VALUES (13152, '2015-06-19 11:02:47.769178+00', '2015-06-19 11:02:47.769178+00', 'Double Diamond Celebration', 1575, '');
INSERT INTO 'tune' VALUES (3601, NULL, '2015-06-19 11:15:30.133758+00', 'Craigellachie Lasses, The', 1516, '');
INSERT INTO 'tune' VALUES (13153, '2015-06-19 11:37:13.217688+00', '2015-06-19 11:37:13.217688+00', 'Reel Beatrice', 9999, '');
INSERT INTO 'tune' VALUES (13154, '2015-06-19 11:40:40.767812+00', '2015-06-19 11:40:40.767812+00', 'Fleur de Mandragore', 11146, '');
INSERT INTO 'tune' VALUES (13155, '2015-06-19 11:43:23.820237+00', '2015-06-19 11:43:23.820237+00', 'Alberta Wild Rose Strathspey', 11147, '');
INSERT INTO 'tune' VALUES (2948, NULL, '2015-06-19 11:45:15.590105+00', 'MacAulays of Benbecula, The', 1557, '');
INSERT INTO 'tune' VALUES (13157, '2015-06-19 11:56:23.925911+00', '2015-06-19 11:56:23.925911+00', 'Linguist, The', 1878, '');
INSERT INTO 'tune' VALUES (13158, '2015-06-19 11:57:33.247813+00', '2015-06-19 11:57:33.247813+00', 'Time to Go', 11148, '');
INSERT INTO 'tune' VALUES (13159, '2015-07-07 13:30:11.369506+00', '2015-07-07 13:30:11.369506+00', 'Mousa Broch', 3383, '');
INSERT INTO 'tune' VALUES (13160, '2015-07-07 14:23:07.380872+00', '2015-07-07 14:23:07.380872+00', 'David''s Hornpipe', 11153, '');
INSERT INTO 'tune' VALUES (13161, '2015-07-07 15:14:48.396198+00', '2015-07-07 15:14:48.396198+00', 'Angel of the North', 11154, '');
INSERT INTO 'tune' VALUES (13162, '2015-07-07 15:32:55.665375+00', '2015-07-07 15:32:55.665375+00', 'Just One More', 3220, '');
INSERT INTO 'tune' VALUES (13163, '2015-07-07 16:04:28.282221+00', '2015-07-07 16:04:28.282221+00', 'Lincoln Imp, The', 1502, '');
INSERT INTO 'tune' VALUES (13164, '2015-07-07 16:24:39.149264+00', '2015-07-07 16:24:39.149264+00', 'Geneva Reel, The', 11151, '');
INSERT INTO 'tune' VALUES (13165, '2015-07-07 16:39:53.344033+00', '2015-07-07 16:39:53.344033+00', 'O''er the Border', 1582, '');
INSERT INTO 'tune' VALUES (3522, NULL, '2015-07-13 02:43:28.806648+00', 'Mrs Mary Prentice', 1652, 'In Drewry''s original leaflet for "By Candlelight" the tune is specified as "Mrs Mary Prentice" composed by Jim Macleod. ');
INSERT INTO 'tune' VALUES (13166, '2015-07-16 20:19:45.676563+00', '2015-07-16 20:19:45.676563+00', 'Magic of Music, The', 645, '');
INSERT INTO 'tune' VALUES (13167, '2015-07-19 12:07:30.261978+00', '2015-07-19 12:07:30.261978+00', 'Camberley Reel, The', 1042, '');
INSERT INTO 'tune' VALUES (13168, '2015-07-19 12:35:58.505769+00', '2015-07-19 12:35:58.505769+00', 'Twas on a Monday Morning', 9999, '');
INSERT INTO 'tune' VALUES (13169, '2015-07-19 12:59:11.670996+00', '2015-07-19 12:59:11.670996+00', 'Harmonious Blacksmith, The', 11156, '');
INSERT INTO 'tune' VALUES (13170, '2015-07-20 07:43:07.59648+00', '2015-07-20 07:43:07.59648+00', 'Posthorn Gallop, The', 1042, '');
INSERT INTO 'tune' VALUES (13172, '2015-07-20 12:25:08.401952+00', '2015-07-20 12:25:08.401952+00', 'Apple for the Teacher, An', 1042, '');
INSERT INTO 'tune' VALUES (13173, '2015-07-20 12:53:00.749593+00', '2015-07-20 12:53:00.749593+00', 'Rhoda''s Delight', 1042, '');
INSERT INTO 'tune' VALUES (13174, '2015-07-20 13:19:33.719403+00', '2015-07-20 13:19:33.719403+00', 'Lexelle''s Reel', 1042, '');
INSERT INTO 'tune' VALUES (13175, '2015-07-20 14:20:44.161229+00', '2015-07-20 14:20:44.161229+00', 'Brave Boris the Bold', 10337, '');
INSERT INTO 'tune' VALUES (13176, '2015-07-20 14:44:08.047383+00', '2015-07-20 14:44:08.047383+00', 'Jane''s Whirly Reel', 1526, '');
INSERT INTO 'tune' VALUES (13177, '2015-07-20 15:09:05.742558+00', '2015-07-20 15:09:05.742558+00', 'MacBeth''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (13178, '2015-07-20 15:11:39.200654+00', '2015-07-20 15:11:39.200654+00', 'Traditional Reel, A (for Sheffield Castle)', 9999, '');
INSERT INTO 'tune' VALUES (13179, '2015-07-20 15:27:57.95444+00', '2015-07-20 15:27:57.95444+00', 'Bellag the Drover', 9999, '');
INSERT INTO 'tune' VALUES (13180, '2015-07-20 15:39:03.977502+00', '2015-07-20 15:39:03.977502+00', 'Capon Tree, The', 1501, '');
INSERT INTO 'tune' VALUES (13181, '2015-07-21 08:54:06.636902+00', '2015-07-21 08:54:06.636902+00', 'Wee Dram, The', 3683, '');
INSERT INTO 'tune' VALUES (13182, '2015-07-26 10:33:34.560869+00', '2015-07-26 10:33:34.560869+00', 'Minnie''s Fancy', 1526, '');
INSERT INTO 'tune' VALUES (13183, '2015-07-26 10:35:11.581865+00', '2015-07-26 10:35:11.581865+00', 'Inspiration', 3220, '');
INSERT INTO 'tune' VALUES (13184, '2015-07-26 10:38:20.975567+00', '2015-07-26 10:38:20.975567+00', 'Maya''s Reel', 1508, '');
INSERT INTO 'tune' VALUES (13186, '2015-07-26 10:41:09.61218+00', '2015-07-26 10:41:09.61218+00', 'Spring is Sprung', 1526, 'Composed 2015');
INSERT INTO 'tune' VALUES (13188, '2015-07-26 10:44:11.486222+00', '2015-07-26 10:44:11.486222+00', 'Rosi''s Smile', 1502, 'Composed 2015');
INSERT INTO 'tune' VALUES (13185, '2015-07-26 10:39:41.957231+00', '2016-09-09 09:27:41.068679+00', 'Ferryboat, The', 3220, '');
INSERT INTO 'tune' VALUES (13171, '2015-07-20 12:12:42.506258+00', '2017-01-20 03:31:31.317335+00', 'Musician, The', 1042, '');
INSERT INTO 'tune' VALUES (7472, NULL, '2015-08-01 13:51:39.547335+00', 'Orpington Caledonians', 1407, '');
INSERT INTO 'tune' VALUES (13190, '2015-08-01 13:52:44.567426+00', '2015-08-01 13:52:44.567426+00', 'Riding Through the Dark', 11154, '');
INSERT INTO 'tune' VALUES (13192, '2015-08-01 13:54:37.261031+00', '2015-08-01 13:54:37.261031+00', 'Ann Dix of Harmans Water', 1590, '');
INSERT INTO 'tune' VALUES (12670, '2013-10-31 15:14:39.724522+00', '2018-04-10 08:46:24.63844+00', 'Letting Go', 3179, 'As I worked on this tune I kept trying to let go of the little theme found in bars two and four

but came back to it time and again. Hence the title.');
INSERT INTO 'tune' VALUES (13194, '2015-08-01 13:59:40.527686+00', '2015-08-01 13:59:40.527686+00', 'John Cass''s 90th Birthday', 1725, '');
INSERT INTO 'tune' VALUES (13195, '2015-08-01 14:00:51.592307+00', '2015-08-01 14:00:51.592307+00', 'Josephine Mason of Kinross', 10337, '');
INSERT INTO 'tune' VALUES (4871, NULL, '2015-08-12 14:09:08.18724+00', 'Miss Mackenzie''s Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (12437, '2013-01-28 20:34:17.898805+00', '2015-08-12 14:10:19.483842+00', 'Back to your Roots for Monica', 1502, 'source: note to the video  https://www.youtube.com/watch?v=Q5RyjqXCTaA&feature=relmfu');
INSERT INTO 'tune' VALUES (9760, '2006-03-07 23:00:00+00', '2015-08-16 15:25:01.581441+00', 'Vicki''s Birthday', 11169, 'Composed  at RSCDS Summerschool 2002 for the dance Seven to Seven by Gabor Turi ');
INSERT INTO 'tune' VALUES (13198, '2015-08-19 14:50:52.806658+00', '2015-08-19 14:50:52.806658+00', 'Dennis'' Jig', 11171, '');
INSERT INTO 'tune' VALUES (13199, '2015-08-19 15:01:55.208869+00', '2015-08-19 15:01:55.208869+00', 'Waltz from Masquerade Suite', 11172, '');
INSERT INTO 'tune' VALUES (13200, '2015-08-19 15:06:41.732077+00', '2015-08-19 15:06:41.732077+00', 'Burn''s Reel', 1645, '');
INSERT INTO 'tune' VALUES (13201, '2015-08-19 15:08:01.751059+00', '2015-08-19 15:08:01.751059+00', 'Jim Lindsay''s Magic Box', 1898, '');
INSERT INTO 'tune' VALUES (13202, '2015-08-19 15:30:48.480382+00', '2015-08-19 15:30:48.480382+00', 'Aberdeen', 1505, '');
INSERT INTO 'tune' VALUES (13203, '2015-08-19 15:38:45.807771+00', '2015-08-19 15:38:45.807771+00', 'Robert Scott''s Reel', 1593, '');
INSERT INTO 'tune' VALUES (5874, NULL, '2015-08-19 15:40:22.183493+00', 'Dr Bill Clegg''s Reel', 1605, '');
INSERT INTO 'tune' VALUES (13204, '2015-08-19 15:50:32.893686+00', '2015-08-19 15:50:32.893686+00', 'Meghann''s Tune', 1585, '');
INSERT INTO 'tune' VALUES (13205, '2015-08-19 16:04:16.511904+00', '2015-08-19 16:04:16.511904+00', 'Radetsky March', 11173, '');
INSERT INTO 'tune' VALUES (13206, '2015-08-19 16:11:14.072174+00', '2015-08-19 16:11:14.072174+00', 'Phil Cunningham MBE', 11174, '');
INSERT INTO 'tune' VALUES (13207, '2015-08-19 16:13:12.228272+00', '2015-08-19 16:13:12.228272+00', 'Kevin''s Reel', 2662, '');
INSERT INTO 'tune' VALUES (13208, '2015-08-27 13:55:53.955378+00', '2015-08-27 13:55:53.955378+00', 'Minnie Walker', 2977, '');
INSERT INTO 'tune' VALUES (13209, '2015-08-27 13:56:17.411878+00', '2015-08-27 13:56:17.411878+00', 'New Jig for Lois', 2335, '');
INSERT INTO 'tune' VALUES (8316, NULL, '2015-08-27 21:34:08.957119+00', 'Jacky Tar', 9999, 'Related tune: "Come Ashore Jolly Tar".  If you compare the (untitled) tune printed in Book 7 to “Jacky Tar“ from *Kerr''s*, you can see that this is recognisably the same tune but the parts are in a

different order and there are variations in the RSCDS book that aren''t in *Kerr''s*. This whole situation probably needs careful revision.  (information supplied by Anselm Lingnau, 2015-08-27.)');
INSERT INTO 'tune' VALUES (13210, '2015-08-29 12:23:01.641836+00', '2015-08-29 12:23:01.641836+00', 'William Williamson of Dykeside', 1954, '');
INSERT INTO 'tune' VALUES (13211, '2015-08-29 12:23:58.45504+00', '2015-08-29 12:23:58.45504+00', 'Blootered in Benidorm', 11184, '');
INSERT INTO 'tune' VALUES (13212, '2015-08-29 12:24:32.305246+00', '2015-08-29 12:24:32.305246+00', 'Amisfield Tower', 11185, '');
INSERT INTO 'tune' VALUES (13213, '2015-08-29 12:25:32.098235+00', '2015-08-29 12:25:32.098235+00', 'Master William Cameron Gall', 11182, '');
INSERT INTO 'tune' VALUES (13215, '2015-08-29 12:26:49.451476+00', '2015-08-29 12:26:49.451476+00', 'Miss Graham of Dykeside', 11185, '');
INSERT INTO 'tune' VALUES (13216, '2015-08-29 12:27:46.522951+00', '2015-08-29 12:27:46.522951+00', 'Winklepickers, The', 11185, '');
INSERT INTO 'tune' VALUES (13217, '2015-08-29 12:29:03.324552+00', '2015-08-29 12:29:03.324552+00', 'Master Howie Gilchrist Gall', 11185, '');
INSERT INTO 'tune' VALUES (13218, '2015-08-29 14:09:36.673544+00', '2015-08-29 14:09:36.673544+00', 'Happy Tartan', 11188, '');
INSERT INTO 'tune' VALUES (13219, '2015-08-29 14:10:23.361817+00', '2015-08-29 14:10:23.361817+00', 'Petite Spirale, La', 11188, '');
INSERT INTO 'tune' VALUES (13221, '2015-08-29 14:11:30.902255+00', '2015-08-29 14:11:30.902255+00', 'Chasing an Elf', 11188, '');
INSERT INTO 'tune' VALUES (13222, '2015-08-29 14:12:12.115539+00', '2015-08-29 14:12:12.115539+00', 'Se Reunir', 11188, '');
INSERT INTO 'tune' VALUES (13223, '2015-08-29 14:12:57.36205+00', '2015-08-29 14:12:57.36205+00', 'Sakura Medley, The', 11188, '');
INSERT INTO 'tune' VALUES (13224, '2015-08-29 14:13:20.692227+00', '2015-08-29 14:13:20.692227+00', 'Ruban, Le', 11188, '');
INSERT INTO 'tune' VALUES (13225, '2015-08-29 14:14:21.882332+00', '2015-08-29 14:14:21.882332+00', 'De L''Autre Côté', 11188, '');
INSERT INTO 'tune' VALUES (13226, '2015-08-29 14:14:56.330181+00', '2015-08-29 14:14:56.330181+00', 'Rouge et le Noir, Le', 11188, '');
INSERT INTO 'tune' VALUES (13227, '2015-08-31 11:13:42.351486+00', '2015-08-31 11:13:42.351486+00', 'Apple Cidre', 3685, '');
INSERT INTO 'tune' VALUES (13220, '2015-08-29 14:11:04.482714+00', '2015-08-31 11:14:41.306324+00', 'Ciel Gris Strathspey, Le', 11188, '');
INSERT INTO 'tune' VALUES (13228, '2015-08-31 11:15:20.814363+00', '2015-08-31 11:15:20.814363+00', 'Ciel Gris Reel, Le', 11188, '');
INSERT INTO 'tune' VALUES (13229, '2015-08-31 11:18:37.049656+00', '2015-08-31 11:18:37.049656+00', 'Alice', 3685, '');
INSERT INTO 'tune' VALUES (13230, '2015-08-31 11:24:26.895317+00', '2015-08-31 11:24:26.895317+00', 'Toréadors, Les', 11192, '');
INSERT INTO 'tune' VALUES (13231, '2015-09-01 15:29:45.953391+00', '2015-09-01 15:31:48.707189+00', 'Kelly''s Kaper', 1590, 'Written for STV Appeal Big Challenge.  Composed in April 2015.');
INSERT INTO 'tune' VALUES (8952, '2003-05-04 22:00:00+00', '2015-09-03 13:14:58.001393+00', 'Alexander''s Ruby', 1582, '');
INSERT INTO 'tune' VALUES (13232, '2015-09-04 08:58:12.58592+00', '2015-09-04 08:58:12.58592+00', 'Fiddlesticks', 11137, '');
INSERT INTO 'tune' VALUES (13233, '2015-09-04 09:00:31.85742+00', '2015-09-04 09:00:31.85742+00', 'Skibo Castle', 1586, '');
INSERT INTO 'tune' VALUES (13234, '2015-09-04 09:02:30.065938+00', '2015-09-04 09:02:30.065938+00', 'Jollity', 11137, '');
INSERT INTO 'tune' VALUES (13235, '2015-09-04 09:09:07.468628+00', '2015-09-04 09:09:07.468628+00', 'Thursday Friends', 11198, '');
INSERT INTO 'tune' VALUES (13237, '2015-09-04 09:23:34.846973+00', '2015-09-04 09:23:34.846973+00', 'Thorngrove', 2856, '');
INSERT INTO 'tune' VALUES (13238, '2015-09-04 09:29:35.554737+00', '2015-09-04 09:29:35.554737+00', 'Jig for Betty', 2856, '');
INSERT INTO 'tune' VALUES (13239, '2015-09-04 09:36:10.66966+00', '2015-09-04 09:36:10.66966+00', 'Beech Cottage', 10972, '');
INSERT INTO 'tune' VALUES (13240, '2015-09-04 09:40:46.102694+00', '2015-09-04 09:40:46.102694+00', 'Tullynessle and Forbes Hall', 11199, '');
INSERT INTO 'tune' VALUES (13196, '2015-08-01 14:03:38.114318+00', '2015-09-05 21:09:56.907942+00', 'Countess of Dunmore''s Reel, The', 1502, '');
INSERT INTO 'tune' VALUES (12943, '2014-05-10 00:09:16.353958+00', '2015-09-05 21:10:14.976406+00', 'Countess of Eglinton''s Strathspey, The', 9999, '');
INSERT INTO 'tune' VALUES (11126, '2010-05-30 22:00:00+00', '2015-09-05 21:11:15.695942+00', 'Freuchie March to Lords, The', 2843, 'The tune was written to commemorate the success of the village cricket team.



The composer, John Crawford, is the well known accordian tuner from Freuchie.');
INSERT INTO 'tune' VALUES (13189, '2015-08-01 13:50:17.044491+00', '2015-09-05 21:12:33.325207+00', 'Hazel''s Singapore Sling', 1621, '');
INSERT INTO 'tune' VALUES (2443, NULL, '2015-09-05 21:25:31.970001+00', 'Laird o'' Thrums, The', 1512, '');
INSERT INTO 'tune' VALUES (12433, '2013-01-24 15:31:49.06108+00', '2015-09-05 21:53:12.92557+00', 'Colonel - Ian Petrie, The', 1902, '');
INSERT INTO 'tune' VALUES (12434, '2013-01-24 15:32:19.812065+00', '2015-09-05 21:53:31.034846+00', 'Colonel''s Lady - Irene, The', 1902, '');
INSERT INTO 'tune' VALUES (2596, NULL, '2015-09-10 10:00:45.815937+00', 'Miss Gordon of Liverpool', 1516, 'Originally a 9/8 jig, but was adapted as a 6/8 jig for <<ddd:The Jubilee Jig>>.');
INSERT INTO 'tune' VALUES (12623, '2013-09-28 22:27:32.121045+00', '2015-09-28 00:10:48.993886+00', 'Montreal Anniversary Jig', 10012, 'This is a tune from the CD "Les Joueurs de Bon Accord" with Laura Risk, Nicolas Williams and Eric Breton.');
INSERT INTO 'tune' VALUES (13242, '2015-10-11 22:35:18.684975+00', '2015-10-11 22:35:18.684975+00', '"Lady" Paulien''s Fancy', 10581, '2015?');
INSERT INTO 'tune' VALUES (13243, '2015-10-15 22:11:46.370245+00', '2015-10-15 22:11:46.370245+00', 'Lady Irvine''s Jig', 3683, '');
INSERT INTO 'tune' VALUES (13245, '2015-10-25 03:33:34.089055+00', '2015-10-25 03:33:34.089055+00', 'Young Willie Hunter', 1677, '');
INSERT INTO 'tune' VALUES (13877, '2018-04-10 09:25:42.535662+00', '2018-04-10 09:27:36.337592+00', 'Minor Ode, A', 3179, '');
INSERT INTO 'tune' VALUES (13191, '2015-08-01 13:53:31.825796+00', '2018-04-10 11:13:53.219373+00', 'Nineteen Years', 3179, '');
INSERT INTO 'tune' VALUES (13197, '2015-08-19 14:40:56.219471+00', '2017-02-13 11:24:34.745937+00', 'Keith Smith''s Compliments to Kathy Frazer', 3436, '');
INSERT INTO 'tune' VALUES (13241, '2015-10-08 08:55:47.584506+00', '2016-01-01 13:03:00.827466+00', 'St John''s Toun', 10596, '');
INSERT INTO 'tune' VALUES (13236, '2015-09-04 09:12:59.774526+00', '2016-09-09 09:23:17.227082+00', 'Birches of Aboyne, The', 10252, '');
INSERT INTO 'tune' VALUES (13272, '2016-03-13 10:05:08.256844+00', '2016-09-09 09:25:46.572647+00', 'Sea Trout, The', 1836, '');
INSERT INTO 'tune' VALUES (12910, '2014-03-26 16:56:55.346307+00', '2016-09-09 09:27:03.366309+00', 'Lass o'' Gowrie, The', 9999, 'Arranged Peter White');
INSERT INTO 'tune' VALUES (13187, '2015-07-26 10:42:47.849473+00', '2016-09-09 09:29:28.983407+00', 'Rose of Weingarten, The', 1502, 'Composed 2015');
INSERT INTO 'tune' VALUES (13214, '2015-08-29 12:26:07.763042+00', '2017-03-03 21:50:22.160859+00', 'Hannah Mary Graham', 11186, 'For my niece Hannah. The tune was composed for her christening in 2000.  It is a bagpipe tune and should be played slowly for the dance.');
INSERT INTO 'tune' VALUES (13879, '2018-04-10 11:54:17.863111+00', '2018-04-10 11:54:17.863111+00', 'Late Again', 3731, '');
INSERT INTO 'tune' VALUES (13244, '2015-10-15 22:26:03.280048+00', '2018-09-15 11:51:46.682521+00', 'Cairn O'' Mohr', 3683, '');
INSERT INTO 'tune' VALUES (1386, NULL, '2015-10-30 14:24:40.863273+00', 'New High Level, The', 2884, 'Often wrongly attributed to Andrew Rankine. Andrew Rankine used the A part of this tune and came

up with a different B part; see <<ddt:New High Level#11937>>.



The title refers to the ''New'' High Level Bridge in Newcastle on Tyne. It was built between 1846 to 1849 and was the first railway bridge over the River Tyne. It was unusual in that there is a road deck below the railway track. it is 112 feet above high water mark. (Information provided by  Iain C. Gent, Linlithgow)');
INSERT INTO 'tune' VALUES (4025, NULL, '2015-10-30 15:42:28.706158+00', 'Laigh o'' Moray', 93, '');
INSERT INTO 'tune' VALUES (5714, NULL, '2015-10-30 23:09:42.0477+00', 'Orilla Waltz', 2569, '');
INSERT INTO 'tune' VALUES (6803, NULL, '2015-10-30 23:11:40.176368+00', 'Parkhill Two Step', 1538, '');
INSERT INTO 'tune' VALUES (13246, '2015-11-09 14:06:46.226472+00', '2015-11-09 14:06:46.226472+00', 'Laird o'' Marlay View, The', 10596, 'The tune was composed by John Barnes in the spring of 2011. He belongs to Dublin Scottish Country Dance Club.');
INSERT INTO 'tune' VALUES (13247, '2015-12-30 18:47:15.12257+00', '2015-12-30 18:47:15.12257+00', 'Memories of Kenny', 11230, '');
INSERT INTO 'tune' VALUES (13249, '2015-12-30 18:48:32.557913+00', '2015-12-30 18:48:32.557913+00', 'Jennie Robertson''s Strathspey', 1591, '');
INSERT INTO 'tune' VALUES (13250, '2015-12-30 18:49:10.092995+00', '2015-12-30 18:49:10.092995+00', 'Buchanan Street Strathspey', 1591, '');
INSERT INTO 'tune' VALUES (13251, '2015-12-30 18:49:49.980083+00', '2015-12-30 18:49:49.980083+00', 'Union Street Strathspey', 1591, '');
INSERT INTO 'tune' VALUES (13252, '2015-12-30 18:53:18.177226+00', '2015-12-30 18:53:18.177226+00', 'Princes Street Strathspey', 1591, '');
INSERT INTO 'tune' VALUES (13253, '2015-12-30 18:53:46.400957+00', '2015-12-30 18:53:46.400957+00', 'Freedom Reel, The', 1591, '');
INSERT INTO 'tune' VALUES (13254, '2015-12-30 18:54:17.801007+00', '2015-12-30 18:54:17.801007+00', 'Spinning Jenny', 1591, '');
INSERT INTO 'tune' VALUES (13302, '2016-09-09 09:15:04.485055+00', '2021-11-24 15:06:22.297248+00', 'Pandas Roux, Les', 11345, '');
INSERT INTO 'tune' VALUES (13304, '2016-09-09 09:17:02.087153+00', '2021-11-25 00:55:00.654315+00', 'Love in the Marais', 11345, '');
INSERT INTO 'tune' VALUES (13303, '2016-09-09 09:16:02.529293+00', '2021-11-25 02:51:21.355376+00', 'Spanish Dance', 11341, '');
INSERT INTO 'tune' VALUES (13301, '2016-09-09 09:13:56.412996+00', '2021-11-25 07:22:35.003048+00', 'Speedy life in Paris', 11341, '');
INSERT INTO 'tune' VALUES (13255, '2015-12-30 18:54:47.033897+00', '2015-12-30 18:54:47.033897+00', 'Fingal''s Cave, The Storm', 1591, '');
INSERT INTO 'tune' VALUES (13248, '2015-12-30 18:47:47.642874+00', '2015-12-30 19:02:57.14401+00', 'Fingal''s Cave', 1591, '');
INSERT INTO 'tune' VALUES (13257, '2016-01-01 11:38:51.641892+00', '2016-01-01 11:38:51.641892+00', 'John and Lily''s Wedding', 10596, '');
INSERT INTO 'tune' VALUES (13259, '2016-01-01 12:24:27.357148+00', '2016-01-01 12:24:27.357148+00', 'Petronella''s Visit to Dublin', 10596, '');
INSERT INTO 'tune' VALUES (13258, '2016-01-01 12:19:44.338392+00', '2016-01-01 12:25:47.363753+00', 'Golden Couple of Leinster Lawn, The', 10596, '');
INSERT INTO 'tune' VALUES (12000, '2012-01-06 23:00:00+00', '2016-01-01 12:26:37.621878+00', 'Pam and Forbes Campbell', 10596, '');
INSERT INTO 'tune' VALUES (13260, '2016-01-01 12:36:57.988655+00', '2016-01-01 12:36:57.988655+00', 'Florrie''s Fancy', 10596, '');
INSERT INTO 'tune' VALUES (13261, '2016-01-01 12:41:12.219946+00', '2016-01-01 12:41:12.219946+00', 'Forty Years Together', 10596, '');
INSERT INTO 'tune' VALUES (13262, '2016-01-01 12:44:25.106762+00', '2016-01-01 12:44:25.106762+00', 'Mrs Jill Bonar', 10596, '');
INSERT INTO 'tune' VALUES (13263, '2016-01-01 12:45:40.622815+00', '2016-01-01 12:45:40.622815+00', 'Mr Frank Roberts Bonar', 10596, '');
INSERT INTO 'tune' VALUES (13880, '2018-04-10 11:59:38.564105+00', '2018-04-10 11:59:38.564105+00', 'Captain Campbell of Carphen', 10507, '');
INSERT INTO 'tune' VALUES (13265, '2016-01-01 12:54:19.075005+00', '2016-01-01 12:54:19.075005+00', 'Strathspey for Helen, A', 10596, '');
INSERT INTO 'tune' VALUES (13266, '2016-01-01 12:58:06.023251+00', '2016-01-01 12:58:06.023251+00', 'Guardian of Early Printed Books, The', 10596, '');
INSERT INTO 'tune' VALUES (13267, '2016-01-01 13:00:55.477972+00', '2016-01-01 13:00:55.477972+00', 'Liam and Hazel Convery', 10596, '');
INSERT INTO 'tune' VALUES (13268, '2016-01-01 13:18:29.534979+00', '2016-01-01 13:18:29.534979+00', 'Rosalie''s Rather Special Birthday', 10596, '');
INSERT INTO 'tune' VALUES (14018, '2019-03-14 00:07:22.842297+00', '2019-03-14 00:07:22.842297+00', 'Y Lili', 9999, '');
INSERT INTO 'tune' VALUES (14033, '2019-03-19 01:37:48.502424+00', '2019-03-19 01:37:48.502424+00', 'Katrina', 1557, '');
INSERT INTO 'tune' VALUES (13270, '2016-01-20 11:41:09.264566+00', '2016-01-20 11:58:46.406502+00', 'Feolin Burn', 1534, 'See "Magic of Music, Book2, p. 25');
INSERT INTO 'tune' VALUES (13269, '2016-01-20 11:41:04.418405+00', '2016-01-20 11:59:26.523721+00', 'Shores of Loch Long', 1534, 'See "Magic of Music, Book2, p. 25');
INSERT INTO 'tune' VALUES (13271, '2016-03-13 01:08:29.291811+00', '2016-03-13 01:08:29.291811+00', 'Findlay J Powrie', 1551, '');
INSERT INTO 'tune' VALUES (10292, '2009-11-04 23:00:00+00', '2016-03-13 09:51:27.017498+00', 'Susan Ross of Abroath', 3186, '');
INSERT INTO 'tune' VALUES (14054, '2019-06-14 10:09:38.442781+00', '2019-06-14 10:09:38.442781+00', 'Crystal', 1829, '');
INSERT INTO 'tune' VALUES (195, NULL, '2016-03-19 11:45:23.507952+00', 'Silver Star, The', 353, '');
INSERT INTO 'tune' VALUES (13273, '2016-03-19 18:43:57.063877+00', '2016-03-19 18:43:57.063877+00', 'Skye Dance', 9999, '');
INSERT INTO 'tune' VALUES (13274, '2016-03-23 21:51:48.410588+00', '2016-03-23 21:51:48.410588+00', 'Lady Rachael Russell', 1516, '');
INSERT INTO 'tune' VALUES (3896, NULL, '2016-03-31 13:36:38.63122+00', 'General Garibaldi''s Reel', 11242, '');
INSERT INTO 'tune' VALUES (10683, '2009-11-21 23:00:00+00', '2016-04-30 22:53:17.841274+00', 'Tuolumne Tournee', 1502, 'Both for the dance and the tune the erroneous spelling "Tuolomne" still turns up.');
INSERT INTO 'tune' VALUES (1086, NULL, '2016-05-12 21:31:55.820034+00', 'Mary Hamilton of Auchincruive', 11251, 'Laird Brown has an original hand-written sheet with the same tune which only has "Mary Hamilton" as the title.



According to the <<http://boxandfiddlearchive.weebly.com/stan-hamilton.html|Box and Fiddle archive>> and Iain Boyd''s book <<http://my.strathspey.org/dd/publication/600/|All Kinds Of Everything>>, Jimmy Hamilton has composed this tune. It is named after his wife.



Because the full names of Jimmy Hamilton and his son Stan Hamilton are both James Stanley Hamilton some tune assignments might be hard to trace back.');
INSERT INTO 'tune' VALUES (752, NULL, '2016-06-03 13:43:56.472849+00', 'Iron Bridge, The', 228, '');
INSERT INTO 'tune' VALUES (1253, NULL, '2016-06-03 13:47:41.481173+00', 'Monika''s Reel', 228, '');
INSERT INTO 'tune' VALUES (1231, NULL, '2016-06-03 13:51:25.664234+00', 'Miss Petra Fries of Paderborn', 228, '');
INSERT INTO 'tune' VALUES (572, NULL, '2016-06-03 13:56:03.90276+00', 'Geordie''s Tunebook', 228, '');
INSERT INTO 'tune' VALUES (13276, '2016-06-08 15:01:48.816002+00', '2016-06-08 15:01:48.816002+00', 'Lass o'' Evelyns', 3298, '');
INSERT INTO 'tune' VALUES (13277, '2016-06-08 15:08:43.83023+00', '2016-06-08 15:08:43.83023+00', 'Catriona''s Ceilidh', 3298, '');
INSERT INTO 'tune' VALUES (13278, '2016-06-08 15:15:37.486228+00', '2016-06-08 15:15:37.486228+00', 'Munro of Dalnair', 3298, '');
INSERT INTO 'tune' VALUES (13279, '2016-07-04 20:19:39.276747+00', '2016-07-04 20:19:39.276747+00', 'All Roads lead to York', 1582, 'J 32');
INSERT INTO 'tune' VALUES (2086, NULL, '2016-07-26 00:58:54.399085+00', 'Dave Wilson - The Balmullo Blacksmith', 1585, 'The tune ''The Balmullo Blacksmith'' was written by Robert (Bobbie) Forsyth Crowe for David Wilson after he became the World Champion Blacksmith at the Calgary Stampede in 1986.



David Wilson and his wife have the original melody handwritten by Bobbie Crowe up on their wall ;)



(Information provided by Iain Masson, the grandson of David Wilson in July 2016)');
INSERT INTO 'tune' VALUES (13280, '2016-07-28 22:32:11.090359+00', '2016-07-29 20:49:25.622833+00', 'Mr. Fred Eustis of Windsor Mill', 1763, '');
INSERT INTO 'tune' VALUES (13281, '2016-08-12 17:37:16.247922+00', '2016-08-12 17:37:16.247922+00', 'Allenbank', 1502, 'I have only the listing in the liner notes to attest to this entry.');
INSERT INTO 'tune' VALUES (13282, '2016-08-12 17:46:25.335678+00', '2016-08-12 17:46:25.335678+00', 'Take the Floor', 1777, '');
INSERT INTO 'tune' VALUES (13283, '2016-08-12 18:15:53.21073+00', '2016-08-12 18:15:53.21073+00', 'Radio Scotland Polka, The', 1777, '');
INSERT INTO 'tune' VALUES (13284, '2016-08-12 18:24:18.865302+00', '2016-08-12 18:24:18.865302+00', 'Sunset on Sunart', 10078, '');
INSERT INTO 'tune' VALUES (13285, '2016-08-12 18:25:13.548378+00', '2016-08-12 18:25:13.548378+00', 'Loch Shiel', 1777, '');
INSERT INTO 'tune' VALUES (13286, '2016-08-12 18:26:03.624552+00', '2016-08-12 18:26:03.624552+00', 'Scotland', 1777, '');
INSERT INTO 'tune' VALUES (2615, NULL, '2016-08-17 14:03:00.258944+00', 'Miss Barbara Ogilvie', 1522, '');
INSERT INTO 'tune' VALUES (13287, '2016-08-21 08:36:03.596219+00', '2016-08-21 08:36:03.596219+00', 'Links with Winchester', 2197, '');
INSERT INTO 'tune' VALUES (13288, '2016-08-22 14:19:12.255686+00', '2016-08-22 14:19:12.255686+00', 'Long John Damond', 10118, '');
INSERT INTO 'tune' VALUES (13289, '2016-08-22 21:07:59.109322+00', '2016-08-22 21:07:59.109322+00', 'Theoretical Chemistry', 11321, 'Tune for "Kristi''s Conundrum.  



Patti says about her tune that Kristi got her Ph.D, in theoretical chemistry (whatever that is) it seemed like a great name for a tune.  The dotted eighth-sixteenth notes may be evened out if not being played for a Scottish dance.



The recording also uses the tune Sphere of Ink by James MacQueen of which he says:   Imagine a floating globule of black ink as if drawn from an old-fashioned inkwell, magnified in mid-air.

');
INSERT INTO 'tune' VALUES (13290, '2016-09-02 20:02:54.786866+00', '2016-09-02 20:02:54.786866+00', 'Sasha''s Jig', 11314, 'For "Les Remparts de Seville"  (Book 50)');
INSERT INTO 'tune' VALUES (13291, '2016-09-04 10:14:38.00501+00', '2016-09-04 10:14:38.00501+00', 'Roz and Gil Gotfried', 2395, '');
INSERT INTO 'tune' VALUES (13292, '2016-09-04 10:25:21.218178+00', '2016-09-04 10:25:25.367376+00', 'From East to West', 1582, '');
INSERT INTO 'tune' VALUES (13293, '2016-09-04 11:51:23.258384+00', '2016-09-04 11:51:23.258384+00', 'Mrs. Marion Small', 1764, '');
INSERT INTO 'tune' VALUES (13295, '2016-09-04 22:49:27.044728+00', '2016-09-04 22:49:27.044728+00', 'Glen Magic', 2913, '');
INSERT INTO 'tune' VALUES (13299, '2016-09-09 09:11:48.68376+00', '2016-09-09 09:11:48.68376+00', 'Noces d''Argent', 1173, '');
INSERT INTO 'tune' VALUES (13193, '2015-08-01 13:58:31.160458+00', '2016-09-09 09:28:39.458341+00', 'Centenary Square, The', 1526, '');
INSERT INTO 'tune' VALUES (13361, '2016-10-08 23:47:11.189258+00', '2018-09-19 10:00:30.213325+00', 'Mrs Jappy''s Measure', 1502, '');
INSERT INTO 'tune' VALUES (13307, '2016-09-12 22:59:18.747473+00', '2016-09-12 22:59:18.747473+00', 'Dr Thomas Ibbotson', 11154, '');
INSERT INTO 'tune' VALUES (13308, '2016-09-12 23:00:43.711945+00', '2016-09-12 23:00:43.711945+00', 'Arbroath Strathspey, The', 11352, '');
INSERT INTO 'tune' VALUES (13309, '2016-09-12 23:01:19.288924+00', '2016-09-12 23:01:19.288924+00', 'Kathleen Carcary', 11352, '');
INSERT INTO 'tune' VALUES (13310, '2016-09-12 23:05:19.285584+00', '2016-09-12 23:05:19.285584+00', 'Miss Ann Gordon, Heath Cottage', 1807, '');
INSERT INTO 'tune' VALUES (13311, '2016-09-12 23:13:44.176965+00', '2016-09-12 23:13:44.176965+00', 'Anne Barne''s Reel', 1590, '');
INSERT INTO 'tune' VALUES (13312, '2016-09-12 23:18:41.342559+00', '2016-09-12 23:18:41.342559+00', 'Air for Megan', 11353, '');
INSERT INTO 'tune' VALUES (13313, '2016-09-12 23:21:25.139351+00', '2016-09-12 23:21:25.139351+00', 'Ian and Judith Muir', 2168, '');
INSERT INTO 'tune' VALUES (13314, '2016-09-12 23:24:31.786413+00', '2016-09-12 23:24:31.786413+00', 'Dots and Dashes', 11354, '');
INSERT INTO 'tune' VALUES (11937, '2011-12-05 23:00:00+00', '2016-09-12 23:26:57.379493+00', 'New High Level, The', 1533, 'Originally by <<ddp:Whinham, Robert>>. Andrew Rankine used the first part of his tune (see <<ddt:The New High Level#1386>>) and added a different second part.



The title refers to the ''New'' High Level Bridge in Newcastle on Tyne. It was built between 1846 to 1849 and was the first railway bridge over the River Tyne. It was unusual in that there is a road deck below the railway track. it is 112 feet above high water mark. (Information provided by  Iain C. Gent, Linlithgow)');
INSERT INTO 'tune' VALUES (13315, '2016-09-12 23:31:02.04123+00', '2016-09-12 23:31:02.04123+00', 'Miss Charles Hamilton Scott''s Jigg', 1401, '');
INSERT INTO 'tune' VALUES (6411, NULL, '2016-09-12 23:32:55.192916+00', 'Band Boys, The', 9999, '');
INSERT INTO 'tune' VALUES (13300, '2016-09-09 09:12:58.921052+00', '2021-11-21 05:27:52.217501+00', 'Capitol Steps, The', 11345, '');
INSERT INTO 'tune' VALUES (13296, '2016-09-08 23:00:03.000909+00', '2021-11-22 10:02:26.120601+00', 'Rendez-vous à Vichy', 11341, '');
INSERT INTO 'tune' VALUES (13297, '2016-09-09 09:08:58.21978+00', '2021-11-24 12:26:28.388531+00', 'Trip to Tobermory, A', 11299, '');
INSERT INTO 'tune' VALUES (13298, '2016-09-09 09:10:25.407276+00', '2021-11-25 07:25:32.714415+00', '4th of May, The', 11299, '');
INSERT INTO 'tune' VALUES (13316, '2016-09-12 23:34:40.223123+00', '2016-09-12 23:34:40.223123+00', 'Audrey and Edward Bell of Midway', 10337, '');
INSERT INTO 'tune' VALUES (13317, '2016-09-12 23:37:47.16785+00', '2016-09-12 23:37:47.16785+00', 'Jim and Helen''s Jig', 11355, '');
INSERT INTO 'tune' VALUES (13318, '2016-09-12 23:38:25.366405+00', '2016-09-12 23:38:25.366405+00', 'Willie McHardy''s Jig', 11355, '');
INSERT INTO 'tune' VALUES (10368, '2009-11-07 23:00:00+00', '2016-09-12 23:41:04.459728+00', 'Fiona Robertson', 2266, '');
INSERT INTO 'tune' VALUES (9099, NULL, '2016-09-12 23:45:03.795417+00', 'Miss Kate Farrell', 1536, '');
INSERT INTO 'tune' VALUES (13319, '2016-09-12 23:46:57.354012+00', '2016-09-12 23:46:57.354012+00', 'Home to Ardsorn', 1605, '');
INSERT INTO 'tune' VALUES (13320, '2016-09-12 23:47:39.171644+00', '2016-09-12 23:47:42.199022+00', 'Tiraghoil March', 1608, '');
INSERT INTO 'tune' VALUES (13321, '2016-09-12 23:48:19.262865+00', '2016-09-12 23:48:19.262865+00', 'Castle Kennedy', 1668, '');
INSERT INTO 'tune' VALUES (13322, '2016-09-12 23:49:06.570485+00', '2016-09-12 23:49:06.570485+00', 'Duncan McCullam', 1668, '');
INSERT INTO 'tune' VALUES (13323, '2016-09-16 19:41:52.279023+00', '2016-09-16 19:43:16.405723+00', 'Ann''s Frolics', 11372, 'In memory of Ann Chambers, a delightful young Scottish country dancer from Denver, Colorado.   (C) Loretta Thompson, October 1994');
INSERT INTO 'tune' VALUES (13324, '2016-09-16 19:44:29.237908+00', '2016-09-16 19:44:29.237908+00', 'Llama Mama', 11372, 'October 1994');
INSERT INTO 'tune' VALUES (13325, '2016-09-16 19:46:35.458451+00', '2016-09-16 19:46:47.374851+00', 'Buckeyball Reel, The', 11366, 'February 1999. Revised, April 2000');
INSERT INTO 'tune' VALUES (4629, NULL, '2016-09-17 21:24:14.993511+00', 'Trip to Paris, A', 9998, 'Note in Whetherly book 24: The tune comprises an eight bar phrase and an eighteen bar phrase.');
INSERT INTO 'tune' VALUES (13326, '2016-10-03 23:24:52.612664+00', '2016-10-03 23:24:52.612664+00', 'On the Wings of a Skorie', 11377, '');
INSERT INTO 'tune' VALUES (13327, '2016-10-03 23:26:00.98022+00', '2016-10-03 23:26:00.98022+00', 'Jennie Hardie''s Reel', 2159, '');
INSERT INTO 'tune' VALUES (13328, '2016-10-03 23:28:31.667247+00', '2016-10-03 23:28:31.667247+00', 'Ice Storm', 11321, '');
INSERT INTO 'tune' VALUES (13329, '2016-10-03 23:29:21.080412+00', '2016-10-03 23:29:21.080412+00', 'Miss Gordon of Gight', 1934, '');
INSERT INTO 'tune' VALUES (13330, '2016-10-03 23:31:01.097246+00', '2016-10-03 23:31:01.097246+00', 'Jig is Up, The', 11321, '');
INSERT INTO 'tune' VALUES (13331, '2016-10-03 23:31:31.19215+00', '2016-10-03 23:31:31.19215+00', 'Changing Lights', 1393, '');
INSERT INTO 'tune' VALUES (13332, '2016-10-03 23:34:14.13671+00', '2016-10-03 23:34:14.13671+00', 'Ice on the Lake', 11321, '');
INSERT INTO 'tune' VALUES (13333, '2016-10-03 23:36:41.879555+00', '2016-10-03 23:36:41.879555+00', 'Unnamed Stallion', 11378, '');
INSERT INTO 'tune' VALUES (1122, NULL, '2016-10-03 23:39:47.126206+00', 'Miller of Drone, The', 1517, '');
INSERT INTO 'tune' VALUES (13334, '2016-10-03 23:41:42.259928+00', '2016-10-03 23:41:42.259928+00', 'Gazing into Her Bold Eyes', 11378, '');
INSERT INTO 'tune' VALUES (13335, '2016-10-03 23:42:24.737215+00', '2016-10-03 23:42:24.737215+00', 'Eyes on the Prize', 11378, '');
INSERT INTO 'tune' VALUES (13336, '2016-10-03 23:43:00.03328+00', '2016-10-03 23:43:00.03328+00', 'Curve in the Dark', 11378, '');
INSERT INTO 'tune' VALUES (13337, '2016-10-03 23:45:53.04965+00', '2016-10-03 23:45:53.04965+00', 'Sweet Garden', 11379, '');
INSERT INTO 'tune' VALUES (13338, '2016-10-03 23:48:58.412364+00', '2016-10-03 23:48:58.412364+00', 'Beaucatcher Farewell', 11380, '');
INSERT INTO 'tune' VALUES (13339, '2016-10-03 23:50:31.190934+00', '2016-10-03 23:50:31.190934+00', 'Beachcomber Reel', 11321, '');
INSERT INTO 'tune' VALUES (13340, '2016-10-03 23:52:10.330166+00', '2016-10-03 23:52:10.330166+00', 'Stolen Time', 11321, '');
INSERT INTO 'tune' VALUES (13341, '2016-10-03 23:54:28.820035+00', '2016-10-03 23:54:28.820035+00', 'Indian Point', 11381, '');
INSERT INTO 'tune' VALUES (13342, '2016-10-03 23:55:23.410457+00', '2016-10-03 23:55:23.410457+00', 'Blue Jig, The', 11382, '');
INSERT INTO 'tune' VALUES (13344, '2016-10-03 23:58:25.676072+00', '2016-10-03 23:58:25.676072+00', 'Lewis J. MacLeod', 11383, '');
INSERT INTO 'tune' VALUES (13374, '2016-10-09 02:07:09.287008+00', '2018-09-19 10:00:42.794326+00', 'Pet''s Galore', 2856, '');
INSERT INTO 'tune' VALUES (13346, '2016-10-04 00:01:25.120097+00', '2016-10-04 00:01:25.120097+00', 'Sphere of Ink', 11378, '');
INSERT INTO 'tune' VALUES (13347, '2016-10-04 00:03:37.388211+00', '2016-10-04 00:03:37.388211+00', 'Long Road Home, The', 11321, '');
INSERT INTO 'tune' VALUES (13348, '2016-10-04 00:04:20.64715+00', '2016-10-04 00:04:20.64715+00', 'Marjorie & Richard''s Wedding', 1782, '');
INSERT INTO 'tune' VALUES (13349, '2016-10-04 00:05:50.905199+00', '2016-10-04 00:05:50.905199+00', 'Hiking to High Point', 11384, '');
INSERT INTO 'tune' VALUES (13438, '2016-12-14 22:50:13.89557+00', '2016-12-14 22:50:13.89557+00', 'I Want A Hippopotamus For Christmas', 11426, '');
INSERT INTO 'tune' VALUES (13350, '2016-10-04 12:57:44.368372+00', '2016-10-04 12:57:44.368372+00', 'Shifting Skies', 11321, 'For "The Aloha Strathspey".  Adapted by Patti Cobb from "Storm Clouds" © Rebecca King 2011');
INSERT INTO 'tune' VALUES (13343, '2016-10-03 23:57:06.620209+00', '2016-10-04 15:47:18.66357+00', 'Oakland Rainstorm', 11378, 'During a long and severe drought in California, I returned for a brief weekend visit from graduate school in Colorado. Upon waking up the next morning in Oakland, a soft rain was falling. Full of gratitude for the precious gift of water and hopeful for more, I was inspired to write this tune.  November 2014');
INSERT INTO 'tune' VALUES (6646, NULL, '2016-10-04 21:00:44.133608+00', 'Extension, The', 1593, '');
INSERT INTO 'tune' VALUES (13351, '2016-10-04 21:17:14.94758+00', '2016-10-04 21:17:14.94758+00', 'Hunter''s Lodge', 1593, '2nd tune for "The Ecclefechan Rant" Joseph Killeen, The Anniversary Book, published by the Carlisle and Border Branch of the RSCDS');
INSERT INTO 'tune' VALUES (13352, '2016-10-04 21:22:45.275855+00', '2016-10-04 21:22:45.275855+00', 'Caldew Caffuffle', 1815, '2nd tune for Annan Welcome (32 J 3C) by Joseph Killeen, The Anniversary Book published by The Carlisle and Border Branch of the RSCDS.');
INSERT INTO 'tune' VALUES (13353, '2016-10-04 21:25:37.559419+00', '2016-10-04 21:27:49.22244+00', 'Bonnie Gelt Woods', 1593, '2nd tune for Joseph Killeen''s dance The Aviemore Strathspey in The Anniversary Book, published by The Carlisle and Border Branch of the RSCDS..');
INSERT INTO 'tune' VALUES (13354, '2016-10-04 21:30:44.537274+00', '2016-10-04 21:33:08.931154+00', 'After-Thought, The', 1815, '2nd tune for Joseph Killeen''s dance The Solway Reel, The Anniversary Book, published by The Carlisle and Border Branch of the RSCDS');
INSERT INTO 'tune' VALUES (13356, '2016-10-05 00:20:32.626176+00', '2016-10-05 00:20:32.626176+00', 'White Bridge, The', 1815, '');
INSERT INTO 'tune' VALUES (13357, '2016-10-08 23:29:26.44174+00', '2016-10-08 23:29:26.44174+00', 'Staircase In Styria', 3220, 'Composed in November 2009.');
INSERT INTO 'tune' VALUES (13358, '2016-10-08 23:38:06.558291+00', '2016-10-08 23:38:06.558291+00', '80th Anniversary Reel', 1575, '');
INSERT INTO 'tune' VALUES (13359, '2016-10-08 23:39:43.748304+00', '2016-10-08 23:39:43.748304+00', 'Pineapple Attack', 2160, '');
INSERT INTO 'tune' VALUES (13360, '2016-10-08 23:46:09.526403+00', '2016-10-08 23:46:09.526403+00', 'Tavira Tuk Tuk, The', 3220, '');
INSERT INTO 'tune' VALUES (10473, '2009-11-15 23:00:00+00', '2016-10-08 23:50:30.198078+00', 'Wee Mary''s Strathspey', 1575, '');
INSERT INTO 'tune' VALUES (13363, '2016-10-08 23:53:38.176235+00', '2016-10-08 23:53:38.176235+00', 'Ayrshire Craig', 1502, '');
INSERT INTO 'tune' VALUES (13364, '2016-10-08 23:56:13.297759+00', '2016-10-08 23:56:13.297759+00', 'Emma''s Reel', 11389, '');
INSERT INTO 'tune' VALUES (13365, '2016-10-09 00:02:13.927183+00', '2016-10-09 00:02:13.927183+00', 'Sunday Tea', 11390, '');
INSERT INTO 'tune' VALUES (13366, '2016-10-09 00:15:16.408758+00', '2016-10-09 00:15:16.408758+00', 'Tribute to West Renfrewshire', 1575, '');
INSERT INTO 'tune' VALUES (13367, '2016-10-09 00:22:11.5948+00', '2016-10-09 00:22:11.5948+00', 'Brock''s Midnight Bin Bash', 3220, '');
INSERT INTO 'tune' VALUES (13368, '2016-10-09 00:33:36.201483+00', '2016-10-09 00:33:36.201483+00', 'Louise & Iain Keegan', 1582, '');
INSERT INTO 'tune' VALUES (13369, '2016-10-09 01:45:35.38901+00', '2016-10-09 01:45:35.38901+00', 'Kalveek''s Polka', 1525, '');
INSERT INTO 'tune' VALUES (13370, '2016-10-09 01:48:49.439846+00', '2016-10-09 01:48:49.439846+00', 'Tipsy Vicar, The', 11391, '');
INSERT INTO 'tune' VALUES (13371, '2016-10-09 01:54:19.817858+00', '2016-10-09 01:54:19.817858+00', 'Give My Regards to Broadway', 11392, '');
INSERT INTO 'tune' VALUES (13372, '2016-10-09 01:55:54.825869+00', '2016-10-09 01:55:54.825869+00', 'Singing in the Rain', 11393, '');
INSERT INTO 'tune' VALUES (13373, '2016-10-09 02:03:29.78196+00', '2016-10-09 02:03:29.78196+00', 'Any Dream Will Do', 11394, '');
INSERT INTO 'tune' VALUES (13375, '2016-10-09 02:09:30.601617+00', '2016-10-09 02:09:30.601617+00', 'Unst', 9998, '');
INSERT INTO 'tune' VALUES (13376, '2016-10-18 12:34:04.445134+00', '2016-10-18 12:34:04.445134+00', 'Ruth Frae Pitlochry', 1502, '');
INSERT INTO 'tune' VALUES (13377, '2016-10-30 12:46:53.860551+00', '2016-10-30 12:46:53.860551+00', 'Little Biscuits', 1647, '');
INSERT INTO 'tune' VALUES (13378, '2016-10-30 12:50:35.868315+00', '2016-10-30 12:50:35.868315+00', 'Memories of Anne Anderson', 1808, '');
INSERT INTO 'tune' VALUES (13379, '2016-10-30 12:55:31.24488+00', '2016-10-30 12:55:31.24488+00', 'Carol Clark''s Reel', 11404, '');
INSERT INTO 'tune' VALUES (13380, '2016-10-30 13:01:01.122467+00', '2016-10-30 13:01:01.122467+00', 'Rosemary of Auchengar', 11405, '');
INSERT INTO 'tune' VALUES (13381, '2016-10-30 13:04:10.537447+00', '2016-10-30 13:04:10.537447+00', 'Miss Lucy Campbell', 9999, '');
INSERT INTO 'tune' VALUES (13382, '2016-10-30 13:50:40.082691+00', '2016-10-30 13:50:40.082691+00', 'A'' The Way to Galloway', 9999, '');
INSERT INTO 'tune' VALUES (13383, '2016-10-30 13:53:51.704817+00', '2016-10-30 13:53:51.704817+00', 'Solway Sands', 2409, '');
INSERT INTO 'tune' VALUES (13384, '2016-10-30 13:56:05.51573+00', '2016-10-30 13:56:05.51573+00', 'Dashwood Square', 2409, '');
INSERT INTO 'tune' VALUES (13385, '2016-10-30 14:14:13.541914+00', '2016-10-30 14:14:13.541914+00', 'Ian Kirkpatrick''s Strathspey', 1668, '');
INSERT INTO 'tune' VALUES (13388, '2016-10-30 17:38:39.666822+00', '2016-10-30 17:38:39.666822+00', 'Willie Little''s Jig', 1668, '');
INSERT INTO 'tune' VALUES (13389, '2016-10-30 17:47:35.965745+00', '2016-10-30 17:47:35.965745+00', 'Welcome Home', 11407, '');
INSERT INTO 'tune' VALUES (13390, '2016-10-30 17:52:24.92376+00', '2016-10-30 17:52:24.92376+00', 'Hope (Mrs Hope Little)', 11408, '');
INSERT INTO 'tune' VALUES (13391, '2016-10-30 17:58:05.016192+00', '2016-10-30 17:58:05.016192+00', 'Ardwall', 11409, '');
INSERT INTO 'tune' VALUES (4412, NULL, '2016-10-30 20:33:42.029629+00', 'Mistress Elaine', 1926, '');
INSERT INTO 'tune' VALUES (13392, '2016-10-30 20:43:24.63958+00', '2016-10-30 20:43:24.63958+00', 'Wee Mary Ellen Wilson''s Air', 1668, '');
INSERT INTO 'tune' VALUES (13393, '2016-10-30 21:41:27.696603+00', '2016-10-30 21:41:27.696603+00', 'Jenny Robertson''s Strathspey', 1591, '');
INSERT INTO 'tune' VALUES (13394, '2016-10-30 22:14:34.56819+00', '2016-10-30 22:14:34.56819+00', 'Kirsten & Rowan''s Time in Da Herra', 1591, '');
INSERT INTO 'tune' VALUES (13395, '2016-10-30 22:21:01.703211+00', '2016-10-30 22:21:01.703211+00', 'Primo McFarlane''s Reel', 11410, '');
INSERT INTO 'tune' VALUES (13396, '2016-10-30 22:21:56.265514+00', '2016-10-30 22:21:56.265514+00', 'Da Trivial O''t', 11410, '');
INSERT INTO 'tune' VALUES (13409, '2016-10-30 23:24:58.90181+00', '2018-10-14 00:09:38.72569+00', 'Ross Memorial Hospital, The', 1761, '');
INSERT INTO 'tune' VALUES (13397, '2016-10-30 22:25:55.893441+00', '2016-10-30 22:26:58.800924+00', 'Brig o'' Broch', 1786, '');
INSERT INTO 'tune' VALUES (13398, '2016-10-30 22:27:26.371612+00', '2016-10-30 22:27:26.371612+00', 'Glenfarquhar', 1786, '');
INSERT INTO 'tune' VALUES (13400, '2016-10-30 22:57:35.91279+00', '2016-10-30 22:57:35.91279+00', 'Spirit of Mortlach, The', 1591, '');
INSERT INTO 'tune' VALUES (13401, '2016-10-30 22:58:06.055517+00', '2016-10-30 22:58:06.055517+00', 'Golden Nectar', 1591, '');
INSERT INTO 'tune' VALUES (13402, '2016-10-30 22:58:42.869485+00', '2016-10-30 22:58:42.869485+00', 'Morning After, The', 1591, '');
INSERT INTO 'tune' VALUES (13403, '2016-10-30 22:59:16.24808+00', '2016-10-30 22:59:16.24808+00', 'Compliments to Rob Sargent', 1591, '');
INSERT INTO 'tune' VALUES (13404, '2016-10-30 23:00:32.421524+00', '2016-10-30 23:00:32.421524+00', 'Gardener, The', 1591, '');
INSERT INTO 'tune' VALUES (13405, '2016-10-30 23:10:57.697722+00', '2016-10-30 23:10:57.697722+00', 'May''s 90th', 2856, '');
INSERT INTO 'tune' VALUES (13406, '2016-10-30 23:13:55.570198+00', '2016-10-30 23:13:55.570198+00', 'Fraser Cailean Donaldson', 1543, '');
INSERT INTO 'tune' VALUES (13407, '2016-10-30 23:19:48.873482+00', '2016-10-30 23:19:48.873482+00', 'Mr Ritchie''s Strathspey', 11411, '');
INSERT INTO 'tune' VALUES (13413, '2016-10-31 20:51:23.549329+00', '2016-10-31 20:51:23.549329+00', 'Ken and Petula''s Wedding', 1576, '');
INSERT INTO 'tune' VALUES (13387, '2016-10-30 17:36:07.333325+00', '2018-10-14 23:12:53.398896+00', 'Beeches, The', 433, '');
INSERT INTO 'tune' VALUES (13415, '2016-11-06 18:04:46.27322+00', '2016-11-06 18:04:46.27322+00', 'Mrs Abernethy''s Strathspey', 1934, '');
INSERT INTO 'tune' VALUES (13416, '2016-11-06 18:06:51.76564+00', '2016-11-06 18:06:51.76564+00', 'Forbes Sheeshin Mull', 9999, '');
INSERT INTO 'tune' VALUES (13417, '2016-11-06 18:20:30.841245+00', '2016-11-06 18:20:30.841245+00', 'Mr Willm. Fordyce''s Strathspey', 1934, '');
INSERT INTO 'tune' VALUES (10181, '2009-08-02 22:00:00+00', '2016-12-01 00:15:38.756026+00', 'Miss Haldane of Gleneagles', 1845, '');
INSERT INTO 'tune' VALUES (13418, '2016-12-14 22:11:34.48993+00', '2016-12-14 22:11:34.48993+00', 'God Rest Ye Merry Gentlemen', 9999, '');
INSERT INTO 'tune' VALUES (3474, NULL, '2016-12-14 22:12:50.974738+00', 'Deck the Halls', 9999, '');
INSERT INTO 'tune' VALUES (13419, '2016-12-14 22:17:28.423307+00', '2016-12-14 22:17:28.423307+00', 'It''s Beginning to Look a Lot Like Christmas', 11417, '');
INSERT INTO 'tune' VALUES (13420, '2016-12-14 22:19:55.272768+00', '2016-12-14 22:19:55.272768+00', 'Pantomime Horse', 3296, '');
INSERT INTO 'tune' VALUES (13421, '2016-12-14 22:21:25.536281+00', '2016-12-14 22:21:25.536281+00', 'Brucks o'' Yule, Da', 1786, '');
INSERT INTO 'tune' VALUES (13422, '2016-12-14 22:24:05.739064+00', '2016-12-14 22:24:09.344475+00', 'Grandma Got Run Over By A Reindeer', 11418, '');
INSERT INTO 'tune' VALUES (13423, '2016-12-14 22:24:49.073483+00', '2016-12-14 22:24:49.073483+00', 'O Come All Ye Faithful', 9999, '');
INSERT INTO 'tune' VALUES (13424, '2016-12-14 22:26:42.508128+00', '2016-12-14 22:26:42.508128+00', 'Silver Bells', 11419, '');
INSERT INTO 'tune' VALUES (13425, '2016-12-14 22:28:13.070066+00', '2016-12-14 22:28:13.070066+00', 'Santie''s Reindeer', 11420, '');
INSERT INTO 'tune' VALUES (13426, '2016-12-14 22:30:15.485076+00', '2016-12-14 22:30:15.485076+00', 'While Shepherds Watched', 9999, '');
INSERT INTO 'tune' VALUES (13427, '2016-12-14 22:33:02.013605+00', '2016-12-14 22:33:02.013605+00', 'Have Yourself a Merry Little Christmas', 11421, '');
INSERT INTO 'tune' VALUES (13428, '2016-12-14 22:35:47.549333+00', '2016-12-14 22:35:47.549333+00', 'Fairytale of New York', 11422, '');
INSERT INTO 'tune' VALUES (13429, '2016-12-14 22:36:20.280289+00', '2016-12-14 22:36:20.280289+00', 'Snowmen''s Dance, The', 3792, '');
INSERT INTO 'tune' VALUES (13430, '2016-12-14 22:37:25.407683+00', '2016-12-14 22:37:25.407683+00', 'Saviour''s Day', 11423, '');
INSERT INTO 'tune' VALUES (13431, '2016-12-14 22:39:32.984525+00', '2016-12-14 22:39:32.984525+00', 'Jolly Old St. Nicholas', 9999, '');
INSERT INTO 'tune' VALUES (13432, '2016-12-14 22:40:54.254417+00', '2016-12-14 22:40:54.254417+00', 'Angels From The Realms Of Glory', 11424, '');
INSERT INTO 'tune' VALUES (13433, '2016-12-14 22:41:21.394688+00', '2016-12-14 22:41:21.394688+00', 'Unto Us a Child is Born', 9999, '');
INSERT INTO 'tune' VALUES (13434, '2016-12-14 22:41:50.348047+00', '2016-12-14 22:41:50.348047+00', 'Little Jesus Sweetly Sleep', 9999, '');
INSERT INTO 'tune' VALUES (13435, '2016-12-14 22:43:45.757159+00', '2016-12-14 22:43:45.757159+00', 'Walking In The Air', 3792, '');
INSERT INTO 'tune' VALUES (13436, '2016-12-14 22:45:48.768779+00', '2016-12-14 22:45:48.768779+00', 'I Believe in Father Christmas', 11425, '');
INSERT INTO 'tune' VALUES (13437, '2016-12-14 22:47:51.906603+00', '2016-12-14 22:47:51.906603+00', 'White Christmas', 2321, '');
INSERT INTO 'tune' VALUES (13410, '2016-10-30 23:28:21.969998+00', '2022-12-23 13:38:01.529597+00', 'Isla''s Reel', 10086, '');
INSERT INTO 'tune' VALUES (13412, '2016-10-30 23:29:51.88453+00', '2022-12-23 13:38:29.435159+00', 'Derek and Katy''s Reel', 10086, '');
INSERT INTO 'tune' VALUES (13440, '2016-12-14 22:52:55.124775+00', '2016-12-14 22:52:55.124775+00', 'Christmas in Killarney', 11427, '');
INSERT INTO 'tune' VALUES (13441, '2016-12-14 22:53:32.139532+00', '2016-12-14 22:53:32.139532+00', 'Old Man, The', 2321, '');
INSERT INTO 'tune' VALUES (13442, '2016-12-14 22:56:11.718275+00', '2016-12-14 22:56:11.718275+00', 'Once In Royal David''s City', 11428, '');
INSERT INTO 'tune' VALUES (13443, '2016-12-14 22:59:52.400923+00', '2016-12-14 22:59:52.400923+00', 'Hark, the Herald Angels Sing', 3460, '');
INSERT INTO 'tune' VALUES (13444, '2016-12-14 23:02:02.690844+00', '2016-12-14 23:02:02.690844+00', 'I Saw Mummy Kissing Santa Claus', 11429, '');
INSERT INTO 'tune' VALUES (13445, '2016-12-14 23:03:30.095116+00', '2016-12-14 23:03:30.095116+00', 'Wonderful Christmas Time', 11430, '');
INSERT INTO 'tune' VALUES (13446, '2016-12-14 23:04:41.320855+00', '2016-12-14 23:04:41.320855+00', 'Merry Christmas Everyone', 11431, '');
INSERT INTO 'tune' VALUES (13447, '2016-12-14 23:07:17.769596+00', '2016-12-14 23:07:17.769596+00', 'I Wish It Could Be Christmas Every Day', 11432, '');
INSERT INTO 'tune' VALUES (13448, '2016-12-14 23:09:19.353552+00', '2016-12-14 23:09:19.353552+00', 'Everybody''s Waiting', 11433, '');
INSERT INTO 'tune' VALUES (13449, '2016-12-14 23:10:02.055237+00', '2016-12-14 23:10:02.055237+00', 'Rocking Around The Christmas Tree', 3807, '');
INSERT INTO 'tune' VALUES (13450, '2016-12-14 23:12:46.586221+00', '2016-12-14 23:12:46.586221+00', 'Joy To The World', 11156, '');
INSERT INTO 'tune' VALUES (13451, '2016-12-14 23:13:18.430724+00', '2016-12-14 23:13:18.430724+00', 'I Saw Three Ships', 9999, '');
INSERT INTO 'tune' VALUES (13452, '2016-12-14 23:17:13.068537+00', '2016-12-14 23:17:13.068537+00', 'Six White Boomers', 11434, '');
INSERT INTO 'tune' VALUES (13453, '2016-12-14 23:19:22.202285+00', '2016-12-14 23:19:22.202285+00', 'Child in a Manger', 9999, '');
INSERT INTO 'tune' VALUES (13454, '2016-12-15 00:15:40.099356+00', '2016-12-15 00:15:40.099356+00', 'Angelika''s Fancy', 11067, '');
INSERT INTO 'tune' VALUES (11581, '2011-08-22 22:00:00+00', '2016-12-17 21:29:24.574452+00', 'Link (Mrs Linklater Shirras)', 1586, 'Mrs. Linklater Shirras was affectionately known as "Link".');
INSERT INTO 'tune' VALUES (13386, '2016-10-30 17:32:03.503924+00', '2018-10-14 23:13:21.823218+00', 'Light of Hope, The', 11406, '');
INSERT INTO 'tune' VALUES (13455, '2016-12-27 00:31:27.670791+00', '2016-12-27 00:41:37.34221+00', 'Auction Sale Breakdown, The', 3798, 'A reel');
INSERT INTO 'tune' VALUES (13456, '2016-12-27 01:08:01.89165+00', '2016-12-27 01:08:01.89165+00', 'Slingshot', 2977, '');
INSERT INTO 'tune' VALUES (13457, '2016-12-31 15:21:21.524076+00', '2016-12-31 15:21:21.524076+00', 'Two Rivers', 1765, '');
INSERT INTO 'tune' VALUES (13458, '2017-01-16 20:02:01.51088+00', '2017-01-16 20:02:01.51088+00', 'Fiddler Crabs', 3383, '');
INSERT INTO 'tune' VALUES (4071, NULL, '2017-01-18 08:01:58.593844+00', 'John Turner''s Compliments to Governor Adams', 3383, '');
INSERT INTO 'tune' VALUES (13459, '2017-01-20 03:28:34.107227+00', '2017-01-20 03:28:34.107227+00', 'Seton''s Two', 1042, '');
INSERT INTO 'tune' VALUES (13460, '2017-01-20 03:29:28.328991+00', '2017-01-20 03:29:28.328991+00', 'Celebration Waltz', 1042, '');
INSERT INTO 'tune' VALUES (13461, '2017-01-20 03:34:24.544094+00', '2017-01-20 03:34:24.544094+00', 'Val Mitchell''s Reel', 1042, '');
INSERT INTO 'tune' VALUES (13585, '2017-05-19 18:18:48.317279+00', '2018-10-30 17:22:51.741547+00', 'Christmas Day in da Mornin''', 3297, '');
INSERT INTO 'tune' VALUES (13411, '2016-10-30 23:29:11.337858+00', '2018-12-07 17:30:21.792195+00', 'Reel for Tazuko, A', 1591, '');
INSERT INTO 'tune' VALUES (13462, '2017-01-20 03:35:56.585565+00', '2017-01-20 03:43:33.071784+00', 'Mairi MacNaughton of Strontian', 1042, 'This tune belongs to "The Strontian Trilogy", three Watzes composed by A Bruce Fordyce.

The Strontian Trilogy comprises "Mairi MacNaughton of Strontian," "Ruby MacNaughton of ''Carm''" and "Corran Ferry."');
INSERT INTO 'tune' VALUES (13588, '2017-05-19 18:24:00.735492+00', '2017-05-19 18:24:00.735492+00', 'North''s Hornpipe', 1829, '');
INSERT INTO 'tune' VALUES (14056, '2019-06-14 19:47:36.977486+00', '2019-06-14 19:47:36.977486+00', 'Mumbai', 2160, '');
INSERT INTO 'tune' VALUES (13463, '2017-01-20 03:37:24.397254+00', '2017-01-20 03:43:23.725386+00', 'Ruby MacNaughton of ''Carm''', 1042, 'This tune belongs to "The Strontian Trilogy", three Watzes composed by A Bruce Fordyce.

The Strontian Trilogy comprises "Mairi MacNaughton of Strontian," "Ruby MacNaughton of ''Carm''" and "Corran Ferry."');
INSERT INTO 'tune' VALUES (13464, '2017-01-20 03:38:21.873602+00', '2017-01-20 03:43:48.256526+00', 'Corran Ferry', 1042, 'This tune belongs to "The Strontian Trilogy", three Watzes composed by A Bruce Fordyce.

The Strontian Trilogy comprises "Mairi MacNaughton of Strontian," "Ruby MacNaughton of ''Carm''" and "Corran Ferry."');
INSERT INTO 'tune' VALUES (13465, '2017-02-03 17:21:59.807862+00', '2017-02-03 17:21:59.807862+00', 'Alastair in the Den', 9998, '');
INSERT INTO 'tune' VALUES (13466, '2017-02-03 17:40:31.11264+00', '2017-02-03 17:40:31.11264+00', 'Bonnie Woods o'' Stirkot, The', 9998, '');
INSERT INTO 'tune' VALUES (11375, '2010-10-08 22:00:00+00', '2017-02-05 00:16:12.411232+00', 'Now is the Month of Maying', 9999, 'Composer:  Thomas Morley.  (1557  -  1602)');
INSERT INTO 'tune' VALUES (13468, '2017-02-12 12:14:14.458454+00', '2017-02-12 12:14:14.458454+00', 'Sean Stewart of Kelty', 2516, '');
INSERT INTO 'tune' VALUES (13469, '2017-02-12 12:15:05.414534+00', '2017-02-12 12:15:05.414534+00', 'Hamemader Reel, The', 2516, '');
INSERT INTO 'tune' VALUES (13470, '2017-02-12 12:17:25.918682+00', '2017-02-12 12:17:25.918682+00', 'Full Marks to Bill Hendry', 1777, '');
INSERT INTO 'tune' VALUES (13471, '2017-02-12 12:20:02.36722+00', '2017-02-12 12:20:02.36722+00', 'Pride of Loch Norman, The', 3683, '');
INSERT INTO 'tune' VALUES (13472, '2017-02-12 12:33:00.297492+00', '2017-02-12 12:33:00.297492+00', 'Mrs Major Mitchell''s Strathspey', 1516, '');
INSERT INTO 'tune' VALUES (13523, '2017-02-24 22:10:51.54702+00', '2018-10-14 00:06:21.188097+00', 'Maid of Forfar, The', 9998, 'Published in the Angus SCD Book.  Probably derived from the Caledonian Companion collection of traditional Scottish tunes');
INSERT INTO 'tune' VALUES (13530, '2017-03-01 23:08:03.800702+00', '2017-03-01 23:08:03.800702+00', 'New Potato, The', 11457, '');
INSERT INTO 'tune' VALUES (13702, '2017-11-02 17:47:15.439407+00', '2017-11-02 17:47:15.439407+00', 'Striking Gold', 1582, '');
INSERT INTO 'tune' VALUES (13517, '2017-02-24 21:58:45.228267+00', '2017-02-24 22:02:26.502783+00', 'Montrose Dancers', 9998, 'Published in the Angus SCD Book.  Probably derived from the Caledonian Companion collection of traditional Scottish tunes, perhaps under a different name.');
INSERT INTO 'tune' VALUES (13474, '2017-02-12 12:54:17.241431+00', '2017-02-12 12:54:17.241431+00', 'Miss Dalrymple (of North Berwick''s) Reel', 1519, '');
INSERT INTO 'tune' VALUES (13475, '2017-02-12 13:06:42.004561+00', '2017-02-12 13:06:42.004561+00', 'Miss Garden of Troup''s Reel', 1519, 'This tune doesn''t seem to exist in “The Mackintosh Collections” (ed. Charles Gore) from the Highland Music Trust, and <<http://tunearch.org|tunearch.org>> doesn''t know anything about it, either.');
INSERT INTO 'tune' VALUES (13476, '2017-02-12 13:35:16.351919+00', '2017-02-12 13:35:16.351919+00', 'Duchess of Bedford''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (13477, '2017-02-12 13:36:59.897953+00', '2017-02-12 13:36:59.897953+00', 'Miss Oswald (of Scotstown''s) Reel', 1519, '');
INSERT INTO 'tune' VALUES (13478, '2017-02-12 13:39:41.938481+00', '2017-02-12 13:39:41.938481+00', 'Man O'' Wee', 1646, '');
INSERT INTO 'tune' VALUES (13480, '2017-02-12 13:47:28.029482+00', '2017-02-12 13:47:28.029482+00', 'McLeans of Keillor, The', 1811, '');
INSERT INTO 'tune' VALUES (13481, '2017-02-12 13:50:02.464804+00', '2017-02-12 13:50:02.464804+00', 'Luke Brady''s Compliments to Helen Russell', 3683, '');
INSERT INTO 'tune' VALUES (13482, '2017-02-12 13:52:58.476887+00', '2017-02-12 13:52:58.476887+00', 'Mairi''s Alternative Wedding', 1502, '');
INSERT INTO 'tune' VALUES (13483, '2017-02-13 10:57:34.208008+00', '2017-02-13 10:57:34.208008+00', 'Bonnieviews O''Forse Caithness', 3203, '');
INSERT INTO 'tune' VALUES (13484, '2017-02-13 10:58:11.535197+00', '2017-02-13 10:58:11.535197+00', 'Wullie Scott''s', 3203, '');
INSERT INTO 'tune' VALUES (13486, '2017-02-13 11:05:17.21129+00', '2017-02-13 11:05:17.21129+00', 'One for the Road', 1808, '');
INSERT INTO 'tune' VALUES (13487, '2017-02-13 11:06:07.468095+00', '2017-02-13 11:07:17.97796+00', 'Dancer''s Dream, A', 3220, '');
INSERT INTO 'tune' VALUES (13489, '2017-02-13 11:09:53.82358+00', '2017-02-13 11:09:53.82358+00', 'Flying Scots', 3220, '');
INSERT INTO 'tune' VALUES (5409, NULL, '2017-02-13 11:10:41.684904+00', 'Willy Walsh''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (13490, '2017-02-13 11:11:27.400507+00', '2017-02-13 11:11:27.400507+00', 'Hamish Colgan''s Railway Sessions', 3220, '');
INSERT INTO 'tune' VALUES (13491, '2017-02-13 11:18:15.911159+00', '2017-02-13 11:18:15.911159+00', 'Our Golden Wedding', 3203, '');
INSERT INTO 'tune' VALUES (13492, '2017-02-13 11:18:47.060786+00', '2017-02-13 11:18:47.060786+00', 'Lugton Strathspey, The', 3203, '');
INSERT INTO 'tune' VALUES (13493, '2017-02-13 11:19:20.022755+00', '2017-02-13 11:19:20.022755+00', 'Risin'' Stour', 3203, '');
INSERT INTO 'tune' VALUES (13494, '2017-02-13 11:20:13.02468+00', '2017-02-13 11:20:13.02468+00', 'A82 Appreciation Society, The', 3203, '');
INSERT INTO 'tune' VALUES (13495, '2017-02-13 11:22:30.264733+00', '2017-02-13 11:22:30.264733+00', 'Brian Campbell''s Reel', 3220, '');
INSERT INTO 'tune' VALUES (13496, '2017-02-13 11:23:07.095008+00', '2017-02-13 11:23:07.095008+00', 'Audrey''s Exposure', 3220, '');
INSERT INTO 'tune' VALUES (13497, '2017-02-13 11:23:45.892365+00', '2017-02-13 11:23:45.892365+00', 'Punch Maker, The', 10892, '');
INSERT INTO 'tune' VALUES (13498, '2017-02-13 11:27:18.589163+00', '2017-02-13 11:27:18.589163+00', 'Sailing South', 3693, '');
INSERT INTO 'tune' VALUES (13499, '2017-02-13 11:27:53.750666+00', '2017-02-13 11:27:53.750666+00', 'To Pauline', 3220, '');
INSERT INTO 'tune' VALUES (13501, '2017-02-13 11:37:50.532564+00', '2017-02-13 11:37:50.532564+00', 'Dunsmore Bat, The', 3220, '');
INSERT INTO 'tune' VALUES (13502, '2017-02-13 11:42:39.6535+00', '2017-02-13 11:42:39.6535+00', 'Snow in Summer', 3220, '');
INSERT INTO 'tune' VALUES (13503, '2017-02-13 11:44:59.730254+00', '2017-02-13 11:44:59.730254+00', 'Mr Graham W Donald', 1502, '');
INSERT INTO 'tune' VALUES (13504, '2017-02-13 11:47:59.117006+00', '2017-02-13 11:47:59.117006+00', 'Ruthless', 11451, '');
INSERT INTO 'tune' VALUES (12549, '2013-06-21 07:25:02.20469+00', '2017-02-13 11:50:15.870948+00', 'Slåttesmeden', 1846, 'The alias spelling is found on the CD Opus Dance, but is a typo according to James Gray.

The other alias is the translation given in the Tweeddale Collection 4.');
INSERT INTO 'tune' VALUES (13505, '2017-02-13 11:51:13.124217+00', '2017-02-13 11:51:13.124217+00', 'Miss Esme McLeod''s Welcome to the Princess Royal', 1463, '');
INSERT INTO 'tune' VALUES (13506, '2017-02-13 12:02:11.968033+00', '2017-02-13 12:02:11.968033+00', 'Eleanor''s Strathspey', 3220, '');
INSERT INTO 'tune' VALUES (13507, '2017-02-13 12:02:51.185328+00', '2017-02-13 12:02:51.185328+00', 'Farewell to Benbecula', 3220, '');
INSERT INTO 'tune' VALUES (13508, '2017-02-13 12:05:02.94039+00', '2017-02-13 12:05:02.94039+00', 'Carol Campbell''s Jig', 2126, '');
INSERT INTO 'tune' VALUES (13467, '2017-02-03 17:51:49.336961+00', '2022-12-18 20:30:16.553603+00', 'Margaret Thomson''s Quickstep', 1520, '');
INSERT INTO 'tune' VALUES (9518, NULL, '2017-02-13 12:06:06.94272+00', 'Helen & Jimmy King of Auchinelvich', 1575, '');
INSERT INTO 'tune' VALUES (13509, '2017-02-13 14:07:32.763233+00', '2017-02-13 14:07:32.763233+00', 'Arbroath Reel, The', 11355, '');
INSERT INTO 'tune' VALUES (13510, '2017-02-13 14:11:39.195045+00', '2017-02-13 14:11:39.195045+00', 'Rejected Reel, The', 11452, '');
INSERT INTO 'tune' VALUES (13511, '2017-02-13 14:23:52.73479+00', '2017-02-13 14:23:52.73479+00', 'Snowman''s Fancy', 9999, '');
INSERT INTO 'tune' VALUES (13512, '2017-02-13 14:25:40.744989+00', '2017-02-13 14:25:40.744989+00', 'Love Life to the Max', 3220, '');
INSERT INTO 'tune' VALUES (13513, '2017-02-13 14:26:01.095551+00', '2017-02-13 14:26:01.095551+00', 'Rio', 3220, '');
INSERT INTO 'tune' VALUES (10045, '2007-01-26 23:00:00+00', '2017-02-24 21:48:10.701263+00', 'Olwynne''s Fancy', 1692, 'The music is dedicated to Olwynne Taylor – pianist at Montrose for many years – in appreciation of her patience and lovely music.');
INSERT INTO 'tune' VALUES (13514, '2017-02-24 21:55:15.553939+00', '2017-02-24 21:55:15.553939+00', 'Strathspey for the Braw Twa', 9998, 'Published in the Angus SCD Book.  Probably derived from the Caledonian Companion collection of traditional Scottish tunes');
INSERT INTO 'tune' VALUES (13479, '2017-02-12 13:44:54.439355+00', '2019-06-07 12:32:50.910998+00', 'Gilderoy', 9999, '');
INSERT INTO 'tune' VALUES (13516, '2017-02-24 21:57:10.993069+00', '2017-02-24 21:57:19.907931+00', 'Kirriemuir Hop', 9998, 'Published in the Angus SCD Book.  Probably derived from the Caledonian Companion collection of traditional Scottish tunes');
INSERT INTO 'tune' VALUES (13518, '2017-02-24 22:01:10.741706+00', '2017-02-24 22:01:49.663257+00', 'Flower of Forfar', 9998, 'Published in the Angus SCD Book.  Probably derived from the Caledonian Companion collection of traditional Scottish tunes, perhaps with a different name');
INSERT INTO 'tune' VALUES (13520, '2017-02-24 22:06:08.851709+00', '2017-02-24 22:06:08.851709+00', 'Unich Jig', 9998, 'Published in the Angus SCD Book.  Probably derived from the Caledonian Companion collection of traditional Scottish tunes');
INSERT INTO 'tune' VALUES (13521, '2017-02-24 22:07:33.554423+00', '2017-02-24 22:07:33.554423+00', 'Bruce''s Jig', 9998, 'Published in the Angus SCD Book.  Probably derived from the Caledonian Companion collection of traditional Scottish tunes');
INSERT INTO 'tune' VALUES (13522, '2017-02-24 22:08:45.290065+00', '2017-02-24 22:08:45.290065+00', 'Angus Prom', 9998, 'Published in the Angus SCD Book.  Probably derived from the Caledonian Companion collection of traditional Scottish tunes');
INSERT INTO 'tune' VALUES (13294, '2016-09-04 22:43:18.787406+00', '2017-02-24 22:09:21.810257+00', 'Aberlemno Lass', 9998, 'Published in the Angus SCD Book.  Probably derived from the Caledonian Companion collection of traditional Scottish tunes');
INSERT INTO 'tune' VALUES (13485, '2017-02-13 11:04:26.431493+00', '2017-03-07 16:45:46.139145+00', 'Ruth''s and Ronnie''s Strathspey', 3220, 'The publication spells the tune with "Ruth''s", the CD just "Ruth".');
INSERT INTO 'tune' VALUES (13488, '2017-02-13 11:09:29.141476+00', '2017-03-07 16:47:23.006293+00', 'Causeway Jig, The', 3220, '');
INSERT INTO 'tune' VALUES (13500, '2017-02-13 11:35:35.214454+00', '2017-03-07 16:51:00.444056+00', 'Lucy''s and Lyn''s Clinks Bag', 11450, 'The book spells the tune as in the title, the CD uses the alias.');
INSERT INTO 'tune' VALUES (13587, '2017-05-19 18:23:13.444993+00', '2017-05-19 18:23:13.444993+00', 'Macrobiotic Hornpipe, The', 2977, '');
INSERT INTO 'tune' VALUES (13524, '2017-02-24 22:11:55.64121+00', '2017-02-24 22:11:55.64121+00', 'Minuet', 9998, 'Published in the Angus SCD Book.  Probably derived from the Caledonian Companion collection of traditional Scottish tunes');
INSERT INTO 'tune' VALUES (13525, '2017-02-24 22:41:21.615897+00', '2017-02-24 22:41:21.615897+00', 'More W Inghean Ghiberlan', 9998, 'Published in the Angus SCD Book.  Probably derived from the Caledonian Companion collection of traditional Scottish tunes');
INSERT INTO 'tune' VALUES (13526, '2017-02-24 22:48:06.774842+00', '2017-02-24 22:48:06.774842+00', 'Highland Lassie', 9998, 'Published in the Angus SCD Book.  Probably derived from the Caledonian Companion collection of traditional Scottish tunes



A check needs to be made if this is the same tune as the "Highland Lassie" composed by Jim Johnstone');
INSERT INTO 'tune' VALUES (13527, '2017-02-24 22:51:00.612278+00', '2017-02-24 22:51:18.295151+00', 'May in Angus', 9998, 'Published in the Angus SCD Book.  Probably derived from the Caledonian Companion collection of traditional Scottish tunes');
INSERT INTO 'tune' VALUES (13528, '2017-02-25 09:53:56.295443+00', '2017-02-25 09:53:56.295443+00', 'Strupak', 1763, 'written in 2012');
INSERT INTO 'tune' VALUES (1648, NULL, '2017-02-25 17:18:02.733666+00', 'Saint Columba''s Sword', 9999, '');
INSERT INTO 'tune' VALUES (9714, NULL, '2017-02-25 18:43:45.738534+00', 'Kinrara', 1516, 'Was appropriated by the Gows under the title, “The Countess of Dalkeith”, and republished by the RSCDS by that name.');
INSERT INTO 'tune' VALUES (8833, NULL, '2017-02-25 19:23:45.793244+00', 'Miss Katherine Stewart Forbes of Auchmedden''s Strathspey', 1516, 'According to the <<http://tunearch.org/wiki/Annotation:Miss_Katherine_Stewart_Forbes|Traditional Tune Archive>>:



> Moyra Cowie (*The Life and Times of William Marshall*, 1999), thinks Miss Katherine was a relation

> of Sir William Forbes of Pitsligo Castle, a grandson of the 4th Laird who forfeited his entire holdings

> after Culloden, and who was sustained for a time on the kindness of his tenantry and friends, while

> he lived in caves disguised as a beggar. Sir William was a banker who was able to purchase the

> forfeited estate of Achmeddan.');
INSERT INTO 'tune' VALUES (13568, '2017-04-01 16:43:56.473593+00', '2017-04-01 16:43:56.473593+00', 'Chartreuse', 11050, 'Name guessed to be the same as the dance for which it was written.');
INSERT INTO 'tune' VALUES (12367, '2013-01-04 16:10:34.52707+00', '2017-03-01 23:12:50.886405+00', 'Saint Antoine Reel', 9999, '');
INSERT INTO 'tune' VALUES (13531, '2017-03-01 23:15:51.338596+00', '2017-03-01 23:15:51.338596+00', 'Jig in D', 9999, '');
INSERT INTO 'tune' VALUES (13570, '2017-04-05 13:35:38.93452+00', '2017-04-05 13:35:38.93452+00', 'Tribute to Alba', 11188, '');
INSERT INTO 'tune' VALUES (1775, NULL, '2017-03-01 23:29:12.053252+00', 'Wark o'' the Weavers, The', 9999, '');
INSERT INTO 'tune' VALUES (13532, '2017-03-01 23:42:24.973708+00', '2017-03-01 23:42:24.973708+00', 'Wizard''s Walk, The', 2086, '');
INSERT INTO 'tune' VALUES (13534, '2017-03-01 23:48:20.859134+00', '2017-03-01 23:48:20.859134+00', 'Ten Minutes Ago', 10229, 'From the musical, *Cinderella*.');
INSERT INTO 'tune' VALUES (13535, '2017-03-01 23:51:50.765571+00', '2017-03-01 23:51:50.765571+00', 'I Could Have Danced All Night', 11459, 'From the musical, *My Fair Lady*.');
INSERT INTO 'tune' VALUES (13536, '2017-03-01 23:54:52.020546+00', '2017-03-01 23:54:52.020546+00', 'Always Able', 11460, '');
INSERT INTO 'tune' VALUES (13537, '2017-03-02 00:03:29.028627+00', '2017-03-02 00:03:29.028627+00', 'Iggy and Squiggie', 1633, '');
INSERT INTO 'tune' VALUES (13538, '2017-03-02 00:05:14.578352+00', '2017-03-02 00:05:14.578352+00', 'Johnny Muise''s Reel', 1633, '');
INSERT INTO 'tune' VALUES (13539, '2017-03-02 00:24:12.595133+00', '2017-03-02 00:24:12.595133+00', 'Diamonds are a Girl''s Best Friend', 3803, '');
INSERT INTO 'tune' VALUES (8224, NULL, '2017-03-02 00:27:26.229696+00', 'Get Me to the Church on Time', 11459, 'From the musical, *My Fair Lady*.');
INSERT INTO 'tune' VALUES (13540, '2017-03-02 00:27:43.256754+00', '2017-03-02 00:27:43.256754+00', 'Wells Fargo Wagon, The', 11417, 'From the musical, *The Music Man*.');
INSERT INTO 'tune' VALUES (13541, '2017-03-02 00:34:30.220138+00', '2017-03-02 00:34:30.220138+00', 'Late Summer Air', 11461, '');
INSERT INTO 'tune' VALUES (13569, '2017-04-03 17:57:15.068341+00', '2017-04-25 05:58:32.099673+00', 'Tanz mit Susanne, Ein', 11473, 'Both this tune and its corresponding dance were written for Susanne Reichhardt, an enthusiastic dancer who joined our Canberra dancing community for several years.');
INSERT INTO 'tune' VALUES (13542, '2017-03-10 15:48:49.592265+00', '2017-03-10 15:50:16.214319+00', 'An Tainig Thu Air à Bhata?', 1621, 'Jan 2007');
INSERT INTO 'tune' VALUES (13543, '2017-03-13 12:50:20.769132+00', '2017-03-13 12:50:20.769132+00', '3 J''s Jig', 1576, 'Score published with the kind permission of Deeay Music.');
INSERT INTO 'tune' VALUES (13264, '2016-01-01 12:52:44.277819+00', '2017-03-17 21:11:58.758222+00', 'Lady Ryder''s Strathspey', 1653, 'Written February 1992, for the dance lady Ryder of Warsaw, 4 x 48 S [play AB x3]



Brian Hamilton named the tune as above, but Helen [then Bonar] named the tune "Sue Ryder Strathspey" on the original dance description.');
INSERT INTO 'tune' VALUES (13544, '2017-03-22 10:31:55.446271+00', '2017-03-22 10:31:55.446271+00', 'Malcolm Coupe', 1764, '');
INSERT INTO 'tune' VALUES (13545, '2017-03-22 10:33:10.963556+00', '2017-03-22 10:33:10.963556+00', 'Honolulu Run, The', 1764, '');
INSERT INTO 'tune' VALUES (13546, '2017-03-22 10:49:20.45+00', '2017-03-22 10:49:20.45+00', 'Kitten''s Jig, The', 1764, '');
INSERT INTO 'tune' VALUES (13547, '2017-03-22 11:30:25.204867+00', '2017-03-22 11:30:25.204867+00', 'Dean MacKay''s Scots Measure', 1764, '');
INSERT INTO 'tune' VALUES (13548, '2017-03-22 11:31:21.416253+00', '2017-03-22 11:31:21.416253+00', 'Rosemary Read', 1764, '');
INSERT INTO 'tune' VALUES (13549, '2017-03-22 11:32:06.861293+00', '2017-03-22 11:32:06.861293+00', 'Lions Gate', 1764, '');
INSERT INTO 'tune' VALUES (13550, '2017-03-22 11:56:38.354115+00', '2017-03-22 11:56:38.354115+00', 'Here''s a Health to Them That''s Awa', 9999, '');
INSERT INTO 'tune' VALUES (13552, '2017-03-22 12:00:21.235175+00', '2017-03-22 12:00:21.235175+00', 'Dear David', 1764, '');
INSERT INTO 'tune' VALUES (13553, '2017-03-22 12:20:28.285459+00', '2017-03-22 12:20:28.285459+00', 'Pretty Peggy', 9999, '');
INSERT INTO 'tune' VALUES (13554, '2017-03-22 12:22:44.345791+00', '2017-03-22 12:22:44.345791+00', 'Andrew MacArthur', 1764, '');
INSERT INTO 'tune' VALUES (13555, '2017-03-22 12:23:41.279567+00', '2017-03-22 12:23:41.279567+00', 'Roaring Rivie', 9999, '');
INSERT INTO 'tune' VALUES (13556, '2017-03-22 12:24:58.756867+00', '2017-03-22 12:24:58.756867+00', 'Gassy Jack''s Eightsome', 1764, '');
INSERT INTO 'tune' VALUES (13557, '2017-03-22 12:26:19.042121+00', '2017-03-22 12:26:19.042121+00', 'New Westminster Strathspey', 1764, '');
INSERT INTO 'tune' VALUES (13558, '2017-03-22 12:27:23.981301+00', '2017-03-22 12:27:23.981301+00', 'Deighton''s Hoedown', 1764, '');
INSERT INTO 'tune' VALUES (13559, '2017-03-22 12:28:07.985513+00', '2017-03-22 12:28:07.985513+00', 'Forres Rant', 1764, '');
INSERT INTO 'tune' VALUES (13560, '2017-03-22 12:29:33.35616+00', '2017-03-22 12:29:33.35616+00', 'Agnes Maguire', 1764, '');
INSERT INTO 'tune' VALUES (13561, '2017-03-22 12:31:41.017839+00', '2017-03-22 12:31:41.017839+00', 'Buckie Rant, The', 1764, '');
INSERT INTO 'tune' VALUES (13563, '2017-03-22 12:33:10.787661+00', '2017-03-22 12:33:10.787661+00', 'Lisa Krause', 1764, '');
INSERT INTO 'tune' VALUES (13551, '2017-03-22 11:59:43.092459+00', '2017-03-24 18:09:19.80844+00', 'Linsay Duncan''s Scots Measure', 1764, '');
INSERT INTO 'tune' VALUES (13564, '2017-03-28 22:06:19.452248+00', '2017-03-28 22:06:19.452248+00', 'Perth meets Perth', 1525, '');
INSERT INTO 'tune' VALUES (13567, '2017-03-31 09:30:30.897402+00', '2017-03-31 09:30:30.897402+00', 'Oor Robbie''s Gowd For A'' That!', 10398, '');
INSERT INTO 'tune' VALUES (13565, '2017-03-31 09:27:45.900185+00', '2017-04-01 11:54:47.261003+00', 'Deca-dance', 10398, '');
INSERT INTO 'tune' VALUES (13566, '2017-03-31 09:29:29.731991+00', '2017-04-01 11:55:55.047551+00', 'Sackville Gardens', 10398, '');
INSERT INTO 'tune' VALUES (934, '2005-01-13 23:00:00+00', '2017-04-05 09:53:44.059106+00', 'Everything Stops for Tea', 11474, 'The song "Everything Stops for Tea" written by Maurice Sigler (tune) and Al Goodheart (lyrics). It was performed by Jack Buchanan in 1935 and was available on records and featured in Buchanan''s 1935 comedy film, “Come Out Of The Pantry”.');
INSERT INTO 'tune' VALUES (418, NULL, '2017-04-23 23:07:50.067346+00', 'Drumduan Cottage', 1586, 'The tune was composed by Drummond Cook, who used to live at Drumduan Cottage.');
INSERT INTO 'tune' VALUES (13572, '2017-04-30 09:13:54.217186+00', '2017-04-30 09:13:54.217186+00', 'Berkhamstead Jig, The', 1596, '');
INSERT INTO 'tune' VALUES (13574, '2017-04-30 09:54:30.542412+00', '2017-04-30 09:56:23.474366+00', 'Stephen Webb''s Hornpipe', 1596, '');
INSERT INTO 'tune' VALUES (13575, '2017-05-07 00:03:42.66988+00', '2017-05-07 00:03:42.66988+00', 'Wages of Gin, The', 3306, '');
INSERT INTO 'tune' VALUES (13576, '2017-05-07 00:04:13.407425+00', '2017-05-07 00:04:13.407425+00', 'Marble Walk, The', 2335, '');
INSERT INTO 'tune' VALUES (13577, '2017-05-07 00:08:12.427215+00', '2017-05-07 00:08:12.427215+00', 'Smoke in the Attic', 10025, '');
INSERT INTO 'tune' VALUES (13578, '2017-05-07 00:08:51.646797+00', '2017-05-07 00:08:51.646797+00', 'Gretl in the Garden', 3722, '');
INSERT INTO 'tune' VALUES (13579, '2017-05-07 00:09:51.55704+00', '2017-05-07 00:09:51.55704+00', 'Green Lady, The', 10315, '');
INSERT INTO 'tune' VALUES (13583, '2017-05-19 17:12:39.209664+00', '2018-10-14 00:27:58.332228+00', 'Murrays of Bentivar, The', 2977, '');
INSERT INTO 'tune' VALUES (13580, '2017-05-19 17:09:46.714046+00', '2017-05-19 17:11:17.201839+00', 'Thornton Jig, The', 11485, '');
INSERT INTO 'tune' VALUES (13581, '2017-05-19 17:11:48.829998+00', '2017-05-19 17:11:48.829998+00', 'Crowd in the Basement, The', 11483, '');
INSERT INTO 'tune' VALUES (13582, '2017-05-19 17:12:05.728927+00', '2017-05-19 17:12:05.728927+00', 'Jeannie', 11483, '');
INSERT INTO 'tune' VALUES (13584, '2017-05-19 18:16:53.865225+00', '2017-05-19 18:16:53.865225+00', 'Pigtown Fling, The', 9998, '');
INSERT INTO 'tune' VALUES (13586, '2017-05-19 18:20:38.059109+00', '2017-05-19 18:20:38.059109+00', 'Hell''s Mezzanine', 2977, '');
INSERT INTO 'tune' VALUES (13589, '2017-05-19 18:25:24.843341+00', '2017-05-19 18:25:24.843341+00', 'Mug of Brown Ale', 9998, '');
INSERT INTO 'tune' VALUES (13591, '2017-05-19 18:28:33.347456+00', '2017-05-19 18:28:33.347456+00', 'Unspoken', 1829, '');
INSERT INTO 'tune' VALUES (13592, '2017-05-19 18:33:34.759237+00', '2017-05-19 18:33:34.759237+00', 'Snowy Wedding', 11483, '');
INSERT INTO 'tune' VALUES (13593, '2017-05-19 18:34:53.133377+00', '2017-05-19 18:34:53.133377+00', 'Our Someday', 2977, '');
INSERT INTO 'tune' VALUES (13594, '2017-05-19 18:35:15.109512+00', '2017-05-19 18:35:15.109512+00', 'David Brooks', 1829, '');
INSERT INTO 'tune' VALUES (13595, '2017-05-19 18:35:32.524137+00', '2017-05-19 18:35:32.524137+00', 'Knight Blooming', 2977, '');
INSERT INTO 'tune' VALUES (13596, '2017-05-19 18:39:30.232138+00', '2017-05-19 18:39:30.232138+00', 'Tyro on the Tye', 2977, '');
INSERT INTO 'tune' VALUES (13598, '2017-05-24 22:34:32.291211+00', '2017-05-24 22:34:32.291211+00', 'Forever Yours', 11321, 'Inspired by Roy and Janet, I wanted the name tune to be stately, warm, and engaging, with a bit of a twinkle. So I was delighted to exploit the James Bond reference in the dance title to slip in a little musical reference of my own.

The second tune [Love Always] takes thematic segments of the first tune and expands them into a different, but related, direction.');
INSERT INTO 'tune' VALUES (13597, '2017-05-24 22:34:14.899247+00', '2017-05-24 22:44:39.184177+00', 'Love Always', 11321, 'Inspired by Roy and Janet, I wanted the name tune [Forever Yours] to be stately, warm, and engaging, with a bit of a twinkle. So I was delighted to exploit the James Bond reference in the dance title to slip in a little musical reference of my own.

The second tune [Love Always] takes thematic segments of the first tune and expands them into a different, but related, direction.');
INSERT INTO 'tune' VALUES (13599, '2017-05-27 16:25:40.962409+00', '2017-05-27 16:25:40.962409+00', 'An Active Octogenarian', 11321, 'An Active Octogenarian, music for "Susie''s Latest Promotion"');
INSERT INTO 'tune' VALUES (13600, '2017-06-07 09:12:05.539038+00', '2017-06-07 09:12:05.539038+00', 'Kissing Cozens', 1463, '');
INSERT INTO 'tune' VALUES (10415, '2009-11-08 23:00:00+00', '2017-06-10 00:23:51.525998+00', 'Susan Worland''s', 2724, 'Susan Worland is a great fiddler who spent many years in the Boston area, where she fiddled up a storm at many Scottish dance events. She moved to Berkely in 2000 after marrying Michael Bentley, but still comes back every year to play and visit. After her wedding in 1999, at which were present a throng of her long-time devoted friends, this tune spontaneously appeared, emanating from Tom''s accordion with a life of its own. [source: www.pixton.org]');
INSERT INTO 'tune' VALUES (13601, '2017-06-10 21:46:25.674519+00', '2017-06-10 21:46:25.674519+00', 'Alles Gute, liebe Leonie !', 10596, 'Fot the dance "Wunderbar" devised by Helen McGinley for Leonie Lübbe when she left Dublin to return home to Germany, June 2017.');
INSERT INTO 'tune' VALUES (13602, '2017-06-28 16:03:43.069565+00', '2017-06-28 16:03:43.069565+00', 'Gerbil Cheeks', 1502, '');
INSERT INTO 'tune' VALUES (13603, '2017-06-28 16:04:25.383592+00', '2017-06-28 16:04:25.383592+00', 'Jam-Reel, The', 3436, '');
INSERT INTO 'tune' VALUES (13604, '2017-06-28 17:49:02.605318+00', '2017-06-28 17:49:08.707369+00', 'Mira River', 1502, '');
INSERT INTO 'tune' VALUES (13605, '2017-06-28 17:49:39.084525+00', '2017-06-28 17:49:39.084525+00', 'Proxy Spouse, The', 1502, '');
INSERT INTO 'tune' VALUES (13606, '2017-06-28 17:53:20.054718+00', '2017-06-28 17:53:20.054718+00', 'Wouter''s Joy', 1502, '');
INSERT INTO 'tune' VALUES (13607, '2017-06-28 17:54:17.563156+00', '2017-06-28 17:54:17.563156+00', 'Creaky Stairs, The', 3436, '');
INSERT INTO 'tune' VALUES (13608, '2017-06-28 17:55:24.659108+00', '2017-06-28 17:55:24.659108+00', 'Katesanna', 3436, '');
INSERT INTO 'tune' VALUES (13609, '2017-06-28 17:57:38.182982+00', '2017-06-28 17:57:38.182982+00', 'Linda''s Laughter', 1502, '');
INSERT INTO 'tune' VALUES (13610, '2017-06-28 17:58:27.260321+00', '2017-06-28 17:58:27.260321+00', 'Kirsten''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (13611, '2017-06-28 17:59:19.255436+00', '2017-06-28 17:59:19.255436+00', 'Mischief on The West Wind', 1502, '');
INSERT INTO 'tune' VALUES (13612, '2017-06-28 18:08:46.76993+00', '2017-06-28 18:08:46.76993+00', 'Bee Sensible', 3436, '');
INSERT INTO 'tune' VALUES (13613, '2017-06-28 18:09:31.786509+00', '2017-06-28 18:09:31.786509+00', 'Moti''s Flute', 3436, '');
INSERT INTO 'tune' VALUES (13614, '2017-06-28 18:10:30.659331+00', '2017-06-28 18:10:30.659331+00', 'Renaissance Woman', 3436, '');
INSERT INTO 'tune' VALUES (1841, NULL, '2017-07-07 12:38:24.739027+00', 'Ye''ll aye be welcome back again', 9999, '');
INSERT INTO 'tune' VALUES (13615, '2017-07-07 12:54:54.831936+00', '2017-07-07 12:54:54.831936+00', 'Miss Bisset, Logierait', 1486, '');
INSERT INTO 'tune' VALUES (13616, '2017-07-07 13:10:18.321044+00', '2017-07-07 13:10:18.321044+00', 'Lady Ann Hope''s Strathspey', 9999, 'Not to be confused with <<ddt:Lady Ann Hope>>, which is an entirely different tune.');
INSERT INTO 'tune' VALUES (713, NULL, '2017-07-12 17:03:00.445947+00', 'Hot Punch', 9999, 'See also <<ddt:Orange and Blue>> for a strathspey version of this tune.');
INSERT INTO 'tune' VALUES (1431, NULL, '2017-07-12 17:03:17.661875+00', 'Orange and Blue', 9999, 'See also <<ddt:Hot Punch>> for a jig version of this tune.');
INSERT INTO 'tune' VALUES (13617, '2017-07-16 11:41:28.782558+00', '2017-07-16 11:41:28.782558+00', 'Miss Marshall of Melbourne', 11505, '');
INSERT INTO 'tune' VALUES (13618, '2017-07-16 11:47:13.537239+00', '2017-07-16 11:47:13.537239+00', 'Humpty''s Great Fall', 1575, '');
INSERT INTO 'tune' VALUES (13621, '2017-07-16 12:12:16.539237+00', '2017-07-16 12:12:16.539237+00', 'Mrs Grant', 1934, '');
INSERT INTO 'tune' VALUES (13622, '2017-07-16 12:16:02.631354+00', '2017-07-16 12:16:02.631354+00', 'Maureen Robson''s Jig', 1643, '');
INSERT INTO 'tune' VALUES (13414, '2016-11-06 18:03:26.300632+00', '2017-07-16 12:29:28.482147+00', 'Miss Isabella Reid''s Reel', 1934, '');
INSERT INTO 'tune' VALUES (13623, '2017-07-16 12:32:42.646846+00', '2017-07-16 12:32:42.646846+00', 'Mickie Banks', 1797, '');
INSERT INTO 'tune' VALUES (13619, '2017-07-16 11:50:32.772354+00', '2017-07-16 12:42:16.926662+00', 'Kathleen Bartlett of Go Home Bay', 709, '');
INSERT INTO 'tune' VALUES (964, NULL, '2017-07-25 19:29:55.616858+00', 'Lawland Lads think they are Fine, The', 1447, '');
INSERT INTO 'tune' VALUES (13625, '2017-08-23 11:24:50.657076+00', '2017-08-23 11:24:50.657076+00', 'Sunset over Connel Bridge', 3220, 'Written for Jens Heckmann.');
INSERT INTO 'tune' VALUES (539, NULL, '2017-08-26 22:36:20.529659+00', 'Foula Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (13626, '2017-08-26 22:44:57.394083+00', '2017-08-26 22:44:57.394083+00', 'McMahon''s', 9998, '');
INSERT INTO 'tune' VALUES (13627, '2017-08-26 23:28:07.927272+00', '2017-08-26 23:28:07.927272+00', 'Comet Valse', 11517, '');
INSERT INTO 'tune' VALUES (13628, '2017-08-26 23:42:02.286686+00', '2017-08-26 23:42:02.286686+00', 'Craig Lockhart', 11518, '');
INSERT INTO 'tune' VALUES (13630, '2017-08-26 23:47:58.033668+00', '2017-08-26 23:47:58.033668+00', 'Barbara''s Rant', 2689, '');
INSERT INTO 'tune' VALUES (13631, '2017-08-26 23:49:34.482239+00', '2017-08-26 23:49:34.482239+00', 'Sidney the Sausage Dog', 2689, '');
INSERT INTO 'tune' VALUES (13633, '2017-08-27 00:07:45.275505+00', '2017-08-27 00:07:45.275505+00', 'Urquharts of the Port, The', 2689, '');
INSERT INTO 'tune' VALUES (13634, '2017-09-16 14:17:31.490866+00', '2017-09-16 14:17:31.490866+00', 'When the Cae Comes Hame', 9998, '');
INSERT INTO 'tune' VALUES (13647, '2017-10-10 12:27:23.688941+00', '2018-04-09 00:11:37.41478+00', 'Christof''s Jig', 3179, 'For my son, Christof');
INSERT INTO 'tune' VALUES (13636, '2017-09-26 22:06:33.122879+00', '2017-09-26 22:06:33.122879+00', 'Quick Scotch', 9999, '');
INSERT INTO 'tune' VALUES (13637, '2017-09-26 23:03:48.469432+00', '2017-09-26 23:03:48.469432+00', 'Zhenya''s Winter Strathspey', 11530, '');
INSERT INTO 'tune' VALUES (13635, '2017-09-26 21:47:16.306214+00', '2017-09-26 23:29:06.595434+00', 'Happy Night', 11532, '');
INSERT INTO 'tune' VALUES (13644, '2017-10-10 12:23:31.706989+00', '2018-04-09 09:34:41.370807+00', 'Gallivanting Guineafowl', 3179, '');
INSERT INTO 'tune' VALUES (13638, '2017-10-09 15:32:46.693276+00', '2017-10-09 15:32:46.693276+00', 'Bencoolen, The', 2197, '');
INSERT INTO 'tune' VALUES (13639, '2017-10-09 15:33:51.463266+00', '2017-10-09 15:33:51.463266+00', 'Westward of Tuska', 2197, '');
INSERT INTO 'tune' VALUES (13640, '2017-10-09 15:34:44.833838+00', '2017-10-09 15:34:44.833838+00', 'Bude Haven', 2197, '');
INSERT INTO 'tune' VALUES (7622, NULL, '2017-10-09 15:37:07.478903+00', 'Captain Ferguson''s Jig', 2646, '');
INSERT INTO 'tune' VALUES (13641, '2017-10-09 15:38:24.702867+00', '2017-10-09 15:38:24.702867+00', '64 bar Jig', 2197, '');
INSERT INTO 'tune' VALUES (8035, NULL, '2017-10-09 15:40:47.165719+00', 'El Alamein', 2420, 'According to the information in Jim Rae''s booklet "A Dancing Tour, Vol. 2" the tune was composed by Pipe Major Wm Denholm.');
INSERT INTO 'tune' VALUES (13642, '2017-10-09 15:41:59.524833+00', '2017-10-09 15:41:59.524833+00', 'Jim Rae''s Compliments to Gordon Simpson', 479, '');
INSERT INTO 'tune' VALUES (13643, '2017-10-10 11:51:44.043444+00', '2017-10-10 11:51:44.043444+00', 'Road To Torridon, The', 2856, '');
INSERT INTO 'tune' VALUES (13651, '2017-10-10 12:30:25.245607+00', '2018-04-09 09:37:14.092489+00', 'Gratitude', 3179, '');
INSERT INTO 'tune' VALUES (13648, '2017-10-10 12:28:29.709137+00', '2018-04-09 13:25:25.946634+00', 'Miss Terry Lynne Harris', 3179, 'For my friend, Terry Lynne');
INSERT INTO 'tune' VALUES (13646, '2017-10-10 12:26:16.696774+00', '2018-04-10 07:41:24.618389+00', 'Sunny Seas', 11521, '');
INSERT INTO 'tune' VALUES (13590, '2017-05-19 18:25:57.952371+00', '2018-10-30 17:23:07.124363+00', 'Double Espresso', 11484, '');
INSERT INTO 'tune' VALUES (13629, '2017-08-26 23:44:05.615317+00', '2017-11-07 13:29:55.967591+00', 'Tommy Ford', 1578, 'Tommy Ford was the lead accordionist of Jim Macleod''s Band.');
INSERT INTO 'tune' VALUES (13732, '2017-11-08 13:53:39.355935+00', '2017-11-08 13:55:06.575224+00', 'Red Rose, The', 1621, '');
INSERT INTO 'tune' VALUES (13731, '2017-11-08 13:49:48.118487+00', '2017-11-08 13:56:53.010815+00', 'Miss Cholmondley Majoribanks'' Favorite', 1621, '');
INSERT INTO 'tune' VALUES (13718, '2017-11-08 11:28:05.316491+00', '2017-11-08 14:28:46.057206+00', 'Vancouver Welcome', 1621, '');
INSERT INTO 'tune' VALUES (13725, '2017-11-08 13:05:00.670908+00', '2017-11-08 14:38:14.605768+00', 'Miss Elizabeth Conder', 1621, '');
INSERT INTO 'tune' VALUES (13737, '2017-11-10 16:44:40.087014+00', '2017-11-10 16:44:40.087014+00', 'Memories of Ayr', 2054, '');
INSERT INTO 'tune' VALUES (13739, '2017-11-10 16:53:11.236311+00', '2017-11-10 16:53:11.236311+00', 'Elena''s Lullaby', 2965, '');
INSERT INTO 'tune' VALUES (13666, '2017-10-10 12:44:31.851319+00', '2017-10-10 12:44:31.851319+00', 'Highland Brigade''s March to Heilbron, The', 1700, 'arr. Wouter Joubert');
INSERT INTO 'tune' VALUES (13674, '2017-10-12 15:32:54.146446+00', '2017-10-12 15:32:54.146446+00', 'Here''s the Allepouss', 3201, '');
INSERT INTO 'tune' VALUES (13675, '2017-10-20 15:04:33.738549+00', '2017-10-20 15:04:33.738549+00', 'Return to Eilean Dubh', 2392, '');
INSERT INTO 'tune' VALUES (13676, '2017-10-22 22:01:54.44918+00', '2017-10-22 22:01:54.44918+00', 'St Andrews Day', 11537, '');
INSERT INTO 'tune' VALUES (13677, '2017-10-22 22:02:19.724863+00', '2017-10-22 22:02:19.724863+00', 'Scottish Covenant', 11537, '');
INSERT INTO 'tune' VALUES (13661, '2017-10-10 12:38:34.698778+00', '2018-04-07 23:28:15.793633+00', 'Thistle Protea, The', 3179, '');
INSERT INTO 'tune' VALUES (13679, '2017-11-02 16:59:07.646984+00', '2017-11-02 16:59:07.646984+00', 'Betty Ferguson', 1582, '');
INSERT INTO 'tune' VALUES (13680, '2017-11-02 17:00:09.809158+00', '2017-11-02 17:00:09.809158+00', 'York Branch', 1582, '');
INSERT INTO 'tune' VALUES (13681, '2017-11-02 17:01:47.634547+00', '2017-11-02 17:01:47.634547+00', 'All Rounder, The', 1582, '');
INSERT INTO 'tune' VALUES (13682, '2017-11-02 17:03:36.5314+00', '2017-11-02 17:03:36.5314+00', 'Cairngorm Strathspey, The', 1582, '');
INSERT INTO 'tune' VALUES (13683, '2017-11-02 17:05:31.199789+00', '2017-11-02 17:05:31.199789+00', 'Trip to Mull, A', 1582, '');
INSERT INTO 'tune' VALUES (13684, '2017-11-02 17:06:34.051388+00', '2017-11-02 17:06:34.051388+00', 'Children''s Celebration, The', 1582, '');
INSERT INTO 'tune' VALUES (13685, '2017-11-02 17:09:47.919714+00', '2017-11-02 17:09:47.919714+00', 'Reel for Eileen, A', 1582, '');
INSERT INTO 'tune' VALUES (13686, '2017-11-02 17:11:12.2099+00', '2017-11-02 17:11:12.2099+00', 'Hallowe''en Shadows', 1582, '');
INSERT INTO 'tune' VALUES (13687, '2017-11-02 17:12:14.80328+00', '2017-11-02 17:12:14.80328+00', 'Jim Stott''s Reel', 1582, '');
INSERT INTO 'tune' VALUES (13688, '2017-11-02 17:14:53.808338+00', '2017-11-02 17:14:53.808338+00', 'John''s Jig', 1582, '');
INSERT INTO 'tune' VALUES (13689, '2017-11-02 17:17:50.015297+00', '2017-11-02 17:17:50.015297+00', 'Mischievous Lindsay', 1582, '');
INSERT INTO 'tune' VALUES (13690, '2017-11-02 17:19:44.427034+00', '2017-11-02 17:19:44.427034+00', 'William''s Strathspey', 1582, '');
INSERT INTO 'tune' VALUES (13691, '2017-11-02 17:20:51.34661+00', '2017-11-02 17:20:51.34661+00', 'Moikei Gold', 1582, '');
INSERT INTO 'tune' VALUES (13692, '2017-11-02 17:21:44.218941+00', '2017-11-02 17:21:44.218941+00', 'Colin''s Jig', 1582, '');
INSERT INTO 'tune' VALUES (13693, '2017-11-02 17:22:46.220111+00', '2017-11-02 17:22:46.220111+00', 'Mrs Betsey Maxwell', 1582, '');
INSERT INTO 'tune' VALUES (13694, '2017-11-02 17:29:02.501386+00', '2017-11-02 17:29:02.501386+00', 'Mrs Sommerville''s Jig', 1582, '');
INSERT INTO 'tune' VALUES (13695, '2017-11-02 17:30:36.667457+00', '2017-11-02 17:30:36.667457+00', 'Natasha''s Jig', 1582, '');
INSERT INTO 'tune' VALUES (13696, '2017-11-02 17:39:09.413158+00', '2017-11-02 17:39:09.413158+00', 'Noble Hill Jig', 1582, '');
INSERT INTO 'tune' VALUES (13697, '2017-11-02 17:41:09.497432+00', '2017-11-02 17:41:09.497432+00', 'Pitter Patter', 1502, '');
INSERT INTO 'tune' VALUES (13698, '2017-11-02 17:42:34.519424+00', '2017-11-02 17:42:34.519424+00', 'Rachel & Tom Fenwick', 1582, '');
INSERT INTO 'tune' VALUES (13699, '2017-11-02 17:44:02.767937+00', '2017-11-02 17:44:02.767937+00', 'Amisfield Jig', 1582, '');
INSERT INTO 'tune' VALUES (13700, '2017-11-02 17:45:25.77788+00', '2017-11-02 17:45:25.77788+00', 'Love for Ever', 1582, '');
INSERT INTO 'tune' VALUES (13701, '2017-11-02 17:46:16.404024+00', '2017-11-02 17:46:16.404024+00', 'Jayne''s Strathspey', 1582, '');
INSERT INTO 'tune' VALUES (13703, '2017-11-02 17:48:06.898818+00', '2017-11-02 17:48:06.898818+00', 'Symmetry', 1582, '');
INSERT INTO 'tune' VALUES (13704, '2017-11-02 17:50:52.485488+00', '2017-11-02 17:50:52.485488+00', 'Max & Anne McNaught', 1582, '');
INSERT INTO 'tune' VALUES (13705, '2017-11-02 17:52:24.670236+00', '2017-11-02 17:52:24.670236+00', 'Ruby''s Strathspey', 1582, '');
INSERT INTO 'tune' VALUES (13706, '2017-11-02 17:53:50.441464+00', '2017-11-02 17:53:50.441464+00', 'RSCDS Dumfries', 1508, '');
INSERT INTO 'tune' VALUES (13707, '2017-11-02 17:55:23.398956+00', '2017-11-02 17:55:23.398956+00', 'Sandy Dodd''s Two-Step', 1582, '');
INSERT INTO 'tune' VALUES (13708, '2017-11-02 17:56:48.632003+00', '2017-11-02 17:56:48.632003+00', 'Change and Go', 1582, '');
INSERT INTO 'tune' VALUES (13709, '2017-11-02 17:58:13.755691+00', '2017-11-02 17:58:13.755691+00', 'DG Dancers'' Celebration', 1582, '');
INSERT INTO 'tune' VALUES (13710, '2017-11-02 17:59:55.797095+00', '2017-11-02 17:59:55.797095+00', 'Fancy meeting you!', 1582, '');
INSERT INTO 'tune' VALUES (13711, '2017-11-02 18:00:41.122413+00', '2017-11-02 18:00:41.122413+00', 'Hamburg 2012', 1582, '');
INSERT INTO 'tune' VALUES (13712, '2017-11-06 18:32:02.834633+00', '2017-11-06 18:32:02.834633+00', 'Mrs A MacGlashan', 11547, '');
INSERT INTO 'tune' VALUES (13713, '2017-11-06 18:35:18.09318+00', '2017-11-06 18:35:18.09318+00', 'Central House', 11548, '');
INSERT INTO 'tune' VALUES (13714, '2017-11-06 18:37:22.243255+00', '2017-11-06 18:37:22.243255+00', 'Norland Wind, The', 11549, '');
INSERT INTO 'tune' VALUES (13715, '2017-11-06 18:38:30.836478+00', '2017-11-06 18:38:30.836478+00', 'Nocht Gur Faoin Mo Chadal Dhomh, An', 9999, '');
INSERT INTO 'tune' VALUES (13716, '2017-11-06 18:47:20.332383+00', '2017-11-06 18:47:20.332383+00', 'I Wish I Was in Glasgow', 11550, '');
INSERT INTO 'tune' VALUES (2006, NULL, '2017-11-06 20:42:05.837897+00', 'Willie Anderson''s Farewell to Dalharn', 1579, 'Called “Willie Anderson''s Farewell to Dalcharn” and attributed to Bill Black on the Glencraig Band''s CD, <<dda:Stirling at 90>>. If anyone can advise us of the proper name and composer of the tune, let us know.');
INSERT INTO 'tune' VALUES (13652, '2017-10-10 12:32:09.655637+00', '2018-04-07 07:13:26.686375+00', 'Andrew''s Serenade', 3179, 'For my friends, Andrew and Heather Hodgson');
INSERT INTO 'tune' VALUES (3382, NULL, '2017-11-07 13:30:40.508913+00', 'Tommy Ford''s Fancy', 1652, 'Tommy Ford was the lead accordionist of the composer''s Band.');
INSERT INTO 'tune' VALUES (3326, NULL, '2017-11-07 13:31:02.889281+00', 'Alex Doig''s Jig', 1531, 'Alex Doig was a drummer who played with Jim MacLeod’s Dance Band in the 1970s. I don’t know who composed this tune, but I would guess that it was either Doig himself, or MacLeod’s accordionist Tommy Ford. The same composer wrote the following, which the Jim MacLeod band recorded after "Alex Doig’s" in 1977.



Source: Post by Nigel Gatherer on June 30th 2012 to <<https://thesession.org/tunes/12135|the session>>



*About the tune:* a leaflet of this dance stated that Tommy Ford, the lead accordionist of Jim Macleod''s Band, wrote the original tune.



The same leaflet also stated the Alex Doig was the drummer for many years with Jim Macleod''s Band.');
INSERT INTO 'tune' VALUES (13736, '2017-11-10 16:37:18.704729+00', '2018-12-07 17:30:59.44398+00', 'Favorite Quickstep by a Gentleman, A', 11553, '');
INSERT INTO 'tune' VALUES (13719, '2017-11-08 11:28:57.267728+00', '2017-11-08 11:28:57.267728+00', 'Southerland Lass', 9998, '');
INSERT INTO 'tune' VALUES (13669, '2017-10-10 12:46:09.784606+00', '2018-04-08 08:13:21.22026+00', 'Rainy Days', 3179, '');
INSERT INTO 'tune' VALUES (13667, '2017-10-10 12:45:04.02937+00', '2018-04-08 08:34:20.577276+00', 'Short Visit, A', 3179, '');
INSERT INTO 'tune' VALUES (13672, '2017-10-10 12:48:44.170426+00', '2018-04-08 08:43:17.480107+00', 'Running Home', 3179, 'Three Childhood Memories');
INSERT INTO 'tune' VALUES (13660, '2017-10-10 12:37:51.085389+00', '2018-04-09 09:30:07.584212+00', 'Five', 11521, '');
INSERT INTO 'tune' VALUES (13671, '2017-10-10 12:47:47.352841+00', '2018-04-09 09:33:18.422266+00', 'Forbidden Forest, The', 11521, '');
INSERT INTO 'tune' VALUES (13673, '2017-10-10 12:49:37.641105+00', '2018-04-09 13:21:26.213011+00', 'Jan''s Choice', 3179, 'For my son, Jan');
INSERT INTO 'tune' VALUES (13649, '2017-10-10 12:29:13.743152+00', '2018-04-09 13:23:06.257632+00', 'Key Confusion', 3179, 'I worked on this tune while my son was practicing his minor scales on the clarinet ...');
INSERT INTO 'tune' VALUES (13664, '2017-10-10 12:40:25.483071+00', '2018-04-10 06:50:03.766786+00', 'Whirling Wind', 11521, '');
INSERT INTO 'tune' VALUES (13656, '2017-10-10 12:35:55.113687+00', '2018-04-10 08:38:45.987089+00', 'Lives Entwining', 3179, 'A wedding gift for Jonathan and Chevonne');
INSERT INTO 'tune' VALUES (13729, '2017-11-08 13:32:29.959395+00', '2017-11-08 13:32:29.959395+00', 'Jack and Dolly Leiper', 1533, '');
INSERT INTO 'tune' VALUES (13730, '2017-11-08 13:39:47.032875+00', '2017-11-08 13:39:47.032875+00', 'Andrew Rankine''s Tribute to Lindsay Ross', 1533, '');
INSERT INTO 'tune' VALUES (13657, '2017-10-10 12:36:22.661308+00', '2018-04-10 09:18:15.814422+00', 'Memories', 3179, '');
INSERT INTO 'tune' VALUES (13655, '2017-10-10 12:34:32.92248+00', '2018-04-10 11:11:24.329107+00', 'My Heart is in the South', 3179, '');
INSERT INTO 'tune' VALUES (13733, '2017-11-08 14:14:07.986341+00', '2017-11-08 14:14:07.986341+00', 'Katharine Hoskins', 1621, '');
INSERT INTO 'tune' VALUES (13734, '2017-11-08 14:15:16.383314+00', '2017-11-08 14:15:16.383314+00', 'Andy Buchanan of Meggemie', 1621, '');
INSERT INTO 'tune' VALUES (13720, '2017-11-08 11:30:38.032284+00', '2017-11-08 14:29:30.33764+00', 'Sutherland Lass, The', 1621, '');
INSERT INTO 'tune' VALUES (13721, '2017-11-08 11:39:13.00234+00', '2017-11-08 14:33:31.032992+00', 'Findlay M MacRae', 1761, '');
INSERT INTO 'tune' VALUES (13722, '2017-11-08 12:31:22.023225+00', '2017-11-08 14:34:44.039179+00', 'Red Fox, The', 1673, '');
INSERT INTO 'tune' VALUES (13723, '2017-11-08 12:41:52.548479+00', '2017-11-08 14:35:51.458643+00', 'Sleepy Laddie, The', 1737, '');
INSERT INTO 'tune' VALUES (13726, '2017-11-08 13:06:35.435992+00', '2017-11-08 14:42:44.019857+00', 'Tea Garden, The', 11551, '');
INSERT INTO 'tune' VALUES (13727, '2017-11-08 13:25:02.837779+00', '2017-11-08 14:45:33.016538+00', 'Shawsmill', 3186, '');
INSERT INTO 'tune' VALUES (13728, '2017-11-08 13:27:22.094681+00', '2017-11-08 14:46:56.373721+00', 'Mr and Mrs Norrie Williams', 3186, '');
INSERT INTO 'tune' VALUES (13670, '2017-10-10 12:47:02.436714+00', '2018-04-10 11:16:53.453716+00', 'Where the Moutains meet the Sea', 11521, '');
INSERT INTO 'tune' VALUES (13654, '2017-10-10 12:33:49.719622+00', '2018-04-10 11:32:56.636698+00', 'Stubborn Composer, The', 11521, '');
INSERT INTO 'tune' VALUES (13659, '2017-10-10 12:37:28.666869+00', '2018-04-10 11:35:07.514127+00', 'Stormy Skies', 11521, '');
INSERT INTO 'tune' VALUES (13653, '2017-10-10 12:32:58.907753+00', '2018-04-10 11:37:12.318658+00', 'Reel Collaboration', 11521, '');
INSERT INTO 'tune' VALUES (13665, '2017-10-10 12:41:02.978602+00', '2018-04-10 11:42:08.847755+00', 'Party Tree, The', 3179, '');
INSERT INTO 'tune' VALUES (13668, '2017-10-10 12:45:37.037587+00', '2018-04-10 11:53:49.915734+00', 'Of Jack and Jill', 3179, '');
INSERT INTO 'tune' VALUES (13662, '2017-10-10 12:39:10.049064+00', '2018-04-10 11:57:35.686869+00', 'No Sitting on the Fence', 3179, '');
INSERT INTO 'tune' VALUES (13663, '2017-10-10 12:39:40.738227+00', '2018-07-23 10:12:52.379594+00', 'Stalking a Pidgeon', 3179, '');
INSERT INTO 'tune' VALUES (13740, '2017-11-10 16:58:45.128111+00', '2017-11-10 16:58:45.128111+00', 'Donny Get out of the Woods', 2965, '');
INSERT INTO 'tune' VALUES (13741, '2017-11-10 17:01:15.760675+00', '2017-11-10 17:01:15.760675+00', 'Emerald Isle, The', 9999, '');
INSERT INTO 'tune' VALUES (13742, '2017-11-10 17:12:46.407096+00', '2017-11-10 17:12:46.407096+00', 'Honeymoon, The', 11554, '');
INSERT INTO 'tune' VALUES (13743, '2017-11-10 17:14:32.901045+00', '2017-11-10 17:14:32.901045+00', 'My Uncle Georg''s Reel', 2965, '');
INSERT INTO 'tune' VALUES (13744, '2017-11-10 17:20:36.893855+00', '2017-11-10 17:20:36.893855+00', 'Genteel Gent, The', 1538, '');
INSERT INTO 'tune' VALUES (13745, '2017-11-10 17:22:34.758442+00', '2017-11-10 17:22:34.758442+00', 'Silver Bracelet, The', 1538, '');
INSERT INTO 'tune' VALUES (13746, '2017-11-10 17:25:22.98356+00', '2017-11-10 17:25:22.98356+00', 'Pans of Kennet, The', 1898, '');
INSERT INTO 'tune' VALUES (13747, '2017-11-10 17:39:56.944288+00', '2017-11-10 17:39:56.944288+00', 'June Darge''s Strathspey', 11556, '');
INSERT INTO 'tune' VALUES (13748, '2017-11-10 17:44:44.290969+00', '2017-11-10 17:44:44.290969+00', 'Visit to Maple Hill Farm', 11557, '');
INSERT INTO 'tune' VALUES (13749, '2017-11-10 17:46:11.10493+00', '2017-11-10 17:46:11.10493+00', 'Through the Years', 2966, '');
INSERT INTO 'tune' VALUES (13750, '2017-11-10 18:00:46.54646+00', '2017-11-10 18:00:46.54646+00', 'Caroline Shaw''s Jig', 10207, '');
INSERT INTO 'tune' VALUES (13751, '2017-11-10 18:02:22.755533+00', '2017-11-10 18:02:22.755533+00', 'Kitty of Oulart', 9999, '');
INSERT INTO 'tune' VALUES (13752, '2017-11-10 18:10:59.774492+00', '2017-11-10 18:10:59.774492+00', 'Barbara McOwen''s Strathspey', 10506, '');
INSERT INTO 'tune' VALUES (13753, '2017-11-10 18:12:16.76668+00', '2017-11-10 18:12:16.76668+00', 'Stef''s Strathspey', 2965, '');
INSERT INTO 'tune' VALUES (13754, '2017-11-10 18:14:06.816734+00', '2017-11-10 18:14:06.816734+00', 'Armadillo, The', 1836, '');
INSERT INTO 'tune' VALUES (13755, '2017-11-10 18:15:56.763099+00', '2017-11-10 18:15:56.763099+00', 'Charlotte Victoria of River Philip', 11557, '');
INSERT INTO 'tune' VALUES (13756, '2017-11-10 19:13:25.220832+00', '2017-11-10 19:13:25.220832+00', 'Wolanski Clan, The', 2085, '');
INSERT INTO 'tune' VALUES (13757, '2017-11-10 19:14:31.894624+00', '2017-11-10 19:14:31.894624+00', 'Baby Dude', 2085, '');
INSERT INTO 'tune' VALUES (13758, '2017-11-10 19:20:37.16024+00', '2017-11-10 19:20:37.16024+00', 'Hugh Allen Reel, The', 11559, '');
INSERT INTO 'tune' VALUES (13759, '2017-11-10 19:23:41.246178+00', '2017-11-10 19:23:41.246178+00', 'Blue Tuque Reel, The', 11560, '');
INSERT INTO 'tune' VALUES (13760, '2017-11-10 19:28:45.037046+00', '2017-11-10 19:28:45.037046+00', 'Laird''s Compliments to Kathy Frasers Collins', 2965, '');
INSERT INTO 'tune' VALUES (13761, '2017-11-10 19:29:49.773398+00', '2017-11-10 19:29:49.773398+00', 'Noble Jean', 1633, '');
INSERT INTO 'tune' VALUES (13762, '2017-11-10 19:34:28.428337+00', '2017-11-10 19:34:28.428337+00', 'Boys of the Loch, The', 9999, '');
INSERT INTO 'tune' VALUES (13763, '2017-11-10 19:38:42.819193+00', '2017-11-10 19:38:42.819193+00', 'Mustard Seed', 11557, '');
INSERT INTO 'tune' VALUES (13764, '2017-11-10 19:42:47.155837+00', '2017-11-10 19:42:47.155837+00', 'Streams of Abernethy, The', 11561, '');
INSERT INTO 'tune' VALUES (13765, '2017-11-10 20:30:01.903404+00', '2017-11-10 20:30:01.903404+00', 'Garett Allen''s Waltz', 2966, '');
INSERT INTO 'tune' VALUES (13766, '2017-11-10 20:32:07.028753+00', '2017-11-10 20:32:07.028753+00', 'Debbie''s Waltz', 1602, '');
INSERT INTO 'tune' VALUES (13767, '2017-11-13 01:01:55.404561+00', '2017-11-13 01:01:55.404561+00', 'Chris Harris''s Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (13768, '2017-11-17 08:35:33.7637+00', '2017-11-17 08:38:22.27037+00', 'Elma McCausland MBE', 3220, 'Composed to acompany the dance with the same name, which was devised by Lucy Mulholland on behalf of the Belfast Branch to celebrate Elma being awarded an MBE in recognition of her years of dedicated service to Scottish County Dancing.');
INSERT INTO 'tune' VALUES (13769, '2017-11-20 15:17:14.349754+00', '2017-11-20 15:17:14.349754+00', 'J D McLennan''s Reel', 1525, '');
INSERT INTO 'tune' VALUES (13770, '2017-11-23 14:30:55.384675+00', '2017-11-23 14:30:55.384675+00', 'Juliet''s Reel', 1643, '');
INSERT INTO 'tune' VALUES (5562, NULL, '2017-11-25 16:16:04.407187+00', 'Harriot', 1518, '');
INSERT INTO 'tune' VALUES (13771, '2017-11-25 16:18:19.734115+00', '2017-11-25 16:18:19.734115+00', 'Morning After, The', 2768, '');
INSERT INTO 'tune' VALUES (13772, '2017-11-25 16:20:24.67441+00', '2017-11-25 16:20:24.67441+00', 'Duchess, The', 1502, '');
INSERT INTO 'tune' VALUES (13773, '2017-11-25 16:26:54.802977+00', '2017-11-25 16:26:54.802977+00', 'New Brig o'' Methlick, The', 11569, '');
INSERT INTO 'tune' VALUES (13774, '2017-11-25 16:31:21.25008+00', '2017-11-25 16:31:21.25008+00', 'Glenfender Jig', 1631, '');
INSERT INTO 'tune' VALUES (13775, '2017-11-25 16:33:07.736384+00', '2017-11-25 16:33:07.736384+00', 'Resolution Jig', 1631, '');
INSERT INTO 'tune' VALUES (13776, '2017-11-25 16:38:41.418888+00', '2017-11-25 16:38:41.418888+00', 'Miss Graham (of Gartmore''s) Strathspey', 1519, '');
INSERT INTO 'tune' VALUES (13777, '2017-11-25 16:42:50.268625+00', '2017-11-25 16:42:50.268625+00', 'Parting Shot, The', 1631, '');
INSERT INTO 'tune' VALUES (13778, '2017-11-25 16:46:19.640764+00', '2017-11-25 16:46:19.640764+00', 'Doris''s Legacy', 1502, '');
INSERT INTO 'tune' VALUES (13779, '2017-11-25 16:50:35.824626+00', '2017-11-25 16:50:35.824626+00', 'Plastered Again', 1631, '');
INSERT INTO 'tune' VALUES (13780, '2017-11-25 17:00:14.189105+00', '2017-11-25 17:00:14.189105+00', 'Cornerstone Strathspey', 1631, '');
INSERT INTO 'tune' VALUES (13781, '2017-11-25 17:01:42.223966+00', '2017-11-25 17:01:42.223966+00', 'Lady Lottery of Faskally', 1631, '');
INSERT INTO 'tune' VALUES (13782, '2017-11-25 17:06:03.076615+00', '2017-11-25 17:06:03.076615+00', 'Ostler''s Field', 1631, '');
INSERT INTO 'tune' VALUES (13783, '2017-11-25 17:06:56.801575+00', '2017-11-25 17:06:56.801575+00', 'Jockalinty', 1593, '');
INSERT INTO 'tune' VALUES (13784, '2017-11-25 17:07:52.793616+00', '2017-11-25 17:07:52.793616+00', 'Esdaile Reel', 1502, '');
INSERT INTO 'tune' VALUES (13785, '2017-11-25 17:27:50.59769+00', '2017-11-25 17:27:50.59769+00', 'On Eildon Hills', 2608, '');
INSERT INTO 'tune' VALUES (13786, '2017-11-25 19:07:18.845677+00', '2017-11-25 19:07:18.845677+00', 'Logger''s Jig, The', 1502, '');
INSERT INTO 'tune' VALUES (13787, '2017-11-25 21:00:10.069545+00', '2017-11-25 21:00:10.069545+00', 'Nose in the Night, The', 1631, '');
INSERT INTO 'tune' VALUES (5036, NULL, '2017-11-26 00:18:15.176335+00', 'Corriechoillie''s Welcome to the Northern Meeting', 1635, '');
INSERT INTO 'tune' VALUES (13789, '2017-11-26 14:05:22.199448+00', '2017-11-26 14:05:22.199448+00', 'Kilberry', 1543, '');
INSERT INTO 'tune' VALUES (13790, '2017-11-26 14:08:09.005289+00', '2017-11-26 14:08:09.005289+00', 'Maids of the Black Glen, The', 9999, '');
INSERT INTO 'tune' VALUES (3116, NULL, '2017-11-26 14:19:26.764521+00', 'Master David R Cunningham', 1521, '');
INSERT INTO 'tune' VALUES (13791, '2017-11-26 14:24:48.425149+00', '2017-11-26 14:24:48.425149+00', 'Bob Robinson''s Dilemma', 1593, '');
INSERT INTO 'tune' VALUES (13792, '2017-12-01 16:41:46.153076+00', '2017-12-01 16:41:46.153076+00', 'Alastair''s 40th', 1508, '');
INSERT INTO 'tune' VALUES (13793, '2017-12-13 16:16:01.000341+00', '2017-12-13 16:16:01.000341+00', 'Sixth of November, The', 10729, 'Written for the West Lothian band leader Jack Stalker.');
INSERT INTO 'tune' VALUES (13794, '2017-12-22 23:04:28.950098+00', '2017-12-22 23:04:28.950098+00', 'Sylvan Delights', 1463, '');
INSERT INTO 'tune' VALUES (13795, '2017-12-27 13:39:23.164904+00', '2017-12-27 13:39:23.164904+00', 'Happy Frien''ship', 9999, '');
INSERT INTO 'tune' VALUES (13796, '2017-12-27 13:42:03.253124+00', '2017-12-27 13:42:03.253124+00', 'Jack Ross of Friockheim', 11355, '');
INSERT INTO 'tune' VALUES (13797, '2017-12-27 13:43:59.018763+00', '2017-12-27 13:43:59.018763+00', 'Angels in the Glen', 11352, '');
INSERT INTO 'tune' VALUES (13798, '2017-12-27 14:28:12.836114+00', '2017-12-27 14:28:12.836114+00', 'Christy MacEachern''s Jig', 1811, '');
INSERT INTO 'tune' VALUES (13799, '2017-12-27 14:29:07.483846+00', '2017-12-27 14:29:07.483846+00', 'Andy McGarth', 1811, '');
INSERT INTO 'tune' VALUES (13800, '2017-12-27 14:29:54.973775+00', '2017-12-27 14:29:54.973775+00', 'David Stoakes', 1811, '');
INSERT INTO 'tune' VALUES (13801, '2017-12-27 14:51:11.542685+00', '2017-12-27 14:51:11.542685+00', 'Mitch and Hutch the Bunessan Waitresses', 1634, '');
INSERT INTO 'tune' VALUES (13802, '2017-12-27 14:52:12.859779+00', '2017-12-27 14:52:12.859779+00', 'Tribute to Albie Tedham', 1634, '');
INSERT INTO 'tune' VALUES (13803, '2017-12-27 15:04:20.119478+00', '2017-12-27 15:04:20.119478+00', 'Waltz for Angus Fitchet', 1668, '');
INSERT INTO 'tune' VALUES (13804, '2017-12-27 16:41:41.856187+00', '2017-12-27 16:41:41.856187+00', 'Soneypath Tower', 1525, '');
INSERT INTO 'tune' VALUES (13805, '2017-12-27 16:43:39.128144+00', '2017-12-27 16:43:39.128144+00', 'Neil''s farewell to his 50s', 10063, '');
INSERT INTO 'tune' VALUES (13806, '2017-12-27 16:44:33.685191+00', '2017-12-27 16:44:33.685191+00', 'Salute to Mauchline Accordion & Fiddle Club', 10063, '');
INSERT INTO 'tune' VALUES (13807, '2017-12-27 17:02:43.702585+00', '2017-12-27 17:02:43.702585+00', 'Memories of Norway', 1668, '');
INSERT INTO 'tune' VALUES (13808, '2018-01-06 21:12:43.26278+00', '2018-01-06 21:12:43.26278+00', 'Bruce Frazer', 1502, '');
INSERT INTO 'tune' VALUES (13809, '2018-01-13 10:48:01.030181+00', '2018-01-13 10:48:01.030181+00', 'Violet Duguid''s Strathspey', 1643, '');
INSERT INTO 'tune' VALUES (4227, NULL, '2018-01-18 21:25:59.936711+00', 'Miss Ann Dickson', 1815, 'Composed in 1974');
INSERT INTO 'tune' VALUES (13810, '2018-01-25 11:57:41.72488+00', '2018-01-25 11:57:41.72488+00', 'RNIB Anniversary Reel', 11595, '');
INSERT INTO 'tune' VALUES (13811, '2018-01-28 20:09:36.728183+00', '2018-01-28 20:10:53.860269+00', 'Muriel Johnstone''s Compliments to Ian Robertson', 1502, '');
INSERT INTO 'tune' VALUES (13812, '2018-02-19 20:54:01.144249+00', '2018-02-19 20:54:01.144249+00', 'Anna Marshall''s Strathspey', 1808, '');
INSERT INTO 'tune' VALUES (13881, '2018-04-10 13:02:00.264726+00', '2018-04-10 13:02:00.264726+00', 'Huntington Castle', 1749, '');
INSERT INTO 'tune' VALUES (13882, '2018-04-10 13:05:20.259589+00', '2018-04-10 13:05:20.259589+00', 'Peachtree Reel', 3683, '');
INSERT INTO 'tune' VALUES (13883, '2018-04-10 13:06:06.813861+00', '2018-04-10 13:06:06.813861+00', 'Danny Will Fix It', 11614, '');
INSERT INTO 'tune' VALUES (13884, '2018-04-10 13:06:30.392778+00', '2018-04-10 13:06:30.392778+00', 'Walt in the Ice Cave', 11614, '');
INSERT INTO 'tune' VALUES (13886, '2018-05-01 09:09:53.496894+00', '2018-05-01 09:09:53.496894+00', 'Kate from St Petersburg', 228, 'Written for Ekaterina Iarmarkina, 25 April 2018.');
INSERT INTO 'tune' VALUES (8310, NULL, '2018-05-12 12:45:02.328692+00', 'Allan Bruce''s Strathspey', 1646, '');
INSERT INTO 'tune' VALUES (13887, '2018-05-21 02:57:55.289806+00', '2018-05-21 07:16:29.165032+00', 'When Harry Wed Meghan', 3179, 'The tune was composed and the dance devised in honour of Prince Harry and Meghan Markle''s wedding at Windsor Castle which took place on 19 May 2018.');
INSERT INTO 'tune' VALUES (13889, '2018-06-09 00:44:14.491598+00', '2018-06-09 00:44:14.491598+00', 'Fergusson''s March, The', 3436, '');
INSERT INTO 'tune' VALUES (13891, '2018-06-09 00:52:10.813431+00', '2018-06-09 00:52:10.813431+00', 'Eric''s Return to Tine', 1502, '');
INSERT INTO 'tune' VALUES (13888, '2018-06-09 00:35:04.808276+00', '2018-06-18 02:11:37.61865+00', 'Colonel Small''s Strathspey', 9999, '');
INSERT INTO 'tune' VALUES (12186, '2012-06-17 14:52:35.829057+00', '2018-09-19 10:05:51.043078+00', 'Mrs O''Sullivan''s', 9999, '');
INSERT INTO 'tune' VALUES (13788, '2017-11-25 21:01:49.684931+00', '2018-10-06 13:52:59.134123+00', 'Dave Cochrane''s Two-Step', 1811, '');
INSERT INTO 'tune' VALUES (13885, '2018-04-10 13:12:22.032663+00', '2018-10-14 23:10:54.559363+00', 'Merry Boys Of Greenland, The', 9999, '');
INSERT INTO 'tune' VALUES (14069, '2019-06-14 20:50:38.404529+00', '2019-06-14 20:50:38.404529+00', 'Top Dog', 11825, '');
INSERT INTO 'tune' VALUES (13912, '2018-06-09 22:49:46.263022+00', '2018-06-09 22:56:24.743815+00', 'Tandem Rabbits', 3436, '');
INSERT INTO 'tune' VALUES (13913, '2018-06-09 23:25:18.258655+00', '2018-06-09 23:25:18.258655+00', 'Dougal Campbell Esq of Ballinby''s Jig', 9999, '');
INSERT INTO 'tune' VALUES (13914, '2018-06-09 23:29:28.81162+00', '2018-06-09 23:29:28.81162+00', 'Harris Dance', 9999, '');
INSERT INTO 'tune' VALUES (13890, '2018-06-09 00:46:06.660566+00', '2018-06-18 02:11:05.839581+00', 'Johnny Fa''a', 9999, '');
INSERT INTO 'tune' VALUES (13915, '2018-06-23 14:33:20.714292+00', '2018-06-23 14:33:20.714292+00', 'Willie Ritchie Esq', 1521, '');
INSERT INTO 'tune' VALUES (13916, '2018-06-23 14:43:51.100654+00', '2018-06-23 14:43:51.100654+00', 'Kontradantz', 9998, '');
INSERT INTO 'tune' VALUES (13917, '2018-06-23 14:51:53.328905+00', '2018-06-23 14:51:53.328905+00', 'Miss Gordon of Fochabers', 10138, '');
INSERT INTO 'tune' VALUES (13919, '2018-06-23 15:47:14.0855+00', '2018-06-23 15:47:14.0855+00', 'Lady Glasgow', 1518, '');
INSERT INTO 'tune' VALUES (13920, '2018-06-23 15:50:02.117448+00', '2018-06-23 15:50:02.117448+00', 'Mrs McInroy of Lude', 1632, '');
INSERT INTO 'tune' VALUES (13921, '2018-06-23 15:52:00.959239+00', '2018-06-23 15:52:00.959239+00', 'Jessie Smith', 1632, '');
INSERT INTO 'tune' VALUES (13922, '2018-06-23 17:05:13.484588+00', '2018-06-23 17:05:13.484588+00', 'Lochan Shira', 1596, '');
INSERT INTO 'tune' VALUES (13923, '2018-07-16 23:46:47.063773+00', '2018-07-16 23:46:47.063773+00', 'Micah Thompson of Mile End', 1590, '');
INSERT INTO 'tune' VALUES (13924, '2018-07-16 23:54:31.02894+00', '2018-07-16 23:54:31.02894+00', 'Pat Houghton''s Hornpipe', 1502, '');
INSERT INTO 'tune' VALUES (13925, '2018-07-16 23:57:31.680595+00', '2018-07-16 23:57:31.680595+00', 'Benrinnes', 9999, 'According to <<https://en.wikipedia.org/wiki/Benrinnes_distillery|Wikipedia>>: “Benrinnes is a malt whisky distillery in Aberlour producing an eponymous whisky. It was founded in 1826, and is still active. The distillery employed a unique partial triple distillation process until 2007.”');
INSERT INTO 'tune' VALUES (13926, '2018-07-17 00:01:43.792938+00', '2018-07-17 00:01:43.792938+00', 'Earl of Seafield''s Reel, The', 11666, 'A 19th century tune from a collection of 1820.');
INSERT INTO 'tune' VALUES (13927, '2018-07-17 00:06:58.343283+00', '2018-07-17 00:06:58.343283+00', 'Ruby Wilkinson of Cranshaws', 1508, '');
INSERT INTO 'tune' VALUES (13928, '2018-07-17 00:10:07.474899+00', '2018-07-17 00:10:07.474899+00', 'Miss Ogilvy of Islabank''s Jigg', 9999, 'From Charles Duff''s collection (1792).');
INSERT INTO 'tune' VALUES (13929, '2018-07-17 00:14:13.335287+00', '2018-07-17 00:14:13.335287+00', 'Judith''s Strathspey', 1590, '');
INSERT INTO 'tune' VALUES (13930, '2018-07-17 00:19:08.00016+00', '2018-07-17 00:19:08.00016+00', 'Among the Clouds', 228, '');
INSERT INTO 'tune' VALUES (13931, '2018-07-17 00:21:14.273797+00', '2018-07-17 00:21:14.273797+00', 'Triple Happiness', 2786, '');
INSERT INTO 'tune' VALUES (13932, '2018-07-17 00:24:03.839042+00', '2018-07-17 00:24:09.61584+00', 'Stewart Adam – Bon Viveur', 1527, '');
INSERT INTO 'tune' VALUES (7569, NULL, '2018-07-29 22:41:12.859588+00', 'Christine''s Strathspey', 1582, '');
INSERT INTO 'tune' VALUES (12230, '2012-11-07 10:49:02.948319+00', '2018-07-30 22:36:09.093527+00', 'George Bateson''s Strathspey', 1596, '');
INSERT INTO 'tune' VALUES (12231, '2012-11-07 10:49:34.208603+00', '2018-07-30 22:36:21.747437+00', 'Alison Bateson''s Strathspey', 1596, '');
INSERT INTO 'tune' VALUES (13935, '2018-08-07 21:07:17.309424+00', '2018-08-07 21:07:17.309424+00', 'Célébrations', 10012, 'Commissioned by Holly Boyd to go with her devised dance.');
INSERT INTO 'tune' VALUES (13936, '2018-08-07 21:08:33.732154+00', '2018-08-07 21:08:33.732154+00', 'Cirque de Kachina', 10012, 'Commissioned by Dagmar Koeppler to go with her devised dance.');
INSERT INTO 'tune' VALUES (13937, '2018-08-07 21:09:28.592796+00', '2018-08-07 21:09:28.592796+00', 'Kempock Stane, The', 10012, 'Commissioned by Margaret Gomersall to go with her devised dance.');
INSERT INTO 'tune' VALUES (13938, '2018-08-07 21:10:29.808143+00', '2018-08-07 21:10:29.808143+00', 'Orange Line, The', 10009, 'Commissioned by Annie Sapucaia.');
INSERT INTO 'tune' VALUES (13939, '2018-08-07 21:11:43.213108+00', '2018-08-07 21:11:43.213108+00', 'Turnbulls of Saskatchewan', 10009, 'Commissioned by Peter White for Joanne Turnbull.');
INSERT INTO 'tune' VALUES (13940, '2018-08-07 21:13:06.781542+00', '2018-08-07 21:13:06.781542+00', 'In Memory of Mothers', 10012, 'Commissioned by Richard South and Janet McLean.');
INSERT INTO 'tune' VALUES (13941, '2018-08-07 21:14:36.468919+00', '2018-08-07 21:14:36.468919+00', 'Moonlight on Mount Royal', 10009, 'Commissioned by Jane and Michael McCusker.');
INSERT INTO 'tune' VALUES (6671, NULL, '2018-10-14 00:03:21.330779+00', 'Gow Quickstep, The', 1518, '');
INSERT INTO 'tune' VALUES (13933, '2018-07-18 17:46:08.0766+00', '2018-08-12 13:46:28.263932+00', 'Luke Around London', 3220, 'Written as the original tune for <<ddd:Luke''s Life in London>> to reflect the time Luke Bradley has spent in the capital.');
INSERT INTO 'tune' VALUES (13942, '2018-08-17 15:35:19.973059+00', '2018-08-17 15:35:19.973059+00', 'AE Lam', 9999, 'Traditional Danish



The official correct spelling would be "Æ Lam".



This beautiful tune from the island of Fanø is traditionally played when the meat is brought out at celebratory events and festivities.');
INSERT INTO 'tune' VALUES (13943, '2018-08-28 08:53:07.205772+00', '2018-08-28 08:53:07.205772+00', 'Algonquin Memories', 3683, '');
INSERT INTO 'tune' VALUES (13945, '2018-09-05 22:51:35.687771+00', '2018-09-05 22:51:35.687771+00', 'Fairyknowe Lodge', 3620, '');
INSERT INTO 'tune' VALUES (6568, NULL, '2018-09-09 09:37:41.210984+00', 'Peter MacKenzie Warren', 2325, '');
INSERT INTO 'tune' VALUES (13946, '2018-09-11 09:22:29.650436+00', '2018-09-11 09:22:29.650436+00', 'Iain Campbell''s Jig', 1456, '');
INSERT INTO 'tune' VALUES (13947, '2018-09-15 10:07:09.297492+00', '2018-09-15 10:10:23.726907+00', 'Manus Lunny''s Terracotta Plower Pop', 1761, '');
INSERT INTO 'tune' VALUES (13948, '2018-09-15 10:12:07.671018+00', '2018-09-15 10:12:07.671018+00', 'Stomach Steinway Man', 2343, '');
INSERT INTO 'tune' VALUES (13949, '2018-09-15 10:16:52.157663+00', '2018-09-15 10:16:52.157663+00', 'Hedwig''s Theme', 11704, '');
INSERT INTO 'tune' VALUES (13950, '2018-09-15 10:35:04.696258+00', '2018-09-15 10:35:04.696258+00', 'Cauldstane Slap, The', 10279, '');
INSERT INTO 'tune' VALUES (13951, '2018-09-15 10:35:48.17778+00', '2018-09-15 10:35:48.17778+00', 'Thieves Road', 10279, '');
INSERT INTO 'tune' VALUES (13953, '2018-09-15 10:37:28.735118+00', '2018-09-15 10:37:28.735118+00', 'Walt''s Waltz', 11614, '');
INSERT INTO 'tune' VALUES (13954, '2018-09-15 10:38:21.132336+00', '2018-09-15 10:38:21.132336+00', 'Winter Wedding', 11614, '');
INSERT INTO 'tune' VALUES (13955, '2018-09-15 10:44:49.996406+00', '2018-09-15 10:44:49.996406+00', 'Cam Ye By Atholl', 1518, 'Probably by Niel Gow (senior) according to Anselm. Alias for Bonnie Prince Charlie according to the Traditional Tune Archive.');
INSERT INTO 'tune' VALUES (13956, '2018-09-15 10:48:10.442393+00', '2018-09-15 10:48:10.442393+00', 'Seoras Beg', 11705, '');
INSERT INTO 'tune' VALUES (13957, '2018-09-15 10:49:20.942715+00', '2018-09-15 10:49:20.942715+00', 'Sky Diving Waltz', 10916, '');
INSERT INTO 'tune' VALUES (13958, '2018-09-15 16:32:33.037982+00', '2018-09-15 16:32:51.451269+00', 'Margaret & Norman''s Golden Wedding Jig', 3220, 'Written to mark the 50th Wedding Anniversary of Margaret & Norman Hill in September 2015 & danced to a tune especially commissioned by members of the Glen Orrin Dancers and composed by Marian Anderson');
INSERT INTO 'tune' VALUES (9881, NULL, '2019-06-27 21:50:01.637039+00', 'Kent County Jig', 11829, '');
INSERT INTO 'tune' VALUES (13959, '2018-09-18 22:30:48.474051+00', '2018-09-19 07:48:27.779137+00', 'Moon Owl Jig', 3617, '');
INSERT INTO 'tune' VALUES (13519, '2017-02-24 22:04:39.237487+00', '2018-09-19 10:00:11.974712+00', 'Elizabeth''s Air', 9998, 'Published in the Angus SCD Book.  Probably derived from the Caledonian Companion collection of traditional Scottish tunes');
INSERT INTO 'tune' VALUES (13934, '2018-08-07 21:05:30.032893+00', '2018-09-19 10:01:13.895445+00', 'Théa''s Welcome', 10009, 'Commissioned by Don Nemiroff for his new granddaughter.');
INSERT INTO 'tune' VALUES (13960, '2018-09-21 15:29:54.842165+00', '2018-09-21 15:29:54.842165+00', 'Brown Dairy Maid, The', 9999, '');
INSERT INTO 'tune' VALUES (10618, '2009-11-20 23:00:00+00', '2018-09-21 19:54:32.614677+00', 'Margaret and John''s Silver Wedding', 10085, '');
INSERT INTO 'tune' VALUES (13961, '2018-09-24 09:08:00.269975+00', '2018-09-24 09:08:00.269975+00', 'Blin Tamig', 1512, '');
INSERT INTO 'tune' VALUES (12252, '2012-12-28 13:41:02.341518+00', '2018-10-06 13:53:32.939771+00', 'Fred McNicoll''s March', 1811, '');
INSERT INTO 'tune' VALUES (12148, '2012-06-12 15:59:44.394441+00', '2018-10-06 14:06:01.999166+00', 'Gordon Pattullo''s Compliments to Davie Flockhart', 1811, '');
INSERT INTO 'tune' VALUES (13962, '2018-10-07 22:08:04.694094+00', '2018-10-07 22:08:04.694094+00', 'Mr. Alexander Troup', 1748, 'See Alexander Walker Collection page 54, Cranford Publications, Cape Breton, Nova Scotia');
INSERT INTO 'tune' VALUES (13963, '2018-10-13 19:54:08.47455+00', '2018-10-13 19:54:08.47455+00', 'Julia Sharp Strathspey, The', 2208, '');
INSERT INTO 'tune' VALUES (9600, '2005-06-26 22:00:00+00', '2018-10-14 00:02:57.328829+00', 'Legacy of Pearl''s, A', 3612, '');
INSERT INTO 'tune' VALUES (13878, '2018-04-10 11:50:05.51081+00', '2018-10-14 00:03:44.58427+00', 'Miss MacQueen''s Reel', 1516, '');
INSERT INTO 'tune' VALUES (11983, '2011-12-10 23:00:00+00', '2018-10-14 00:05:22.684903+00', 'Lightnin'' Bug, The', 3722, '');
INSERT INTO 'tune' VALUES (13529, '2017-02-25 16:54:28.811969+00', '2018-10-14 00:10:06.894602+00', 'St Columba''s Anniversary Reel, The', 1590, '');
INSERT INTO 'tune' VALUES (13034, '2014-11-14 09:56:54.064578+00', '2018-10-14 00:27:15.776657+00', 'Calican Scot, The', 1533, '');
INSERT INTO 'tune' VALUES (13038, '2014-11-14 10:07:32.672403+00', '2018-10-14 00:27:36.583709+00', 'Five Bar Gate, The', 1501, '');
INSERT INTO 'tune' VALUES (13571, '2017-04-23 07:00:24.336948+00', '2018-10-24 16:31:07.841103+00', 'Tremblin'' String, The', 3383, '© Fiddletree Music, 2014');
INSERT INTO 'tune' VALUES (13964, '2018-10-24 16:51:44.297903+00', '2018-10-24 16:51:44.297903+00', 'Zombie Town', 10581, '');
INSERT INTO 'tune' VALUES (13355, '2016-10-04 23:01:19.703334+00', '2018-10-30 17:22:16.836251+00', 'He''ll Marry Me Now', 11321, '');
INSERT INTO 'tune' VALUES (14094, '2019-08-14 09:55:57.601338+00', '2019-08-14 09:55:57.601338+00', 'Jiggin at Reelig', 3383, '');
INSERT INTO 'tune' VALUES (14095, '2019-08-14 09:56:27.094641+00', '2019-08-14 09:56:27.094641+00', 'Jink in January', 3383, '');
INSERT INTO 'tune' VALUES (14096, '2019-08-14 09:56:58.497342+00', '2019-08-14 09:56:58.497342+00', 'Mr & Mrs Barwick, Woolwine', 3383, '');
INSERT INTO 'tune' VALUES (14097, '2019-08-14 09:58:36.314469+00', '2019-08-14 09:58:36.314469+00', 'Muckle Spate - 1829, The', 3383, '');
INSERT INTO 'tune' VALUES (14098, '2019-08-14 09:59:02.804741+00', '2019-08-14 09:59:02.804741+00', 'Playing the Smudges', 3383, '');
INSERT INTO 'tune' VALUES (13967, '2018-10-26 20:33:25.501853+00', '2018-10-26 20:33:25.501853+00', '40 Bar Strathspey (Our Nancy)', 1456, '');
INSERT INTO 'tune' VALUES (11553, '2011-07-09 22:00:00+00', '2018-10-30 17:19:12.664996+00', '"Any Good Jig" (author''s statement)', 10653, 'This can be entered in the "Tune" field when the author of a Jig explicitly leaves the choice of a tune to the reader.');
INSERT INTO 'tune' VALUES (12427, '2013-01-23 13:18:31.47522+00', '2018-10-30 17:20:06.570857+00', 'Seventy not out', 2989, 'Information came from iain Gent');
INSERT INTO 'tune' VALUES (13439, '2016-12-14 22:51:09.53045+00', '2018-10-30 17:22:34.976971+00', 'Gee, I Wish I Was Back In The Army', 2321, '');
INSERT INTO 'tune' VALUES (1544, NULL, '2018-10-30 22:27:05.897735+00', 'Rose of Allendale, The', 11742, 'Composer corrected to Sidney Nelson following http://my.strathspey.org/dd/issue/1419/');
INSERT INTO 'tune' VALUES (1961, NULL, '2018-10-30 22:33:36.816918+00', 'Bonnie Mary of Argyle', 11742, 'Following http://my.strathspey.org/dd/issue/1419/ the composer of this tune was also corrected to Sidney Nelson.');
INSERT INTO 'tune' VALUES (13969, '2018-11-13 22:55:35.242335+00', '2018-11-14 10:26:08.619455+00', 'Legacy, The', 9999, 'According to Steve Wyrick (http://my.strathspey.org/dd/issue/1574/) and Bruce Herbold (http://my.strathspey.org/dd/issue/1576/) this jig tune is different from (and long predates) a reel tune of the same name by Gordon Pattullo.



Steve adds that the tune was published as "How Can We Abstain From Whisky"  in the Captain Simon Fraser Collection (The Airs and Melodies Peculiar to the Highlands of Scotland and the Isles, 1817) but appears as "The Legacy" in several later collections (among them Kerr''s, Ryan''s Mammoth Collection, Howe''s).');
INSERT INTO 'tune' VALUES (6937, NULL, '2018-11-14 23:56:42.438063+00', 'Reverend Mr Frog, The', 3383, '');
INSERT INTO 'tune' VALUES (13970, '2018-11-20 23:02:10.235157+00', '2018-11-20 23:02:10.235157+00', 'Road Not Taken, The', 3383, '');
INSERT INTO 'tune' VALUES (13971, '2018-11-20 23:05:41.455598+00', '2018-11-20 23:05:41.455598+00', 'Stone Heroes', 3383, '');
INSERT INTO 'tune' VALUES (13972, '2018-11-20 23:08:44.997011+00', '2018-11-20 23:08:44.997011+00', 'Music Maks the Dance', 3383, '');
INSERT INTO 'tune' VALUES (13973, '2018-11-20 23:11:48.852397+00', '2018-11-20 23:11:48.852397+00', 'Loon Mountain Reel, The', 3383, '');
INSERT INTO 'tune' VALUES (9946, '2006-10-19 22:00:00+00', '2018-11-21 16:52:03.598831+00', 'Logan''s Welcome to Jink and Diddle', 3383, '');
INSERT INTO 'tune' VALUES (1642, NULL, '2018-11-21 19:54:39.967026+00', 'Springbank House', 1776, '1951.  Published in dance leaflet The Dundee Strathspey');
INSERT INTO 'tune' VALUES (3702, NULL, '2018-11-21 19:54:55.340608+00', 'Mrs Douglas Henderson', 1776, '1951.  Published in dance leaflet The Dundee Strathspey');
INSERT INTO 'tune' VALUES (14035, '2019-03-22 20:19:16.11127+00', '2019-03-22 20:19:29.833149+00', 'Touch & Go', 3436, '');
INSERT INTO 'tune' VALUES (12844, '2014-03-16 11:41:04.103631+00', '2019-03-24 21:07:25.839949+00', 'Grande Chaine, La', 9998, '');
INSERT INTO 'tune' VALUES (14036, '2019-03-23 10:45:14.913889+00', '2021-02-19 19:41:03.748834+00', 'Peter Knight''s Strathspey', 1631, '');
INSERT INTO 'tune' VALUES (13965, '2018-10-24 19:11:36.937973+00', '2021-09-23 20:39:43.019118+00', 'Pounce de Leon', 389, '');
INSERT INTO 'tune' VALUES (1132, NULL, '2018-11-22 00:03:23.836148+00', 'Miss Anne Drummond Smith''s Reel', 11746, 'RSCDS Book 17 ascribes this tune to Syd Chalmers, but Finlay Forbes reports (http://my.strathspey.org/dd/issue/1394/) that this is not correct and that it was published much earlier by John Clarkson senior.



However it may not have been composed by him, so might actually be Traditional.



Possible duplicate of http://my.strathspey.org/dd/tune/2589/?');
INSERT INTO 'tune' VALUES (13990, '2019-01-10 10:36:36.136983+00', '2019-01-10 10:36:36.136983+00', 'Welcome to Auchnahyle', 1502, '');
INSERT INTO 'tune' VALUES (13974, '2018-11-22 20:22:16.889246+00', '2018-11-23 16:07:00.443664+00', 'Jig for Danny', 1557, 'For Danielle Reinstein, inspired by a tee shirt she was wearing with birds sitting on what looked like a musical stave.

');
INSERT INTO 'tune' VALUES (8158, NULL, '2018-12-06 18:22:17.641114+00', 'Lintrathen Jig, The', 1646, '');
INSERT INTO 'tune' VALUES (2535, NULL, '2018-12-06 18:40:58.737917+00', 'Cullen House', 9999, 'The Glen Collection (https://digital.nls.uk/special-collections-of-printed-music/archive/105813936) attributes this tune - or one of the same name - to D. Grant, presumably Donald Grant?');
INSERT INTO 'tune' VALUES (1597, NULL, '2018-12-06 19:07:41.704232+00', 'She''s ower young to Marry Yet', 9999, 'Although this tune is credited in some places to John Thomas Surenne, this attribution is disputed by Finlay Forbes in issue 1329 (http://my.strathspey.org/dd/issue/1329/) who suggests it is traditional.');
INSERT INTO 'tune' VALUES (5185, NULL, '2018-12-06 19:34:29.830828+00', 'Davie''s Burn', 1525, 'This may be a misspelling of Davie''s Brae (http://my.strathspey.org/dd/tune/376/) according to issue 1036 (http://my.strathspey.org/dd/issue/1036/). If confirmed this entry should be deleted and its links to recordings moved to Davie''s Brae.');
INSERT INTO 'tune' VALUES (13975, '2018-12-06 23:46:30.766284+00', '2018-12-06 23:46:30.766284+00', 'Sandra Fraser''s Jig', 1596, '');
INSERT INTO 'tune' VALUES (12639, '2013-10-04 19:20:17.794629+00', '2018-12-07 17:29:40.46212+00', 'Trip to Bavaria, A', 240, '');
INSERT INTO 'tune' VALUES (13976, '2018-12-10 12:44:03.98732+00', '2018-12-10 12:44:03.98732+00', 'Fair Helen', 11225, '');
INSERT INTO 'tune' VALUES (13977, '2018-12-12 11:39:08.88802+00', '2018-12-12 11:39:08.88802+00', 'Vana Tallinn', 11532, '');
INSERT INTO 'tune' VALUES (13978, '2018-12-14 00:35:13.118765+00', '2018-12-14 00:35:13.118765+00', 'Jimmy McMillan of Giffnock', 1456, '');
INSERT INTO 'tune' VALUES (13981, '2018-12-19 14:02:59.918824+00', '2018-12-19 14:02:59.918824+00', 'Frances Corbett''s Hornpipe', 1596, '');
INSERT INTO 'tune' VALUES (13983, '2019-01-04 16:09:35.874228+00', '2019-01-04 16:09:35.874228+00', 'Rose of Cambridge', 11766, '');
INSERT INTO 'tune' VALUES (13982, '2018-12-29 02:50:49.83845+00', '2019-01-08 23:57:46.922977+00', 'Half Century Waltz, The', 3383, 'Full name:  ''The Half Century Waltz ~ Fifty Years Together''');
INSERT INTO 'tune' VALUES (13984, '2019-01-10 10:24:26.367996+00', '2019-01-10 10:24:26.367996+00', 'Dancing Piper of Lochanbrae', 3220, '');
INSERT INTO 'tune' VALUES (13985, '2019-01-10 10:25:58.42658+00', '2019-01-10 10:25:58.42658+00', 'Gordon''s 50th', 3220, '');
INSERT INTO 'tune' VALUES (13986, '2019-01-10 10:27:53.467798+00', '2019-01-10 10:27:53.467798+00', 'Ballylesson', 3220, '');
INSERT INTO 'tune' VALUES (13987, '2019-01-10 10:28:45.205643+00', '2019-01-10 10:28:45.205643+00', 'David Quarrie''s Bluebell', 3220, '');
INSERT INTO 'tune' VALUES (13988, '2019-01-10 10:29:32.055895+00', '2019-01-10 10:29:32.055895+00', 'Paula''s Party', 1575, '');
INSERT INTO 'tune' VALUES (13989, '2019-01-10 10:31:45.842773+00', '2019-01-10 10:31:45.842773+00', 'Au Revoir Mes Amis', 3220, '');
INSERT INTO 'tune' VALUES (13991, '2019-01-10 10:37:29.094351+00', '2019-01-10 10:37:29.094351+00', 'Susan & Fergie', 1502, '');
INSERT INTO 'tune' VALUES (13992, '2019-01-10 10:38:20.870183+00', '2019-01-10 10:38:20.870183+00', 'Monday Boy', 2160, '');
INSERT INTO 'tune' VALUES (13993, '2019-01-10 10:39:03.394087+00', '2019-01-10 10:39:03.394087+00', 'Miss Emily Bates', 2160, '');
INSERT INTO 'tune' VALUES (13994, '2019-01-10 10:41:24.309037+00', '2019-01-10 10:41:24.309037+00', 'Leaving Lordenshaw', 2608, '');
INSERT INTO 'tune' VALUES (13995, '2019-01-10 10:43:57.889692+00', '2019-01-10 10:43:57.889692+00', 'Unknown Motive', 1673, '');
INSERT INTO 'tune' VALUES (13996, '2019-01-10 10:51:24.758333+00', '2019-01-10 10:51:24.758333+00', 'Panmure Gardens', 3220, '');
INSERT INTO 'tune' VALUES (13997, '2019-01-10 10:52:35.980553+00', '2019-01-10 10:52:35.980553+00', 'St Helier Hospital', 3220, '');
INSERT INTO 'tune' VALUES (13998, '2019-01-10 10:53:17.623129+00', '2019-01-10 10:53:17.623129+00', 'Sylvia''s Strathspey', 3220, '');
INSERT INTO 'tune' VALUES (13999, '2019-01-10 10:56:09.920678+00', '2019-01-10 10:56:09.920678+00', 'Deb''s Christmas Cracker', 11645, '');
INSERT INTO 'tune' VALUES (14000, '2019-01-10 11:03:23.917657+00', '2019-01-10 11:03:23.917657+00', 'Tug Argan Gap', 11767, '');
INSERT INTO 'tune' VALUES (14001, '2019-01-17 00:46:52.093187+00', '2019-01-17 00:46:52.093187+00', 'Derby Road', 1631, 'Composed for the centenary of the Watford and West Herts Scottish Society  "Derby Road and so named because the composer''s grandparents lived in Derby Road Watford around the time the society was founded.');
INSERT INTO 'tune' VALUES (14002, '2019-01-17 00:47:17.568057+00', '2019-01-17 00:47:17.568057+00', 'Watford Centenary Reel', 1631, '');
INSERT INTO 'tune' VALUES (13980, '2018-12-16 01:20:23.982872+00', '2019-01-17 22:54:08.547494+00', 'Donaldson''s Rant', 11765, 'This tune was named after the author of The Gruffalo book, Julia Donaldson.');
INSERT INTO 'tune' VALUES (14003, '2019-01-22 14:38:54.143922+00', '2019-01-22 14:38:54.143922+00', 'Dance of Love', 11775, '');
INSERT INTO 'tune' VALUES (14006, '2019-02-20 23:11:32.615887+00', '2019-02-21 08:06:22.250794+00', 'Mme Sophie Marchand of Méaudre', 11530, '');
INSERT INTO 'tune' VALUES (14007, '2019-02-21 23:38:02.87008+00', '2019-02-21 23:38:06.268834+00', 'Marmot''s Reel, The', 11530, '');
INSERT INTO 'tune' VALUES (14008, '2019-02-21 23:40:01.747866+00', '2019-02-21 23:40:01.747866+00', 'Forty Bars of Clouds', 11781, '');
INSERT INTO 'tune' VALUES (14009, '2019-02-26 11:46:18.936925+00', '2019-02-26 11:46:18.936925+00', 'Lachlan Village near New Norfolk', 11792, '');
INSERT INTO 'tune' VALUES (6312, NULL, '2019-03-08 16:52:39.741277+00', 'Dance the Baby', 1533, 'Although entered in SCDDB with the name Dance the Baby, it seems more likely from a web search that the correct name is Dancing the Baby (which is entered as an alias).');
INSERT INTO 'tune' VALUES (14093, '2019-08-14 09:55:17.002896+00', '2019-08-14 09:55:17.002896+00', 'Jig for Cheryl and Charlie, A', 3383, '');
INSERT INTO 'tune' VALUES (14099, '2019-08-14 09:59:45.334733+00', '2019-08-14 09:59:45.334733+00', 'Reel for John Gibb and Catherine McIntyre Young, A', 3383, '');
INSERT INTO 'tune' VALUES (13979, '2018-12-14 17:59:06.05549+00', '2019-10-13 18:31:18.875755+00', 'Smiling Lila', 709, 'Sheet music is available via <<https://www.scottish-country-dancing-dictionary.com/dance-crib/smiling-lila.html>>');
INSERT INTO 'tune' VALUES (3802, NULL, '2019-03-08 16:56:56.316977+00', 'Bouncing the Baby', 9998, 'This was entered as the tune for the <<ddd:Friars Reel#7401>>. However the original source for that dance actually reads "Dancing the Baby" by Andrew Rankine. So this entry may have been a mistake.');
INSERT INTO 'tune' VALUES (7437, NULL, '2019-03-08 17:09:37.308844+00', 'Barbara Stirling', 1531, 'The instructions for <<ddd:The Dunblane Reel#7387>> attribute this tune to Tommy Ford (under the name Miss Barbara A. Stirling). Originally SCDDB had the composer as "unknown".');
INSERT INTO 'tune' VALUES (14010, '2019-03-08 20:00:32.044234+00', '2019-03-08 20:00:32.044234+00', 'Pixies in the Mist', 11798, '');
INSERT INTO 'tune' VALUES (14011, '2019-03-08 20:03:12.654897+00', '2019-03-08 20:03:12.654897+00', 'Alcanede Strathspey', 11225, '');
INSERT INTO 'tune' VALUES (14012, '2019-03-08 20:05:46.482454+00', '2019-03-08 20:05:46.482454+00', 'Doreens''s Fancy', 1593, '');
INSERT INTO 'tune' VALUES (14013, '2019-03-08 20:08:07.057217+00', '2019-03-08 20:08:07.057217+00', 'Thorngrove Jig, The', 2856, '');
INSERT INTO 'tune' VALUES (14014, '2019-03-08 20:10:52.630756+00', '2019-03-08 20:10:52.630756+00', 'Alasdair''s Pipe A.', 1593, '');
INSERT INTO 'tune' VALUES (14015, '2019-03-08 20:12:55.450769+00', '2019-03-08 20:12:55.450769+00', 'Road to Javea, The', 2856, '');
INSERT INTO 'tune' VALUES (14016, '2019-03-08 20:32:03.755332+00', '2019-03-08 20:32:57.960074+00', 'Jeronimo''s Inspiration', 2856, '');
INSERT INTO 'tune' VALUES (13275, '2016-05-06 21:05:15.269606+00', '2019-03-11 01:54:13.286571+00', 'Tallinn Town Hall Home-Made Medieval Elk Soup Incident, The', 228, '');
INSERT INTO 'tune' VALUES (14017, '2019-03-14 00:03:05.899733+00', '2019-03-14 00:03:05.899733+00', 'Honorable Peace, An', 1781, '');
INSERT INTO 'tune' VALUES (14020, '2019-03-14 00:24:11.79849+00', '2019-03-14 00:24:11.79849+00', 'Tim Horton''s Strathspey', 1633, '');
INSERT INTO 'tune' VALUES (14021, '2019-03-14 00:25:32.020537+00', '2019-03-14 00:25:32.020537+00', 'Cawdor Fair', 9999, '');
INSERT INTO 'tune' VALUES (14022, '2019-03-14 00:28:45.58325+00', '2019-03-14 00:28:45.58325+00', 'Mary''s Dream', 9999, '');
INSERT INTO 'tune' VALUES (14023, '2019-03-14 00:29:39.729751+00', '2019-03-14 00:29:39.729751+00', 'Paula''s Scots Measure', 2335, '');
INSERT INTO 'tune' VALUES (14024, '2019-03-14 00:31:48.869553+00', '2019-03-14 00:31:48.869553+00', 'Jennet Drinks No Water', 9999, '');
INSERT INTO 'tune' VALUES (14025, '2019-03-14 00:36:12.425577+00', '2019-03-14 00:36:12.425577+00', 'Ragg, The', 9999, '');
INSERT INTO 'tune' VALUES (14026, '2019-03-14 00:37:43.213358+00', '2019-03-14 00:37:43.213358+00', 'Air in F', 1763, '');
INSERT INTO 'tune' VALUES (14027, '2019-03-14 00:39:43.443995+00', '2019-03-14 00:39:43.443995+00', 'Aways my Heart that we mun sunder', 9999, '');
INSERT INTO 'tune' VALUES (14028, '2019-03-14 00:40:54.464177+00', '2019-03-14 00:40:54.464177+00', 'An thou wert my ain thing', 9999, '');
INSERT INTO 'tune' VALUES (14029, '2019-03-14 00:41:46.394585+00', '2019-03-14 00:41:46.394585+00', 'Cosen Cole''s Delight', 9999, '');
INSERT INTO 'tune' VALUES (14031, '2019-03-14 00:49:23.27198+00', '2019-03-14 00:49:23.27198+00', 'Tam''s Grey Mare', 1632, '');
INSERT INTO 'tune' VALUES (14019, '2019-03-14 00:16:30.417262+00', '2019-03-14 10:38:13.533733+00', 'Ronald''s Rant', 2335, '');
INSERT INTO 'tune' VALUES (12989, '2014-08-19 09:13:57.404437+00', '2019-03-17 01:22:47.832906+00', 'Rose-bud by My Early Walk, A', 9999, 'Lyrics by Robert Burns.');
INSERT INTO 'tune' VALUES (14034, '2019-03-22 20:18:45.422636+00', '2019-03-22 20:18:50.441117+00', 'Monika''s Jig', 3436, '');
INSERT INTO 'tune' VALUES (14071, '2019-06-14 20:51:36.410486+00', '2019-06-14 20:51:36.410486+00', 'Barwick Green', 3154, '');
INSERT INTO 'tune' VALUES (14032, '2019-03-14 23:23:15.309777+00', '2020-06-16 15:43:53.135765+00', 'Vanessa''s Pleasure', 3220, 'For Vanessa de Schoene');
INSERT INTO 'tune' VALUES (14037, '2019-03-25 00:25:20.456254+00', '2019-03-25 00:25:20.456254+00', 'Toast to st. Andrew''s, A', 1533, '');
INSERT INTO 'tune' VALUES (14038, '2019-04-17 08:40:16.906823+00', '2019-04-17 08:40:16.906823+00', 'Mick and Trisha Rawlings of Middle Barton', 1590, '');
INSERT INTO 'tune' VALUES (5956, NULL, '2019-05-11 21:46:09.044568+00', 'Kenny Gillies of Portnalong, Skye', 1604, '');
INSERT INTO 'tune' VALUES (14040, '2019-05-12 09:19:25.360674+00', '2019-05-12 09:19:25.360674+00', 'Billy & Lana Fotheringham''s Ruby Wedding Reel', 11809, '');
INSERT INTO 'tune' VALUES (14041, '2019-05-12 10:03:05.512994+00', '2019-05-12 10:03:05.512994+00', 'Sapphire Strathspey, The', 11472, '');
INSERT INTO 'tune' VALUES (11122, '2010-05-30 22:00:00+00', '2019-05-13 00:57:52.585243+00', 'Hana (Blossoms along the River)', 10174, '');
INSERT INTO 'tune' VALUES (14042, '2019-05-15 16:05:49.656162+00', '2019-05-15 16:05:49.656162+00', 'Kilt Swing', 1846, '');
INSERT INTO 'tune' VALUES (14043, '2019-05-21 16:23:31.791093+00', '2019-05-21 16:23:31.791093+00', 'Bordeaux en Belle', 2977, 'For Terry Harvey and Line Farr');
INSERT INTO 'tune' VALUES (14044, '2019-05-30 07:09:14.90568+00', '2019-05-30 07:09:14.90568+00', 'Popcorn Behavior', 2086, '');
INSERT INTO 'tune' VALUES (14046, '2019-06-01 11:47:59.297564+00', '2019-06-01 11:47:59.297564+00', 'Madame Gris', 3683, 'For Katy Gray');
INSERT INTO 'tune' VALUES (14047, '2019-06-04 09:14:40.903695+00', '2019-06-04 09:14:40.903695+00', 'Dagda Circle', 11819, '');
INSERT INTO 'tune' VALUES (14048, '2019-06-04 09:48:42.581236+00', '2019-06-04 09:48:42.581236+00', 'Farewell to Geneva', 1502, '');
INSERT INTO 'tune' VALUES (14049, '2019-06-04 09:48:58.387217+00', '2019-06-04 09:48:58.387217+00', 'Germany Bound', 1502, '');
INSERT INTO 'tune' VALUES (10148, '2009-08-02 22:00:00+00', '2019-06-06 08:18:03.914315+00', 'Road to Errogie, The', 10013, 'NB this tune is misspelled "The Road to Eroggie" on the CD for RSCDS Book 52.');
INSERT INTO 'tune' VALUES (14050, '2019-06-07 15:11:33.621961+00', '2019-06-07 15:11:33.621961+00', 'Wee Lassie fae Gourock, The', 3383, '');
INSERT INTO 'tune' VALUES (14051, '2019-06-07 15:11:59.159168+00', '2019-06-07 15:11:59.159168+00', 'Braid Knot, The', 3383, '');
INSERT INTO 'tune' VALUES (14052, '2019-06-07 15:12:30.781609+00', '2019-06-07 15:12:30.781609+00', 'Stella at Stobhill', 3383, '');
INSERT INTO 'tune' VALUES (14053, '2019-06-14 10:09:23.865104+00', '2019-06-14 10:09:23.865104+00', 'David Knight''s Farewell to Apathy (Whatever)', 1829, '');
INSERT INTO 'tune' VALUES (14055, '2019-06-14 10:22:10.315999+00', '2019-06-14 10:22:10.315999+00', 'My Love is Not Here', 11483, '');
INSERT INTO 'tune' VALUES (14057, '2019-06-14 19:52:13.853362+00', '2019-06-14 19:52:13.853362+00', 'Staircase Jig, The', 1539, '');
INSERT INTO 'tune' VALUES (14058, '2019-06-14 20:03:42.367315+00', '2019-06-14 20:03:42.367315+00', 'Catharsis', 11820, '');
INSERT INTO 'tune' VALUES (14059, '2019-06-14 20:10:24.851178+00', '2019-06-14 20:10:24.851178+00', 'Hungarian Dance No 5', 11821, '');
INSERT INTO 'tune' VALUES (14060, '2019-06-14 20:13:46.863272+00', '2019-06-14 20:13:46.863272+00', 'Hungarian Rhapsody No. 2', 11822, '');
INSERT INTO 'tune' VALUES (14062, '2019-06-14 20:29:25.974112+00', '2019-06-14 20:29:25.974112+00', 'Anlan McKinney', 11145, '');
INSERT INTO 'tune' VALUES (14063, '2019-06-14 20:33:47.850445+00', '2019-06-14 20:33:47.850445+00', 'Drew and Eleanor', 1679, '');
INSERT INTO 'tune' VALUES (14064, '2019-06-14 20:37:03.674894+00', '2019-06-14 20:37:03.674894+00', 'Lament for a Blind Harper', 11823, '');
INSERT INTO 'tune' VALUES (14065, '2019-06-14 20:38:57.548729+00', '2019-06-14 20:38:57.548729+00', 'Lydia''s Garden', 1502, '');
INSERT INTO 'tune' VALUES (14066, '2019-06-14 20:41:39.997134+00', '2019-06-14 20:41:39.997134+00', 'Hidden Gem, The', 2266, '');
INSERT INTO 'tune' VALUES (14067, '2019-06-14 20:43:05.53138+00', '2019-06-14 20:43:05.53138+00', 'Hex-dash Caur, The', 10652, '');
INSERT INTO 'tune' VALUES (14070, '2019-06-14 20:51:03.193899+00', '2019-06-14 20:51:03.193899+00', 'Comedy Hour', 11825, '');
INSERT INTO 'tune' VALUES (11747, '2011-11-02 23:00:00+00', '2019-06-18 08:28:58.694254+00', 'Reel de Mattawa', 10006, '');
INSERT INTO 'tune' VALUES (14072, '2019-07-02 20:07:11.887685+00', '2019-07-02 20:33:14.731835+00', 'Diane Breslin''s Strathspey', 1576, '');
INSERT INTO 'tune' VALUES (14073, '2019-07-24 22:01:51.015905+00', '2019-07-24 22:01:51.015905+00', 'Holmenkollen', 1442, '');
INSERT INTO 'tune' VALUES (14074, '2019-07-24 22:02:18.113819+00', '2019-07-24 22:02:18.113819+00', 'Oslo Fjord', 1442, '');
INSERT INTO 'tune' VALUES (14075, '2019-07-24 22:03:11.26448+00', '2019-07-24 22:03:11.26448+00', 'Major''s Tourie, The', 1442, '');
INSERT INTO 'tune' VALUES (14076, '2019-07-25 09:32:56.639122+00', '2019-07-25 09:32:56.639122+00', 'Strathspey for Emma''s Wedding, A', 11843, '');
INSERT INTO 'tune' VALUES (14077, '2019-07-25 11:25:05.172312+00', '2019-07-25 11:25:05.172312+00', 'Melin''s Rant', 11846, '');
INSERT INTO 'tune' VALUES (14078, '2019-07-25 11:26:32.684888+00', '2019-07-25 11:26:32.684888+00', 'Stockholm Branch Ruby Jubilee', 11169, '');
INSERT INTO 'tune' VALUES (14079, '2019-08-11 21:08:09.393753+00', '2019-08-11 21:08:09.393753+00', 'Swarthmore College Reel, The', 1502, '');
INSERT INTO 'tune' VALUES (14080, '2019-08-12 09:09:59.717004+00', '2019-08-12 09:21:03.208217+00', 'Director Jim', 11858, 'Devised 6 August 2019 for Jim Stott''s retiral as Director of Summer School.');
INSERT INTO 'tune' VALUES (14082, '2019-08-14 09:22:52.952727+00', '2019-08-14 09:22:52.952727+00', 'Trinity Knot, The', 3383, '');
INSERT INTO 'tune' VALUES (14083, '2019-08-14 09:23:18.445685+00', '2019-08-14 09:23:18.445685+00', 'Triquetra, The', 3383, '');
INSERT INTO 'tune' VALUES (14084, '2019-08-14 09:44:18.416409+00', '2019-08-14 09:46:11.000039+00', 'World''s End Close', 3383, '');
INSERT INTO 'tune' VALUES (14086, '2019-08-14 09:51:20.794854+00', '2019-08-14 09:51:20.794854+00', 'Caitlin''s Clarinet', 3383, '');
INSERT INTO 'tune' VALUES (14088, '2019-08-14 09:52:49.472886+00', '2019-08-14 09:52:49.472886+00', 'Chris Wagner Turner', 3383, '');
INSERT INTO 'tune' VALUES (14089, '2019-08-14 09:53:20.3196+00', '2019-08-14 09:53:20.3196+00', 'Comely Lass frae Comely Bank, The', 3383, '');
INSERT INTO 'tune' VALUES (14090, '2019-08-14 09:53:43.780888+00', '2019-08-14 09:53:43.780888+00', 'Dapifer to King David II', 3383, '');
INSERT INTO 'tune' VALUES (14091, '2019-08-14 09:54:13.454213+00', '2019-08-14 09:54:13.454213+00', 'Forever and Ever', 3383, '');
INSERT INTO 'tune' VALUES (14092, '2019-08-14 09:54:40.533109+00', '2019-08-14 09:54:40.533109+00', 'James in Spate, The', 3383, '');
INSERT INTO 'tune' VALUES (14081, '2019-08-12 09:16:25.781836+00', '2019-08-16 09:40:23.469365+00', 'Jim Stott''s Tangents', 11858, 'Devised at Summer School 2019 for Jim Stott''s retiral as Director.');
INSERT INTO 'tune' VALUES (14100, '2019-08-21 22:05:53.579361+00', '2019-08-21 22:05:53.579361+00', 'William Williamson of Dykeside', 1574, '');
INSERT INTO 'tune' VALUES (3014, NULL, '2019-08-24 09:29:54.650541+00', 'Back of Catterthin, The', 9999, '');
INSERT INTO 'tune' VALUES (14101, '2019-08-26 12:14:15.511737+00', '2019-08-26 12:14:15.511737+00', 'Wyrick''s Jig', 11378, '');
INSERT INTO 'tune' VALUES (14102, '2019-08-26 12:21:10.762326+00', '2019-08-26 12:21:10.762326+00', 'Spurtle King, The', 10432, '');
INSERT INTO 'tune' VALUES (14103, '2019-08-26 12:22:14.047221+00', '2019-08-26 12:23:04.162172+00', 'Storm Before the Calm, The', 10432, '');
INSERT INTO 'tune' VALUES (14104, '2019-08-26 12:25:42.434021+00', '2019-08-26 12:25:42.434021+00', 'Lord Seaforth''s Strathspey', 9999, 'traditional Scottish from Gow''s Complete Repository Part 3 (1803)');
INSERT INTO 'tune' VALUES (14105, '2019-08-26 12:34:05.406375+00', '2019-08-26 12:34:05.406375+00', 'à la Mode', 10432, 'dedicated to Kate Fletcher formerly of the RSCDS Berkeley class, a "modal" jig to go with Kate''s delicious apple pie!');
INSERT INTO 'tune' VALUES (14106, '2019-08-26 12:35:16.599852+00', '2019-08-26 12:35:16.599852+00', 'lngonish Jig', 9999, 'traditional Cape Breton');
INSERT INTO 'tune' VALUES (14107, '2019-08-26 12:35:59.748147+00', '2019-08-26 12:35:59.748147+00', 'Ingonish Jig', 9999, 'traditional Cape Breton');
INSERT INTO 'tune' VALUES (14108, '2019-08-26 12:36:54.833397+00', '2019-08-26 12:36:54.833397+00', 'Bow Sisters', 10432, '');
INSERT INTO 'tune' VALUES (14109, '2019-08-26 12:40:43.705176+00', '2019-08-26 12:40:43.705176+00', 'Reznicks'' Double Sixty', 10432, 'written to commemorate Greg and Olga''s double 60th birthday celebration');
INSERT INTO 'tune' VALUES (14110, '2019-08-26 12:42:49.141721+00', '2019-08-26 12:42:49.141721+00', 'Steve''s Reel', 10432, '');
INSERT INTO 'tune' VALUES (14111, '2019-08-26 12:45:11.473877+00', '2019-08-26 12:45:11.473877+00', 'Miss Johnson', 9999, 'Irish traditional');
INSERT INTO 'tune' VALUES (14112, '2019-08-26 12:48:52.260087+00', '2019-08-26 12:48:52.260087+00', 'Smoky Morning, A', 10432, '');
INSERT INTO 'tune' VALUES (14113, '2019-08-26 12:50:34.800461+00', '2019-08-26 12:51:57.708383+00', 'Miss Kelman''s Strathspey', 11411, 'by William Christie, A Collection of Strathspeys, Reels & etc. (1820)');
INSERT INTO 'tune' VALUES (14115, '2019-08-26 12:53:17.442987+00', '2019-08-26 12:53:17.442987+00', 'Five Years Mairrit', 10432, 'written to celebrate Julie and Steve''s 5th anniversary');
INSERT INTO 'tune' VALUES (14116, '2019-08-26 12:56:28.132313+00', '2019-08-26 12:56:28.132313+00', 'Eileen''s Hospitality', 10432, 'written 2012 for Eileen Richey in thanks for hosting us and being our tour guide on our visit to Yellowstone National Park');
INSERT INTO 'tune' VALUES (14117, '2019-08-26 12:58:17.575028+00', '2019-08-26 12:58:17.575028+00', 'Mark and Laura''s Wedding', 10432, 'written 2010 for the wedding of Mark Sturdivant and Laura Briggs, dancers from the RSCDS Reno Branch');
INSERT INTO 'tune' VALUES (14118, '2019-08-26 14:02:15.068516+00', '2019-08-26 14:02:15.068516+00', 'Pete and Line''s Comfortable Couch', 10432, 'composed 2013,

dedicated to Pete and Anne-Line Anderson of the RSCDS Orange County Branch');
INSERT INTO 'tune' VALUES (14119, '2019-08-26 14:03:37.306045+00', '2019-08-26 14:04:18.062627+00', 'Interbranch Jig, The', 10432, 'composed 2017, 

dedicated to all the members of the Southern California RSCDS branches');
INSERT INTO 'tune' VALUES (14120, '2019-08-26 14:05:54.096094+00', '2019-08-26 14:05:54.096094+00', 'Jeff and Margaret''s Jig', 10432, 'composed 2018, 

dedicated to Jeff Altman and Margaret Burnett of the RSCDS San Gabriel Valley Branch');
INSERT INTO 'tune' VALUES (14121, '2019-08-26 14:06:58.149883+00', '2019-08-26 14:06:58.149883+00', 'Ghosts of Fort Worden', 10432, 'composed 2014');
INSERT INTO 'tune' VALUES (14122, '2019-08-26 14:10:47.167834+00', '2019-08-26 14:10:47.167834+00', 'Mrs General Campbell', 9998, 'Kerr''s Collection of Merry Melodies Volume 2 (1875)');
INSERT INTO 'tune' VALUES (14123, '2019-08-26 14:15:31.612259+00', '2019-08-26 14:15:31.612259+00', 'Cap''n Caplin''s Hornpipe', 10432, 'composed 2011, 

dedicated to Mark Caplin of the RSCDS San Francisco Branch');
INSERT INTO 'tune' VALUES (14124, '2019-08-26 14:17:57.49112+00', '2019-08-26 14:17:57.49112+00', 'Ball and Pin Hornpipe', 9998, 'Ryan''s Mammoth Collection (1883)');
INSERT INTO 'tune' VALUES (14087, '2019-08-14 09:51:53.459904+00', '2020-01-20 10:24:48.912349+00', 'Chris Turner''s Christmas Waltz', 11917, '');
INSERT INTO 'tune' VALUES (14085, '2019-08-14 09:45:17.554496+00', '2020-05-08 17:25:21.949656+00', 'Goldsmith''s House at Netherbow, The', 3383, '');
INSERT INTO 'tune' VALUES (14068, '2019-06-14 20:48:59.740325+00', '2020-12-02 10:48:32.283204+00', 'Jumping Bean', 11824, '');
INSERT INTO 'tune' VALUES (14125, '2019-08-26 14:19:07.494125+00', '2019-08-26 14:19:07.494125+00', 'Quindaro', 9998, 'Ryan''s Mammoth Collection');
INSERT INTO 'tune' VALUES (14126, '2019-08-26 14:29:11.506655+00', '2019-08-26 14:29:11.506655+00', 'Second Chance', 10432, 'written 2013 for Greg and Olga Reznick on the occasion of their fifth wedding anniversary');
INSERT INTO 'tune' VALUES (14127, '2019-09-01 23:20:40.118382+00', '2019-09-01 23:20:40.118382+00', 'Patrick Keith Stacey', 1502, '');
INSERT INTO 'tune' VALUES (14130, '2019-09-05 09:27:13.314304+00', '2019-09-05 09:29:08.674071+00', 'David Teale''s Reel', 1938, '');
INSERT INTO 'tune' VALUES (14141, '2019-10-24 16:59:08.10047+00', '2019-10-24 16:59:08.10047+00', 'Summer Bird, The', 11894, '');
INSERT INTO 'tune' VALUES (14131, '2019-09-05 09:51:45.32401+00', '2019-09-05 09:51:45.32401+00', 'Leftovers', 11873, '');
INSERT INTO 'tune' VALUES (14128, '2019-09-05 09:24:47.984639+00', '2019-09-06 09:57:42.95504+00', 'Tribute to Tim Bolton-Maggs, A', 2743, '');
INSERT INTO 'tune' VALUES (148, NULL, '2019-09-14 20:15:48.859215+00', 'Bonnie Breist Knots, The', 9999, '');
INSERT INTO 'tune' VALUES (14132, '2019-09-16 21:31:15.62804+00', '2019-09-16 21:31:15.62804+00', 'Great Valerio, The', 11321, 'Composer:  Richard Thompson, adapted by Patti Cobb');
INSERT INTO 'tune' VALUES (14133, '2019-09-22 16:46:35.485174+00', '2019-09-22 16:46:35.485174+00', 'Diamond in Sutton Coldfield, A', 1526, '2019');
INSERT INTO 'tune' VALUES (14134, '2019-09-23 07:52:37.01114+00', '2019-09-23 07:52:37.01114+00', 'All Saints Strathspey', 1526, '');
INSERT INTO 'tune' VALUES (8847, NULL, '2019-09-30 22:23:18.736594+00', 'Piper and the Penguin, The', 1502, '');
INSERT INTO 'tune' VALUES (8499, NULL, '2019-09-30 23:12:49.509054+00', 'Margaret & Jim Dewar', 1591, '');
INSERT INTO 'tune' VALUES (14135, '2019-10-01 13:16:30.758925+00', '2019-10-01 13:16:30.758925+00', 'Geneva Dancers, The', 3465, 'This tune was a gift to Liz and Gordon Matthew for their hospitality.');
INSERT INTO 'tune' VALUES (8797, NULL, '2019-10-01 21:04:59.886442+00', 'Anne Marie Morrison of Borve', 1634, 'There are various spelling variations of this tune, eg "Anne Marie", "Anne-Marie", "Ann-Marie", "Ann-Maree".');
INSERT INTO 'tune' VALUES (2986, NULL, '2019-10-03 18:32:42.123082+00', 'Willie Brewed a Peck o'' Maut', 9999, 'The title is a Burns poem set to music by Allan Masterton.');
INSERT INTO 'tune' VALUES (14137, '2019-10-23 13:23:38.515972+00', '2019-10-23 13:23:38.515972+00', 'Link, The', 1456, '');
INSERT INTO 'tune' VALUES (14138, '2019-10-24 16:57:22.03307+00', '2019-10-24 16:57:22.03307+00', 'Smoke on the Mountain', 11894, '');
INSERT INTO 'tune' VALUES (14139, '2019-10-24 16:57:51.445703+00', '2019-10-24 16:57:51.445703+00', 'Mr Stewart''s Jig', 3454, '');
INSERT INTO 'tune' VALUES (14140, '2019-10-24 16:58:40.541056+00', '2019-10-24 16:58:40.541056+00', 'First of May, The', 9999, '');
INSERT INTO 'tune' VALUES (14142, '2019-10-24 16:59:40.624122+00', '2019-10-24 16:59:40.624122+00', 'Alice''s Strathspey', 11805, '');
INSERT INTO 'tune' VALUES (14143, '2019-10-24 17:00:29.264941+00', '2019-10-24 17:00:29.264941+00', 'President''s Hornpipe, The', 11463, '');
INSERT INTO 'tune' VALUES (14144, '2019-10-24 17:04:55.763392+00', '2019-10-24 17:04:55.763392+00', 'Saligo Bay', 11894, '');
INSERT INTO 'tune' VALUES (14145, '2019-10-24 17:05:24.159911+00', '2019-10-24 17:05:24.159911+00', 'Honest Poverty', 11894, '');
INSERT INTO 'tune' VALUES (14146, '2019-10-24 17:05:55.548052+00', '2019-10-24 17:05:55.548052+00', 'Romance sans paroles', 3454, '');
INSERT INTO 'tune' VALUES (14147, '2019-10-24 17:06:39.416965+00', '2019-10-24 17:06:39.416965+00', 'Rachel''s Jig', 11463, '');
INSERT INTO 'tune' VALUES (14148, '2019-10-24 17:07:14.834049+00', '2019-10-24 17:07:14.834049+00', 'Miss Millar', 2193, '');
INSERT INTO 'tune' VALUES (14149, '2019-10-24 17:07:50.178667+00', '2019-10-24 17:07:50.178667+00', 'Millennium Reel, The', 2193, '');
INSERT INTO 'tune' VALUES (10823, '2009-11-30 23:00:00+00', '2019-10-25 21:45:29.683097+00', 'Pottinger''s Pineapple Polka', 1645, '');
INSERT INTO 'tune' VALUES (10644, '2009-11-20 23:00:00+00', '2019-10-28 23:35:46.367172+00', 'Glenkinchie''s Compliments to Lord and Lady Macfarlane of Bearsden', 1539, '');
INSERT INTO 'tune' VALUES (14151, '2019-10-28 22:51:15.916699+00', '2019-10-29 12:08:08.335384+00', 'Reavey Roundabout, The', 11898, '');
INSERT INTO 'tune' VALUES (14152, '2019-10-29 10:17:49.883323+00', '2019-10-29 12:09:05.506967+00', 'Wendouree Waters', 11898, '');
INSERT INTO 'tune' VALUES (14154, '2019-10-29 11:17:37.20304+00', '2019-10-29 12:04:54.210137+00', 'Daylesford Reel, The', 11898, '');
INSERT INTO 'tune' VALUES (14155, '2019-10-29 11:23:52.717979+00', '2019-10-29 12:06:10.461858+00', 'Ballarat Bertie''s Bounce', 11898, '');
INSERT INTO 'tune' VALUES (14150, '2019-10-28 21:19:42.979153+00', '2019-10-29 12:07:17.362701+00', 'Jane''s Canadian Strathspey', 11898, '');
INSERT INTO 'tune' VALUES (14153, '2019-10-29 10:31:31.499926+00', '2019-10-29 12:10:14.561079+00', 'Wheels for April Fools', 11898, '');
INSERT INTO 'tune' VALUES (14156, '2019-11-01 17:37:28.04746+00', '2019-11-01 17:37:28.04746+00', 'I''ll Give It Five-O!', 1899, '');
INSERT INTO 'tune' VALUES (14157, '2019-11-01 17:44:13.022672+00', '2019-11-01 17:44:13.022672+00', 'All Roads Lead to the ''G', 1899, '');
INSERT INTO 'tune' VALUES (14158, '2019-11-01 17:46:04.564712+00', '2019-11-01 17:46:04.564712+00', 'Amberley', 1899, '');
INSERT INTO 'tune' VALUES (14160, '2019-11-01 17:59:31.726194+00', '2019-11-01 17:59:31.726194+00', 'Celebration Reel, The', 1899, '');
INSERT INTO 'tune' VALUES (14161, '2019-11-01 18:02:27.255951+00', '2019-11-01 18:02:27.255951+00', 'Curlique', 1899, '');
INSERT INTO 'tune' VALUES (13717, '2017-11-08 11:19:39.066185+00', '2019-11-02 13:52:41.190568+00', 'Ollaberry Two Step, The', 2286, '');
INSERT INTO 'tune' VALUES (14159, '2019-11-01 17:53:21.817264+00', '2019-11-02 17:46:56.817883+00', 'Bronzewing, The', 1899, '');
INSERT INTO 'tune' VALUES (13735, '2017-11-08 14:22:48.565336+00', '2019-11-03 07:56:53.316471+00', 'Margaret and Donald Ferguson', 10086, '');
INSERT INTO 'tune' VALUES (4415, NULL, '2019-11-03 23:38:28.839433+00', 'Captain Craig Brown', 1959, 'For information about this tune see <<https://boxandfiddlearchive.weebly.com/captain-craig-brown.html>>.');
INSERT INTO 'tune' VALUES (10495, '2009-11-16 23:00:00+00', '2019-11-04 13:05:29.586101+00', 'Bobby Tulloch''s Reel', 10758, '');
INSERT INTO 'tune' VALUES (11523, '2011-06-14 22:00:00+00', '2019-11-04 18:33:39.855694+00', 'Coldstream Jig, The', 10058, '');
INSERT INTO 'tune' VALUES (14166, '2019-12-09 13:21:14.21354+00', '2019-12-09 13:21:14.21354+00', 'Ruby Red, The', 1815, '');
INSERT INTO 'tune' VALUES (14136, '2019-10-14 14:24:12.59723+00', '2023-02-26 21:56:25.609045+00', 'Sarah May''s Jig', 1445, '');
INSERT INTO 'tune' VALUES (284, NULL, '2019-11-04 21:27:33.648903+00', 'Clach na Cudain', 9999, 'In the description of this dance, John Drewry writes:  

The Secretary of the Inverness branch tells me theat "Cudainn" should be speled with two ""s, but the name of the tune is spelled :Cudain" in my music books  ');
INSERT INTO 'tune' VALUES (14045, '2019-05-31 17:24:07.466167+00', '2019-11-10 13:16:26.220701+00', 'Iris Ronayne''s Reel', 1596, '');
INSERT INTO 'tune' VALUES (12217, '2012-10-18 14:35:38.476171+00', '2019-11-14 08:55:19.162032+00', 'Traditional Canadian Jig', 9999, '');
INSERT INTO 'tune' VALUES (14162, '2019-11-17 22:57:39.295169+00', '2019-11-17 23:00:10.519572+00', 'Mrs Cuthbert of Selkirk', 1815, 'A Strathspey');
INSERT INTO 'tune' VALUES (12510, '2013-02-27 13:14:26.938296+00', '2019-11-21 18:16:47.671185+00', 'Shine On, Harvest Moon', 10757, 'The song is officially credited to Bayes and Norworth, but during the early 20th century (the song was written in 1908) songs were often sold outright, and the purchase then got the writing title. It''s more likely that this song was either written by Edward Madden and Gus Edwards or Dave Stamper (the later was employed as a pianist by Bayes and Norworth at the time).');
INSERT INTO 'tune' VALUES (14163, '2019-11-22 19:38:47.545787+00', '2019-11-22 19:38:47.545787+00', 'Purfy', 3043, '');
INSERT INTO 'tune' VALUES (14164, '2019-11-22 19:40:42.513354+00', '2019-11-22 19:40:42.513354+00', 'Grand Antiquity, The', 9999, '');
INSERT INTO 'tune' VALUES (1702, NULL, '2019-11-22 19:46:36.727434+00', 'Ally Crocker', 2167, 'There seems to be many possible aliases for this tune with variants of Allie/Ally/Alley/Aly and Crocker/Croker/Croaker.');
INSERT INTO 'tune' VALUES (14165, '2019-11-22 20:01:22.031348+00', '2019-11-22 20:01:22.031348+00', 'Dr. Angus and Emily MacDonald''s Trip to San Francisco', 1782, '');
INSERT INTO 'tune' VALUES (1845, NULL, '2019-11-26 22:19:57.624638+00', '''S ioma rud tha dhidh orm', 9999, 'As mentioned in <<http://my.strathspey.org/dd/issue/1896/|issue 1896>> this tune is known both by the first line of the song (''S ioma rud tha dhidh orm) and the name of the person mentioned later on (Mor a'' Cheannaich).');
INSERT INTO 'tune' VALUES (2321, NULL, '2019-12-20 19:22:17.012374+00', 'J. F. MacKenzie of Garrynahine, Stornoway', 1635, '');
INSERT INTO 'tune' VALUES (12414, '2013-01-16 13:18:21.85583+00', '2019-12-20 20:03:33.258172+00', 'You Made Me Love You', 10712, '');
INSERT INTO 'tune' VALUES (14168, '2019-12-23 21:15:45.360446+00', '2019-12-23 21:15:45.360446+00', 'Ian Rose, Man of Mistley', 1631, '');
INSERT INTO 'tune' VALUES (14169, '2019-12-23 21:17:11.308464+00', '2019-12-23 21:17:11.308464+00', 'Mr and Mrs McDonald of Home Park', 1631, '');
INSERT INTO 'tune' VALUES (10886, '2009-12-02 23:00:00+00', '2020-01-03 21:29:58.953584+00', 'Young Fiddler, The', 11645, '');
INSERT INTO 'tune' VALUES (10262, '2009-11-02 23:00:00+00', '2020-01-12 12:55:17.165327+00', 'Jim Brown of Kintillo', 1554, '');
INSERT INTO 'tune' VALUES (2873, NULL, '2020-01-12 12:57:02.455058+00', 'Billy Nicolson', 1724, '');
INSERT INTO 'tune' VALUES (9328, NULL, '2020-01-12 13:04:24.192658+00', 'Bridge of Spey, The', 1516, '');
INSERT INTO 'tune' VALUES (14170, '2020-01-19 11:36:49.001512+00', '2020-01-19 11:36:49.001512+00', 'Bealach na Bà', 1846, '');
INSERT INTO 'tune' VALUES (14171, '2020-01-19 22:07:14.332813+00', '2020-01-19 22:07:14.332813+00', 'Croft Conundrum, The', 1631, '');
INSERT INTO 'tune' VALUES (14172, '2020-01-19 22:26:26.750646+00', '2020-01-19 22:26:26.750646+00', 'Robertson Crescent', 1677, '');
INSERT INTO 'tune' VALUES (14173, '2020-01-19 22:27:09.052647+00', '2020-01-19 22:27:09.052647+00', 'Struan Char, The', 1631, '');
INSERT INTO 'tune' VALUES (14174, '2020-01-19 22:36:16.103449+00', '2020-01-19 22:36:16.103449+00', 'When Reality Dawns', 1631, '');
INSERT INTO 'tune' VALUES (5593, NULL, '2020-01-19 22:53:24.526666+00', 'Eleanora Robertson''s Favourite', 1517, '');
INSERT INTO 'tune' VALUES (14175, '2020-01-19 22:56:25.89859+00', '2020-01-19 22:56:25.89859+00', 'Jig for Joan, A', 1631, '');
INSERT INTO 'tune' VALUES (14176, '2020-01-19 23:04:01.308194+00', '2020-01-19 23:04:01.308194+00', 'Mr Robertson of Ladykirk', 1517, '');
INSERT INTO 'tune' VALUES (14177, '2020-01-19 23:04:40.815802+00', '2020-01-19 23:04:40.815802+00', 'Tom''s Majority', 1631, '');
INSERT INTO 'tune' VALUES (13904, '2018-06-09 22:09:16.680546+00', '2020-01-20 10:48:43.865718+00', 'Mrs Robertson of Lawers'' Delight', 9999, '');
INSERT INTO 'tune' VALUES (14178, '2020-01-20 11:00:38.985513+00', '2020-01-20 11:01:15.858086+00', 'Mrs Robertson of Lawers'' Reel', 1486, '');
INSERT INTO 'tune' VALUES (14179, '2020-01-20 11:03:24.987094+00', '2020-01-20 11:03:24.987094+00', 'Mrs Robertson of Lawers', 1486, '');
INSERT INTO 'tune' VALUES (14180, '2020-01-20 11:08:40.636198+00', '2020-01-20 11:08:40.636198+00', 'Miss Robertson of Tullybelton', 1517, '');
INSERT INTO 'tune' VALUES (7948, NULL, '2020-01-20 11:10:23.278472+00', 'Mr Robertson of Lude', 1518, '');
INSERT INTO 'tune' VALUES (14181, '2020-01-20 11:13:15.502359+00', '2020-01-20 11:13:15.502359+00', 'Colonel Robertson of Lawers', 1486, '');
INSERT INTO 'tune' VALUES (14182, '2020-01-20 11:28:37.172331+00', '2020-01-20 11:28:37.172331+00', 'Mrs Robertson of Ladykirk''s Favourite', 1974, '');
INSERT INTO 'tune' VALUES (11848, '2011-11-25 23:00:00+00', '2020-01-20 22:29:31.41251+00', 'Cape Breton Fiddler''s Welcome To Shetland, The', 1677, '');
INSERT INTO 'tune' VALUES (14184, '2020-01-20 23:27:57.495539+00', '2020-01-20 23:27:57.495539+00', 'Four Score Reel', 1631, 'Written by Ian for his mother''s 80th birthday.');
INSERT INTO 'tune' VALUES (14185, '2020-01-20 23:29:52.641557+00', '2020-01-20 23:29:52.641557+00', 'Life, Love and Loss', 1631, 'Written as a memorial for the composer''s father Alan who died in 2013.');
INSERT INTO 'tune' VALUES (14186, '2020-01-20 23:35:40.172627+00', '2020-01-20 23:35:40.172627+00', 'Orfosay', 11918, '');
INSERT INTO 'tune' VALUES (14187, '2020-01-20 23:38:21.53344+00', '2020-01-20 23:38:21.53344+00', 'Sedorwood', 1644, '');
INSERT INTO 'tune' VALUES (14188, '2020-01-20 23:41:42.221728+00', '2020-01-20 23:41:42.221728+00', 'Ian and Isobel', 1644, '');
INSERT INTO 'tune' VALUES (14189, '2020-01-20 23:43:03.580016+00', '2020-01-20 23:43:03.580016+00', 'Jennifer', 1631, '');
INSERT INTO 'tune' VALUES (14190, '2020-01-20 23:43:22.304029+00', '2020-01-20 23:43:22.304029+00', 'After the Summer Rain', 1631, '');
INSERT INTO 'tune' VALUES (14191, '2020-01-21 10:09:19.18256+00', '2020-01-21 10:09:19.18256+00', 'William J Birnie', 1644, '');
INSERT INTO 'tune' VALUES (14192, '2020-01-21 10:17:26.093024+00', '2020-01-21 10:17:26.093024+00', 'Stewart Robertson''s Strathspey', 1695, '');
INSERT INTO 'tune' VALUES (14183, '2020-01-20 11:30:59.208882+00', '2020-01-21 10:18:39.930897+00', 'Miss Isabella Robertson''s Hornpipe', 1519, '');
INSERT INTO 'tune' VALUES (14193, '2020-01-21 10:22:06.04183+00', '2020-01-21 10:22:06.04183+00', 'Miss Eleanora Robertson''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (14194, '2020-01-21 10:23:19.647856+00', '2020-01-21 10:23:19.647856+00', 'Miss Stewart-Robertson of Edradynate', 1695, '');
INSERT INTO 'tune' VALUES (14195, '2020-01-21 10:25:38.724771+00', '2020-01-21 10:25:38.724771+00', 'Fiddler o'' Bath', 1505, '');
INSERT INTO 'tune' VALUES (14196, '2020-01-21 10:26:46.135156+00', '2020-01-21 10:26:46.135156+00', 'Miss Mary L Robertson', 1516, '');
INSERT INTO 'tune' VALUES (5268, NULL, '2020-01-21 10:29:50.984582+00', 'Mrs George Robertson''s Reel', 1516, '');
INSERT INTO 'tune' VALUES (14197, '2020-01-21 10:31:14.668766+00', '2020-01-21 10:31:14.668766+00', 'Friend for All Seasons, A', 1631, '');
INSERT INTO 'tune' VALUES (14198, '2020-01-21 10:38:58.458626+00', '2020-01-21 10:38:58.458626+00', 'On the Road to Fermoy', 1515, '');
INSERT INTO 'tune' VALUES (14199, '2020-01-21 10:42:37.066736+00', '2020-01-21 10:42:37.066736+00', 'Betty Jessiman', 1515, '');
INSERT INTO 'tune' VALUES (14200, '2020-01-21 10:43:21.166042+00', '2020-01-21 10:43:21.166042+00', 'Home by Dawn', 1631, '');
INSERT INTO 'tune' VALUES (14201, '2020-01-21 10:44:56.666779+00', '2020-01-21 10:44:56.666779+00', 'Waltz for Rebecca and Joe', 1631, '');
INSERT INTO 'tune' VALUES (14202, '2020-01-21 10:45:07.583256+00', '2020-01-21 10:45:07.583256+00', 'Every Time I Dance', 1631, '');
INSERT INTO 'tune' VALUES (14203, '2020-01-21 10:46:31.949536+00', '2020-01-21 10:46:31.949536+00', 'Awkward Customer, The', 1631, '');
INSERT INTO 'tune' VALUES (14204, '2020-01-21 15:20:15.143077+00', '2020-01-21 15:20:15.143077+00', 'Francis Robertson', 1554, '');
INSERT INTO 'tune' VALUES (357, NULL, '2020-01-22 23:45:42.177723+00', 'D. Morrison''s Seven Thistles', 1512, '');
INSERT INTO 'tune' VALUES (5464, NULL, '2020-01-24 21:28:50.050014+00', 'Rodd Ta Houll, Da', 1710, 'There are many variants of the name.');
INSERT INTO 'tune' VALUES (2134, NULL, '2020-01-24 23:42:49.675072+00', 'Sir David Davidson of Cantry', 445, 'The original SCDDB entry has "Cantry" and there seem to be several recordings using that. However the "Cantray" spelling seems more common in the tune websites (<<https://tunearch.org>>, <<https://thesession.org>>, <<https://john-chambers.us/~jc/cgi/abc/tunefind>>) so that is added as an alias.');
INSERT INTO 'tune' VALUES (13256, '2015-12-30 18:55:24.008503+00', '2020-01-25 23:12:12.085865+00', 'Up and Doon the Doldenhorn', 1591, '');
INSERT INTO 'tune' VALUES (2800, NULL, '2020-01-26 22:39:37.641282+00', 'Rev. Peter Fenton, The', 1598, '');
INSERT INTO 'tune' VALUES (17, NULL, '2020-01-26 22:56:48.504377+00', 'Alan Maxwell''s Farewell to Balmerino', 1680, 'The entry for the dance <<ddd:Farewell To Balmerino#2081>> originally referred to this tune as Alex (not Alan) Maxwell''s Farewell to Balmerino. This is assumed to be a typo though its not clear if its in the published book or the original SCDDB entry for it. This typo is kept as an alias.');
INSERT INTO 'tune' VALUES (5153, NULL, '2020-01-27 09:19:14.72779+00', 'Sir James G Baird, Bart.', 1519, '');
INSERT INTO 'tune' VALUES (11409, '2010-10-15 22:00:00+00', '2020-01-30 22:10:45.24835+00', 'Anything Doing', 1567, '');
INSERT INTO 'tune' VALUES (5190, NULL, '2020-01-30 22:30:46.043527+00', 'Roses o'' Prince Charlie', 2274, '');
INSERT INTO 'tune' VALUES (14209, '2020-03-05 09:27:01.663238+00', '2020-03-05 09:27:01.663238+00', 'Rev. Everett H Greene, The', 3383, '');
INSERT INTO 'tune' VALUES (14210, '2020-03-05 09:27:28.132117+00', '2020-03-05 09:27:28.132117+00', 'Tinker''s Holiday, The', 3383, '');
INSERT INTO 'tune' VALUES (14205, '2020-02-01 17:15:19.654995+00', '2020-02-01 17:15:19.654995+00', 'Marching thru'' the Heather', 9998, 'Not sure if this might be a duplicate/alias of <<ddt:#3900>>.');
INSERT INTO 'tune' VALUES (14206, '2020-02-05 21:08:50.730911+00', '2020-02-05 21:08:50.730911+00', 'Schoolgirls Together', 3383, '');
INSERT INTO 'tune' VALUES (4360, NULL, '2020-02-06 21:46:05.427162+00', 'O''er the Hills and Far Away', 9999, '');
INSERT INTO 'tune' VALUES (8851, NULL, '2020-02-10 10:18:45.166586+00', 'Miss Ann Douglas Brigton''s Jig', 1749, 'NB this is not the same tune as <<ddt:#7599>>.');
INSERT INTO 'tune' VALUES (7599, NULL, '2020-02-10 10:19:18.602746+00', 'Miss Douglas Brigton''s Jigg', 1749, 'NB this is not the same tune as <<ddt:#8851>>.');
INSERT INTO 'tune' VALUES (14208, '2020-02-15 16:22:08.892783+00', '2020-02-15 16:22:08.892783+00', 'Lou Hanson''s Strathspey', 3419, '');
INSERT INTO 'tune' VALUES (14213, '2020-03-05 09:42:39.438978+00', '2020-03-05 09:42:39.438978+00', 'Helen Angus of Meadowbank', 3383, '');
INSERT INTO 'tune' VALUES (14214, '2020-03-05 09:43:43.560587+00', '2020-03-05 09:44:39.01595+00', 'Penny Tray at the Sweetie Shop, The', 3383, '');
INSERT INTO 'tune' VALUES (9382, '2004-11-01 23:00:00+00', '2020-04-01 15:21:29.884199+00', 'Strictly Scottish', 2743, '');
INSERT INTO 'tune' VALUES (6520, NULL, '2020-04-07 14:51:45.603949+00', 'Dr Stella Clark', 1585, '');
INSERT INTO 'tune' VALUES (14223, '2020-05-03 14:41:46.092899+00', '2020-05-03 14:41:46.092899+00', 'Piece of Cake, A', 1526, '');
INSERT INTO 'tune' VALUES (13896, '2018-06-09 01:05:07.929713+00', '2020-04-10 18:30:36.627183+00', 'Three Bernadettes, The', 1502, 'The instructions for the <<ddd:#19944|dance of the same name>>, also by Muriel Johnstone, mention the tune as B Times Three. The recording of <<ddrec:#10034>> has it as The Three Bernadettes.');
INSERT INTO 'tune' VALUES (935, NULL, '2020-04-12 23:38:42.787817+00', 'Meldrum House', 2963, '');
INSERT INTO 'tune' VALUES (14216, '2020-05-02 16:48:14.286957+00', '2020-05-02 16:48:14.286957+00', 'Castle Church Jig', 1526, '');
INSERT INTO 'tune' VALUES (14217, '2020-05-02 16:48:34.448888+00', '2020-05-02 16:48:34.448888+00', 'Welcome to Morland', 1526, '');
INSERT INTO 'tune' VALUES (14218, '2020-05-02 16:48:59.346414+00', '2020-05-02 16:48:59.346414+00', 'Guid Health', 1526, '');
INSERT INTO 'tune' VALUES (14220, '2020-05-03 14:40:38.297821+00', '2020-05-03 14:40:38.297821+00', 'Sunshine and Snow', 1526, '');
INSERT INTO 'tune' VALUES (14222, '2020-05-03 14:41:19.274126+00', '2020-05-03 14:41:19.274126+00', 'Weavers of Tillicoultry, The', 1526, '');
INSERT INTO 'tune' VALUES (14224, '2020-05-03 14:42:13.107384+00', '2020-05-03 14:42:13.107384+00', 'Remembering Fethaland', 1526, '');
INSERT INTO 'tune' VALUES (14229, '2020-05-03 15:04:26.938564+00', '2020-05-03 15:04:26.938564+00', 'Star of Munster', 9998, '');
INSERT INTO 'tune' VALUES (14230, '2020-05-03 15:04:49.9783+00', '2020-05-03 15:04:49.9783+00', 'St Anne''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (14231, '2020-05-04 10:46:53.731394+00', '2020-05-04 10:46:53.731394+00', 'Langleys Reel', 1526, '');
INSERT INTO 'tune' VALUES (14233, '2020-05-04 10:50:20.48308+00', '2020-05-04 10:50:20.48308+00', 'Humours of Glendart', 9998, '');
INSERT INTO 'tune' VALUES (14235, '2020-05-04 10:54:50.178459+00', '2020-05-04 10:54:50.178459+00', 'Salt Fish and Dumplings', 9998, '');
INSERT INTO 'tune' VALUES (14236, '2020-05-04 10:56:28.422244+00', '2020-05-04 10:56:28.422244+00', 'St Magnus Bay', 1521, '');
INSERT INTO 'tune' VALUES (14228, '2020-05-03 14:43:42.314616+00', '2020-05-08 17:26:12.337476+00', 'Campbell''s Oaties', 1526, '');
INSERT INTO 'tune' VALUES (14207, '2020-02-05 21:32:46.316247+00', '2021-01-02 12:23:24.52903+00', 'Jack Jack', 3383, '');
INSERT INTO 'tune' VALUES (14227, '2020-05-03 14:43:23.928579+00', '2020-05-08 07:42:54.722681+00', 'Life in the Fast Lane', 1526, '');
INSERT INTO 'tune' VALUES (14215, '2020-05-02 16:47:54.278901+00', '2020-05-08 17:25:39.03158+00', 'St Andrews'' Welcome', 1526, '');
INSERT INTO 'tune' VALUES (14225, '2020-05-03 14:42:36.214954+00', '2020-05-08 17:25:58.202589+00', 'Hams o'' Roe, The', 1526, '');
INSERT INTO 'tune' VALUES (14237, '2020-05-04 11:13:12.291674+00', '2020-05-08 17:26:46.016411+00', 'Lochiel''s Welcome', 9998, '');
INSERT INTO 'tune' VALUES (14238, '2020-05-04 11:14:33.506211+00', '2020-05-08 17:27:00.023356+00', 'Helen Jones'' Strathspey', 3359, '');
INSERT INTO 'tune' VALUES (14232, '2020-05-04 10:50:00.692495+00', '2020-05-08 18:50:18.942096+00', 'Love, Port and Sherry', 9999, '');
INSERT INTO 'tune' VALUES (14234, '2020-05-04 10:51:45.341588+00', '2020-05-08 18:51:10.498713+00', '72nd''s Farewell to Aberdeen', 9999, '');
INSERT INTO 'tune' VALUES (14211, '2020-03-05 09:28:52.69846+00', '2021-01-02 16:24:39.906901+00', 'Seán Heely, National Champion 2016', 3383, '');
INSERT INTO 'tune' VALUES (14219, '2020-05-03 14:40:19.869666+00', '2020-05-08 07:41:44.965941+00', 'Lomond Hills', 1526, '');
INSERT INTO 'tune' VALUES (13968, '2018-11-12 00:36:16.86339+00', '2020-05-08 17:25:03.532543+00', 'Swans o'' the bay', 3179, '');
INSERT INTO 'tune' VALUES (14262, '2020-05-29 15:33:09.758728+00', '2020-05-29 15:33:09.758728+00', 'Chris Werner', 1764, '');
INSERT INTO 'tune' VALUES (471, NULL, '2020-05-22 22:12:47.972761+00', 'Durisdeer', 1703, '');
INSERT INTO 'tune' VALUES (12933, '2014-05-09 23:02:23.528374+00', '2020-05-08 21:16:48.292776+00', 'Da Sockit Light', 9999, 'Possibly a reel version of <<ddt:#7803>>. To be checked.');
INSERT INTO 'tune' VALUES (62, NULL, '2020-05-09 17:55:20.913127+00', 'Athlone Jig, The', 9999, 'The database previously attributed this tune to <<ddp:#1554>>. However this was questioned by <<ddp:#1526>> who writes:



*Regarding “The Athlone Jig”, I am pretty confident that the tune is not by Angus Fitchet, since it is not included in any of the 3 volumes of his music which were published by “The National Association of Accordion and Fiddle Clubs”.  According to the foreword in Volume 3 (written by Nicol McLaren) this is a complete anthology of Angus’s compositions.  Of course, it is always possible that a lesser-known tune might have been missed, but this seems unlikely, since “The Athlone Jig” has been recorded by many well-known bands.*

 

*I have not yet come across “The Athlone Jig” in a publication, but the same tune, in a longer form, and with some small melodic differences, was published in “The Francis Roche Collection of Traditional Irish Music, Volume 3, 1927, Page 44, Tune 140” under the name “The Bridge of Athlone”, so whilst both the tune and the name have been shortened, it would seem reasonable to assume that “The Athlone Jig” is ‘Traditional’.*

');
INSERT INTO 'tune' VALUES (987, NULL, '2020-05-09 18:06:01.546223+00', 'Leaving Lismore', 2461, 'The database previously attributed this tune to <<ddp:#2334>>. However this was questioned by <<ddp:#1526>> who writes:



*It is published in the Scots Guards Pipe Music Volume 2, where it is credited to Mrs Martin Hardie; it is used as a hymn tune (for “Spirit of God, Come Dwell Within Me”) in “The Church Hymnary”, where the composer is given as Margaret Martin-Hardie, and it has several other titles, including the Gaelic “Fagail Liosmor”.  I notice it is also included in the SCD Database under <<ddt:#6879|this name>>. The MCPS licence for our CD gives the writer’s name as “Hardie”, and indicates that the tune is a “non-copyright work” in the public domain.  Many online sources also give Margaret Martin-Hardie as the composer, so whilst I am no expert, it seems likely to me that either the tune was composed by Margaret Martin-Hardie (the most commonly-held view), or that it is a traditional tune which she arranged (for which I have seen no evidence as yet).  The name “A MacLaren” (given as the composer in the SCD Database) is not commonly associated with the tune.*');
INSERT INTO 'tune' VALUES (14241, '2020-05-11 19:51:59.812767+00', '2020-05-11 19:51:59.812767+00', 'Orcadian Jig', 9999, '');
INSERT INTO 'tune' VALUES (9040, NULL, '2020-05-11 20:01:30.677151+00', 'Orcadian Reel', 11947, '');
INSERT INTO 'tune' VALUES (14242, '2020-05-11 21:33:36.299399+00', '2020-05-11 21:33:36.299399+00', 'Country Dance (Jig)', 9999, 'Note this tune is not the same as <<ddt:#328>> which is a reel.');
INSERT INTO 'tune' VALUES (14243, '2020-05-21 09:16:19.356171+00', '2020-05-21 09:16:19.356171+00', 'Thornton Glen', 3710, '');
INSERT INTO 'tune' VALUES (14244, '2020-05-21 09:16:50.024411+00', '2020-05-21 09:16:50.024411+00', 'Fourmerkland Tower', 1668, '');
INSERT INTO 'tune' VALUES (14245, '2020-05-21 09:30:31.543153+00', '2020-05-21 09:30:31.543153+00', 'Law Society of Scotland Platinum Jig', 11858, '');
INSERT INTO 'tune' VALUES (14246, '2020-05-21 09:45:35.699767+00', '2020-05-21 09:45:35.699767+00', 'Aye Aye Chief - Martin Galloway''s Reel', 11858, '');
INSERT INTO 'tune' VALUES (14247, '2020-05-21 09:46:30.987206+00', '2020-05-21 09:46:30.987206+00', 'H.M.S Bristol', 11858, '');
INSERT INTO 'tune' VALUES (14249, '2020-05-21 10:02:43.165636+00', '2020-05-21 10:02:43.165636+00', 'Stephen''s Lost Baggage', 11858, '');
INSERT INTO 'tune' VALUES (14250, '2020-05-22 21:31:06.298678+00', '2020-05-22 21:31:06.298678+00', 'They Can''t Take That Away From Me', 9998, 'Tune (with missing composer) taken from: https://www.allcelticmusic.com/music/94397cce-f86e-102a-8020-000f1f67beb1/Note_n_Away.html ');
INSERT INTO 'tune' VALUES (14251, '2020-05-22 21:31:41.337075+00', '2020-05-22 21:31:41.337075+00', 'Nearness Of You, The', 9998, 'Tune (with missing composer) taken from: https://www.allcelticmusic.com/music/94397cce-f86e-102a-8020-000f1f67beb1/Note_n_Away.html ');
INSERT INTO 'tune' VALUES (14252, '2020-05-22 21:34:54.13641+00', '2020-05-22 21:34:54.13641+00', 'Anne Grant''s Compliments To Alex MacArthur', 478, '');
INSERT INTO 'tune' VALUES (14253, '2020-05-22 21:40:33.101971+00', '2020-05-22 21:41:38.432711+00', 'Levenwick Two-Step', 9998, 'Tune (with missing composer) taken from: https://www.allcelticmusic.com/music/94397cce-f86e-102a-8020-000f1f67beb1/Note_n_Away.html ');
INSERT INTO 'tune' VALUES (14254, '2020-05-22 21:45:08.901069+00', '2020-05-22 21:45:54.500077+00', 'Hillside In Scotland', 9998, 'Tune (with missing composer) taken from: https://www.allcelticmusic.com/music/94397cce-f86e-102a-8020-000f1f67beb1/Note_n_Away.html ');
INSERT INTO 'tune' VALUES (14256, '2020-05-22 21:52:27.851059+00', '2020-05-22 21:53:00.886162+00', 'Nicol''s March', 9998, 'Tune (with missing composer) taken from: https://www.allcelticmusic.com/music/94397cce-f86e-102a-8020-000f1f67beb1/Note_n_Away.html ');
INSERT INTO 'tune' VALUES (14257, '2020-05-22 21:53:37.63445+00', '2020-05-22 21:53:37.63445+00', 'Uncle Allan''s March', 9998, 'Tune (with missing composer) taken from: https://www.allcelticmusic.com/music/94397cce-f86e-102a-8020-000f1f67beb1/Note_n_Away.html ');
INSERT INTO 'tune' VALUES (14258, '2020-05-22 21:55:06.161487+00', '2020-05-22 21:55:06.161487+00', 'Mrs Susan O''Sullivan', 9998, 'Tune (with missing composer) taken from: https://www.allcelticmusic.com/music/94397cce-f86e-102a-8020-000f1f67beb1/Note_n_Away.html ');
INSERT INTO 'tune' VALUES (14259, '2020-05-22 21:59:25.020747+00', '2020-05-22 21:59:25.020747+00', 'Mrs Susan O''Sullivan', 9998, 'Tune (with missing composer) taken from: https://www.allcelticmusic.com/music/94397cce-f86e-102a-8020-000f1f67beb1/Note_n_Away.html ');
INSERT INTO 'tune' VALUES (14260, '2020-05-22 22:00:17.022078+00', '2020-05-22 22:00:17.022078+00', 'Nicole', 9998, 'Tune (with missing composer) taken from: https://www.allcelticmusic.com/music/94397cce-f86e-102a-8020-000f1f67beb1/Note_n_Away.html ');
INSERT INTO 'tune' VALUES (14261, '2020-05-22 22:08:06.690115+00', '2020-05-22 22:08:06.690115+00', 'Fred Bremner', 9998, 'Tune (with missing composer) taken from: https://www.allcelticmusic.com/music/94397cce-f86e-102a-8020-000f1f67beb1/Note_n_Away.html ');
INSERT INTO 'tune' VALUES (1190, NULL, '2020-05-25 10:25:16.204985+00', 'Miss Hay of Yester', 9999, 'Possible duplicate of <<ddt:#1318>>?');
INSERT INTO 'tune' VALUES (1318, NULL, '2020-05-25 10:45:57.975636+00', 'Mrs Hay of Yester''s Reel', 9999, 'Possible duplicate of <<ddt:#1190>>?



Book 13 attributes this to Neil Gow 4th Book.');
INSERT INTO 'tune' VALUES (1421, NULL, '2020-05-25 10:47:32.939708+00', 'Oh! as I was kissed yestreen', 9999, 'Book 13 quotes the source as *Bremner, here from Gow*.');
INSERT INTO 'tune' VALUES (305, NULL, '2020-05-25 10:54:36.145408+00', 'Colonel Byng''s Favourite', 1517, 'Originally attributed in SCDDB to <<ddp:Gow, Niel>>, but book 13 and the ABC tune finder suggest <<ddp:Gow, Nathaniel>>.');
INSERT INTO 'tune' VALUES (10623, '2009-11-20 23:00:00+00', '2020-05-26 21:29:01.758914+00', 'Jimmy Allen''s Favourite', 1572, 'Possibly a misspelling of <<ddt:#2428>>?');
INSERT INTO 'tune' VALUES (1294, NULL, '2020-05-26 21:48:29.22798+00', 'Mrs B. Jolly', 1505, 'According to a strathspey message from Steve Wyrick:

*It''s in the Bon Accord Collection, page 38. [Bert Murray''s Bon Accord

Collection: Traditional and Contemporary Scottish Fiddle Music from North

East Scotland, copyright 1999 pub. by Taigh Na Teud Music Publishers]*');
INSERT INTO 'tune' VALUES (9720, NULL, '2020-05-27 11:31:38.951495+00', 'Jenny Younger', 1527, 'Possible duplicate of <<ddt:#4782>>?');
INSERT INTO 'tune' VALUES (10603, '2009-11-20 23:00:00+00', '2020-05-27 11:39:25.246261+00', 'John Sinclair - Younger of Ulbster', 2362, 'Possible duplicate of <<ddt:#8298>>?');
INSERT INTO 'tune' VALUES (14263, '2020-05-29 15:36:33.228544+00', '2020-05-29 15:36:33.228544+00', 'Miller''s Daughter, The', 9998, '');
INSERT INTO 'tune' VALUES (14265, '2020-05-29 16:01:14.771815+00', '2020-05-29 16:01:14.771815+00', 'James McNicoll', 9998, '');
INSERT INTO 'tune' VALUES (14266, '2020-05-29 16:02:16.915592+00', '2020-05-29 16:02:16.915592+00', 'King George IV''s Welcome', 9998, '');
INSERT INTO 'tune' VALUES (14268, '2020-05-29 16:07:40.678656+00', '2020-05-29 16:07:40.678656+00', 'Eagle on the Heather, The', 1764, '');
INSERT INTO 'tune' VALUES (14267, '2020-05-29 16:07:03.589198+00', '2020-05-29 16:07:56.696547+00', 'Tak Anither Dram', 1764, '');
INSERT INTO 'tune' VALUES (14269, '2020-05-29 16:18:50.905187+00', '2020-05-31 09:07:47.811731+00', 'Mormaer''s Reel, The', 1764, '');
INSERT INTO 'tune' VALUES (14270, '2020-05-29 16:24:14.703958+00', '2020-05-29 16:24:14.703958+00', 'Miss Stewart Fleming of Killiechassie', 9998, '');
INSERT INTO 'tune' VALUES (14271, '2020-05-30 09:56:36.07439+00', '2020-05-30 09:56:36.07439+00', 'Kirkland House', 1764, '');
INSERT INTO 'tune' VALUES (14272, '2020-05-30 09:57:00.688902+00', '2020-05-30 09:57:00.688902+00', 'Puddock''s Jig, The', 1764, '');
INSERT INTO 'tune' VALUES (14273, '2020-05-30 10:09:42.894214+00', '2020-05-30 10:09:42.894214+00', 'Andrew Potter''s Jig', 1764, '');
INSERT INTO 'tune' VALUES (14264, '2020-05-29 15:37:01.660394+00', '2020-05-31 09:06:45.189565+00', 'Lads o'' Elgin, The', 9998, '');
INSERT INTO 'tune' VALUES (11779, '2011-11-03 23:00:00+00', '2020-06-15 20:17:15.958736+00', 'Hughie Jim Paul''s Reel', 2416, '');
INSERT INTO 'tune' VALUES (14274, '2020-06-16 15:41:50.969449+00', '2020-06-16 15:41:50.969449+00', 'Ashley Weller''s Jig', 1631, 'Original tune for the dance <<ddd:Ashley and Her Husbands>>.');
INSERT INTO 'tune' VALUES (14275, '2020-06-16 18:15:42.776645+00', '2020-06-16 18:15:42.776645+00', 'Unlocked Reel', 11962, '');
INSERT INTO 'tune' VALUES (14276, '2020-06-17 15:04:24.15252+00', '2020-06-17 15:04:24.15252+00', 'Peter Dixon''s Reel', 1631, 'Written as the original tune for the dance “Bubbly and Cake”.  Peter is a familiar figure on the dance scene in the south of England and was celebrating his 80th birthday in 2018.');
INSERT INTO 'tune' VALUES (14277, '2020-07-04 15:12:40.926591+00', '2020-07-04 15:12:40.926591+00', 'Dancing Feet', 1042, '');
INSERT INTO 'tune' VALUES (14278, '2020-07-04 15:19:27.628598+00', '2020-07-04 15:19:27.628598+00', 'Sinclair''s Return, The', 1042, '');
INSERT INTO 'tune' VALUES (6956, NULL, '2020-10-29 16:51:07.854002+00', 'Bonny Tyneside', 11989, 'composed by Robert Chatt of Wark');
INSERT INTO 'tune' VALUES (14291, '2020-10-29 16:59:19.092236+00', '2020-10-29 16:59:19.092236+00', 'Diana''s hesitation waltz', 11990, '');
INSERT INTO 'tune' VALUES (6526, NULL, '2020-07-10 08:14:55.097544+00', 'Pipe Major Jimmy Pryde', 1548, 'In the database this was originally attributed to <<ddp:#1908>> but <<https://tunearch.org/wiki/Annotation:P.M._Jimmy_Pryde|this article>> gives the composer as <<ddp:#1548>>.');
INSERT INTO 'tune' VALUES (4104, NULL, '2020-07-10 08:22:09.943506+00', 'McNeils of Ugadale, The', 11964, '');
INSERT INTO 'tune' VALUES (14280, '2020-07-14 11:03:50.330937+00', '2020-07-14 11:03:50.330937+00', 'Kathy''s Fascinator', 1502, '');
INSERT INTO 'tune' VALUES (14281, '2020-07-14 11:04:21.016127+00', '2020-07-14 11:04:21.016127+00', 'Halifax Treasure, The', 1502, '');
INSERT INTO 'tune' VALUES (6596, NULL, '2020-10-29 17:16:42.373571+00', 'Bonnie Strathearn', 11990, 'Composed by Jacca R A Mclaren Hay, words by John Hall.



A recording can be found online at https://raretunes.org/jenna-and-jacca-hay-2/');
INSERT INTO 'tune' VALUES (14279, '2020-07-07 14:31:26.58173+00', '2020-07-31 15:43:21.173403+00', 'So Much Amazing Creativity', 11858, 'The title is an alternative expansion, suggested by Robb Quint, of the acronym SMAC used by the Graziani family in the production of a <<https://www.youtube.com/channel/UCyojdYqjbxETi1C5mFptXtg/videos|series of videos>> of two couple dances they made during the Covid lockdown. SMAC actually stands for their names: Samuele, Mattia, Alessia and Camilla.



There is a recording of this tune available via <<https://my.strathspey.org/u/murrough/recording/>>.');
INSERT INTO 'tune' VALUES (14282, '2020-07-31 16:09:54.972199+00', '2020-07-31 16:09:54.972199+00', 'Partie du lancier', 9999, 'Traditional Québec.');
INSERT INTO 'tune' VALUES (11377, '2010-10-13 22:00:00+00', '2020-07-31 16:28:51.386644+00', 'Lady Elizabeth Montague''s Favourite', 1519, 'This tune is not listed in the compilation of Mackintosh tunes at <<https://www.heallan.com/mackintosh_contents.html>>. Possibly the same as Lady Elisabeth Montague''s Jig??');
INSERT INTO 'tune' VALUES (14283, '2020-07-31 16:29:20.229033+00', '2020-07-31 16:29:20.229033+00', 'Lady Elisabeth Montague''s Jig', 1519, '');
INSERT INTO 'tune' VALUES (9171, NULL, '2020-07-31 16:44:45.339066+00', 'Hull''s', 3421, '');
INSERT INTO 'tune' VALUES (14284, '2020-07-31 16:51:30.349007+00', '2020-07-31 16:51:30.349007+00', 'Reel Eugène', 9999, '');
INSERT INTO 'tune' VALUES (2424, NULL, '2020-07-31 19:06:10.370683+00', 'Lady Hamilton Dalrymple''s Strathspey', 1519, 'Originally the database attributed this tune to "traditional" but the <<https://tunearch.org/wiki/Lady_Hamilton_Dalrymple|Traditional Tune Archive>> entry gives the composer as Robert Mackintosh. Along with many aliases for the name.');
INSERT INTO 'tune' VALUES (14286, '2020-08-12 09:34:12.399841+00', '2020-08-12 09:34:12.399841+00', 'No Hands!', 3179, '');
INSERT INTO 'tune' VALUES (14287, '2020-08-12 09:34:29.680486+00', '2020-08-12 09:34:29.680486+00', 'See-Saw', 3179, '');
INSERT INTO 'tune' VALUES (14288, '2020-08-25 09:36:00.123362+00', '2020-08-25 09:36:00.123362+00', 'Carola''s Tolt', 1502, '');
INSERT INTO 'tune' VALUES (14289, '2020-09-11 08:36:59.433485+00', '2020-09-11 08:36:59.433485+00', 'Leanabh an Aigh', 9999, 'Traditional melody also used as a <<https://en.wikipedia.org/wiki/Bunessan_(hymn_tune)|hymn tune>>.');
INSERT INTO 'tune' VALUES (3953, NULL, '2020-09-21 12:29:13.54814+00', 'Inveruglas Reel, The', 1830, 'For a wee bit of background information about the tune see <<https://my.strathspey.org/dd/dance/3115/| Inveruglas Water>>.');
INSERT INTO 'tune' VALUES (14290, '2020-09-29 01:21:23.139089+00', '2020-09-29 01:21:23.139089+00', '"Any Good Irish Reel" (author''s statement)', 10653, '');
INSERT INTO 'tune' VALUES (13573, '2017-04-30 09:30:32.982112+00', '2020-09-29 08:49:57.906934+00', 'Dancers'' Delight', 2168, '');
INSERT INTO 'tune' VALUES (4293, NULL, '2020-10-10 12:23:38.643796+00', 'Mr Hamilton of Wishaw''s Reel', 9998, 'The original reference in <<ddpub:#474>> was given as "Washaw" but this seems likely to be a spelling mistake. The original is kept as a spelling alias.

');
INSERT INTO 'tune' VALUES (13818, '2018-02-24 03:08:25.272414+00', '2020-10-29 17:34:20.226045+00', 'Brig Gen Ronald Cheape of Tiroran', 1635, 'composed by Pipe Major Willie Ross');
INSERT INTO 'tune' VALUES (9763, NULL, '2020-10-29 17:54:21.264891+00', 'Green Hills of Islay, The', 11991, 'composed by Duncan MacNiven');
INSERT INTO 'tune' VALUES (5119, NULL, '2020-10-29 17:57:19.040672+00', 'Dr & Mrs R Walker', 1555, '');
INSERT INTO 'tune' VALUES (7334, NULL, '2020-10-31 10:47:03.163764+00', 'March Hare, The', 11993, 'Composed for 1955 film of this name.');
INSERT INTO 'tune' VALUES (5243, NULL, '2020-10-31 10:55:30.12386+00', 'John MacKenzie''s Farewell to Strathglass', 1635, '');
INSERT INTO 'tune' VALUES (14337, '2020-11-10 17:29:16.055899+00', '2020-11-10 17:55:40.553385+00', 'Gin for Judith, A', 10973, 'From the publication about "A Gin for Judith":



Written for fiddler, Judith Smith, after she confused gin and jig!');
INSERT INTO 'tune' VALUES (14292, '2020-11-10 07:38:33.924561+00', '2020-11-10 08:51:22.314388+00', 'Wee Jig, A', 11998, 'From the publication: 

A Wee Jig, written in frustration to go into a dance set when I couldn’t find a suitable tune.



The tune is a Jig.');
INSERT INTO 'tune' VALUES (14368, '2020-11-10 21:10:45.116732+00', '2020-11-10 21:10:45.116732+00', 'Seonaid', 11998, 'From the publication about "Seonaid":



Written for my partner and co-author.');
INSERT INTO 'tune' VALUES (14296, '2020-11-10 07:47:42.347087+00', '2020-11-10 09:02:08.47615+00', 'Ben Nevis Ceilidh, The', 11998, 'From the publication about "The Ben Nevis Ceilidh":



I wrote this when we played for a Ceilidh at the Nevis Range on Anoach Mor in 2013. Re-discovered when clearing out some old sheet music.



The tune is a Reel.');
INSERT INTO 'tune' VALUES (14298, '2020-11-10 07:51:13.26868+00', '2020-11-10 09:02:45.195924+00', 'Bin There Done That', 11998, 'The tune is a Reel.');
INSERT INTO 'tune' VALUES (14295, '2020-11-10 07:44:28.209979+00', '2020-11-10 09:41:54.210797+00', 'Ballinluig Nights', 10973, 'From the publication about "Ballinluig Nights":



Mid Atholl Strings meet regularly in Ballinluig. This tune is a thank you for the music and good company (and home baking) they have so generously shared with us.



The tune is a Strathspey.');
INSERT INTO 'tune' VALUES (14300, '2020-11-10 07:57:44.761399+00', '2020-11-10 09:04:32.546502+00', 'Cabin Fever', 10973, 'From the publication about  "Cabin Fever":



Cabin Fever was written during Covid19 2020 lockdown.



The tune is a Jig.');
INSERT INTO 'tune' VALUES (14302, '2020-11-10 08:06:08.551407+00', '2020-11-10 09:06:16.563435+00', 'Gazing Through the Window', 11998, 'From the publication about "Gazing Through the Window":



Gazing Through the Window was written during Covid19 2020 lockdown.



The tune is a Strathspey.');
INSERT INTO 'tune' VALUES (14303, '2020-11-10 08:08:26.160333+00', '2020-11-10 09:08:49.931822+00', 'Goodbye Old Friend', 11998, 'From the publication about "Goodbye Old Friend":



Thne tune followed an emergency visit to the dentist during lockdown.



The tune is an Air.');
INSERT INTO 'tune' VALUES (14299, '2020-11-10 07:52:49.57504+00', '2020-11-10 09:33:05.365104+00', 'Bobban-Tilter', 11998, 'From the publication about "Bobban-Tilter":



Bobban-Tilter is an old Scots saying for any bouncing, dangling object.



The tune is a Reel.');
INSERT INTO 'tune' VALUES (14304, '2020-11-10 08:10:08.251429+00', '2020-11-10 09:42:53.295863+00', 'Jiggin'' About', 11998, 'The tune is a Jig.');
INSERT INTO 'tune' VALUES (14370, '2020-11-10 21:13:54.08538+00', '2020-11-10 21:13:54.08538+00', 'Springtime in the Vercors', 11998, '');
INSERT INTO 'tune' VALUES (14297, '2020-11-10 07:49:30.268359+00', '2020-11-10 13:56:30.567967+00', 'Bearded Stranger, The', 10973, 'Some information from the composers of the publication:



The bearded Stranger is Seonaid''s take on Roddy having grown a beard during lockdown.



The tune is a Reel.');
INSERT INTO 'tune' VALUES (14294, '2020-11-10 07:42:40.621044+00', '2020-11-10 08:59:39.772144+00', 'Bairnkine Winter', 10973, 'From the publication about "Bairnkine Winter":



Bairnkine is a hamlet south of Jedburgh where our artist and friend, Alan Turner, lives and works.



The tune is a Strathspey.');
INSERT INTO 'tune' VALUES (14306, '2020-11-10 08:17:31.35152+00', '2020-11-10 09:09:17.566354+00', 'L'' Accordeoniste', 11998, 'From the publication about "L’ Accordeoniste (Pour Jocelyne)" and "Nos Bon Amis (Pour Joce & Chris)":



Written for two good friends Joce and Christian who live on the outskirts of Grenoble. They have taken care of us for many years when we have attended the Meaudre Reel Scottish Country Dance weekend. Joceline plays the accordion and Christian is an exponent of the region’s traditional dance.



The tune is a Mazurka.');
INSERT INTO 'tune' VALUES (14307, '2020-11-10 08:20:10.209598+00', '2020-11-10 09:11:31.373212+00', 'Danse de Celie, La', 11998, 'From the publication about "La Danse de Celie" or "Celie''s Dance":



Celie is a young dancer and the daughter of Sophie the founder of Meaudre Reel.



The tune is a Reel.');
INSERT INTO 'tune' VALUES (14316, '2020-11-10 08:39:51.246473+00', '2020-11-10 09:12:04.277039+00', 'Wire Bridge, The', 11998, 'From the publication about "The Wire Bridge":



A cable suspension footbridge over the Tweed at Mertoun that we cross on another of our local walks.



The tune is a Reel.');
INSERT INTO 'tune' VALUES (14315, '2020-11-10 08:39:34.816442+00', '2020-11-10 09:28:54.042128+00', 'Up To Muirhouselaw', 10973, 'From the publication about "Up to Muirhouselaw":



One of Seonaid’s regular walks during Covid-19 lockdown in 2020.



The tune is a Strathspey.');
INSERT INTO 'tune' VALUES (14308, '2020-11-10 08:22:15.220313+00', '2020-11-10 09:18:54.590232+00', 'Littledean Tower', 11998, 'From the publication about "Littledean Tower":



While researching the area around our home we discovered the ruins of 15th century tower with a very dark history.



The tune is a Strathspey



See <<https://www.borderarchaeology.co.uk/home/sites/littledean-tower>> for more information and some pictures on the Littledean Tower.');
INSERT INTO 'tune' VALUES (14309, '2020-11-10 08:25:30.594293+00', '2020-11-10 09:22:36.483881+00', 'Logie''s Lullaby', 10973, 'From the publication about "Logie’s Lullaby": 



Logie is Theresa and Pete Clark’s Cocker Spaniel, and 13 weeks old when the tune was written.



The Tune is a slow air.');
INSERT INTO 'tune' VALUES (14310, '2020-11-10 08:25:54.594833+00', '2020-11-10 09:23:23.961378+00', 'Nos Bon Amis', 11998, 'From the publication about "Nos Bon Amis (Pour Joce & Chris)" and "L’ Accordeoniste (Pour Jocelyne)":



Written for two good friends Joce and Christian who live on the outskirts of Grenoble. They have taken care of us for many years when we have attended the Meaudre Reel Scottish Country Dance weekend. Joceline plays the accordion and Christian is an exponent of the region’s traditional dance.



This tune is a Rigadon.');
INSERT INTO 'tune' VALUES (14311, '2020-11-10 08:28:05.302835+00', '2020-11-10 09:26:38.864715+00', 'Over Carter Bar', 11998, 'From the publication about "Over Carter Bar":



Traveling home from the South we cross the Border on the A68 at Carter Bar. In good weather the views are spectacular and we can see our home in the far distance.



The tune is a Jig.');
INSERT INTO 'tune' VALUES (14305, '2020-11-10 08:11:21.077691+00', '2020-11-10 13:57:24.135489+00', 'Jigsaw, The', 10973, 'Some information from the composers of the publication:



The Jigsaw, a way many of us passed time in the early stages of lockdown.



The tune is a Jig.');
INSERT INTO 'tune' VALUES (14312, '2020-11-10 08:34:53.496784+00', '2020-11-10 09:27:09.974668+00', 'Sandra''s Tune', 10973, 'From the publication about "Sandra’s Tune":



Written for a fiddler friend from Aberfeldy who also makes excellent cakes.



The tune is a Jig.');
INSERT INTO 'tune' VALUES (14313, '2020-11-10 08:35:57.079598+00', '2020-11-10 09:27:22.670909+00', 'Those Soft Borders Hills', 11998, 'From the publication about "Those Soft Border Hills":



Celebrating the beautiful scenery of the Scottish Borders.



The tune is a Waltz.');
INSERT INTO 'tune' VALUES (14314, '2020-11-10 08:38:45.380313+00', '2020-11-10 09:28:22.862077+00', 'Touring the Meniscus', 10973, 'From the publication about "Touring" the Meniscus: 



A linguistic misunderstanding and a painful experience for a friend from Birmingham.



The tune is a Reel.');
INSERT INTO 'tune' VALUES (14317, '2020-11-10 16:54:59.432037+00', '2020-11-10 16:54:59.432037+00', 'Absent Friends', 10973, '');
INSERT INTO 'tune' VALUES (14320, '2020-11-10 16:58:00.294689+00', '2020-11-10 16:58:00.294689+00', 'Black Diamond Reel', 10973, '');
INSERT INTO 'tune' VALUES (14335, '2020-11-10 17:22:52.797583+00', '2020-11-10 18:05:53.938338+00', 'Gentian Blue', 11998, 'From the publication about "Gentian Blue":



Composed after one of our annual trips to play for the Meaudre Reel group in the Vercors. Gentians grow wild in the mountains.');
INSERT INTO 'tune' VALUES (14330, '2020-11-10 17:12:50.316264+00', '2020-11-10 17:54:52.746167+00', 'Duncansburgh Jig, The', 11998, 'From the publication about "The Duncansburgh Jig" and "The Duncansburgh Rant":



Both tunes were written for the RSCDS dance classes in Fort William.');
INSERT INTO 'tune' VALUES (14332, '2020-11-10 17:17:01.995131+00', '2020-11-10 17:17:01.995131+00', 'Eileen and Ian''s Golden Wedding Waltz', 10973, '');
INSERT INTO 'tune' VALUES (14340, '2020-11-10 17:32:48.525571+00', '2020-11-10 17:32:48.525571+00', 'Highland Welcome', 10973, '');
INSERT INTO 'tune' VALUES (14345, '2020-11-10 17:41:46.747465+00', '2020-11-10 17:41:46.747465+00', 'Just a Bit of Fun', 10973, '');
INSERT INTO 'tune' VALUES (14331, '2020-11-10 17:14:47.381255+00', '2020-11-10 17:54:11.390267+00', 'Duncansburgh Rant, The', 11998, 'From the publication about "The Duncansburgh Rant" and "The Duncansburgh Jig":



Both tunes were written for the RSCDS dance classes in Fort William.');
INSERT INTO 'tune' VALUES (14319, '2020-11-10 16:56:51.311053+00', '2020-11-10 17:56:50.227779+00', 'Betty''s Garden', 10973, 'From the publication about "Betty''s Garden":



Betty Winslow has been a friend since we taught together and played piano duets in Hawick. She enjoys her garden which is always full of colour.');
INSERT INTO 'tune' VALUES (14400, '2021-02-18 04:57:46.679989+00', '2021-02-18 04:57:46.679989+00', 'Veteran''s Return, The', 1836, '');
INSERT INTO 'tune' VALUES (14401, '2021-02-18 04:59:17.105773+00', '2021-02-18 04:59:17.105773+00', 'Appin Place', 1836, '');
INSERT INTO 'tune' VALUES (14323, '2020-11-10 17:00:32.947934+00', '2020-11-10 17:58:22.611098+00', 'Castle and Kirk', 10973, 'From the publication about "Castle and Kirk":



From a certain spot in Holyrood Park you get a perfect view of Duddingston Kirk with Craigmillar Castle in the background.');
INSERT INTO 'tune' VALUES (14328, '2020-11-10 17:09:58.40773+00', '2020-11-10 18:01:28.339343+00', 'Diana''s Summer Stravaig', 10973, 'From the publication about "Diana''s Summer Stravaig":



Diana Sarran, our good friend from Lyon, likes to spend her summers in Scotland.');
INSERT INTO 'tune' VALUES (14329, '2020-11-10 17:11:05.87907+00', '2020-11-10 18:02:02.040243+00', 'Dr George Winslow of Monikie', 10973, 'From the publication about "Dr George Winslow of Monikie":



George is married to Betty (of Betty’s Garden). They’re good friends and great company.');
INSERT INTO 'tune' VALUES (14339, '2020-11-10 17:32:00.828584+00', '2020-11-10 18:10:49.175691+00', 'Guillemot, The', 10973, 'From the publication about "The Guillemot":



I spotted this particular Guillemot sheltering in North Berwick Harbour after a very wild winter storm.');
INSERT INTO 'tune' VALUES (14344, '2020-11-10 17:40:57.203699+00', '2020-11-10 18:12:17.024059+00', 'Jane''s Flying Cello', 11998, 'From the publication about "Jane''s Flying Cello":



For our friend Jane, a cellist, who frequently flies from the USA to attend the RSCDS Summer School Musicians Course.');
INSERT INTO 'tune' VALUES (14347, '2020-11-10 17:44:27.145522+00', '2020-11-10 18:14:21.616614+00', 'Leaving Birnam', 10973, 'From the publication about "Leaving Birnam":



I started writing this tune while waiting on the platform at Birnam/Dunkeld station and continued it on the train to Edinburgh.');
INSERT INTO 'tune' VALUES (14350, '2020-11-10 17:47:45.955548+00', '2020-11-10 18:16:14.269701+00', 'Trois Pucelles, Les', 11998, 'From the publication about "Les Trois Pucelles" or "The Three Maidens":



An unusual triple peak in the Vercors above Grenoble.');
INSERT INTO 'tune' VALUES (14369, '2020-11-10 21:12:09.781438+00', '2020-11-10 21:12:09.781438+00', 'Seonaid''s Red Shoes', 11998, '');
INSERT INTO 'tune' VALUES (14430, '2021-02-19 16:30:01.176033+00', '2021-02-19 16:30:01.176033+00', 'Sord Colmeille', 9999, '');
INSERT INTO 'tune' VALUES (14431, '2021-02-19 16:48:59.694166+00', '2021-02-19 16:48:59.694166+00', 'Scotland''s Flag', 1534, '');
INSERT INTO 'tune' VALUES (14432, '2021-02-20 13:13:32.19818+00', '2021-02-20 13:13:32.19818+00', 'Zsófi''s Saxophone', 10118, '');
INSERT INTO 'tune' VALUES (14433, '2021-02-27 10:15:26.200586+00', '2021-02-27 10:15:26.200586+00', 'Emily''s Wedding', 2197, '');
INSERT INTO 'tune' VALUES (14434, '2021-03-01 21:13:07.108002+00', '2021-03-01 21:13:07.108002+00', 'Alastair and Carol Cuthbertson', 2197, '');
INSERT INTO 'tune' VALUES (14472, '2021-08-19 12:47:08.669605+00', '2021-08-19 12:47:08.669605+00', 'Stagger Inn Reel, The', 10664, '');
INSERT INTO 'tune' VALUES (14473, '2021-08-19 20:02:39.170575+00', '2021-08-19 20:02:39.170575+00', 'Lucy''s Round', 3220, '');
INSERT INTO 'tune' VALUES (14474, '2021-08-19 20:05:28.005364+00', '2021-08-19 20:05:28.005364+00', 'Chief Garry, Our Bar Manager', 12055, '');
INSERT INTO 'tune' VALUES (14475, '2021-08-19 20:13:42.395308+00', '2021-08-19 20:13:42.395308+00', 'First and Last, The', 12056, '');
INSERT INTO 'tune' VALUES (14476, '2021-08-19 22:24:46.658184+00', '2021-08-19 22:24:46.658184+00', 'Derek''s Birthday Surprise', 11858, '');
INSERT INTO 'tune' VALUES (14318, '2020-11-10 16:55:56.043211+00', '2020-11-10 17:56:19.581985+00', 'Asleep Aside the Tay', 11998, 'From the publication about "Asleep Aside the Tay":



This tune was written following the funeral of a good friend and wonderful fiddler, Gordon Simpson, who is buried at Tayport overlooking the River Tay.');
INSERT INTO 'tune' VALUES (14321, '2020-11-10 16:59:11.174839+00', '2020-11-10 17:57:14.647477+00', 'Bonnie Lassies of St Andrews, The', 11998, 'From the publication about "The Bonnie Lassies of St Andrews":



For the ladies on the Summer School Musicians Course 2009.');
INSERT INTO 'tune' VALUES (14322, '2020-11-10 16:59:51.541203+00', '2020-11-10 17:57:58.047145+00', 'Camusdarach', 10973, 'From the publication about "Camusdarach":



A reminder of a day spent on one of the most beautiful beaches on the West Coast of Scotland.');
INSERT INTO 'tune' VALUES (14324, '2020-11-10 17:05:29.731636+00', '2020-11-10 17:58:51.710526+00', 'Collecting the Toll', 11998, 'From the publication about "Collecting the Toll":



My work desk sits at the toll collector’s window at our home in the Scottish Borders, an old toll house.');
INSERT INTO 'tune' VALUES (14325, '2020-11-10 17:06:16.239948+00', '2020-11-10 17:59:21.9037+00', 'Creaking Gait', 11998, 'From the publication about "Creaking Gait":



The name we gave to our group of 5 friends who met on the Summer School Musicians Course at St. Andrews.');
INSERT INTO 'tune' VALUES (14326, '2020-11-10 17:07:43.028094+00', '2020-11-10 18:00:18.635339+00', 'Dancer and the Artist, The', 11998, 'From the publication about "The Dancer and the Artist":



Written for friends Anne and Alistair Smyth. Anne is a well known and accomplished dance teacher for the RSCDS. She encouraged me to play for her dance classes in Fort William. Alistair is a great artist whose SCD cartoons are legendary.');
INSERT INTO 'tune' VALUES (14327, '2020-11-10 17:09:02.064523+00', '2020-11-10 18:01:00.407839+00', 'Dennis & Morin Orr''s Trip to Scotland', 11998, 'From the publication about "Dennis & Morin Orr''s Trip to Scotland":



Dennis and Morin Orr, from Canada, stayed with me while on route to the RSCDS Summer School in St Andrews in 2012.');
INSERT INTO 'tune' VALUES (13001, '2014-10-01 23:47:59.829389+00', '2020-11-10 18:04:10.930959+00', 'Eric''s Reel', 10973, 'From the publication about "Eric''s Reel":



Original tune written for the dance of the same name by Ian Brockbank. Ian devised the dance for his beginners SCD class which met in the Eric Liddell Centre in Edinburgh.');
INSERT INTO 'tune' VALUES (14333, '2020-11-10 17:18:29.78061+00', '2020-11-10 18:04:40.715938+00', 'Fields of Bow, The', 10973, 'From the publication about "The Fields of Bow":



This tune was composed for a dance devised by Lyn Bryce (Melrose) for Melv Stirling on the occasion of a special birthday. Melv and his wife are long time members of the RSCDS Melrose branch. They live at Bow Farm in the Borders.');
INSERT INTO 'tune' VALUES (14334, '2020-11-10 17:20:05.521245+00', '2020-11-10 18:05:15.181936+00', 'Fit Doon, Di', 10973, 'From the publication about "Fit Doon, Di":



The instruction given to fiddler, Di Jevons, as she drove us back to Birnam after an evening playing with the Mid Atholl Strings in Ballinluig Village Hall.');
INSERT INTO 'tune' VALUES (14338, '2020-11-10 17:31:17.670927+00', '2020-11-10 18:07:02.164465+00', 'Gordon''s Shoulders', 10973, 'From the publication about "Gordon''s Shoulders":



Fiddler and friend, Gordon Simpson, used his shoulders to great effect when encouraging musicians on the Musicians Course at Summer School to get lift into the music.');
INSERT INTO 'tune' VALUES (14341, '2020-11-10 17:38:16.590765+00', '2020-11-10 18:11:15.59999+00', 'In Eclipse', 10973, 'From the publication about "In Eclipse":



I thought I’d discovered a new species of duck until I realised the mallards were moulting their flight feathers.');
INSERT INTO 'tune' VALUES (14342, '2020-11-10 17:39:17.366446+00', '2020-11-10 18:11:41.258933+00', 'Jan MacLean''s Farewell to Inveresk', 10973, 'From the publication about "Jan MacLean''s Farewell to Inveresk":



Written for good friend and box player when she moved, reluctantly, from Scotland down to Kent.');
INSERT INTO 'tune' VALUES (14343, '2020-11-10 17:40:04.043324+00', '2020-11-10 18:13:21.544884+00', 'Janet''s Waltz', 11998, 'From the publication about "Janet''s Waltz":



A simple tune written for the wife of a fiddler friend who had returned to playing the piano.');
INSERT INTO 'tune' VALUES (14346, '2020-11-10 17:43:42.769507+00', '2020-11-10 18:13:59.737242+00', 'Last Sausage Roll, The', 10973, 'From the publication about "The Last Sausage Roll":



Written for fiddler, Dave Hale, who thought he’d eaten it!');
INSERT INTO 'tune' VALUES (14348, '2020-11-10 17:45:25.882615+00', '2020-11-10 18:14:47.05677+00', 'Lemming Ridge (''D'')', 10973, 'From the publication about "Lemming Ridge (''D'')":



Written after playing for a ceilidh at the Nevis Range and named after one of the ski runs.');
INSERT INTO 'tune' VALUES (14349, '2020-11-10 17:46:00.790349+00', '2020-11-10 18:15:29.906585+00', 'Lemming Ridge (Dm)', 10973, 'From the publication about "Lemming Ridge (Dm)":



I tried Lemming Ridge in a minor key when looking for a tune to make up a set for the dance Widdershins.');
INSERT INTO 'tune' VALUES (14351, '2020-11-10 20:31:58.769317+00', '2020-11-10 20:33:43.46255+00', 'Margo''s Welcome to Edinburgh', 11998, 'From the publication about "Margo''s Welcome to Edinburgh":



Margo Priestley, dance teacher and former director of Summer School, gave us the biggest welcome you could imagine when we arrived at an Edinburgh Branch dance.');
INSERT INTO 'tune' VALUES (14352, '2020-11-10 20:36:25.165946+00', '2020-11-10 20:36:25.165946+00', 'McLymonts of Scotstoun, The', 10973, '');
INSERT INTO 'tune' VALUES (14353, '2020-11-10 20:38:09.257077+00', '2020-11-10 20:38:09.257077+00', 'Memories of Lochaber', 11998, 'From the publication about "Memories of Lochaber":



Inspired by my last walk along the west coast of Lochaber at Arisaig before moving to the Borders.');
INSERT INTO 'tune' VALUES (13620, '2017-07-16 11:53:51.456984+00', '2020-11-10 20:40:50.925831+00', 'Miss Gibson of Maybole', 10973, 'From the publication about "Miss Gibson of Maybole":



Written for my Niece on her 16th birthday. The tune was selected as the original for the dance “Fair Enough” in RSCDS Book 51.');
INSERT INTO 'tune' VALUES (14354, '2020-11-10 20:46:59.909727+00', '2020-11-10 20:46:59.909727+00', 'Missing Gordon', 10973, '');
INSERT INTO 'tune' VALUES (14355, '2020-11-10 20:49:00.549619+00', '2020-11-10 20:49:00.549619+00', 'Neptune''s Staircase', 11998, 'From the publication about "Neptune''s Staircase":



My home, when I lived in Fort William, was located beside the Caledonian Canal, at Neptune’s Staircase.');
INSERT INTO 'tune' VALUES (14356, '2020-11-10 20:50:17.834407+00', '2020-11-10 20:50:17.834407+00', 'On the Cusp', 10973, '');
INSERT INTO 'tune' VALUES (14357, '2020-11-10 20:52:11.593928+00', '2020-11-10 20:52:11.593928+00', 'On the Tiles', 10973, 'From the publication about "On the Tiles":



Written at the turn of the year, 2013 into ’14. As well as being the festive season, Roddy was doing emergency repairs on his roof in very windy weather.');
INSERT INTO 'tune' VALUES (14358, '2020-11-10 20:53:40.627344+00', '2020-11-10 20:53:40.627344+00', 'Pairt Time Fairmer', 11998, 'From the publication about "Pairt Time Fairmer":



Written for a fiddler friend who spends a lot of time helping a family member manage a farm in Aberdeenshire.');
INSERT INTO 'tune' VALUES (14359, '2020-11-10 20:55:43.424785+00', '2020-11-10 20:55:43.424785+00', 'Peniel Heugh', 11998, 'From the publication about "Peniel Heugh":



A hill in the Scottish Borders area of Scotland close to our home. On it stands the Waterloo Monument. It also ls one of the finest viewpoints in the Borders.');
INSERT INTO 'tune' VALUES (14360, '2020-11-10 20:57:52.335996+00', '2020-11-10 20:57:52.335996+00', 'Peppermint Tea', 11998, 'From the publication about "Peppermint Tea":



Written for a good friend who always requested a cup of peppermint tea at Summer School.');
INSERT INTO 'tune' VALUES (14361, '2020-11-10 20:59:41.350702+00', '2020-11-10 20:59:41.350702+00', 'Pilgrims'' Way', 10973, 'From the publication about "Pilgrims'' Way":



The St Cuthbert’s Way passes close by our Border home and links Melrose with Holy Island off the Northumberland coast. A route long travelled by pilgrims.');
INSERT INTO 'tune' VALUES (14362, '2020-11-10 21:01:02.734652+00', '2020-11-10 21:01:02.734652+00', 'Roddy''s Jig', 10973, '');
INSERT INTO 'tune' VALUES (14363, '2020-11-10 21:03:04.220184+00', '2020-11-10 21:03:04.220184+00', 'Rose Window, The', 10973, 'From the publication about "The Rose Window":



The tune relates to the Rose Window at Melrose Abbey.');
INSERT INTO 'tune' VALUES (14364, '2020-11-10 21:04:12.381841+00', '2020-11-10 21:04:12.381841+00', 'Salute to Sassenage', 10973, '');
INSERT INTO 'tune' VALUES (14365, '2020-11-10 21:07:08.509931+00', '2020-11-10 21:07:08.509931+00', 'Samson''s Ribs', 10973, 'From the publication about "Samson''s Ribs":



A striking geological feature in Edinburgh’s Holyrood Park.');
INSERT INTO 'tune' VALUES (14366, '2020-11-10 21:08:38.390838+00', '2020-11-10 21:08:38.390838+00', 'Sandra Armstrong of Snizort', 10973, '');
INSERT INTO 'tune' VALUES (14367, '2020-11-10 21:09:26.510557+00', '2020-11-10 21:09:26.510557+00', 'September Mist', 10973, '');
INSERT INTO 'tune' VALUES (14371, '2020-11-10 21:15:32.269971+00', '2020-11-10 21:15:32.269971+00', 'Sutherland''s Jig', 10973, 'From the publication about "Sutherland''s Jig":



Bruce and Marion run ‘Sutherland’s Hair and Beauty’ in Newport on Tay. Well worth the journey for a hair cut!');
INSERT INTO 'tune' VALUES (14372, '2020-11-10 21:16:48.379369+00', '2020-11-10 21:16:48.379369+00', 'Swirling Eddies', 10973, 'From the publication about "Swirling Eddies":



Inspired by the turbulent waters flowing through the locks of the Caledonian Canal.');
INSERT INTO 'tune' VALUES (14373, '2020-11-10 21:18:13.728146+00', '2020-11-10 21:18:13.728146+00', 'Sylvia''s Jig', 10973, 'From the publication about "Sylvia''s Jig":



For a lifelong friend and one-time singing partner.');
INSERT INTO 'tune' VALUES (14374, '2020-11-10 21:20:13.494436+00', '2020-11-10 21:20:13.494436+00', 'Ten Bob Note, The', 10973, 'From the publication about "The Ten Bob Note":



Written after a fruitless search for a tune to complete the set for ‘The Cupar’s Wife’.');
INSERT INTO 'tune' VALUES (14375, '2020-11-10 21:22:36.113736+00', '2020-11-10 21:22:36.113736+00', 'Toll House Reel, The', 10973, '');
INSERT INTO 'tune' VALUES (14376, '2020-11-10 21:24:30.793049+00', '2020-11-10 21:24:30.793049+00', 'Tree Creeper, The', 11998, 'From the publication about "The Tree Creeper":



A frequent visitor to my Fort William garden.');
INSERT INTO 'tune' VALUES (14377, '2020-11-10 21:26:19.990868+00', '2020-11-10 21:26:19.990868+00', 'Trip to Auchencairn, A', 10973, '');
INSERT INTO 'tune' VALUES (14378, '2020-11-10 21:26:57.506104+00', '2020-11-10 21:50:29.108333+00', 'True Gentleman, A', 10973, 'From the publication about "A True Gentleman":



Written after attending the funeral of Gordon Simpson.');
INSERT INTO 'tune' VALUES (14380, '2020-11-10 22:36:54.962415+00', '2020-11-10 22:37:50.953822+00', 'Waltz for Elisabeth', 10973, 'From the publication about "Waltz for Elisabeth":



For Elisabeth Arnoux an amazing SCD teacher and repository of RSCDS knowledge. She and her husband Jacques are good friends and live near Grenoble.');
INSERT INTO 'tune' VALUES (14403, '2021-02-18 05:00:59.238934+00', '2021-02-18 05:00:59.238934+00', 'Chipmunk, The', 1836, '');
INSERT INTO 'tune' VALUES (14381, '2020-11-10 22:38:38.880175+00', '2020-11-10 22:40:16.760112+00', 'Waltz for Jan', 11998, 'From the publication about "Waltz for Jan":



Written for friend and accordionist Jan MacLean.');
INSERT INTO 'tune' VALUES (14382, '2020-11-10 22:41:36.681721+00', '2020-11-10 22:41:36.681721+00', 'Wet Wednesday', 10973, '');
INSERT INTO 'tune' VALUES (12955, '2014-07-11 12:57:26.1586+00', '2020-11-10 22:43:26.858245+00', 'Winds of Change', 10973, 'From the publication about "Winds of Change":



A reflection on the unexpected turns that life takes.');
INSERT INTO 'tune' VALUES (14293, '2020-11-10 07:40:58.54754+00', '2020-11-11 09:37:30.319189+00', 'Alison Baxter''s Jig', 10973, 'From the publication about "Alison Baxter’s Jig":



Alison is a music teacher, pianist and choral director friend from Dunfermline.



The tune is a Jig.



Please note, an early version of the booklet by mistake mentioned "Alison Baxter’s Tune" in the tune information list. This will be corrected in future version.');
INSERT INTO 'tune' VALUES (14301, '2020-11-10 08:05:00.064407+00', '2020-11-11 09:38:36.853242+00', 'David''s Fingers', 10973, 'From the publication about "David’s Fingers (Open the B.... Door)":



On route to play for a dance in Leicester, fiddler and friend, David trapped his fingers in the car door just as we were about to drive to the gig. Luckily the door flexed enough to prevent injury but David’s language was rather colourful! The tune is meant to reflect the occasion.



The tune is a Jig.');
INSERT INTO 'tune' VALUES (14336, '2020-11-10 17:28:14.2207+00', '2020-11-11 11:24:17.164482+00', 'George and Jane''s Trip to the Fort', 11998, 'From the publication about "George and Jane''s Trip to The Fort":



Written for George and Jane Meikle after one of George’s regular visits to play for the RSCDS Class in Fort William.



Please note, the table of contents and additional information in the book "Wind of Change" mistakenly state "George and Jane''s Visit to the Fort" - clarified by the composer.');
INSERT INTO 'tune' VALUES (14379, '2020-11-10 22:34:09.297428+00', '2020-11-11 11:26:35.60994+00', 'Walking on the Sands', 11998, 'From the publication about "Walking on the Sands":



An annual ritual of walking along the North Beach at St Andrews on the final Saturday of Summer School.



Please note, the table of contents and additional information in the book "Wind of Change" mistakenly state "Walking Across the Sands" - clarified by the composer.');
INSERT INTO 'tune' VALUES (14383, '2020-11-14 14:39:35.760786+00', '2020-11-14 14:39:35.760786+00', 'We''ll Meet Again', 12003, '');
INSERT INTO 'tune' VALUES (14384, '2020-12-07 23:07:17.027826+00', '2020-12-07 23:07:17.027826+00', 'Ruth Jappy', 709, '');
INSERT INTO 'tune' VALUES (14385, '2020-12-07 23:14:52.536513+00', '2020-12-07 23:14:52.536513+00', 'Gordon Hamilton', 709, '');
INSERT INTO 'tune' VALUES (14386, '2020-12-07 23:32:38.431166+00', '2020-12-07 23:32:38.431166+00', 'Delta Borderers, The', 709, '');
INSERT INTO 'tune' VALUES (9341, NULL, '2021-01-05 19:27:50.875515+00', 'Braid Burn, The', 10073, 'Composer given as "Andrew Knight" in the instructions for <<ddd:February Gold#16106>>.');
INSERT INTO 'tune' VALUES (10004, NULL, '2021-01-25 16:14:34.605383+00', 'Winter Morning', 3744, 'Information supplied by Danielle Reinstein: the tune is indeed called “Winter Morning”, taken from the 2nd movement of Winter from The Four Seasons by Vivaldi and adapted by Martin Cairns.');
INSERT INTO 'tune' VALUES (14387, '2021-02-01 16:59:13.1492+00', '2021-02-01 16:59:13.1492+00', 'Salute to Cap''n Jim', 1502, '');
INSERT INTO 'tune' VALUES (14388, '2021-02-16 19:33:54.824491+00', '2021-02-16 19:33:54.824491+00', 'Cluny Rock', 1790, '');
INSERT INTO 'tune' VALUES (14389, '2021-02-18 04:41:17.362621+00', '2021-02-18 04:41:17.362621+00', 'Accidental Reel, The', 1836, '');
INSERT INTO 'tune' VALUES (14390, '2021-02-18 04:42:45.479377+00', '2021-02-18 04:42:45.479377+00', 'Ballinluig', 1836, '');
INSERT INTO 'tune' VALUES (14391, '2021-02-18 04:43:36.300377+00', '2021-02-18 04:43:36.300377+00', 'Black Label, The', 1836, '');
INSERT INTO 'tune' VALUES (14392, '2021-02-18 04:44:57.36578+00', '2021-02-18 04:44:57.36578+00', 'Candidates Hornpipe, The', 1836, '');
INSERT INTO 'tune' VALUES (14393, '2021-02-18 04:45:57.481016+00', '2021-02-18 04:45:57.481016+00', 'Golf Bag, The', 1836, '');
INSERT INTO 'tune' VALUES (14394, '2021-02-18 04:47:21.200561+00', '2021-02-18 04:47:21.200561+00', 'Hot Buttered Toast', 1836, '');
INSERT INTO 'tune' VALUES (8182, NULL, '2021-02-18 04:48:25.967415+00', 'Irish Commodore, The', 1836, '');
INSERT INTO 'tune' VALUES (14395, '2021-02-18 04:49:37.412586+00', '2021-02-18 04:49:37.412586+00', 'Pedal Aroma', 1836, '');
INSERT INTO 'tune' VALUES (14396, '2021-02-18 04:50:14.747482+00', '2021-02-18 04:50:14.747482+00', 'Pitcairnie Hornpipe', 1836, '');
INSERT INTO 'tune' VALUES (14397, '2021-02-18 04:51:28.211738+00', '2021-02-18 04:51:28.211738+00', 'Reel George, The', 1836, '');
INSERT INTO 'tune' VALUES (14398, '2021-02-18 04:52:18.749481+00', '2021-02-18 04:52:18.749481+00', 'Sarasota Honrpipe, The', 1836, '');
INSERT INTO 'tune' VALUES (14399, '2021-02-18 04:52:58.668644+00', '2021-02-18 04:52:58.668644+00', 'See-Saw, The', 1836, '');
INSERT INTO 'tune' VALUES (14402, '2021-02-18 04:59:52.961417+00', '2021-02-18 04:59:52.961417+00', 'Badger''s Set, The', 1836, '');
INSERT INTO 'tune' VALUES (14404, '2021-02-18 05:01:35.778379+00', '2021-02-18 05:01:35.778379+00', 'Chrissy''s Jig', 1836, '');
INSERT INTO 'tune' VALUES (14405, '2021-02-18 05:03:51.574636+00', '2021-02-18 05:03:51.574636+00', 'Piper''s Jig, The', 1836, '');
INSERT INTO 'tune' VALUES (14406, '2021-02-18 05:04:45.812924+00', '2021-02-18 05:04:49.544061+00', 'Polly ''n Dale, Adieu', 1836, '');
INSERT INTO 'tune' VALUES (14407, '2021-02-18 05:05:26.822665+00', '2021-02-18 05:05:26.822665+00', 'Rene Martell', 1836, '');
INSERT INTO 'tune' VALUES (14408, '2021-02-18 05:06:21.92294+00', '2021-02-18 05:06:21.92294+00', 'Smiddy, The', 1836, '');
INSERT INTO 'tune' VALUES (14409, '2021-02-18 05:07:44.070811+00', '2021-02-18 05:07:44.070811+00', 'Twinkle Toes', 1836, '');
INSERT INTO 'tune' VALUES (14410, '2021-02-18 05:09:06.432292+00', '2021-02-18 05:09:06.432292+00', 'Bonnie Jean MacDonald', 1836, '');
INSERT INTO 'tune' VALUES (14411, '2021-02-18 05:10:11.897505+00', '2021-02-18 05:10:11.897505+00', 'Christine', 1836, '');
INSERT INTO 'tune' VALUES (14412, '2021-02-18 05:11:24.525746+00', '2021-02-18 05:11:24.525746+00', 'Clydesdale Brasses', 1836, '');
INSERT INTO 'tune' VALUES (14413, '2021-02-18 05:12:31.660105+00', '2021-02-18 05:12:31.660105+00', 'Driftwood', 1836, '');
INSERT INTO 'tune' VALUES (14414, '2021-02-18 05:13:51.680568+00', '2021-02-18 05:13:51.680568+00', 'Duntaylor', 1836, '');
INSERT INTO 'tune' VALUES (14415, '2021-02-18 05:15:33.332584+00', '2021-02-18 05:15:33.332584+00', 'Camino, El', 1836, '');
INSERT INTO 'tune' VALUES (14416, '2021-02-18 05:17:35.895235+00', '2021-02-18 05:17:35.895235+00', 'Elizabeth and Alan Ghent', 1836, '');
INSERT INTO 'tune' VALUES (14417, '2021-02-18 05:19:07.865022+00', '2021-02-18 05:19:07.865022+00', 'Glasgow Botanic Gardens', 1836, '');
INSERT INTO 'tune' VALUES (14418, '2021-02-18 05:19:56.871332+00', '2021-02-18 05:19:56.871332+00', 'Glasgow in Bloom', 1836, '');
INSERT INTO 'tune' VALUES (14419, '2021-02-18 05:20:27.930289+00', '2021-02-18 05:20:27.930289+00', 'Manderley', 1836, '');
INSERT INTO 'tune' VALUES (14420, '2021-02-18 05:21:00.846714+00', '2021-02-18 05:21:00.846714+00', 'Reflections', 1836, '');
INSERT INTO 'tune' VALUES (14421, '2021-02-18 05:21:58.398972+00', '2021-02-18 05:21:58.398972+00', 'Robin on the Lawn, A', 1836, '');
INSERT INTO 'tune' VALUES (14422, '2021-02-18 05:24:32.689729+00', '2021-02-18 05:24:32.689729+00', 'St Thomas Strathspey', 1836, '');
INSERT INTO 'tune' VALUES (14423, '2021-02-18 05:25:11.230989+00', '2021-02-18 05:25:11.230989+00', 'Sun and Shade', 1836, '');
INSERT INTO 'tune' VALUES (14424, '2021-02-18 05:26:01.580976+00', '2021-02-18 05:26:01.580976+00', 'Sunday Strathspey', 1836, '');
INSERT INTO 'tune' VALUES (14425, '2021-02-18 05:26:38.094206+00', '2021-02-18 05:26:38.094206+00', 'Syd Fender', 1836, '');
INSERT INTO 'tune' VALUES (14426, '2021-02-18 05:27:19.647614+00', '2021-02-18 05:27:19.647614+00', 'Taymouth Castle', 1836, '');
INSERT INTO 'tune' VALUES (14427, '2021-02-18 05:27:57.812891+00', '2021-02-18 05:27:57.812891+00', 'Tummel Garry Scheme, The', 1836, '');
INSERT INTO 'tune' VALUES (14428, '2021-02-18 05:28:40.849042+00', '2021-02-18 05:28:40.849042+00', 'Wednesday''s Child', 1836, '');
INSERT INTO 'tune' VALUES (14429, '2021-02-19 14:40:07.748879+00', '2021-02-19 14:40:07.748879+00', 'Susana Page''s Strathspey', 1590, '');
INSERT INTO 'tune' VALUES (7203, NULL, '2021-03-08 21:50:39.876405+00', 'Bill Armstrong', 1593, 'SCDDB originally had the composer as unknown. The instructions for Frae Near and Far by Evelyn Ramwell attribute it to Donald Ridley.');
INSERT INTO 'tune' VALUES (14435, '2021-03-10 23:51:01.396526+00', '2021-03-10 23:51:01.396526+00', 'Colin and Carol Johnston', 2197, '');
INSERT INTO 'tune' VALUES (14436, '2021-03-13 09:40:40.897798+00', '2021-03-13 09:40:40.897798+00', 'Mayumi''s Strathspey', 3683, 'Written for Peter Marshall''s dance City of Wisteria.');
INSERT INTO 'tune' VALUES (14437, '2021-03-13 20:08:10.731133+00', '2021-03-13 20:08:10.731133+00', 'Liz''s Delight', 12026, '');
INSERT INTO 'tune' VALUES (14438, '2021-03-13 20:15:01.708343+00', '2021-03-13 20:15:01.708343+00', '90 Years On', 645, '');
INSERT INTO 'tune' VALUES (14439, '2021-03-13 20:18:58.129966+00', '2021-03-13 20:18:58.129966+00', 'John Philip''s Jig', 2848, '');
INSERT INTO 'tune' VALUES (14440, '2021-03-13 20:29:41.168567+00', '2021-03-13 20:29:41.168567+00', 'Carnegie''s Legacy', 1836, '');
INSERT INTO 'tune' VALUES (14441, '2021-03-13 20:33:44.41245+00', '2021-03-13 20:33:44.41245+00', 'Miss Ella Macleod', 12027, '');
INSERT INTO 'tune' VALUES (14442, '2021-03-13 21:02:25.189116+00', '2021-03-13 21:02:25.189116+00', 'Milton Brae', 12028, '');
INSERT INTO 'tune' VALUES (14443, '2021-03-13 21:09:27.591406+00', '2021-03-13 21:09:27.591406+00', 'Mrs. Douglas Of Ednam', 9998, 'According to entries in the John Chamber''s ABC Tune Finder and notes on The Session this appears in the Athole Collection and Kerr''s collection Merry Melodies.');
INSERT INTO 'tune' VALUES (4034, NULL, '2021-03-13 21:15:48.901733+00', 'Bonnie Gallowa''', 1905, '');
INSERT INTO 'tune' VALUES (14444, '2021-03-13 21:21:34.989079+00', '2021-03-13 21:21:34.989079+00', 'Peter Johnston of Berryhead', 1585, 'Written for <<ddp:Johnston, Janet#11759>>''s father.');
INSERT INTO 'tune' VALUES (14445, '2021-03-13 21:24:11.530266+00', '2021-03-13 21:24:11.530266+00', 'Royal Bengal Strathspey, The', 10038, '');
INSERT INTO 'tune' VALUES (7400, NULL, '2021-03-14 00:39:25.846402+00', 'Thormanby Strathspey, The', 1582, '');
INSERT INTO 'tune' VALUES (14447, '2021-03-22 21:04:48.589739+00', '2021-03-22 21:04:48.589739+00', 'First Dram, A', 3139, '');
INSERT INTO 'tune' VALUES (6781, NULL, '2021-03-27 12:45:39.356488+00', 'Alasdair''s Reel', 1846, '');
INSERT INTO 'tune' VALUES (1529, NULL, '2021-03-30 21:11:16.850651+00', 'Robert & Judith Whitehead''s Compliments to Mr & Mrs Ian Barbour', 1709, '');
INSERT INTO 'tune' VALUES (14448, '2021-04-02 17:59:07.327008+00', '2021-04-02 17:59:07.327008+00', 'Patricia''s New Scotia Strathspey', 1971, '');
INSERT INTO 'tune' VALUES (14449, '2021-04-03 01:42:55.604422+00', '2021-04-03 01:42:55.604422+00', 'Skeely Skipper, The', 2944, '');
INSERT INTO 'tune' VALUES (3545, NULL, '2021-04-05 13:02:32.356464+00', 'Merry-Go-Round, The', 9999, '');
INSERT INTO 'tune' VALUES (1718, NULL, '2021-04-07 16:45:26.428375+00', 'Tickle my Fancy', 9998, 'This entry only seems to be known in relation to <<ddd:#6601|John Drewry''s dance of the same name>>. However the instructions for that dance mention three other tunes - but not one of this name. So this entry may be a mistaken addition to the database.');
INSERT INTO 'tune' VALUES (608, NULL, '2021-04-17 18:09:44.323642+00', 'Gobbie O, The', 9999, 'In the instructions to <<ddd:Provost, The>> as published in The Reel, this tune is referred to as The Gobyo.');
INSERT INTO 'tune' VALUES (1759, NULL, '2021-04-21 20:20:29.804069+00', 'Ury Water, The', 1512, 'The notes to <<ddd:Ross Meor>> in the revised edition of Book 29 say that although this tune is attributed to James Scott Skinner this is not verified.');
INSERT INTO 'tune' VALUES (14450, '2021-04-21 23:02:54.473202+00', '2021-04-21 23:17:09.761562+00', 'Full Circle', 3179, '');
INSERT INTO 'tune' VALUES (7835, NULL, '2021-04-22 18:15:20.890471+00', 'Martin & Barbara Munro of Ottawa', 1899, '');
INSERT INTO 'tune' VALUES (10150, '2009-08-02 22:00:00+00', '2021-04-24 22:36:06.700313+00', 'Montréal Summers', 10009, '');
INSERT INTO 'tune' VALUES (4828, NULL, '2021-05-01 20:09:20.672677+00', 'Miss Russell of Blackhall''s Reel', 1519, '');
INSERT INTO 'tune' VALUES (14460, '2021-06-30 11:21:23.707761+00', '2021-06-30 11:21:23.707761+00', 'Kylish', 1808, 'Check if G Shand is actually Gordon Shand');
INSERT INTO 'tune' VALUES (1588, NULL, '2021-05-07 22:37:28.911068+00', 'Scotsman in America, The', 9999, 'When given as the tune for <<ddd:Miss Bonny Parker#4436>> in <<https://www.rscdslondon.org.uk/wp-content/uploads/2018/10/The-Thistle-029-October-1966.pdf#page=3|issue 29 of The Thistle>> this is attributed to J. Blair.');
INSERT INTO 'tune' VALUES (2565, NULL, '2021-05-15 20:32:07.240013+00', 'Miss Agnes Lowden', 2380, 'The tune was entered in SCDDB as "Miss Agnes Lowden" but seems more normally to be spelled "Miss Agnes Loudon" which is entered as an alias (possibly main name and alias should be switched?). John Mitchell devised separate dances using each spelling.');
INSERT INTO 'tune' VALUES (10191, '2009-10-17 22:00:00+00', '2021-05-26 09:25:14.882891+00', 'Invercauld''s Reel', 1587, 'Possibly the same as <<ddt:Invercauld#2307>>? To be checked.');
INSERT INTO 'tune' VALUES (359, NULL, '2021-05-30 10:33:35.489844+00', 'Baldy Bain''s Fiddle', 9998, 'This tune was probably added because of a reference from <<ddp:Skelton, Barry#352>>''s dance <<ddd:Thane of Argyle#3085>>. However although there are poetic references to "the music o'' Baldy Bain''s fiddle" there seems to be no evidence there is a tune with that name - only a similarly named dance using a different tune.');
INSERT INTO 'tune' VALUES (564, NULL, '2021-06-05 11:38:44.213745+00', 'Gathering, The', 9998, 'Entered as a tune for the dance <<ddd:Gathering, The#2419>> whose recommended tune is <<ddt:Rendezvous, The#1518>>. So this entry might be a mistake?



');
INSERT INTO 'tune' VALUES (14452, '2021-06-20 13:17:56.917444+00', '2021-06-22 19:04:59.656357+00', 'Translator, The', 11781, '');
INSERT INTO 'tune' VALUES (14453, '2021-06-22 23:51:21.466948+00', '2021-06-22 23:51:21.466948+00', 'Golden Sun of Early Spring, The', 12035, '');
INSERT INTO 'tune' VALUES (14454, '2021-06-22 23:54:47.046138+00', '2021-06-22 23:54:47.046138+00', 'Sibylle''s Mother', 11341, '');
INSERT INTO 'tune' VALUES (14455, '2021-06-23 00:04:06.634842+00', '2021-06-23 00:04:06.634842+00', 'Pléiades', 11299, '');
INSERT INTO 'tune' VALUES (14456, '2021-06-23 00:06:33.95021+00', '2021-06-23 00:06:33.95021+00', 'Stop Worrying and have Fun', 12036, '');
INSERT INTO 'tune' VALUES (14457, '2021-06-23 00:10:10.289126+00', '2021-06-23 00:10:10.289126+00', 'Holden Together', 11341, '');
INSERT INTO 'tune' VALUES (14458, '2021-06-23 23:55:16.223424+00', '2021-06-23 23:55:16.223424+00', 'Love is in the Air', 11781, '');
INSERT INTO 'tune' VALUES (4334, NULL, '2021-06-24 16:38:58.167582+00', 'Nacton Hall', 1534, 'Dave Hall (David I. Hall) wrote Nacton Hall, for the dance of the same name by Judy Dix. 



Dave has confirmed that he is the composer and that there are recordings of it by him and his Band on the London Branch CD for one of their anniversaries.');
INSERT INTO 'tune' VALUES (3250, NULL, '2021-07-03 13:51:09.544085+00', 'Top of Balvenie, The', 1516, 'Originally entered in SCDDB as "The Top of Belvenie" but the spelling seems to be "The Top of Balvenie". The original is left as a spelling alias.');
INSERT INTO 'tune' VALUES (14446, '2021-03-16 18:37:32.878295+00', '2022-12-31 17:40:27.460741+00', 'Four Ladies, The', 1527, '');
INSERT INTO 'tune' VALUES (12691, '2013-10-31 15:41:19.98449+00', '2021-07-03 14:39:55.926297+00', 'Red Disa Reel', 3179, '');
INSERT INTO 'tune' VALUES (14463, '2021-07-03 14:59:37.439485+00', '2021-07-03 14:59:37.439485+00', 'March Madness', 3179, '');
INSERT INTO 'tune' VALUES (7194, NULL, '2021-07-03 21:41:56.345726+00', 'Royal Scottish Country Dance Society, The', 1556, '<<https://my.strathspey.org/dd/issue/2512/|Issue 2512>> says this was also published as a separate leaflet.');
INSERT INTO 'tune' VALUES (14464, '2021-07-04 08:49:59.673442+00', '2021-07-04 08:49:59.673442+00', 'John''s Request', 3281, '');
INSERT INTO 'tune' VALUES (14465, '2021-07-10 13:16:46.54433+00', '2021-07-10 13:16:46.54433+00', 'Markinch Mars Bar King, The', 11314, '');
INSERT INTO 'tune' VALUES (14466, '2021-07-14 08:11:47.241994+00', '2021-07-14 08:11:47.241994+00', 'Patsy & Ian Marks', 1899, '');
INSERT INTO 'tune' VALUES (9248, '2004-04-27 22:00:00+00', '2021-07-21 12:15:30.935693+00', 'Reel of the Transvaal Scottish, The', 1556, 'According to Aad Boode (the deviser of the dance), the tune was also composed by Bill Clement also in 2002 (same year as the dance itself). 



In October 1927, the Transvaal Scottish was affiliated to The Black Watch (Royal Highland Regiment).

Bill Clement (the composer of the dance''s tune) served in The Black Watch (Royal Highland Regiment) from May 1942 to April 1947; he joined the 10th Battalion Pipe Band in January 1943 and was acting Pipe-Major from January 1946. He joined the Atholl Highlanders in October 1947. (see dance entry for more information)');
INSERT INTO 'tune' VALUES (14468, '2021-07-30 21:17:03.736795+00', '2021-07-30 21:17:03.736795+00', 'Miss Cameron Of Balvenie', 1516, '');
INSERT INTO 'tune' VALUES (14467, '2021-07-30 20:35:11.072957+00', '2021-07-30 21:27:39.270772+00', 'Miss Jean Aberdein''s Reel', 1444, '');
INSERT INTO 'tune' VALUES (8155, NULL, '2021-08-06 20:49:35.697227+00', 'Puffin''s Reel', 2975, '');
INSERT INTO 'tune' VALUES (3147, NULL, '2021-08-11 19:02:47.243159+00', 'Mrs Wilson', 9999, 'See <<https://my.strathspey.org/dd/issue/2601/|issue 2601>> for a discussion of this tune''s name, availability and renditions.');
INSERT INTO 'tune' VALUES (14469, '2021-08-13 21:25:03.861609+00', '2021-08-13 21:25:03.861609+00', 'Lockdown with Bill Ewan', 1725, '');
INSERT INTO 'tune' VALUES (14470, '2021-08-13 21:26:06.666453+00', '2021-08-13 21:26:06.666453+00', 'Skiddin'' Roond the Bends', 12028, '');
INSERT INTO 'tune' VALUES (14471, '2021-08-16 10:22:04.528784+00', '2021-08-16 10:22:04.528784+00', '1921 Jig, The', 2168, 'From information in <<https://my.strathspey.org/dd/issue/2606/|issue 2606>>.');
INSERT INTO 'tune' VALUES (14477, '2021-08-20 12:18:30.677735+00', '2021-08-20 12:18:30.677735+00', 'Frolics at Midnight', 11962, '');
INSERT INTO 'tune' VALUES (14478, '2021-08-20 12:27:40.781804+00', '2021-08-20 12:27:40.781804+00', 'Ewan''s Midnight Mayhem', 12058, '');
INSERT INTO 'tune' VALUES (14479, '2021-08-20 12:29:49.641757+00', '2021-08-20 12:29:49.641757+00', '"Reel" Dandy Dancers, The', 11858, '');
INSERT INTO 'tune' VALUES (14480, '2021-08-20 12:59:46.741879+00', '2021-08-20 12:59:46.741879+00', 'Da Vyldest Pests', 11858, '');
INSERT INTO 'tune' VALUES (14481, '2021-08-20 13:18:08.724943+00', '2021-08-20 13:18:08.724943+00', 'Stagger Dreaming', 2101, '');
INSERT INTO 'tune' VALUES (14482, '2021-08-20 13:33:57.323447+00', '2021-08-20 13:33:57.323447+00', 'Judith''s Nights at the Stagger Inn', 1709, '');
INSERT INTO 'tune' VALUES (14483, '2021-08-20 13:43:53.454472+00', '2021-08-20 13:43:53.454472+00', 'One for the Road', 12028, '');
INSERT INTO 'tune' VALUES (14484, '2021-08-20 13:51:26.341627+00', '2021-08-20 13:51:26.341627+00', 'Daundrin'' Hame', 1631, '');
INSERT INTO 'tune' VALUES (14485, '2021-08-20 15:17:32.36645+00', '2021-08-20 15:17:32.36645+00', 'Corryvrechan', 1631, '');
INSERT INTO 'tune' VALUES (14486, '2021-08-23 22:56:03.293658+00', '2021-08-23 23:11:23.286789+00', 'Minnowburn, The', 12063, '');
INSERT INTO 'tune' VALUES (13562, '2017-03-22 12:32:33.000739+00', '2021-09-16 08:56:44.323388+00', 'Mormaer''s Reel, The', 1764, 'NB originally entered in SCDDB as "Moramaer''s Reel" which is taken to be a spelling mistake, but added as a spelling alias just in case.');
INSERT INTO 'tune' VALUES (14487, '2021-09-16 09:19:01.764321+00', '2021-09-16 09:19:01.764321+00', 'Further Ado', 12063, '');
INSERT INTO 'tune' VALUES (14488, '2021-09-16 09:19:40.133719+00', '2021-09-16 09:19:40.133719+00', 'Arthur Govan''s Here', 12063, '');
INSERT INTO 'tune' VALUES (14491, '2021-09-16 09:21:45.519477+00', '2021-09-16 09:21:45.519477+00', 'Gold in My Pocket', 12063, '');
INSERT INTO 'tune' VALUES (14492, '2021-09-16 11:30:27.042153+00', '2021-09-16 11:30:27.042153+00', 'Gillie''s Garters', 12063, 'My parents named me ‘Gilbert’ after my mother’s father. Over the years many have shortened

it to Gil or Gillie. So, this title has nothing to do with the lad who follows the Laird.');
INSERT INTO 'tune' VALUES (14493, '2021-09-16 12:22:22.75903+00', '2021-09-16 12:22:22.75903+00', 'Bird in the Hand', 12063, '');
INSERT INTO 'tune' VALUES (14495, '2021-09-16 20:08:08.854332+00', '2021-09-16 20:08:08.854332+00', 'Only the One', 12063, '');
INSERT INTO 'tune' VALUES (14494, '2021-09-16 12:24:08.354609+00', '2021-09-16 22:01:20.128358+00', 'On Bennetts'' Brae', 12063, 'Musicians'' note: For variety this tune can easily be transposed into G Major. Just ignore the 2 flats in the key signature and play in C Major but still play all the indicated F sharps.');
INSERT INTO 'tune' VALUES (14490, '2021-09-16 09:20:57.951253+00', '2021-09-16 22:01:55.497488+00', 'Branches of the Yew are Evergreen, The', 12063, 'Dedicated to all unnamed composers who have become ‘traditional’. Memory fades, but “The Branches of the Yew are Evergreen”.');
INSERT INTO 'tune' VALUES (14489, '2021-09-16 09:20:09.671162+00', '2021-09-16 22:02:38.239566+00', 'View of the Moon, A', 12063, 'Musicians'' note: For variety, and to create the effect of orbiting the moon, play as written but change each ‘B’ to ‘B flat’ in bars 1-8 and 17-24 only. ...However, this cheeky title has nothing to do with a lunar eclipse!');
INSERT INTO 'tune' VALUES (2658, NULL, '2021-09-23 17:15:17.256659+00', 'Loch of Lumgair', 1538, 'Previously entered in SCDDB as "Loch of Lungair" but the correct spelling of the place name seems to be Lumgair (with M rather than N).');
INSERT INTO 'tune' VALUES (13966, '2018-10-24 20:20:34.677971+00', '2021-09-23 20:37:58.976594+00', 'Pilot''s Delight', 389, 'The dance and tune are the result of Pat Gregory’s successful bid at the 2016 Asilomar Weekend Auction. In addition to Scottish Country dancing, Pat’s an active member of the Ninety-Nines, an international organization of women pilots.');
INSERT INTO 'tune' VALUES (150, NULL, '2021-09-24 09:38:57.157763+00', 'Bonnie Charlie', 1518, 'Information from Finlay Forbes (by email):  

*"Bonnie Charlie" appears as "Bonny Charlie" on Page 5 of the third part of Gow''s Repository, in which it is described as "A Scotish (sic) Measure" with instruction to be played "Slowish".  In its day, it probably sounded a bit like a "Lea Rig"/"Duchess Tree" style of strathspey.*

');
INSERT INTO 'tune' VALUES (14496, '2021-09-30 20:13:10.782913+00', '2021-09-30 20:13:10.782913+00', 'Gary and Joanna Coull''s Wedding', 2375, '');
INSERT INTO 'tune' VALUES (14497, '2021-09-30 20:24:38.753416+00', '2021-09-30 20:24:38.753416+00', 'John McLean''s Reel', 2375, '');
INSERT INTO 'tune' VALUES (14498, '2021-09-30 20:36:18.262274+00', '2021-09-30 20:36:18.262274+00', 'Farewell Jig', 12070, '');
INSERT INTO 'tune' VALUES (14499, '2021-09-30 20:41:11.73252+00', '2021-09-30 20:41:11.73252+00', 'Millbank', 2856, '');
INSERT INTO 'tune' VALUES (14500, '2021-09-30 20:48:01.881497+00', '2021-09-30 20:48:01.881497+00', 'Kathleen Johnston''s Jig', 1626, '');
INSERT INTO 'tune' VALUES (14501, '2021-09-30 20:49:31.03648+00', '2021-09-30 20:49:31.03648+00', 'Jack Hosie''s Fancy', 1522, '');
INSERT INTO 'tune' VALUES (14502, '2021-09-30 21:03:22.156496+00', '2021-09-30 21:03:22.156496+00', 'Roundabout Jig, The', 2523, '');
INSERT INTO 'tune' VALUES (14503, '2021-10-11 22:11:34.677238+00', '2021-10-11 22:11:34.677238+00', 'Lock-in Jig, The', 3203, '');
INSERT INTO 'tune' VALUES (14504, '2021-10-11 22:23:17.890454+00', '2021-10-11 22:23:17.890454+00', 'Pacemaker, The', 3220, '');
INSERT INTO 'tune' VALUES (14505, '2021-10-11 22:27:04.938926+00', '2021-10-11 22:27:04.938926+00', 'Belmont Lassies', 2126, '');
INSERT INTO 'tune' VALUES (14506, '2021-10-11 22:33:22.598157+00', '2021-10-11 22:33:22.598157+00', 'Capt I A Campbell', 2126, '');
INSERT INTO 'tune' VALUES (14507, '2021-10-12 07:44:05.661707+00', '2021-10-12 07:44:05.661707+00', 'Mrs Cameron''s Strathspey', 2126, '');
INSERT INTO 'tune' VALUES (14508, '2021-10-12 07:48:19.734366+00', '2021-10-12 07:48:19.734366+00', 'Bin Hoker, The', 12075, '');
INSERT INTO 'tune' VALUES (14509, '2021-10-12 07:59:11.80172+00', '2021-10-12 07:59:11.80172+00', 'Kellswater', 9999, '');
INSERT INTO 'tune' VALUES (14510, '2021-10-12 15:32:32.332605+00', '2021-10-12 15:32:32.332605+00', 'Bugle Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (14511, '2021-10-12 15:35:42.778547+00', '2021-10-12 15:35:42.778547+00', 'Moonstar', 11917, '');
INSERT INTO 'tune' VALUES (14512, '2021-10-12 15:46:49.087421+00', '2021-10-12 15:46:49.087421+00', 'Nottingham Cottage', 10596, '');
INSERT INTO 'tune' VALUES (14513, '2021-10-12 15:49:42.011217+00', '2021-10-12 15:49:42.011217+00', 'Freedom Reel, The', 3220, '');
INSERT INTO 'tune' VALUES (14514, '2021-10-16 22:09:52.912948+00', '2021-10-16 22:09:52.912948+00', 'Farquhar''s Reel', 1668, '');
INSERT INTO 'tune' VALUES (14525, '2021-10-17 09:57:18.56173+00', '2021-10-17 10:08:09.631828+00', 'Mrs Ferguson of Raith''s Delight', 9998, 'According to the comments in an article in The Session (<<https://thesession.org/tunes/3057>>) this tune is by Robert Petrie. However the CD insert for the album <<dda:Joy of Sets#1082>> ascribes it to James Walker. For the moment the composer is left as unknown.');
INSERT INTO 'tune' VALUES (14515, '2021-10-16 22:10:32.784871+00', '2021-10-16 22:24:59.771965+00', 'Pat and Wilson''s Ruby', 1575, '');
INSERT INTO 'tune' VALUES (14516, '2021-10-16 22:28:02.399516+00', '2021-10-16 22:28:02.399516+00', 'Warrior o'' Persie, The', 1512, '');
INSERT INTO 'tune' VALUES (14517, '2021-10-16 22:30:55.302804+00', '2021-10-16 22:30:55.302804+00', 'Muriel Malloy''s Strathspey', 10038, '');
INSERT INTO 'tune' VALUES (14518, '2021-10-16 22:43:34.91359+00', '2021-10-16 22:43:34.91359+00', 'Firth of Lorne, The', 1910, '');
INSERT INTO 'tune' VALUES (5932, NULL, '2021-10-16 22:45:28.183671+00', 'Inspector Donald Campbell, Ness', 1597, '');
INSERT INTO 'tune' VALUES (14526, '2021-10-17 10:23:11.405097+00', '2021-10-17 10:23:11.405097+00', 'Errol''s Reel', 10270, '');
INSERT INTO 'tune' VALUES (14520, '2021-10-16 23:02:50.795194+00', '2021-10-16 23:02:50.795194+00', 'Captain Lachlan MacPhail of Tiree', 1604, '');
INSERT INTO 'tune' VALUES (14519, '2021-10-16 22:51:53.076421+00', '2021-10-16 23:07:51.634591+00', 'Sparry, the Drone Tuner', 12077, '');
INSERT INTO 'tune' VALUES (14521, '2021-10-16 23:17:13.892041+00', '2021-10-16 23:17:13.892041+00', 'Archie Kenneth', 12078, '');
INSERT INTO 'tune' VALUES (14522, '2021-10-17 09:24:45.50447+00', '2021-10-17 09:24:45.50447+00', 'Gordon James Coutts', 3186, '');
INSERT INTO 'tune' VALUES (2979, NULL, '2021-10-17 09:31:15.274626+00', 'Alec Soammes'' Reel', 1660, 'Possible duplicate of <<ddt:Alex Soane''s Reel#7025>>?');
INSERT INTO 'tune' VALUES (7025, NULL, '2021-10-17 09:32:14.472674+00', 'Alex Soane''s Reel', 1660, 'Possible duplicate of <<ddt:Alec Soammes'' Reel#2979>>?');
INSERT INTO 'tune' VALUES (1874, NULL, '2021-10-17 09:33:48.588003+00', 'Angus McFadyen', 1660, 'Possible duplicate of <<ddt:Angus MacFadyen#7241>>?');
INSERT INTO 'tune' VALUES (7241, NULL, '2021-10-17 09:34:00.256339+00', 'Angus MacFadyen', 1660, 'Possible duplicate of <<ddt:Angus McFadyen#1874>>?');
INSERT INTO 'tune' VALUES (14523, '2021-10-17 09:34:55.882866+00', '2021-10-17 09:34:55.882866+00', 'Exclusive, The', 1660, '');
INSERT INTO 'tune' VALUES (14524, '2021-10-17 09:41:13.526848+00', '2021-10-17 09:41:13.526848+00', 'Robert Mitchell More', 3621, '');
INSERT INTO 'tune' VALUES (14527, '2021-10-30 07:48:51.719395+00', '2021-10-30 07:48:51.719395+00', 'Mr. Ian Gaylor', 1862, 'Source <<https://my.strathspey.org/dd/issue/2641/|Issue 2641>>.');
INSERT INTO 'tune' VALUES (2064, NULL, '2021-10-25 10:35:46.649492+00', 'Iain Peterson''s Reel', 1596, 'Possibly <<ddt:Iain Peterson#10664>> is a duplicate of this tune?');
INSERT INTO 'tune' VALUES (14528, '2021-11-04 21:57:16.89389+00', '2021-11-04 21:57:16.89389+00', 'Einstein''s Prediction', 1631, '');
INSERT INTO 'tune' VALUES (14529, '2021-11-11 09:47:39.739257+00', '2021-11-11 09:47:39.739257+00', 'Pretoria''s Purple Octobers', 3179, 'That time of year in Pretoria - purple Jacaranda lined streets heralding the imminent end of the academic year.

');
INSERT INTO 'tune' VALUES (14530, '2021-11-14 20:54:16.981717+00', '2021-11-14 20:54:16.981717+00', 'Frank Bennett''s Jig', 1596, '');
INSERT INTO 'tune' VALUES (14531, '2021-11-21 21:23:38.777031+00', '2021-11-21 21:23:38.777031+00', 'Katydid', 1829, 'Composed 2013.');
INSERT INTO 'tune' VALUES (14532, '2021-11-23 07:13:05.941536+00', '2021-11-23 07:13:05.941536+00', 'Shortest Legs take the Longest Steps, The', 12086, '');
INSERT INTO 'tune' VALUES (14534, '2021-11-23 08:52:45.711877+00', '2021-11-23 08:52:45.711877+00', 'Nissa la Bella', 11299, '');
INSERT INTO 'tune' VALUES (14536, '2021-11-23 08:59:53.500613+00', '2021-11-23 08:59:53.500613+00', 'Phare de Cordouan, Le', 1502, '');
INSERT INTO 'tune' VALUES (14537, '2021-11-23 09:04:00.886786+00', '2021-11-23 09:04:00.886786+00', 'Jig So Puzzled, A', 11781, '');
INSERT INTO 'tune' VALUES (14533, '2021-11-23 08:50:25.386602+00', '2021-11-24 14:02:05.643009+00', 'Ville Lumière, La', 11341, '');
INSERT INTO 'tune' VALUES (14538, '2021-11-23 09:05:15.177016+00', '2021-11-23 09:05:15.177016+00', 'Fifty and Fabulous', 11775, '');
INSERT INTO 'tune' VALUES (14539, '2021-11-23 09:07:51.971177+00', '2021-11-23 09:09:01.551548+00', 'Madame Rutabaga et le Chevalier Blanc', 11299, '');
INSERT INTO 'tune' VALUES (14535, '2021-11-23 08:57:00.523028+00', '2021-11-24 12:29:53.328555+00', 'Chambéry Blues', 3436, '');
INSERT INTO 'tune' VALUES (14459, '2021-06-26 13:37:32.341776+00', '2021-11-24 12:32:15.380421+00', 'Danièle Landrieau', 1502, '');
INSERT INTO 'tune' VALUES (13305, '2016-09-09 09:18:33.864378+00', '2021-11-24 15:02:50.117059+00', '20 Novembre, Le', 11341, '');
INSERT INTO 'tune' VALUES (14540, '2021-11-23 09:11:16.334923+00', '2021-11-25 09:01:52.991352+00', 'Banks of Loch Ness & The Wedding Ring, The', 389, '');
INSERT INTO 'tune' VALUES (14541, '2021-11-26 16:28:05.301813+00', '2021-11-26 16:28:05.301813+00', 'Geoff''s Jig', 1706, '');
INSERT INTO 'tune' VALUES (14542, '2021-11-27 22:42:20.882516+00', '2021-11-27 22:42:20.882516+00', 'Regina Freinbichler of Salzburg', 3179, '');
INSERT INTO 'tune' VALUES (14543, '2021-12-02 11:09:43.92274+00', '2021-12-02 11:09:43.92274+00', 'Peaceful, Festive Christmas Eve', 3179, 'Composed on 24.12.2019.');
INSERT INTO 'tune' VALUES (14544, '2021-12-03 18:19:30.951205+00', '2021-12-03 18:19:30.951205+00', 'Heart of Midlothian, The', 9998, '');
INSERT INTO 'tune' VALUES (14546, '2021-12-03 21:19:34.908214+00', '2021-12-03 21:19:34.908214+00', 'Laird of Dumbiedike''s Favorite, The', 9998, '');
INSERT INTO 'tune' VALUES (14547, '2021-12-03 22:16:37.46061+00', '2021-12-03 22:16:37.46061+00', 'Madge Wildfire''s Reel', 9998, '');
INSERT INTO 'tune' VALUES (14548, '2021-12-03 22:45:03.947323+00', '2021-12-03 22:45:03.947323+00', 'Kenilworth', 9998, '');
INSERT INTO 'tune' VALUES (14549, '2021-12-03 22:52:38.472547+00', '2021-12-03 22:52:38.472547+00', 'Pirate, The', 1517, '');
INSERT INTO 'tune' VALUES (14545, '2021-12-03 20:12:38.460513+00', '2021-12-03 23:35:07.955694+00', 'Jeanie Dean''s Strathspey', 9998, '');
INSERT INTO 'tune' VALUES (14550, '2021-12-06 12:30:41.501885+00', '2021-12-06 12:30:41.501885+00', 'London Nine-O', 1596, 'Composed for the winning entry of the London Branch 90th Anniversary competition.');
INSERT INTO 'tune' VALUES (14551, '2021-12-21 16:07:19.700956+00', '2021-12-21 16:07:19.700956+00', 'Anzac Strathspey, The', 1643, '');
INSERT INTO 'tune' VALUES (14552, '2022-01-09 19:36:23.735477+00', '2022-01-09 19:36:23.735477+00', 'Sherwood Nights', 9998, 'Given as the tune for the dance <<ddd:Saturday Morning Jig>> but otherwise unknown.');
INSERT INTO 'tune' VALUES (14553, '2022-01-09 19:41:46.288131+00', '2022-01-09 19:41:46.288131+00', 'Nan Lawson''s Favourite', 9998, 'Given as the tune for the dance <<ddd:Sherwood Strathspey>> but otherwise unknown.');
INSERT INTO 'tune' VALUES (14554, '2022-01-11 08:20:59.37578+00', '2022-01-11 08:20:59.37578+00', 'Bob Grant of Edinburgh', 1502, '');
INSERT INTO 'tune' VALUES (14555, '2022-01-11 09:33:44.754818+00', '2022-01-11 09:33:44.754818+00', 'Anne Mackenzie Smyth', 1502, '');
INSERT INTO 'tune' VALUES (14556, '2022-01-11 09:34:54.725447+00', '2022-01-11 09:35:29.359189+00', 'Bexi - the Golden Girl', 1502, '');
INSERT INTO 'tune' VALUES (14557, '2022-01-11 09:36:35.147324+00', '2022-01-11 09:36:35.147324+00', 'Dule Tree, The', 1502, '');
INSERT INTO 'tune' VALUES (14558, '2022-01-11 09:39:26.864897+00', '2022-01-11 09:39:26.864897+00', 'Good Times on Tiree', 1502, '');
INSERT INTO 'tune' VALUES (14559, '2022-01-11 09:42:43.955163+00', '2022-01-11 09:42:43.955163+00', 'Hirplin'' Fiddler, The', 1502, '');
INSERT INTO 'tune' VALUES (14560, '2022-01-11 09:45:23.599039+00', '2022-01-11 09:45:23.599039+00', 'Jig for Connie', 1502, '');
INSERT INTO 'tune' VALUES (14561, '2022-01-11 09:46:05.181878+00', '2022-01-11 09:46:05.181878+00', 'Margie''s 90th', 1502, '');
INSERT INTO 'tune' VALUES (14562, '2022-01-11 09:46:44.455365+00', '2022-01-11 09:46:44.455365+00', 'Marian''s Smile', 1502, '');
INSERT INTO 'tune' VALUES (14563, '2022-01-11 09:47:54.679214+00', '2022-01-11 09:47:54.679214+00', 'Self-levelling Compound, The', 1502, '');
INSERT INTO 'tune' VALUES (14564, '2022-01-11 09:48:35.721806+00', '2022-01-11 09:48:35.721806+00', 'To the Max', 1502, '');
INSERT INTO 'tune' VALUES (14565, '2022-01-11 09:51:06.26713+00', '2022-01-11 09:51:06.26713+00', 'Twa New Een', 1502, '');
INSERT INTO 'tune' VALUES (14566, '2022-01-11 09:51:42.229388+00', '2022-01-11 09:51:42.229388+00', 'Wenatchee Quilter, The', 1502, '');
INSERT INTO 'tune' VALUES (14567, '2022-01-11 09:52:26.058523+00', '2022-01-11 09:52:26.058523+00', 'Alistair, the Cartoonist', 1502, '');
INSERT INTO 'tune' VALUES (14568, '2022-01-11 09:53:20.992215+00', '2022-01-11 09:53:20.992215+00', 'Amisfield Lockdown Reel, The', 1502, '');
INSERT INTO 'tune' VALUES (14569, '2022-01-11 09:54:11.149126+00', '2022-01-11 09:54:11.149126+00', 'Connie''s Dance', 1502, '');
INSERT INTO 'tune' VALUES (14570, '2022-01-11 09:56:02.187024+00', '2022-01-11 09:56:02.187024+00', 'Da Rain Dancin''', 1502, '');
INSERT INTO 'tune' VALUES (14571, '2022-01-11 09:56:47.091659+00', '2022-01-11 09:56:47.091659+00', 'Da Wild Dratsie', 1502, '');
INSERT INTO 'tune' VALUES (14572, '2022-01-11 09:57:33.510662+00', '2022-01-11 09:57:33.510662+00', 'Dave @ 50', 1502, '');
INSERT INTO 'tune' VALUES (14573, '2022-01-11 09:58:12.425685+00', '2022-01-11 09:58:12.425685+00', 'Davie Minto''s Hornpipe', 1502, '');
INSERT INTO 'tune' VALUES (14574, '2022-01-11 09:58:45.155971+00', '2022-01-11 09:58:45.155971+00', 'Expectancy', 1502, '');
INSERT INTO 'tune' VALUES (14575, '2022-01-11 09:59:21.937492+00', '2022-01-11 09:59:21.937492+00', 'Fetlar Magic', 1502, '');
INSERT INTO 'tune' VALUES (14576, '2022-01-11 09:59:48.718373+00', '2022-01-11 09:59:48.718373+00', 'Friday Dancing', 1502, '');
INSERT INTO 'tune' VALUES (14577, '2022-01-11 10:00:25.206953+00', '2022-01-11 10:00:25.206953+00', 'Gow Memorial Reel, The', 1502, '');
INSERT INTO 'tune' VALUES (14578, '2022-01-11 10:00:54.401742+00', '2022-01-11 10:00:54.401742+00', 'Honey Bee', 1502, '');
INSERT INTO 'tune' VALUES (14579, '2022-01-11 10:01:48.217596+00', '2022-01-11 10:01:48.217596+00', 'Ian''s Underarm Serve', 1502, '');
INSERT INTO 'tune' VALUES (14580, '2022-01-11 10:02:22.460171+00', '2022-01-11 10:02:22.460171+00', 'Logie Longtail', 1502, '');
INSERT INTO 'tune' VALUES (14581, '2022-01-11 10:02:49.066419+00', '2022-01-11 10:02:49.066419+00', 'Logs, The', 1502, '');
INSERT INTO 'tune' VALUES (14582, '2022-01-11 10:03:24.2833+00', '2022-01-11 10:03:24.2833+00', 'Margot, Intrepid Sailor', 1502, '');
INSERT INTO 'tune' VALUES (14583, '2022-01-11 10:04:22.186689+00', '2022-01-11 10:04:22.186689+00', 'Sinclair Shewan', 1502, '');
INSERT INTO 'tune' VALUES (14584, '2022-01-11 10:04:53.592811+00', '2022-01-11 10:04:53.592811+00', 'Tegarmughd', 1502, '');
INSERT INTO 'tune' VALUES (14585, '2022-01-11 10:09:30.971251+00', '2022-01-11 10:09:30.971251+00', 'Yellow Hare, The', 1502, '');
INSERT INTO 'tune' VALUES (14586, '2022-01-11 10:09:57.588951+00', '2022-01-11 10:09:57.588951+00', 'Air for Bruce and Val', 1502, '');
INSERT INTO 'tune' VALUES (14587, '2022-01-11 10:10:34.280741+00', '2022-01-11 10:10:34.280741+00', 'Angela''s BAFTA Award', 1502, '');
INSERT INTO 'tune' VALUES (14588, '2022-01-11 10:18:19.398252+00', '2022-01-11 10:18:19.398252+00', 'Auld Scots Pine, The', 1502, '');
INSERT INTO 'tune' VALUES (14590, '2022-01-11 10:23:05.354491+00', '2022-01-11 10:23:05.354491+00', 'Heather Flint''s Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (14591, '2022-01-11 10:23:42.006048+00', '2022-01-11 10:23:42.006048+00', 'Heylipol', 1502, '');
INSERT INTO 'tune' VALUES (14592, '2022-01-11 10:24:29.146718+00', '2022-01-11 10:24:29.146718+00', 'Judge Lesley Allan', 1502, '');
INSERT INTO 'tune' VALUES (14593, '2022-01-11 10:25:08.703485+00', '2022-01-11 10:25:14.027657+00', 'Nouvelle Alliance, La', 1502, '');
INSERT INTO 'tune' VALUES (14594, '2022-01-11 10:26:08.572478+00', '2022-01-11 10:26:08.572478+00', 'Muriel Johnstone''s compliments to David Hall', 1502, '');
INSERT INTO 'tune' VALUES (14595, '2022-01-11 10:27:30.500024+00', '2022-01-11 10:27:30.500024+00', 'Muriel Johnstone''s compliments to Marian Anderson', 1502, '');
INSERT INTO 'tune' VALUES (14596, '2022-01-11 10:28:04.675425+00', '2022-01-11 10:28:04.675425+00', 'Rawsons of Old Moulin, The', 1502, '');
INSERT INTO 'tune' VALUES (14597, '2022-01-11 10:29:02.909909+00', '2022-01-11 10:29:02.909909+00', 'Returning the Compliment', 1502, '');
INSERT INTO 'tune' VALUES (14598, '2022-01-11 10:29:33.200716+00', '2022-01-11 10:29:33.200716+00', 'Stellaria for Paula', 1502, '');
INSERT INTO 'tune' VALUES (14599, '2022-01-11 10:30:27.585475+00', '2022-01-11 10:30:27.585475+00', 'Sue Hargreaves'' Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (14600, '2022-01-11 10:31:01.694011+00', '2022-01-11 10:31:01.694011+00', 'Theresa McVarish Clark', 1502, '');
INSERT INTO 'tune' VALUES (14601, '2022-01-11 10:31:31.748505+00', '2022-01-11 10:31:31.748505+00', 'To Di For', 1502, '');
INSERT INTO 'tune' VALUES (14602, '2022-01-11 10:33:09.537413+00', '2022-01-11 10:33:09.537413+00', 'Tribute to Bob Blackie', 1502, '');
INSERT INTO 'tune' VALUES (14589, '2022-01-11 10:22:22.775531+00', '2022-01-12 09:47:45.354303+00', 'Eric Finley''s Flourish', 1502, '');
INSERT INTO 'tune' VALUES (14604, '2022-01-11 10:37:00.236433+00', '2022-01-11 10:37:00.236433+00', 'Hats Off to Ponteland!', 1502, '"Caroline’s Charisma" (S) and "Hats Off to Ponteland!" (R) belong to "The Marvellous Middle School Medley"');
INSERT INTO 'tune' VALUES (14605, '2022-01-11 10:40:54.157747+00', '2022-01-11 10:40:54.157747+00', 'Fairfield Scotts', 1502, 'Waltz');
INSERT INTO 'tune' VALUES (14606, '2022-01-11 10:41:28.925439+00', '2022-01-11 10:41:28.925439+00', 'Farewell to Fetlar', 1502, 'Waltz');
INSERT INTO 'tune' VALUES (14607, '2022-01-11 10:41:59.748866+00', '2022-01-11 10:41:59.748866+00', 'Margie Elise', 1502, 'Waltz');
INSERT INTO 'tune' VALUES (14608, '2022-01-11 10:43:19.889238+00', '2022-01-11 10:43:19.889238+00', 'Memories of Still', 1502, 'Waltz');
INSERT INTO 'tune' VALUES (14609, '2022-01-11 10:43:58.07502+00', '2022-01-11 10:43:58.07502+00', 'Saltire on St Charles', 1502, 'Waltz');
INSERT INTO 'tune' VALUES (14610, '2022-01-11 10:44:40.122604+00', '2022-01-11 10:44:40.122604+00', 'Howmans of Auchnahyle, The', 1502, 'March');
INSERT INTO 'tune' VALUES (14611, '2022-01-11 10:45:37.795956+00', '2022-01-11 10:45:37.795956+00', 'Piercy''s Choice', 1502, 'March');
INSERT INTO 'tune' VALUES (14612, '2022-01-11 11:19:19.797393+00', '2022-01-11 11:19:19.797393+00', 'Morag''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (14613, '2022-01-11 11:20:34.057439+00', '2022-01-11 11:20:34.057439+00', 'St Andrews ''75', 1502, '');
INSERT INTO 'tune' VALUES (14614, '2022-01-11 11:21:03.058419+00', '2022-01-11 11:21:03.058419+00', 'Woolmarket, The', 1502, '');
INSERT INTO 'tune' VALUES (14615, '2022-01-11 11:23:59.284144+00', '2022-01-11 11:23:59.284144+00', 'Mr David Gray', 1502, '');
INSERT INTO 'tune' VALUES (10154, '2009-08-02 22:00:00+00', '2022-01-11 11:26:09.728942+00', 'Alexander Small Reel', 1502, '');
INSERT INTO 'tune' VALUES (14616, '2022-01-11 11:26:49.644718+00', '2022-01-11 11:26:49.644718+00', 'Barnton Roundabout', 1502, '');
INSERT INTO 'tune' VALUES (14617, '2022-01-11 11:27:58.50406+00', '2022-01-11 11:27:58.50406+00', 'Bo''sun''s Chair, The', 1502, '');
INSERT INTO 'tune' VALUES (14618, '2022-01-11 11:28:51.423047+00', '2022-01-11 11:28:51.423047+00', 'East of the Rockies', 1502, '');
INSERT INTO 'tune' VALUES (14619, '2022-01-11 11:29:31.033557+00', '2022-01-11 11:29:31.033557+00', 'Ladies Skerrs', 1502, '');
INSERT INTO 'tune' VALUES (14620, '2022-01-11 11:30:01.02318+00', '2022-01-11 11:30:01.02318+00', 'Mae Aitkenhead', 1502, '');
INSERT INTO 'tune' VALUES (14621, '2022-01-11 11:30:41.461351+00', '2022-01-11 11:30:41.461351+00', 'Master W E R Hatch', 1502, '');
INSERT INTO 'tune' VALUES (14622, '2022-01-11 11:32:22.308694+00', '2022-01-11 11:32:22.308694+00', 'Willie Hunter', 1502, '');
INSERT INTO 'tune' VALUES (14623, '2022-01-11 11:32:55.083299+00', '2022-01-11 11:32:55.083299+00', 'Gentle Mother, The', 1502, 'Waltz');
INSERT INTO 'tune' VALUES (14624, '2022-01-11 11:33:22.76159+00', '2022-01-11 11:33:22.76159+00', 'Lullaby for William', 1502, 'Waltz');
INSERT INTO 'tune' VALUES (14625, '2022-01-11 11:36:27.442844+00', '2022-01-11 11:36:27.442844+00', 'Stafford Knot', 2744, '');
INSERT INTO 'tune' VALUES (14626, '2022-01-12 01:15:15.786537+00', '2022-01-12 01:15:15.786537+00', 'George & Carmen''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (14627, '2022-01-12 01:16:07.655971+00', '2022-01-12 01:16:07.655971+00', 'Head for Heights', 1502, '');
INSERT INTO 'tune' VALUES (14628, '2022-01-12 01:17:55.239944+00', '2022-01-12 01:17:55.239944+00', 'Johan''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (14629, '2022-01-12 01:19:28.35087+00', '2022-01-12 01:19:28.35087+00', 'Julie Steven''s Surprise', 1502, '');
INSERT INTO 'tune' VALUES (14630, '2022-01-12 01:21:01.537717+00', '2022-01-12 01:21:01.537717+00', 'Laurin of Ardveche', 1502, '');
INSERT INTO 'tune' VALUES (14631, '2022-01-12 01:22:28.013446+00', '2022-01-12 01:22:28.013446+00', 'Longmeadow', 1502, '');
INSERT INTO 'tune' VALUES (14632, '2022-01-12 01:24:04.68451+00', '2022-01-12 01:24:04.68451+00', 'Scotsgate, The', 1502, '');
INSERT INTO 'tune' VALUES (14633, '2022-01-12 01:24:52.739086+00', '2022-01-12 01:24:52.739086+00', 'Sheena Sturrock''s Fancy', 1502, '');
INSERT INTO 'tune' VALUES (7312, NULL, '2022-01-12 01:27:18.538364+00', 'Upham Park Road', 1502, '');
INSERT INTO 'tune' VALUES (14634, '2022-01-12 01:28:39.786471+00', '2022-01-12 01:28:39.786471+00', 'Zoe''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (2234, NULL, '2022-01-12 01:36:07.203736+00', 'Gran Douglas''s Delight', 1502, '');
INSERT INTO 'tune' VALUES (14635, '2022-01-12 01:39:52.030895+00', '2022-01-12 01:39:52.030895+00', 'Mr & Mrs Livingstone of San Francisco', 1502, '');
INSERT INTO 'tune' VALUES (14636, '2022-01-12 01:41:46.346073+00', '2022-01-12 01:41:46.346073+00', 'Peggy''s Reel', 1502, '');
INSERT INTO 'tune' VALUES (14637, '2022-01-12 01:43:01.165296+00', '2022-01-12 01:43:01.165296+00', 'Rechberg Reel', 1502, '');
INSERT INTO 'tune' VALUES (14638, '2022-01-12 01:44:10.451844+00', '2022-01-12 01:44:10.451844+00', 'Ritchies'' Reel, The', 1502, '');
INSERT INTO 'tune' VALUES (14639, '2022-01-12 01:46:36.154131+00', '2022-01-12 01:46:36.154131+00', 'Alex Harvey', 1502, '');
INSERT INTO 'tune' VALUES (14640, '2022-01-12 01:49:18.53164+00', '2022-01-12 01:49:18.53164+00', 'F W Macondray', 1502, '');
INSERT INTO 'tune' VALUES (14641, '2022-01-12 01:52:52.147311+00', '2022-01-12 01:52:52.147311+00', 'Jean Harrison', 1502, '');
INSERT INTO 'tune' VALUES (14642, '2022-01-12 01:54:59.845159+00', '2022-01-12 01:54:59.845159+00', 'Leigh of Montrose', 1502, '');
INSERT INTO 'tune' VALUES (14643, '2022-01-12 02:08:56.600378+00', '2022-01-12 02:08:56.600378+00', 'Alastair''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (14644, '2022-01-12 02:09:53.814258+00', '2022-01-12 02:09:53.814258+00', 'Cherry Blossom Time', 1502, '');
INSERT INTO 'tune' VALUES (14645, '2022-01-12 02:11:24.731597+00', '2022-01-12 02:11:24.731597+00', 'Continental, The', 1502, '');
INSERT INTO 'tune' VALUES (14646, '2022-01-12 02:12:39.966616+00', '2022-01-12 02:12:39.966616+00', 'Douglas Baygull''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (14647, '2022-01-12 02:15:04.174475+00', '2022-01-12 02:15:04.174475+00', 'Gina''s Jig', 1502, '');
INSERT INTO 'tune' VALUES (14648, '2022-01-12 02:21:48.430314+00', '2022-01-12 02:21:48.430314+00', 'Norlins', 1502, '');
INSERT INTO 'tune' VALUES (14649, '2022-01-12 02:23:14.177774+00', '2022-01-12 02:23:14.177774+00', 'Raven Lodge', 1502, '');
INSERT INTO 'tune' VALUES (14650, '2022-01-12 02:28:14.947477+00', '2022-01-12 02:28:14.947477+00', 'Alexander Lumsden', 1502, '');
INSERT INTO 'tune' VALUES (14651, '2022-01-12 02:35:42.540294+00', '2022-01-12 02:35:42.540294+00', 'George Sessford - A Highland Gentleman', 1502, '');
INSERT INTO 'tune' VALUES (14652, '2022-01-12 02:36:41.047061+00', '2022-01-12 02:36:41.047061+00', 'Jolly Roger', 1502, '');
INSERT INTO 'tune' VALUES (14653, '2022-01-12 02:43:14.500037+00', '2022-01-12 02:43:14.500037+00', 'Muriel Johnstone''s compliments to Jim Lindsay', 1502, '');
INSERT INTO 'tune' VALUES (14654, '2022-01-12 02:48:45.118096+00', '2022-01-12 02:48:45.118096+00', 'Up Periscope', 1502, '');
INSERT INTO 'tune' VALUES (14655, '2022-01-12 02:52:21.645541+00', '2022-01-12 02:52:21.645541+00', 'Anne Riley''s Whimsy', 1502, '');
INSERT INTO 'tune' VALUES (14656, '2022-01-12 02:53:35.450061+00', '2022-01-12 02:53:35.450061+00', 'Certificate Strathspey, The', 1502, '');
INSERT INTO 'tune' VALUES (14657, '2022-01-12 02:55:35.131634+00', '2022-01-12 02:55:35.131634+00', 'E for Evelyn', 1502, '');
INSERT INTO 'tune' VALUES (14658, '2022-01-12 02:59:16.487752+00', '2022-01-12 02:59:16.487752+00', 'Georgina', 1502, '');
INSERT INTO 'tune' VALUES (14659, '2022-01-12 03:00:35.438829+00', '2022-01-12 03:00:35.438829+00', 'Houghtons of Meddat, The', 1502, '');
INSERT INTO 'tune' VALUES (14660, '2022-01-12 03:01:18.896339+00', '2022-01-12 03:01:18.896339+00', 'Jane Mo Gradh', 1502, '');
INSERT INTO 'tune' VALUES (14661, '2022-01-12 03:02:38.965356+00', '2022-01-12 03:02:38.965356+00', 'Ken Way''s Strathspey', 1502, '');
INSERT INTO 'tune' VALUES (14662, '2022-01-12 03:03:21.883012+00', '2022-01-12 03:03:21.883012+00', 'Mistress Mary', 1502, '');
INSERT INTO 'tune' VALUES (14663, '2022-01-12 03:04:11.289438+00', '2022-01-12 03:04:11.289438+00', 'Monica Roots', 1502, '');
INSERT INTO 'tune' VALUES (12763, '2014-02-06 18:53:24.578315+00', '2022-01-12 03:09:05.660901+00', 'Muriel Johnstone''s Compliments to Graham Donald', 1502, '');
INSERT INTO 'tune' VALUES (9329, NULL, '2022-01-12 03:14:42.422737+00', 'Ship of Dreams', 1502, '');
INSERT INTO 'tune' VALUES (14664, '2022-01-12 03:15:36.068302+00', '2022-01-12 03:15:36.068302+00', 'Swiss Chris', 1502, '');
INSERT INTO 'tune' VALUES (14665, '2022-01-12 03:16:13.650887+00', '2022-01-12 03:16:13.650887+00', 'Weather Rock Welcome', 1502, '');
INSERT INTO 'tune' VALUES (14666, '2022-01-12 03:17:16.890841+00', '2022-01-12 03:17:16.890841+00', 'As the River Flows', 1502, '');
INSERT INTO 'tune' VALUES (14667, '2022-01-12 03:18:32.827457+00', '2022-01-12 03:18:32.827457+00', 'Non-Judgemental Air, The', 1502, '');
INSERT INTO 'tune' VALUES (14603, '2022-01-11 10:33:42.062106+00', '2022-01-12 09:48:15.711854+00', 'Caroline''s Charisma', 1502, '"Caroline’s Charisma" (S) and "Hats Off to Ponteland!" (R) belong to "The Marvellous Middle School Medley"');
INSERT INTO 'tune' VALUES (14668, '2022-01-13 14:12:26.804714+00', '2022-01-13 14:12:26.804714+00', 'Trip to Orlova', 1508, '');
INSERT INTO 'tune' VALUES (14669, '2022-01-13 17:30:53.958382+00', '2022-01-13 17:30:53.958382+00', 'Skye High Jig, The', 1770, '');
INSERT INTO 'tune' VALUES (14670, '2022-01-13 17:34:58.059597+00', '2022-01-13 17:34:58.059597+00', 'Jock Gudmundson''s Farewell to the Eng''s', 1811, '');
INSERT INTO 'tune' VALUES (14671, '2022-01-13 18:14:34.202185+00', '2022-01-13 18:14:34.202185+00', 'All Through the Night', 9999, '');
INSERT INTO 'tune' VALUES (14672, '2022-01-13 18:17:51.811578+00', '2022-01-13 18:17:51.811578+00', 'English Country Garden', 9999, '');
INSERT INTO 'tune' VALUES (14673, '2022-01-13 18:42:02.448192+00', '2022-01-13 18:42:02.448192+00', 'Scunnered', 9999, '');
INSERT INTO 'tune' VALUES (3914, NULL, '2022-01-13 20:01:42.197326+00', 'Hielan Brochan', 9999, '');
INSERT INTO 'tune' VALUES (2358, NULL, '2022-01-13 20:03:39.354641+00', 'John Gideon Jamieson of Cullivoe', 1527, '');
INSERT INTO 'tune' VALUES (14674, '2022-01-16 21:55:59.28014+00', '2022-01-16 21:55:59.28014+00', 'Brig o'' Perth, The', 12095, '');
INSERT INTO 'tune' VALUES (4348, NULL, '2022-01-20 22:24:17.955516+00', 'Saint Johnstoun Reel', 1953, 'In <<ddpub:Book of Perth Dances, A#1057>> this tune is call The St Johnstoun Reel.



');
INSERT INTO 'tune' VALUES (14675, '2022-01-21 23:09:48.901532+00', '2022-01-21 23:09:48.901532+00', 'Crail Harbour', 12098, '');
INSERT INTO 'tune' VALUES (14676, '2022-01-22 20:38:56.503211+00', '2022-01-22 20:38:56.503211+00', 'Happy Trails', 12099, '');
INSERT INTO 'tune' VALUES (14677, '2022-02-07 11:39:18.385999+00', '2022-02-07 11:39:18.385999+00', 'Barbara''s Favourites', 1502, '');
INSERT INTO 'tune' VALUES (2592, NULL, '2022-01-27 18:49:36.010287+00', 'Miss Elizabeth Purcell''s Favourite', 1527, 'Possibly a duplicate of <<ddt:#12903>>?');
INSERT INTO 'tune' VALUES (12903, '2014-03-26 16:09:23.928904+00', '2022-01-27 18:49:56.044979+00', 'Elizabeth Purcells Favourite', 1527, 'Possibly a duplicate of <<ddt:#2592>>?');
INSERT INTO 'tune' VALUES (285, NULL, '2022-02-12 22:13:32.632928+00', 'Clachan, The', 1437, 'This tune exists both in a strathspey and a jig version.');
INSERT INTO 'tune' VALUES (9581, NULL, '2022-02-12 22:16:00.078559+00', 'John Piper "McCulloch"', 9998, '');
INSERT INTO 'tune' VALUES (14678, '2022-02-16 14:51:54.61131+00', '2022-02-16 14:51:54.61131+00', 'Bright Moonlight', 11390, 'Composed in memory of Pam Hood.');
INSERT INTO 'tune' VALUES (14679, '2022-02-16 14:52:21.391104+00', '2022-02-16 14:52:21.391104+00', 'Tune for Pam, A', 11390, 'Composed in memory of Pam Hood.');
INSERT INTO 'tune' VALUES (13306, '2016-09-09 09:39:38.574331+00', '2022-02-17 01:38:49.258168+00', 'Pretty Bride of Préty, The', 11341, '');
INSERT INTO 'tune' VALUES (14680, '2022-02-20 23:40:46.527099+00', '2022-02-20 23:40:46.527099+00', 'Jane Rose''s Strathspey', 1576, '');
INSERT INTO 'tune' VALUES (14681, '2022-02-20 23:41:02.279167+00', '2022-02-20 23:41:02.279167+00', 'Brian Rose''s Reel', 1576, '');
INSERT INTO 'tune' VALUES (485, NULL, '2022-02-25 18:44:23.653603+00', 'Edinburgh Castle Reel, The', 9999, '');
INSERT INTO 'tune' VALUES (14461, '2021-06-30 21:32:51.986804+00', '2022-03-01 23:39:09.987385+00', 'Pairtin'' Kiss, The', 709, '');
INSERT INTO 'tune' VALUES (14682, '2022-03-01 23:47:28.428388+00', '2022-03-01 23:47:28.428388+00', 'Miss Colston''s Strathspey', 1518, '');
INSERT INTO 'tune' VALUES (14683, '2022-03-01 23:51:55.860428+00', '2022-03-01 23:51:55.860428+00', 'Cross Roads', 9999, '');
INSERT INTO 'tune' VALUES (14684, '2022-03-01 23:55:02.803611+00', '2022-03-01 23:55:02.803611+00', 'Bridge of Lodi, The', 9999, '');
INSERT INTO 'tune' VALUES (14685, '2022-03-02 00:02:48.135806+00', '2022-03-02 00:02:48.135806+00', 'Queen o'' the Haggis, The', 709, 'Dedicated to Ruth Jappy.');
INSERT INTO 'tune' VALUES (14686, '2022-03-02 00:04:13.54754+00', '2022-03-02 00:04:13.54754+00', 'Alex Jappy', 709, '');
INSERT INTO 'tune' VALUES (14687, '2022-03-02 00:04:29.078471+00', '2022-03-02 00:04:29.078471+00', 'All the Little Jappys', 709, '');
INSERT INTO 'tune' VALUES (14688, '2022-03-02 00:11:58.314485+00', '2022-03-02 00:11:58.314485+00', 'Mr. Young''s', 12117, '');
INSERT INTO 'tune' VALUES (14689, '2022-03-02 00:16:07.028762+00', '2022-03-02 00:16:07.028762+00', 'Miss Ann Mackay''s Favorite', 1519, '');
INSERT INTO 'tune' VALUES (14690, '2022-03-02 00:18:47.347981+00', '2022-03-02 00:18:47.347981+00', 'Maid of the Mist, The', 709, '');
INSERT INTO 'tune' VALUES (14691, '2022-03-02 00:22:13.74655+00', '2022-03-02 00:22:13.74655+00', 'St. Anne''s Cathedral', 709, '');
INSERT INTO 'tune' VALUES (14692, '2022-03-02 00:23:05.659237+00', '2022-03-02 00:23:05.659237+00', 'Scots Recluse, The', 1859, '');
INSERT INTO 'tune' VALUES (14693, '2022-03-02 00:24:19.955216+00', '2022-03-02 00:24:19.955216+00', 'Her Absence Will Not Alter Me', 9998, '');
INSERT INTO 'tune' VALUES (14694, '2022-03-02 00:25:15.898251+00', '2022-03-02 00:25:15.898251+00', 'Winter', 9999, '');
INSERT INTO 'tune' VALUES (14695, '2022-03-02 00:26:51.903966+00', '2022-03-02 00:26:51.903966+00', 'Miss Ali Bartlett', 709, '');
INSERT INTO 'tune' VALUES (14696, '2022-03-02 00:27:10.941993+00', '2022-03-02 00:27:10.941993+00', 'Dominique''s Birthday', 709, '');
INSERT INTO 'tune' VALUES (14697, '2022-03-02 00:28:07.385752+00', '2022-03-02 00:28:07.385752+00', 'Summer Day in Autumn, A', 709, '');
INSERT INTO 'tune' VALUES (14698, '2022-03-02 00:28:35.751428+00', '2022-03-02 00:28:35.751428+00', 'Eaton Hall', 709, '');
INSERT INTO 'tune' VALUES (14699, '2022-03-02 00:29:41.188565+00', '2022-03-02 00:29:41.188565+00', 'April Fool', 709, '');
INSERT INTO 'tune' VALUES (14700, '2022-03-02 00:30:00.127325+00', '2022-03-02 00:30:00.127325+00', 'Merry Ground, The', 709, '');
INSERT INTO 'tune' VALUES (14701, '2022-03-02 00:31:39.230411+00', '2022-03-02 00:31:39.230411+00', 'Jappy Farewell Waltz, The', 709, '');
INSERT INTO 'tune' VALUES (14704, '2022-03-13 18:32:09.614265+00', '2022-10-01 11:53:48.843451+00', 'Roland Telle de Bretagne', 3179, '');
INSERT INTO 'tune' VALUES (14705, '2022-03-26 20:09:08.914415+00', '2022-03-26 20:09:08.914415+00', 'Tyneside Lassie, The', 1643, 'Composed: 2008-08

Played AABC (The Second Kiwi Collection)');
INSERT INTO 'tune' VALUES (14706, '2022-04-02 18:42:49.032113+00', '2022-04-02 18:50:20.243344+00', 'Open The Doors!', 3683, 'Inspired by Morgan''s poem: "For The Opening of the Scottish Parliament, 9 October 2004"



The name of the dance is taken from the opening line and of the tune from the last. The dance is suitable for the opening of a Scottish Dance programme allowing dancers of any age or ability to join in. The music highlights the joy and optimism of the poem, with some descending musical reference to mimic Morgan''s trip, "down the mile, into the heart of the city". There is occasional syncopation to interrupt the flow, suggesting the political missteps that Morgan warns against.');
INSERT INTO 'tune' VALUES (14707, '2022-04-02 18:55:45.451222+00', '2022-04-02 18:55:45.451222+00', 'Off Course', 3683, 'In Spacepoem 3: Off Course, Morgan uses a series of ever slightly changing images to create a sense of isolation and unease, but also hopefulness and optimism.

The dance emphasises some of the elegant images of "turning continents" and "imaginary somersaults." The tune warps from sombre minor to hopeful major and takes inspiration from the uplifting final image: "the floating song."');
INSERT INTO 'tune' VALUES (14708, '2022-04-02 19:00:10.898753+00', '2022-04-02 19:00:10.898753+00', 'George Square Starlings', 3683, 'The Starlings in George Square is a three part poem that describes the plight of the starlings and their eviction from central Glasgow.

The dance and the tune are both focussed on the first of the three parts. The starlings are in their multitudes and dance, dash and dart like a shower of arrows.');
INSERT INTO 'tune' VALUES (14709, '2022-04-02 19:04:53.182113+00', '2022-04-02 19:04:53.182113+00', 'Trinity, The', 3683, 'Trio is a tremendously joyous poem. This dance maintains the clever continued use of three and emulates the joy and happiness of the poem''s protagonists.

The tune refers to the memorable line, "Orphean Sprig! Melting Baby! Warm Chihuahua!" The melody references the threesome''s journey, bouncing repeatedly onward, without looking back.');
INSERT INTO 'tune' VALUES (14710, '2022-04-02 19:08:02.085575+00', '2022-04-02 19:08:02.085575+00', 'Strawberries', 3683, 'Strawberries is one of Morgan''s best known and most loved poems.

The dance celebrates the connection between the two people. The tune ends unfinished, left behind, not unlike the discarded plates.');
INSERT INTO 'tune' VALUES (14711, '2022-04-02 19:14:25.473724+00', '2022-04-02 19:14:25.473724+00', 'Mercury Men', 3683, 'A dance and tune for those native to Mercury on meeting their visitors from Earth in Morgan''s poem, The First Men on Mercury.

The dance is complex and involves dancers in the unconventional feature in Country dancing of couples changing sides as the dance progresses. This reflects the way that the men arriving on Mercury and the inhabitants adopt each other''s language and become increasingly difficult to disentangle.

The tune is named after the Alien''s initial greeting and has a simple theme, which becomes gradually altered and more complicated. As Morgan concludes, "but nothing is ever the same, now is it?"');
INSERT INTO 'tune' VALUES (1251, NULL, '2022-04-07 21:10:49.086116+00', 'Misses Little''s Fancy, The', 1495, '');
INSERT INTO 'tune' VALUES (1793, NULL, '2022-04-24 11:42:10.090553+00', 'Welcome to Queen''s Cross', 2370, 'Thought to be a duplicate of <<ddt:Mrs Kyd''s Favourite#802>> (see <<https://my.strathspey.org/dd/issue/2762/|issue 2762>>. This entry, and that for person #2370, should be deleted once this is confirmed.');
INSERT INTO 'tune' VALUES (14715, '2022-04-29 20:48:52.90439+00', '2022-04-29 20:48:52.90439+00', 'Ode to Graham', 3693, '');
INSERT INTO 'tune' VALUES (802, NULL, '2022-04-24 11:52:20.61396+00', 'Mrs Kyd''s Favourite', 1565, 'Also known as "Welcome to Queen''s Cross" after the <<ddd:Welcome to Queen''s Cross#7028|dance>> for which it was written (see <<https://my.strathspey.org/dd/issue/2762/|issue 2762>>).');
INSERT INTO 'tune' VALUES (14712, '2022-04-29 20:41:11.347171+00', '2022-04-29 20:41:11.347171+00', 'Eric''s North Esk Hideaway', 2101, '');
INSERT INTO 'tune' VALUES (14713, '2022-04-29 20:46:18.235305+00', '2022-04-29 20:46:29.011802+00', 'Miss Pamela Rae', 11314, '');
INSERT INTO 'tune' VALUES (14714, '2022-04-29 20:47:55.384711+00', '2022-04-29 20:47:55.384711+00', 'Glens of Antrim, The', 1537, '');
INSERT INTO 'tune' VALUES (14716, '2022-04-29 20:52:39.770335+00', '2022-04-29 20:52:39.770335+00', 'Hebbie''s Roon o'' Golf', 2101, '');
INSERT INTO 'tune' VALUES (14717, '2022-04-29 20:54:37.881039+00', '2022-04-29 20:54:37.881039+00', 'Peter Ruadh of Mullaghmossin', 2253, '');
INSERT INTO 'tune' VALUES (14718, '2022-04-29 21:11:26.320557+00', '2022-04-29 21:11:26.320557+00', 'Cattie Croft', 12028, '');
INSERT INTO 'tune' VALUES (14719, '2022-04-29 21:20:44.868659+00', '2022-04-29 21:20:44.868659+00', 'Doreen''s Strathspey', 2101, '');
INSERT INTO 'tune' VALUES (14720, '2022-04-29 21:22:02.810447+00', '2022-04-29 21:22:02.810447+00', 'Reel for Maria Sol', 2101, '');
INSERT INTO 'tune' VALUES (14721, '2022-04-29 21:26:31.109773+00', '2022-04-29 21:26:31.109773+00', 'Marie Pottinger''s Reel', 1710, '');
INSERT INTO 'tune' VALUES (14722, '2022-04-29 21:31:57.813095+00', '2022-04-29 21:31:57.813095+00', 'George Hepburn Stott', 2101, '');
INSERT INTO 'tune' VALUES (14723, '2022-04-29 21:37:54.880964+00', '2022-04-29 21:37:54.880964+00', 'Marcella''s Jig', 2101, '');
INSERT INTO 'tune' VALUES (14724, '2022-04-29 21:41:50.600835+00', '2022-04-29 21:41:50.600835+00', 'Monteith Strathspey, The', 11314, '');
INSERT INTO 'tune' VALUES (14725, '2022-04-29 21:43:22.736484+00', '2022-04-29 21:43:22.736484+00', 'Hauplands Muir', 11962, '');
INSERT INTO 'tune' VALUES (14726, '2022-04-29 21:49:36.734916+00', '2022-04-29 21:49:36.734916+00', 'Charly Candia''s Reel', 11858, '');
INSERT INTO 'tune' VALUES (14727, '2022-04-29 21:57:20.433414+00', '2022-04-29 21:57:20.433414+00', 'Jim Stott''s Jig', 11314, '');
INSERT INTO 'tune' VALUES (14728, '2022-04-29 21:59:05.122165+00', '2022-04-29 22:00:17.465666+00', 'Cullen Burn Fisher, The', 2253, '');
INSERT INTO 'tune' VALUES (14729, '2022-04-29 22:03:46.20295+00', '2022-04-29 22:03:46.20295+00', 'Paul Grant''s Hairy Highland Friends', 2253, '');
INSERT INTO 'tune' VALUES (14730, '2022-04-29 22:06:40.121538+00', '2022-04-29 22:06:40.121538+00', 'Memories of Beryl', 2101, '');
INSERT INTO 'tune' VALUES (14731, '2022-04-29 22:09:37.034383+00', '2022-04-29 22:09:37.034383+00', 'Ashridge', 1631, '');
INSERT INTO 'tune' VALUES (14703, '2022-03-07 18:45:13.334193+00', '2022-12-31 17:41:59.313521+00', 'Masako Nomura''s Strathspey', 1527, '');
INSERT INTO 'tune' VALUES (14733, '2022-04-29 22:15:35.575923+00', '2022-04-29 22:16:10.801341+00', 'Eddy with the Silver Kilt', 2101, '');
INSERT INTO 'tune' VALUES (14734, '2022-04-29 22:19:36.250016+00', '2022-04-29 22:19:36.250016+00', 'Dancing Dominie, The', 1586, '');
INSERT INTO 'tune' VALUES (14735, '2022-05-03 19:57:26.420366+00', '2022-05-03 19:57:26.420366+00', 'Feeling Knotty!', 11858, '');
INSERT INTO 'tune' VALUES (14736, '2022-05-03 20:10:56.622522+00', '2022-05-03 20:10:56.622522+00', 'Plastic, Fantastic', 11858, '');
INSERT INTO 'tune' VALUES (14737, '2022-05-03 20:27:40.16653+00', '2022-05-03 20:27:40.16653+00', 'Out on the Forth', 11858, '');
INSERT INTO 'tune' VALUES (14738, '2022-05-03 21:07:00.193794+00', '2022-05-03 21:30:46.935871+00', 'H.M.S Diamond, The Type 45', 11858, '');
INSERT INTO 'tune' VALUES (14739, '2022-05-03 21:08:24.392665+00', '2022-05-03 21:31:19.665178+00', 'T.S. Trinity', 11858, '');
INSERT INTO 'tune' VALUES (14740, '2022-05-03 21:09:11.54242+00', '2022-05-03 21:32:03.224568+00', 'Grand Fleet, The', 11858, '');
INSERT INTO 'tune' VALUES (14741, '2022-05-03 21:16:36.422639+00', '2022-05-03 21:32:58.054847+00', 'Erin''s Jig', 9998, '');
INSERT INTO 'tune' VALUES (14742, '2022-05-03 21:22:02.712262+00', '2022-05-03 21:33:32.480626+00', 'Sarah''s Stamp Party', 11858, '');
INSERT INTO 'tune' VALUES (14743, '2022-05-03 21:26:52.411757+00', '2022-05-03 21:34:05.154694+00', 'Ducky''s Adventures', 11858, '');
INSERT INTO 'tune' VALUES (14744, '2022-05-03 21:27:40.891697+00', '2022-05-03 21:34:33.28083+00', 'Shipshape and Bristol Fashion', 11858, '');
INSERT INTO 'tune' VALUES (14745, '2022-05-03 21:28:46.109105+00', '2022-05-03 21:37:26.546174+00', 'Land Ho!', 11858, '');
INSERT INTO 'tune' VALUES (14746, '2022-05-03 21:38:01.002887+00', '2022-05-03 21:38:01.002887+00', 'Loch Ard (Source of the Forth)', 11858, '');
INSERT INTO 'tune' VALUES (14747, '2022-05-03 21:38:53.797384+00', '2022-05-03 21:38:53.797384+00', 'Painting the Forth Bridge', 11858, '');
INSERT INTO 'tune' VALUES (14748, '2022-05-03 21:41:16.338625+00', '2022-05-03 21:41:16.338625+00', 'Multi-Talented Drummer, The', 11858, '');
INSERT INTO 'tune' VALUES (14749, '2022-05-03 21:42:25.907018+00', '2022-05-03 21:42:25.907018+00', 'Ewan Galloway''s Compliments to Alan Gifford', 11858, '');
INSERT INTO 'tune' VALUES (14750, '2022-05-09 14:49:46.704598+00', '2022-05-09 14:49:46.704598+00', 'Frazers of Strathkinness, The', 3683, '');
INSERT INTO 'tune' VALUES (14751, '2022-05-14 18:10:40.032438+00', '2022-05-14 18:10:40.032438+00', 'Cheeky Claude', 1502, '');
INSERT INTO 'tune' VALUES (1462, NULL, '2022-05-14 22:27:47.733731+00', 'Piper of Dundee, The', 9999, 'Presumably <<ddt:#10978>> is a duplicate of this?');
INSERT INTO 'tune' VALUES (10978, '2009-12-22 23:00:00+00', '2022-05-14 22:27:51.059257+00', 'Piper o'' Dundee', 9999, 'Presumably a duplicate of <<ddt:#1462>>?');
INSERT INTO 'tune' VALUES (1136, NULL, '2022-05-15 20:30:32.408969+00', 'Miss Baird of Saughtonhall', 1517, '');
INSERT INTO 'tune' VALUES (14752, '2022-05-29 10:58:37.784019+00', '2022-05-29 10:58:37.784019+00', 'Anne Newton''s Strathspey', 1596, '');
INSERT INTO 'tune' VALUES (14753, '2022-05-29 11:44:15.232181+00', '2022-05-29 11:44:15.232181+00', 'Stephen John Webb Esq.', 1596, '');
INSERT INTO 'tune' VALUES (14754, '2022-05-29 11:44:50.039181+00', '2022-05-29 11:44:50.039181+00', 'Jeremy Newton''s Strathspey', 1596, '');
INSERT INTO 'tune' VALUES (14755, '2022-06-07 21:14:10.156324+00', '2022-06-07 21:14:10.156324+00', 'Mr Francis Walduck', 11790, '');
INSERT INTO 'tune' VALUES (14756, '2022-06-07 21:53:06.630861+00', '2022-06-07 21:53:06.630861+00', 'Sweetfish of Neo River', 2786, '');
INSERT INTO 'tune' VALUES (14757, '2022-06-07 22:38:00.967924+00', '2022-06-07 22:38:00.967924+00', 'Celebrate Ten and Twenty Years', 11188, '');
INSERT INTO 'tune' VALUES (14758, '2022-06-08 09:39:11.444655+00', '2022-06-08 09:39:11.444655+00', 'Always on my Mind', 2786, '');
INSERT INTO 'tune' VALUES (14759, '2022-06-08 11:13:11.997139+00', '2022-06-08 11:13:11.997139+00', 'Avenue of Ginkgo Trees', 11188, '');
INSERT INTO 'tune' VALUES (14760, '2022-06-20 08:27:00.964379+00', '2022-06-20 08:27:00.964379+00', 'Girniere Castle', 9998, 'Only found on Jim Macleod recording: maybe a misspelling for Girnigoe?');
INSERT INTO 'tune' VALUES (14761, '2022-06-20 08:27:24.109638+00', '2022-06-20 08:27:24.109638+00', 'Monks of Melrose', 9998, '');
INSERT INTO 'tune' VALUES (14762, '2022-06-23 18:35:52.678204+00', '2022-06-23 18:35:52.678204+00', 'Jag me in the Arm', 11185, '');
INSERT INTO 'tune' VALUES (14763, '2022-06-23 18:37:08.908376+00', '2022-06-24 09:03:16.201255+00', 'Mrs. MacInroy of Lude', 9999, '');
INSERT INTO 'tune' VALUES (14764, '2022-06-25 16:23:28.843374+00', '2022-06-25 16:23:28.843374+00', 'Newcastle''s 70th', 1576, '');
INSERT INTO 'tune' VALUES (14766, '2022-06-25 16:25:25.443494+00', '2022-06-25 16:25:25.443494+00', 'Sheila Trafford''s Strathspey', 1725, '');
INSERT INTO 'tune' VALUES (14767, '2022-06-25 16:25:58.91136+00', '2022-06-25 16:25:58.91136+00', 'South of the Tyne', 3220, '');
INSERT INTO 'tune' VALUES (14768, '2022-06-25 16:26:25.565138+00', '2022-06-25 16:26:25.565138+00', 'Remembering Robert', 1725, '');
INSERT INTO 'tune' VALUES (14770, '2022-06-25 16:29:10.340629+00', '2022-06-25 16:29:10.340629+00', 'Music Teacher, The', 2807, '');
INSERT INTO 'tune' VALUES (14771, '2022-06-25 16:30:39.350023+00', '2022-06-25 16:30:39.350023+00', 'Tune for Cathie, A', 2807, '');
INSERT INTO 'tune' VALUES (14772, '2022-06-25 16:31:16.31965+00', '2022-06-25 16:31:16.31965+00', 'Farne Islands Jig, The', 10038, '');
INSERT INTO 'tune' VALUES (14773, '2022-06-25 16:31:42.710472+00', '2022-06-25 16:31:42.710472+00', 'Howard''s Strathspey', 1725, '');
INSERT INTO 'tune' VALUES (14774, '2022-06-25 16:32:12.956181+00', '2022-06-25 16:32:12.956181+00', 'Benridge Moor', 1725, '');
INSERT INTO 'tune' VALUES (14775, '2022-06-25 16:32:33.661503+00', '2022-06-25 16:32:33.661503+00', 'Wansbeck Water', 1725, '');
INSERT INTO 'tune' VALUES (14776, '2022-06-25 16:33:02.542971+00', '2022-06-25 16:33:02.542971+00', 'Golden Wishes for Stocksfield', 1725, '');
INSERT INTO 'tune' VALUES (14777, '2022-06-25 16:33:36.319854+00', '2022-06-25 16:33:36.319854+00', 'Tyne Bridge, The', 10038, '');
INSERT INTO 'tune' VALUES (14778, '2022-06-25 16:34:03.643845+00', '2022-06-25 16:34:03.643845+00', 'Chasing Shadows', 3220, '');
INSERT INTO 'tune' VALUES (14779, '2022-06-25 16:34:28.525026+00', '2022-06-25 16:34:28.525026+00', 'Seven Up', 2806, '');
INSERT INTO 'tune' VALUES (14780, '2022-06-25 16:49:20.456505+00', '2022-06-25 16:49:20.456505+00', 'Jig for Jean, A', 3220, '');
INSERT INTO 'tune' VALUES (14782, '2022-06-25 16:57:07.390978+00', '2022-06-25 16:57:07.390978+00', 'Stroll in the Dene, A', 12156, '');
INSERT INTO 'tune' VALUES (14783, '2022-06-25 17:38:31.9583+00', '2022-06-25 17:38:31.9583+00', 'Jean''s Anniversary', 3220, '');
INSERT INTO 'tune' VALUES (14784, '2022-06-25 17:56:26.124835+00', '2022-06-25 17:56:26.124835+00', 'Isobel McMillan of Strachan', 3220, '');
INSERT INTO 'tune' VALUES (14785, '2022-06-25 18:02:07.484896+00', '2022-06-25 18:02:07.484896+00', 'Speed Bump, The', 3220, 'This is the same tune as The Speed Hump');
INSERT INTO 'tune' VALUES (14786, '2022-06-25 18:06:48.473237+00', '2022-06-25 18:06:48.473237+00', 'Magnum Flume, The', 1575, '');
INSERT INTO 'tune' VALUES (14794, '2022-06-25 18:39:36.788278+00', '2022-12-31 17:42:33.552133+00', 'Mrs Frances Aitken of Cramond', 1527, '');
INSERT INTO 'tune' VALUES (14765, '2022-06-25 16:24:43.462408+00', '2023-01-30 18:11:38.834226+00', 'George Darling''s Jig', 1527, '');
INSERT INTO 'tune' VALUES (14800, '2022-07-24 18:26:16.509418+00', '2022-07-24 18:26:16.509418+00', 'Lovely Lettram', 9999, '');
INSERT INTO 'tune' VALUES (14801, '2022-07-24 18:26:45.298475+00', '2022-07-24 18:26:45.298475+00', 'Staic an Margaid', 9999, '');
INSERT INTO 'tune' VALUES (14802, '2022-07-27 13:20:45.059174+00', '2022-07-27 13:20:45.059174+00', '40 Shades of Red', 10908, 'Written for the 40th Australian Winter School in 2015.');
INSERT INTO 'tune' VALUES (14803, '2022-07-27 13:23:22.011074+00', '2022-07-27 13:23:22.011074+00', 'Tazmanian Devil, The', 10505, 'The spelling is with "z" in the name (<<https://my.strathspey.org/dd/issue/2849/>>).');
INSERT INTO 'tune' VALUES (14804, '2022-07-27 13:25:45.510719+00', '2022-07-27 13:25:45.510719+00', 'Maggie''s Pancakes', 12182, '');
INSERT INTO 'tune' VALUES (14805, '2022-07-27 13:33:23.828913+00', '2022-07-27 13:33:23.828913+00', 'Ardgour Seamstress, The', 12183, '');
INSERT INTO 'tune' VALUES (14806, '2022-07-27 13:40:29.962409+00', '2022-07-27 13:40:29.962409+00', 'Miss Mary Stirling', 11792, '');
INSERT INTO 'tune' VALUES (12967, '2014-08-11 15:24:26.95629+00', '2022-07-27 17:23:32.626998+00', 'Andy Dejarlis Jig', 9998, 'From »Taigh na Teud« (according to the RSCDS Book 48 CD).');
INSERT INTO 'tune' VALUES (14807, '2022-07-27 17:30:58.061317+00', '2022-07-27 17:30:58.061317+00', 'Whisky Flight', 11790, '');
INSERT INTO 'tune' VALUES (6129, NULL, '2022-07-27 17:36:53.577253+00', 'John Spence', 9999, 'Possibly a duplicate of <<ddt:John Spence o'' Uyeasound#1862>>?');
INSERT INTO 'tune' VALUES (14808, '2022-07-27 17:48:44.743742+00', '2022-07-27 17:48:44.743742+00', 'Mr Sharp of Hoddom', 9999, 'Both the Traditional Tune Archive and the ABC Tune Finder have tunes with similar but not the same name. Exactly which one of those this tune is supposed to correspond to is unclear.');
INSERT INTO 'tune' VALUES (4904, NULL, '2022-07-27 19:38:33.447457+00', 'John Keith Laing', 2362, '');
INSERT INTO 'tune' VALUES (14810, '2022-07-27 19:44:07.933733+00', '2022-07-27 19:44:07.933733+00', 'Black Bear Jig', 11790, '');
INSERT INTO 'tune' VALUES (14811, '2022-07-27 19:45:04.746163+00', '2022-07-27 19:45:04.746163+00', 'Cruise on the Ouse', 11790, '');
INSERT INTO 'tune' VALUES (14809, '2022-07-27 19:42:03.105236+00', '2022-07-27 19:45:51.032707+00', 'Viva La Paz', 10908, '');
INSERT INTO 'tune' VALUES (14812, '2022-07-27 19:47:46.408378+00', '2022-07-27 19:47:46.408378+00', 'Two Steps, The', 10908, '');
INSERT INTO 'tune' VALUES (14813, '2022-07-27 19:53:58.765904+00', '2022-07-27 19:53:58.765904+00', 'Cheers Lyle', 2343, '');
INSERT INTO 'tune' VALUES (1339, NULL, '2022-07-27 20:04:58.074022+00', 'Mrs McLeod of Geaston', 9998, 'Presumably a duplicate of <<Mrs MacLeod of Gesto#4801>>?');
INSERT INTO 'tune' VALUES (4801, NULL, '2022-07-27 20:05:43.461784+00', 'Mrs MacLeod of Gesto', 9999, 'Presumably duplicated as <<Mrs McLeod of Geaston#1339>>?');
INSERT INTO 'tune' VALUES (14814, '2022-07-27 20:14:54.471987+00', '2022-07-27 20:14:54.471987+00', 'Contradiction', 9999, 'There are several alternative names for this given in <<https://tunearch.org/wiki/Contradiction_Reel_(1)_(The)>>.');
INSERT INTO 'tune' VALUES (14789, '2022-06-25 18:18:50.154991+00', '2022-12-31 17:39:28.429338+00', 'Alastair Wood''s Jig', 1527, '');
INSERT INTO 'tune' VALUES (14797, '2022-06-25 18:44:21.478284+00', '2022-12-31 17:39:55.869564+00', 'Delia Thornton''s Jig - New Pitsligo Quine', 1527, '');
INSERT INTO 'tune' VALUES (14769, '2022-06-25 16:28:37.34149+00', '2022-12-31 17:40:14.173245+00', 'Emily''s Reel', 1527, '');
INSERT INTO 'tune' VALUES (14792, '2022-06-25 18:37:33.32937+00', '2022-12-31 17:40:42.128685+00', 'Graham Johnston''s Reel', 1527, '');
INSERT INTO 'tune' VALUES (14793, '2022-06-25 18:38:38.064754+00', '2022-12-31 17:41:06.896387+00', 'Joy Johnston''s Reel', 1527, '');
INSERT INTO 'tune' VALUES (14787, '2022-06-25 18:17:26.381079+00', '2022-12-31 17:41:19.650655+00', 'Judith Smith''s Jig', 1527, '');
INSERT INTO 'tune' VALUES (14788, '2022-06-25 18:18:09.039019+00', '2022-12-31 17:41:30.488317+00', 'June Nelson''s Jig', 1527, '');
INSERT INTO 'tune' VALUES (14795, '2022-06-25 18:42:13.186077+00', '2022-12-31 17:41:44.710168+00', 'Margret Plummer''s Return to Scotland', 1527, '');
INSERT INTO 'tune' VALUES (14796, '2022-06-25 18:42:54.433058+00', '2022-12-31 17:42:09.34449+00', 'May Cook''s Jig - Fraserburgh Quine', 1527, '');
INSERT INTO 'tune' VALUES (14791, '2022-06-25 18:25:47.275927+00', '2022-12-31 17:42:57.619313+00', 'Sandra Wallace''s Strathspey', 1527, '');
INSERT INTO 'tune' VALUES (14790, '2022-06-25 18:24:55.527843+00', '2022-12-31 17:43:09.203968+00', 'Sheila Trafford''s Strathspey of Morpeth', 1527, '');
INSERT INTO 'tune' VALUES (14799, '2022-06-25 18:51:11.613796+00', '2022-12-31 17:43:20.654566+00', 'St Andrew Society of Rio De Janeiro, The', 1527, '');
INSERT INTO 'tune' VALUES (6812, NULL, '2022-07-27 21:03:48.214756+00', 'Forth Brig Hornpipe, The', 9998, '<<https://thesession.org/tunes/5628>> mentions this as composed by James Scott Skinner.');
INSERT INTO 'tune' VALUES (14815, '2022-07-30 12:06:13.411778+00', '2022-07-30 12:06:13.411778+00', 'Golden Days', 2335, '');
INSERT INTO 'tune' VALUES (14816, '2022-07-30 12:13:25.558541+00', '2022-07-30 12:13:25.558541+00', 'Miss Baker''s Choice', 2335, '');
INSERT INTO 'tune' VALUES (14817, '2022-08-03 18:23:16.620764+00', '2022-08-03 18:23:16.620764+00', 'Crook Inn, The', 1582, '');
INSERT INTO 'tune' VALUES (14818, '2022-08-06 14:38:22.083832+00', '2022-08-06 14:38:22.083832+00', 'Emma', 3710, '');
INSERT INTO 'tune' VALUES (14819, '2022-08-06 14:41:41.047428+00', '2022-08-06 14:41:41.047428+00', 'George Atkinson Polka', 1709, '');
INSERT INTO 'tune' VALUES (5299, NULL, '2022-08-06 14:44:44.580987+00', 'Craig Royal Strathspey', 1720, 'Probable duplicate of <<ddt:#9342>>.');
INSERT INTO 'tune' VALUES (9342, NULL, '2022-08-06 14:45:06.870075+00', 'Craigroyal Strathspey', 1720, 'Probable duplicate of <<ddt:#5299>>.');
INSERT INTO 'tune' VALUES (14820, '2022-08-06 14:45:54.025546+00', '2022-08-06 14:45:54.025546+00', 'Miss Jacqueline Dixon', 1720, '');
INSERT INTO 'tune' VALUES (14821, '2022-08-06 15:02:04.852591+00', '2022-08-06 15:02:38.942164+00', 'Clutha Hornpipe, The', 9999, '');
INSERT INTO 'tune' VALUES (14822, '2022-08-06 15:46:13.971604+00', '2022-08-06 15:46:13.971604+00', 'Dancing Granny, The', 1709, '');
INSERT INTO 'tune' VALUES (14823, '2022-08-06 15:50:07.024945+00', '2022-08-06 15:50:07.024945+00', 'All Along Loch Long', 12187, '');
INSERT INTO 'tune' VALUES (12416, '2013-01-17 15:05:14.345345+00', '2022-08-06 15:53:06.797658+00', 'Muriel Bell', 1579, '');
INSERT INTO 'tune' VALUES (11855, '2011-11-25 23:00:00+00', '2022-08-06 15:56:50.288612+00', 'James Forester Rankine', 1533, 'Probable duplicate of <<ddt:#763>>.');
INSERT INTO 'tune' VALUES (1821, NULL, '2022-08-06 16:03:13.659748+00', 'Willafjord', 9999, 'According to Edwin Werner in <<http://my.strathspey.org/dd/issue/1765/|issue 1765>> this tune is a "whalin'' reel" collected by Tom Anderson (not composed by him).');
INSERT INTO 'tune' VALUES (7240, NULL, '2022-08-06 16:07:29.145139+00', 'Kesh Jig, The', 9999, '');
INSERT INTO 'tune' VALUES (14824, '2022-08-06 16:09:07.916828+00', '2022-08-06 16:09:07.916828+00', 'Whistling Postman, The', 9998, '');
INSERT INTO 'tune' VALUES (14825, '2022-08-06 16:16:13.231988+00', '2022-08-06 16:16:13.231988+00', 'Torbeag', 1811, '');
INSERT INTO 'tune' VALUES (14826, '2022-08-10 23:39:39.595645+00', '2022-08-10 23:42:00.36493+00', 'Mall in St. James''s Park, The', 11781, '');
INSERT INTO 'tune' VALUES (14827, '2022-08-10 23:49:02.499688+00', '2022-08-10 23:49:02.499688+00', 'Sober Piper, The', 12036, '');
INSERT INTO 'tune' VALUES (13944, '2018-09-04 11:37:11.951509+00', '2022-08-14 07:45:34.624277+00', 'Yellowing Leaves', 3179, '');
INSERT INTO 'tune' VALUES (14828, '2022-08-21 16:40:03.621077+00', '2022-08-21 16:40:03.621077+00', 'Let''s Have a Ceilidh', 12190, '');
INSERT INTO 'tune' VALUES (14829, '2022-08-21 16:43:43.071003+00', '2022-08-21 16:43:43.071003+00', 'Vega Mandolin', 1633, '');
INSERT INTO 'tune' VALUES (14830, '2022-08-21 16:45:32.154928+00', '2022-08-21 16:45:32.154928+00', 'Sarah Lawrie', 12191, '');
INSERT INTO 'tune' VALUES (14831, '2022-08-21 16:46:42.299302+00', '2022-08-21 16:46:42.299302+00', 'Islay Ball, The', 12192, '');
INSERT INTO 'tune' VALUES (14832, '2022-08-21 16:48:27.409974+00', '2022-08-21 16:48:27.409974+00', 'Men of Argyll', 11522, '');
INSERT INTO 'tune' VALUES (14833, '2022-08-21 16:49:48.928327+00', '2022-08-21 16:49:48.928327+00', 'Gallant Forty-Twa, The', 9999, '');
INSERT INTO 'tune' VALUES (14834, '2022-08-21 16:53:16.546723+00', '2022-08-21 16:53:16.546723+00', 'MacDonald''s Fancy', 9999, 'This could by any of “Captain MacDonald''s Fancy”, ”Donald MacDonald''s Fancy”, “Dr MacDonald''s Fancy”, “Roddy MacDonald''s Fancy”, or a different tune altogether.');
INSERT INTO 'tune' VALUES (14835, '2022-08-21 16:54:42.622188+00', '2022-08-21 16:54:42.622188+00', 'Bear in the Cage', 2238, '');
INSERT INTO 'tune' VALUES (14836, '2022-08-21 16:56:11.022186+00', '2022-08-21 16:56:11.022186+00', 'Morag Beag', 9999, '');
INSERT INTO 'tune' VALUES (14837, '2022-08-21 16:59:07.908677+00', '2022-08-21 16:59:07.908677+00', 'Barbara Needham''s', 9999, '');
INSERT INTO 'tune' VALUES (14838, '2022-08-21 16:59:41.890238+00', '2022-08-21 16:59:41.890238+00', 'Miller''s Maggot', 9999, '');
INSERT INTO 'tune' VALUES (6110, NULL, '2022-08-21 17:07:21.71583+00', 'Lass o'' Lowrie, The', 12193, 'Composer according to the liner notes of <<dda:Dance, Sing and Rejoice>>.');
INSERT INTO 'tune' VALUES (14839, '2022-08-21 17:12:33.489853+00', '2022-08-21 17:12:33.489853+00', 'When Geordie Plays His Fiddle', 12194, '');
INSERT INTO 'tune' VALUES (14840, '2022-08-21 17:13:05.979364+00', '2022-08-21 17:13:05.979364+00', 'Night in the Glen', 2238, '');
INSERT INTO 'tune' VALUES (14841, '2022-08-21 17:18:47.408114+00', '2022-08-21 17:18:47.408114+00', 'Dressed Ship, The', 9999, '');
INSERT INTO 'tune' VALUES (9995, NULL, '2022-08-21 17:20:40.88999+00', 'Bonnie Ship, the Diamond, The', 9999, '');
INSERT INTO 'tune' VALUES (14843, '2022-08-21 17:21:58.273242+00', '2022-08-21 17:21:58.273242+00', 'Highlander''s Return, The', 9999, '');
INSERT INTO 'tune' VALUES (14844, '2022-08-21 18:30:48.71184+00', '2022-08-21 18:30:48.71184+00', 'Eric Ferguson, E-crib Master', 3179, 'Dedicated to Eric Ferguson on his retirement from decades of active service as a member of the strathspey database editing team and as author of thousands of E-cribs.');
INSERT INTO 'tune' VALUES (14846, '2022-08-22 23:02:44.749305+00', '2022-08-22 23:02:44.749305+00', 'Miss MacDonald of Tote', 12197, '');
INSERT INTO 'tune' VALUES (14847, '2022-08-22 23:06:05.897399+00', '2022-08-22 23:06:05.897399+00', 'Margaret Chisholm''s Jig', 9999, 'From Cape Breton. Possibly the same as <<ddt:Margaret Chisolm>>.');
INSERT INTO 'tune' VALUES (14848, '2022-08-22 23:13:42.213376+00', '2022-08-22 23:13:42.213376+00', 'Tir mo Ghraidh', 12198, '');
INSERT INTO 'tune' VALUES (14849, '2022-08-22 23:15:16.438064+00', '2022-08-22 23:15:16.438064+00', 'Cronan Charsaig', 12199, '');
INSERT INTO 'tune' VALUES (7022, NULL, '2022-08-22 23:18:04.815035+00', 'Mr & Mrs McShane of Houston', 1575, '');
INSERT INTO 'tune' VALUES (14850, '2022-08-22 23:26:08.51179+00', '2022-08-22 23:26:08.51179+00', 'I Feel Pretty', 12200, 'From *West Side Story*.');
INSERT INTO 'tune' VALUES (14851, '2022-08-22 23:36:53.655953+00', '2022-08-22 23:36:53.655953+00', 'Donald McLeod''s Reel', 2225, 'Possibly identical to <<ddt:Donald McLeod>> or <<ddt:Dougie Mcleod>>.');
INSERT INTO 'tune' VALUES (2316, NULL, '2022-08-22 23:39:08.789189+00', 'Itchy Fingers', 11945, 'Often thought to be composed by <<ddp:Mathieson, P/M Robert#1673>> who arranged and published it, but actually composed by Rab Pinkman. See <<https://thesession.org/tunes/3931>> and also reported in <<https://my.strathspey.org/dd/issue/2093/|issue 2093>>.');
INSERT INTO 'tune' VALUES (14852, '2022-08-22 23:42:07.354113+00', '2022-08-22 23:42:07.354113+00', 'Pretty Polly Stewart', 9999, '');
INSERT INTO 'tune' VALUES (14853, '2022-08-22 23:43:03.644764+00', '2022-08-22 23:43:03.644764+00', 'Pretty Little Cindy', 9999, '');
INSERT INTO 'tune' VALUES (14732, '2022-04-29 22:11:14.484975+00', '2022-09-02 02:07:52.052966+00', 'Memories of Jimmy Thom', 1631, 'Jimmy Thom was a good friend of Ian Robertson, the composer of the tune, and farmer from Guildtown just outside Perth.');
INSERT INTO 'tune' VALUES (14854, '2022-09-04 08:09:15.535844+00', '2022-09-04 08:09:15.535844+00', 'Szilvia''s Summer School Birthday', 11858, '');
INSERT INTO 'tune' VALUES (14855, '2022-09-13 15:01:44.722171+00', '2022-09-13 15:01:44.722171+00', 'Jig for Jessie', 11766, '');
INSERT INTO 'tune' VALUES (14856, '2022-09-27 12:00:33.187161+00', '2022-09-27 12:00:33.187161+00', 'John Renton of Inveraray', 1575, '');
INSERT INTO 'tune' VALUES (14857, '2022-10-01 11:36:06.744671+00', '2022-10-01 11:36:06.744671+00', 'Stefan Turns Twenty', 3179, '');
INSERT INTO 'tune' VALUES (14858, '2022-10-01 11:37:03.878804+00', '2022-10-01 11:37:03.878804+00', 'Tomorrow the Sun will Shine Again', 3179, '');
INSERT INTO 'tune' VALUES (14859, '2022-10-01 11:38:29.643938+00', '2022-10-01 11:38:29.643938+00', 'Keith''s 5000', 3179, 'Inscribed "For Keith Rose, to honour his contribution to SCD through his dance diagrams."');
INSERT INTO 'tune' VALUES (14862, '2022-10-01 11:51:02.781707+00', '2022-10-01 11:51:02.781707+00', 'My Teacher Taught Me', 3179, '');
INSERT INTO 'tune' VALUES (14863, '2022-10-01 11:54:45.009162+00', '2022-10-01 11:54:45.009162+00', 'Lailah at the Vet', 3179, '');
INSERT INTO 'tune' VALUES (14865, '2022-10-01 11:59:39.471327+00', '2022-10-01 11:59:39.471327+00', 'Smile on Your Face, The', 3179, '');
INSERT INTO 'tune' VALUES (14866, '2022-10-01 12:00:35.251306+00', '2022-10-01 12:00:35.251306+00', 'Look on the Bright Side', 3179, '');
INSERT INTO 'tune' VALUES (14868, '2022-10-01 12:09:05.205433+00', '2022-10-01 12:09:05.205433+00', 'One Hundred in Fifteen', 3179, 'Wouter writes "I started composing for SCD in 2003 and it took me 15 years to reach tune number 100"');
INSERT INTO 'tune' VALUES (14871, '2022-10-01 12:13:30.254464+00', '2022-10-01 12:15:00.43364+00', 'Joenie''s Jig', 3179, 'In fond memory of Johannes (Joenie) Venter, 26 May 1956 - 25 June 2021.

For all those who loved him and will miss his presence.');
INSERT INTO 'tune' VALUES (14872, '2022-10-01 12:16:42.40592+00', '2022-10-01 12:16:42.40592+00', 'Take My Hand', 3179, '');
INSERT INTO 'tune' VALUES (14845, '2022-08-21 18:38:16.945923+00', '2022-10-09 13:03:25.566855+00', 'Baker''s Half-Century, A', 3179, '');
INSERT INTO 'tune' VALUES (14864, '2022-10-01 11:56:12.668827+00', '2022-10-09 14:31:57.533118+00', 'Birders Hornpipe, The', 3179, '');
INSERT INTO 'tune' VALUES (14873, '2022-10-01 12:17:26.392136+00', '2022-10-09 14:36:32.714637+00', 'Bitter Sweet', 3179, '');
INSERT INTO 'tune' VALUES (14870, '2022-10-01 12:12:38.170738+00', '2022-10-09 16:20:14.172953+00', 'Daffadowndillies', 3179, '');
INSERT INTO 'tune' VALUES (14861, '2022-10-01 11:41:49.730207+00', '2022-10-10 12:31:04.478899+00', 'Desmond Tutu''s Legacy of Love', 3179, 'Inscribed "In honour of the late Archbishop Desmond Tutu, who passed away on 26 December 2021"');
INSERT INTO 'tune' VALUES (14869, '2022-10-01 12:12:00.913396+00', '2022-10-10 16:08:34.91098+00', 'Fee Fi Foh', 3179, '');
INSERT INTO 'tune' VALUES (14860, '2022-10-01 11:39:39.145993+00', '2022-10-11 03:12:36.218497+00', 'Fond Farewell', 3179, 'Inscribed "In fond memory of Hennie Grobler. For Darlene"');
INSERT INTO 'tune' VALUES (14867, '2022-10-01 12:01:16.460895+00', '2022-10-13 06:17:10.977859+00', 'Happy Father''s Day', 3179, '');
INSERT INTO 'tune' VALUES (5962, NULL, '2022-12-16 21:19:08.087182+00', 'Old Scotch Mother', 3152, 'This name is the tunes first appearance in 1956 <<https://www.discogs.com/artist/5186663-Joseph-Maxwell>>; it has been released under numerous names since.');
INSERT INTO 'tune' VALUES (5320, NULL, '2022-12-26 21:18:54.556125+00', 'Mursheen Durkin', 9999, 'Both name versions exist and are assigned to recordings, "Mursheen" (used more often) and "Muirsheen".');
INSERT INTO 'tune' VALUES (6343, NULL, '2022-12-26 21:44:00.028652+00', 'Battle of the Somme', 12248, '');
INSERT INTO 'tune' VALUES (14462, '2021-07-03 14:53:16.356684+00', '2022-10-01 12:20:54.851277+00', 'Ho! Tom Bombadil', 3179, 'Wouter writes "I have a habit of setting to music bits of verse I encounter in the books I read.

Here I have joined two of those, both relating to Tom Bombadil from The Lord of the Rings,

in a bright little reel tune."');
INSERT INTO 'tune' VALUES (14874, '2022-10-01 12:22:37.203571+00', '2022-10-01 12:22:37.203571+00', 'I Believe in a Better Tomorrow', 3179, '');
INSERT INTO 'tune' VALUES (14875, '2022-10-01 12:23:45.196373+00', '2022-10-01 12:23:45.196373+00', 'Silver Linings', 3179, '');
INSERT INTO 'tune' VALUES (14877, '2022-10-01 12:26:15.484206+00', '2022-10-01 12:26:15.484206+00', 'Hobbit Hole, The', 11521, '');
INSERT INTO 'tune' VALUES (14878, '2022-10-01 12:28:05.805637+00', '2022-10-01 12:28:05.805637+00', 'Prosecco is in the Fridge, The', 3179, 'My 200th tune');
INSERT INTO 'tune' VALUES (14883, '2022-10-01 13:08:11.212167+00', '2022-10-01 13:08:11.212167+00', 'Peter''s LMP', 3179, '');
INSERT INTO 'tune' VALUES (14884, '2022-10-01 13:09:41.301201+00', '2022-10-01 13:09:41.301201+00', 'Platinum Jig, A', 3179, '');
INSERT INTO 'tune' VALUES (14885, '2022-10-01 13:11:12.665685+00', '2022-10-01 13:11:12.665685+00', 'Reel for Bessie, A', 3179, '');
INSERT INTO 'tune' VALUES (14890, '2022-10-01 13:17:28.71682+00', '2022-10-01 13:17:28.71682+00', 'Miss Sophie Aletta Thompson', 3179, '');
INSERT INTO 'tune' VALUES (14891, '2022-10-01 13:18:35.333366+00', '2022-10-01 13:18:35.333366+00', 'No April Fool', 3179, '');
INSERT INTO 'tune' VALUES (14892, '2022-10-01 13:19:36.743727+00', '2022-10-01 13:19:36.743727+00', 'Stitches in Time', 11521, '');
INSERT INTO 'tune' VALUES (14893, '2022-10-01 13:20:50.246572+00', '2022-10-01 13:20:50.246572+00', 'Silvia Miskoe''s Strathspey', 3179, '');
INSERT INTO 'tune' VALUES (14894, '2022-10-01 13:22:26.479313+00', '2022-10-01 13:22:26.479313+00', 'Winter Rose, A', 3179, '');
INSERT INTO 'tune' VALUES (14887, '2022-10-01 13:13:08.85377+00', '2022-10-01 18:14:16.435565+00', 'Under a Gingko Tree', 3179, 'Inscribed "For Robb Quint, who is always in inspiration".');
INSERT INTO 'tune' VALUES (14889, '2022-10-01 13:16:02.843011+00', '2022-10-09 10:26:44.273144+00', 'All the King''s Horses', 3179, '');
INSERT INTO 'tune' VALUES (14702, '2022-03-06 10:42:34.11636+00', '2022-10-09 11:11:16.459453+00', 'And When it Rains...', 3179, 'Rain is a metaphor on many levels indicating sorrow, cleansing, growth, and hope. All of these would be applicable in our world today.



In support of peace, and dedicated to all those bullied by the tyrants of this world.

');
INSERT INTO 'tune' VALUES (1487, NULL, '2022-12-10 21:26:16.744063+00', 'Push about the Jorum', 9999, 'Previously, the database connected this tune to <<ddp:Gow, Niel#1518>>, but research shows it is rather a traditional tune, composer unknown.

<<https://tunearch.org/wiki/Push_about_the_Jorum_(1)>>');
INSERT INTO 'tune' VALUES (14882, '2022-10-01 12:33:09.99871+00', '2022-10-09 14:50:56.877197+00', 'Brandied Cherries', 3179, '');
INSERT INTO 'tune' VALUES (14886, '2022-10-01 13:11:46.688988+00', '2022-10-09 14:59:07.594667+00', '02_02_2020', 3179, '');
INSERT INTO 'tune' VALUES (14876, '2022-10-01 12:24:22.972393+00', '2022-10-09 15:07:34.426859+00', 'Brave Ladies', 3179, 'Composed on South Africa''s National Woman''s Day');
INSERT INTO 'tune' VALUES (14880, '2022-10-01 12:30:06.332571+00', '2022-10-09 15:16:57.082363+00', 'By the C Hornpipe', 3179, '');
INSERT INTO 'tune' VALUES (14888, '2022-10-01 13:14:02.081916+00', '2022-10-09 16:16:52.476197+00', 'Calcifer, Sophie and the Heart of Howl', 3179, '');
INSERT INTO 'tune' VALUES (14901, '2022-12-11 21:01:50.594108+00', '2022-12-11 21:04:26.206235+00', 'Old Codger', 9998, '');
INSERT INTO 'tune' VALUES (14902, '2022-12-11 21:04:38.666233+00', '2022-12-11 21:04:38.666233+00', 'On Top of the World', 9998, '');
INSERT INTO 'tune' VALUES (14879, '2022-10-01 12:29:01.122262+00', '2022-10-09 17:11:28.974529+00', 'Boys High Café Concert', 3179, '');
INSERT INTO 'tune' VALUES (10648, '2009-11-20 23:00:00+00', '2022-12-11 23:42:45.513585+00', 'George Carmichael''s Strathspey', 1646, 'Originally assigned to <<ddp:Cameron, Alan#2841>> in SCDDB. However it is listed in <<https://oldschoolbeauly.com/products/angus-cameron-of-kirriemuir>> as by <<ddp:Cameron, Angus#1646>>. See also <<https://my.strathspey.org/dd/issue/1782/|issue 1782>>.');
INSERT INTO 'tune' VALUES (14881, '2022-10-01 12:32:31.034234+00', '2022-10-09 22:39:19.900558+00', 'Departures', 3179, '');
INSERT INTO 'tune' VALUES (13874, '2018-04-05 12:00:47.303215+00', '2022-10-10 15:40:14.014974+00', 'Dragons in Flight', 3179, '');
INSERT INTO 'tune' VALUES (14039, '2019-05-10 13:19:24.85359+00', '2022-10-10 16:02:27.046576+00', 'Embracing Difference', 3179, 'This tune is based on the musical traditions of Eastern Europe');
INSERT INTO 'tune' VALUES (13875, '2018-04-05 17:35:28.653363+00', '2022-10-11 03:16:47.617136+00', 'From A Dream', 3179, '');
INSERT INTO 'tune' VALUES (14895, '2022-10-25 22:56:01.111536+00', '2022-10-25 22:56:01.111536+00', 'Carrots and Cabbages', 11793, '');
INSERT INTO 'tune' VALUES (9907, NULL, '2022-10-29 17:26:37.845089+00', 'Mr & Mrs Rayworth of Mousemill House', 2253, '');
INSERT INTO 'tune' VALUES (1297, NULL, '2022-11-01 17:59:01.037828+00', 'Mrs Campbell of Monzies', 1519, 'This is entered in SCDDB as "Mrs Campbell of Monzies" whereas the instructions for Two to One in RSCDS Book 28 mention "Miss Campbell of Monzies’s Reel". To be checked one day...');
INSERT INTO 'tune' VALUES (14896, '2022-11-18 20:12:34.928769+00', '2022-11-18 20:12:34.928769+00', 'Black Joke, The', 9999, 'In 6 and 10 bar phrases.');
INSERT INTO 'tune' VALUES (444, NULL, '2022-11-20 14:24:12.334865+00', 'Duke of Gordon''s Birthday, The', 1516, 'Seems to be a duplicate of <<ddt:#445>>? Remove this one?');
INSERT INTO 'tune' VALUES (9683, NULL, '2022-12-04 19:00:50.202085+00', 'Davy Ketchin "The Jazz Piper"', 3220, '');
INSERT INTO 'tune' VALUES (14897, '2022-12-08 15:45:24.864404+00', '2022-12-08 15:45:24.864404+00', 'Take Your Partners', 12216, '');
INSERT INTO 'tune' VALUES (14898, '2022-12-08 15:46:01.007103+00', '2022-12-08 15:46:01.007103+00', 'Collector''s Choice', 12216, '');
INSERT INTO 'tune' VALUES (14899, '2022-12-08 15:46:22.832762+00', '2022-12-08 15:46:22.832762+00', 'Castlemaine', 12216, '');
INSERT INTO 'tune' VALUES (4651, NULL, '2022-12-08 16:34:25.0535+00', 'Vera Hughes'' Fancy', 1558, '');
INSERT INTO 'tune' VALUES (6254, NULL, '2022-12-08 19:32:13.519061+00', 'Paardeburg', 9998, 'Some sources suggest the composer is <<ddp:McLellan , John#11522>>, Dunoon. However, there seems to be no ultimate confirmation for it.');
INSERT INTO 'tune' VALUES (7098, NULL, '2022-12-08 19:52:05.620437+00', 'Silverton Polka, The', 9999, 'From <<https://my.strathspey.org/dd/issue/2199/|issue 2199>>:

*Believed to be traditional. Copy held in national library Edinburgh. This states:- Music published by Mozart and Allan Glasgow between 1925 and 1950. As played by Jimmy Shand arranged by Ian Macleish.*

Peter Wyper recorded a 10'''' shellac in 1915 (Regal - G 7142).');
INSERT INTO 'tune' VALUES (6387, NULL, '2022-12-08 23:13:13.037237+00', 'Bonawe Highlanders, The', 9999, '');
INSERT INTO 'tune' VALUES (393, NULL, '2022-12-09 09:31:25.011019+00', 'Dod House', 9998, 'This tune was published in the "Glen Collection", page 27.');
INSERT INTO 'tune' VALUES (9126, NULL, '2022-12-09 11:22:26.513268+00', 'Streaker Hornpipe, The', 3150, 'Seems to be variously known as The Streaker or The Streaker Hornpipe (<<https://my.strathspey.org/dd/issue/828/|issue 828>>).');
INSERT INTO 'tune' VALUES (10581, '2009-11-17 23:00:00+00', '2022-12-11 23:47:05.668486+00', 'Tony Reid', 1646, 'Originally assigned to <<ddp:Cameron, Alan#2841>> in SCDDB. However the list of tunes by <<ddp:Cameron, Angus#1646>> given in <<https://oldschoolbeauly.com/products/angus-cameron-of-kirriemuir>> includes Tony Reid of Balnakilly. So this tune entry is probably a duplicate of <<ddt:Tony Reid of Balnakilly#1777>> (to be checked). Anyway this "Tony Reid" entry is now assigned to Angus Cameron. See also <<https://my.strathspey.org/dd/issue/1782/|issue 1782>>.');
INSERT INTO 'tune' VALUES (1656, NULL, '2022-12-09 20:02:17.165586+00', 'Steamboat Hornpipe, The', 9999, 'This tune is a reel, other than "The Steamboat Quickstep" which is a jig.');
INSERT INTO 'tune' VALUES (5786, NULL, '2022-12-09 20:02:41.643048+00', 'Steamboat Quickstep, The', 9999, 'This is a jig, other than "The Steamboat [Hornpipe]" which is a reel.');
INSERT INTO 'tune' VALUES (6865, NULL, '2022-12-09 21:12:28.828106+00', 'March to Reform Street, The', 1615, 'Published in "The New Atholl Collection", 1986');
INSERT INTO 'tune' VALUES (14900, '2022-12-10 20:04:54.981519+00', '2022-12-10 20:04:54.981519+00', 'Miss Cox', 9999, '');
INSERT INTO 'tune' VALUES (2943, NULL, '2022-12-12 23:08:34.309648+00', 'Top o'' Ben Lomond, The', 9999, '');
INSERT INTO 'tune' VALUES (2746, NULL, '2022-12-14 17:45:30.161191+00', 'Parks of Kilbirnie, The', 9999, 'This tune is most likely a duplicate to <<https://my.strathspey.org/dd/tune/2746/>> where the city name is misspelled as "Kilburnie", yet there seem to exist tune sheets with that spelling. See notes at the linked duplicate. Needs further checking.');
INSERT INTO 'tune' VALUES (2751, NULL, '2022-12-14 17:45:45.590279+00', 'Parks of Kilburnie, The', 9999, '"Kilburnie" is not an existing city name, but there are tune sheets for this exakt name. This tune however is most likely a duplicate to <<https://my.strathspey.org/dd/tune/2751/>> and might have been misspelled in the past, even in official publications and recordings. Needs further checking.');
INSERT INTO 'tune' VALUES (14903, '2022-12-15 11:50:31.256809+00', '2022-12-15 11:50:31.256809+00', 'Oh, to Joy!', 1763, '');
INSERT INTO 'tune' VALUES (14904, '2022-12-15 12:24:43.9623+00', '2022-12-15 12:24:43.9623+00', 'Laddie Lie Near Me', 9998, 'Anonymous, circa 1750s, according to <<https://my.strathspey.org/dd/issue/2962/|issue 2962>>.');
INSERT INTO 'tune' VALUES (470, NULL, '2022-12-16 14:36:15.753677+00', 'Duran Rangers', 9999, 'See the <<https://tunearch.org/wiki/Annotation:Durham_Rangers|Traditional Tune Archive>> for a discussion of the tune''s title and provenance.');
INSERT INTO 'tune' VALUES (6282, NULL, '2022-12-26 21:42:52.985275+00', '8th Argyll''s Farewell to the 116th Regt. de Ligne', 12248, '');
INSERT INTO 'tune' VALUES (4055, NULL, '2022-12-16 23:34:12.908233+00', 'Lichted Ha'', The', 2347, 'Iain Gent writes:  "I have an old photocopy of music which states attributed to Burns." Jo Pickering states in issue 617 that this tune "... appears to be a quote from Burns''s poem Mary Morrison - ''Yestreen when to the trembling string the dance gaed through the lichted ha''''. It is to be sung to the tune Duncan Davison."');
INSERT INTO 'tune' VALUES (6969, NULL, '2022-12-18 17:43:29.682627+00', 'Horsey! Horsey!', 2249, '');
INSERT INTO 'tune' VALUES (10864, '2009-12-01 23:00:00+00', '2022-12-19 16:29:11.697386+00', 'Jig for Judi', 1592, 'Spelling confirmed by author 2022-12-19.');
INSERT INTO 'tune' VALUES (5837, NULL, '2022-12-19 16:30:47.777295+00', 'Hutchie''s Bash', 1592, 'Spelling confirmed by author 2022-12-19.');
INSERT INTO 'tune' VALUES (10129, '2009-08-02 22:00:00+00', '2022-12-19 16:35:18.152702+00', 'Jessie Stuart''s Welcome in Dufftown', 1592, 'Spelling confirmed by author 2022-12-19. All aliases are previous incorrect name entries in our database.');
INSERT INTO 'tune' VALUES (2153, NULL, '2022-12-19 22:15:56.232886+00', 'Earl of Dalkeith', 1518, '"Earl of Dalkeith" and "Dalkeith''s Strathspey" are the same tune composed by Niel Gow. The former original  was written as a reel, the latter was rearranged by Dr. Herbert Wiseman as a strathspey version for RSCDS book 9. ');
INSERT INTO 'tune' VALUES (364, NULL, '2022-12-19 22:16:09.272754+00', 'Dalkeith''s Strathspey', 1518, '"Earl of Dalkeith" and "Dalkeith''s Strathspey" are the same tune composed by Niel Gow. The former original  was written as a reel, the latter was rearranged by Dr. Herbert Wiseman as a strathspey version for RSCDS book 9. ');
INSERT INTO 'tune' VALUES (12492, '2013-02-22 15:59:04.93358+00', '2022-12-19 22:39:48.907345+00', 'Waiting for the Robert E. Lee', 10754, 'The (shortened) alias is used on a CD recording.');
INSERT INTO 'tune' VALUES (14905, '2022-12-20 10:56:01.472789+00', '2022-12-20 10:56:01.472789+00', 'Christopher Columbus', 12229, 'This is a jazz standard.');
INSERT INTO 'tune' VALUES (14906, '2022-12-20 15:14:44.539004+00', '2022-12-20 15:14:44.539004+00', 'It Don''t Mean a Thing (If It Ain''t Got That Swing)', 12230, 'This is a jazz standard.');
INSERT INTO 'tune' VALUES (14907, '2022-12-20 15:18:05.353318+00', '2022-12-20 15:18:05.353318+00', 'Makin'' Whoopee', 12231, 'This is a jazz/blues song.');
INSERT INTO 'tune' VALUES (14908, '2022-12-20 19:56:53.192716+00', '2022-12-20 19:56:53.192716+00', 'Pinetop''s Blues', 12232, 'This is a blues song.');
INSERT INTO 'tune' VALUES (14909, '2022-12-20 20:20:46.289609+00', '2022-12-20 20:20:46.289609+00', 'I''ve Found a New Baby', 12233, 'This is a jazz standard.');
INSERT INTO 'tune' VALUES (14910, '2022-12-20 20:23:41.211786+00', '2022-12-20 20:23:41.211786+00', 'Gee, Baby, Ain''t I Good to You', 12234, 'This is a jazz standard.');
INSERT INTO 'tune' VALUES (14911, '2022-12-20 20:25:48.042422+00', '2022-12-20 20:25:48.042422+00', 'Nobody Knows You When You''re Down and Out', 12235, 'This is a blues standard.');
INSERT INTO 'tune' VALUES (14912, '2022-12-20 20:29:38.909882+00', '2022-12-20 20:29:38.909882+00', 'China Boy', 12236, 'This is a vaudeville song and jazz standard.');
INSERT INTO 'tune' VALUES (14913, '2022-12-20 20:32:50.742407+00', '2022-12-20 20:32:50.742407+00', 'Honky-Tonk Château', 12237, 'This is a jazz tune.');
INSERT INTO 'tune' VALUES (14914, '2022-12-20 20:35:33.55349+00', '2022-12-20 20:35:33.55349+00', 'Hobo''s Blues', 12237, 'This is a jazz tune.');
INSERT INTO 'tune' VALUES (14915, '2022-12-20 22:52:01.612509+00', '2022-12-20 22:52:01.612509+00', 'Grand Teton', 9998, '');
INSERT INTO 'tune' VALUES (14916, '2022-12-20 22:56:01.561662+00', '2022-12-20 22:56:01.561662+00', 'Grandpa''s Shrine', 9998, '');
INSERT INTO 'tune' VALUES (14917, '2022-12-20 22:56:34.188757+00', '2022-12-20 22:56:34.188757+00', 'Music for a Found Harmonium', 9998, '');
INSERT INTO 'tune' VALUES (14918, '2022-12-20 22:57:07.93579+00', '2022-12-20 22:57:07.93579+00', 'Kitchen Girl', 9998, '');
INSERT INTO 'tune' VALUES (14919, '2022-12-20 22:58:17.704282+00', '2022-12-20 22:58:17.704282+00', 'Cherry Tree', 9998, '');
INSERT INTO 'tune' VALUES (14920, '2022-12-20 22:59:39.225288+00', '2022-12-20 22:59:39.225288+00', 'Return to the Stewartry', 9998, '');
INSERT INTO 'tune' VALUES (14921, '2022-12-20 23:00:05.107539+00', '2022-12-20 23:00:05.107539+00', 'Packing up George', 9998, '');
INSERT INTO 'tune' VALUES (14922, '2022-12-20 23:00:35.389906+00', '2022-12-20 23:00:35.389906+00', 'Pass the Peper', 9998, '');
INSERT INTO 'tune' VALUES (14923, '2022-12-20 23:01:34.997532+00', '2022-12-20 23:01:34.997532+00', 'Oddville Cupola', 9998, '');
INSERT INTO 'tune' VALUES (14924, '2022-12-20 23:02:09.94439+00', '2022-12-20 23:02:09.94439+00', 'Flying Home to Shelley', 9998, '');
INSERT INTO 'tune' VALUES (14925, '2022-12-20 23:03:03.060022+00', '2022-12-20 23:03:03.060022+00', 'Trout Transmigration', 9998, '');
INSERT INTO 'tune' VALUES (14926, '2022-12-20 23:04:19.434592+00', '2022-12-20 23:04:19.434592+00', 'Toy Train Wreck', 9998, '');
INSERT INTO 'tune' VALUES (14927, '2022-12-20 23:04:59.100169+00', '2022-12-20 23:04:59.100169+00', 'Metaphysical Circus', 9998, '');
INSERT INTO 'tune' VALUES (14928, '2022-12-20 23:05:55.369158+00', '2022-12-20 23:05:55.369158+00', 'Julia Delaney', 9998, '');
INSERT INTO 'tune' VALUES (14929, '2022-12-20 23:07:42.065119+00', '2022-12-20 23:07:42.065119+00', 'Reel De Montreal', 9998, '');
INSERT INTO 'tune' VALUES (14930, '2022-12-20 23:08:06.978619+00', '2022-12-20 23:08:06.978619+00', 'Landslide', 9998, '');
INSERT INTO 'tune' VALUES (14931, '2022-12-20 23:08:40.267569+00', '2022-12-20 23:08:40.267569+00', 'Indescribable Blue, The', 9998, '');
INSERT INTO 'tune' VALUES (14932, '2022-12-20 23:20:36.699278+00', '2022-12-20 23:20:36.699278+00', 'Ice Palace', 9998, '');
INSERT INTO 'tune' VALUES (14933, '2022-12-20 23:21:09.247783+00', '2022-12-20 23:21:09.247783+00', 'He Gives You Wings', 9998, '');
INSERT INTO 'tune' VALUES (14934, '2022-12-20 23:21:35.527355+00', '2022-12-20 23:21:35.527355+00', 'Madame Neruda', 9998, '');
INSERT INTO 'tune' VALUES (14935, '2022-12-20 23:22:28.640143+00', '2022-12-20 23:22:28.640143+00', 'Round the Horn', 9998, '');
INSERT INTO 'tune' VALUES (14936, '2022-12-20 23:23:03.698065+00', '2022-12-20 23:23:03.698065+00', 'Evil Diane', 9998, '');
INSERT INTO 'tune' VALUES (14937, '2022-12-20 23:23:54.461294+00', '2022-12-20 23:23:54.461294+00', 'Far Away', 9998, '');
INSERT INTO 'tune' VALUES (14938, '2022-12-20 23:24:23.533424+00', '2022-12-20 23:24:23.533424+00', 'Remembrance', 9998, '');
INSERT INTO 'tune' VALUES (14939, '2022-12-20 23:25:22.384785+00', '2022-12-20 23:25:22.384785+00', 'Magician''s Hornpipe', 9998, '');
INSERT INTO 'tune' VALUES (14940, '2022-12-20 23:26:10.483668+00', '2022-12-20 23:26:10.483668+00', 'Ginger Sling', 9998, '');
INSERT INTO 'tune' VALUES (14941, '2022-12-20 23:26:58.261957+00', '2022-12-20 23:26:58.261957+00', 'Reel De Gasp', 9998, '');
INSERT INTO 'tune' VALUES (14942, '2022-12-20 23:27:29.172175+00', '2022-12-20 23:27:29.172175+00', 'Bus Stop Reel', 9998, '');
INSERT INTO 'tune' VALUES (14943, '2022-12-20 23:27:54.449048+00', '2022-12-20 23:27:54.449048+00', 'It''s too hot', 9998, '');
INSERT INTO 'tune' VALUES (14944, '2022-12-20 23:28:52.051113+00', '2022-12-20 23:28:52.051113+00', 'Kitty in the High Grass', 9998, '');
INSERT INTO 'tune' VALUES (14946, '2022-12-20 23:30:27.839739+00', '2022-12-20 23:30:27.839739+00', 'Driving Across Nebraska', 9998, '');
INSERT INTO 'tune' VALUES (14947, '2022-12-20 23:30:53.269828+00', '2022-12-20 23:30:53.269828+00', 'Lightning Bug, The', 9998, '');
INSERT INTO 'tune' VALUES (14948, '2022-12-20 23:31:48.366019+00', '2022-12-20 23:31:48.366019+00', 'Vladi On the Trans Siberian', 9998, '');
INSERT INTO 'tune' VALUES (14949, '2022-12-20 23:32:11.53626+00', '2022-12-20 23:32:11.53626+00', 'Sniff the Biscuit', 9998, '');
INSERT INTO 'tune' VALUES (14950, '2022-12-20 23:32:31.489165+00', '2022-12-20 23:32:31.489165+00', 'Spindrifter', 9998, '');
INSERT INTO 'tune' VALUES (14951, '2022-12-20 23:33:49.587507+00', '2022-12-20 23:33:49.587507+00', 'Spinning Tree, The', 9998, '');
INSERT INTO 'tune' VALUES (14952, '2022-12-20 23:34:19.266051+00', '2022-12-20 23:34:19.266051+00', 'Dancing Bear', 9998, '');
INSERT INTO 'tune' VALUES (14953, '2022-12-20 23:35:40.068935+00', '2022-12-20 23:35:40.068935+00', 'Whiskey Before Breakfast', 9998, '');
INSERT INTO 'tune' VALUES (14954, '2022-12-20 23:36:03.1806+00', '2022-12-20 23:36:03.1806+00', 'Beth Cohens', 9998, '');
INSERT INTO 'tune' VALUES (14955, '2022-12-20 23:36:32.955881+00', '2022-12-20 23:36:32.955881+00', 'Chronosynclastic Infundibula, The', 9998, '');
INSERT INTO 'tune' VALUES (14956, '2022-12-21 10:28:50.713647+00', '2022-12-21 10:28:50.713647+00', 'Careless Love', 9999, '');
INSERT INTO 'tune' VALUES (12494, '2013-02-22 16:02:11.336506+00', '2022-12-21 10:46:47.69691+00', 'Row Row Row', 12242, '');
INSERT INTO 'tune' VALUES (14945, '2022-12-20 23:30:01.206216+00', '2022-12-21 11:25:16.470489+00', 'Maison De Glace, La', 9998, '');
INSERT INTO 'tune' VALUES (13156, '2015-06-19 11:47:28.753029+00', '2022-12-21 14:21:32.555475+00', 'Doug Macdonald''s Birthday', 2395, '');
INSERT INTO 'tune' VALUES (2614, NULL, '2022-12-22 13:46:36.454492+00', 'Miss McPherson Grant''s Jig, of Ballindalloch', 1516, 'Name as in "Marshall''s First Collection"; should be our first choice for various other spellings which were added as aliases.');
INSERT INTO 'tune' VALUES (14958, '2022-12-23 12:08:02.834772+00', '2022-12-23 12:08:02.834772+00', 'Captain W M McIntosh', 9998, '');
INSERT INTO 'tune' VALUES (14959, '2022-12-23 12:12:11.519851+00', '2022-12-23 12:12:11.519851+00', 'By Yon Bonnie', 9998, '');
INSERT INTO 'tune' VALUES (14960, '2022-12-23 12:14:00.269866+00', '2022-12-23 12:14:00.269866+00', 'Bill Thomson''s Farewell to Dunblane', 9998, '');
INSERT INTO 'tune' VALUES (14961, '2022-12-23 12:22:45.943498+00', '2022-12-23 12:22:45.943498+00', 'Mia''s Tune', 9998, '');
INSERT INTO 'tune' VALUES (14962, '2022-12-23 12:23:34.315225+00', '2022-12-23 12:23:34.315225+00', 'One for Charlie', 9998, '');
INSERT INTO 'tune' VALUES (14963, '2022-12-23 12:25:04.787577+00', '2022-12-23 12:25:04.787577+00', 'Waverly Steps', 9998, '');
INSERT INTO 'tune' VALUES (14964, '2022-12-23 12:31:58.564972+00', '2022-12-23 12:31:58.564972+00', 'John MacFadyen of Glencoe', 9998, '');
INSERT INTO 'tune' VALUES (10258, '2009-11-02 23:00:00+00', '2022-12-23 13:36:22.8421+00', 'Gibbie and Maggie''s Diamond Wedding', 10086, '');
INSERT INTO 'tune' VALUES (13408, '2016-10-30 23:22:07.488145+00', '2022-12-23 13:37:38.754083+00', 'Cooper''s Rant', 10086, '');
INSERT INTO 'tune' VALUES (11388, '2010-10-13 22:00:00+00', '2022-12-23 13:38:14.207335+00', 'Prue Reel', 10086, '');
INSERT INTO 'tune' VALUES (14965, '2022-12-26 18:31:31.903373+00', '2022-12-26 18:31:31.903373+00', 'Dr. John Grierson', 9998, '');
INSERT INTO 'tune' VALUES (14966, '2022-12-26 19:07:17.488441+00', '2022-12-26 19:07:17.488441+00', 'Engfold House', 9998, 'Might be a misspelled duplicate of "Edgefauld House" by James Scott Skinner');
INSERT INTO 'tune' VALUES (14967, '2022-12-26 19:10:02.197794+00', '2022-12-26 19:10:02.197794+00', 'Kilworth Hills', 9998, '');
INSERT INTO 'tune' VALUES (14968, '2022-12-26 19:12:38.350861+00', '2022-12-26 19:12:38.350861+00', 'Piper in the Heather', 9998, '');
INSERT INTO 'tune' VALUES (14969, '2022-12-26 19:21:40.277061+00', '2022-12-26 19:21:40.277061+00', 'Provost of Wick, The', 9998, '');
INSERT INTO 'tune' VALUES (14970, '2022-12-26 19:25:42.87447+00', '2022-12-26 19:25:42.87447+00', 'Close The Door Gently', 12247, '');
INSERT INTO 'tune' VALUES (2798, NULL, '2022-12-26 20:52:05.907543+00', 'Remmerts of Herford', 1670, 'Has an uncanny resemblance to the German song "Die Fischerin vom Bodensee" by Franz Winkler, 1947.');
INSERT INTO 'tune' VALUES (5672, NULL, '2022-12-26 21:44:43.242756+00', 'Captain Carswell', 12248, '');
INSERT INTO 'tune' VALUES (2673, NULL, '2022-12-26 21:46:14.834206+00', 'Inveraray Castle', 12248, '');
INSERT INTO 'tune' VALUES (14971, '2022-12-26 21:53:00.402944+00', '2022-12-26 21:53:00.402944+00', '8th Argylls, The', 12248, '');
INSERT INTO 'tune' VALUES (14972, '2022-12-26 21:53:25.395036+00', '2022-12-26 21:53:25.395036+00', 'Cellars of Authuille, The', 12248, '');
INSERT INTO 'tune' VALUES (14973, '2022-12-26 21:54:11.011916+00', '2022-12-26 21:54:11.011916+00', 'Clach Larich', 12248, '');
INSERT INTO 'tune' VALUES (14974, '2022-12-26 21:54:33.304588+00', '2022-12-26 21:54:33.304588+00', 'Gurkhas'' Joy, The', 12248, '');
INSERT INTO 'tune' VALUES (14975, '2022-12-26 21:54:44.427203+00', '2022-12-26 21:54:44.427203+00', 'Pap of Glencoe, The', 12248, '');
INSERT INTO 'tune' VALUES (14798, '2022-06-25 18:49:13.996088+00', '2022-12-31 17:39:41.121849+00', 'Alistair Forbes of Craigievar', 1527, '');
INSERT INTO 'tune' VALUES (12567, '2013-07-03 18:54:35.133463+00', '2022-12-31 17:40:55.03496+00', 'James M Cameron''s Farewell to Arran', 1527, '');
INSERT INTO 'tune' VALUES (14976, '2023-01-04 11:35:18.294408+00', '2023-01-04 11:44:46.625538+00', 'Paddy Chevens'' Reel', 1582, 'Composed in March 2016. AABAB.');
INSERT INTO 'tune' VALUES (14977, '2023-01-04 11:36:03.7156+00', '2023-01-04 11:45:00.727328+00', 'Maureen Chevens', 1582, 'Composed in March 2016. ABBC.');
INSERT INTO 'tune' VALUES (14978, '2023-01-04 11:36:30.283043+00', '2023-01-04 11:45:40.519911+00', 'Strickeen House', 1582, 'Composed in May 2016.');
INSERT INTO 'tune' VALUES (1625, NULL, '2023-01-07 21:27:43.331467+00', 'Sneug of Foula', 140, '');
INSERT INTO 'tune' VALUES (532, NULL, '2023-01-07 21:28:14.902796+00', 'Fitful Head', 140, '');
INSERT INTO 'tune' VALUES (6523, NULL, '2023-01-10 22:31:49.040259+00', 'Away up in Clachan', 9998, 'This tune might be a duplicate for tune 4971 <<ddt:Way up in Clachan#4971>>. Both tune names appear in waltz recordings under slightly different names.');
INSERT INTO 'tune' VALUES (4971, NULL, '2023-01-10 22:32:41.256652+00', 'Way Up in Clachan', 9998, 'This tune might be a duplicate for tune 6523 <<ddt:Away up in Clachan#6523>>. Both tune names appear in waltz recordings under slightly different names.');
INSERT INTO 'tune' VALUES (9484, '2004-12-08 23:00:00+00', '2023-01-11 19:44:12.736856+00', 'Newtyle Rhymer, The', 2208, 'A misspelled duplicate "The Newstyle Rhymer" has been deleted from our database.');
INSERT INTO 'tune' VALUES (14979, '2023-01-12 19:26:03.784725+00', '2023-01-12 19:26:03.784725+00', 'Shapinsay Polka', 1895, '');
INSERT INTO 'tune' VALUES (1527, NULL, '2023-01-20 17:42:53.144826+00', 'Road to the Isles, The', 1700, 'According to <<https://tunearch.org/wiki/Annotation:Road_to_the_Isles>>, "The Bens of Jura" is the original title given by its author, and "The Road to the Isles" is its most famous.');
INSERT INTO 'tune' VALUES (5177, NULL, '2023-01-21 22:30:31.336512+00', 'Life in the Finland Woods', 12256, 'Carl Jularbo first recorded the tune in 1915, and it was published in a 1938 Swedish tune book "Jularbos Basta" where he was credited as composer. ');
INSERT INTO 'tune' VALUES (11759, '2011-11-03 23:00:00+00', '2023-01-24 20:37:07.021972+00', 'We''er no very fou but we''er gayly yet', 1517, 'Possibly a duplicate of <<ddt:We''re no'' very fou but we''re gaily yet#12710>>?');
INSERT INTO 'tune' VALUES (12710, '2013-12-07 21:42:02.604223+00', '2023-01-24 20:37:09.372374+00', 'We''re no'' very fou but we''re gaily yet', 9999, 'Possibly a duplicate of <<ddt:We''er no very fou but we''er gayly yet#11759>>?');
INSERT INTO 'tune' VALUES (14980, '2023-01-25 12:45:28.252519+00', '2023-01-25 12:45:28.252519+00', 'Planetarium, The', 11185, '');
INSERT INTO 'tune' VALUES (14981, '2023-01-25 12:53:03.832131+00', '2023-01-25 12:53:03.832131+00', 'Compliments to Glasgow', 1596, '');
INSERT INTO 'tune' VALUES (14982, '2023-01-25 12:55:21.927207+00', '2023-01-25 12:55:21.927207+00', 'Hand Fasting, The', 11185, '');
INSERT INTO 'tune' VALUES (14983, '2023-01-25 13:39:11.948327+00', '2023-01-25 13:39:11.948327+00', 'Daffy Don''t You', 12259, '');
INSERT INTO 'tune' VALUES (14984, '2023-01-25 13:42:42.744478+00', '2023-01-25 13:42:42.744478+00', 'Manual Memories', 11185, '');
INSERT INTO 'tune' VALUES (14985, '2023-01-25 13:46:59.298935+00', '2023-01-25 13:46:59.298935+00', 'Cho Sona ri Bròig', 11185, '');
INSERT INTO 'tune' VALUES (14986, '2023-01-25 13:50:30.149105+00', '2023-01-25 13:50:30.149105+00', 'Miss Betty Forbes', 1934, '');
INSERT INTO 'tune' VALUES (14987, '2023-01-25 14:37:20.171638+00', '2023-01-25 14:37:20.171638+00', 'Malin''s Wandering Piano', 12033, '');
INSERT INTO 'tune' VALUES (14988, '2023-01-25 14:51:03.684889+00', '2023-01-25 14:51:03.684889+00', 'Hundred Years Since, A', 2646, '');
INSERT INTO 'tune' VALUES (14989, '2023-01-25 15:03:20.59004+00', '2023-01-25 15:03:20.59004+00', 'Glasgow Green', 12033, '');
INSERT INTO 'tune' VALUES (14990, '2023-02-26 22:06:06.305776+00', '2023-02-26 22:06:06.305776+00', 'Surprise, The', 1665, 'Mentioned in the CD <<dda:RSCDS Tokai 25th Anniversary>>.');
INSERT INTO 'tune' VALUES (14991, '2023-02-26 22:16:23.20379+00', '2023-02-26 22:16:23.20379+00', 'Hippo''s Progress', 1445, 'Mentioned in the CD <<dda:RSCDS Tokai 25th Anniversary>>.');
INSERT INTO 'tune' VALUES (14992, '2023-02-26 22:16:56.202659+00', '2023-02-26 22:16:56.202659+00', 'Diplomat, The', 1445, 'Mentioned in the CD <<dda:RSCDS Tokai 25th Anniversary>>.');
INSERT INTO 'tune' VALUES (14993, '2023-02-26 22:32:32.058196+00', '2023-02-26 22:32:32.058196+00', 'Miss Daisy Grant', 1445, 'Mentioned in the CD <<dda:RSCDS Tokai 25th Anniversary>>.');
INSERT INTO 'tune' VALUES (14994, '2023-02-26 22:42:12.378716+00', '2023-02-26 22:42:12.378716+00', 'Dixon''s Day', 1445, 'Mentioned in the CD <<dda:RSCDS Tokai 25th Anniversary>>.');
INSERT INTO 'tune' VALUES (14995, '2023-02-26 22:43:09.980338+00', '2023-02-26 22:43:09.980338+00', 'Experimental, The', 1445, 'Mentioned in the CD <<dda:RSCDS Tokai 25th Anniversary>>.');
INSERT INTO 'tune' VALUES (14996, '2023-02-26 22:45:09.042057+00', '2023-02-26 22:45:09.042057+00', 'Chicken Kyiv', 3685, 'Mentioned in the CD <<dda:RSCDS Tokai 25th Anniversary>>.');
INSERT INTO 'tune' VALUES (407, NULL, '2023-02-26 23:04:24.919609+00', 'Dove Cot, The', 1512, 'Originally entered in SCDDB as The Dovecot, the spelling in the tune websites seems to be The Dove Cot. The single word version is kept as an alias.');
INSERT INTO 'tune' VALUES (3672, NULL, '2023-02-26 23:13:42.988116+00', 'Kohler''s Hornpipe', 1416, '');
INSERT INTO 'tune' VALUES (14997, '2023-02-27 17:30:17.804597+00', '2023-02-27 17:32:50.540659+00', 'Frances Packwood', 1590, 'Composed January 2023');
INSERT INTO 'tune' VALUES (14998, '2023-02-28 10:39:52.534145+00', '2023-02-28 10:39:52.534145+00', 'Nit Nurse Napper', 1590, '');
INSERT INTO 'tune' VALUES (12519, '2013-03-14 10:02:46.305198+00', '2023-02-28 14:27:41.044006+00', 'Dennis & Diana Tucker of Cumnor', 1590, '');
INSERT INTO 'tune' VALUES (11558, '2011-07-12 22:00:00+00', '2023-02-28 14:31:31.573319+00', 'Gillian Collis'' Strathspey', 1590, 'Copyright lan Muir February 2008');
INSERT INTO 'tune' VALUES (4547, NULL, '2023-02-28 14:50:27.983262+00', 'Manorfield', 1590, '');
INSERT INTO 'tune' VALUES (8403, NULL, '2023-02-28 14:51:07.269622+00', 'Mrs Margaret Mitchell', 1575, '');
INSERT INTO 'tune' VALUES (14999, '2023-02-28 15:07:16.851185+00', '2023-02-28 15:07:16.851185+00', 'Vectis 70', 1590, '');


--
INSERT INTO 'tunealias' VALUES (1, 2285, 'Humours of Glendart, The', 0);
INSERT INTO 'tunealias' VALUES (2, 2285, 'East at Glandart', 0);
INSERT INTO 'tunealias' VALUES (3, 2285, 'Shins around the Fireside', 0);
INSERT INTO 'tunealias' VALUES (4, 2285, 'Custom House, The', 0);
INSERT INTO 'tunealias' VALUES (5, 1329, 'Mrs MacLeod', 0);
INSERT INTO 'tunealias' VALUES (6, 4801, 'Mrs McLeod of Geaston', 0);
INSERT INTO 'tunealias' VALUES (7, 730, 'I Lo''ed nae a Lassie but Ane', 0);
INSERT INTO 'tunealias' VALUES (8, 4578, 'Storrar''s Hornpipe', 0);
INSERT INTO 'tunealias' VALUES (9, 5308, 'Mervyn''s Reel', 0);
INSERT INTO 'tunealias' VALUES (10, 1026, 'Louden''s Bonnie Woods And Braes', 0);
INSERT INTO 'tunealias' VALUES (11, 415, 'Strip the Willow', 0);
INSERT INTO 'tunealias' VALUES (12, 2054, 'Sailor''s Hornpipe, The', 0);
INSERT INTO 'tunealias' VALUES (13, 381, 'Miss Gray of Carse', 0);
INSERT INTO 'tunealias' VALUES (14, 3333, 'Pot Pourri', 0);
INSERT INTO 'tunealias' VALUES (15, 5890, 'MacLean''s Nose', 0);
INSERT INTO 'tunealias' VALUES (16, 4401, 'Pitnacree Boatman, The', 0);
INSERT INTO 'tunealias' VALUES (17, 1059, 'Lewis Bridal Song', 0);
INSERT INTO 'tunealias' VALUES (19, 218, 'Lord Elphinston', 0);
INSERT INTO 'tunealias' VALUES (20, 3005, 'Cape Breton Symphony''s Visit to the Shetlands, The', 0);
INSERT INTO 'tunealias' VALUES (21, 1857, 'Alister o'' the Den', 0);
INSERT INTO 'tunealias' VALUES (22, 209, 'Lady in the Boat', 0);
INSERT INTO 'tunealias' VALUES (23, 6028, 'Farewell', 0);
INSERT INTO 'tunealias' VALUES (24, 6157, 'O Hear Me Love', 0);
INSERT INTO 'tunealias' VALUES (25, 6158, 'A Lover''s Parting', 0);
INSERT INTO 'tunealias' VALUES (26, 2798, 'Hamish''s Tune', 0);
INSERT INTO 'tunealias' VALUES (27, 981, 'Caubeen, The', 0);
INSERT INTO 'tunealias' VALUES (28, 981, 'Auld Caubeen, The', 0);
INSERT INTO 'tunealias' VALUES (29, 981, 'Liberton Polka, The', 0);
INSERT INTO 'tunealias' VALUES (30, 981, 'Maids of Ardagh, THe', 0);
INSERT INTO 'tunealias' VALUES (31, 981, 'Back of the Hazard, The', 0);
INSERT INTO 'tunealias' VALUES (32, 3149, 'Rollicking Irishman, The', 0);
INSERT INTO 'tunealias' VALUES (34, 2455, 'Lord Balgonie''s Favourite', 0);
INSERT INTO 'tunealias' VALUES (35, 13, 'Galloway House', 0);
INSERT INTO 'tunealias' VALUES (36, 1880, 'Atherny Lodge', 0);
INSERT INTO 'tunealias' VALUES (37, 579, 'Waefu'' Heart, The', 0);
INSERT INTO 'tunealias' VALUES (38, 542, 'Fraser Patrick''s Favourite', 0);
INSERT INTO 'tunealias' VALUES (39, 2055, 'Hamilton House', 0);
INSERT INTO 'tunealias' VALUES (40, 430, 'Highland Rory', 0);
INSERT INTO 'tunealias' VALUES (41, 4913, 'McKewan''s Barn', 0);
INSERT INTO 'tunealias' VALUES (42, 1882, 'Duke of Atholl''s Reel, The', 0);
INSERT INTO 'tunealias' VALUES (43, 5948, 'Mountain Ranger Hornpipe', 0);
INSERT INTO 'tunealias' VALUES (44, 188, 'Owen''s Birthday', 0);
INSERT INTO 'tunealias' VALUES (45, 5816, 'McNabb''s Hornpipe', 0);
INSERT INTO 'tunealias' VALUES (46, 3419, 'Babbity Bowster', 0);
INSERT INTO 'tunealias' VALUES (47, 5087, 'Alfie''s Hornpipe', 0);
INSERT INTO 'tunealias' VALUES (48, 2680, 'Wild Geese, The', 0);
INSERT INTO 'tunealias' VALUES (50, 1528, 'Smash the Windows', 0);
INSERT INTO 'tunealias' VALUES (51, 5029, 'Miss Maule''s Reel', 0);
INSERT INTO 'tunealias' VALUES (52, 1221, 'Miss Maule', 0);
INSERT INTO 'tunealias' VALUES (53, 1345, 'Mrs Muir McKenzie''s Fancy', 0);
INSERT INTO 'tunealias' VALUES (54, 3036, 'A''bhanais Irteach', 0);
INSERT INTO 'tunealias' VALUES (55, 981, 'Liberton Boys, The', 0);
INSERT INTO 'tunealias' VALUES (56, 6913, 'Ruidhleadh nan Coileach Dubh', 0);
INSERT INTO 'tunealias' VALUES (57, 1514, 'Jimmy Allen', 0);
INSERT INTO 'tunealias' VALUES (58, 1238, 'Miss Sally Hunter of Thurston''s Jig', 0);
INSERT INTO 'tunealias' VALUES (59, 1482, 'Miss MacDermott', 0);
INSERT INTO 'tunealias' VALUES (60, 5148, 'Soraidh Slan Le Fiann-Airidh', 0);
INSERT INTO 'tunealias' VALUES (61, 2180, 'Blanchard''s Hornpipe', 0);
INSERT INTO 'tunealias' VALUES (62, 1257, 'Monymusk', 0);
INSERT INTO 'tunealias' VALUES (63, 423, 'Drumley''s Reel', 0);
INSERT INTO 'tunealias' VALUES (64, 423, 'Drumley''s Hornpipe', 0);
INSERT INTO 'tunealias' VALUES (65, 1732, 'Jessie''s Hornpipe', 0);
INSERT INTO 'tunealias' VALUES (66, 182, 'Some Say the Divil''s Deid', 0);
INSERT INTO 'tunealias' VALUES (274, 7680, 'Hughie Shortie''s', 2);
INSERT INTO 'tunealias' VALUES (276, 346, 'Cropies Strathspey', 1);
INSERT INTO 'tunealias' VALUES (280, 8521, 'High Drive', 1);
INSERT INTO 'tunealias' VALUES (49, 926, 'Haud the Lass ''till I Get at Her', 0);
INSERT INTO 'tunealias' VALUES (284, 5634, 'Oor Highland Queen', 1);
INSERT INTO 'tunealias' VALUES (285, 4738, 'Ian Peterson''s Compliments to Jack Delaney', 1);
INSERT INTO 'tunealias' VALUES (286, 4023, 'Here''s to the Health', 2);
INSERT INTO 'tunealias' VALUES (290, 587, 'Silver City Waltz, The', 1);
INSERT INTO 'tunealias' VALUES (291, 12289, 'Newmill Brig', 2);
INSERT INTO 'tunealias' VALUES (292, 12308, 'Blacksmith''s Jig', 2);
INSERT INTO 'tunealias' VALUES (293, 12339, 'Loch Maree', 0);
INSERT INTO 'tunealias' VALUES (295, 4690, 'The Bugle Call Two-Step', 2);
INSERT INTO 'tunealias' VALUES (67, 5126, 'Sean Truibhas', 0);
INSERT INTO 'tunealias' VALUES (68, 3121, 'Helen Campbell', 0);
INSERT INTO 'tunealias' VALUES (69, 497, 'Largo''s Fairy Dance', 0);
INSERT INTO 'tunealias' VALUES (70, 284, 'Cross of Inverness, The', 0);
INSERT INTO 'tunealias' VALUES (71, 430, 'Highland Ruaridh', 0);
INSERT INTO 'tunealias' VALUES (72, 7616, 'Quaker''s Grace, The', 0);
INSERT INTO 'tunealias' VALUES (73, 913, 'Lady Louisa Ramsay''s Strathspey', 0);
INSERT INTO 'tunealias' VALUES (74, 1303, 'Mrs Dalzell of Dalzell Lodge', 0);
INSERT INTO 'tunealias' VALUES (75, 7600, 'Braes of Banffshire', 0);
INSERT INTO 'tunealias' VALUES (76, 7670, 'Bonfire, The', 0);
INSERT INTO 'tunealias' VALUES (77, 7655, 'Aberarder''s Rant', 0);
INSERT INTO 'tunealias' VALUES (78, 7715, 'Hippo Hop, The', 0);
INSERT INTO 'tunealias' VALUES (79, 103, 'Mais an Taobh Tuath', 0);
INSERT INTO 'tunealias' VALUES (80, 445, 'Duke of Gordon''s Birthday, The', 0);
INSERT INTO 'tunealias' VALUES (81, 247, 'Captain Campbell of Lochiell', 0);
INSERT INTO 'tunealias' VALUES (82, 6492, 'Shetland Twostep', 0);
INSERT INTO 'tunealias' VALUES (83, 1789, 'Wee Tod', 0);
INSERT INTO 'tunealias' VALUES (84, 1084, 'My Ain Hoose', 0);
INSERT INTO 'tunealias' VALUES (85, 155, 'Boys of Limerick', 0);
INSERT INTO 'tunealias' VALUES (86, 4755, 'Judy Brallaghan', 0);
INSERT INTO 'tunealias' VALUES (87, 8148, 'Peeler and the Goat', 0);
INSERT INTO 'tunealias' VALUES (88, 8227, 'Reel for Janet Kurnick, A', 0);
INSERT INTO 'tunealias' VALUES (89, 8232, 'Mighty Monty', 0);
INSERT INTO 'tunealias' VALUES (90, 497, 'Old Molly Hare', 0);
INSERT INTO 'tunealias' VALUES (91, 504, 'Sitting in the Stern of a Boat', 0);
INSERT INTO 'tunealias' VALUES (92, 2270, 'Scotland is My Ain Hame', 0);
INSERT INTO 'tunealias' VALUES (93, 4123, 'Sligo Maid', 0);
INSERT INTO 'tunealias' VALUES (94, 4126, 'Drover''s Lads, The', 0);
INSERT INTO 'tunealias' VALUES (95, 857, 'Suas Leis a'' Bhagalais', 0);
INSERT INTO 'tunealias' VALUES (96, 8489, 'Claire''s Quickstep', 0);
INSERT INTO 'tunealias' VALUES (97, 8650, '19 Market Street', 0);
INSERT INTO 'tunealias' VALUES (98, 8667, 'J F Dickie', 0);
INSERT INTO 'tunealias' VALUES (99, 8668, 'Cunningsburgh', 0);
INSERT INTO 'tunealias' VALUES (100, 327, 'Lady Hamilton', 0);
INSERT INTO 'tunealias' VALUES (101, 3252, 'Lonach Highland Fling, The', 0);
INSERT INTO 'tunealias' VALUES (102, 2762, 'Paddy on the Railroad', 0);
INSERT INTO 'tunealias' VALUES (103, 2545, 'Auld Brig o'' Ayr, The', 0);
INSERT INTO 'tunealias' VALUES (104, 2545, 'Bob Steele', 0);
INSERT INTO 'tunealias' VALUES (105, 2545, 'New Brig O'' Dee, The', 0);
INSERT INTO 'tunealias' VALUES (106, 183, 'Hon Mrs Drummond of Perth''s Strathspey', 0);
INSERT INTO 'tunealias' VALUES (108, 1509, 'Watson''s Scotch Measure', 0);
INSERT INTO 'tunealias' VALUES (109, 172, 'Roualeyn''s Plaid', 0);
INSERT INTO 'tunealias' VALUES (110, 1464, 'MacCrimmond''s Farewell', 0);
INSERT INTO 'tunealias' VALUES (111, 8772, 'Cotton Pickin'' Time', 0);
INSERT INTO 'tunealias' VALUES (112, 2241, 'Boc Liath Nan Gobhar', 0);
INSERT INTO 'tunealias' VALUES (113, 807, 'Big John McNeil', 0);
INSERT INTO 'tunealias' VALUES (114, 7402, 'Corryvreckon', 0);
INSERT INTO 'tunealias' VALUES (115, 1093, 'Gypsy Hornpipe', 0);
INSERT INTO 'tunealias' VALUES (116, 1466, 'Dennis O''Conner', 0);
INSERT INTO 'tunealias' VALUES (117, 9064, 'Gray Old Lady of Raasay, The', 0);
INSERT INTO 'tunealias' VALUES (118, 9011, 'Weaver''s Daughter, The', 0);
INSERT INTO 'tunealias' VALUES (119, 6589, 'Put it in the Great Chest', 0);
INSERT INTO 'tunealias' VALUES (120, 4365, 'Mug of Brown Ale', 0);
INSERT INTO 'tunealias' VALUES (122, 4578, 'Storrers, The', 0);
INSERT INTO 'tunealias' VALUES (275, 2798, 'Remots of Herford', 1);
INSERT INTO 'tunealias' VALUES (107, 1527, 'Bens of Jura, The', 2);
INSERT INTO 'tunealias' VALUES (123, 1542, 'Monadh Liath, Am', 0);
INSERT INTO 'tunealias' VALUES (124, 1542, 'Sportsman''s Haunt, The', 0);
INSERT INTO 'tunealias' VALUES (125, 1196, 'Johnny Pringle', 0);
INSERT INTO 'tunealias' VALUES (126, 2152, 'Navvie on the Line, The', 0);
INSERT INTO 'tunealias' VALUES (127, 2152, 'Evan''s Hornpipe', 0);
INSERT INTO 'tunealias' VALUES (128, 1078, 'Ninety-second, The', 0);
INSERT INTO 'tunealias' VALUES (129, 2646, 'Muilean Dubh', 0);
INSERT INTO 'tunealias' VALUES (130, 4253, 'Goodbye Murshin Durkin', 0);
INSERT INTO 'tunealias' VALUES (131, 9020, 'Ghoid iad bhean uam an raoir', 0);
INSERT INTO 'tunealias' VALUES (132, 2379, 'Jackie Coleman''s Reel', 0);
INSERT INTO 'tunealias' VALUES (277, 692, 'Highland Whiskey', 1);
INSERT INTO 'tunealias' VALUES (281, 926, 'Lady Susan Stewart', 1);
INSERT INTO 'tunealias' VALUES (287, 7102, 'My Boy Tammie', 1);
INSERT INTO 'tunealias' VALUES (294, 12340, 'Cuckoo, The', 0);
INSERT INTO 'tunealias' VALUES (134, 7176, 'Mrs E M Monair of Bruach', 0);
INSERT INTO 'tunealias' VALUES (135, 2596, 'Jubilee Jig, The', 0);
INSERT INTO 'tunealias' VALUES (136, 129, 'Blue Bonnets O''er the Border', 0);
INSERT INTO 'tunealias' VALUES (137, 1659, 'Grey Daylight', 0);
INSERT INTO 'tunealias' VALUES (138, 1624, 'Carrick''s Rant', 0);
INSERT INTO 'tunealias' VALUES (139, 3124, 'An t''Eilean Mulladh', 0);
INSERT INTO 'tunealias' VALUES (140, 5346, 'Gille Callum', 0);
INSERT INTO 'tunealias' VALUES (141, 2017, 'Captain Horn', 0);
INSERT INTO 'tunealias' VALUES (142, 5828, 'Old Man Old Woman', 0);
INSERT INTO 'tunealias' VALUES (143, 1852, 'Sands o'' Murness', 0);
INSERT INTO 'tunealias' VALUES (144, 411, 'Dr. Bob Smith', 0);
INSERT INTO 'tunealias' VALUES (145, 4991, 'Plough and Starts, The', 0);
INSERT INTO 'tunealias' VALUES (146, 1620, 'White Heather Jig', 0);
INSERT INTO 'tunealias' VALUES (147, 6443, 'Brier Rose, The', 0);
INSERT INTO 'tunealias' VALUES (148, 3460, 'Bonnie House of Airlie March', 0);
INSERT INTO 'tunealias' VALUES (149, 7673, 'Lord Byron', 0);
INSERT INTO 'tunealias' VALUES (150, 7904, 'Lord Drighorn''s', 0);
INSERT INTO 'tunealias' VALUES (151, 1193, 'Mrs. Irene Fidler''s Strathspey', 0);
INSERT INTO 'tunealias' VALUES (152, 5490, 'Mrs Oswald of Auchincruive''s Favourite Reel', 0);
INSERT INTO 'tunealias' VALUES (153, 9262, 'Croughly''s', 0);
INSERT INTO 'tunealias' VALUES (154, 9568, 'House of Auchluncart, The', 0);
INSERT INTO 'tunealias' VALUES (155, 9508, 'Lady Bromes Strathspey', 0);
INSERT INTO 'tunealias' VALUES (156, 388, 'Deuks Dang O''er my Daddie, The', 0);
INSERT INTO 'tunealias' VALUES (157, 1498, 'Balmeddie Lassies', 0);
INSERT INTO 'tunealias' VALUES (158, 4050, 'Honourable Captain Maitland', 0);
INSERT INTO 'tunealias' VALUES (159, 1230, 'Miss Ogleves Fancy', 0);
INSERT INTO 'tunealias' VALUES (160, 702, 'Holyrood', 0);
INSERT INTO 'tunealias' VALUES (162, 3512, 'Dr Neil McLeod', 0);
INSERT INTO 'tunealias' VALUES (164, 2808, 'Mrs Coutts Trotter''s Reel', 0);
INSERT INTO 'tunealias' VALUES (165, 1190, 'Mrs Hay of Yester', 0);
INSERT INTO 'tunealias' VALUES (166, 277, 'Long Chase, The', 0);
INSERT INTO 'tunealias' VALUES (169, 2424, 'Lady Hamilton Dalrymple', 0);
INSERT INTO 'tunealias' VALUES (170, 5857, 'Thomson''s Got A Dirk', 0);
INSERT INTO 'tunealias' VALUES (171, 6632, 'Patrick George Moncrieff Esq.', 0);
INSERT INTO 'tunealias' VALUES (172, 2030, 'Maghie''s Matchless', 0);
INSERT INTO 'tunealias' VALUES (173, 1031, 'Luggin'' The Box', 0);
INSERT INTO 'tunealias' VALUES (174, 93, 'Banks o'' Spey, The', 0);
INSERT INTO 'tunealias' VALUES (175, 1082, 'Marshall''s Compliments to Niel Gow', 0);
INSERT INTO 'tunealias' VALUES (176, 1700, 'Teviot Bridge', 0);
INSERT INTO 'tunealias' VALUES (177, 6483, 'Jean Reid', 0);
INSERT INTO 'tunealias' VALUES (178, 2410, 'Earl of Morton', 0);
INSERT INTO 'tunealias' VALUES (179, 699, 'Hoddom Castle', 0);
INSERT INTO 'tunealias' VALUES (180, 1435, 'Over the Water', 0);
INSERT INTO 'tunealias' VALUES (181, 206, 'Bromley Brae', 0);
INSERT INTO 'tunealias' VALUES (182, 1670, 'Robertson Rant', 0);
INSERT INTO 'tunealias' VALUES (183, 2076, 'Miss Grace Hayes', 0);
INSERT INTO 'tunealias' VALUES (184, 8225, 'Stan Chapman''s', 0);
INSERT INTO 'tunealias' VALUES (185, 7678, 'Lady Elizabeth Cole''s', 0);
INSERT INTO 'tunealias' VALUES (186, 9270, 'Miss MacDowal Grant''s', 0);
INSERT INTO 'tunealias' VALUES (188, 5892, 'Craig o'' Barns', 0);
INSERT INTO 'tunealias' VALUES (189, 344, 'Crook''d Horn''d Ewie', 0);
INSERT INTO 'tunealias' VALUES (190, 1059, 'Lewis Bridal Song, The', 0);
INSERT INTO 'tunealias' VALUES (192, 7200, 'Crosshills Jig', 0);
INSERT INTO 'tunealias' VALUES (193, 2252, 'Heather Dewar', 0);
INSERT INTO 'tunealias' VALUES (194, 2987, 'Miss Elizabeth Campbell''s Jig', 0);
INSERT INTO 'tunealias' VALUES (195, 9915, 'Going to the Well of Water', 0);
INSERT INTO 'tunealias' VALUES (196, 2375, 'McMahon''s', 0);
INSERT INTO 'tunealias' VALUES (197, 2608, 'Miss Margaret Graham', 0);
INSERT INTO 'tunealias' VALUES (198, 3086, 'Ferry Reel, Da', 0);
INSERT INTO 'tunealias' VALUES (199, 673, 'Here''s a Health to Ane an'' a''', 0);
INSERT INTO 'tunealias' VALUES (200, 651, 'Sunset on Calton Hill', 0);
INSERT INTO 'tunealias' VALUES (201, 2999, 'John Brennan''s Reel', 0);
INSERT INTO 'tunealias' VALUES (202, 7673, 'Lord Byron''s Strathspey', 0);
INSERT INTO 'tunealias' VALUES (187, 5390, 'Miss Hannah''s Jig - Elgin', 2);
INSERT INTO 'tunealias' VALUES (278, 8507, 'Andy Brown''s Reel', 1);
INSERT INTO 'tunealias' VALUES (282, 1402, 'Neil Gow''s Second Wife', 1);
INSERT INTO 'tunealias' VALUES (288, 6276, ' Braes Aboon Bonaw', 1);
INSERT INTO 'tunealias' VALUES (203, 835, 'Jinglin'' Johnnie', 0);
INSERT INTO 'tunealias' VALUES (204, 6713, 'Archibald Minto', 0);
INSERT INTO 'tunealias' VALUES (205, 3545, 'Flirtation', 0);
INSERT INTO 'tunealias' VALUES (206, 4578, 'Storrers', 0);
INSERT INTO 'tunealias' VALUES (207, 9251, 'Weindia Little', 0);
INSERT INTO 'tunealias' VALUES (208, 4301, 'Mrs Double', 0);
INSERT INTO 'tunealias' VALUES (209, 8241, 'Mitton''s Breakdown', 0);
INSERT INTO 'tunealias' VALUES (210, 6384, 'Kildare Fancy', 0);
INSERT INTO 'tunealias' VALUES (211, 10489, 'Sunshine Hornpipe', 0);
INSERT INTO 'tunealias' VALUES (212, 8169, 'Loretta', 0);
INSERT INTO 'tunealias' VALUES (213, 2279, 'Honourable Capt. Elliott''s Quickstep, The', 0);
INSERT INTO 'tunealias' VALUES (214, 682, 'High Level', 0);
INSERT INTO 'tunealias' VALUES (215, 3919, 'Ho Ro My Nut Brown Maiden', 0);
INSERT INTO 'tunealias' VALUES (216, 5188, 'Absent Minded Professor, The', 0);
INSERT INTO 'tunealias' VALUES (217, 724, 'Wi a Hundred Pipers', 0);
INSERT INTO 'tunealias' VALUES (218, 6695, 'Isles o'' Gletness, Da', 0);
INSERT INTO 'tunealias' VALUES (219, 4653, 'Shaalds o'' Foula, Da', 0);
INSERT INTO 'tunealias' VALUES (220, 4737, 'Peerie Hoose Ahint da Burn, Da', 0);
INSERT INTO 'tunealias' VALUES (221, 1102, 'Bonnie Isle o'' Whalsay, Da, Da', 0);
INSERT INTO 'tunealias' VALUES (222, 5018, 'Lime Hill Strathspey, The', 0);
INSERT INTO 'tunealias' VALUES (223, 9337, '60 Fathom Reel, The', 0);
INSERT INTO 'tunealias' VALUES (224, 4878, 'Red Haired Lad, The', 0);
INSERT INTO 'tunealias' VALUES (225, 1748, 'Tushker, The', 0);
INSERT INTO 'tunealias' VALUES (226, 7344, 'Miss McCloud''s Reel', 0);
INSERT INTO 'tunealias' VALUES (227, 3390, 'St. Anne''s Reel', 0);
INSERT INTO 'tunealias' VALUES (229, 3874, 'Miss Gordon of Haddo', 0);
INSERT INTO 'tunealias' VALUES (230, 1241, 'Miss Stewart''s Jig', 0);
INSERT INTO 'tunealias' VALUES (231, 1026, 'Bonnie Louden''s Woods and Braes', 0);
INSERT INTO 'tunealias' VALUES (233, 673, 'Here''s a Health', 0);
INSERT INTO 'tunealias' VALUES (234, 687, 'Heiland Lad, A', 0);
INSERT INTO 'tunealias' VALUES (235, 9070, 'Miss Admiral Gordon''s Strathspey', 0);
INSERT INTO 'tunealias' VALUES (236, 4727, 'Ca the Yowes', 0);
INSERT INTO 'tunealias' VALUES (237, 1435, 'O''er the Water to Charlie', 0);
INSERT INTO 'tunealias' VALUES (524, 4310, 'Mrs H L MacDonald of Dunach', 1);
INSERT INTO 'tunealias' VALUES (239, 4500, 'Maids of Mourne Shore, The', 0);
INSERT INTO 'tunealias' VALUES (240, 11017, 'Daffeedowndilly, The', 0);
INSERT INTO 'tunealias' VALUES (242, 2330, 'Jeanette MacInnes', 0);
INSERT INTO 'tunealias' VALUES (243, 433, 'Duchess of Buccleuch, The', 0);
INSERT INTO 'tunealias' VALUES (244, 8265, 'Lady Mary Douglas', 0);
INSERT INTO 'tunealias' VALUES (245, 1685, 'Tom Bain''s Lum', 0);
INSERT INTO 'tunealias' VALUES (246, 13, 'Aitken Drum', 0);
INSERT INTO 'tunealias' VALUES (249, 1857, 'Alasdair an Dun', 0);
INSERT INTO 'tunealias' VALUES (250, 1460, 'Pibroch O'' Donald Dhu', 0);
INSERT INTO 'tunealias' VALUES (251, 378, 'Davy Knick Knack', 0);
INSERT INTO 'tunealias' VALUES (252, 1328, 'Mrs MacDouwal Grant', 0);
INSERT INTO 'tunealias' VALUES (161, 2577, 'Miss Campbell of Saddell', 0);
INSERT INTO 'tunealias' VALUES (133, 624, 'Green Grow the Rushes, O', 1);
INSERT INTO 'tunealias' VALUES (256, 1126, 'Minister of Birse, The', 0);
INSERT INTO 'tunealias' VALUES (257, 9542, 'Rosemary Baird''s Farewell', 0);
INSERT INTO 'tunealias' VALUES (258, 613, 'Goodnight and Joy be Wi'' Ye A''', 0);
INSERT INTO 'tunealias' VALUES (259, 8072, 'Ay Wakin'' O', 0);
INSERT INTO 'tunealias' VALUES (260, 11777, 'Ca'' the Wethers to the Hill', 0);
INSERT INTO 'tunealias' VALUES (261, 148, 'Bonnie Briest Knot, The', 0);
INSERT INTO 'tunealias' VALUES (262, 1805, 'What''s A'' The Steer', 0);
INSERT INTO 'tunealias' VALUES (263, 2579, 'Air from Haydn''s Symphony No. 12', 0);
INSERT INTO 'tunealias' VALUES (264, 1802, 'Wha''ll Be King But Charlie', 0);
INSERT INTO 'tunealias' VALUES (265, 1387, '(New) Highland Laddie, The', 0);
INSERT INTO 'tunealias' VALUES (267, 1805, 'What''s A'' The Steer', 0);
INSERT INTO 'tunealias' VALUES (268, 848, 'Kelvin Grove', 0);
INSERT INTO 'tunealias' VALUES (269, 2834, 'Sandie Ower the Sea', 0);
INSERT INTO 'tunealias' VALUES (270, 11217, 'Ho-Ree Ho-Ro, My Little Wee Girl', 0);
INSERT INTO 'tunealias' VALUES (271, 1908, 'Bay of Fundy, The', 0);
INSERT INTO 'tunealias' VALUES (272, 2646, 'Muilin Dhu', 0);
INSERT INTO 'tunealias' VALUES (273, 1421, 'As I Was Kissed Yestreen', 0);
INSERT INTO 'tunealias' VALUES (279, 2347, 'Jim McAlister''s Jig', 1);
INSERT INTO 'tunealias' VALUES (283, 9505, 'Spin and Glow', 1);
INSERT INTO 'tunealias' VALUES (289, 2703, 'My Heart is Sair for Somebody', 0);
INSERT INTO 'tunealias' VALUES (296, 2458, 'Johnny Murray of Lochee', 0);
INSERT INTO 'tunealias' VALUES (297, 2458, 'J Murray of Lochee', 0);
INSERT INTO 'tunealias' VALUES (299, 5563, 'William Richie Esquire', 1);
INSERT INTO 'tunealias' VALUES (300, 9010, 'Mrs Oswald of Auchencruive''s Favourite Reel', 2);
INSERT INTO 'tunealias' VALUES (301, 503, 'Far From Home', 1);
INSERT INTO 'tunealias' VALUES (303, 3433, 'Lass o'' Fyvie', 0);
INSERT INTO 'tunealias' VALUES (306, 1431, 'Brochan Lom', 2);
INSERT INTO 'tunealias' VALUES (307, 1431, 'Thin Porridge', 0);
INSERT INTO 'tunealias' VALUES (121, 1527, 'Burning Sands of Egypt, The', 2);
INSERT INTO 'tunealias' VALUES (310, 3502, 'Road to the Isles, The', 2);
INSERT INTO 'tunealias' VALUES (305, 2240, 'Greenwood Side', 0);
INSERT INTO 'tunealias' VALUES (311, 12591, 'Light in the Darkness', 2);
INSERT INTO 'tunealias' VALUES (312, 4702, 'Cropie''s Strathspey', 2);
INSERT INTO 'tunealias' VALUES (313, 576, 'Gillian''s Reel', 1);
INSERT INTO 'tunealias' VALUES (314, 12592, 'Oor Lassie Frae Lossie', 2);
INSERT INTO 'tunealias' VALUES (315, 12564, 'Salut les Boulduc', 1);
INSERT INTO 'tunealias' VALUES (317, 12549, 'Tunesmith, The', 2);
INSERT INTO 'tunealias' VALUES (316, 12549, 'Slåttesmedden', 1);
INSERT INTO 'tunealias' VALUES (318, 875, 'City of Nairobi Reel, The', 0);
INSERT INTO 'tunealias' VALUES (319, 3646, 'Dr Mackay''s Fareweel to Creagory', 2);
INSERT INTO 'tunealias' VALUES (320, 2086, ' David Wilson MBE - The Balmullo Blacksmith', 2);
INSERT INTO 'tunealias' VALUES (321, 12639, 'Eine Reise nach Bayern', 2);
INSERT INTO 'tunealias' VALUES (325, 5986, 'Whisky in the Jar', 1);
INSERT INTO 'tunealias' VALUES (326, 2724, 'O''Donnell Abu', 1);
INSERT INTO 'tunealias' VALUES (327, 188, 'Break Down', 1);
INSERT INTO 'tunealias' VALUES (328, 1646, 'Saint Andrews Nicht', 1);
INSERT INTO 'tunealias' VALUES (329, 9187, 'Lass of Ballantrae, The', 1);
INSERT INTO 'tunealias' VALUES (330, 1086, 'Mary Hamilton', 2);
INSERT INTO 'tunealias' VALUES (331, 12949, 'Braes of Yarrow', 0);
INSERT INTO 'tunealias' VALUES (324, 12658, 'Kobobeiniki', 1);
INSERT INTO 'tunealias' VALUES (332, 12658, 'Korobeiniki', 1);
INSERT INTO 'tunealias' VALUES (333, 12658, 'Коробейники', 2);
INSERT INTO 'tunealias' VALUES (334, 168, 'Borestone, The', 1);
INSERT INTO 'tunealias' VALUES (335, 11932, 'Dantesque', 2);
INSERT INTO 'tunealias' VALUES (336, 2570, 'Miss Ann Munro', 1);
INSERT INTO 'tunealias' VALUES (337, 143, 'Bog o'' Gight, The', 1);
INSERT INTO 'tunealias' VALUES (338, 239, 'Cambeltown Kiltie Ball', 1);
INSERT INTO 'tunealias' VALUES (339, 7537, 'Islay Ranters, The', 1);
INSERT INTO 'tunealias' VALUES (340, 7538, 'Calgary Fiddler''s Welcome to Scotland', 1);
INSERT INTO 'tunealias' VALUES (341, 1862, 'John Spence of Uyeasound', 1);
INSERT INTO 'tunealias' VALUES (342, 4758, 'Billy MacKinnon', 1);
INSERT INTO 'tunealias' VALUES (343, 2427, 'Lady Jemima Johnstone', 1);
INSERT INTO 'tunealias' VALUES (344, 2683, 'Mrs Margaret Holmes'' Strathspey', 1);
INSERT INTO 'tunealias' VALUES (345, 98, 'Banyards o'' Delgaty, The', 1);
INSERT INTO 'tunealias' VALUES (346, 12979, 'Columbia The Gem of The Ocean', 1);
INSERT INTO 'tunealias' VALUES (347, 1838, '''Twas Within a Mile o'' Edinburgh Toon', 1);
INSERT INTO 'tunealias' VALUES (348, 239, 'Campbelltown Kiltie Ball', 1);
INSERT INTO 'tunealias' VALUES (349, 403, 'Doon the Burn, Davie, Love', 1);
INSERT INTO 'tunealias' VALUES (350, 833, 'Ka-Foo-Za-Lum', 1);
INSERT INTO 'tunealias' VALUES (351, 1832, 'Willie''s Gane to Melville Castle', 1);
INSERT INTO 'tunealias' VALUES (352, 1066, 'Man''s A Man, A', 1);
INSERT INTO 'tunealias' VALUES (354, 4361, 'Of A'' The Airts The Wind Can Blaw', 2);
INSERT INTO 'tunealias' VALUES (355, 1087, 'Mary Morrison', 1);
INSERT INTO 'tunealias' VALUES (356, 861, 'Kind Robin Lo''es Me', 2);
INSERT INTO 'tunealias' VALUES (357, 2728, 'When the King Comes Over The Hill', 0);
INSERT INTO 'tunealias' VALUES (358, 730, 'I Lo''ed Ne''er a Laddie but Ane', 1);
INSERT INTO 'tunealias' VALUES (359, 624, 'Green Grow the Rashes O', 1);
INSERT INTO 'tunealias' VALUES (360, 4331, 'Big Kilmarnock Bonnet', 1);
INSERT INTO 'tunealias' VALUES (361, 2789, 'That''s the Reason Noo'' I Wear The Kilt', 0);
INSERT INTO 'tunealias' VALUES (362, 3267, 'Mrs Gordon of Rafford', 0);
INSERT INTO 'tunealias' VALUES (363, 4854, 'Misses Gordon of Rafford, The', 0);
INSERT INTO 'tunealias' VALUES (364, 109, 'Taigh Bhelladrum', 2);
INSERT INTO 'tunealias' VALUES (365, 2693, 'Laird o'' Mackintosh, The', 1);
INSERT INTO 'tunealias' VALUES (366, 914, 'Lady MacKenzie of Coul', 0);
INSERT INTO 'tunealias' VALUES (367, 12997, 'Mis Grace Bowie', 1);
INSERT INTO 'tunealias' VALUES (368, 11286, 'Doe a deer', 0);
INSERT INTO 'tunealias' VALUES (369, 12795, 'Saints, The', 0);
INSERT INTO 'tunealias' VALUES (370, 2882, 'Sproats o'' Burnieboozle, The', 0);
INSERT INTO 'tunealias' VALUES (371, 1895, 'CM Hall', 0);
INSERT INTO 'tunealias' VALUES (372, 2691, 'Polmander Jig', 1);
INSERT INTO 'tunealias' VALUES (373, 3132, 'Capt J Petersen of Melbey', 1);
INSERT INTO 'tunealias' VALUES (374, 171, 'Punch Bowl Reel', 0);
INSERT INTO 'tunealias' VALUES (375, 1880, 'Athernie Lodge', 0);
INSERT INTO 'tunealias' VALUES (376, 2844, 'Sally Picker, The', 0);
INSERT INTO 'tunealias' VALUES (378, 2297, 'Iain MacPhail''s Compliments to Gordon Jamieson', 0);
INSERT INTO 'tunealias' VALUES (377, 128, 'Cocker''s Roses', 1);
INSERT INTO 'tunealias' VALUES (379, 128, 'Cockers Roses', 2);
INSERT INTO 'tunealias' VALUES (380, 128, 'Blooms of Bon-Accord, The', 1);
INSERT INTO 'tunealias' VALUES (381, 5855, 'Miss Douglas'' (Strathspey)', 1);
INSERT INTO 'tunealias' VALUES (382, 1861, 'Alex Little M C', 1);
INSERT INTO 'tunealias' VALUES (383, 1861, 'Alex Little M.C.', 1);
INSERT INTO 'tunealias' VALUES (385, 1352, 'Mrs Stewart Nicholson''s Strathspey', 0);
INSERT INTO 'tunealias' VALUES (386, 3120, 'Stormont Lads, The', 1);
INSERT INTO 'tunealias' VALUES (387, 6203, 'Biddy from Sligo', 1);
INSERT INTO 'tunealias' VALUES (388, 389, 'Deveron Reel', 1);
INSERT INTO 'tunealias' VALUES (389, 2055, 'Col Hamilton''s Delight', 1);
INSERT INTO 'tunealias' VALUES (390, 3001, 'Wing Commander Donald MacKenzie''s Reel', 1);
INSERT INTO 'tunealias' VALUES (391, 7537, 'Islay Ranters Reel, The', 1);
INSERT INTO 'tunealias' VALUES (392, 91, 'Banks o'' Clyde, The', 1);
INSERT INTO 'tunealias' VALUES (393, 6764, 'Tulloch gorm', 1);
INSERT INTO 'tunealias' VALUES (394, 986, 'Link''um Doddie', 1);
INSERT INTO 'tunealias' VALUES (395, 5581, 'Miss Lauren Rose Patrick''s Jig', 2);
INSERT INTO 'tunealias' VALUES (396, 4578, 'Storrer''s Hornpipe, The', 1);
INSERT INTO 'tunealias' VALUES (397, 1717, 'Tibby Flower o'' the Glen', 0);
INSERT INTO 'tunealias' VALUES (398, 1597, 'She''s owre young to Marry Yet', 1);
INSERT INTO 'tunealias' VALUES (399, 7596, 'Tax Man''s Gone, The', 1);
INSERT INTO 'tunealias' VALUES (525, 13872, 'Where you were yestreen', 0);
INSERT INTO 'tunealias' VALUES (401, 1295, 'Mrs Blair of Blair''s Strathspey', 0);
INSERT INTO 'tunealias' VALUES (402, 4242, 'Miss Isaac Forsyth, Elgin', 1);
INSERT INTO 'tunealias' VALUES (403, 1174, 'Miss Esther Oswald of Auchencruive''s Strathspey', 1);
INSERT INTO 'tunealias' VALUES (404, 403, 'Doun the Burn Davie Lad', 1);
INSERT INTO 'tunealias' VALUES (405, 141, 'Bobby Harvey''s Strathspey', 1);
INSERT INTO 'tunealias' VALUES (406, 9170, 'Laird o'' MacIntosh, The', 1);
INSERT INTO 'tunealias' VALUES (407, 3111, 'Fiddler, Play the Light Strathspey', 1);
INSERT INTO 'tunealias' VALUES (323, 10993, 'De''il Amang The Tailors', 0);
INSERT INTO 'tunealias' VALUES (384, 2443, 'Laird O'' Thrums', 1);
INSERT INTO 'tunealias' VALUES (408, 10579, 'Ian and Betty''s Jig', 1);
INSERT INTO 'tunealias' VALUES (409, 7961, 'Lady Chatherine Pelhams Reel', 1);
INSERT INTO 'tunealias' VALUES (410, 876, 'Tempete, La', 1);
INSERT INTO 'tunealias' VALUES (411, 7293, 'George Carrick', 2);
INSERT INTO 'tunealias' VALUES (412, 3004, 'Ythan Bar, The', 1);
INSERT INTO 'tunealias' VALUES (413, 9854, 'Gordon R Keers', 1);
INSERT INTO 'tunealias' VALUES (414, 3431, 'Miss Monaghan', 2);
INSERT INTO 'tunealias' VALUES (415, 1248, 'Miss Williams Fancy', 1);
INSERT INTO 'tunealias' VALUES (416, 1241, 'Mrs Stewart''s Jig of Bombay', 0);
INSERT INTO 'tunealias' VALUES (417, 1158, 'Miss Clementina Loughan', 1);
INSERT INTO 'tunealias' VALUES (418, 3132, 'Captain Peterson of Melbay', 1);
INSERT INTO 'tunealias' VALUES (419, 20, 'Mrs Fordyce''s (of Ayton''s) Strathspey', 1);
INSERT INTO 'tunealias' VALUES (420, 10282, 'Lieut Howard Douglas''s Strathspey', 1);
INSERT INTO 'tunealias' VALUES (421, 10283, 'Mrs Menzies of Culdair''s Strathspey', 1);
INSERT INTO 'tunealias' VALUES (422, 5153, 'Sir James G Baird Bart. Strathspey', 0);
INSERT INTO 'tunealias' VALUES (423, 2570, 'Miss Ann Munro''s Reel', 1);
INSERT INTO 'tunealias' VALUES (424, 75, 'Awa'' Whigs Awa''', 1);
INSERT INTO 'tunealias' VALUES (425, 7002, 'Buchan Plooman', 1);
INSERT INTO 'tunealias' VALUES (426, 2675, 'Mrs Eileen Cowan', 1);
INSERT INTO 'tunealias' VALUES (526, 1129, 'McLauchlan''s Scotch Measure', 1);
INSERT INTO 'tunealias' VALUES (518, 1989, 'Brown Haired Maid', 0);
INSERT INTO 'tunealias' VALUES (428, 7241, 'Angus MacFadzean', 0);
INSERT INTO 'tunealias' VALUES (429, 312, 'Come Let''s Dance And Sing', 0);
INSERT INTO 'tunealias' VALUES (430, 6047, '72nd Highlanders', 0);
INSERT INTO 'tunealias' VALUES (431, 1967, 'Campdown Races', 0);
INSERT INTO 'tunealias' VALUES (432, 2862, 'Off with the Good St Nicholas Boat', 0);
INSERT INTO 'tunealias' VALUES (433, 6945, 'Burnt Potato, The', 0);
INSERT INTO 'tunealias' VALUES (434, 13133, 'Crowley''s Reel', 2);
INSERT INTO 'tunealias' VALUES (435, 2804, 'Miss Thompson', 2);
INSERT INTO 'tunealias' VALUES (436, 2804, 'Miss Thompson''s Hornpipe', 2);
INSERT INTO 'tunealias' VALUES (437, 3601, 'Craigellachie Lassies, The', 1);
INSERT INTO 'tunealias' VALUES (438, 4267, 'Miss Sophia Campbell', 0);
INSERT INTO 'tunealias' VALUES (439, 2948, 'MacAuleys of Benbecula, The', 1);
INSERT INTO 'tunealias' VALUES (440, 12653, 'Jig O Beer', 1);
INSERT INTO 'tunealias' VALUES (441, 12437, 'Back To Your Roots', 2);
INSERT INTO 'tunealias' VALUES (442, 8316, 'Jacky Tar Hornpipe', 2);
INSERT INTO 'tunealias' VALUES (443, 8952, 'Alexanders'' Ruby', 0);
INSERT INTO 'tunealias' VALUES (400, 11126, 'Freuchie''s March to Lords', 1);
INSERT INTO 'tunealias' VALUES (444, 1013, 'Lord McLay''s Reel', 1);
INSERT INTO 'tunealias' VALUES (445, 10683, 'Tuolomne Tournee', 1);
INSERT INTO 'tunealias' VALUES (446, 1086, 'Mary Hamilton of Auchencruive', 1);
INSERT INTO 'tunealias' VALUES (447, 8403, 'Margaret Mitchell''s Reel', 0);
INSERT INTO 'tunealias' VALUES (448, 2615, 'Miss Barbara Ogalvie', 1);
INSERT INTO 'tunealias' VALUES (449, 3766, 'Duncan MacDonald''s Fancy', 1);
INSERT INTO 'tunealias' VALUES (450, 13311, 'Anne Barnes'' Reel', 1);
INSERT INTO 'tunealias' VALUES (451, 6411, 'Band Boys Polka', 0);
INSERT INTO 'tunealias' VALUES (452, 10368, 'Fiona Robertson''s Reel', 0);
INSERT INTO 'tunealias' VALUES (453, 9099, 'Miss Kate Farrel', 1);
INSERT INTO 'tunealias' VALUES (454, 1001, 'Lochiel''s Awa''', 0);
INSERT INTO 'tunealias' VALUES (455, 1122, 'Miller o'' Drone, The', 0);
INSERT INTO 'tunealias' VALUES (456, 9310, 'New House, The', 0);
INSERT INTO 'tunealias' VALUES (457, 3474, 'Deck the Halls With Boughs Of Holly', 1);
INSERT INTO 'tunealias' VALUES (458, 10121, 'Rudolf the Red Nosed Reindeer', 1);
INSERT INTO 'tunealias' VALUES (459, 10085, 'It Came Upon a Midnight Clear', 1);
INSERT INTO 'tunealias' VALUES (460, 10086, 'See Amid The Winter''s Snow', 1);
INSERT INTO 'tunealias' VALUES (461, 10082, 'We Three Kings Of Orient Are', 0);
INSERT INTO 'tunealias' VALUES (462, 13171, 'Musicians, The', 1);
INSERT INTO 'tunealias' VALUES (463, 4801, 'Mrs Macleod of Geastow', 0);
INSERT INTO 'tunealias' VALUES (464, 3017, 'Willie Man of Paddy', 1);
INSERT INTO 'tunealias' VALUES (465, 5409, 'Willie Walsh''s Jig', 1);
INSERT INTO 'tunealias' VALUES (466, 13197, 'Keith Smith''s Compliments to Cathy Fraser', 1);
INSERT INTO 'tunealias' VALUES (467, 2064, 'Iain Peterson', 0);
INSERT INTO 'tunealias' VALUES (468, 12549, 'Slattesmeden', 1);
INSERT INTO 'tunealias' VALUES (469, 12549, 'Slattesmedden', 1);
INSERT INTO 'tunealias' VALUES (470, 9518, 'Helen and Jimmy King of Auchmelvich', 1);
INSERT INTO 'tunealias' VALUES (471, 12610, 'Melanie Murphy''s', 1);
INSERT INTO 'tunealias' VALUES (472, 10045, 'Alwyn''s Fancy', 0);
INSERT INTO 'tunealias' VALUES (473, 13524, 'Minuet for a Ball', 0);
INSERT INTO 'tunealias' VALUES (474, 13529, 'The Saint Columba''s Anniversary Reel', 1);
INSERT INTO 'tunealias' VALUES (475, 1648, 'Columba''s Sword', 0);
INSERT INTO 'tunealias' VALUES (476, 1648, 'Sword of Saint Columba, The', 0);
INSERT INTO 'tunealias' VALUES (477, 1648, 'Sord Colmcille', 2);
INSERT INTO 'tunealias' VALUES (478, 1648, 'Sword of Columcelle', 0);
INSERT INTO 'tunealias' VALUES (479, 9714, 'Countess of Dalkeith''s Strathspey, The', 0);
INSERT INTO 'tunealias' VALUES (480, 9714, 'Countess of Dalkeith, The', 0);
INSERT INTO 'tunealias' VALUES (527, 3741, 'Miss Fanny Powers', 0);
INSERT INTO 'tunealias' VALUES (481, 12367, 'Saint Antoine''s', 0);
INSERT INTO 'tunealias' VALUES (528, 12186, 'Cairngorum Mountain', 0);
INSERT INTO 'tunealias' VALUES (484, 1775, 'Work of the Weavers, The', 1);
INSERT INTO 'tunealias' VALUES (485, 3622, 'Dan Harry Burton''s Jig', 0);
INSERT INTO 'tunealias' VALUES (529, 12186, 'The Cairngorm Mountains', 0);
INSERT INTO 'tunealias' VALUES (487, 2382, 'Kelly the Boy from Killarney', 1);
INSERT INTO 'tunealias' VALUES (488, 3912, 'Johnnie Cope', 0);
INSERT INTO 'tunealias' VALUES (489, 1157, 'Miss Christy Stewart', 1);
INSERT INTO 'tunealias' VALUES (490, 13485, 'Ruth and Ronnie''s Strathspey', 1);
INSERT INTO 'tunealias' VALUES (491, 13488, 'Causeway Jig', 1);
INSERT INTO 'tunealias' VALUES (492, 13500, 'Lucy and Lyn''s Clinksbag', 1);
INSERT INTO 'tunealias' VALUES (493, 13264, 'Sue Ryder Strathspey', 0);
INSERT INTO 'tunealias' VALUES (494, 13565, 'A Decade of Fun and Delight!', 2);
INSERT INTO 'tunealias' VALUES (495, 13566, 'Dancing Dave', 2);
INSERT INTO 'tunealias' VALUES (496, 191, 'Mr Fletcher''s Delight', 2);
INSERT INTO 'tunealias' VALUES (497, 142, 'New Bob, The', 2);
INSERT INTO 'tunealias' VALUES (238, 1080, 'Royal Gift, The', 2);
INSERT INTO 'tunealias' VALUES (498, 1882, 'Atholl Highlanders, The', 1);
INSERT INTO 'tunealias' VALUES (499, 13414, 'Miss Isabelle Reid''s Reel', 1);
INSERT INTO 'tunealias' VALUES (500, 964, 'Lowland Lads think they are Fine, The', 1);
INSERT INTO 'tunealias' VALUES (501, 539, 'Foula Reel, Da', 1);
INSERT INTO 'tunealias' VALUES (502, 2999, 'John Brennan''s', 0);
INSERT INTO 'tunealias' VALUES (503, 3627, 'Rose of the North, The', 0);
INSERT INTO 'tunealias' VALUES (504, 7622, 'Captn. Ferguson''s Jig', 1);
INSERT INTO 'tunealias' VALUES (530, 12186, 'Cairngorm Mountains', 0);
INSERT INTO 'tunealias' VALUES (506, 13067, 'Lakeside Reel, The', 2);
INSERT INTO 'tunealias' VALUES (507, 13704, 'Max and Anne McNaught', 1);
INSERT INTO 'tunealias' VALUES (508, 13708, 'Change & Go', 1);
INSERT INTO 'tunealias' VALUES (509, 2006, 'Willie Anderson''s Farewell to Dalcharn', 1);
INSERT INTO 'tunealias' VALUES (510, 3616, 'Johnnie MacDonald''s Reel', 0);
INSERT INTO 'tunealias' VALUES (511, 351, 'Cumbernould House', 2);
INSERT INTO 'tunealias' VALUES (512, 351, 'My Lord Aboyne''s Air', 2);
INSERT INTO 'tunealias' VALUES (513, 351, 'My Lord Aboyne''s welcome', 2);
INSERT INTO 'tunealias' VALUES (514, 5562, 'Harriot, The', 1);
INSERT INTO 'tunealias' VALUES (515, 5114, 'Corbie An'' Da Craa, Da', 1);
INSERT INTO 'tunealias' VALUES (516, 5036, 'Corriechoillie''s Welcome', 0);
INSERT INTO 'tunealias' VALUES (517, 5039, 'High Road to Gairloch, The', 1);
INSERT INTO 'tunealias' VALUES (519, 3116, 'Master David Cunningham', 2);
INSERT INTO 'tunealias' VALUES (520, 12165, 'Doreen and Roy Goldring''s Jig', 1);
INSERT INTO 'tunealias' VALUES (521, 13794, 'Bus Pass Polka', 2);
INSERT INTO 'tunealias' VALUES (522, 796, 'Jo and Evelyn Ramwell', 1);
INSERT INTO 'tunealias' VALUES (523, 3946, 'In Garb of Old Gaul', 0);
INSERT INTO 'tunealias' VALUES (533, 13885, 'Da Merry Boys o'' Greenland', 0);
INSERT INTO 'tunealias' VALUES (534, 4130, 'Mo Mhairi Mhin Mheall-Shuileach', 1);
INSERT INTO 'tunealias' VALUES (535, 4130, 'Mo Mhairi Mhin Meall', 0);
INSERT INTO 'tunealias' VALUES (536, 413, 'Mr & Mrs Green', 1);
INSERT INTO 'tunealias' VALUES (537, 7707, 'Memories of Father Angus MacDonald', 1);
INSERT INTO 'tunealias' VALUES (538, 13942, 'Æ Lam', 2);
INSERT INTO 'tunealias' VALUES (539, 3210, 'Braigh Bhanbh', 0);
INSERT INTO 'tunealias' VALUES (540, 3210, 'Braes Of Banffshire, The', 0);
INSERT INTO 'tunealias' VALUES (531, 12186, 'I Ne''er Shall Wean Her', 0);
INSERT INTO 'tunealias' VALUES (541, 3210, 'Highlands of Banffshire, The', 2);
INSERT INTO 'tunealias' VALUES (532, 12186, 'Mrs. Sullivan''s', 0);
INSERT INTO 'tunealias' VALUES (543, 13305, 'Le Vingt Novembre', 1);
INSERT INTO 'tunealias' VALUES (544, 13571, 'Trembling String, The', 1);
INSERT INTO 'tunealias' VALUES (545, 1544, 'Rose of Allandale', 1);
INSERT INTO 'tunealias' VALUES (546, 13969, 'How Can We Abstain From Whisky', 2);
INSERT INTO 'tunealias' VALUES (547, 1132, 'Miss Ann Drummond Smythe''s Reel', 1);
INSERT INTO 'tunealias' VALUES (548, 9051, 'Miss Nichola Jack', 1);
INSERT INTO 'tunealias' VALUES (549, 6312, 'Dancing the Baby', 1);
INSERT INTO 'tunealias' VALUES (550, 7437, 'Miss Barbara A. Stirling', 1);
INSERT INTO 'tunealias' VALUES (551, 12542, 'Gabor and Szilvi of Budapest', 1);
INSERT INTO 'tunealias' VALUES (552, 10148, 'Road to Eroggie, The', 1);
INSERT INTO 'tunealias' VALUES (553, 12094, 'Ann Riley''s Whimsey', 1);
INSERT INTO 'tunealias' VALUES (554, 14105, 'a la Mode', 1);
INSERT INTO 'tunealias' VALUES (555, 14111, 'Cow That Ate the Blanket, The', 2);
INSERT INTO 'tunealias' VALUES (556, 11674, 'Steve Wyrick''s Compliments to Claudette Sigg', 2);
INSERT INTO 'tunealias' VALUES (557, 8847, 'Piper & the Penguin, The', 1);
INSERT INTO 'tunealias' VALUES (558, 8499, 'Margaret and Jim Dewar', 1);
INSERT INTO 'tunealias' VALUES (559, 3001, 'Wing-Commander Donald McKenzie''s Reel', 1);
INSERT INTO 'tunealias' VALUES (560, 8797, 'Anne-Marie Morrison of Borve', 1);
INSERT INTO 'tunealias' VALUES (561, 8797, 'Ann-Marie Morrison of Borve', 1);
INSERT INTO 'tunealias' VALUES (562, 8797, 'Ann-Maree Morrison of Borve', 1);
INSERT INTO 'tunealias' VALUES (563, 2986, 'O Willie Brewed a Peck o'' Maut', 0);
INSERT INTO 'tunealias' VALUES (564, 1867, 'Farqhuar Mathieson', 1);
INSERT INTO 'tunealias' VALUES (565, 1867, 'Farquahar Mathieson', 1);
INSERT INTO 'tunealias' VALUES (566, 12510, 'Shine on Harvest Moon', 1);
INSERT INTO 'tunealias' VALUES (567, 1702, 'Allie Crocker', 1);
INSERT INTO 'tunealias' VALUES (568, 1845, 'Mor a'' Cheannaich', 2);
INSERT INTO 'tunealias' VALUES (569, 2321, 'JF McKenzie of Garrynahine Stornoway', 1);
INSERT INTO 'tunealias' VALUES (570, 2321, 'J. F. MacKenzie Esq. of Garrynahine, Stornoway', 1);
INSERT INTO 'tunealias' VALUES (571, 12414, 'You Made Me Love You (I Didn''t Want to Do It)', 0);
INSERT INTO 'tunealias' VALUES (572, 10262, 'Jim Broon of Kintillo', 1);
INSERT INTO 'tunealias' VALUES (573, 2873, 'Billy Nicholson', 1);
INSERT INTO 'tunealias' VALUES (574, 5593, 'Elenora Robertson''s Favourite', 1);
INSERT INTO 'tunealias' VALUES (575, 13904, 'Mrs Robertson of Lawer''s Delight', 0);
INSERT INTO 'tunealias' VALUES (576, 2621, 'Miss Robertson - Edinburgh', 1);
INSERT INTO 'tunealias' VALUES (577, 7948, 'Mr Robertson of Ludes', 1);
INSERT INTO 'tunealias' VALUES (578, 14188, 'Ian and Isobel of Balnearn', 1);
INSERT INTO 'tunealias' VALUES (579, 5268, 'Mrs George Robertson', 1);
INSERT INTO 'tunealias' VALUES (580, 357, 'D Morrison''s Seven Thistles', 1);
INSERT INTO 'tunealias' VALUES (581, 357, 'Dr Morrison''s Seven Thistles', 1);
INSERT INTO 'tunealias' VALUES (582, 5464, 'Da Road Ta Houll', 1);
INSERT INTO 'tunealias' VALUES (583, 5464, 'Da Road To Houll', 1);
INSERT INTO 'tunealias' VALUES (584, 2134, 'Sir David Davidson of Cantray', 0);
INSERT INTO 'tunealias' VALUES (585, 10749, 'Ben Wilson''s Farewell to Troloss', 1);
INSERT INTO 'tunealias' VALUES (586, 13256, 'Up & Doon the Doldenhorn', 1);
INSERT INTO 'tunealias' VALUES (587, 2650, 'Mr and Mrs T M Robertson', 1);
INSERT INTO 'tunealias' VALUES (588, 2800, 'Rev Peter Fenton', 1);
INSERT INTO 'tunealias' VALUES (589, 17, 'Alex Maxwell''s Farewell to Balmerino', 1);
INSERT INTO 'tunealias' VALUES (590, 6282, '8th Argyll''s Farewell to the 116th Regiment de Ligne', 1);
INSERT INTO 'tunealias' VALUES (591, 5153, 'Sir James G Boyd, Bart.', 1);
INSERT INTO 'tunealias' VALUES (592, 1426, 'Auld Willie Hunter', 0);
INSERT INTO 'tunealias' VALUES (593, 11409, 'Anything Doing?', 0);
INSERT INTO 'tunealias' VALUES (594, 5190, 'Roses of Prince Charlie, The', 0);
INSERT INTO 'tunealias' VALUES (595, 4360, 'Over the Hills and Far Away', 0);
INSERT INTO 'tunealias' VALUES (596, 7599, 'Miss Douglas Brigton''s Jig', 0);
INSERT INTO 'tunealias' VALUES (597, 14214, 'A''ll Chum Ye tae the Bus', 2);
INSERT INTO 'tunealias' VALUES (598, 13896, 'B Times Three', 0);
INSERT INTO 'tunealias' VALUES (599, 11423, 'Troops, The', 0);
INSERT INTO 'tunealias' VALUES (600, 2258, 'Hesleyside', 0);
INSERT INTO 'tunealias' VALUES (601, 471, 'Durrisdeer', 1);
INSERT INTO 'tunealias' VALUES (602, 2670, 'Mrs Dundas of Arniston''s Reel', 0);
INSERT INTO 'tunealias' VALUES (603, 1294, 'Mrs B Jolly', 0);
INSERT INTO 'tunealias' VALUES (604, 9171, 'Hull''s Reel', 0);
INSERT INTO 'tunealias' VALUES (605, 2424, 'Lady Hamilton of Dalrymple', 0);
INSERT INTO 'tunealias' VALUES (606, 2424, 'Lady Dalrymple''s Strathspey', 0);
INSERT INTO 'tunealias' VALUES (607, 10866, 'Sir J. M. Barrie of Thrums', 0);
INSERT INTO 'tunealias' VALUES (608, 1448, 'Fireside Reel, The', 2);
INSERT INTO 'tunealias' VALUES (609, 4293, 'Mr Hamilton of Washaw''s Reel', 1);
INSERT INTO 'tunealias' VALUES (610, 2152, 'Reel De Montréal', 0);
INSERT INTO 'tunealias' VALUES (611, 14301, 'Open the B.... Door', 2);
INSERT INTO 'tunealias' VALUES (612, 14306, 'Pour Jocelyne', 0);
INSERT INTO 'tunealias' VALUES (613, 14307, 'Celie''s Dance', 2);
INSERT INTO 'tunealias' VALUES (614, 14310, 'Pour Joce & Chris', 0);
INSERT INTO 'tunealias' VALUES (615, 14293, 'Alison Baxter''s Tune', 0);
INSERT INTO 'tunealias' VALUES (616, 14326, 'Anne and Alistair''s Reel', 2);
INSERT INTO 'tunealias' VALUES (617, 14350, 'Three Maidens, The', 2);
INSERT INTO 'tunealias' VALUES (619, 14336, 'George and Jane''s Visit to the Fort', 0);
INSERT INTO 'tunealias' VALUES (618, 14379, 'Walking Across the Sands', 1);
INSERT INTO 'tunealias' VALUES (620, 14390, 'All Change for Aberfeldy', 2);
INSERT INTO 'tunealias' VALUES (621, 4034, 'Bonnie Galloway', 1);
INSERT INTO 'tunealias' VALUES (622, 6781, 'Tinker Tyke', 0);
INSERT INTO 'tunealias' VALUES (18, 3545, 'Merry Go-Round, The', 1);
INSERT INTO 'tunealias' VALUES (624, 3545, 'Flirtation Hornpipe', 0);
INSERT INTO 'tunealias' VALUES (625, 2152, 'Flirtation Hornpipe, The', 0);
INSERT INTO 'tunealias' VALUES (626, 10150, 'Montreal Summers', 1);
INSERT INTO 'tunealias' VALUES (627, 4828, 'Miss Russel of Blackhall''s Reel', 1);
INSERT INTO 'tunealias' VALUES (628, 5246, 'Humors of Donnybrook, The', 1);
INSERT INTO 'tunealias' VALUES (629, 2565, 'Miss Agnes Loudon', 0);
INSERT INTO 'tunealias' VALUES (632, 14455, 'Pleiades', 0);
INSERT INTO 'tunealias' VALUES (634, 3250, 'Top of Belvenie, The', 1);
INSERT INTO 'tunealias' VALUES (635, 14467, 'Miss Jean Aberdein', 2);
INSERT INTO 'tunealias' VALUES (636, 3147, 'Mrs Wilson''s Reel', 0);
INSERT INTO 'tunealias' VALUES (637, 11345, 'Bill Forbes'' Strathspey', 1);
INSERT INTO 'tunealias' VALUES (638, 11299, 'David Ross of Rosehall', 0);
INSERT INTO 'tunealias' VALUES (639, 13562, 'Moramaer''s Reel, The', 1);
INSERT INTO 'tunealias' VALUES (640, 2864, 'Young Scottie', 1);
INSERT INTO 'tunealias' VALUES (641, 150, 'Bonny Charlie', 1);
INSERT INTO 'tunealias' VALUES (642, 1981, 'Wellwynd, The', 1);
INSERT INTO 'tunealias' VALUES (643, 5932, 'Inspector Donald Campbell of Ness', 1);
INSERT INTO 'tunealias' VALUES (644, 10809, 'Doctor Boyd''s Jig', 0);
INSERT INTO 'tunealias' VALUES (645, 14535, 'Chambery Blues', 1);
INSERT INTO 'tunealias' VALUES (633, 14459, 'Daniele Landrieau', 1);
INSERT INTO 'tunealias' VALUES (646, 14533, 'Ville Lumiere, La', 1);
INSERT INTO 'tunealias' VALUES (647, 13306, 'Pretty Bride of Prety, The', 0);
INSERT INTO 'tunealias' VALUES (648, 14572, 'Dave at 50', 1);
INSERT INTO 'tunealias' VALUES (649, 10154, 'Alexander Small', 2);
INSERT INTO 'tunealias' VALUES (650, 2234, 'Gran Douglas'' Delight', 1);
INSERT INTO 'tunealias' VALUES (651, 9329, 'Ship of Dreams – The Titanic', 2);
INSERT INTO 'tunealias' VALUES (652, 3914, 'Heilan'' Brochan', 1);
INSERT INTO 'tunealias' VALUES (653, 2358, 'John Gideon Gibson of Cullavoe', 1);
INSERT INTO 'tunealias' VALUES (654, 4348, 'St Johnstoun Reel, The', 0);
INSERT INTO 'tunealias' VALUES (660, 802, 'Welcome to Queen''s Cross', 0);
INSERT INTO 'tunealias' VALUES (656, 485, 'Countess of Cassilli', 0);
INSERT INTO 'tunealias' VALUES (655, 485, 'Countess of Cassillis''s Reel', 0);
INSERT INTO 'tunealias' VALUES (657, 14461, 'Pairtin'' Kiss, A', 0);
INSERT INTO 'tunealias' VALUES (658, 4952, 'Lass o'' Waverley, The', 0);
INSERT INTO 'tunealias' VALUES (659, 14688, 'Peter Bailie', 0);
INSERT INTO 'tunealias' VALUES (661, 1136, 'Miss Baird of Saughton Hall', 0);
INSERT INTO 'tunealias' VALUES (662, 14763, 'Mrs. McInroy of Lude', 0);
INSERT INTO 'tunealias' VALUES (663, 14806, 'Miss Mary Stirling''s Hornpipe', 0);
INSERT INTO 'tunealias' VALUES (664, 12967, 'Andy de Jarlis'' Jig', 1);
INSERT INTO 'tunealias' VALUES (665, 269, 'Cauld Kail', 2);
INSERT INTO 'tunealias' VALUES (666, 1345, 'Mrs Muir McKenzie''s Fancie', 0);
INSERT INTO 'tunealias' VALUES (667, 4904, 'John Keith Lang', 0);
INSERT INTO 'tunealias' VALUES (668, 1453, 'Perthshire Hunt, The', 2);
INSERT INTO 'tunealias' VALUES (669, 14814, 'Miss Gunning''s Reel', 2);
INSERT INTO 'tunealias' VALUES (670, 6876, 'Forth Brig, The', 0);
INSERT INTO 'tunealias' VALUES (671, 14821, 'Cluther Hornpipe, The', 1);
INSERT INTO 'tunealias' VALUES (672, 9289, 'Goggle-Eyed Prawn, The', 1);
INSERT INTO 'tunealias' VALUES (673, 12416, 'Muriel Bell Waltz', 0);
INSERT INTO 'tunealias' VALUES (674, 1334, 'Mary Printy', 0);
INSERT INTO 'tunealias' VALUES (675, 1821, 'Wullafjord', 1);
INSERT INTO 'tunealias' VALUES (676, 7240, 'Kesh, The', 0);
INSERT INTO 'tunealias' VALUES (678, 7022, 'Mrs MacShea of Houston', 0);
INSERT INTO 'tunealias' VALUES (679, 1141, 'Miss Bennet''s Jig', 0);
INSERT INTO 'tunealias' VALUES (680, 14704, 'Roland Telle of Bretagne', 0);
INSERT INTO 'tunealias' VALUES (681, 6254, 'Paardeberg', 0);
INSERT INTO 'tunealias' VALUES (682, 10974, 'My Own Lass', 0);
INSERT INTO 'tunealias' VALUES (683, 9126, 'Streaker, The', 0);
INSERT INTO 'tunealias' VALUES (684, 1656, 'Steamboat, The', 0);
INSERT INTO 'tunealias' VALUES (685, 5786, 'Steamboat, The', 0);
INSERT INTO 'tunealias' VALUES (687, 2943, 'Top of Ben Lomond, The', 0);
INSERT INTO 'tunealias' VALUES (688, 2905, 'Glasgow Reel, The', 2);
INSERT INTO 'tunealias' VALUES (689, 470, 'Sherwood Rangers', 2);
INSERT INTO 'tunealias' VALUES (690, 5962, 'Old Scotch Mother Mine', 2);
INSERT INTO 'tunealias' VALUES (691, 5962, 'Auld Scotch Mither Mine', 2);
INSERT INTO 'tunealias' VALUES (692, 5962, 'Auld Scots Mither O'' Mine', 2);
INSERT INTO 'tunealias' VALUES (693, 5962, 'Auld Scots Mither Mine', 2);
INSERT INTO 'tunealias' VALUES (33, 1373, 'My Love is like a Red Red Rose', 0);
INSERT INTO 'tunealias' VALUES (353, 1373, 'My Luve is like a Red Red Rose', 0);
INSERT INTO 'tunealias' VALUES (694, 1373, 'Oh My Love is like a Red, Red Rose', 0);
INSERT INTO 'tunealias' VALUES (695, 10864, 'Jig for Judy', 1);
INSERT INTO 'tunealias' VALUES (696, 5837, 'Hutchy''s Bash', 1);
INSERT INTO 'tunealias' VALUES (697, 10129, 'Jessie Stewart''s Welcome to Dufftown', 1);
INSERT INTO 'tunealias' VALUES (698, 10129, 'Jessie Stuart of Dufftown', 1);
INSERT INTO 'tunealias' VALUES (699, 10129, 'Jessie Stuart''s Welcome to Dufftown', 0);
INSERT INTO 'tunealias' VALUES (700, 9337, 'Sixty Fathom Reel', 0);
INSERT INTO 'tunealias' VALUES (701, 12492, 'Robert E Lee, The', 0);
INSERT INTO 'tunealias' VALUES (705, 2614, 'Miss McPherson Grant''s Jig', 1);
INSERT INTO 'tunealias' VALUES (703, 2614, 'Miss MacPherson Grant of Ballindalloch''s Jig', 1);
INSERT INTO 'tunealias' VALUES (704, 2614, 'Miss MacPherson Grant''s Jig', 1);
INSERT INTO 'tunealias' VALUES (702, 2614, 'Miss McPherson Grant of Ballindalloch''s Jig', 1);
INSERT INTO 'tunealias' VALUES (706, 2614, 'Miss Mcpherson Grant''s Jig', 1);
INSERT INTO 'tunealias' VALUES (707, 2614, 'Miss Macpherson Grant''s Jig', 1);
INSERT INTO 'tunealias' VALUES (708, 2614, 'Miss Mcpherson Grant of Ballindalloch''s Jig', 1);
INSERT INTO 'tunealias' VALUES (709, 2614, 'Miss Macpherson Grant of Ballindalloch''s Jig', 1);
INSERT INTO 'tunealias' VALUES (710, 2336, 'Jeanie''s Blue Een', 1);
INSERT INTO 'tunealias' VALUES (712, 2336, 'Jeannie''s Blue Een', 1);
INSERT INTO 'tunealias' VALUES (711, 2336, 'Jeanie''s Blue E''en', 1);
INSERT INTO 'tunealias' VALUES (713, 10611, '79th Farewell to Gibraltar', 1);
INSERT INTO 'tunealias' VALUES (714, 5320, 'Muirsheen Durkin', 2);
INSERT INTO 'tunealias' VALUES (715, 11911, 'P.M. George Ross', 0);
INSERT INTO 'tunealias' VALUES (716, 14973, 'Henderson’s Stone', 2);
INSERT INTO 'tunealias' VALUES (717, 14973, 'Clachlarich', 1);
INSERT INTO 'tunealias' VALUES (718, 14973, 'Clachlarick', 1);
INSERT INTO 'tunealias' VALUES (719, 1146, 'Miss C M Barbour', 1);
INSERT INTO 'tunealias' VALUES (720, 1146, 'Miss CM Barbour', 1);
INSERT INTO 'tunealias' VALUES (721, 1146, 'Miss C.M. Barbour', 1);
INSERT INTO 'tunealias' VALUES (722, 9484, 'Newstyle Rhymer, The', 1);
INSERT INTO 'tunealias' VALUES (723, 1527, 'Callanish Vows', 0);
INSERT INTO 'tunealias' VALUES (724, 1527, '71st’s Farewell to Dover, The', 2);
INSERT INTO 'tunealias' VALUES (725, 1527, 'Highland Brigade’s March to Heilbron, The', 2);
INSERT INTO 'tunealias' VALUES (726, 5177, 'Life in the Finnish Woods', 2);
INSERT INTO 'tunealias' VALUES (727, 5177, 'Livet i Finnskogarna', 2);
INSERT INTO 'tunealias' VALUES (728, 9119, 'Katy Shaw''s Reel', 1);
INSERT INTO 'tunealias' VALUES (729, 14765, 'George Darling’s Jig – of Alnwick', 1);
INSERT INTO 'tunealias' VALUES (730, 14991, 'Harry the Hippo', 2);
INSERT INTO 'tunealias' VALUES (731, 14992, 'Tom''s Strathspey', 2);
INSERT INTO 'tunealias' VALUES (732, 92, 'Bruachan Loch Nis', 1);
INSERT INTO 'tunealias' VALUES (733, 407, 'Dovecot, The', 1);
INSERT INTO 'tunealias' VALUES (734, 3672, 'Pachelbel’s Frolics', 2);


--
INSERT INTO 'tunespublicationsmap' VALUES (28, 792, 147, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (29, 2591, 147, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (30, 2602, 147, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (23, 2824, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7132, 14047, 1505, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7133, 14066, 1506, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6153, 12546, 1152, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6155, 12588, 1152, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6156, 12549, 1152, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (76, 668, 75, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (77, 334, 75, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (78, 1657, 75, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5784, 12001, 1099, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5785, 12002, 1099, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5786, 5935, 1099, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5867, 4471, 1103, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5868, 4472, 1103, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5896, 3922, 675, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6131, 12546, 1152, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (41, 1560, 113, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (42, 1736, 113, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (43, 619, 113, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (44, 1709, 113, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (31, 2604, 147, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5980, 503, 1112, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5981, 12193, 1112, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5982, 12194, 1112, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5991, 5865, 1113, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5992, 5949, 1113, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5999, 12202, 995, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6000, 553, 156, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6010, 12227, 1091, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6011, 12233, 1117, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6012, 12234, 1117, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6013, 12235, 1117, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6014, 12236, 1117, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (79, 740, 75, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (80, 1134, 75, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (81, 402, 704, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (82, 386, 704, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (83, 1133, 704, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (84, 167, 704, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (87, 3291, 215, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (88, 3292, 215, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (89, 3293, 215, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (90, 3294, 215, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (91, 3295, 215, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (92, 3299, 232, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (93, 3300, 232, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (98, 3306, 101, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (102, 1971, 305, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (103, 2160, 334, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (104, 3308, 548, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (108, 1665, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (110, 1284, 24, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5883, 12044, 1106, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5884, 12049, 1106, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5885, 12050, 1106, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (10, 206, 761, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (11, 1767, 761, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (12, 1270, 761, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (13, 1826, 761, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (14, 282, 761, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (105, 1759, 29, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (100, 764, 27, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (109, 482, 47, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (74, 48, 176, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (75, 387, 176, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (32, 2606, 147, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (33, 2610, 147, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (34, 2163, 147, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (35, 2617, 147, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (96, 1990, 595, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (97, 1991, 595, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (65, 2193, 136, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (66, 5, 136, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (67, 2209, 136, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (68, 2217, 136, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (69, 2638, 136, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (70, 2242, 136, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (71, 2250, 136, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (72, 2261, 136, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (73, 2267, 136, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6734, 13483, 1342, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6735, 13485, 1342, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6736, 13488, 1342, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6737, 4842, 1342, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (45, 862, 113, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (46, 1754, 113, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (47, 1532, 113, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (48, 703, 113, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (49, 315, 113, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1, 215, 115, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2, 525, 115, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3, 683, 115, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4, 609, 115, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5, 828, 115, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6, 96, 115, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7, 474, 115, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (8, 1353, 115, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (9, 1469, 115, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (101, 1163, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5860, 7253, 95, 12, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5861, 12038, 95, 13, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6154, 12547, 1152, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6132, 12550, 1152, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6157, 12550, 1152, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6158, 12551, 1152, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5826, 9537, 1100, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5827, 8514, 1100, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (111, 1214, 24, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (112, 12, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (118, 23, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (119, 1048, 305, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (122, 3334, 93, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (125, 31, 23, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (126, 3338, 248, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5869, 11595, 1055, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (99, 3307, 580, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (106, 3309, 121, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5870, 11596, 1055, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5997, 322, 1114, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5998, 12201, 1114, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (4876, 445, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4877, 446, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4878, 2183, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (127, 34, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (130, 3340, 563, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (132, 808, 32, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (138, 329, 36, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (139, 3349, 93, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (140, 44, 679, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (142, 35, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (24, 2829, 801, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (25, 1544, 801, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (51, 11, 778, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (52, 1413, 778, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (53, 20, 778, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (54, 89, 778, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (85, 13, 202, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (86, 41, 202, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5882, 12082, 339, 10, 3111);
INSERT INTO 'tunespublicationsmap' VALUES (113, 3317, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (107, 3310, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (144, 49, 24, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (146, 2986, 54, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (147, 614, 23, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (148, 3353, 341, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (149, 1374, 9, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (150, 424, 20, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (151, 53, 108, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (152, 54, 36, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (154, 1356, 35, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6159, 12552, 1152, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (157, 3366, 557, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6740, 13498, 1342, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6741, 13500, 1342, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6742, 13502, 1342, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (137, 346, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (171, 71, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6738, 13491, 1342, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6739, 13495, 1342, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6743, 13504, 1342, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6744, 10838, 1342, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6745, 13508, 1342, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6746, 13509, 1342, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6747, 6257, 1342, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6748, 13512, 1342, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (153, 56, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (143, 1453, 2, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (180, 627, 2, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (194, 1482, 2, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (116, 982, 4, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (198, 318, 4, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (117, 915, 6, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5787, 12003, 1099, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5788, 11930, 1099, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5789, 6509, 1099, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (120, 1015, 6, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (124, 1757, 5, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (160, 1882, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5983, 858, 1112, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5993, 9456, 1113, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6001, 535, 156, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6002, 1046, 156, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6015, 12237, 1117, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (161, 64, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (162, 687, 341, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (163, 1834, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (164, 1621, 11, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (165, 1137, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (166, 1618, 20, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (167, 705, 23, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (190, 3912, 156, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6133, 10226, 1152, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (174, 1227, 11, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6003, 952, 156, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6160, 10226, 1152, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (177, 1010, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (178, 3381, 169, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (181, 81, 189, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (182, 80, 189, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (183, 82, 189, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (184, 243, 36, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (187, 84, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (188, 3390, 305, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (6016, 12238, 1117, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (192, 1674, 33, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (195, 2055, 7, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (202, 1797, 32, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (204, 46, 33, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (134, 47, 151, 1, 5);
INSERT INTO 'tunespublicationsmap' VALUES (205, 537, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5886, 12053, 1106, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5887, 12054, 1106, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5888, 12060, 1106, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (191, 95, 56, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (186, 1081, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (128, 1527, 803, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (201, 1644, 30, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (133, 1226, 27, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (115, 14, 26, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (145, 1082, 26, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (189, 103, 26, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (193, 552, 25, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (196, 1167, 25, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (172, 1533, 44, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (179, 1530, 38, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (131, 3341, 648, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (206, 3297, 175, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (207, 3298, 145, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (135, 593, 477, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (203, 3399, 672, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6162, 12554, 1152, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6134, 12553, 1152, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6163, 12555, 1152, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6164, 12556, 1152, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6161, 12553, 1152, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6167, 12558, 1152, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6168, 12559, 1152, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6135, 10321, 1152, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6165, 10321, 1152, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6166, 12618, 1152, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6136, 2308, 1152, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6170, 12561, 1152, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6137, 12560, 1152, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6169, 12560, 1152, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6138, 12562, 1152, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6173, 12562, 1152, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6148, 12591, 1152, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6139, 12591, 1152, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6172, 12564, 1152, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1841, 1858, 390, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (1865, 1713, 390, 50, 41);
INSERT INTO 'tunespublicationsmap' VALUES (158, 3368, 332, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (159, 3369, 332, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5862, 12039, 95, 11, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6171, 12563, 1152, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (208, 1223, 23, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (210, 602, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (211, 761, 8, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (213, 1915, 93, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (214, 111, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (215, 3409, 93, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6140, 12563, 1152, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (223, 1834, 9, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (224, 1565, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (228, 2680, 24, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (231, 2021, 33, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (234, 953, 8, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (212, 773, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (123, 1290, 16, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (129, 121, 16, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (4863, 9005, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4864, 7323, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5872, 11599, 1055, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5873, 11600, 1055, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5874, 11601, 1055, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4865, 9597, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6749, 13542, 1354, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6750, 13560, 1358, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (6751, 13554, 1358, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (6752, 13561, 1358, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (6753, 347, 1358, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (6754, 13547, 1358, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6755, 13558, 1358, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (6756, 13559, 1358, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (6757, 13556, 1358, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (6758, 13550, 1358, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6759, 685, 1358, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (6760, 13545, 1358, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6761, 13546, 1358, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5965, 12112, 1107, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (200, 944, 141, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (216, 113, 141, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (209, 3407, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (136, 3192, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (141, 3053, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6762, 13551, 1358, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (6763, 13549, 1358, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6764, 13563, 1358, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (6765, 3156, 1358, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (6766, 1027, 1358, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6767, 13544, 1358, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5790, 10565, 1099, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5791, 5770, 1099, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5792, 12004, 1099, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6768, 13562, 1358, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (6769, 13293, 1358, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (251, 3466, 111, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (250, 236, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5984, 1745, 1112, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5985, 2556, 1112, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5986, 1117, 1112, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5994, 9853, 1113, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5995, 12198, 1113, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5996, 9050, 1113, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (170, 70, 156, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (175, 75, 156, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6004, 803, 156, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (237, 992, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (243, 3439, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (248, 1733, 37, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (286, 1069, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (254, 129, 169, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (255, 148, 169, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (257, 310, 7, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (260, 176, 8, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (261, 179, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (262, 180, 9, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (263, 413, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5832, 9481, 1100, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (268, 1257, 169, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (270, 2168, 341, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5833, 2074, 1100, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (273, 198, 334, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (277, 1721, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5834, 12025, 1100, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (281, 1280, 33, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (283, 223, 9, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (275, 448, 1, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (235, 1948, 149, 1, 17);
INSERT INTO 'tunespublicationsmap' VALUES (292, 3511, 334, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5903, 7813, 1108, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5889, 10016, 1106, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5890, 12064, 1106, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5891, 12068, 1106, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (4929, 8264, 866, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4930, 8259, 866, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (217, 3414, 803, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (218, 3415, 803, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (246, 345, 803, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (247, 68, 803, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (284, 447, 30, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (226, 911, 29, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (229, 742, 29, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (242, 1766, 29, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (249, 1276, 28, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (225, 1236, 27, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (280, 589, 27, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (295, 722, 26, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (233, 1361, 25, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (265, 1062, 25, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (266, 392, 25, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (219, 551, 44, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (278, 597, 44, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4931, 1372, 866, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (222, 471, 307, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (259, 3478, 477, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (282, 1958, 648, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4932, 8260, 934, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (4933, 8263, 934, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (4934, 8257, 934, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (287, 2007, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (288, 2731, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (289, 763, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (290, 1753, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4935, 9639, 934, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (258, 3475, 145, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (285, 3506, 145, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (274, 1448, 84, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (269, 2597, 477, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (256, 685, 1, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (239, 137, 2, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (252, 183, 2, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (276, 1638, 2, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (236, 3430, 3, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (240, 138, 6, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (245, 1809, 5, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (232, 1132, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (241, 1355, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5863, 3759, 95, 3, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5864, 3510, 95, 5, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5865, 3873, 95, 7, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6005, 814, 156, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (299, 3513, 305, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (300, 328, 8, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (302, 2561, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (304, 1499, 24, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (309, 897, 20, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (310, 253, 7, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (311, 2019, 341, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (313, 257, 489, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (314, 2022, 341, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6770, 13557, 1358, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (6771, 13553, 1358, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (6772, 6503, 1358, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (6773, 13555, 1358, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (6774, 13548, 1358, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (353, 1741, 1, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (244, 150, 16, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (4905, 498, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4906, 500, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5875, 11602, 1055, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5876, 11603, 1055, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (4907, 1557, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (337, 283, 1, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (372, 350, 1, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (336, 385, 2, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (303, 234, 6, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4965, 9647, 986, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4966, 9648, 986, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4967, 9656, 986, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4968, 9653, 986, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4969, 9651, 986, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4970, 9654, 986, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5793, 9832, 1099, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5794, 12005, 1099, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5795, 2675, 1099, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (322, 452, 6, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (305, 171, 5, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (368, 771, 5, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (371, 349, 5, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (301, 382, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5987, 12195, 1112, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5988, 12196, 1112, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5968, 1181, 1107, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4971, 5562, 724, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (4972, 9694, 724, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (4973, 9695, 724, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (4974, 7806, 724, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4975, 9696, 724, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (306, 3526, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (307, 3529, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (264, 3482, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (296, 3512, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (312, 3532, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (298, 231, 156, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6006, 1380, 156, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (6017, 12239, 1117, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (318, 3539, 93, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (319, 1662, 23, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6007, 6276, 156, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (325, 269, 9, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (317, 425, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (327, 2050, 334, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (331, 1512, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (332, 1467, 34, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (335, 1842, 7, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (338, 2279, 32, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (324, 939, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (344, 290, 23, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (346, 825, 20, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (347, 1692, 7, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (349, 1459, 341, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (350, 2457, 305, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6018, 4087, 1123, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (352, 1511, 7, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (354, 1171, 23, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (355, 1401, 169, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (356, 861, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (357, 873, 11, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (359, 3594, 341, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (360, 327, 341, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (361, 1288, 34, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (362, 1401, 34, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (363, 338, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (365, 341, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (369, 1737, 341, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (374, 362, 11, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (375, 364, 9, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (377, 1557, 32, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (379, 1179, 169, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (380, 989, 8, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (381, 1234, 35, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (384, 381, 23, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (294, 380, 157, 1, 2);
INSERT INTO 'tunespublicationsmap' VALUES (386, 388, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (390, 3682, 305, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (391, 3683, 334, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5906, 558, 1108, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5892, 11469, 1106, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5893, 12074, 1106, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5894, 12077, 1106, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (315, 993, 803, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (382, 3643, 803, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (316, 1002, 30, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (330, 498, 30, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (367, 9, 29, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (341, 1116, 28, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (348, 669, 28, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (373, 1828, 28, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (378, 919, 28, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (334, 1210, 25, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (383, 1094, 25, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (370, 506, 47, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4942, 9641, 934, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (364, 839, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4943, 9642, 934, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (389, 3678, 175, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (333, 3554, 145, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (297, 3282, 84, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (342, 1181, 84, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (366, 344, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (308, 251, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (358, 898, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (387, 396, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (329, 1213, 52, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1871, 37, 390, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (1867, 3946, 390, 50, 46);
INSERT INTO 'tunespublicationsmap' VALUES (1320, 119, 390, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (1870, 4360, 390, 50, 47);
INSERT INTO 'tunespublicationsmap' VALUES (1868, 5343, 390, 50, 48);
INSERT INTO 'tunespublicationsmap' VALUES (5866, 3471, 95, 9, 1);
INSERT INTO 'tunespublicationsmap' VALUES (39, 60, 76, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (40, 573, 76, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5835, 8499, 1100, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5836, 2975, 1100, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5837, 12027, 1100, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5497, 11542, 1031, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5498, 11539, 1031, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5499, 11540, 1031, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5500, 749, 1031, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5501, 11543, 1031, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5502, 1126, 1031, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5503, 11544, 1031, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5504, 11545, 1031, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5505, 11546, 1031, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (5838, 7704, 1100, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5839, 12028, 1100, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5840, 8338, 1100, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5796, 11363, 1099, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5797, 12006, 1099, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5798, 12007, 1099, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6775, 12286, 1134, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6776, 12522, 1134, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6777, 12523, 1134, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6778, 13564, 1134, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5989, 12197, 1112, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (321, 267, 156, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6008, 7102, 156, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (351, 1785, 156, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (6019, 3684, 1123, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6020, 4393, 1123, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6061, 200, 1129, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6062, 671, 1129, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6063, 778, 1129, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (395, 432, 9, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (397, 120, 24, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (400, 2183, 334, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (403, 456, 7, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (406, 1615, 341, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (4944, 1303, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7134, 12560, 1511, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (7135, 14076, 1511, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (5878, 11605, 1055, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5879, 11606, 1055, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (5880, 11607, 1055, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (4945, 4532, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4946, 563, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4947, 1672, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (408, 463, 19, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (413, 1428, 20, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4987, 215, 980, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4989, 3163, 980, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (423, 1228, 32, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (425, 3730, 259, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (426, 2082, 334, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (428, 1360, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (429, 520, 20, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (439, 2185, 341, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (445, 3764, 334, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (447, 1639, 305, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4996, 3164, 980, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (449, 423, 169, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (450, 492, 341, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (453, 1542, 169, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (455, 1415, 8, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (458, 2779, 341, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (459, 3790, 588, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (460, 3788, 588, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (461, 3726, 588, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (462, 1683, 161, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (463, 3311, 161, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (464, 769, 161, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (465, 3570, 161, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (466, 3715, 161, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (467, 874, 161, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5990, 12737, 1112, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (328, 1507, 141, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (376, 3639, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (405, 458, 151, 1, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5909, 12164, 1108, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (5910, 1215, 1108, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (5895, 12078, 1106, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (442, 637, 52, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (456, 1509, 803, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (430, 894, 29, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (433, 517, 29, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (424, 1297, 28, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (435, 1391, 80, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (436, 3527, 80, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (437, 3747, 80, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (427, 1739, 28, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (396, 925, 27, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (407, 1404, 27, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (421, 1371, 27, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (451, 1195, 27, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (431, 762, 26, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (443, 1444, 25, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (402, 3694, 477, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (457, 1154, 38, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6026, 6639, 1127, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6027, 2830, 1127, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (409, 1289, 84, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (393, 1903, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (410, 1519, 84, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (420, 1527, 84, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6028, 5711, 1127, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (4992, 3165, 980, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (438, 3748, 80, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (4994, 609, 980, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4995, 9702, 980, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4991, 3170, 980, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4988, 3171, 980, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5025, 2209, 993, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (441, 964, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (468, 433, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (452, 534, 1, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (394, 415, 1, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (422, 1540, 1, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (446, 598, 1, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (412, 588, 2, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (471, 2106, 3, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (392, 226, 4, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (432, 500, 4, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (469, 539, 4, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (404, 1554, 6, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (415, 2410, 6, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (399, 446, 5, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (401, 451, 5, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (417, 1825, 5, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (440, 2696, 5, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5491, 2076, 1031, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5799, 11167, 1099, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5800, 12008, 1099, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (5801, 2040, 1099, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6779, 13565, 1360, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6780, 13566, 1360, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6009, 3136, 156, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (6021, 12431, 1123, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (472, 543, 161, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (473, 3801, 334, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (475, 819, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (478, 1026, 169, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (479, 1303, 36, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (482, 1672, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (483, 273, 32, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (484, 271, 35, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (486, 1110, 7, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6781, 13567, 1360, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5035, 2213, 993, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1794, 5128, 390, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (501, 1429, 36, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (502, 584, 305, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (503, 3834, 334, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (506, 1209, 23, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (509, 1051, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (511, 1801, 37, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1789, 1658, 390, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (515, 2780, 334, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (516, 912, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5034, 2215, 993, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (518, 887, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (519, 1186, 9, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5033, 2216, 993, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (533, 411, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (537, 2087, 341, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (538, 145, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (539, 647, 169, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (540, 3891, 341, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (543, 377, 24, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (544, 2555, 305, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (548, 1642, 679, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (550, 580, 33, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (554, 3437, 334, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (555, 680, 679, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (558, 512, 24, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (559, 1457, 341, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (5063, 9742, 932, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5064, 8185, 932, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5065, 9743, 932, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5066, 9737, 932, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5067, 8186, 932, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5068, 9744, 932, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5069, 9746, 932, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5070, 9745, 932, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5071, 8184, 932, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5073, 9801, 769, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5074, 9802, 769, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5912, 11260, 1108, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (444, 523, 16, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (419, 753, 16, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (514, 3856, 580, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1748, 829, 390, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5032, 2242, 993, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (525, 631, 30, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (532, 640, 30, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (560, 1066, 30, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (535, 626, 29, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (481, 1309, 28, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (513, 907, 25, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (546, 1489, 47, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (487, 3262, 286, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (494, 3408, 286, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (541, 3892, 648, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (526, 3872, 648, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (505, 3842, 175, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (536, 3889, 175, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (474, 3803, 145, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (545, 3899, 145, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (508, 1744, 84, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (531, 3283, 84, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (497, 3249, 286, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (496, 3264, 286, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6029, 427, 1127, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5029, 2244, 993, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5036, 2245, 993, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (480, 563, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (551, 1108, 1, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (520, 628, 2, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (488, 3263, 253, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (499, 3265, 253, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (490, 3185, 253, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (495, 211, 253, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (491, 266, 253, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6064, 9847, 1130, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6068, 9969, 1130, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (434, 930, 141, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (529, 638, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (530, 3191, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (477, 3808, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (504, 1659, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (500, 3828, 253, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (553, 692, 2, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (542, 654, 4, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (521, 486, 6, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (524, 1329, 6, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (523, 1700, 5, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (527, 1592, 5, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (561, 1513, 5, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (557, 1021, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (485, 568, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (528, 347, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (549, 1731, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (626, 152, 103, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (633, 472, 103, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (635, 708, 103, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (628, 3600, 103, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (638, 961, 103, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (636, 482, 103, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (641, 960, 103, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (629, 1091, 103, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (627, 1106, 103, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (625, 2802, 103, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (634, 643, 103, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1781, 1487, 390, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1745, 3914, 390, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1737, 3767, 390, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1766, 5022, 390, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1795, 1797, 390, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1758, 967, 390, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1755, 1796, 390, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1786, 5029, 390, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1750, 842, 390, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1756, 949, 390, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1763, 4895, 390, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1778, 1289, 390, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1776, 2122, 390, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1770, 5274, 390, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1751, 2415, 390, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1775, 4270, 390, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1747, 823, 390, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1741, 2219, 390, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1742, 5412, 390, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (5075, 9803, 769, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5076, 9804, 769, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5077, 9805, 769, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5078, 9806, 769, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5079, 9807, 769, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5802, 7067, 1099, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5803, 12009, 1099, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5804, 12010, 1099, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5645, 11011, 1063, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5646, 10228, 1063, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5647, 8316, 1063, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5648, 1370, 1063, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6022, 12432, 1123, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6023, 12435, 1123, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6024, 12433, 1123, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (565, 29, 24, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5492, 1533, 1031, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (568, 194, 11, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (569, 1820, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (570, 693, 334, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (571, 1036, 35, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (572, 3952, 334, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (573, 1044, 169, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (577, 755, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (578, 1102, 305, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (579, 1497, 33, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (580, 3965, 588, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5649, 4500, 1063, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (582, 1732, 8, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (586, 1191, 9, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (587, 337, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (589, 807, 9, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (590, 823, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2654, 7487, 435, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (592, 815, 33, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (596, 3997, 341, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (597, 923, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (598, 1252, 679, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5493, 88, 1031, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (601, 4006, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5494, 8237, 1031, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (603, 880, 341, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (605, 2385, 341, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (606, 886, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (607, 891, 9, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (611, 913, 341, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (613, 1219, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (614, 918, 7, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (615, 920, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (616, 928, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2655, 7489, 435, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (619, 937, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (620, 1000, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (624, 1414, 35, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5495, 11541, 1031, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5496, 10163, 1031, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5844, 8792, 1100, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5845, 12031, 1100, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5846, 10870, 1100, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5847, 8798, 1100, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5848, 12032, 1100, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (5849, 8513, 1100, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (637, 962, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (640, 960, 8, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5080, 9808, 769, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5081, 9809, 769, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5082, 9810, 769, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5083, 9811, 769, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5084, 9812, 769, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2656, 7490, 435, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (2657, 7491, 435, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (507, 610, 16, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (593, 3990, 580, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2658, 7493, 435, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (584, 775, 151, 1, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6782, 7912, 727, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6783, 1042, 727, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6784, 2724, 727, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6785, 687, 727, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (6786, 7922, 727, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6787, 231, 727, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (5805, 12011, 1099, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5806, 12012, 1099, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5807, 12013, 1099, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6788, 10993, 727, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (6789, 588, 727, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (566, 728, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (576, 1629, 2, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (594, 843, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (609, 902, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (617, 4023, 156, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6025, 12434, 1123, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (588, 794, 52, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (642, 2565, 341, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (644, 318, 169, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (645, 967, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (647, 1408, 679, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5915, 3695, 1108, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (5916, 12165, 1108, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (599, 2996, 286, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (6030, 480, 1127, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (604, 435, 26, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (612, 1029, 26, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (564, 1172, 47, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (608, 4016, 648, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (575, 1813, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (639, 2418, 477, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5085, 9816, 771, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5086, 9817, 771, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (563, 3934, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (595, 2873, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5087, 9818, 771, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5088, 9819, 771, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5089, 9820, 771, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5090, 9821, 771, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5091, 9822, 771, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5092, 9823, 771, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5093, 9824, 771, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5094, 9825, 771, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6031, 324, 1127, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6032, 555, 1127, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6033, 542, 1127, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6034, 548, 1127, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6035, 9714, 1127, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (630, 348, 103, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (631, 433, 103, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (632, 439, 103, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (650, 997, 23, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (657, 1689, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (658, 169, 24, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (668, 3078, 334, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (669, 1235, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (670, 21, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (671, 4074, 341, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (674, 1566, 305, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (675, 1619, 679, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (676, 986, 8, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (680, 126, 8, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (681, 4100, 341, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (687, 4138, 292, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (688, 4139, 292, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (689, 4140, 292, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (690, 4141, 292, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (691, 4142, 292, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (692, 4143, 292, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (693, 4144, 292, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (694, 4145, 292, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (695, 4146, 292, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (696, 4147, 292, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (699, 4150, 302, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (700, 4151, 302, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (701, 4152, 302, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (702, 4153, 302, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (703, 4154, 302, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (704, 4155, 302, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (705, 4156, 302, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (706, 4157, 302, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (707, 4158, 302, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (708, 4159, 302, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (709, 4160, 302, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (710, 4161, 302, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (711, 4162, 563, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (714, 1043, 9, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (715, 1046, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (717, 1590, 35, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (718, 326, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (722, 4192, 341, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6790, 283, 727, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (6791, 1059, 727, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (664, 603, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (678, 704, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5636, 11667, 1062, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (663, 1001, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (677, 1030, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (739, 1111, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (732, 1103, 1, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (661, 3156, 4, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (737, 1107, 4, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (648, 974, 6, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (746, 1136, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5637, 11668, 1062, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (5638, 11669, 1062, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (662, 991, 103, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1784, 1585, 390, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1743, 2225, 390, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1791, 1149, 390, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1733, 5516, 390, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1771, 1175, 390, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1759, 974, 390, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1783, 4665, 390, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1792, 1385, 390, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1760, 986, 390, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1739, 5866, 390, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1774, 2630, 390, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1735, 6041, 390, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5808, 12014, 1099, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (5809, 12015, 1099, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (5810, 6999, 1099, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1761, 1017, 390, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1729, 2525, 390, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (660, 3946, 156, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (643, 963, 156, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (723, 4193, 563, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (726, 1090, 679, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (728, 1095, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (729, 2307, 11, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (733, 4207, 336, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (673, 1012, 16, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (724, 4194, 580, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5097, 622, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5098, 623, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5099, 624, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5100, 626, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1734, 4799, 390, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (735, 1105, 7, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (736, 2762, 305, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (738, 636, 334, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (744, 2567, 336, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (747, 1141, 20, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (749, 1145, 20, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (751, 1157, 341, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (752, 1159, 9, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (753, 1161, 341, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (754, 835, 9, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (755, 1321, 20, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (756, 1164, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (758, 1192, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1773, 2528, 390, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (760, 1197, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5945, 12173, 1108, 10, 101);
INSERT INTO 'tunespublicationsmap' VALUES (672, 969, 26, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (741, 351, 26, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (742, 1017, 25, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (748, 222, 25, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1730, 329, 390, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1790, 5446, 390, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (659, 1266, 286, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (713, 4164, 672, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (720, 4187, 648, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (649, 4052, 648, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (651, 977, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (656, 1907, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (679, 4089, 175, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (730, 4204, 175, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (731, 4205, 175, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (655, 4062, 145, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (719, 4184, 145, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (667, 1324, 84, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (686, 4103, 84, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (743, 1364, 253, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6036, 2832, 1127, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6037, 2596, 1127, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6038, 2829, 1127, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1749, 834, 390, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1753, 2424, 390, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1772, 2764, 390, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1736, 5654, 390, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1777, 4760, 390, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7096, 1132, 1485, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5850, 12033, 1100, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7138, 14132, 1515, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (652, 4053, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (665, 3036, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (654, 4056, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5851, 12034, 1100, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5852, 12035, 1100, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (761, 1204, 20, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (762, 1600, 679, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (764, 2648, 341, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (765, 3604, 119, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (766, 1218, 34, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (767, 1220, 119, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (768, 1221, 20, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (771, 1230, 20, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (772, 2628, 305, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (776, 1173, 37, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (778, 4281, 341, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (779, 1009, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (780, 1255, 679, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (781, 139, 679, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (785, 1262, 11, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (786, 1119, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (787, 1264, 305, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (788, 1267, 20, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (791, 1296, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (793, 1317, 23, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (797, 248, 35, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (800, 61, 33, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (801, 1370, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6792, 1391, 1362, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6793, 3527, 1362, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6796, 13575, 1364, 30, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6797, 13576, 1364, 30, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6798, 3052, 1364, 30, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6799, 13577, 1364, 30, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6800, 13578, 1364, 30, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6801, 13579, 1364, 30, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6810, 13620, 1381, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (36, 2618, 147, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (37, 2633, 147, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (38, 2632, 147, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (841, 1458, 1, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (4021, 633, 526, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4022, 1697, 526, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5811, 2584, 1099, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (5812, 3116, 1099, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (5813, 2036, 1099, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (4023, 1795, 526, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (725, 1087, 156, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5853, 11812, 1100, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (804, 1200, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (807, 1559, 34, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (810, 900, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (811, 1389, 9, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (812, 4341, 341, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (813, 1767, 336, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5854, 2319, 1100, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (821, 4358, 341, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (822, 4361, 11, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (823, 1351, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (828, 78, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (830, 1286, 34, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (831, 4378, 588, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (832, 1435, 34, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5855, 8515, 1100, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (837, 1830, 32, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (757, 1168, 151, 1, 13);
INSERT INTO 'tunespublicationsmap' VALUES (842, 1383, 108, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (843, 1755, 108, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (844, 135, 108, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (845, 1663, 108, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (846, 796, 108, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (847, 985, 108, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (854, 4405, 563, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (856, 1277, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (857, 203, 36, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (858, 4411, 557, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (859, 3596, 557, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (860, 3861, 557, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (861, 4068, 557, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (864, 3146, 305, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (865, 1473, 7, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (866, 4416, 334, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (868, 1478, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (769, 1229, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (867, 824, 6, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5116, 687, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5117, 909, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5118, 692, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5152, 1191, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5153, 791, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (851, 1677, 29, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (794, 1320, 28, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (796, 1237, 28, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (816, 393, 28, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (770, 1587, 27, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (777, 1293, 27, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (827, 1554, 26, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (792, 1312, 44, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (790, 1287, 38, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (834, 4383, 648, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (817, 3057, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (863, 4221, 220, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (773, 4274, 175, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (819, 4355, 145, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (820, 4356, 145, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (783, 2645, 84, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (802, 696, 38, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (836, 1768, 38, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (784, 1651, 286, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (824, 3178, 286, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (805, 2614, 672, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (826, 724, 672, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (840, 2887, 253, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (815, 117, 253, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (799, 1319, 672, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (6039, 5709, 1127, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6040, 1065, 1127, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (795, 706, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (809, 1380, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (839, 1454, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (862, 148, 103, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (852, 4034, 327, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (838, 2761, 1, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6794, 1319, 1363, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6795, 1226, 1363, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (818, 733, 1, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (833, 4382, 3, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (825, 850, 4, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (782, 300, 5, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (872, 4429, 334, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (873, 1345, 36, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (874, 1202, 37, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (875, 1156, 37, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (876, 4435, 334, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (877, 1506, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (879, 4446, 588, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6805, 13617, 1381, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6808, 13618, 1381, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6809, 13619, 1381, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6814, 13622, 1381, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6815, 7716, 1381, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (936, 2869, 281, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5828, 2983, 1100, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5829, 2228, 1100, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5830, 12024, 1100, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (745, 281, 141, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (853, 1347, 141, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7139, 14109, 1515, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7137, 14102, 1515, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (775, 4275, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (763, 656, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5831, 8525, 1100, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (903, 1553, 6, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5814, 6327, 1099, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (5815, 12016, 1099, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (5816, 12017, 1099, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (922, 926, 5, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (803, 1375, 156, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (806, 1378, 156, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (881, 720, 23, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (883, 57, 32, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (885, 4463, 557, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (871, 1487, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (938, 1597, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (912, 791, 52, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (882, 1521, 103, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (887, 1695, 103, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1764, 1046, 390, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1782, 2822, 390, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1744, 148, 390, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (904, 1480, 34, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1333, 1884, 390, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (906, 4481, 341, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (908, 4483, 334, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (911, 1761, 24, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (913, 1488, 37, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (916, 4503, 93, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (919, 905, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (920, 4509, 341, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (923, 1508, 18, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (925, 4515, 248, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (926, 4517, 119, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (927, 899, 24, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (930, 702, 22, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (932, 4521, 508, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (937, 465, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (939, 1603, 226, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (940, 516, 226, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (941, 738, 226, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (942, 1534, 226, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (944, 4532, 341, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (946, 4535, 557, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (921, 1577, 151, 1, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1785, 4656, 390, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1738, 2179, 390, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1793, 4840, 390, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1349, 133, 390, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1825, 2720, 390, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1300, 3389, 390, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1814, 927, 390, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1799, 4043, 390, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1807, 4936, 390, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1828, 4572, 390, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1831, 5347, 390, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1815, 2440, 390, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1824, 1403, 390, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1822, 2706, 390, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1810, 3894, 390, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1804, 3662, 390, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1806, 4931, 390, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1818, 2692, 390, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1817, 2486, 390, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (902, 4475, 580, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (798, 810, 13, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5154, 794, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5155, 3115, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6804, 12662, 1374, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (878, 1701, 803, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (943, 1248, 30, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (924, 1580, 25, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (894, 261, 589, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (895, 1376, 589, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (909, 4485, 175, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (929, 4520, 220, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (918, 1570, 84, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (935, 3284, 84, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (934, 4522, 672, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (914, 3166, 253, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6042, 1516, 1127, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5841, 12029, 1100, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5842, 11821, 1100, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5843, 12030, 1100, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5856, 8244, 1100, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (5857, 8401, 1100, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (5858, 12036, 1100, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (7147, 14138, 1521, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7148, 14139, 1521, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7149, 14140, 1521, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7150, 14141, 1521, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7151, 14142, 1521, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7152, 14143, 1521, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7153, 14144, 1521, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7154, 14145, 1521, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7155, 14146, 1521, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7156, 14147, 1521, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7157, 14148, 1521, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7158, 14149, 1521, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6822, 13635, 1386, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6823, 13636, 1386, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6824, 13637, 1386, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1038, 569, 281, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1039, 2948, 281, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5817, 2184, 1099, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (5818, 12018, 1099, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (5819, 12019, 1099, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1040, 2939, 281, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (980, 2554, 305, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (983, 4557, 588, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (988, 4562, 248, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (990, 4574, 557, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1000, 1327, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1006, 4586, 509, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1012, 4595, 557, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1015, 2920, 10, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1017, 4602, 341, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1018, 4604, 557, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1028, 1714, 36, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1029, 4610, 11, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1030, 1717, 8, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1034, 780, 679, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6811, 9411, 1381, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1014, 1100, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1016, 1301, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6812, 6574, 1381, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6813, 13621, 1381, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6816, 13414, 1381, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6817, 13623, 1381, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6818, 7028, 1381, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5859, 12037, 1100, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1052, 363, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1053, 1079, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1054, 1616, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1055, 274, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1056, 1152, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5228, 997, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7143, 199, 1518, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5229, 982, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5227, 129, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (917, 1569, 141, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (910, 1484, 141, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7140, 11674, 1515, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7141, 11672, 1515, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7142, 14112, 1515, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (947, 1067, 60, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (948, 3, 60, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (949, 1349, 60, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (880, 4447, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (888, 3042, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (889, 4468, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (950, 1340, 60, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (933, 4518, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1010, 4593, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5820, 12020, 1099, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (5821, 12021, 1099, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (5822, 12022, 1099, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1057, 275, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6240, 12690, 1159, 10, 61);
INSERT INTO 'tunespublicationsmap' VALUES (6241, 12691, 1159, 10, 62);
INSERT INTO 'tunespublicationsmap' VALUES (979, 4543, 156, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (982, 2703, 156, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (991, 3296, 102, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (992, 3331, 102, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (993, 122, 102, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (994, 4575, 102, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (995, 3541, 102, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (981, 417, 803, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1036, 1251, 28, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1003, 476, 26, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (987, 1637, 44, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1031, 4613, 648, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1007, 4588, 145, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1037, 1833, 570, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1013, 4404, 589, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1005, 1144, 38, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1041, 2939, 286, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1009, 2506, 286, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (978, 3033, 672, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1001, 2115, 672, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1004, 3956, 672, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (6043, 309, 1127, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6044, 103, 1127, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6045, 1368, 1127, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6046, 4260, 1127, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6047, 1544, 1127, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (6048, 2608, 1127, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1058, 1418, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1059, 1825, 15, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1020, 1992, 121, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1021, 3557, 121, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1022, 3705, 121, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (961, 601, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (962, 91, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (963, 1042, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6821, 4475, 1374, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (6819, 13604, 1374, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (6820, 13605, 1374, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1023, 3953, 121, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1024, 4172, 121, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1025, 4501, 121, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1026, 4502, 121, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5188, 899, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5189, 900, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5190, 901, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5191, 904, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5192, 905, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5193, 906, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5194, 907, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5195, 912, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5196, 913, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5197, 1546, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5249, 1046, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5250, 1051, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5251, 1054, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5252, 1309, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5253, 1590, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1060, 1333, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6825, 5905, 938, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6826, 8938, 938, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6827, 7415, 938, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6828, 8903, 938, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6829, 13638, 938, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6830, 13639, 938, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6831, 13640, 938, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6832, 7620, 938, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6833, 7621, 938, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6834, 7622, 938, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1033, 1734, 4, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1011, 181, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1065, 4634, 557, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1066, 437, 35, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1067, 4636, 557, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1068, 4641, 588, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1069, 1751, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1070, 1201, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1072, 4649, 563, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1076, 4661, 119, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1077, 4663, 8, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1078, 292, 20, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1079, 4673, 557, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1082, 4679, 563, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1087, 2976, 341, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1089, 4693, 588, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6835, 7623, 938, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6836, 13641, 938, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6837, 8035, 938, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6838, 13642, 938, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1061, 299, 15, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1119, 876, 2, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1075, 313, 4, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1086, 1804, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1101, 1359, 19, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1108, 1829, 14, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1104, 1821, 305, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (1106, 2994, 341, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1109, 4706, 588, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1110, 1711, 37, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1111, 1838, 21, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1112, 1841, 7, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1064, 1322, 17, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1115, 1427, 704, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1118, 2285, 305, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (1120, 884, 384, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (1121, 1189, 384, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (1122, 112, 384, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1123, 3031, 384, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1124, 2600, 384, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1125, 2891, 384, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1126, 3540, 384, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1127, 1751, 384, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1128, 4059, 384, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1129, 1843, 384, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1130, 5443, 384, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1131, 5444, 384, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1132, 5445, 384, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1133, 5446, 384, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1134, 5447, 384, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1135, 152, 384, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1823, 1389, 390, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1809, 3862, 390, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1826, 5408, 390, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1813, 4935, 390, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1827, 1627, 390, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1796, 3160, 390, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1797, 1882, 390, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1803, 2031, 390, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1798, 1901, 390, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1808, 581, 390, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1305, 384, 390, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1805, 2110, 390, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1802, 3524, 390, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1812, 2135, 390, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1821, 1378, 390, 50, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1800, 2792, 390, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1801, 189, 390, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1830, 4942, 390, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1811, 661, 390, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1819, 1360, 390, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1816, 2468, 390, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1820, 1375, 390, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1829, 1665, 390, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (959, 1646, 60, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (984, 403, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1063, 4631, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1071, 4644, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1849, 3234, 390, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1845, 3237, 390, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1842, 3371, 390, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1169, 1311, 590, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5823, 6329, 1099, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (5824, 11820, 1099, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (5825, 12023, 1099, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1170, 3877, 590, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1088, 2806, 156, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1085, 1802, 156, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1171, 650, 590, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1173, 1624, 590, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1136, 5448, 384, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1137, 955, 384, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1138, 5449, 384, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1139, 997, 384, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1140, 5450, 384, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1073, 1760, 151, 1, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1141, 5451, 384, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1142, 5452, 384, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1143, 5453, 384, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1144, 5454, 384, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1145, 2540, 384, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1146, 1950, 384, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1147, 2774, 384, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1148, 1046, 384, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1149, 5456, 384, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1150, 318, 384, 50, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1151, 5457, 384, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1152, 5458, 384, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (1153, 5459, 384, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1154, 1360, 384, 50, 35);
INSERT INTO 'tunespublicationsmap' VALUES (5960, 11646, 1108, 10, 129);
INSERT INTO 'tunespublicationsmap' VALUES (1114, 2748, 761, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1081, 759, 29, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1155, 4801, 27, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1172, 1140, 590, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1083, 4680, 145, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1160, 1076, 589, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1105, 2990, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1117, 1386, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1162, 1666, 589, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1090, 4287, 640, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1091, 3854, 640, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1092, 2846, 640, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1163, 1241, 589, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1164, 608, 589, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1165, 405, 589, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1166, 782, 589, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1167, 1524, 589, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1161, 106, 589, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1168, 1413, 589, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1174, 2144, 590, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1156, 3086, 691, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (1158, 2799, 691, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1157, 2278, 691, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5286, 1161, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1062, 197, 38, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6049, 1346, 1127, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1074, 3269, 253, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1084, 3270, 253, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1189, 2679, 588, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1190, 2689, 591, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1198, 1603, 385, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (1183, 1636, 590, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1182, 1118, 590, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1184, 3357, 590, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1186, 2822, 590, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1185, 1884, 590, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6839, 13644, 1383, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6840, 13645, 1383, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6841, 13646, 1383, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6842, 13647, 1383, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1289, 2989, 387, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (1290, 2190, 387, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (1291, 2192, 387, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1292, 3164, 387, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1197, 5343, 803, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1191, 4049, 600, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (1192, 3333, 600, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1188, 4359, 594, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1196, 4451, 589, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1265, 5909, 286, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (1271, 5911, 286, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1272, 5912, 286, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1273, 5913, 286, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1274, 5914, 286, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1256, 658, 253, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (1257, 5503, 253, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1258, 5519, 253, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1259, 5904, 253, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1260, 5905, 253, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1261, 5906, 253, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1262, 5907, 253, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1263, 5908, 253, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (6843, 13648, 1383, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1255, 2249, 2, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1187, 2577, 590, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (1175, 450, 590, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1176, 4307, 590, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1177, 1806, 590, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1179, 1042, 590, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1178, 812, 590, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1181, 1026, 590, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1180, 456, 590, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (5370, 8189, 774, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5371, 6109, 774, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5372, 9880, 774, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5373, 9883, 774, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5374, 8170, 774, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5375, 5390, 994, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5376, 4318, 994, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5377, 5821, 994, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5378, 7680, 994, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5379, 2835, 994, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5380, 7453, 994, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (5381, 9167, 994, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5382, 9332, 994, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5384, 9885, 995, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5390, 9891, 995, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (5385, 9886, 995, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5393, 9894, 995, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5386, 9887, 995, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5388, 9889, 995, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5389, 9890, 995, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5392, 9893, 995, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5383, 9884, 995, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5387, 9888, 995, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5287, 1167, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5288, 1171, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5289, 1172, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5290, 1173, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5291, 1175, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5292, 6685, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5293, 1177, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5294, 1178, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5322, 1248, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5323, 1250, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5324, 1251, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5325, 4483, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5326, 1257, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5327, 1262, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5328, 1263, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5329, 1280, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5330, 1283, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5331, 1286, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5332, 1287, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5333, 1290, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5334, 3137, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5335, 1293, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5336, 1301, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1250, 5707, 386, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5337, 1307, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5338, 1312, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5339, 1317, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5340, 1320, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5341, 1329, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5342, 2680, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5343, 4801, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5394, 9895, 995, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (5391, 9892, 995, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1298, 5989, 389, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1302, 5984, 389, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1303, 5985, 391, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1304, 2514, 391, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (1308, 5992, 389, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1311, 5993, 389, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1313, 2754, 389, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1314, 66, 389, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1322, 2781, 391, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1324, 27, 391, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1326, 4769, 389, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1327, 1876, 389, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1328, 49, 391, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1329, 56, 391, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1332, 5286, 391, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1334, 3373, 389, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1335, 71, 391, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1336, 1890, 391, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1344, 104, 391, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1345, 4551, 391, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1347, 4758, 389, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1348, 1948, 389, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1350, 4751, 389, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1352, 143, 391, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1353, 145, 391, 50, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1355, 150, 389, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1356, 1957, 389, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1357, 152, 391, 50, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1358, 155, 389, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1359, 2114, 389, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1367, 2507, 391, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1368, 4005, 391, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1369, 191, 391, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1370, 193, 391, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5401, 9969, 1001, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5402, 7436, 1001, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5403, 9645, 1001, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5404, 2766, 1002, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5405, 9973, 1002, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5406, 9974, 1008, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5407, 9975, 1008, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5408, 9976, 1008, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5409, 9977, 1008, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5410, 109, 303, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5411, 58, 303, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5412, 4708, 303, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5413, 1122, 303, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5421, 242, 303, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5422, 2718, 303, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5423, 1352, 303, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5424, 398, 303, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5425, 3561, 303, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5426, 2963, 303, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5427, 2737, 303, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5428, 68, 303, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5429, 850, 303, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5430, 5162, 303, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5396, 9897, 995, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5399, 9143, 995, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (5398, 9139, 995, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5400, 9146, 995, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (5395, 9896, 995, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (5397, 9156, 995, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1373, 218, 391, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1375, 223, 389, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1376, 2423, 391, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5360, 2800, 990, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5358, 9841, 990, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5361, 9161, 990, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5359, 2531, 990, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1310, 4269, 390, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1323, 3323, 390, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1372, 3495, 390, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1318, 6005, 390, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1354, 150, 390, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1341, 1898, 390, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1360, 164, 390, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1319, 68, 390, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1340, 4759, 390, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1377, 1983, 390, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1299, 3033, 390, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1385, 4829, 391, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1388, 252, 391, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1394, 1842, 391, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5431, 1380, 303, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5432, 9999, 1013, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5433, 9996, 1013, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5434, 9998, 1013, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5435, 9584, 1013, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5443, 1158, 1022, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5444, 964, 1022, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5445, 806, 1022, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5446, 277, 11, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5451, 11490, 1026, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5463, 11175, 1030, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5464, 10764, 1030, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5465, 7575, 1030, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5466, 11177, 1030, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5439, 9595, 1015, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5447, 11470, 1025, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5448, 11471, 1025, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5449, 10690, 1025, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5440, 3831, 1021, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5441, 2574, 1021, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5442, 33, 1021, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6856, 13661, 1383, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (6858, 13663, 1383, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (5454, 10057, 1029, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6060, 360, 1127, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1386, 3528, 390, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1382, 12082, 390, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1389, 255, 390, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1392, 269, 390, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1391, 2029, 390, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1546, 1687, 285, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5467, 1895, 1030, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5468, 11178, 1030, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5469, 11180, 1030, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5470, 2975, 1030, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5471, 1126, 1030, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5472, 3601, 1030, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5473, 10653, 1030, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5474, 11183, 1030, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5475, 11528, 1030, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5476, 11529, 939, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5477, 9140, 939, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5478, 11530, 939, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5479, 9651, 939, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5480, 11531, 939, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5481, 11532, 939, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5482, 11533, 939, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5483, 9141, 939, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5484, 9136, 939, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5485, 9142, 939, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5486, 11534, 939, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5487, 11535, 939, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5488, 11536, 939, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5489, 11537, 939, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1598, 209, 392, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1610, 284, 391, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1611, 2535, 391, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1612, 3660, 391, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1613, 3706, 391, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1614, 4825, 391, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1615, 439, 391, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1616, 2151, 391, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1617, 2181, 391, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1618, 5369, 391, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1619, 3797, 391, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1620, 624, 391, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1621, 2235, 391, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1622, 648, 391, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1623, 3876, 391, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1624, 6121, 391, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1625, 3210, 391, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1626, 5361, 391, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (1627, 5144, 391, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1628, 4050, 391, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1629, 726, 391, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1630, 4382, 391, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1631, 2307, 391, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5490, 11538, 939, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (5506, 11317, 1024, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5507, 11321, 1024, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5508, 11315, 1024, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5509, 11332, 1024, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5510, 11323, 1024, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5511, 11324, 1024, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5512, 11311, 1024, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5513, 1542, 1024, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5514, 11320, 1024, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (5515, 11330, 1024, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (5516, 713, 1024, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (5517, 416, 1024, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (5518, 11328, 1024, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (5519, 10314, 1035, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (5520, 10312, 1035, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (5521, 9542, 1035, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (5522, 2988, 1035, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (5523, 10313, 1035, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (5524, 10317, 1035, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (5525, 10318, 1035, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (5526, 10320, 1035, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (5527, 10321, 1035, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (5528, 10322, 1035, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (5529, 3564, 1035, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (5530, 10323, 1035, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (5531, 10324, 1035, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (5532, 10325, 1035, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (1632, 810, 391, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1633, 843, 391, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1634, 915, 391, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1635, 2431, 391, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1636, 898, 391, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1637, 3832, 391, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1638, 2427, 391, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1639, 914, 391, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1640, 890, 391, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1641, 949, 391, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1642, 2563, 391, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1643, 4603, 391, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1644, 2104, 391, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1645, 1008, 391, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1646, 991, 391, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1647, 1067, 391, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1648, 3588, 391, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1649, 1050, 391, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1650, 4173, 391, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1651, 1108, 391, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1652, 1141, 391, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1653, 2636, 391, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1654, 1140, 391, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1655, 2764, 391, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1656, 2623, 391, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1657, 1257, 391, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1658, 4292, 391, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1659, 2670, 391, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1660, 2517, 391, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1661, 1311, 391, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1662, 2516, 391, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1663, 1400, 391, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1664, 4830, 391, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1665, 4555, 391, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1666, 2094, 391, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1667, 2093, 391, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1668, 1412, 391, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1669, 3154, 391, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1670, 2797, 391, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1671, 1518, 391, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1672, 1588, 391, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1673, 4539, 391, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1674, 5151, 391, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1675, 3496, 391, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1676, 3036, 391, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1677, 4537, 391, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1678, 1711, 391, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1679, 1840, 391, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1680, 1838, 391, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1681, 2806, 391, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1682, 5413, 391, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1683, 1379, 391, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1684, 3324, 391, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (1685, 3400, 391, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1686, 3236, 391, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1687, 3358, 391, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (1688, 942, 391, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (1689, 5486, 391, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1690, 1533, 391, 50, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1691, 2857, 391, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1692, 4785, 391, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (1693, 5544, 391, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (1694, 2898, 391, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (1695, 4522, 391, 50, 42);
INSERT INTO 'tunespublicationsmap' VALUES (1696, 3255, 391, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (1697, 4793, 391, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1698, 1980, 391, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1699, 295, 391, 50, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1700, 415, 391, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1701, 452, 391, 50, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1702, 6136, 391, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (1703, 629, 391, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1704, 2200, 391, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (1705, 625, 391, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (1706, 2309, 391, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1707, 2287, 391, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1708, 728, 391, 50, 35);
INSERT INTO 'tunespublicationsmap' VALUES (1709, 5542, 391, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5533, 10326, 1035, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (5534, 6500, 1035, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (5535, 10327, 1035, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (5536, 10328, 1035, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (5537, 10329, 1035, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (5538, 10794, 1035, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (5539, 10330, 1035, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (5540, 10331, 1035, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (5541, 10332, 1035, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (5542, 10333, 1035, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (5543, 10796, 1035, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (5544, 11549, 1035, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (5545, 11550, 1035, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (5546, 11551, 1035, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (6866, 13671, 1383, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (6867, 13672, 1383, 10, 58);
INSERT INTO 'tunespublicationsmap' VALUES (6868, 13673, 1383, 10, 60);
INSERT INTO 'tunespublicationsmap' VALUES (6869, 13606, 1383, 10, 62);
INSERT INTO 'tunespublicationsmap' VALUES (1843, 3564, 390, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1844, 4342, 390, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (1846, 4073, 390, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (1864, 1505, 390, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (1862, 2922, 390, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (1852, 5123, 390, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (1858, 848, 390, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (1855, 3912, 390, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (1854, 2910, 390, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (1851, 198, 390, 50, 42);
INSERT INTO 'tunespublicationsmap' VALUES (5565, 10399, 1043, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5566, 10403, 1043, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5567, 10415, 1043, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5568, 11560, 1042, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1710, 2809, 391, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1863, 1468, 390, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (1866, 1828, 390, 50, 42);
INSERT INTO 'tunespublicationsmap' VALUES (1315, 6002, 390, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (1711, 2377, 391, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1712, 982, 391, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1713, 932, 391, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1714, 2436, 391, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (1715, 2490, 391, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1716, 1366, 391, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1717, 2706, 391, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (1718, 2539, 391, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1719, 1431, 391, 50, 35);
INSERT INTO 'tunespublicationsmap' VALUES (1720, 2744, 391, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1721, 4395, 391, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1722, 5143, 391, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1723, 2078, 391, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1724, 2895, 391, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1725, 1565, 391, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1726, 4833, 391, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (1727, 2909, 391, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1728, 4, 391, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (5436, 1431, 154, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5437, 726, 154, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5438, 600, 154, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5575, 205, 1044, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5576, 931, 1044, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5577, 983, 1044, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5578, 94, 1044, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5579, 335, 1044, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5580, 3124, 1044, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5581, 1811, 1044, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6870, 13676, 1390, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6871, 13677, 1390, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1779, 2339, 390, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1769, 4231, 390, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1754, 921, 390, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1787, 2134, 390, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1752, 2419, 390, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1757, 5032, 390, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1732, 2077, 390, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1765, 1062, 390, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1768, 2568, 390, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1746, 743, 390, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1780, 1407, 390, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1788, 1621, 390, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1767, 5468, 390, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1762, 1018, 390, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1740, 5107, 390, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1731, 347, 390, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5622, 11654, 1061, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (5623, 10030, 1061, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (5614, 11065, 1038, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5615, 11067, 1038, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5616, 9565, 1038, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5639, 11670, 1063, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5640, 11002, 1063, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5641, 2555, 1063, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5642, 11005, 1063, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5643, 3694, 1063, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5644, 4132, 1063, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1874, 152, 389, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1873, 6213, 388, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (5612, 11562, 1046, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1875, 5123, 389, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1876, 336, 389, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1877, 4835, 389, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1878, 385, 389, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1879, 396, 389, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1880, 404, 389, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1881, 2796, 389, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1882, 416, 389, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1883, 435, 389, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1884, 450, 389, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1885, 5719, 389, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1886, 520, 389, 50, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1887, 2177, 389, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1888, 2795, 389, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1889, 2117, 389, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1890, 5418, 389, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1891, 5792, 389, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1892, 4773, 389, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1893, 2550, 389, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1894, 627, 389, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1895, 3894, 389, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1896, 2286, 389, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1897, 2102, 389, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1898, 2403, 389, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1899, 882, 389, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1900, 930, 389, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1901, 1024, 389, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1902, 5791, 389, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1903, 2503, 389, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1904, 1040, 389, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1905, 2043, 389, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1906, 1191, 389, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1907, 3573, 389, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1908, 3992, 389, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1909, 1447, 389, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1910, 1449, 389, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1911, 3242, 389, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1912, 1486, 389, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1913, 2115, 389, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1914, 1585, 389, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1915, 6266, 389, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1916, 5508, 389, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1917, 1632, 389, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1918, 1805, 389, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1919, 5407, 389, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1920, 2903, 389, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1921, 1840, 389, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1922, 2944, 389, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1923, 1761, 389, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1924, 2121, 389, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1925, 4754, 389, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1926, 1788, 389, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1927, 1828, 389, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1928, 5711, 389, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1929, 1439, 389, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1930, 3157, 389, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1931, 1621, 389, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1932, 2856, 389, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1933, 1911, 389, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1934, 4129, 389, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1935, 3159, 389, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1936, 390, 389, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1937, 3149, 389, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1938, 6306, 389, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1939, 777, 389, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1940, 2474, 389, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1941, 4379, 389, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1942, 5408, 389, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1943, 4390, 389, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1944, 3146, 389, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1945, 4852, 389, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (5605, 2122, 773, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (5624, 11655, 1062, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5626, 11657, 1062, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5628, 11659, 1062, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5629, 3165, 1062, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (5630, 11661, 1062, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5631, 11662, 1062, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (5632, 11663, 1062, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (5633, 11664, 1062, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (5634, 11665, 1062, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (5635, 11666, 1062, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1847, 2095, 390, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1836, 1839, 390, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1832, 13969, 390, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1833, 3161, 390, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1835, 1835, 390, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1834, 1757, 390, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1839, 1601, 390, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (1838, 313, 390, 50, 33);
INSERT INTO 'tunespublicationsmap' VALUES (1837, 70, 390, 50, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1840, 5726, 390, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1848, 5266, 390, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (1853, 457, 390, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (1859, 952, 390, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (1860, 4045, 390, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (1857, 2368, 390, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (1850, 2579, 390, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (1856, 803, 390, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (1861, 1120, 390, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (1872, 4134, 390, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (1869, 1179, 390, 50, 46);
INSERT INTO 'tunespublicationsmap' VALUES (2035, 6491, 727, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (2040, 6492, 727, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2041, 6493, 727, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2042, 6494, 727, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2043, 6495, 727, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2044, 6496, 727, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2045, 6497, 727, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2046, 3305, 727, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2047, 6498, 727, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5673, 11688, 1074, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5674, 11689, 1074, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5675, 11690, 1074, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5676, 11691, 1074, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5677, 11692, 1074, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1946, 425, 389, 50, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1947, 626, 389, 50, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1948, 2241, 389, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1949, 716, 389, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1950, 2812, 389, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1951, 2336, 389, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1952, 2520, 389, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1953, 2793, 389, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1954, 1463, 389, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1955, 2089, 389, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1956, 3365, 393, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1957, 1304, 393, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1958, 6424, 393, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1959, 2614, 393, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1960, 3773, 393, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1961, 1232, 393, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1962, 1152, 393, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1963, 1413, 393, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1964, 917, 393, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1965, 6425, 393, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1966, 188, 389, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1967, 6213, 389, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1968, 317, 389, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1969, 3254, 389, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1970, 5121, 389, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1971, 348, 389, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1972, 2515, 389, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1973, 6359, 389, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1974, 5046, 389, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1975, 2513, 389, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1976, 825, 389, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1977, 4413, 389, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1978, 6212, 389, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1979, 3119, 389, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1980, 5789, 389, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1981, 2510, 389, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1982, 1714, 389, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1983, 3946, 389, 50, 41);
INSERT INTO 'tunespublicationsmap' VALUES (1984, 3035, 391, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2036, 6500, 400, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2037, 6503, 400, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2038, 6501, 400, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2039, 6502, 400, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2050, 6691, 391, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (5678, 11693, 1074, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5679, 11694, 1074, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2048, 6499, 727, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5695, 10670, 1081, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5696, 10671, 1081, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5697, 10673, 1081, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5698, 10674, 1081, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5699, 10675, 1081, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5651, 11671, 1064, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (5652, 11672, 1064, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5653, 11673, 1064, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (5654, 11674, 1064, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (2052, 4912, 590, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (2053, 1528, 389, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (2062, 5077, 787, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (2063, 71, 787, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2064, 5283, 787, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2065, 5076, 787, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (2066, 5293, 787, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (2067, 2631, 787, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (2068, 453, 787, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (2069, 2397, 787, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (2070, 5288, 787, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (2071, 1979, 787, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (2072, 5290, 787, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (2073, 5294, 787, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (2074, 5078, 787, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (2076, 2753, 414, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (2077, 3129, 414, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (2078, 2211, 414, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (2079, 2615, 414, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2080, 1965, 414, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2081, 2360, 414, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2082, 2524, 414, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2083, 2294, 414, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2084, 6026, 414, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2085, 3130, 414, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2086, 7105, 414, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (2087, 2586, 414, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (2088, 2583, 414, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2089, 2522, 414, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (2090, 2212, 414, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (2091, 7106, 414, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (2092, 7107, 414, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (2093, 7108, 414, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (2094, 5322, 414, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (2095, 2331, 414, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (2096, 2163, 414, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (2097, 792, 414, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (2098, 7109, 414, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (2034, 6445, 398, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (2099, 3009, 414, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (2100, 2660, 414, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (2101, 2345, 414, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (2102, 2995, 414, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (2103, 7110, 414, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (2104, 7111, 414, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (2105, 7112, 414, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (2106, 7113, 414, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (2107, 7114, 414, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (2108, 7115, 414, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (2109, 7116, 414, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (2110, 5879, 414, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (2111, 6763, 415, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2112, 2659, 415, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2113, 7117, 415, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2114, 6250, 415, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2115, 1664, 415, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2116, 6251, 415, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2117, 7118, 415, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2118, 7119, 415, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2119, 2981, 415, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2120, 7120, 415, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (2121, 376, 415, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (2122, 2081, 415, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (2123, 3581, 415, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (2124, 5313, 415, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2125, 7121, 415, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (2126, 2937, 415, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (2127, 7122, 415, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (2128, 7123, 415, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5700, 10676, 1081, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5701, 10677, 1081, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5702, 10676, 1081, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5703, 10677, 1081, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5704, 10678, 1081, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5705, 10679, 1081, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (5706, 10682, 1081, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5680, 10879, 1079, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5681, 9480, 1079, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5682, 10475, 1079, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5683, 10870, 1079, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5684, 10711, 1079, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (2051, 6361, 388, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (2049, 1882, 16, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1985, 6436, 374, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1986, 6437, 374, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1987, 6438, 374, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1988, 6439, 374, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1989, 3289, 374, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1990, 6440, 374, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5707, 10685, 1081, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5708, 10686, 1081, 50, 28);
INSERT INTO 'tunespublicationsmap' VALUES (5709, 10687, 1081, 50, 28);
INSERT INTO 'tunespublicationsmap' VALUES (5710, 10686, 1081, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (5711, 10687, 1081, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (5712, 10688, 1081, 50, 31);
INSERT INTO 'tunespublicationsmap' VALUES (5713, 10691, 1081, 50, 33);
INSERT INTO 'tunespublicationsmap' VALUES (5714, 3219, 1084, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5715, 11360, 1084, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5716, 67, 1084, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5717, 434, 1084, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5718, 1198, 1084, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5719, 943, 1084, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5720, 11364, 1084, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5721, 3896, 1084, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5722, 3394, 1084, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5723, 2081, 1084, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5724, 1881, 1084, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5725, 2687, 1084, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5726, 2069, 1084, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5727, 4989, 1084, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5728, 4371, 1084, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5729, 189, 1084, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (5730, 2091, 1084, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5731, 1085, 1084, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5732, 3268, 1084, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5733, 11370, 1084, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5734, 9844, 1084, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (5735, 4045, 1084, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (2129, 1894, 415, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (2130, 2950, 415, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (2131, 1867, 415, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (2132, 2931, 415, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (2133, 7124, 415, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (2134, 5666, 415, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (2135, 7125, 415, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (2136, 7126, 415, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (2137, 2238, 415, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (2138, 7127, 415, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (2139, 7031, 415, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (2140, 6249, 415, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (2141, 7128, 415, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (2142, 259, 415, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (2143, 2992, 415, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (2144, 7129, 415, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (2145, 2318, 415, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (2146, 7130, 415, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (2147, 6949, 415, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (2148, 2932, 415, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (2149, 2625, 415, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (2150, 2993, 415, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (2151, 1929, 415, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (2152, 688, 415, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (2153, 7131, 415, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (2154, 168, 415, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (2155, 7132, 415, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (2156, 1981, 415, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (2157, 2138, 415, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (2158, 7133, 415, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (2159, 3023, 415, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (2160, 7134, 415, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (2161, 39, 416, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2162, 3261, 416, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2163, 1898, 416, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (2164, 88, 416, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (2165, 1943, 416, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (2166, 146, 416, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (2167, 172, 416, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (2168, 208, 416, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2169, 284, 416, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2170, 375, 416, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2171, 3232, 416, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (2172, 381, 416, 50, 40);
INSERT INTO 'tunespublicationsmap' VALUES (2173, 420, 416, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2055, 6938, 689, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (2075, 5072, 672, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (2054, 1176, 390, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (2174, 450, 416, 50, 38);
INSERT INTO 'tunespublicationsmap' VALUES (2175, 536, 416, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2176, 3810, 416, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (2177, 599, 416, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (2178, 3881, 416, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2179, 650, 416, 50, 44);
INSERT INTO 'tunespublicationsmap' VALUES (2180, 2725, 416, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (2181, 5034, 416, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (2182, 764, 416, 50, 37);
INSERT INTO 'tunespublicationsmap' VALUES (2183, 890, 416, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (2184, 6765, 416, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (2185, 975, 416, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (2186, 2556, 416, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (2187, 4075, 416, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (2188, 2518, 416, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2189, 6687, 416, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (2190, 2500, 416, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (2191, 2802, 416, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2192, 370, 416, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (2193, 4238, 416, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (2194, 1117, 416, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2195, 2628, 416, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (2196, 6139, 416, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (2197, 3848, 416, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (2199, 1431, 416, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (2200, 3252, 416, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (2201, 2132, 416, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (2202, 3711, 416, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (2203, 311, 416, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (2204, 2834, 416, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (2205, 1578, 416, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (2206, 6206, 416, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (2207, 5010, 416, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (5736, 9979, 1084, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5737, 135, 1084, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (5738, 544, 1085, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5739, 1364, 1085, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5740, 9849, 1085, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5741, 10053, 1085, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5742, 10054, 1085, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5743, 11157, 1086, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5744, 11158, 1086, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5745, 11168, 1086, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5746, 10655, 1086, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5747, 11172, 1086, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5748, 11479, 1087, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5749, 6005, 601, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5768, 1271, 159, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5769, 476, 159, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5770, 2614, 159, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (2208, 2862, 416, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (2209, 2721, 416, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2210, 2342, 416, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2211, 1882, 416, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (2212, 156, 416, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (2213, 2511, 416, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2214, 2048, 416, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (2215, 2111, 416, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (2216, 100, 416, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (2217, 128, 416, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (2218, 6898, 416, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (2219, 177, 416, 50, 37);
INSERT INTO 'tunespublicationsmap' VALUES (2220, 3517, 416, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (2221, 333, 416, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (2222, 2054, 416, 50, 44);
INSERT INTO 'tunespublicationsmap' VALUES (2223, 2106, 416, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (2224, 382, 416, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (2225, 407, 416, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (2226, 431, 416, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (2227, 3690, 416, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (2228, 482, 416, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (2229, 533, 416, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (2230, 6812, 416, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (2231, 2218, 416, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2232, 3210, 416, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (2233, 682, 416, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (2234, 656, 416, 50, 47);
INSERT INTO 'tunespublicationsmap' VALUES (2235, 971, 416, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2236, 2442, 416, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2237, 3233, 416, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (2238, 1118, 416, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (2239, 1077, 416, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (2240, 1368, 416, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (2241, 6786, 416, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (2242, 6714, 416, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (2243, 1513, 416, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (2244, 6165, 416, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (2245, 1624, 416, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (2246, 1745, 416, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2247, 6738, 416, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (2248, 3025, 417, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (2249, 5516, 417, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (2250, 3104, 417, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (2251, 2785, 417, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (2252, 2767, 417, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (2253, 2768, 417, 10, 59);
INSERT INTO 'tunespublicationsmap' VALUES (2254, 2653, 417, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (2255, 7161, 416, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (2256, 7169, 417, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (2257, 7170, 417, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2258, 1543, 418, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (2259, 980, 418, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (2260, 6866, 418, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2261, 1154, 418, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2262, 2596, 418, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2263, 2597, 418, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2264, 1185, 418, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (2265, 5056, 418, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (2266, 4242, 418, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (2267, 1547, 418, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (2268, 2444, 418, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (2269, 1273, 418, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (2270, 1278, 418, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (2271, 1282, 418, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (2272, 6160, 418, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (2273, 4539, 418, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (2274, 3601, 418, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2275, 476, 418, 50, 33);
INSERT INTO 'tunespublicationsmap' VALUES (2276, 477, 418, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (2277, 2176, 418, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (2278, 3250, 418, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (2279, 1768, 418, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2280, 1822, 418, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (2281, 2781, 419, 50, 44);
INSERT INTO 'tunespublicationsmap' VALUES (2282, 2021, 419, 50, 54);
INSERT INTO 'tunespublicationsmap' VALUES (2283, 1409, 419, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (2284, 2219, 419, 50, 54);
INSERT INTO 'tunespublicationsmap' VALUES (2285, 602, 419, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5767, 11739, 1012, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5771, 10143, 1094, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5772, 10152, 1094, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5773, 10158, 1094, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (2286, 2235, 419, 50, 40);
INSERT INTO 'tunespublicationsmap' VALUES (2287, 844, 419, 10, 59);
INSERT INTO 'tunespublicationsmap' VALUES (2288, 2125, 419, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (2289, 3207, 419, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2290, 3478, 419, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (2291, 4603, 419, 50, 38);
INSERT INTO 'tunespublicationsmap' VALUES (2292, 1827, 419, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2293, 2578, 419, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (2294, 2581, 419, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (2295, 6630, 419, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2296, 3384, 419, 10, 51);
INSERT INTO 'tunespublicationsmap' VALUES (2297, 1196, 419, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (2298, 2621, 419, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (2299, 2623, 419, 50, 33);
INSERT INTO 'tunespublicationsmap' VALUES (2300, 1241, 419, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (2301, 2044, 419, 10, 53);
INSERT INTO 'tunespublicationsmap' VALUES (2302, 4270, 419, 50, 48);
INSERT INTO 'tunespublicationsmap' VALUES (2303, 1247, 419, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (2304, 2769, 419, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (2305, 6556, 419, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2306, 5268, 419, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2307, 379, 419, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (2308, 1082, 419, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (2309, 93, 419, 50, 48);
INSERT INTO 'tunespublicationsmap' VALUES (2310, 143, 419, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (2311, 2111, 419, 50, 36);
INSERT INTO 'tunespublicationsmap' VALUES (2312, 380, 419, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (2313, 440, 419, 10, 58);
INSERT INTO 'tunespublicationsmap' VALUES (2314, 477, 419, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (2315, 714, 419, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (2316, 715, 419, 10, 57);
INSERT INTO 'tunespublicationsmap' VALUES (2317, 1068, 419, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2318, 5790, 419, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (2319, 1077, 419, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (2320, 4361, 420, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2321, 4718, 420, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2322, 602, 420, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2323, 4745, 420, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2324, 36, 420, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2325, 5273, 420, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2528, 7254, 425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2529, 3419, 425, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2530, 388, 425, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2531, 882, 425, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2532, 7255, 425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2533, 7256, 425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2534, 7257, 425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2535, 7258, 425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2536, 7259, 425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2537, 967, 425, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2538, 1487, 425, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2539, 7260, 425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2540, 2986, 425, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2541, 7281, 426, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2557, 7288, 428, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2558, 7289, 428, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2559, 7290, 428, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2560, 7291, 428, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2573, 7362, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2574, 7363, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2575, 7364, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2576, 7365, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2577, 7366, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2578, 7367, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2579, 7368, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2580, 7369, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2581, 7370, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2582, 7371, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2583, 7372, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2584, 7373, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2585, 7374, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2586, 7375, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2587, 7376, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2588, 7377, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2589, 7378, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2590, 7379, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2591, 7380, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2592, 7381, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2593, 7382, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2594, 7383, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2595, 7384, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2596, 7385, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2597, 7386, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2515, 1651, 133, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (2516, 1266, 133, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2517, 454, 133, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2518, 1817, 133, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2519, 2577, 133, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2520, 1258, 133, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (2521, 1555, 133, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2522, 38, 133, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (2523, 1810, 133, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (2524, 1837, 133, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (2525, 401, 133, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (2526, 391, 133, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (2527, 1085, 133, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (7097, 589, 1487, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7098, 13978, 1487, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (7099, 12569, 1487, 10, 61);
INSERT INTO 'tunespublicationsmap' VALUES (2599, 7387, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2600, 7388, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2601, 7389, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2602, 7390, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2603, 7391, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2604, 7392, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2605, 7393, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2606, 7394, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7101, 14011, 1492, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7104, 14013, 1492, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7103, 14012, 1492, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7102, 13237, 1492, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7105, 14014, 1492, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7100, 14010, 1492, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (7106, 14015, 1492, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (2607, 7395, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2608, 7396, 800, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2609, 7397, 430, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2610, 7398, 430, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2611, 7399, 430, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2612, 7400, 430, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2613, 7401, 430, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2647, 7482, 435, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2648, 929, 435, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2649, 760, 435, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2650, 1164, 435, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2659, 7543, 437, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2660, 7544, 437, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2661, 7545, 437, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2662, 7546, 437, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2663, 7547, 437, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2664, 7548, 437, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2665, 7549, 437, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2666, 7550, 437, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2667, 7551, 437, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2668, 7552, 437, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2669, 7553, 437, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2670, 7561, 431, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (2671, 7562, 431, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2672, 7563, 431, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2673, 7564, 431, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2674, 7565, 431, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2675, 7566, 431, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2709, 6764, 8, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2676, 7567, 431, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2677, 5573, 431, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (2678, 7253, 431, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (2679, 2268, 431, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2680, 3121, 431, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2681, 1749, 431, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2682, 6117, 431, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2561, 7350, 716, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2562, 7351, 716, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2563, 7352, 716, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2564, 7353, 716, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2565, 7354, 716, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2566, 7355, 716, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2567, 7356, 716, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2568, 7357, 716, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2569, 7358, 716, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2570, 7359, 716, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2571, 7360, 716, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2572, 7361, 716, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2614, 7421, 432, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2615, 7422, 432, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2624, 7359, 432, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2598, 2825, 145, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2631, 7431, 433, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (2632, 7432, 433, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (2633, 7433, 433, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (2704, 290, 103, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6916, 1664, 874, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3865, 1781, 874, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6915, 13768, 1401, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (2625, 7425, 433, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (2626, 7426, 433, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2627, 7427, 433, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2628, 7428, 433, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2629, 7429, 433, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2630, 7430, 433, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (2705, 588, 103, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2710, 6764, 388, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2623, 7424, 369, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2719, 70, 488, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2756, 3569, 488, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (2734, 156, 488, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (2733, 5044, 488, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (2736, 172, 488, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (2738, 177, 488, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (2752, 4323, 488, 50, 70);
INSERT INTO 'tunespublicationsmap' VALUES (2745, 2048, 488, 50, 71);
INSERT INTO 'tunespublicationsmap' VALUES (2755, 288, 488, 10, 72);
INSERT INTO 'tunespublicationsmap' VALUES (2720, 71, 488, 50, 88);
INSERT INTO 'tunespublicationsmap' VALUES (2739, 182, 488, 50, 90);
INSERT INTO 'tunespublicationsmap' VALUES (2744, 1216, 488, 10, 91);
INSERT INTO 'tunespublicationsmap' VALUES (2746, 199, 488, 50, 92);
INSERT INTO 'tunespublicationsmap' VALUES (2751, 234, 488, 50, 93);
INSERT INTO 'tunespublicationsmap' VALUES (2730, 109, 488, 50, 103);
INSERT INTO 'tunespublicationsmap' VALUES (2731, 137, 488, 50, 117);
INSERT INTO 'tunespublicationsmap' VALUES (2728, 104, 488, 50, 118);
INSERT INTO 'tunespublicationsmap' VALUES (2724, 92, 488, 50, 164);
INSERT INTO 'tunespublicationsmap' VALUES (2741, 5517, 488, 50, 166);
INSERT INTO 'tunespublicationsmap' VALUES (2618, 3348, 196, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (2621, 3645, 196, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2617, 4225, 196, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2622, 3058, 196, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2619, 4450, 196, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2616, 4633, 196, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2620, 4694, 196, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2706, 7568, 103, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2707, 879, 103, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (2708, 13969, 103, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3835, 141, 874, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3864, 4489, 874, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3849, 787, 874, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3838, 2727, 874, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6918, 13769, 874, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3843, 6054, 874, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3842, 398, 874, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3855, 1135, 874, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3852, 1725, 874, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3844, 2159, 874, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3845, 2162, 874, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3859, 4311, 874, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3857, 6051, 874, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3841, 1193, 874, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6919, 376, 874, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3833, 6057, 874, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3853, 2488, 874, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3840, 9342, 874, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3860, 1399, 874, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3856, 6050, 874, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3848, 5883, 874, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3837, 3559, 874, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3851, 841, 874, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (3861, 1456, 874, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (2712, 285, 153, 2, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2903, 1746, 492, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3015, 822, 568, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3016, 7694, 568, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3011, 7691, 568, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3012, 3542, 568, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3013, 7692, 568, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3018, 7696, 568, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3014, 7693, 568, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3017, 7695, 568, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6467, 13122, 1239, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3006, 265, 567, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3025, 7708, 599, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3034, 103, 599, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2639, 4550, 82, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2640, 2853, 82, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2683, 5765, 707, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2684, 5766, 707, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2685, 4109, 707, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2686, 5769, 707, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (2687, 5771, 707, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2688, 609, 707, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (2689, 474, 707, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (2690, 3519, 707, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3032, 6691, 599, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3026, 7711, 599, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3033, 1119, 599, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3027, 7713, 599, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3028, 7714, 599, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3029, 7715, 599, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6945, 3467, 1412, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6921, 4329, 1410, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3030, 7716, 599, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3031, 7717, 599, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6951, 3729, 1414, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6952, 12167, 1414, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (2984, 4763, 430, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2985, 4824, 430, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2986, 5339, 430, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2987, 3049, 562, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2988, 7660, 562, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2989, 7661, 562, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2990, 3050, 562, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2991, 7664, 562, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2992, 7665, 562, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2993, 7666, 562, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2994, 7667, 562, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2995, 7662, 562, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2996, 7600, 562, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2997, 2769, 562, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2998, 1696, 562, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2999, 7655, 562, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3000, 7681, 562, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3001, 2134, 562, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3002, 3860, 562, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3003, 7684, 566, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3004, 7685, 566, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3005, 7686, 566, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3019, 7698, 389, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3020, 7699, 598, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3021, 7700, 598, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3022, 7704, 404, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3023, 7705, 404, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3024, 7706, 404, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3035, 7712, 614, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3036, 7722, 614, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3037, 7723, 614, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3038, 7724, 614, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3039, 7725, 614, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3040, 7726, 614, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3041, 7727, 614, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3042, 7728, 614, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3043, 7729, 614, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3044, 7730, 614, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3045, 7731, 614, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3046, 7732, 614, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3047, 7733, 614, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3048, 7734, 614, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3049, 7735, 614, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3050, 7736, 614, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3051, 7737, 614, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3052, 7752, 475, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3053, 7754, 475, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3054, 7755, 624, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3055, 7756, 624, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3056, 7757, 624, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3057, 7758, 475, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3058, 7759, 475, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6946, 3695, 1412, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (2983, 2915, 488, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2919, 2850, 488, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2933, 2851, 488, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2929, 2849, 488, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (2924, 3848, 488, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (2921, 1322, 488, 50, 33);
INSERT INTO 'tunespublicationsmap' VALUES (2928, 1368, 488, 50, 36);
INSERT INTO 'tunespublicationsmap' VALUES (2947, 2012, 488, 50, 37);
INSERT INTO 'tunespublicationsmap' VALUES (3071, 1809, 632, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6920, 13770, 1402, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6922, 1755, 1411, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5783, 7812, 617, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5782, 7813, 617, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6923, 53, 1411, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6949, 1341, 330, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6950, 1771, 330, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6877, 7422, 1351, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (2926, 1352, 13, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3007, 7687, 567, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3009, 7689, 567, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3079, 2201, 636, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3080, 7769, 642, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3081, 7763, 642, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3082, 7764, 642, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3083, 7765, 642, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3084, 7766, 642, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3085, 7767, 642, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3086, 7642, 642, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3087, 7768, 642, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3088, 7770, 642, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3089, 7771, 642, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3135, 3874, 662, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3137, 7931, 662, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3138, 7932, 662, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3106, 445, 419, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3107, 7818, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3108, 7819, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3109, 3115, 654, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3110, 7820, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3111, 7821, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3112, 1089, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3113, 7822, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3114, 7741, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3115, 7823, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3116, 7824, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3117, 7825, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3118, 7826, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3119, 7827, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3120, 7828, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3121, 7829, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3122, 7830, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3123, 7831, 654, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3125, 533, 654, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3126, 7879, 658, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3127, 7409, 658, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3128, 7880, 658, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3129, 7876, 658, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3130, 7877, 658, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3131, 7878, 658, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3132, 2975, 658, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3133, 1963, 658, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3134, 3484, 658, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3148, 7348, 661, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3149, 655, 661, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3150, 4482, 661, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3151, 7941, 661, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3152, 3629, 661, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3153, 7942, 661, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3154, 7943, 661, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3155, 7944, 661, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3139, 7933, 662, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3140, 7934, 662, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3141, 471, 662, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3142, 7935, 662, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3143, 7936, 662, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3144, 7937, 662, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3146, 802, 662, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3136, 7940, 662, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3145, 7938, 662, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3147, 7939, 662, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3189, 7997, 669, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3190, 7998, 669, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3191, 7999, 669, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3192, 8000, 669, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3193, 8001, 669, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3212, 717, 766, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3213, 4901, 766, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3214, 7454, 766, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3215, 8047, 766, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3216, 822, 766, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3217, 5285, 766, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3218, 7980, 766, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3219, 68, 766, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3220, 2816, 766, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3221, 692, 766, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3206, 713, 307, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3207, 1372, 307, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3208, 407, 307, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3209, 694, 307, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3210, 1440, 307, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3211, 1461, 307, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3124, 7848, 655, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3104, 445, 488, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7110, 247, 31, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7111, 173, 31, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3090, 3403, 647, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3091, 2057, 647, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3092, 4732, 647, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3093, 7772, 647, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3094, 3145, 647, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3095, 1127, 647, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3096, 7773, 647, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3097, 1336, 647, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3098, 7774, 647, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3099, 7775, 647, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3100, 2388, 647, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3203, 6504, 759, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3205, 8025, 759, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3204, 8026, 759, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3222, 4002, 776, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3223, 8050, 776, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3224, 1003, 776, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3225, 1238, 776, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3226, 8051, 776, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3227, 8052, 776, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3228, 2287, 776, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3169, 7976, 382, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3170, 7977, 382, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3171, 7978, 382, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3172, 7979, 382, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3173, 7981, 382, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3174, 7982, 382, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3175, 7983, 382, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3176, 7984, 382, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3177, 7985, 382, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3178, 7986, 382, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3179, 7987, 382, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3180, 7988, 382, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3181, 7990, 382, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3182, 7991, 382, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3183, 7992, 382, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3194, 8005, 309, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3195, 8006, 309, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3196, 8007, 309, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3197, 2201, 309, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3198, 8008, 309, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3199, 8009, 309, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3200, 8010, 309, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3201, 8011, 309, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3202, 8012, 309, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3072, 2387, 632, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3073, 685, 632, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3074, 4014, 632, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3075, 1805, 632, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3076, 2920, 632, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3077, 692, 632, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3078, 1317, 632, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7112, 1474, 31, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7113, 1719, 31, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7114, 698, 31, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7115, 1583, 31, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7116, 159, 31, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7117, 342, 31, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7118, 13102, 1501, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7119, 14041, 1501, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6953, 3408, 1414, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3309, 100, 765, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3310, 290, 765, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3311, 4829, 765, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3312, 318, 765, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3313, 5377, 765, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3314, 448, 765, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3315, 414, 765, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3316, 382, 765, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3317, 3761, 765, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3318, 497, 765, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3319, 624, 765, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3320, 771, 765, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3321, 835, 765, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3322, 3156, 765, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3323, 995, 765, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3324, 891, 765, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3325, 967, 765, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3326, 1175, 765, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3327, 1452, 765, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3328, 1453, 765, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3329, 1503, 765, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3330, 1638, 765, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3331, 5407, 765, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3332, 2922, 765, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3333, 1734, 765, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3334, 1721, 765, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3335, 1834, 765, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3336, 439, 765, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3337, 444, 765, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3338, 385, 765, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3339, 692, 765, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3340, 773, 765, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3341, 890, 765, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3342, 4974, 765, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3343, 920, 765, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3344, 2489, 765, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3345, 959, 765, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3346, 1311, 765, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3347, 6335, 765, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3348, 2816, 765, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3349, 1067, 765, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3350, 1400, 765, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3351, 1673, 765, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3352, 1731, 765, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3353, 6764, 765, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3354, 5413, 765, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3355, 5126, 765, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3356, 5346, 765, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3357, 1181, 765, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3358, 4989, 765, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3359, 606, 765, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3360, 3894, 765, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3361, 1366, 765, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3362, 1421, 765, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3363, 1415, 765, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3364, 1528, 765, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3365, 1540, 765, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3366, 1650, 765, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3367, 3935, 765, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3368, 1665, 765, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3369, 283, 765, 50, 31);
INSERT INTO 'tunespublicationsmap' VALUES (3370, 350, 765, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (3371, 534, 765, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3372, 2249, 765, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3373, 2374, 765, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3374, 1103, 765, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3375, 733, 765, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3376, 1458, 765, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3377, 1741, 765, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3378, 3600, 765, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3379, 182, 765, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3380, 456, 765, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3381, 2323, 765, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3382, 842, 765, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3383, 833, 765, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3384, 1805, 765, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3385, 2806, 765, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3386, 1622, 765, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (3387, 313, 765, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3388, 5123, 765, 50, 34);
INSERT INTO 'tunespublicationsmap' VALUES (3389, 374, 765, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3390, 482, 765, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3391, 650, 765, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (3392, 4939, 765, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3393, 5525, 765, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (3394, 790, 765, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (3395, 1006, 765, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3396, 6389, 765, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (3397, 5727, 765, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (3398, 5462, 765, 50, 37);
INSERT INTO 'tunespublicationsmap' VALUES (3399, 1691, 765, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3400, 4045, 765, 50, 36);
INSERT INTO 'tunespublicationsmap' VALUES (3401, 724, 765, 50, 35);
INSERT INTO 'tunespublicationsmap' VALUES (3402, 1541, 765, 50, 33);
INSERT INTO 'tunespublicationsmap' VALUES (3403, 2988, 765, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (3404, 6898, 779, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3405, 3431, 779, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3406, 2968, 779, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3407, 2369, 779, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3408, 850, 779, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3409, 709, 779, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3410, 1643, 779, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3411, 685, 779, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3412, 1875, 779, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3413, 1777, 779, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3414, 7894, 779, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3415, 4615, 779, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3416, 8129, 779, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3417, 789, 779, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3418, 1091, 779, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3419, 6079, 779, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3420, 5212, 779, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3421, 644, 779, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3422, 6322, 779, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3423, 8130, 779, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3424, 4571, 779, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3425, 8131, 779, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3426, 8132, 779, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3427, 8133, 779, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3428, 1882, 783, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3429, 100, 783, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3430, 295, 783, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3431, 405, 783, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3432, 430, 783, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3433, 5148, 783, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3434, 601, 783, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3435, 119, 783, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3436, 670, 783, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3437, 687, 783, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3438, 697, 783, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3439, 3919, 783, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3440, 4939, 783, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3441, 3428, 783, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3442, 8135, 783, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3443, 8136, 783, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3444, 8137, 783, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3445, 6687, 783, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3446, 6381, 783, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3447, 8138, 783, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3448, 6, 783, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3449, 155, 783, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3451, 348, 783, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3452, 4755, 783, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3453, 8139, 783, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3454, 992, 783, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3455, 4395, 783, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3456, 8140, 783, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3457, 1505, 783, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3458, 8141, 783, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3459, 2498, 783, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3460, 1696, 783, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3461, 8142, 783, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3462, 3400, 783, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3463, 1985, 783, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3464, 165, 783, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (3465, 3584, 783, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3466, 2180, 783, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3467, 682, 783, 50, 28);
INSERT INTO 'tunespublicationsmap' VALUES (3468, 942, 783, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3469, 4069, 783, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3470, 8143, 783, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3471, 5315, 783, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3472, 1123, 783, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (3473, 1181, 783, 50, 28);
INSERT INTO 'tunespublicationsmap' VALUES (3474, 2152, 783, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3475, 1395, 783, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3476, 7192, 783, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3477, 8144, 783, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (3478, 5789, 783, 50, 28);
INSERT INTO 'tunespublicationsmap' VALUES (3479, 8145, 783, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3480, 1332, 783, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3481, 1744, 783, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3482, 8146, 783, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3483, 8147, 783, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3484, 3484, 783, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3485, 2974, 783, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3486, 171, 783, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3487, 2423, 783, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3488, 232, 783, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3489, 374, 783, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3490, 482, 783, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3491, 955, 783, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3492, 1374, 783, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3493, 1541, 783, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3494, 1942, 783, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3495, 1919, 783, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3496, 189, 783, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3497, 8148, 783, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3498, 415, 783, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3499, 560, 783, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3500, 4543, 783, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3501, 8149, 783, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3502, 1380, 783, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3503, 4379, 783, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3504, 2744, 783, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3505, 8150, 783, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3506, 1528, 783, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3507, 1650, 783, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3508, 8151, 783, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3509, 1665, 783, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3510, 5347, 783, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3511, 8152, 783, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3512, 8153, 783, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3513, 234, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3514, 1995, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3515, 2106, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3516, 448, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3517, 692, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3518, 770, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3519, 8154, 783, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3520, 857, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3521, 915, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3522, 1014, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3523, 1017, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3524, 4167, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3525, 4173, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3526, 1091, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3527, 2802, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3528, 1140, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3529, 5646, 783, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3530, 1542, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3531, 7503, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3532, 1721, 783, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3533, 1814, 783, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3534, 8176, 341, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3535, 8177, 341, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (3538, 372, 391, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (3539, 607, 305, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (3557, 7645, 559, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3558, 7646, 559, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3559, 7647, 559, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3560, 7648, 559, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3561, 7649, 559, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3562, 7651, 559, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3563, 7652, 559, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3565, 3882, 548, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3566, 4223, 548, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3567, 4228, 548, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3570, 7213, 161, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3571, 1520, 538, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3581, 2316, 426, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3583, 7280, 831, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3584, 8318, 831, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3585, 8372, 831, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3586, 8373, 831, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3587, 8374, 831, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3588, 8375, 831, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3589, 8376, 831, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3609, 8377, 832, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3610, 8188, 832, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3611, 8379, 832, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3612, 8378, 832, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3613, 8381, 832, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3614, 8382, 832, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3615, 8383, 832, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3616, 1624, 832, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3617, 3431, 832, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3618, 8384, 832, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3619, 920, 832, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3620, 8385, 832, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3623, 944, 832, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6956, 4714, 1417, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6957, 2353, 1418, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6958, 4558, 1419, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6959, 7815, 626, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3621, 8380, 839, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3622, 944, 839, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3624, 5, 839, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3625, 2418, 839, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3626, 760, 839, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3627, 8472, 839, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3628, 8473, 839, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3629, 8474, 839, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3630, 8475, 839, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3631, 3330, 839, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3656, 8526, 855, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3657, 8527, 855, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3658, 8528, 855, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3659, 8529, 855, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3660, 8530, 855, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3661, 8531, 855, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3662, 8532, 855, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3663, 8533, 855, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3664, 8534, 855, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3665, 8535, 855, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3666, 8536, 855, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3667, 8537, 855, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3668, 8538, 855, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3669, 8539, 855, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3670, 8540, 855, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3671, 8541, 855, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3672, 8542, 855, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3673, 8543, 855, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3674, 8544, 855, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3675, 8545, 855, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3676, 8546, 855, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3677, 8547, 855, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3678, 8548, 855, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3679, 8549, 855, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3680, 8550, 855, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3681, 8551, 855, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3682, 8552, 855, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3683, 8553, 855, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3684, 8554, 855, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3685, 8555, 855, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3686, 8556, 855, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3687, 8557, 855, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3688, 8558, 855, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3689, 8559, 855, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3690, 8560, 855, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3691, 8561, 855, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3692, 8562, 855, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3693, 8563, 855, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3694, 8564, 855, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (3695, 8565, 855, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (3696, 8566, 855, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3697, 8567, 855, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3698, 8568, 855, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3699, 8569, 855, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3700, 8570, 855, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3701, 8571, 855, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3702, 8572, 855, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (3703, 8573, 855, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (3704, 8574, 855, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3705, 8575, 855, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3706, 8576, 855, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (3707, 8577, 855, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (3708, 8578, 855, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (3564, 5231, 797, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3568, 8222, 797, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3569, 8223, 797, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6960, 12169, 626, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3069, 7761, 625, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3070, 7762, 625, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6961, 1212, 630, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6962, 1336, 630, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6963, 1215, 630, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6964, 1249, 630, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4261, 8454, 885, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4270, 8455, 885, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (4269, 8456, 885, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3582, 613, 388, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3536, 8178, 309, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3537, 3613, 309, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4275, 821, 885, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3709, 8579, 855, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (3710, 8580, 856, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3711, 8581, 856, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3712, 8582, 856, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3713, 4517, 856, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3714, 8583, 856, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3715, 8584, 856, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3716, 8591, 862, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3821, 866, 256, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3724, 8603, 869, 10, 104);
INSERT INTO 'tunespublicationsmap' VALUES (3822, 1798, 256, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3726, 8605, 870, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (3727, 3870, 870, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (3728, 7511, 870, 10, 77);
INSERT INTO 'tunespublicationsmap' VALUES (3729, 3212, 870, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (3730, 8606, 870, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (3731, 8607, 870, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (3732, 6795, 871, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3733, 2034, 871, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3734, 2028, 870, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3735, 5573, 871, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3736, 2051, 871, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3737, 8608, 871, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (3738, 8609, 871, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3739, 8610, 871, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (3740, 8611, 871, 10, 78);
INSERT INTO 'tunespublicationsmap' VALUES (3741, 8612, 871, 10, 76);
INSERT INTO 'tunespublicationsmap' VALUES (3742, 8613, 871, 10, 95);
INSERT INTO 'tunespublicationsmap' VALUES (3743, 8614, 871, 10, 87);
INSERT INTO 'tunespublicationsmap' VALUES (3744, 8615, 871, 10, 101);
INSERT INTO 'tunespublicationsmap' VALUES (3745, 8616, 871, 10, 63);
INSERT INTO 'tunespublicationsmap' VALUES (3746, 8617, 871, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (3747, 8618, 871, 10, 102);
INSERT INTO 'tunespublicationsmap' VALUES (3748, 8619, 871, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3749, 8620, 871, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3645, 4624, 282, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3719, 8601, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3540, 999, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3720, 3698, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3649, 8484, 574, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3650, 8485, 574, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3651, 8486, 574, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3652, 416, 574, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3750, 8621, 871, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3751, 8622, 871, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (3752, 8623, 871, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (3753, 8624, 871, 10, 51);
INSERT INTO 'tunespublicationsmap' VALUES (3754, 8625, 871, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (3755, 8626, 871, 10, 57);
INSERT INTO 'tunespublicationsmap' VALUES (3756, 8627, 871, 10, 69);
INSERT INTO 'tunespublicationsmap' VALUES (3757, 8628, 871, 10, 77);
INSERT INTO 'tunespublicationsmap' VALUES (3758, 8629, 871, 10, 77);
INSERT INTO 'tunespublicationsmap' VALUES (3759, 8630, 871, 10, 93);
INSERT INTO 'tunespublicationsmap' VALUES (3760, 8631, 871, 10, 96);
INSERT INTO 'tunespublicationsmap' VALUES (3761, 8632, 870, 10, 68);
INSERT INTO 'tunespublicationsmap' VALUES (3762, 8633, 870, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (3763, 8634, 870, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (3764, 8635, 870, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (3765, 8636, 870, 10, 55);
INSERT INTO 'tunespublicationsmap' VALUES (3766, 8637, 870, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (3767, 8638, 870, 10, 72);
INSERT INTO 'tunespublicationsmap' VALUES (3768, 8639, 870, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3769, 8640, 870, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3770, 8641, 870, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (3771, 8642, 870, 10, 73);
INSERT INTO 'tunespublicationsmap' VALUES (3772, 8643, 870, 10, 70);
INSERT INTO 'tunespublicationsmap' VALUES (3773, 8644, 870, 10, 57);
INSERT INTO 'tunespublicationsmap' VALUES (3774, 8645, 870, 10, 55);
INSERT INTO 'tunespublicationsmap' VALUES (3775, 8646, 870, 10, 66);
INSERT INTO 'tunespublicationsmap' VALUES (3776, 8647, 870, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3777, 8648, 870, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3778, 8649, 870, 10, 59);
INSERT INTO 'tunespublicationsmap' VALUES (3779, 8650, 870, 10, 80);
INSERT INTO 'tunespublicationsmap' VALUES (3780, 8651, 870, 10, 83);
INSERT INTO 'tunespublicationsmap' VALUES (3781, 8652, 870, 10, 74);
INSERT INTO 'tunespublicationsmap' VALUES (3782, 8653, 870, 10, 81);
INSERT INTO 'tunespublicationsmap' VALUES (3783, 8654, 870, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3784, 8655, 870, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3785, 8656, 870, 10, 95);
INSERT INTO 'tunespublicationsmap' VALUES (3786, 8657, 870, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3787, 8658, 870, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (3788, 8659, 870, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (3789, 8660, 870, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3790, 8661, 870, 10, 71);
INSERT INTO 'tunespublicationsmap' VALUES (3791, 8662, 870, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (3792, 8663, 870, 10, 67);
INSERT INTO 'tunespublicationsmap' VALUES (3793, 8664, 870, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (3794, 8665, 870, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3795, 8666, 870, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3796, 8667, 870, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3797, 8668, 870, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (3798, 8669, 870, 10, 65);
INSERT INTO 'tunespublicationsmap' VALUES (3799, 8670, 870, 10, 64);
INSERT INTO 'tunespublicationsmap' VALUES (3800, 8671, 870, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3801, 8672, 870, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (3802, 8673, 870, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3803, 8674, 870, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (3804, 8675, 870, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3805, 8676, 870, 10, 75);
INSERT INTO 'tunespublicationsmap' VALUES (3806, 8677, 870, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (3807, 8678, 870, 10, 64);
INSERT INTO 'tunespublicationsmap' VALUES (3808, 8679, 870, 10, 81);
INSERT INTO 'tunespublicationsmap' VALUES (3809, 8680, 870, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3810, 362, 870, 50, 78);
INSERT INTO 'tunespublicationsmap' VALUES (3811, 8681, 870, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3812, 8682, 870, 10, 78);
INSERT INTO 'tunespublicationsmap' VALUES (3813, 8163, 872, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3814, 7187, 873, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3815, 5975, 872, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3816, 8683, 872, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3817, 8684, 872, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3818, 8685, 872, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3819, 8686, 872, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3823, 22, 256, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3824, 67, 256, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3825, 74, 256, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3826, 455, 256, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3827, 605, 256, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3828, 837, 256, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3829, 970, 256, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3830, 1397, 256, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3831, 1538, 256, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3832, 1635, 256, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4274, 8245, 885, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4282, 8447, 885, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (4278, 8448, 885, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3847, 3846, 874, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4277, 8437, 885, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (4273, 8457, 885, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (4280, 3290, 885, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (4272, 8441, 885, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (4281, 8442, 885, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (4279, 8443, 885, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (4276, 8444, 885, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (4285, 8451, 885, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (4283, 8452, 885, 50, 31);
INSERT INTO 'tunespublicationsmap' VALUES (4286, 8747, 885, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (4284, 8418, 885, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (4293, 8438, 885, 50, 35);
INSERT INTO 'tunespublicationsmap' VALUES (4292, 8439, 885, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (4288, 6115, 885, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (4294, 422, 885, 50, 38);
INSERT INTO 'tunespublicationsmap' VALUES (4291, 8458, 885, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (4296, 8459, 885, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (4287, 8460, 885, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (4295, 4715, 885, 50, 42);
INSERT INTO 'tunespublicationsmap' VALUES (4290, 8449, 885, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (4289, 8450, 885, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (3718, 8592, 863, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3717, 8593, 863, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7121, 8968, 903, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7122, 8969, 903, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3820, 8687, 175, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3871, 7236, 161, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3872, 8690, 161, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3873, 8691, 161, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3874, 8693, 161, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3875, 8235, 161, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3876, 8694, 161, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3877, 8695, 161, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3878, 8696, 161, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3879, 8697, 161, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3880, 8698, 161, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3881, 8699, 161, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3882, 8700, 334, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3883, 8701, 334, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3900, 7923, 875, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3901, 3026, 875, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (3902, 7856, 875, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3903, 765, 875, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3904, 812, 875, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3905, 2482, 875, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (3906, 3067, 875, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3907, 2587, 875, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3908, 8702, 875, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3909, 7914, 875, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3910, 8703, 875, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3911, 8704, 875, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3912, 3498, 875, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3913, 502, 875, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3914, 2543, 875, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3915, 7557, 875, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3916, 5370, 875, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3917, 834, 875, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3918, 1291, 875, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3919, 1424, 875, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3920, 3737, 93, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3921, 2829, 93, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3922, 4222, 93, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3923, 3708, 93, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4009, 93, 526, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4010, 1600, 526, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4011, 1642, 526, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4012, 797, 526, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4013, 127, 526, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4014, 1207, 526, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4015, 390, 526, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4016, 378, 526, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4017, 774, 526, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4018, 1039, 526, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4019, 160, 526, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4020, 73, 526, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4247, 8404, 884, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (4248, 8408, 884, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3946, 8705, 869, 10, 102);
INSERT INTO 'tunespublicationsmap' VALUES (3947, 8706, 869, 10, 127);
INSERT INTO 'tunespublicationsmap' VALUES (3948, 333, 869, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3949, 3252, 869, 50, 33);
INSERT INTO 'tunespublicationsmap' VALUES (3953, 5933, 305, 10, 51);
INSERT INTO 'tunespublicationsmap' VALUES (3954, 1389, 305, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3955, 3199, 305, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3956, 1386, 305, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3957, 7846, 305, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3958, 2047, 305, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3959, 2300, 305, 50, 31);
INSERT INTO 'tunespublicationsmap' VALUES (3960, 2379, 305, 50, 35);
INSERT INTO 'tunespublicationsmap' VALUES (3961, 6647, 305, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (3962, 3133, 305, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3963, 8707, 305, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (3964, 2921, 305, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3965, 5958, 305, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (3966, 8708, 305, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (3967, 1862, 305, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3968, 8709, 305, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3969, 5567, 305, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3970, 8710, 305, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3971, 1594, 305, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (3972, 8711, 305, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (3973, 8712, 305, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3974, 2790, 305, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (3975, 8713, 305, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3976, 8714, 305, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3977, 1581, 305, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (3978, 3772, 305, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3979, 2134, 305, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3980, 858, 305, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (3981, 8715, 557, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3986, 4684, 448, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3991, 2545, 416, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3993, 4418, 509, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3994, 8716, 869, 10, 84);
INSERT INTO 'tunespublicationsmap' VALUES (3995, 8716, 416, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4007, 332, 391, 10, 384);
INSERT INTO 'tunespublicationsmap' VALUES (4024, 3878, 99, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4025, 3469, 99, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4026, 4430, 99, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4027, 3686, 99, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4028, 4660, 99, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4029, 3464, 527, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4030, 3982, 527, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4031, 3426, 527, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4032, 1142, 527, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4033, 8717, 527, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4047, 5900, 879, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (4048, 4731, 879, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (4049, 2873, 879, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4050, 2661, 879, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4051, 2432, 879, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4052, 2691, 873, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4054, 2762, 391, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (3990, 2929, 877, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3945, 366, 47, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3988, 2072, 877, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3989, 1031, 877, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (3867, 2971, 874, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3870, 8689, 874, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3869, 8688, 874, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3866, 1786, 874, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3924, 965, 77, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3925, 1945, 77, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3926, 3273, 77, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3927, 3274, 77, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3928, 3275, 77, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3929, 2110, 77, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3930, 3276, 77, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3868, 1800, 874, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3987, 3827, 648, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4249, 4093, 884, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4053, 2762, 640, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4250, 3734, 884, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4251, 2254, 884, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (4252, 8416, 884, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (4253, 4776, 884, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (4254, 4034, 884, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (4255, 8424, 884, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4256, 5778, 884, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (4257, 7436, 884, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (4246, 4125, 884, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (4993, 1353, 980, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4990, 3181, 980, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3992, 2545, 390, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (4058, 8719, 873, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (4059, 5245, 873, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (4060, 8720, 873, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4061, 3222, 873, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (4062, 8721, 873, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4063, 1986, 873, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4064, 3463, 873, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (4065, 6944, 873, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (4066, 2571, 873, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (4067, 7186, 873, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4068, 2616, 873, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4069, 8722, 873, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (4070, 8723, 873, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (4071, 7188, 873, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (4072, 5403, 873, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4073, 8724, 873, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (4074, 2619, 873, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (4205, 8404, 883, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4208, 8407, 883, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4206, 2254, 883, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4209, 8414, 883, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4211, 8424, 883, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4204, 8425, 883, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (4207, 8428, 883, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (4210, 8429, 883, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (4998, 3182, 980, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4086, 8725, 414, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4087, 723, 7, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4088, 5173, 880, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4089, 7448, 880, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4090, 8726, 880, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4091, 4692, 880, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4094, 3472, 601, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (4095, 613, 601, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (4096, 9273, 601, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (4098, 3970, 601, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4099, 4394, 601, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4100, 4427, 601, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4101, 4438, 601, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4102, 2071, 601, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4103, 3904, 601, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4104, 8727, 601, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4112, 8729, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4113, 7462, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4114, 5082, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4115, 2243, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4116, 4904, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4117, 5324, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4118, 8730, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4119, 8731, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4120, 8732, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4121, 8733, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4122, 8734, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4123, 8735, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4046, 3538, 610, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4001, 85, 86, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (4002, 1124, 86, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4003, 1676, 86, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4004, 1610, 86, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (4124, 8736, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4125, 8737, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4126, 8738, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4127, 8739, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4128, 8740, 878, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4034, 3301, 149, 1, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4129, 2858, 881, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4130, 1912, 881, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (4131, 3443, 881, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (4132, 7191, 881, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (4133, 5498, 881, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (4134, 5571, 881, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (4135, 2291, 881, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (4136, 8171, 881, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (4137, 7654, 881, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (4138, 2358, 881, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (4139, 2362, 881, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (4140, 6856, 881, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (4141, 1146, 881, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (4142, 2580, 881, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (4143, 2592, 881, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (4144, 4782, 881, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (4145, 2605, 881, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (4146, 2635, 881, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (4147, 1679, 881, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (4148, 2637, 881, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (4149, 3028, 881, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (4150, 2364, 881, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4151, 2650, 881, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (4152, 4290, 881, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4153, 4302, 881, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (4154, 7190, 881, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (4155, 1334, 881, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (4156, 1392, 881, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4157, 3367, 881, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (4158, 1510, 881, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (4159, 6857, 881, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (4160, 1574, 881, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (4161, 2629, 881, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4162, 8741, 881, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4163, 8742, 881, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4164, 8743, 881, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (4165, 6849, 881, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4166, 8744, 881, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4167, 8745, 881, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (4168, 8746, 881, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (4170, 4480, 263, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4171, 156, 869, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (4172, 172, 869, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4173, 2511, 869, 50, 72);
INSERT INTO 'tunespublicationsmap' VALUES (4174, 2128, 869, 10, 80);
INSERT INTO 'tunespublicationsmap' VALUES (4175, 420, 869, 50, 73);
INSERT INTO 'tunespublicationsmap' VALUES (4176, 3113, 869, 10, 74);
INSERT INTO 'tunespublicationsmap' VALUES (4177, 5034, 869, 50, 83);
INSERT INTO 'tunespublicationsmap' VALUES (4178, 2381, 869, 10, 91);
INSERT INTO 'tunespublicationsmap' VALUES (4179, 2442, 869, 50, 93);
INSERT INTO 'tunespublicationsmap' VALUES (4180, 971, 869, 50, 95);
INSERT INTO 'tunespublicationsmap' VALUES (4181, 1117, 869, 50, 76);
INSERT INTO 'tunespublicationsmap' VALUES (4182, 2628, 869, 50, 67);
INSERT INTO 'tunespublicationsmap' VALUES (4183, 3093, 869, 10, 77);
INSERT INTO 'tunespublicationsmap' VALUES (4184, 3476, 869, 10, 101);
INSERT INTO 'tunespublicationsmap' VALUES (4185, 4924, 869, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4186, 243, 869, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4187, 1464, 416, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (4188, 2915, 416, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4189, 7944, 882, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4190, 3651, 882, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4191, 7942, 882, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (4192, 1859, 882, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4193, 3629, 882, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4194, 4482, 882, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4195, 7857, 882, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (4196, 2363, 882, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4197, 5520, 871, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (4198, 3818, 571, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4199, 3819, 571, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4105, 8728, 803, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4106, 1059, 803, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4107, 1542, 803, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4169, 1660, 877, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (4108, 1509, 84, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4109, 3285, 84, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4110, 3286, 84, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4055, 4005, 640, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4056, 3731, 640, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4057, 8718, 640, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4111, 4102, 84, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4202, 2256, 488, 10, 76);
INSERT INTO 'tunespublicationsmap' VALUES (4200, 7834, 488, 10, 89);
INSERT INTO 'tunespublicationsmap' VALUES (4203, 7949, 488, 10, 148);
INSERT INTO 'tunespublicationsmap' VALUES (4201, 576, 488, 10, 230);
INSERT INTO 'tunespublicationsmap' VALUES (4307, 7817, 902, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4308, 2869, 902, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (4309, 48, 902, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (4310, 7350, 902, 50, 37);
INSERT INTO 'tunespublicationsmap' VALUES (4311, 7351, 902, 50, 37);
INSERT INTO 'tunespublicationsmap' VALUES (4312, 7360, 902, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (4313, 7406, 902, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (4314, 7407, 902, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4315, 4633, 902, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (4316, 7569, 902, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (4317, 7408, 902, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (4318, 387, 902, 50, 35);
INSERT INTO 'tunespublicationsmap' VALUES (4319, 7418, 902, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (4320, 7352, 902, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (4297, 8867, 893, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4321, 7419, 902, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (4322, 7409, 902, 50, 34);
INSERT INTO 'tunespublicationsmap' VALUES (4323, 3348, 902, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4324, 7397, 902, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (4325, 8376, 902, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (4326, 7374, 902, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (4327, 4450, 902, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (4328, 8017, 902, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (4329, 7410, 902, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (4330, 7402, 902, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4331, 7412, 902, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4332, 7411, 902, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (4333, 4694, 902, 50, 36);
INSERT INTO 'tunespublicationsmap' VALUES (4334, 7356, 902, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (4335, 1749, 902, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (4336, 3645, 902, 50, 36);
INSERT INTO 'tunespublicationsmap' VALUES (4337, 3121, 902, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (4338, 2833, 902, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (4339, 7424, 902, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (4340, 7414, 902, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (4341, 8374, 902, 50, 36);
INSERT INTO 'tunespublicationsmap' VALUES (4342, 7357, 902, 50, 28);
INSERT INTO 'tunespublicationsmap' VALUES (4343, 7399, 902, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (4344, 4204, 902, 50, 33);
INSERT INTO 'tunespublicationsmap' VALUES (4345, 2756, 902, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (4346, 7415, 902, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (4347, 3058, 902, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (4348, 7401, 902, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (4349, 8905, 902, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (4350, 8906, 902, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (4351, 8907, 902, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (4352, 8908, 902, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (4353, 8909, 902, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (4354, 8910, 902, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (4355, 8911, 902, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4356, 8912, 902, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4357, 8913, 902, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4358, 8914, 902, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4359, 8915, 902, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4360, 8916, 902, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4361, 8917, 902, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4362, 8918, 902, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4363, 8919, 902, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4364, 8920, 902, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4365, 8921, 902, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4366, 8922, 902, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4367, 8923, 902, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4368, 8924, 902, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4264, 7927, 885, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4267, 8435, 885, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4258, 7926, 885, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4268, 8436, 885, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4260, 8445, 885, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4263, 8308, 885, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4265, 8446, 885, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4262, 8461, 885, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4259, 8462, 885, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (4271, 8463, 885, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4266, 8464, 885, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (4216, 8405, 883, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4217, 8406, 883, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4214, 8415, 883, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4213, 8426, 883, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4215, 8427, 883, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (4212, 7436, 883, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4219, 8408, 883, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (4218, 8409, 883, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4222, 8410, 883, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (4234, 8411, 883, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (4232, 8412, 883, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (4225, 3734, 883, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (4223, 8413, 883, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (4221, 8416, 883, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (4227, 8417, 883, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (4229, 5773, 883, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (4224, 8419, 883, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (4220, 4034, 883, 50, 28);
INSERT INTO 'tunespublicationsmap' VALUES (4230, 8422, 883, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (4231, 1266, 883, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (4233, 8423, 883, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (4228, 5779, 883, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (4226, 5778, 883, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (4245, 8007, 883, 50, 34);
INSERT INTO 'tunespublicationsmap' VALUES (4243, 4093, 883, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (4242, 3661, 883, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (4237, 8420, 883, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (4235, 4776, 883, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (4241, 8421, 883, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (4244, 4125, 883, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (4240, 8430, 883, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (4238, 8431, 883, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (4236, 8433, 883, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (4239, 8434, 883, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (4369, 8925, 902, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4370, 8926, 902, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4371, 8927, 902, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4372, 8928, 902, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4373, 8929, 902, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4374, 8930, 902, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4375, 8931, 902, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (4376, 8932, 902, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4377, 8933, 902, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4378, 8934, 902, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4379, 8935, 902, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (4380, 8936, 902, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (4381, 8937, 902, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (4382, 8938, 902, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (4383, 8939, 902, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4384, 8940, 902, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (4385, 8941, 902, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (4386, 8942, 902, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (4387, 8943, 902, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (4388, 8944, 902, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (4389, 8945, 902, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (4390, 7416, 902, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (4391, 7405, 902, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (4392, 3720, 902, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (4393, 8947, 902, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (4394, 8948, 902, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (4395, 8949, 902, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (4396, 8950, 902, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (4397, 8951, 902, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (4398, 8952, 902, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (4399, 8953, 902, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (4400, 8954, 902, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (4401, 8955, 902, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (4402, 8956, 902, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (4403, 8957, 902, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (4404, 8958, 902, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (4405, 8959, 902, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (4406, 8961, 902, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (4407, 8962, 902, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (4408, 8963, 902, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (4409, 8964, 902, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (4410, 8965, 902, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (4411, 8966, 902, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (4412, 8375, 902, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (4425, 8978, 902, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (4426, 7370, 904, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (4427, 3554, 904, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (4428, 3298, 904, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (4429, 8979, 904, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4430, 4089, 904, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4431, 4184, 904, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4432, 4062, 904, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4433, 7398, 904, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4434, 7371, 904, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4435, 4485, 904, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4436, 7385, 904, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (4437, 7380, 904, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4438, 7387, 904, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (4439, 3975, 904, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4440, 3678, 904, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (4441, 3889, 904, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (4442, 4588, 904, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (4443, 4680, 904, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (4444, 3899, 904, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4445, 3506, 904, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (4446, 3803, 904, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (4447, 7395, 904, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (4448, 7381, 904, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (4449, 7388, 904, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (4450, 4274, 904, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (4451, 7403, 904, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (4452, 3297, 904, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (4453, 8980, 904, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (4454, 8981, 904, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (4455, 8982, 904, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (4456, 8983, 904, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (4457, 8987, 906, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4458, 8988, 906, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4997, 3183, 980, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5003, 525, 980, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5000, 266, 980, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5007, 3166, 980, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5006, 2366, 980, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (4999, 96, 980, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (5005, 3179, 980, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5001, 3180, 980, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (5004, 2487, 980, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5002, 474, 980, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (4503, 9043, 83, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4504, 9044, 83, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4505, 9045, 83, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4506, 9046, 83, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4487, 418, 161, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4488, 8882, 918, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (4489, 8892, 918, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (4490, 8878, 918, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4491, 8946, 921, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4492, 8960, 921, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4493, 9023, 921, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4494, 9072, 921, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4495, 9073, 921, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4496, 9074, 921, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4497, 9075, 921, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4498, 9076, 921, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4499, 9077, 921, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4500, 9078, 921, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4501, 9079, 921, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4502, 9080, 921, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4513, 9096, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4514, 9095, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4515, 9094, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4516, 9090, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4517, 9091, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4518, 9092, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4519, 9093, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4520, 9088, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4521, 9089, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4522, 9087, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4523, 9085, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4524, 9086, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4525, 9084, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4467, 1852, 911, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4468, 3865, 911, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4469, 8998, 911, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4470, 8999, 911, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4471, 9000, 911, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4472, 9001, 911, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4507, 9047, 83, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4508, 9050, 83, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4509, 152, 83, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (4510, 9051, 83, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (4511, 9052, 83, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (4512, 9055, 83, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (5013, 683, 980, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (5009, 3167, 980, 50, 31);
INSERT INTO 'tunespublicationsmap' VALUES (4464, 8994, 910, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4460, 8990, 910, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4463, 8993, 910, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (4462, 8992, 910, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4459, 8989, 910, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (4466, 8996, 910, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (4461, 8991, 910, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (4465, 8995, 910, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (4526, 9083, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4527, 8238, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4528, 9082, 920, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7124, 8971, 903, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7125, 3168, 903, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4581, 9480, 943, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4582, 7706, 943, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4541, 9414, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4542, 9413, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4543, 9415, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4544, 9417, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4545, 9418, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4546, 9419, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4547, 9420, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4548, 9421, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4549, 9422, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4550, 9423, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4551, 9424, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4552, 9425, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4553, 9426, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4554, 9427, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4555, 9428, 940, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4556, 2209, 659, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (4557, 3362, 659, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (4558, 7840, 659, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (4559, 3288, 659, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4560, 3068, 659, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4561, 9436, 659, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4562, 2261, 659, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4563, 9437, 659, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4564, 9438, 659, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4565, 858, 659, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4566, 6119, 659, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (4567, 9439, 659, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4568, 9440, 659, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (4569, 9441, 659, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4570, 9442, 659, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (4571, 9443, 659, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (4572, 9444, 659, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4573, 1469, 659, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (4574, 1314, 659, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (4575, 9448, 941, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4576, 9449, 941, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4577, 9450, 941, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4578, 9451, 941, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4579, 9452, 941, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4580, 9453, 941, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4591, 9561, 949, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4592, 9562, 949, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (4594, 9566, 783, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4596, 3739, 508, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4599, 1196, 765, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4600, 63, 765, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (4601, 3512, 510, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4606, 1645, 841, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (4607, 2187, 841, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (4608, 8385, 841, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (4609, 3299, 841, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4610, 2152, 841, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4611, 1461, 841, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4612, 6507, 841, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4613, 7323, 841, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4614, 9597, 841, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4615, 3740, 841, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4616, 674, 841, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4619, 9609, 953, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4620, 9598, 953, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4621, 9599, 953, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4593, 2973, 337, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4529, 9248, 931, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4622, 568, 953, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4623, 9600, 953, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4624, 9601, 953, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4625, 9602, 953, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4626, 9603, 953, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4627, 9604, 953, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4628, 9605, 953, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4629, 9606, 953, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4630, 9607, 953, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4631, 9608, 953, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4632, 2473, 953, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4633, 234, 953, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4634, 2670, 953, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4583, 7704, 943, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4584, 9481, 943, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4585, 9482, 943, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4586, 9484, 943, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4587, 9454, 943, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4588, 7705, 943, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7126, 8972, 903, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7127, 8974, 903, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5017, 3168, 980, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (5016, 3169, 980, 50, 33);
INSERT INTO 'tunespublicationsmap' VALUES (5015, 828, 980, 50, 34);
INSERT INTO 'tunespublicationsmap' VALUES (5012, 3176, 980, 50, 35);
INSERT INTO 'tunespublicationsmap' VALUES (5014, 3177, 980, 50, 36);
INSERT INTO 'tunespublicationsmap' VALUES (5010, 3178, 980, 50, 37);
INSERT INTO 'tunespublicationsmap' VALUES (5018, 1469, 980, 50, 38);
INSERT INTO 'tunespublicationsmap' VALUES (5011, 3184, 980, 50, 39);
INSERT INTO 'tunespublicationsmap' VALUES (5008, 3185, 980, 50, 40);
INSERT INTO 'tunespublicationsmap' VALUES (5020, 3186, 980, 50, 42);
INSERT INTO 'tunespublicationsmap' VALUES (5019, 3187, 980, 50, 43);
INSERT INTO 'tunespublicationsmap' VALUES (5021, 3175, 980, 50, 44);
INSERT INTO 'tunespublicationsmap' VALUES (5022, 3172, 980, 50, 46);
INSERT INTO 'tunespublicationsmap' VALUES (5023, 3173, 980, 50, 47);
INSERT INTO 'tunespublicationsmap' VALUES (5024, 3174, 980, 50, 48);
INSERT INTO 'tunespublicationsmap' VALUES (7120, 8967, 903, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7123, 8970, 903, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7128, 8973, 903, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7129, 8975, 903, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7130, 8976, 903, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7131, 8977, 903, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4589, 12, 648, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4540, 3184, 253, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5031, 2248, 993, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5027, 2267, 993, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5028, 2268, 993, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5026, 2271, 993, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5030, 2272, 993, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5048, 5, 993, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5050, 2204, 993, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5053, 2207, 993, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5057, 2208, 993, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (4602, 9593, 977, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5054, 2217, 993, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (5042, 2201, 993, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5052, 2221, 993, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5051, 2261, 993, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (5055, 2049, 993, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5056, 2262, 993, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (5049, 2265, 993, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (5045, 2193, 993, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (5044, 2195, 993, 50, 31);
INSERT INTO 'tunespublicationsmap' VALUES (5040, 2198, 993, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (5046, 2250, 993, 50, 34);
INSERT INTO 'tunespublicationsmap' VALUES (5047, 2251, 993, 50, 35);
INSERT INTO 'tunespublicationsmap' VALUES (5039, 2253, 993, 50, 36);
INSERT INTO 'tunespublicationsmap' VALUES (5038, 2254, 993, 50, 37);
INSERT INTO 'tunespublicationsmap' VALUES (5043, 2638, 993, 50, 38);
INSERT INTO 'tunespublicationsmap' VALUES (5041, 2224, 993, 50, 40);
INSERT INTO 'tunespublicationsmap' VALUES (5058, 2239, 993, 50, 42);
INSERT INTO 'tunespublicationsmap' VALUES (5059, 2233, 993, 50, 43);
INSERT INTO 'tunespublicationsmap' VALUES (5060, 2237, 993, 50, 44);
INSERT INTO 'tunespublicationsmap' VALUES (5061, 2275, 993, 50, 46);
INSERT INTO 'tunespublicationsmap' VALUES (5062, 2273, 993, 50, 48);
INSERT INTO 'tunespublicationsmap' VALUES (5037, 2222, 993, 50, 49);
INSERT INTO 'tunespublicationsmap' VALUES (3632, 7927, 840, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3633, 8437, 840, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3634, 8457, 840, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3635, 8438, 840, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3636, 3290, 840, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3637, 8308, 840, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3638, 821, 840, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3639, 4715, 840, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3640, 8451, 840, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3641, 8452, 840, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3642, 8454, 840, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3643, 422, 840, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3644, 8461, 840, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6924, 135, 1411, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6925, 1663, 1411, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6926, 796, 1411, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6927, 985, 1411, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6928, 1383, 1411, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6929, 795, 1411, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6930, 1626, 1411, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6931, 746, 1411, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6932, 1651, 1411, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6933, 1266, 1411, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6934, 454, 1411, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6935, 1817, 1411, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6936, 2577, 1411, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6937, 1258, 1411, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6938, 1555, 1411, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6939, 38, 1411, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6940, 1810, 1411, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6941, 1837, 1411, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6942, 401, 1411, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (6943, 391, 1411, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6944, 1085, 1411, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (6844, 13649, 1383, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6845, 13650, 1383, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6846, 13651, 1383, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6847, 13652, 1383, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6848, 13653, 1383, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (6849, 13654, 1383, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (6850, 13655, 1383, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (6851, 13656, 1383, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (6852, 13657, 1383, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (6853, 13658, 1383, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (6854, 13659, 1383, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (6855, 13660, 1383, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (6859, 13664, 1383, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (6860, 13665, 1383, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (6861, 13666, 1383, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (6862, 13667, 1383, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (6863, 13668, 1383, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (6864, 13669, 1383, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (6865, 13670, 1383, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (50, 684, 113, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6968, 5729, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6969, 13813, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6970, 13814, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6971, 79, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6972, 13815, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6973, 9175, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6974, 1969, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6975, 13816, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6976, 13817, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6977, 13818, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6978, 4727, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6979, 4746, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6980, 13819, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6981, 13820, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6982, 6345, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6983, 13821, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6984, 13822, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4635, 7547, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6965, 5080, 1423, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6985, 13822, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6986, 13823, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6987, 13824, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6988, 13825, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6989, 486, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6990, 487, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6991, 13826, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6992, 13827, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6993, 13828, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6994, 13829, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6995, 13830, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6996, 13831, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6997, 13832, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6998, 13833, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6999, 13834, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6082, 9024, 913, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6083, 2269, 913, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6084, 9025, 913, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6085, 7797, 913, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6086, 8840, 913, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6087, 9026, 913, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6088, 9523, 913, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6089, 1137, 913, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6090, 9028, 913, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6091, 2636, 913, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6092, 2594, 913, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6093, 1126, 913, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6094, 9029, 913, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6095, 576, 913, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6096, 106, 913, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (931, 1593, 3, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (238, 374, 3, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (915, 1650, 3, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6097, 2949, 715, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6098, 4109, 715, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6099, 4111, 715, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6100, 4113, 715, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6101, 2830, 715, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6102, 4136, 715, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6103, 4123, 715, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6104, 4126, 715, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6105, 857, 715, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3572, 4833, 822, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3573, 8245, 822, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3574, 8244, 822, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3575, 8246, 822, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3576, 8247, 822, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3577, 4801, 822, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3578, 37, 822, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3579, 6422, 822, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3580, 8248, 822, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6106, 7194, 1146, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6107, 2151, 1146, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6108, 9047, 1146, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6109, 12570, 1146, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6110, 543, 1146, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6111, 1427, 1146, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6112, 12571, 1146, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6113, 11065, 1146, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6114, 12572, 1146, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6115, 12425, 1146, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6116, 2457, 1146, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6117, 2577, 1146, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1116, 3151, 3, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6119, 12573, 666, 1, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6120, 12574, 666, 1, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6121, 12575, 666, 1, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6122, 12576, 666, 1, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6123, 12593, 1156, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6124, 12594, 1156, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6125, 12595, 1156, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6176, 10158, 1149, 1, 30);
INSERT INTO 'tunespublicationsmap' VALUES (6177, 12623, 1149, 1, 32);
INSERT INTO 'tunespublicationsmap' VALUES (6178, 10157, 1149, 1, 34);
INSERT INTO 'tunespublicationsmap' VALUES (6179, 6490, 948, 1, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6180, 2299, 948, 1, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6181, 12624, 948, 1, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6182, 10153, 948, 1, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6183, 12625, 948, 1, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6127, 11158, 1152, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6142, 12537, 1152, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6141, 12536, 1152, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6128, 12536, 1152, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (510, 497, 3, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (886, 1535, 3, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (320, 1503, 3, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (398, 1546, 3, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (418, 487, 3, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7000, 13835, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7001, 13836, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7002, 13837, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7003, 13838, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6144, 12538, 1152, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6143, 11158, 1152, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6147, 12541, 1152, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6129, 12539, 1152, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6145, 12539, 1152, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6146, 12540, 1152, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6150, 12543, 1152, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6149, 12542, 1152, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6130, 12542, 1152, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6151, 12544, 1152, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6152, 12545, 1152, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6184, 12626, 948, 1, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6185, 12627, 948, 1, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6186, 1578, 948, 1, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6187, 6760, 948, 1, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6188, 4323, 948, 1, 23);
INSERT INTO 'tunespublicationsmap' VALUES (6189, 12628, 948, 1, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6190, 12629, 948, 1, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3884, 8, 152, 1, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3885, 302, 152, 1, 33);
INSERT INTO 'tunespublicationsmap' VALUES (3886, 331, 152, 1, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3887, 2317, 152, 1, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3888, 488, 152, 1, 3);
INSERT INTO 'tunespublicationsmap' VALUES (3889, 538, 152, 1, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3890, 540, 152, 1, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3891, 585, 152, 1, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3892, 757, 152, 1, 34);
INSERT INTO 'tunespublicationsmap' VALUES (3893, 779, 152, 1, 27);
INSERT INTO 'tunespublicationsmap' VALUES (4683, 698, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3894, 1279, 152, 1, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3895, 1310, 152, 1, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3896, 1406, 152, 1, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3897, 1481, 152, 1, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3898, 1531, 152, 1, 31);
INSERT INTO 'tunespublicationsmap' VALUES (3899, 1823, 152, 1, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7004, 13839, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7005, 4310, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7006, 8331, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6211, 12664, 1159, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6212, 11499, 1159, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6213, 12665, 1159, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6214, 12666, 1159, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6215, 12667, 1159, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6216, 3358, 1159, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6217, 12668, 1159, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6218, 12669, 1159, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6219, 12670, 1159, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6208, 875, 1163, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6209, 3665, 1163, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6243, 11565, 1048, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6244, 8955, 1048, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6245, 11567, 1048, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6246, 8952, 1048, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6247, 11569, 1048, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6248, 11570, 1048, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6249, 11571, 1048, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6250, 11572, 1048, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6251, 11573, 1048, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6252, 11574, 1048, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (6253, 11575, 1048, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (6254, 12694, 1048, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (6255, 11577, 1048, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (6256, 8953, 1048, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (6257, 11579, 1048, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (6258, 11580, 1048, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (6259, 5535, 1168, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6260, 3072, 1169, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6261, 12696, 1169, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6262, 12695, 1169, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6263, 12697, 1169, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6264, 12698, 1169, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6265, 12699, 1169, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6266, 821, 1169, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6267, 12700, 1169, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6268, 12701, 1169, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6269, 12702, 1169, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6270, 12703, 1169, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (6271, 12704, 1169, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6272, 12705, 1169, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (6273, 12706, 1169, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (6274, 12707, 1169, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (6275, 12708, 1169, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (6276, 12081, 1169, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (6277, 12709, 1169, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (6278, 9552, 1169, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (6279, 12710, 1169, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (6280, 5390, 1169, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (7019, 13809, 1408, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (567, 1285, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4008, 1308, 151, 1, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1019, 1712, 151, 1, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6065, 4766, 1130, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6066, 7436, 1130, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6191, 7587, 529, 1, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6192, 7594, 529, 1, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6193, 7595, 529, 1, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6194, 7596, 529, 1, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6195, 12630, 529, 1, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6196, 12631, 529, 1, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6197, 12632, 529, 1, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6198, 7597, 529, 1, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6199, 12633, 529, 1, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6200, 11560, 529, 1, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6201, 12634, 529, 1, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6202, 7583, 529, 1, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6203, 12635, 529, 1, 23);
INSERT INTO 'tunespublicationsmap' VALUES (6204, 12636, 529, 1, 23);
INSERT INTO 'tunespublicationsmap' VALUES (6205, 12637, 529, 1, 25);
INSERT INTO 'tunespublicationsmap' VALUES (339, 721, 151, 1, 15);
INSERT INTO 'tunespublicationsmap' VALUES (155, 3360, 149, 1, 25);
INSERT INTO 'tunespublicationsmap' VALUES (185, 3385, 149, 1, 13);
INSERT INTO 'tunespublicationsmap' VALUES (4038, 3637, 149, 1, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4039, 4455, 149, 1, 11);
INSERT INTO 'tunespublicationsmap' VALUES (4040, 4338, 149, 1, 15);
INSERT INTO 'tunespublicationsmap' VALUES (4041, 3865, 149, 1, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4042, 3917, 149, 1, 21);
INSERT INTO 'tunespublicationsmap' VALUES (4043, 3956, 149, 1, 23);
INSERT INTO 'tunespublicationsmap' VALUES (4044, 806, 149, 1, 27);
INSERT INTO 'tunespublicationsmap' VALUES (4045, 4297, 149, 1, 29);
INSERT INTO 'tunespublicationsmap' VALUES (6300, 5562, 149, 2, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4035, 3302, 149, 2, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4037, 3304, 149, 4, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4036, 3303, 149, 3, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2711, 849, 153, 1, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6299, 12889, 1062, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6298, 5080, 1062, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5414, 9898, 1009, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5415, 9901, 1009, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5416, 9904, 1009, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5417, 2892, 1009, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5418, 1651, 1009, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5419, 2056, 1009, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5420, 3784, 1009, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6210, 10033, 1062, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7007, 13840, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7008, 966, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7009, 3614, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7010, 13841, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (600, 1019, 15, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3983, 1691, 1, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3984, 547, 1, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3985, 560, 1, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3982, 2572, 1, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (279, 3419, 2, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2713, 559, 153, 3, 6);
INSERT INTO 'tunespublicationsmap' VALUES (121, 1282, 157, 1, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5072, 9800, 157, 2, 2);
INSERT INTO 'tunespublicationsmap' VALUES (789, 1273, 157, 1, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6303, 12622, 1149, 1, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6307, 12953, 1183, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6308, 1334, 1183, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6309, 4871, 1183, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6310, 12076, 1183, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6311, 1413, 1183, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6312, 10650, 1183, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6313, 7904, 1183, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6314, 3484, 1183, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6315, 143, 1183, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6316, 12954, 1183, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6317, 5535, 1183, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6318, 5018, 1183, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6319, 2812, 1183, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6320, 12955, 1183, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6321, 12956, 1183, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7023, 1185, 160, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7024, 602, 160, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7025, 1153, 160, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7026, 1247, 160, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7027, 859, 160, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7028, 1268, 160, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (7029, 1395, 160, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (6336, 3335, 1187, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6337, 3336, 1187, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6339, 1013, 1192, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6340, 767, 1192, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6342, 13000, 1199, 20, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6343, 13001, 1199, 20, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6344, 5855, 1199, 20, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6345, 13002, 1199, 20, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6346, 13003, 1199, 20, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6347, 13004, 1199, 20, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6348, 13005, 1199, 20, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6349, 13006, 1199, 20, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6350, 8602, 1199, 20, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6351, 9109, 1199, 20, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6352, 13007, 1199, 20, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6353, 13008, 1199, 20, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6354, 2973, 1199, 20, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1051, 1561, 16, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (814, 1393, 13, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2061, 1514, 409, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6355, 6003, 409, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6356, 3628, 409, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6357, 10345, 409, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6358, 1609, 409, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6359, 3004, 409, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6360, 1888, 409, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6361, 2531, 409, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (227, 124, 12, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (253, 3468, 12, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (326, 1673, 12, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7030, 845, 160, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (6377, 13055, 1210, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (6295, 7881, 1175, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (6296, 12876, 1175, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (6362, 10866, 1201, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6363, 10466, 1201, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6364, 10463, 1201, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6365, 10454, 1201, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6366, 10486, 1201, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6367, 7705, 1201, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6368, 10480, 1201, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6297, 5080, 1175, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (6378, 13056, 1210, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (6379, 10524, 1210, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (6380, 13057, 1210, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (6381, 13058, 1210, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (6301, 1199, 631, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6302, 1807, 631, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6288, 2110, 1175, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6289, 2048, 1175, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6290, 2255, 1175, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6411, 13083, 1215, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6412, 1897, 1215, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (340, 578, 12, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (414, 479, 12, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (416, 481, 12, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (448, 872, 12, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (522, 624, 12, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (581, 770, 12, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (591, 1627, 12, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (618, 820, 12, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (712, 1041, 12, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (716, 3496, 12, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1113, 1843, 12, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5452, 11504, 1028, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5453, 11506, 1028, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5455, 10057, 1028, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5456, 11507, 1028, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5457, 11508, 1028, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5458, 11509, 1028, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5459, 1553, 1028, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5460, 11510, 1028, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5461, 11511, 1028, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5462, 11512, 1028, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6413, 13084, 1219, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6414, 13085, 1220, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6415, 13086, 1222, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6416, 13087, 1222, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6291, 8886, 1175, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6292, 5390, 1175, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6293, 12875, 1175, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6294, 9256, 1175, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6322, 19, 1184, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6323, 12957, 1184, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6324, 1788, 1184, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6325, 3264, 1184, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6242, 12675, 421, 10, 130);
INSERT INTO 'tunespublicationsmap' VALUES (7020, 13844, 1427, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7021, 13845, 1427, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6338, 3938, 1191, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6326, 2427, 1184, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6327, 107, 1184, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6328, 9354, 1184, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6382, 13059, 1210, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (6383, 10015, 1210, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (6384, 13060, 1210, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (6385, 13078, 1210, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (6386, 13079, 1210, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (6387, 8940, 1210, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (6388, 13061, 1210, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (6389, 13062, 1210, 10, 51);
INSERT INTO 'tunespublicationsmap' VALUES (6417, 13088, 1222, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6418, 13089, 1222, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6419, 13090, 1222, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6420, 13091, 1222, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6421, 162, 1222, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6422, 13092, 1222, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6423, 13093, 1222, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6441, 12073, 1235, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6442, 13109, 1236, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6443, 4825, 1236, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6444, 13110, 1236, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6424, 12952, 1223, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6425, 13095, 1223, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (996, 3655, 102, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (997, 3656, 102, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (998, 4230, 102, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (999, 4460, 102, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6445, 1164, 1238, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6446, 11260, 1238, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6447, 975, 1238, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6448, 13111, 1238, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6449, 12647, 1238, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6450, 1331, 1238, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6451, 6970, 1238, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6452, 13112, 1238, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6453, 13113, 1238, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (6454, 11269, 1238, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6455, 11272, 1238, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (5689, 568, 1080, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5690, 11697, 1080, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5691, 9606, 1080, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5692, 11698, 1080, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5693, 11699, 1080, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5694, 11700, 1080, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6426, 13097, 1223, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6456, 9912, 1239, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6457, 13114, 1239, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6458, 13115, 1239, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3723, 4091, 868, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3725, 8604, 868, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5897, 12161, 1108, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5898, 12162, 1108, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5899, 11644, 1108, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5900, 7812, 1108, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5901, 3372, 1108, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5902, 12163, 1108, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5904, 3408, 1108, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5905, 3467, 1108, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (5907, 3312, 1108, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5908, 7815, 1108, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (5911, 3566, 1108, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (5913, 2959, 1108, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (5914, 7134, 1108, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (5917, 12166, 1108, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (5918, 7796, 1108, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (5919, 3729, 1108, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (5920, 12167, 1108, 10, 53);
INSERT INTO 'tunespublicationsmap' VALUES (5921, 1336, 1108, 10, 55);
INSERT INTO 'tunespublicationsmap' VALUES (5922, 164, 1108, 10, 57);
INSERT INTO 'tunespublicationsmap' VALUES (5923, 3791, 1108, 10, 59);
INSERT INTO 'tunespublicationsmap' VALUES (5924, 12168, 1108, 10, 61);
INSERT INTO 'tunespublicationsmap' VALUES (5925, 6951, 1108, 10, 64);
INSERT INTO 'tunespublicationsmap' VALUES (5926, 7028, 1108, 10, 64);
INSERT INTO 'tunespublicationsmap' VALUES (5927, 7029, 1108, 10, 65);
INSERT INTO 'tunespublicationsmap' VALUES (5928, 1616, 1108, 10, 67);
INSERT INTO 'tunespublicationsmap' VALUES (5929, 5864, 1108, 10, 69);
INSERT INTO 'tunespublicationsmap' VALUES (5930, 1894, 1108, 10, 71);
INSERT INTO 'tunespublicationsmap' VALUES (5931, 12169, 1108, 10, 73);
INSERT INTO 'tunespublicationsmap' VALUES (5932, 1981, 1108, 10, 75);
INSERT INTO 'tunespublicationsmap' VALUES (5933, 5666, 1108, 10, 77);
INSERT INTO 'tunespublicationsmap' VALUES (5934, 12170, 1108, 10, 79);
INSERT INTO 'tunespublicationsmap' VALUES (5935, 1771, 1108, 10, 81);
INSERT INTO 'tunespublicationsmap' VALUES (5936, 1249, 1108, 10, 83);
INSERT INTO 'tunespublicationsmap' VALUES (5937, 3590, 1108, 10, 85);
INSERT INTO 'tunespublicationsmap' VALUES (5938, 4221, 1108, 10, 87);
INSERT INTO 'tunespublicationsmap' VALUES (5939, 4227, 1108, 10, 89);
INSERT INTO 'tunespublicationsmap' VALUES (5940, 1541, 1108, 10, 91);
INSERT INTO 'tunespublicationsmap' VALUES (5941, 12171, 1108, 10, 93);
INSERT INTO 'tunespublicationsmap' VALUES (5942, 4714, 1108, 10, 95);
INSERT INTO 'tunespublicationsmap' VALUES (5943, 2386, 1108, 10, 97);
INSERT INTO 'tunespublicationsmap' VALUES (5944, 12172, 1108, 10, 99);
INSERT INTO 'tunespublicationsmap' VALUES (5946, 12174, 1108, 10, 101);
INSERT INTO 'tunespublicationsmap' VALUES (5947, 12175, 1108, 10, 103);
INSERT INTO 'tunespublicationsmap' VALUES (5948, 12176, 1108, 10, 105);
INSERT INTO 'tunespublicationsmap' VALUES (5949, 2353, 1108, 10, 107);
INSERT INTO 'tunespublicationsmap' VALUES (5950, 4558, 1108, 10, 109);
INSERT INTO 'tunespublicationsmap' VALUES (5951, 4632, 1108, 10, 112);
INSERT INTO 'tunespublicationsmap' VALUES (5952, 2939, 1108, 10, 113);
INSERT INTO 'tunespublicationsmap' VALUES (5953, 4643, 1108, 10, 115);
INSERT INTO 'tunespublicationsmap' VALUES (5954, 1341, 1108, 10, 117);
INSERT INTO 'tunespublicationsmap' VALUES (5955, 11645, 1108, 10, 119);
INSERT INTO 'tunespublicationsmap' VALUES (5956, 3257, 1108, 10, 122);
INSERT INTO 'tunespublicationsmap' VALUES (5957, 996, 1108, 10, 123);
INSERT INTO 'tunespublicationsmap' VALUES (5958, 12177, 1108, 10, 125);
INSERT INTO 'tunespublicationsmap' VALUES (5959, 1212, 1108, 10, 127);
INSERT INTO 'tunespublicationsmap' VALUES (5961, 12178, 1108, 10, 131);
INSERT INTO 'tunespublicationsmap' VALUES (6459, 13116, 1239, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6427, 12073, 1232, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6428, 10175, 1233, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6429, 13019, 1233, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6430, 13020, 1233, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6431, 9322, 1233, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6432, 13021, 1233, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6433, 13022, 1233, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6434, 13106, 1233, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6435, 2224, 1233, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6436, 13023, 1233, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6437, 8882, 1233, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6438, 13025, 1233, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (6439, 8340, 1233, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6440, 13107, 1234, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6460, 1758, 1239, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6461, 2675, 1239, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6462, 13117, 1239, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6473, 5584, 1244, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6468, 12643, 1164, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6469, 10842, 1164, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6470, 12649, 1164, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6471, 12652, 1164, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6472, 11305, 1164, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (5597, 9930, 773, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5598, 9931, 773, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5599, 9933, 773, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5600, 2692, 773, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5601, 9935, 773, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5602, 3804, 773, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5603, 625, 773, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5604, 9940, 773, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5606, 9941, 773, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5607, 9942, 773, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5608, 9943, 773, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (5609, 9944, 773, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (5610, 2459, 773, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (5611, 9945, 773, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (6463, 13118, 1239, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6464, 13119, 1239, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6465, 13120, 1239, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (6466, 13121, 1239, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (7031, 3301, 923, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7032, 7061, 923, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7033, 4455, 923, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7034, 3385, 1452, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7035, 4338, 1452, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7036, 1948, 1452, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7037, 3865, 1453, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7038, 5562, 1453, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7039, 3917, 1453, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7040, 3956, 1453, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7041, 3360, 1454, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5582, 878, 1044, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5583, 460, 1044, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5584, 1438, 1044, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5585, 95, 1044, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5586, 240, 1044, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5587, 1549, 1044, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5588, 1589, 1044, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5589, 394, 1044, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5590, 1678, 1044, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5591, 1165, 1044, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (5592, 462, 1044, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (5593, 45, 1044, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5594, 1523, 1044, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (5595, 1495, 1044, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5596, 108, 1044, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3156, 205, 56, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3157, 931, 56, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3158, 983, 56, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3159, 94, 56, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3160, 335, 56, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3161, 1811, 56, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3162, 3124, 56, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3163, 878, 56, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3164, 460, 56, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3165, 1438, 56, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3166, 240, 56, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3167, 1549, 56, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3168, 1589, 56, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3937, 394, 58, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3938, 1678, 58, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3939, 462, 58, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3940, 1165, 58, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3941, 45, 58, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3942, 1523, 58, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3943, 1495, 58, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3944, 108, 58, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2635, 4638, 79, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2634, 7435, 79, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2636, 3327, 79, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2637, 3679, 79, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (2638, 4239, 79, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6475, 11519, 1260, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6476, 13137, 1260, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6477, 13138, 1260, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6478, 9830, 1260, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6479, 5126, 1260, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6480, 2706, 1260, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6481, 1598, 1260, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6482, 13139, 1260, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6483, 13140, 1260, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6484, 8496, 1260, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6485, 13142, 1260, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6486, 5643, 1260, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6487, 730, 1260, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6488, 206, 1260, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6489, 13143, 1260, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6534, 13189, 1264, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6535, 7472, 1264, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6536, 13190, 1264, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6537, 13191, 1264, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6538, 13192, 1264, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6539, 7612, 1264, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6490, 1500, 197, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6491, 543, 197, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6492, 1683, 197, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6493, 1694, 197, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6494, 1073, 197, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6540, 4327, 1264, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6041, 4832, 1127, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6509, 10523, 1266, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6369, 13045, 1203, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6370, 13046, 1203, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6371, 13047, 1203, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6372, 13048, 1203, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6373, 13049, 1203, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6374, 13050, 1203, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6375, 13051, 1203, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6376, 13052, 1203, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6510, 8811, 1266, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6511, 13175, 1266, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6512, 1219, 1266, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6513, 13176, 1266, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7042, 806, 1454, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7043, 4297, 1454, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6474, 1270, 1249, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4479, 8838, 894, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4480, 8839, 894, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4481, 8841, 894, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6514, 13177, 1266, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6515, 2729, 1266, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6516, 13178, 1266, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6517, 1989, 1266, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6541, 2416, 1264, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6542, 13193, 1264, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6543, 13194, 1264, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6544, 13195, 1264, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6545, 2872, 1264, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6546, 13196, 1264, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4530, 3137, 935, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4531, 9279, 935, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4532, 9281, 935, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4533, 1922, 935, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4534, 9284, 935, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4535, 2522, 935, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4536, 9285, 935, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4537, 9286, 935, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4538, 3061, 935, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4539, 9291, 935, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4473, 9002, 911, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4474, 9003, 911, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6518, 9757, 1266, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6519, 2115, 1266, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6520, 13179, 1266, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6521, 13180, 1266, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5780, 11992, 1095, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5778, 11990, 1095, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5779, 11991, 1095, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5781, 11993, 1095, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4482, 8844, 894, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4483, 8846, 894, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4484, 8847, 894, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4485, 8849, 894, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6050, 5707, 1127, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (6051, 5708, 1127, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (6052, 5710, 1127, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6053, 1494, 1127, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (6054, 1479, 1127, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (6055, 1568, 1127, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (6056, 1515, 1127, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (6057, 1567, 1127, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (6058, 1008, 1127, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (6059, 890, 1127, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (4475, 9004, 911, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4476, 9005, 911, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4477, 9006, 911, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4478, 9007, 911, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4486, 1466, 911, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6549, 13210, 1278, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6550, 13211, 1278, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6551, 13212, 1278, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6552, 13213, 1278, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6553, 13214, 1278, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6554, 13215, 1278, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6555, 13216, 1278, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6556, 13217, 1278, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3931, 3277, 77, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3932, 3278, 77, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3933, 3279, 77, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3934, 3280, 77, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3935, 1856, 77, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3936, 3281, 77, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6547, 13208, 1276, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6548, 13209, 1276, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6557, 13218, 1279, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6558, 13219, 1279, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6559, 13220, 1279, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6560, 13221, 1279, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6561, 13222, 1279, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6562, 13223, 1279, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6563, 13224, 1279, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6564, 13225, 1279, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6565, 13226, 1279, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (15, 16, 761, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (16, 469, 761, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (17, 1670, 761, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (18, 1063, 761, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (19, 1053, 761, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (20, 224, 761, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (21, 1475, 761, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (22, 287, 761, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5613, 11583, 1053, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (3059, 281, 623, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3060, 2948, 623, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5774, 10151, 1094, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5775, 10146, 1094, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5776, 10150, 1094, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (5777, 10157, 1094, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (6577, 13247, 1289, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6578, 13248, 1289, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6579, 13249, 1289, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6580, 13250, 1289, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6581, 13251, 1289, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6582, 13253, 1289, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6583, 13254, 1289, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6584, 13255, 1289, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6585, 13256, 1289, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6586, 13252, 1289, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3061, 2392, 623, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3062, 7760, 623, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3063, 7425, 623, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3064, 3115, 623, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3065, 2562, 623, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3066, 536, 623, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3067, 6109, 623, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3068, 6612, 623, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7044, 276, 567, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7045, 9393, 567, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6566, 11592, 1053, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6567, 11593, 1053, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6568, 11594, 1053, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6569, 11584, 1053, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6570, 11585, 1053, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6571, 11586, 1053, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6572, 11587, 1053, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6573, 11588, 1053, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6574, 11589, 1053, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6575, 11590, 1053, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6576, 11591, 1053, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6221, 12672, 1159, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (6222, 12673, 1159, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (6223, 12674, 1159, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (6522, 4849, 1266, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (6523, 365, 1266, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (6524, 5560, 1266, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (6220, 12671, 1159, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (6224, 12675, 1159, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (6225, 12676, 1159, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (6226, 12677, 1159, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (6227, 12678, 1159, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (6228, 11989, 1159, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (6229, 12680, 1159, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (6230, 12681, 1159, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (6231, 12682, 1159, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (6232, 12683, 1159, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (7046, 13923, 1459, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7047, 13924, 1459, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7048, 13925, 1459, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7049, 13926, 1459, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (4076, 1726, 81, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4077, 189, 81, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4078, 582, 81, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4079, 1471, 81, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4080, 101, 81, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4081, 522, 81, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4082, 493, 81, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4083, 3627, 81, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4084, 1075, 81, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4085, 410, 81, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1193, 4441, 600, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1194, 4046, 600, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1195, 4004, 600, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6587, 13233, 1281, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6588, 13234, 1281, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6589, 13235, 1281, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6590, 13236, 1281, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6591, 13237, 1281, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6592, 13238, 1281, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6593, 13232, 1281, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6594, 13239, 1281, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6595, 13240, 1281, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6596, 5390, 1281, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5362, 9842, 990, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5363, 9843, 990, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5364, 9844, 990, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5365, 9845, 990, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5366, 6462, 990, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (5367, 7216, 990, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5368, 9846, 990, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5369, 1198, 990, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (291, 216, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (734, 2145, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (759, 4243, 62, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4936, 8258, 934, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (4937, 9640, 934, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6608, 13288, 1327, 30, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1093, 3929, 640, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2651, 7484, 435, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1094, 3757, 640, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1095, 4224, 640, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1096, 649, 640, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1097, 2860, 640, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1098, 3677, 640, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1099, 996, 640, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1100, 662, 640, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1103, 4699, 640, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4938, 8267, 934, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4939, 8256, 934, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4940, 8262, 934, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4941, 8261, 934, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6609, 13291, 1299, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (6610, 13292, 1299, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (850, 4398, 145, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6611, 3342, 1299, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (6614, 13294, 1195, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6612, 13293, 1299, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (63, 2850, 778, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (64, 3247, 778, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2694, 5780, 707, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (2695, 5781, 707, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (2696, 5782, 707, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (2697, 5783, 707, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (2698, 4494, 707, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (2699, 5784, 707, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (2700, 5785, 707, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (2701, 4221, 707, 50, 35);
INSERT INTO 'tunespublicationsmap' VALUES (2702, 3465, 707, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (2703, 4520, 707, 50, 39);
INSERT INTO 'tunespublicationsmap' VALUES (2652, 7485, 435, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (2056, 971, 689, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6615, 13295, 1195, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (2057, 490, 689, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (2058, 2680, 689, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (2059, 2631, 689, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2060, 3073, 689, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6616, 13323, 1333, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6617, 13324, 1333, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6618, 13325, 1333, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (2653, 7402, 435, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6607, 13279, 1324, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6597, 13276, 1306, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6598, 13277, 1306, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6599, 13278, 1306, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6233, 8831, 1159, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (6234, 12684, 1159, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (6235, 12685, 1159, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (6236, 12686, 1159, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (6237, 12687, 1159, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (6238, 12688, 1159, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (6239, 12689, 1159, 10, 60);
INSERT INTO 'tunespublicationsmap' VALUES (4685, 1078, 4, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7050, 8229, 1459, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7051, 13927, 1459, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3850, 2349, 874, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3858, 2644, 874, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3839, 320, 874, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3834, 1920, 874, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3863, 2938, 874, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3846, 6053, 874, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3836, 6055, 874, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3854, 1089, 874, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3862, 1669, 874, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6613, 1747, 1330, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (3590, 8045, 833, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3606, 4848, 833, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3592, 8386, 833, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6600, 1039, 1310, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6601, 127, 1310, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6602, 1207, 1310, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6604, 378, 1310, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6605, 797, 1310, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7052, 13928, 1459, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7053, 13929, 1459, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7054, 13930, 1459, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7055, 13931, 1459, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7056, 4323, 1459, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7057, 13932, 1459, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7058, 10126, 1459, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6329, 11667, 1184, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6330, 387, 1184, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6331, 2433, 1184, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6332, 20, 1184, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6333, 3271, 1184, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6334, 3373, 1184, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6335, 12240, 1184, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (2895, 1184, 488, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6638, 13357, 1336, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6639, 13358, 1335, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6640, 13360, 1335, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6641, 12096, 1335, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6642, 13365, 1335, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6643, 13366, 1335, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6644, 13367, 1335, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6645, 13368, 1335, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6646, 13370, 1335, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (2864, 1057, 488, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (2758, 5643, 488, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2843, 940, 488, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2861, 4022, 488, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2815, 698, 488, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (2865, 7243, 488, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7068, 887, 1467, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7069, 5635, 1467, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7070, 1276, 1467, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7071, 248, 1467, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7072, 10992, 1467, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7073, 1157, 1467, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4075, 804, 81, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7011, 5042, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7012, 3634, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7013, 3109, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7014, 6764, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7015, 1824, 1425, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7074, 10483, 1472, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7075, 13961, 1472, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7076, 3014, 1472, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6619, 13350, 1334, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6620, 13328, 1334, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6621, 13343, 1334, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6622, 13333, 1334, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6623, 13330, 1334, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6624, 13331, 1334, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6625, 13289, 1334, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6626, 13346, 1334, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6627, 13347, 1334, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6628, 13349, 1334, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6629, 13355, 1334, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (2761, 333, 488, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (2793, 533, 488, 50, 28);
INSERT INTO 'tunespublicationsmap' VALUES (2844, 4771, 488, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (2870, 5012, 488, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (2948, 5043, 488, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (2781, 456, 488, 50, 39);
INSERT INTO 'tunespublicationsmap' VALUES (2897, 2136, 488, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (2779, 5617, 488, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (2792, 1401, 488, 50, 47);
INSERT INTO 'tunespublicationsmap' VALUES (2887, 2577, 488, 50, 57);
INSERT INTO 'tunespublicationsmap' VALUES (2949, 5650, 488, 10, 62);
INSERT INTO 'tunespublicationsmap' VALUES (2869, 5790, 488, 50, 63);
INSERT INTO 'tunespublicationsmap' VALUES (2979, 2852, 488, 10, 64);
INSERT INTO 'tunespublicationsmap' VALUES (2956, 3637, 488, 10, 66);
INSERT INTO 'tunespublicationsmap' VALUES (2898, 1208, 488, 50, 67);
INSERT INTO 'tunespublicationsmap' VALUES (2891, 2816, 488, 50, 68);
INSERT INTO 'tunespublicationsmap' VALUES (2934, 4555, 488, 50, 69);
INSERT INTO 'tunespublicationsmap' VALUES (6630, 13339, 1334, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6631, 13340, 1334, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (6632, 13334, 1334, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (6633, 13335, 1334, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (6634, 13336, 1334, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (6635, 13332, 1334, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (6636, 13337, 1334, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (7059, 12622, 1465, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7060, 13934, 1465, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7061, 13935, 1465, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7062, 13936, 1465, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7063, 13937, 1465, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7064, 13938, 1465, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7065, 13939, 1465, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7066, 13940, 1465, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7067, 13941, 1465, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7077, 11325, 1484, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7078, 11360, 1484, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7079, 3618, 1484, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7080, 3203, 1484, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7081, 972, 1484, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7082, 13788, 1484, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7083, 10738, 1484, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7085, 5876, 1484, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7084, 9910, 1484, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7086, 13480, 1484, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7088, 12252, 1484, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (7089, 10737, 1484, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (7087, 8478, 1484, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7090, 8339, 1484, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (7091, 3617, 1484, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (7092, 11097, 1484, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (7093, 3620, 1484, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (7094, 7898, 1484, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (7095, 3619, 1484, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (2808, 654, 488, 50, 74);
INSERT INTO 'tunespublicationsmap' VALUES (2799, 5369, 488, 50, 77);
INSERT INTO 'tunespublicationsmap' VALUES (6895, 13695, 1351, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (6896, 13067, 1351, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (6897, 13696, 1351, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (6898, 13697, 1351, 10, 58);
INSERT INTO 'tunespublicationsmap' VALUES (6899, 13698, 1351, 10, 60);
INSERT INTO 'tunespublicationsmap' VALUES (6900, 7413, 1351, 10, 62);
INSERT INTO 'tunespublicationsmap' VALUES (6901, 13699, 1351, 10, 64);
INSERT INTO 'tunespublicationsmap' VALUES (6914, 13711, 1351, 10, 92);
INSERT INTO 'tunespublicationsmap' VALUES (6603, 774, 1310, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2831, 2413, 488, 50, 78);
INSERT INTO 'tunespublicationsmap' VALUES (2834, 892, 488, 10, 79);
INSERT INTO 'tunespublicationsmap' VALUES (2840, 2693, 488, 10, 80);
INSERT INTO 'tunespublicationsmap' VALUES (2848, 5899, 488, 10, 81);
INSERT INTO 'tunespublicationsmap' VALUES (2912, 2769, 488, 50, 82);
INSERT INTO 'tunespublicationsmap' VALUES (2914, 1284, 488, 50, 83);
INSERT INTO 'tunespublicationsmap' VALUES (2910, 1257, 488, 50, 84);
INSERT INTO 'tunespublicationsmap' VALUES (2954, 1618, 488, 50, 85);
INSERT INTO 'tunespublicationsmap' VALUES (2976, 6764, 488, 50, 86);
INSERT INTO 'tunespublicationsmap' VALUES (2980, 5126, 488, 50, 87);
INSERT INTO 'tunespublicationsmap' VALUES (2762, 1409, 488, 50, 95);
INSERT INTO 'tunespublicationsmap' VALUES (2783, 469, 488, 50, 96);
INSERT INTO 'tunespublicationsmap' VALUES (2797, 2543, 488, 10, 97);
INSERT INTO 'tunespublicationsmap' VALUES (2790, 1886, 488, 10, 100);
INSERT INTO 'tunespublicationsmap' VALUES (2825, 773, 488, 50, 101);
INSERT INTO 'tunespublicationsmap' VALUES (2873, 6335, 488, 10, 104);
INSERT INTO 'tunespublicationsmap' VALUES (2830, 867, 488, 10, 105);
INSERT INTO 'tunespublicationsmap' VALUES (2837, 920, 488, 50, 106);
INSERT INTO 'tunespublicationsmap' VALUES (2855, 2489, 488, 50, 107);
INSERT INTO 'tunespublicationsmap' VALUES (2875, 1081, 488, 50, 108);
INSERT INTO 'tunespublicationsmap' VALUES (2859, 1042, 488, 50, 109);
INSERT INTO 'tunespublicationsmap' VALUES (2925, 1352, 488, 10, 110);
INSERT INTO 'tunespublicationsmap' VALUES (2884, 1118, 488, 50, 111);
INSERT INTO 'tunespublicationsmap' VALUES (2958, 1624, 488, 50, 112);
INSERT INTO 'tunespublicationsmap' VALUES (2964, 1659, 488, 50, 114);
INSERT INTO 'tunespublicationsmap' VALUES (2764, 2561, 488, 50, 119);
INSERT INTO 'tunespublicationsmap' VALUES (2772, 2106, 488, 50, 120);
INSERT INTO 'tunespublicationsmap' VALUES (2785, 2151, 488, 50, 122);
INSERT INTO 'tunespublicationsmap' VALUES (2802, 5346, 488, 50, 124);
INSERT INTO 'tunespublicationsmap' VALUES (2803, 594, 488, 10, 125);
INSERT INTO 'tunespublicationsmap' VALUES (2804, 604, 488, 10, 126);
INSERT INTO 'tunespublicationsmap' VALUES (2812, 692, 488, 50, 127);
INSERT INTO 'tunespublicationsmap' VALUES (2820, 2559, 488, 10, 128);
INSERT INTO 'tunespublicationsmap' VALUES (2821, 4876, 488, 10, 129);
INSERT INTO 'tunespublicationsmap' VALUES (2832, 2185, 488, 50, 130);
INSERT INTO 'tunespublicationsmap' VALUES (2841, 2443, 488, 10, 131);
INSERT INTO 'tunespublicationsmap' VALUES (2805, 2218, 488, 50, 132);
INSERT INTO 'tunespublicationsmap' VALUES (2839, 2442, 488, 50, 134);
INSERT INTO 'tunespublicationsmap' VALUES (2850, 986, 488, 50, 135);
INSERT INTO 'tunespublicationsmap' VALUES (2862, 2578, 488, 50, 136);
INSERT INTO 'tunespublicationsmap' VALUES (2868, 1067, 488, 50, 137);
INSERT INTO 'tunespublicationsmap' VALUES (2863, 4167, 488, 10, 139);
INSERT INTO 'tunespublicationsmap' VALUES (2882, 1119, 488, 50, 140);
INSERT INTO 'tunespublicationsmap' VALUES (2872, 1077, 488, 50, 141);
INSERT INTO 'tunespublicationsmap' VALUES (2906, 2631, 488, 50, 143);
INSERT INTO 'tunespublicationsmap' VALUES (2883, 1122, 488, 50, 144);
INSERT INTO 'tunespublicationsmap' VALUES (2901, 1221, 488, 50, 145);
INSERT INTO 'tunespublicationsmap' VALUES (2920, 1321, 488, 50, 146);
INSERT INTO 'tunespublicationsmap' VALUES (2960, 7503, 488, 10, 149);
INSERT INTO 'tunespublicationsmap' VALUES (2967, 1673, 488, 50, 150);
INSERT INTO 'tunespublicationsmap' VALUES (2970, 1711, 488, 50, 151);
INSERT INTO 'tunespublicationsmap' VALUES (2975, 1745, 488, 50, 152);
INSERT INTO 'tunespublicationsmap' VALUES (2915, 1289, 488, 50, 154);
INSERT INTO 'tunespublicationsmap' VALUES (2866, 4238, 488, 50, 155);
INSERT INTO 'tunespublicationsmap' VALUES (2822, 764, 488, 50, 156);
INSERT INTO 'tunespublicationsmap' VALUES (2811, 3210, 488, 50, 157);
INSERT INTO 'tunespublicationsmap' VALUES (2777, 432, 488, 50, 158);
INSERT INTO 'tunespublicationsmap' VALUES (2889, 1158, 488, 10, 161);
INSERT INTO 'tunespublicationsmap' VALUES (2923, 1349, 488, 50, 163);
INSERT INTO 'tunespublicationsmap' VALUES (2918, 1311, 488, 50, 165);
INSERT INTO 'tunespublicationsmap' VALUES (2740, 183, 488, 50, 167);
INSERT INTO 'tunespublicationsmap' VALUES (2778, 433, 488, 50, 168);
INSERT INTO 'tunespublicationsmap' VALUES (2791, 5654, 488, 50, 169);
INSERT INTO 'tunespublicationsmap' VALUES (2860, 4529, 488, 10, 172);
INSERT INTO 'tunespublicationsmap' VALUES (2877, 2544, 488, 10, 175);
INSERT INTO 'tunespublicationsmap' VALUES (2727, 103, 488, 50, 179);
INSERT INTO 'tunespublicationsmap' VALUES (2765, 6787, 488, 50, 180);
INSERT INTO 'tunespublicationsmap' VALUES (2768, 381, 488, 50, 181);
INSERT INTO 'tunespublicationsmap' VALUES (2890, 1163, 488, 50, 184);
INSERT INTO 'tunespublicationsmap' VALUES (2748, 1995, 488, 50, 186);
INSERT INTO 'tunespublicationsmap' VALUES (2817, 704, 488, 50, 187);
INSERT INTO 'tunespublicationsmap' VALUES (2747, 202, 488, 50, 188);
INSERT INTO 'tunespublicationsmap' VALUES (2828, 823, 488, 50, 189);
INSERT INTO 'tunespublicationsmap' VALUES (2916, 2670, 488, 50, 190);
INSERT INTO 'tunespublicationsmap' VALUES (2899, 1594, 488, 10, 191);
INSERT INTO 'tunespublicationsmap' VALUES (2904, 2628, 488, 50, 192);
INSERT INTO 'tunespublicationsmap' VALUES (4710, 2646, 488, 50, 193);
INSERT INTO 'tunespublicationsmap' VALUES (2754, 284, 488, 50, 195);
INSERT INTO 'tunespublicationsmap' VALUES (2763, 347, 488, 50, 195);
INSERT INTO 'tunespublicationsmap' VALUES (2788, 2572, 488, 50, 196);
INSERT INTO 'tunespublicationsmap' VALUES (2823, 754, 488, 10, 197);
INSERT INTO 'tunespublicationsmap' VALUES (2833, 890, 488, 50, 197);
INSERT INTO 'tunespublicationsmap' VALUES (2851, 3156, 488, 50, 198);
INSERT INTO 'tunespublicationsmap' VALUES (2854, 4603, 488, 50, 199);
INSERT INTO 'tunespublicationsmap' VALUES (2856, 1014, 488, 50, 200);
INSERT INTO 'tunespublicationsmap' VALUES (2972, 1734, 488, 50, 204);
INSERT INTO 'tunespublicationsmap' VALUES (2721, 2342, 488, 50, 205);
INSERT INTO 'tunespublicationsmap' VALUES (2742, 2511, 488, 50, 206);
INSERT INTO 'tunespublicationsmap' VALUES (2743, 193, 488, 50, 207);
INSERT INTO 'tunespublicationsmap' VALUES (2766, 363, 488, 50, 209);
INSERT INTO 'tunespublicationsmap' VALUES (2770, 785, 488, 10, 210);
INSERT INTO 'tunespublicationsmap' VALUES (2773, 2300, 488, 10, 211);
INSERT INTO 'tunespublicationsmap' VALUES (2795, 6935, 488, 10, 212);
INSERT INTO 'tunespublicationsmap' VALUES (2796, 6876, 488, 10, 213);
INSERT INTO 'tunespublicationsmap' VALUES (2942, 3146, 488, 50, 214);
INSERT INTO 'tunespublicationsmap' VALUES (2943, 1503, 488, 50, 215);
INSERT INTO 'tunespublicationsmap' VALUES (2824, 770, 488, 50, 216);
INSERT INTO 'tunespublicationsmap' VALUES (2885, 607, 488, 10, 217);
INSERT INTO 'tunespublicationsmap' VALUES (2908, 3199, 488, 50, 218);
INSERT INTO 'tunespublicationsmap' VALUES (2845, 497, 488, 50, 219);
INSERT INTO 'tunespublicationsmap' VALUES (2957, 1621, 488, 50, 220);
INSERT INTO 'tunespublicationsmap' VALUES (2962, 1639, 488, 50, 222);
INSERT INTO 'tunespublicationsmap' VALUES (2982, 1834, 488, 50, 223);
INSERT INTO 'tunespublicationsmap' VALUES (2717, 39, 488, 50, 224);
INSERT INTO 'tunespublicationsmap' VALUES (2732, 146, 488, 50, 225);
INSERT INTO 'tunespublicationsmap' VALUES (2786, 5541, 488, 10, 227);
INSERT INTO 'tunespublicationsmap' VALUES (2769, 382, 488, 50, 229);
INSERT INTO 'tunespublicationsmap' VALUES (2977, 1748, 488, 10, 231);
INSERT INTO 'tunespublicationsmap' VALUES (2714, 584, 488, 50, 232);
INSERT INTO 'tunespublicationsmap' VALUES (2784, 5252, 488, 10, 233);
INSERT INTO 'tunespublicationsmap' VALUES (2814, 685, 488, 50, 234);
INSERT INTO 'tunespublicationsmap' VALUES (2787, 2634, 488, 10, 235);
INSERT INTO 'tunespublicationsmap' VALUES (2818, 726, 488, 50, 236);
INSERT INTO 'tunespublicationsmap' VALUES (2826, 807, 488, 50, 237);
INSERT INTO 'tunespublicationsmap' VALUES (2819, 2536, 488, 50, 238);
INSERT INTO 'tunespublicationsmap' VALUES (2847, 971, 488, 50, 240);
INSERT INTO 'tunespublicationsmap' VALUES (2829, 835, 488, 50, 241);
INSERT INTO 'tunespublicationsmap' VALUES (2871, 2534, 488, 50, 243);
INSERT INTO 'tunespublicationsmap' VALUES (2874, 2802, 488, 50, 244);
INSERT INTO 'tunespublicationsmap' VALUES (2876, 1091, 488, 50, 245);
INSERT INTO 'tunespublicationsmap' VALUES (2881, 1116, 488, 50, 246);
INSERT INTO 'tunespublicationsmap' VALUES (2938, 1453, 488, 50, 247);
INSERT INTO 'tunespublicationsmap' VALUES (2909, 2552, 488, 50, 248);
INSERT INTO 'tunespublicationsmap' VALUES (2922, 1329, 488, 50, 249);
INSERT INTO 'tunespublicationsmap' VALUES (2945, 1513, 488, 50, 250);
INSERT INTO 'tunespublicationsmap' VALUES (2951, 3036, 488, 50, 251);
INSERT INTO 'tunespublicationsmap' VALUES (2953, 5029, 488, 50, 252);
INSERT INTO 'tunespublicationsmap' VALUES (2955, 853, 488, 10, 253);
INSERT INTO 'tunespublicationsmap' VALUES (2966, 1672, 488, 50, 254);
INSERT INTO 'tunespublicationsmap' VALUES (2978, 6100, 488, 10, 256);
INSERT INTO 'tunespublicationsmap' VALUES (2971, 1721, 488, 50, 257);
INSERT INTO 'tunespublicationsmap' VALUES (2718, 51, 488, 10, 259);
INSERT INTO 'tunespublicationsmap' VALUES (2753, 2024, 488, 10, 260);
INSERT INTO 'tunespublicationsmap' VALUES (2782, 465, 488, 50, 261);
INSERT INTO 'tunespublicationsmap' VALUES (2937, 1452, 488, 10, 262);
INSERT INTO 'tunespublicationsmap' VALUES (2941, 1472, 488, 10, 263);
INSERT INTO 'tunespublicationsmap' VALUES (2760, 327, 488, 50, 264);
INSERT INTO 'tunespublicationsmap' VALUES (2835, 891, 488, 50, 267);
INSERT INTO 'tunespublicationsmap' VALUES (2838, 923, 488, 50, 268);
INSERT INTO 'tunespublicationsmap' VALUES (2892, 1167, 488, 50, 271);
INSERT INTO 'tunespublicationsmap' VALUES (2893, 2590, 488, 10, 272);
INSERT INTO 'tunespublicationsmap' VALUES (2900, 2608, 488, 10, 274);
INSERT INTO 'tunespublicationsmap' VALUES (2917, 2671, 488, 10, 275);
INSERT INTO 'tunespublicationsmap' VALUES (2800, 2202, 488, 10, 276);
INSERT INTO 'tunespublicationsmap' VALUES (2935, 1410, 488, 10, 279);
INSERT INTO 'tunespublicationsmap' VALUES (2776, 425, 488, 50, 280);
INSERT INTO 'tunespublicationsmap' VALUES (2932, 1389, 488, 50, 281);
INSERT INTO 'tunespublicationsmap' VALUES (2894, 6685, 488, 10, 281);
INSERT INTO 'tunespublicationsmap' VALUES (2968, 1687, 488, 50, 282);
INSERT INTO 'tunespublicationsmap' VALUES (2780, 452, 488, 50, 283);
INSERT INTO 'tunespublicationsmap' VALUES (2775, 415, 488, 50, 284);
INSERT INTO 'tunespublicationsmap' VALUES (2809, 2249, 488, 50, 285);
INSERT INTO 'tunespublicationsmap' VALUES (2880, 1111, 488, 50, 287);
INSERT INTO 'tunespublicationsmap' VALUES (2798, 539, 488, 50, 288);
INSERT INTO 'tunespublicationsmap' VALUES (2896, 5390, 488, 10, 289);
INSERT INTO 'tunespublicationsmap' VALUES (2716, 6167, 488, 50, 290);
INSERT INTO 'tunespublicationsmap' VALUES (2774, 4858, 488, 10, 291);
INSERT INTO 'tunespublicationsmap' VALUES (2846, 962, 488, 50, 292);
INSERT INTO 'tunespublicationsmap' VALUES (2902, 1238, 488, 50, 293);
INSERT INTO 'tunespublicationsmap' VALUES (2905, 1241, 488, 50, 294);
INSERT INTO 'tunespublicationsmap' VALUES (2927, 2696, 488, 50, 295);
INSERT INTO 'tunespublicationsmap' VALUES (2771, 388, 488, 50, 296);
INSERT INTO 'tunespublicationsmap' VALUES (2939, 1457, 488, 50, 297);
INSERT INTO 'tunespublicationsmap' VALUES (2842, 939, 488, 50, 298);
INSERT INTO 'tunespublicationsmap' VALUES (2757, 295, 488, 50, 299);
INSERT INTO 'tunespublicationsmap' VALUES (2907, 3315, 488, 10, 300);
INSERT INTO 'tunespublicationsmap' VALUES (2930, 5272, 488, 10, 301);
INSERT INTO 'tunespublicationsmap' VALUES (2965, 1665, 488, 50, 303);
INSERT INTO 'tunespublicationsmap' VALUES (2969, 1700, 488, 50, 304);
INSERT INTO 'tunespublicationsmap' VALUES (2722, 78, 488, 50, 305);
INSERT INTO 'tunespublicationsmap' VALUES (2849, 982, 488, 50, 306);
INSERT INTO 'tunespublicationsmap' VALUES (2749, 2423, 488, 50, 308);
INSERT INTO 'tunespublicationsmap' VALUES (2789, 482, 488, 50, 309);
INSERT INTO 'tunespublicationsmap' VALUES (2794, 534, 488, 50, 310);
INSERT INTO 'tunespublicationsmap' VALUES (2867, 6706, 488, 10, 311);
INSERT INTO 'tunespublicationsmap' VALUES (2888, 1152, 488, 50, 312);
INSERT INTO 'tunespublicationsmap' VALUES (2981, 1809, 488, 50, 313);
INSERT INTO 'tunespublicationsmap' VALUES (2963, 1655, 488, 50, 314);
INSERT INTO 'tunespublicationsmap' VALUES (2879, 1103, 488, 50, 315);
INSERT INTO 'tunespublicationsmap' VALUES (2950, 1553, 488, 50, 316);
INSERT INTO 'tunespublicationsmap' VALUES (2959, 1629, 488, 50, 317);
INSERT INTO 'tunespublicationsmap' VALUES (2961, 1638, 488, 50, 318);
INSERT INTO 'tunespublicationsmap' VALUES (2973, 1741, 488, 50, 319);
INSERT INTO 'tunespublicationsmap' VALUES (2767, 374, 488, 50, 320);
INSERT INTO 'tunespublicationsmap' VALUES (2827, 819, 488, 50, 321);
INSERT INTO 'tunespublicationsmap' VALUES (2886, 1128, 488, 10, 322);
INSERT INTO 'tunespublicationsmap' VALUES (2940, 1458, 488, 50, 323);
INSERT INTO 'tunespublicationsmap' VALUES (2836, 917, 488, 50, 324);
INSERT INTO 'tunespublicationsmap' VALUES (2931, 1395, 488, 50, 325);
INSERT INTO 'tunespublicationsmap' VALUES (2974, 1744, 488, 50, 326);
INSERT INTO 'tunespublicationsmap' VALUES (2852, 992, 488, 50, 327);
INSERT INTO 'tunespublicationsmap' VALUES (2946, 7192, 488, 10, 328);
INSERT INTO 'tunespublicationsmap' VALUES (2807, 650, 488, 50, 329);
INSERT INTO 'tunespublicationsmap' VALUES (2853, 1003, 488, 10, 331);
INSERT INTO 'tunespublicationsmap' VALUES (2878, 6786, 488, 50, 332);
INSERT INTO 'tunespublicationsmap' VALUES (2737, 173, 488, 50, 334);
INSERT INTO 'tunespublicationsmap' VALUES (2715, 12, 488, 50, 335);
INSERT INTO 'tunespublicationsmap' VALUES (2759, 2054, 488, 50, 336);
INSERT INTO 'tunespublicationsmap' VALUES (2729, 3401, 488, 10, 337);
INSERT INTO 'tunespublicationsmap' VALUES (2813, 682, 488, 50, 338);
INSERT INTO 'tunespublicationsmap' VALUES (2723, 88, 488, 50, 340);
INSERT INTO 'tunespublicationsmap' VALUES (2944, 3765, 488, 10, 342);
INSERT INTO 'tunespublicationsmap' VALUES (2726, 100, 488, 50, 343);
INSERT INTO 'tunespublicationsmap' VALUES (2806, 6772, 488, 10, 344);
INSERT INTO 'tunespublicationsmap' VALUES (2952, 6206, 488, 50, 345);
INSERT INTO 'tunespublicationsmap' VALUES (2750, 3517, 488, 50, 347);
INSERT INTO 'tunespublicationsmap' VALUES (2913, 1279, 488, 10, 351);
INSERT INTO 'tunespublicationsmap' VALUES (2936, 1431, 488, 50, 354);
INSERT INTO 'tunespublicationsmap' VALUES (2810, 672, 488, 10, 355);
INSERT INTO 'tunespublicationsmap' VALUES (2911, 4039, 488, 10, 357);
INSERT INTO 'tunespublicationsmap' VALUES (2857, 1027, 488, 10, 358);
INSERT INTO 'tunespublicationsmap' VALUES (2735, 3433, 488, 10, 359);
INSERT INTO 'tunespublicationsmap' VALUES (2816, 2279, 488, 50, 360);
INSERT INTO 'tunespublicationsmap' VALUES (2725, 98, 488, 10, 363);
INSERT INTO 'tunespublicationsmap' VALUES (2858, 2882, 488, 10, 364);
INSERT INTO 'tunespublicationsmap' VALUES (1275, 5776, 286, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6694, 10491, 1027, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6695, 10494, 1027, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6696, 9715, 1027, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6697, 10499, 1027, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6698, 10454, 1027, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (493, 3520, 286, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (492, 3519, 286, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1266, 5910, 286, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1276, 929, 286, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1264, 985, 286, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (512, 3855, 286, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (489, 2262, 286, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1267, 1249, 286, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1268, 1212, 286, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1269, 1336, 286, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1270, 1215, 286, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (498, 1416, 286, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1277, 863, 286, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1278, 3177, 286, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1279, 5915, 286, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1280, 5916, 286, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (517, 3858, 286, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1281, 5917, 286, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1282, 5918, 286, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (1283, 5919, 286, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1284, 5920, 286, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1285, 5921, 286, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (1286, 5922, 286, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (1287, 5923, 286, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (1288, 5924, 286, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (6708, 10501, 1027, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6699, 10506, 1027, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6700, 10510, 1027, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6701, 11581, 1027, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6702, 1694, 1027, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (6703, 10517, 1027, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (6704, 10521, 1027, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (6705, 10524, 1027, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (6706, 10526, 1027, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (6707, 10529, 1027, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (896, 1238, 589, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (897, 503, 589, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (898, 927, 589, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (900, 501, 589, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (893, 312, 589, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (901, 1101, 589, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (892, 1853, 589, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (905, 1774, 589, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (899, 1713, 589, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (870, 3268, 253, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (808, 3163, 253, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (6710, 2846, 1349, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6711, 13459, 1349, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6712, 13460, 1349, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6713, 13170, 1349, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6714, 13171, 1349, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6715, 13461, 1349, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6716, 13462, 1349, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6717, 13463, 1349, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2551, 1498, 427, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (2542, 7282, 427, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (2543, 2419, 427, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (2544, 7283, 427, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2552, 3408, 427, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2545, 7284, 427, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2553, 1221, 427, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2546, 4371, 427, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2554, 5162, 427, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2556, 2963, 427, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2555, 699, 427, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2547, 7285, 427, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (2548, 7286, 427, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2549, 7287, 427, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (2550, 2758, 427, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5095, 9826, 771, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6677, 5130, 1339, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6678, 8786, 1339, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6719, 10045, 1195, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (6720, 13514, 1195, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6721, 13516, 1195, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6722, 13517, 1195, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6709, 13457, 1255, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6692, 13356, 574, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3101, 7777, 647, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3102, 7778, 647, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3103, 7779, 647, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6723, 13518, 1195, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6724, 13519, 1195, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6725, 13520, 1195, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6726, 13521, 1195, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6727, 13522, 1195, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6729, 13523, 1195, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6730, 13524, 1195, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6731, 13525, 1195, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6732, 13526, 1195, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (6733, 13527, 1195, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6679, 10514, 1339, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6680, 2792, 1339, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6681, 13414, 1339, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6682, 13415, 1339, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6683, 1322, 1339, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6684, 2641, 1339, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6685, 13416, 1339, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6686, 2101, 1339, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (6687, 1138, 1339, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6688, 2219, 1339, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (6689, 13310, 1339, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (6690, 11179, 1339, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (6691, 13417, 1339, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (6390, 13063, 1210, 10, 51);
INSERT INTO 'tunespublicationsmap' VALUES (6391, 13064, 1210, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (6392, 13065, 1210, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (6393, 13066, 1210, 10, 53);
INSERT INTO 'tunespublicationsmap' VALUES (6394, 13067, 1210, 10, 53);
INSERT INTO 'tunespublicationsmap' VALUES (6395, 13068, 1210, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (6396, 8941, 1210, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (6397, 3678, 1210, 10, 55);
INSERT INTO 'tunespublicationsmap' VALUES (6398, 13071, 1210, 10, 55);
INSERT INTO 'tunespublicationsmap' VALUES (6399, 13069, 1210, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (6400, 13070, 1210, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (6401, 10567, 1210, 10, 57);
INSERT INTO 'tunespublicationsmap' VALUES (6402, 13072, 1210, 10, 57);
INSERT INTO 'tunespublicationsmap' VALUES (6403, 13073, 1210, 10, 58);
INSERT INTO 'tunespublicationsmap' VALUES (6404, 13074, 1210, 10, 58);
INSERT INTO 'tunespublicationsmap' VALUES (6405, 13075, 1210, 10, 59);
INSERT INTO 'tunespublicationsmap' VALUES (6406, 13076, 1210, 10, 59);
INSERT INTO 'tunespublicationsmap' VALUES (6407, 13077, 1210, 10, 60);
INSERT INTO 'tunespublicationsmap' VALUES (6408, 13080, 1210, 10, 61);
INSERT INTO 'tunespublicationsmap' VALUES (6409, 13081, 1210, 10, 62);
INSERT INTO 'tunespublicationsmap' VALUES (6410, 13082, 1210, 10, 63);
INSERT INTO 'tunespublicationsmap' VALUES (6718, 13464, 1349, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6647, 13377, 1338, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6648, 13378, 1338, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6649, 13379, 1338, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6650, 4034, 1338, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6651, 13380, 1338, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6652, 13381, 1338, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6653, 13382, 1338, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6654, 13383, 1338, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6655, 13384, 1338, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6656, 333, 1338, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (6657, 51, 1338, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6658, 861, 1338, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (6659, 78, 1338, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (6660, 13385, 1338, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (6661, 4830, 1338, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (6662, 13386, 1338, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (6663, 13387, 1338, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (6664, 13388, 1338, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (6665, 1166, 1338, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (6666, 13389, 1338, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (6667, 13390, 1338, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (6668, 457, 1338, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (6669, 945, 1338, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (6670, 13391, 1338, 10, 51);
INSERT INTO 'tunespublicationsmap' VALUES (6671, 6138, 1338, 10, 53);
INSERT INTO 'tunespublicationsmap' VALUES (6672, 3315, 1338, 10, 55);
INSERT INTO 'tunespublicationsmap' VALUES (6673, 4412, 1338, 10, 57);
INSERT INTO 'tunespublicationsmap' VALUES (6674, 3195, 1338, 10, 59);
INSERT INTO 'tunespublicationsmap' VALUES (6675, 13392, 1338, 10, 61);
INSERT INTO 'tunespublicationsmap' VALUES (6676, 13184, 1338, 10, 63);
INSERT INTO 'tunespublicationsmap' VALUES (6947, 3312, 1413, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6948, 4227, 1413, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6954, 3590, 1416, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (6955, 558, 1416, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6803, 10134, 1370, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (6802, 13599, 1370, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (5685, 10469, 1079, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (5686, 4907, 1079, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5687, 10253, 1079, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (5688, 10455, 1079, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (5655, 11675, 1067, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5656, 122, 1067, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5657, 611, 1067, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5658, 2419, 1067, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6872, 7403, 1351, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6873, 13679, 1351, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6874, 13680, 1351, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (6875, 13681, 1351, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5659, 2943, 1067, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5660, 11676, 1067, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5661, 11677, 1067, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5662, 11678, 1067, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5663, 11679, 1067, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (5664, 11680, 1067, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5665, 11681, 1067, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7159, 10197, 1523, 18, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7160, 1620, 1523, 18, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7161, 2209, 1523, 18, 31);
INSERT INTO 'tunespublicationsmap' VALUES (7162, 3289, 1523, 18, 47);
INSERT INTO 'tunespublicationsmap' VALUES (5617, 11648, 1060, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5618, 3287, 1060, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5619, 11651, 1060, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (5620, 9967, 1060, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5621, 11653, 1060, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (6876, 13682, 1351, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6878, 13683, 1351, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6879, 13684, 1351, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (6880, 7404, 1351, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (6881, 866, 1351, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (6882, 7407, 1351, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (6883, 13685, 1351, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (6884, 13686, 1351, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (6885, 13687, 1351, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (6886, 13688, 1351, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (6887, 13104, 1351, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (6888, 13689, 1351, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (4818, 324, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4819, 555, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4820, 898, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4822, 3594, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4823, 326, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4824, 327, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4825, 1288, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4826, 337, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4827, 1689, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4828, 9286, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4829, 340, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4830, 341, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4831, 342, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4832, 344, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4833, 2948, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4834, 349, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4835, 350, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4836, 1828, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4837, 4435, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4838, 360, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4839, 362, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4821, 9714, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4841, 366, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4842, 760, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4843, 2082, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4844, 374, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4845, 2087, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4846, 8475, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4847, 377, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4848, 1094, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4849, 381, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4850, 382, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5666, 11682, 1067, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5667, 1415, 1067, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (5668, 11683, 1067, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (5669, 186, 1067, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (5670, 11685, 1067, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (5671, 11686, 1067, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (5672, 4360, 1067, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (6525, 13182, 1269, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6526, 13183, 1269, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6527, 10858, 1269, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6528, 12815, 1269, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6529, 13184, 1269, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (6530, 13185, 1269, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (6531, 13186, 1269, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (6532, 13187, 1269, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (6533, 13188, 1269, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (94, 531, 329, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (95, 1198, 329, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6341, 12990, 1142, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7163, 9936, 1542, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7164, 9447, 1542, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7165, 9006, 1542, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7166, 9004, 1542, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7167, 8472, 1542, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7168, 9938, 1542, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7169, 11185, 1542, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7170, 12966, 1542, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7171, 10649, 1542, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7172, 9937, 1542, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7173, 10197, 1542, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7174, 12487, 1542, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7175, 10200, 1542, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7176, 10293, 1543, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7177, 11713, 1543, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7178, 11278, 1543, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7179, 10661, 1543, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7180, 10453, 1543, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7181, 13727, 1543, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7182, 10292, 1543, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7183, 10568, 1543, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7184, 11458, 1544, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7185, 13728, 1544, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7186, 11262, 1544, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1294, 328, 388, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1462, 3550, 388, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1561, 6014, 388, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1477, 2016, 388, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1428, 806, 388, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1483, 1629, 388, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1309, 2414, 388, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1425, 2536, 388, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1498, 1825, 388, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1482, 1624, 388, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1476, 1513, 388, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1474, 1503, 388, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1426, 771, 388, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1427, 773, 388, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1499, 1834, 388, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1407, 445, 388, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1402, 362, 388, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1379, 4746, 388, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1486, 1659, 388, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1338, 2120, 388, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1415, 6040, 388, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1489, 1670, 388, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1464, 1329, 388, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1458, 1208, 388, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1452, 2534, 388, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1417, 5346, 388, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1418, 598, 388, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1459, 2816, 388, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1422, 654, 388, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1501, 1842, 388, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1472, 5949, 388, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1488, 1673, 388, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1404, 385, 388, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1490, 5407, 388, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1403, 382, 388, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1495, 3072, 388, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1419, 2455, 388, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1475, 5535, 388, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1423, 692, 388, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1466, 2646, 388, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1424, 685, 388, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1443, 3156, 388, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1469, 1453, 388, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1453, 1077, 388, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1400, 354, 388, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1442, 1021, 388, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1405, 424, 388, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1435, 959, 388, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1444, 1000, 388, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1384, 4323, 388, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1480, 3640, 388, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1492, 1704, 388, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1437, 2413, 388, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1380, 234, 388, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1460, 2717, 388, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1445, 1014, 388, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1487, 3120, 388, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1395, 289, 388, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1436, 920, 388, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1411, 4726, 388, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1413, 497, 388, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1429, 817, 388, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1408, 448, 388, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1478, 1550, 388, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1364, 178, 388, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1471, 4401, 388, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1412, 2572, 388, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1496, 5126, 388, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1484, 1636, 388, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1399, 1409, 388, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1454, 2802, 388, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1491, 2498, 388, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1467, 2711, 388, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1455, 1062, 388, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1461, 1167, 388, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1446, 1018, 388, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1387, 2002, 388, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1307, 2718, 388, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1439, 903, 388, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1463, 2552, 388, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1317, 913, 388, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1416, 2196, 388, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1363, 177, 388, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1374, 1995, 388, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1438, 895, 388, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1414, 3761, 388, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1396, 290, 388, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1410, 4210, 388, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1434, 951, 388, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1447, 1020, 388, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1470, 4408, 388, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1409, 456, 388, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1440, 923, 388, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1448, 5416, 388, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1366, 5517, 388, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1481, 3352, 388, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1401, 3932, 388, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1500, 4703, 388, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1441, 986, 388, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1465, 1347, 388, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1457, 1122, 388, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1493, 1721, 388, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1468, 3252, 388, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1449, 1026, 388, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1398, 5892, 388, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1456, 4173, 388, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1494, 1707, 388, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1365, 183, 388, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1432, 842, 388, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1362, 182, 388, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1450, 2489, 388, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1433, 1997, 388, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1421, 624, 388, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1566, 833, 388, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1342, 91, 388, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1479, 1542, 388, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1430, 798, 388, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1497, 1805, 388, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1371, 194, 388, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1574, 1431, 388, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1393, 5377, 388, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1579, 1541, 388, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1581, 1655, 388, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1565, 687, 388, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1293, 1741, 388, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1567, 955, 388, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1339, 298, 388, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1337, 76, 388, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1331, 1390, 388, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1560, 544, 388, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1325, 1702, 388, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1568, 1374, 388, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1316, 2532, 388, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1577, 1458, 388, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1578, 4379, 388, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1584, 1809, 388, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1296, 1103, 388, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1583, 1734, 388, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1451, 1091, 388, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1558, 482, 388, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1572, 1423, 388, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1559, 534, 388, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1420, 2218, 388, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1431, 835, 388, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1406, 414, 388, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1397, 318, 388, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1473, 1470, 388, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1351, 138, 388, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1485, 1638, 388, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1297, 2988, 388, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1606, 3003, 388, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1605, 648, 388, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1609, 2703, 388, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1608, 1373, 388, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1582, 1656, 388, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1361, 171, 388, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1552, 283, 388, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1580, 5462, 388, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1570, 4360, 388, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1555, 350, 388, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1562, 4543, 388, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1569, 733, 388, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1563, 2249, 388, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1306, 5990, 388, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1573, 1424, 388, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1571, 3749, 388, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1390, 256, 388, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1576, 2737, 388, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1553, 2039, 388, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1564, 649, 388, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1575, 1415, 388, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1378, 4663, 388, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1557, 429, 388, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1554, 312, 388, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1556, 374, 388, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1321, 3545, 388, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1295, 5988, 388, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1301, 2289, 388, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1312, 2918, 388, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1343, 90, 388, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1537, 724, 388, 50, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1538, 730, 388, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1539, 4960, 388, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1544, 1435, 388, 50, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1547, 1460, 388, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1549, 1665, 388, 50, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1550, 1700, 388, 50, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1535, 388, 388, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1381, 238, 388, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1346, 114, 388, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1541, 2396, 388, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1330, 55, 388, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1551, 1802, 388, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1540, 850, 388, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1543, 1106, 388, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1545, 1419, 388, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (1548, 1565, 388, 50, 33);
INSERT INTO 'tunespublicationsmap' VALUES (1536, 608, 388, 50, 33);
INSERT INTO 'tunespublicationsmap' VALUES (1542, 2411, 388, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (1383, 242, 388, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (1518, 5439, 388, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1516, 2449, 388, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1502, 4902, 388, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1533, 6122, 388, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1529, 1582, 388, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1532, 1696, 388, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (1519, 5437, 388, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (1507, 4989, 388, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1511, 750, 388, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1512, 1958, 388, 50, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1514, 5260, 388, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1515, 5073, 388, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1522, 1455, 388, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1531, 2668, 388, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1505, 2063, 388, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1503, 1919, 388, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1504, 1942, 388, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1534, 5406, 388, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1523, 2786, 388, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1520, 2744, 388, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1509, 5246, 388, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1508, 560, 388, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1506, 3572, 388, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1510, 5494, 388, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (1524, 5943, 388, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (1526, 5601, 388, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (1525, 1540, 388, 50, 39);
INSERT INTO 'tunespublicationsmap' VALUES (3450, 155, 388, 50, 39);
INSERT INTO 'tunespublicationsmap' VALUES (1513, 4748, 388, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (1530, 1650, 388, 50, 39);
INSERT INTO 'tunespublicationsmap' VALUES (1528, 2827, 388, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (1521, 4781, 388, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (1527, 1528, 388, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (1517, 577, 388, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (1591, 4069, 388, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (1589, 650, 388, 50, 42);
INSERT INTO 'tunespublicationsmap' VALUES (1587, 3584, 388, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (1593, 4277, 388, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (1586, 165, 388, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (1594, 1730, 388, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (1585, 1985, 388, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (1590, 760, 388, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (1595, 1744, 388, 50, 45);
INSERT INTO 'tunespublicationsmap' VALUES (1596, 2974, 388, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (1592, 1395, 388, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (1588, 2054, 388, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (1597, 3484, 388, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (1602, 4939, 388, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (1601, 697, 388, 50, 47);
INSERT INTO 'tunespublicationsmap' VALUES (1600, 405, 388, 50, 48);
INSERT INTO 'tunespublicationsmap' VALUES (1599, 5620, 388, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (1603, 2387, 388, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (1604, 2766, 388, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (1607, 132, 388, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (7187, 14242, 388, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (470, 1283, 13, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (230, 305, 13, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (168, 430, 13, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7191, 1591, 13, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (272, 1425, 13, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (221, 13616, 13, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (602, 1450, 13, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (891, 1598, 13, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7192, 2388, 1546, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7206, 13787, 1552, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (7207, 13782, 1552, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (7208, 12155, 1552, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (7209, 13777, 1552, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (7210, 5578, 1552, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1049, 1155, 16, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1050, 1839, 16, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1042, 133, 16, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (1043, 306, 16, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (653, 1628, 16, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1044, 904, 16, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1045, 1325, 16, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (293, 1316, 16, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (345, 303, 16, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1032, 1727, 16, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1002, 2282, 16, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1046, 1306, 16, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (323, 2609, 16, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1047, 1295, 16, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1048, 2310, 16, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7211, 13779, 1552, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (7236, 14288, 1556, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7237, 10025, 1556, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (740, 4219, 580, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7193, 9999, 1552, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7194, 8997, 1552, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7195, 10732, 1552, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7196, 14203, 1552, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7197, 10730, 1552, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7198, 4392, 1552, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7199, 2182, 1552, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7200, 10747, 1552, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7201, 14189, 1552, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7202, 2446, 1552, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7212, 10736, 1552, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (7213, 13775, 1552, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (7214, 2695, 1552, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (7215, 14174, 1552, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (411, 470, 13, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7188, 1318, 13, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (750, 1147, 13, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (169, 1232, 13, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (197, 97, 13, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (552, 909, 13, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7189, 2670, 13, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7190, 1421, 13, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (547, 679, 13, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (721, 1080, 13, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (928, 889, 13, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (454, 114, 13, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (835, 908, 13, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (7225, 14168, 1553, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7220, 14202, 1553, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7226, 14175, 1553, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7233, 14177, 1553, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7217, 13780, 1553, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7234, 14201, 1553, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7232, 14173, 1553, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7216, 14190, 1553, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7222, 14197, 1553, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7203, 14185, 1552, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7204, 12139, 1552, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (7205, 10748, 1552, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (7235, 14002, 1553, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (7221, 14184, 1553, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7228, 13843, 1553, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7223, 13774, 1553, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7229, 14169, 1553, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (7227, 13781, 1553, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (7230, 14276, 1553, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (7219, 14001, 1553, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (7231, 14036, 1553, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (7218, 14171, 1553, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (7224, 14200, 1553, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (4597, 8857, 73, 10, 242);
INSERT INTO 'tunespublicationsmap' VALUES (7238, 5243, 1560, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7263, 14305, 1561, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7250, 14306, 1561, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7251, 14307, 1561, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (7252, 14308, 1561, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7253, 14309, 1561, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7254, 14310, 1561, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7255, 14311, 1561, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7256, 14312, 1561, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (7257, 14313, 1561, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7258, 14314, 1561, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7259, 14315, 1561, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7260, 14316, 1561, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (7264, 14317, 1562, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7265, 14318, 1562, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7266, 14319, 1562, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7267, 14320, 1562, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7268, 14321, 1562, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7239, 14292, 1561, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7240, 14293, 1561, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7241, 14294, 1561, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7261, 14295, 1561, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7242, 14297, 1561, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7243, 14296, 1561, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7244, 14298, 1561, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7245, 14299, 1561, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7246, 14300, 1561, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7247, 14301, 1561, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7248, 14302, 1561, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7249, 14303, 1561, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7262, 14304, 1561, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7269, 14322, 1562, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7270, 14323, 1562, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7271, 14324, 1562, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7272, 14325, 1562, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7273, 14326, 1562, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7274, 14327, 1562, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7275, 14328, 1562, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7276, 14329, 1562, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7277, 14330, 1562, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7278, 14331, 1562, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7279, 14332, 1562, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (7280, 13001, 1562, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7281, 14333, 1562, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7282, 14334, 1562, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7283, 14335, 1562, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7284, 14336, 1562, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (7285, 14337, 1562, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7286, 14338, 1562, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7287, 14339, 1562, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7288, 14340, 1562, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (7289, 14341, 1562, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (7290, 14342, 1562, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (7291, 14343, 1562, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (7292, 14344, 1562, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (7293, 14345, 1562, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (7294, 14346, 1562, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (7295, 14347, 1562, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (7296, 14348, 1562, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (7297, 14349, 1562, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (7298, 14350, 1562, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (7299, 14351, 1562, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (7300, 14352, 1562, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (7301, 14353, 1562, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (7302, 13620, 1562, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (7303, 14354, 1562, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (7304, 14355, 1562, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (7305, 14356, 1562, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (7306, 14357, 1562, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (7307, 14358, 1562, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (7308, 14359, 1562, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (7309, 14360, 1562, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (7310, 14361, 1562, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (7311, 14362, 1562, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (7312, 14363, 1562, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (7313, 14364, 1562, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (7314, 14365, 1562, 10, 51);
INSERT INTO 'tunespublicationsmap' VALUES (7315, 14366, 1562, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (7316, 14367, 1562, 10, 53);
INSERT INTO 'tunespublicationsmap' VALUES (7317, 14368, 1562, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (7381, 14206, 1569, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (7382, 14213, 1569, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (7383, 14214, 1569, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (7358, 14082, 1569, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (7359, 14083, 1569, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (7364, 14087, 1570, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7355, 14094, 1568, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7353, 14091, 1568, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7354, 14098, 1568, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7351, 14097, 1568, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7352, 14090, 1568, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7386, 14387, 1538, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7318, 14369, 1562, 10, 55);
INSERT INTO 'tunespublicationsmap' VALUES (7319, 14370, 1562, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (7320, 14371, 1562, 10, 57);
INSERT INTO 'tunespublicationsmap' VALUES (7321, 14372, 1562, 10, 58);
INSERT INTO 'tunespublicationsmap' VALUES (7322, 14373, 1562, 10, 59);
INSERT INTO 'tunespublicationsmap' VALUES (7323, 14374, 1562, 10, 60);
INSERT INTO 'tunespublicationsmap' VALUES (7324, 14375, 1562, 10, 61);
INSERT INTO 'tunespublicationsmap' VALUES (7325, 14376, 1562, 10, 62);
INSERT INTO 'tunespublicationsmap' VALUES (7326, 14377, 1562, 10, 63);
INSERT INTO 'tunespublicationsmap' VALUES (7327, 14378, 1562, 10, 64);
INSERT INTO 'tunespublicationsmap' VALUES (7328, 14379, 1562, 10, 65);
INSERT INTO 'tunespublicationsmap' VALUES (7329, 14380, 1562, 10, 66);
INSERT INTO 'tunespublicationsmap' VALUES (7330, 14381, 1562, 10, 67);
INSERT INTO 'tunespublicationsmap' VALUES (7331, 14382, 1562, 10, 68);
INSERT INTO 'tunespublicationsmap' VALUES (7332, 12955, 1562, 10, 69);
INSERT INTO 'tunespublicationsmap' VALUES (6889, 13690, 1351, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (6890, 13691, 1351, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (6891, 13692, 1351, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (6892, 13693, 1351, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (6893, 13694, 1351, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (6894, 1798, 1351, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (6902, 13700, 1351, 10, 66);
INSERT INTO 'tunespublicationsmap' VALUES (6903, 13701, 1351, 10, 68);
INSERT INTO 'tunespublicationsmap' VALUES (6904, 13702, 1351, 10, 70);
INSERT INTO 'tunespublicationsmap' VALUES (6905, 13703, 1351, 10, 72);
INSERT INTO 'tunespublicationsmap' VALUES (6906, 13704, 1351, 10, 74);
INSERT INTO 'tunespublicationsmap' VALUES (6907, 7421, 1351, 10, 76);
INSERT INTO 'tunespublicationsmap' VALUES (6908, 13705, 1351, 10, 78);
INSERT INTO 'tunespublicationsmap' VALUES (6909, 13706, 1351, 10, 80);
INSERT INTO 'tunespublicationsmap' VALUES (6910, 13707, 1351, 10, 82);
INSERT INTO 'tunespublicationsmap' VALUES (6911, 13708, 1351, 10, 86);
INSERT INTO 'tunespublicationsmap' VALUES (6912, 13709, 1351, 10, 88);
INSERT INTO 'tunespublicationsmap' VALUES (6913, 13710, 1351, 10, 90);
INSERT INTO 'tunespublicationsmap' VALUES (7334, 330, 1563, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7335, 14084, 1528, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7336, 14085, 1528, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7337, 14097, 1528, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7365, 9946, 1528, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7366, 9948, 1528, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7367, 14092, 1528, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7368, 9952, 1528, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7345, 13982, 1567, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7350, 9954, 1567, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7347, 14050, 1567, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7346, 14089, 1567, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7348, 14051, 1567, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7349, 14052, 1567, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7342, 9952, 1566, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7343, 14093, 1566, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7370, 14083, 1528, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (7369, 14082, 1528, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (7371, 13982, 1528, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7372, 14091, 1528, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (7373, 14207, 1528, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (7376, 14052, 1528, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (7375, 14051, 1528, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (7374, 14050, 1528, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (7377, 9954, 1528, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (7379, 14213, 1528, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (7378, 14206, 1528, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (7380, 14214, 1528, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (7344, 14096, 1566, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7340, 14095, 1566, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7339, 9946, 1566, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7341, 14086, 1566, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7338, 14092, 1565, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7384, 9948, 1571, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (7385, 14088, 1571, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (7361, 14209, 1569, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7362, 14210, 1569, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (7363, 14211, 1569, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7356, 14084, 1569, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7357, 14085, 1569, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7360, 14207, 1569, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7388, 14389, 1572, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7389, 14390, 1572, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7390, 14391, 1572, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7391, 14392, 1572, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7392, 9558, 1572, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7393, 14393, 1572, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7394, 9931, 1572, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7395, 14394, 1572, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7396, 8182, 1572, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7397, 10794, 1572, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7398, 14395, 1572, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7399, 14396, 1572, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7400, 14397, 1572, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7401, 14398, 1572, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7402, 14399, 1572, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7403, 7873, 1572, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (7404, 14400, 1572, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7405, 9547, 1572, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7406, 10796, 1572, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7407, 14401, 1572, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7408, 14402, 1572, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (7409, 10331, 1572, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7410, 14403, 1572, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7411, 14404, 1572, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7412, 9539, 1572, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (7413, 9549, 1572, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (7414, 780, 1572, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (7415, 9541, 1572, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (7416, 10793, 1572, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (7417, 14405, 1572, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (7418, 14406, 1572, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (7419, 14407, 1572, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (7420, 14408, 1572, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (7421, 9546, 1572, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (7422, 14409, 1572, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (7423, 13754, 1572, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (7424, 14410, 1572, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (7425, 14411, 1572, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (7426, 14412, 1572, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (3607, 5414, 833, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3608, 8399, 833, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3593, 8387, 833, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3594, 8388, 833, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3595, 8389, 833, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3596, 5825, 833, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (3597, 8390, 833, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3591, 8046, 833, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (3598, 8391, 833, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (3599, 8392, 833, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (3600, 8393, 833, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (3601, 8394, 833, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (3602, 8395, 833, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (3603, 8396, 833, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (3604, 8397, 833, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (3605, 8398, 833, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (7427, 10312, 1572, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (7428, 14413, 1572, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (7429, 9554, 1572, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (7430, 14414, 1572, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (7431, 14415, 1572, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (7432, 14416, 1572, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (7433, 10801, 1572, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (7434, 12285, 1572, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (7435, 14417, 1572, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (7436, 14418, 1572, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (7437, 14419, 1572, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (7438, 14420, 1572, 10, 51);
INSERT INTO 'tunespublicationsmap' VALUES (7439, 11562, 1572, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (7440, 14421, 1572, 10, 53);
INSERT INTO 'tunespublicationsmap' VALUES (7441, 14422, 1572, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (7442, 14423, 1572, 10, 55);
INSERT INTO 'tunespublicationsmap' VALUES (7443, 10324, 1572, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (7444, 14424, 1572, 10, 57);
INSERT INTO 'tunespublicationsmap' VALUES (7445, 14425, 1572, 10, 58);
INSERT INTO 'tunespublicationsmap' VALUES (7446, 14426, 1572, 10, 59);
INSERT INTO 'tunespublicationsmap' VALUES (7447, 14427, 1572, 10, 60);
INSERT INTO 'tunespublicationsmap' VALUES (7448, 14428, 1572, 10, 61);
INSERT INTO 'tunespublicationsmap' VALUES (7449, 8045, 1574, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7450, 4848, 1574, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7451, 5414, 1574, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7452, 8399, 1574, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7469, 5249, 1587, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7470, 10782, 1587, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7471, 12440, 1587, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7453, 8386, 1573, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7454, 8387, 1573, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7455, 8388, 1573, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7456, 8389, 1573, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7457, 5825, 1573, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7458, 8390, 1573, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7459, 9138, 1573, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7460, 8046, 1573, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7461, 8392, 1573, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7462, 8393, 1573, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7463, 8394, 1573, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7464, 8395, 1573, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7465, 8396, 1573, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7466, 8397, 1573, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7467, 8398, 1573, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7472, 12419, 1587, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (964, 768, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (965, 933, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (966, 164, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (967, 998, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (968, 1037, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (969, 948, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (970, 104, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (971, 857, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (972, 295, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (973, 697, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (974, 1263, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (975, 1770, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (976, 230, 61, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (977, 482, 61, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7473, 2430, 1587, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7474, 12446, 1587, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7475, 12417, 1587, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7476, 9705, 1587, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7477, 5187, 1587, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (7478, 12454, 1587, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7479, 12453, 1587, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7480, 2189, 1587, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7481, 12418, 1587, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (7483, 12416, 1587, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (7482, 12439, 1587, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (7484, 12421, 1587, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (7485, 12438, 1587, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (7486, 12452, 1587, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (7487, 2985, 1587, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (7488, 10890, 1587, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7513, 7139, 714, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (4598, 8858, 73, 10, 242);
INSERT INTO 'tunespublicationsmap' VALUES (7489, 1067, 1582, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7490, 3, 1582, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7491, 1770, 1582, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7492, 1131, 1582, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7512, 7140, 714, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7515, 7143, 714, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7514, 7147, 714, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7517, 7150, 714, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7516, 7151, 714, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7511, 7152, 714, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7519, 7153, 714, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7518, 7154, 714, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7520, 7138, 714, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7521, 7148, 714, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7522, 9239, 1594, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7523, 9240, 1594, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5871, 11598, 1055, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5877, 11604, 1055, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (5881, 11609, 1055, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1199, 1305, 158, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (1200, 1564, 158, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (1201, 2866, 158, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1202, 4084, 158, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7493, 1349, 1581, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7494, 482, 1581, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7495, 948, 1581, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7496, 1646, 1581, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7500, 1037, 1580, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7501, 933, 1580, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7502, 941, 1580, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7503, 190, 1583, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7504, 1263, 1583, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7505, 998, 1583, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7509, 1177, 1585, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7510, 890, 1585, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (4298, 8868, 893, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4299, 8869, 893, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4300, 8874, 893, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4301, 122, 893, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4302, 8870, 893, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4303, 8871, 893, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4304, 8875, 893, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4305, 8872, 893, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4306, 8873, 893, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1203, 5354, 158, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1204, 5455, 158, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (1205, 5561, 158, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (1206, 5673, 158, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (1207, 5264, 158, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (1208, 5674, 158, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (1209, 5675, 158, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (1210, 5611, 158, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (1211, 5676, 158, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (1212, 5677, 158, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (1213, 5678, 158, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (1214, 5679, 158, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1215, 3194, 158, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1217, 5680, 158, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (1216, 5681, 158, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (1218, 5682, 158, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1219, 5683, 158, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (1220, 3364, 158, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1221, 2157, 158, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1222, 5684, 158, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (1223, 5685, 158, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1224, 5686, 158, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (1225, 5687, 158, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (1226, 5688, 158, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1227, 5689, 158, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (1229, 5690, 158, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (1230, 5691, 158, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (1228, 5692, 158, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (1231, 5693, 158, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (1232, 5694, 158, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (1233, 1169, 158, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (1234, 5695, 158, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1235, 5696, 158, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (1236, 5697, 158, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (1240, 5698, 158, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (1237, 5699, 158, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (1238, 5700, 158, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (1239, 5701, 158, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (1241, 4910, 158, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (1242, 5317, 158, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (1243, 5702, 158, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (1244, 5703, 158, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (1245, 5704, 158, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (1246, 5705, 158, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (1247, 5706, 158, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (1248, 2143, 158, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (1249, 2147, 158, 10, 51);
INSERT INTO 'tunespublicationsmap' VALUES (3184, 7993, 382, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3185, 7994, 382, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3186, 7995, 382, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3187, 7996, 382, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3188, 5884, 382, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (1991, 6441, 374, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1992, 3243, 374, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1993, 6442, 374, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1994, 6443, 374, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7468, 14443, 339, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4092, 1130, 141, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4093, 1411, 141, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (951, 199, 60, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (952, 1131, 60, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (385, 3654, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (388, 3672, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (953, 941, 60, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7506, 1302, 1584, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7507, 1723, 1584, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7508, 548, 1584, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7525, 8238, 361, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7526, 12083, 361, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7527, 3928, 361, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7528, 1109, 361, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7531, 3379, 361, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7529, 1337, 361, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7530, 1883, 361, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7524, 4346, 361, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6126, 3613, 1157, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (4879, 451, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4880, 452, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4881, 453, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4866, 415, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4908, 9004, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4909, 512, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4910, 964, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4911, 517, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4912, 3764, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4913, 1673, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4914, 523, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5101, 3865, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5102, 627, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5103, 628, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5104, 631, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5105, 636, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5106, 637, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5107, 8472, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5254, 2522, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5255, 1474, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4636, 1404, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4637, 3, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4638, 347, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4639, 8998, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4640, 3061, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4641, 5, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4642, 1078, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4643, 1066, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4840, 364, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4867, 424, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4868, 427, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4869, 430, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4870, 432, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4871, 435, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4872, 437, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4873, 925, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4874, 441, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4875, 469, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4882, 6001, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4883, 456, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4884, 457, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4885, 465, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4886, 470, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4887, 476, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4888, 4074, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4889, 479, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4890, 480, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4891, 482, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4892, 485, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4893, 1459, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4894, 486, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4895, 7548, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4896, 487, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4897, 2166, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4898, 492, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4899, 1739, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4900, 520, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4901, 894, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4902, 3740, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4903, 762, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4904, 497, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4915, 1195, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4916, 9281, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4917, 534, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4918, 1154, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4919, 7553, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4920, 536, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4921, 7546, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4922, 539, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4923, 542, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4924, 722, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4925, 2779, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4926, 548, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4927, 551, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4928, 552, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4948, 568, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4949, 2832, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4950, 1429, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4951, 578, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4952, 580, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4953, 4361, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4954, 588, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4955, 1218, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4956, 590, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4957, 594, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4958, 597, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4959, 602, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4960, 1209, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4961, 610, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4962, 1674, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4963, 614, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4964, 1801, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5108, 640, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5109, 7549, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5110, 654, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5111, 2249, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5112, 669, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5113, 673, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5114, 3151, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5115, 1360, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5119, 1453, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5120, 693, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5121, 696, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5122, 702, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5123, 704, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5124, 3381, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5125, 3952, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5126, 1457, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5127, 720, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5128, 1552, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5129, 724, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5130, 1285, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5131, 4382, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5132, 732, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5133, 3891, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5134, 8841, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5135, 1826, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5136, 1820, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5137, 743, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5138, 2307, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5139, 1036, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5140, 1638, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5141, 755, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5142, 1497, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5143, 759, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5144, 761, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5145, 4358, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5146, 768, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5147, 770, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5148, 771, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5149, 1732, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5150, 4281, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5151, 1021, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5156, 803, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5157, 2366, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5158, 808, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5159, 815, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5160, 810, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5161, 819, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5162, 820, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5163, 823, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5164, 824, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5165, 674, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5166, 843, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5167, 2829, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5168, 846, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5169, 850, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5170, 857, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5171, 4509, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5172, 864, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5173, 1421, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5174, 872, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5175, 2737, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5176, 873, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5177, 876, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5178, 1450, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5179, 880, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5180, 886, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5181, 887, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5182, 4015, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5183, 2185, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5184, 892, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5185, 1597, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5186, 896, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5187, 9003, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5198, 1029, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5199, 918, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5200, 919, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5201, 923, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5202, 1361, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5203, 5709, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5204, 926, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5205, 1737, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5206, 928, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5207, 933, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5208, 937, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5209, 939, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5210, 941, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5211, 944, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5212, 949, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5213, 953, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5214, 2565, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5215, 952, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5216, 955, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5217, 960, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5218, 962, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5219, 1665, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5220, 1442, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5221, 967, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5222, 1065, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5223, 969, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5224, 1565, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5225, 974, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5226, 3430, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5230, 986, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5231, 2696, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5232, 989, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5233, 992, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5234, 998, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5235, 1001, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5236, 1000, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5237, 3078, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5238, 1235, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5239, 1008, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5240, 1009, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5241, 1012, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5242, 1015, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5243, 1017, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5244, 1024, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5245, 1019, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5246, 1041, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5247, 1037, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5248, 1043, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5256, 1080, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5257, 4192, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5258, 1082, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5259, 1095, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5260, 8380, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5261, 9291, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5262, 1516, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5263, 4100, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5264, 1302, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5265, 1100, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5266, 1103, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5267, 1105, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5268, 1107, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5269, 1108, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5270, 1110, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5271, 1111, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5272, 1116, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5273, 2562, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5274, 1141, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5275, 1780, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5276, 1615, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5277, 6639, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5278, 1144, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5279, 1145, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5280, 1147, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5281, 1297, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5282, 1151, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5283, 1157, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5284, 1156, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5285, 1159, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5295, 1368, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5296, 1186, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5297, 1662, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5298, 1188, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5299, 1321, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5300, 1197, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5301, 1200, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5302, 1201, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5303, 1202, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5304, 4260, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5305, 1213, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5306, 2608, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5307, 2648, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5308, 1219, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5309, 2614, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5310, 1223, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5311, 1226, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5312, 1227, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5313, 1228, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5314, 1229, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5315, 1587, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5316, 1230, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5317, 1234, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5318, 7545, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5319, 1236, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5320, 1237, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5321, 1243, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5344, 1544, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5345, 1345, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5346, 1346, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5347, 7425, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5348, 1351, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5349, 1359, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5350, 2646, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5351, 1371, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5352, 1374, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5353, 1079, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5354, 2152, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5355, 5707, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5356, 1559, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5357, 4341, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4644, 351, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4645, 9, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4646, 1214, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4647, 12, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4648, 14, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4649, 7550, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4650, 13, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4651, 16, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4652, 8385, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4653, 23, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4654, 1518, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4655, 24, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4656, 3801, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4657, 3330, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4658, 4602, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4659, 29, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4660, 31, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4661, 34, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4662, 35, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4663, 2748, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4664, 36, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4665, 7543, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4666, 46, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4667, 6507, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4668, 329, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4669, 8838, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4670, 49, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4671, 3353, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4672, 55, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4673, 54, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4674, 1466, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4675, 1356, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4676, 56, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4677, 57, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4678, 61, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4679, 64, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4680, 705, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4681, 764, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4682, 71, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4684, 1010, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4686, 1530, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4687, 84, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4688, 1284, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4689, 91, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4690, 90, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4691, 97, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4692, 1644, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4693, 9006, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4694, 3997, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4695, 103, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4696, 1067, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4697, 104, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4698, 661, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4699, 114, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4700, 2160, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4701, 1922, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4702, 120, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4703, 1834, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4704, 1618, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4705, 1757, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4706, 1759, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4707, 121, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4708, 124, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4709, 948, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4711, 1939, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4712, 6109, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4713, 126, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4714, 3299, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4715, 129, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4716, 133, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4717, 137, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4718, 138, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4719, 1355, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4720, 145, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4721, 601, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4722, 152, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4723, 2168, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4724, 8177, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4725, 3459, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4726, 1733, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4727, 346, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4728, 1276, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4729, 159, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4730, 1163, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4731, 164, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4732, 169, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4733, 171, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4734, 173, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4735, 176, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4736, 1682, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4737, 1349, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4738, 179, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4739, 180, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4740, 181, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4741, 1062, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4742, 183, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4743, 392, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4744, 1766, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4745, 2523, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4746, 1425, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4747, 194, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4748, 197, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4749, 198, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4750, 199, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4751, 2830, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4752, 448, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4753, 203, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4754, 8846, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4755, 206, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4756, 1721, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4757, 210, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4758, 589, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4759, 1467, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4760, 2609, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4761, 222, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4762, 223, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4763, 807, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4764, 447, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4765, 226, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4766, 3511, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4767, 1316, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4768, 230, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4769, 232, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4770, 328, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4771, 234, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4772, 274, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4773, 238, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4774, 1499, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4775, 236, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4776, 243, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4777, 247, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4778, 2021, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4779, 248, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4780, 253, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4781, 2019, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4782, 251, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4783, 897, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4784, 2022, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4785, 9007, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4786, 9285, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4787, 269, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4788, 2050, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4789, 271, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4790, 8999, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4791, 273, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4792, 1210, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4793, 2392, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4794, 742, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4795, 277, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4796, 2418, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4797, 281, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4798, 282, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4799, 283, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4800, 2279, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4801, 287, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4802, 290, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4803, 8844, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4804, 295, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4805, 9284, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4806, 825, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4807, 1002, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4808, 2055, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4809, 5711, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4810, 309, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4811, 310, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4812, 313, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4813, 1194, 979, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4814, 7760, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4815, 1852, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4816, 318, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4817, 8474, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4851, 385, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4852, 2106, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4853, 9279, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4854, 393, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4855, 394, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4856, 396, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4857, 3834, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4858, 2187, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4859, 408, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4860, 3683, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4861, 413, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4862, 411, 979, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7532, 14472, 1598, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7534, 14473, 1598, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7535, 14474, 1598, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7536, 14475, 1598, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7533, 14476, 1598, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7538, 14478, 1598, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7537, 14477, 1598, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7539, 14479, 1598, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (7540, 14480, 1598, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7541, 2197, 1598, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7542, 14481, 1598, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7543, 14482, 1598, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7544, 14483, 1598, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7545, 14484, 1598, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3229, 2757, 776, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3230, 8053, 776, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3231, 2418, 776, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3232, 2423, 776, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3233, 5615, 776, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3234, 1396, 776, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (3235, 8080, 776, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3236, 1241, 776, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (3237, 7503, 776, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3238, 7494, 776, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (3239, 8081, 776, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3240, 518, 776, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3241, 1840, 776, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3242, 8082, 776, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (3243, 8083, 776, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3244, 916, 776, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (3245, 4726, 776, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (3246, 51, 776, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3247, 8084, 776, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (3248, 1084, 776, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3249, 1158, 776, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (3250, 106, 776, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3251, 196, 776, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (3252, 55, 776, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3253, 2433, 776, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (3254, 1262, 776, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3255, 326, 776, 50, 18);
INSERT INTO 'tunespublicationsmap' VALUES (3256, 8085, 776, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3257, 2922, 776, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (3258, 8086, 776, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3259, 2582, 776, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (3260, 1470, 776, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3261, 3195, 776, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (3262, 8087, 776, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3263, 730, 776, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (3264, 388, 776, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3265, 895, 776, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (3266, 1435, 776, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (3267, 8088, 776, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (3268, 3381, 776, 50, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3269, 2811, 776, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (3270, 2396, 776, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3271, 1401, 776, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (3272, 4959, 776, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (3273, 914, 776, 50, 28);
INSERT INTO 'tunespublicationsmap' VALUES (3274, 2718, 776, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (3275, 2774, 776, 50, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3276, 2601, 776, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (3277, 8089, 776, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (3278, 8090, 776, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (3279, 5268, 776, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (3280, 1328, 776, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (3281, 2387, 776, 50, 33);
INSERT INTO 'tunespublicationsmap' VALUES (3282, 2112, 776, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (3283, 470, 776, 50, 35);
INSERT INTO 'tunespublicationsmap' VALUES (3284, 1369, 776, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (3285, 6244, 776, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (3286, 856, 776, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (3287, 8091, 776, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (3288, 901, 776, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (3289, 3550, 776, 50, 39);
INSERT INTO 'tunespublicationsmap' VALUES (3290, 8092, 776, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (3291, 935, 776, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (3292, 4718, 776, 50, 41);
INSERT INTO 'tunespublicationsmap' VALUES (3293, 3713, 776, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (3294, 8093, 776, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (3295, 1995, 776, 50, 42);
INSERT INTO 'tunespublicationsmap' VALUES (3296, 8094, 776, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (3297, 465, 776, 50, 44);
INSERT INTO 'tunespublicationsmap' VALUES (3298, 1496, 776, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (3299, 8095, 776, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (3300, 8096, 776, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (3301, 8097, 776, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (3302, 530, 776, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (3303, 1827, 776, 50, 47);
INSERT INTO 'tunespublicationsmap' VALUES (3304, 3260, 776, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (3305, 8098, 776, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (3306, 2101, 776, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (3307, 4720, 776, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (3308, 8099, 776, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (7576, 13304, 1605, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7546, 14487, 1600, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7547, 14488, 1600, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7548, 14489, 1600, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7549, 14490, 1600, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7550, 14491, 1600, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7551, 14492, 1600, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7552, 14493, 1600, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7553, 14494, 1600, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7554, 14486, 1600, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (7555, 14495, 1600, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7577, 12053, 1605, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7578, 12054, 1605, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7579, 13305, 1605, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7580, 13306, 1605, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7604, 14547, 1607, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (7581, 14453, 1606, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7582, 14454, 1606, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7583, 14455, 1606, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7584, 14456, 1606, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7585, 14532, 1606, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7586, 14457, 1606, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7587, 14452, 1606, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7588, 14533, 1606, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7589, 14534, 1606, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7590, 13019, 1606, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7591, 14535, 1606, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7592, 14536, 1606, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7593, 14537, 1606, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7594, 14538, 1606, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7595, 14459, 1606, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7556, 14503, 1602, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7557, 14504, 1602, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7558, 14505, 1602, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7559, 14506, 1602, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7560, 14507, 1602, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7561, 14508, 1602, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7562, 14509, 1602, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7563, 14510, 1602, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7564, 14511, 1602, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (7565, 14512, 1602, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (7566, 14513, 1602, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (7596, 14458, 1606, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (7597, 14539, 1606, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7598, 14540, 1606, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7567, 13296, 1605, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7568, 13297, 1605, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7605, 14548, 1607, 10, 53);
INSERT INTO 'tunespublicationsmap' VALUES (7606, 14549, 1607, 10, 57);
INSERT INTO 'tunespublicationsmap' VALUES (7569, 13298, 1605, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7570, 13299, 1605, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7599, 14544, 1607, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7600, 14545, 1607, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (7601, 9256, 1607, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (7602, 14546, 1607, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (7603, 1043, 1607, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (7571, 10674, 1605, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7572, 13300, 1605, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7573, 13301, 1605, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7574, 13302, 1605, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7575, 13303, 1605, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (3996, 3949, 316, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3997, 3814, 316, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3998, 3863, 316, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3999, 4591, 316, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4000, 4622, 316, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7608, 14555, 1614, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7607, 14551, 1609, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7609, 14556, 1614, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7610, 14557, 1614, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7611, 14558, 1614, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7612, 14281, 1614, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7613, 14559, 1614, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7614, 14280, 1614, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7615, 14560, 1614, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7616, 14561, 1614, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7617, 14562, 1614, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7618, 14387, 1614, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7619, 14563, 1614, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7620, 14564, 1614, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7621, 14565, 1614, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7622, 14566, 1614, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7623, 14567, 1614, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (7624, 14568, 1614, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7625, 14569, 1614, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7626, 14570, 1614, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7627, 14571, 1614, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7628, 14572, 1614, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (7629, 14573, 1614, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7630, 14574, 1614, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7631, 14575, 1614, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7632, 14576, 1614, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (7633, 14577, 1614, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (7634, 14578, 1614, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (7635, 14579, 1614, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (7636, 14580, 1614, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (7637, 14581, 1614, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (7638, 14582, 1614, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (7639, 7913, 1614, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (7640, 14583, 1614, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (7641, 14584, 1614, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (7642, 14585, 1614, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (7643, 14586, 1614, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (7644, 14587, 1614, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (7647, 14588, 1614, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (7648, 14554, 1614, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (7649, 14459, 1614, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (7650, 14589, 1614, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (7651, 14590, 1614, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (7652, 14591, 1614, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (7653, 14592, 1614, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (7654, 14593, 1614, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (7655, 14594, 1614, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (7656, 13811, 1614, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (7657, 14595, 1614, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (7659, 14536, 1614, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (7658, 14596, 1614, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (7660, 14597, 1614, 10, 51);
INSERT INTO 'tunespublicationsmap' VALUES (7661, 14598, 1614, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (7662, 14599, 1614, 10, 53);
INSERT INTO 'tunespublicationsmap' VALUES (7663, 14600, 1614, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (7664, 14601, 1614, 10, 55);
INSERT INTO 'tunespublicationsmap' VALUES (7665, 14602, 1614, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (7666, 14603, 1614, 10, 57);
INSERT INTO 'tunespublicationsmap' VALUES (7667, 14604, 1614, 10, 58);
INSERT INTO 'tunespublicationsmap' VALUES (7668, 4471, 1614, 10, 59);
INSERT INTO 'tunespublicationsmap' VALUES (7669, 4472, 1614, 10, 60);
INSERT INTO 'tunespublicationsmap' VALUES (7670, 14605, 1614, 10, 61);
INSERT INTO 'tunespublicationsmap' VALUES (7671, 14606, 1614, 10, 62);
INSERT INTO 'tunespublicationsmap' VALUES (7672, 14607, 1614, 10, 63);
INSERT INTO 'tunespublicationsmap' VALUES (7674, 14609, 1614, 10, 65);
INSERT INTO 'tunespublicationsmap' VALUES (7675, 14610, 1614, 10, 66);
INSERT INTO 'tunespublicationsmap' VALUES (7676, 14611, 1614, 10, 67);
INSERT INTO 'tunespublicationsmap' VALUES (2409, 7177, 422, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6118, 10060, 1147, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (2427, 7179, 422, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2411, 4614, 422, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2425, 7178, 422, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (2412, 3163, 422, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2410, 215, 422, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2415, 3165, 422, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2413, 2209, 422, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2429, 2213, 422, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2426, 2216, 422, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2428, 2215, 422, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2417, 2268, 422, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2416, 2267, 422, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2414, 2271, 422, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (2421, 2272, 422, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (2419, 5588, 422, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (2430, 5587, 422, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7673, 14608, 1614, 10, 64);
INSERT INTO 'tunespublicationsmap' VALUES (2418, 5589, 422, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2422, 2248, 422, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (2420, 2244, 422, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (2431, 2245, 422, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (2423, 2242, 422, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (2433, 52, 422, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (2445, 5599, 422, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (2452, 4094, 422, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (2439, 683, 422, 50, 20);
INSERT INTO 'tunespublicationsmap' VALUES (2435, 3167, 422, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (2443, 3168, 422, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (2442, 3169, 422, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (2440, 828, 422, 50, 22);
INSERT INTO 'tunespublicationsmap' VALUES (2438, 3176, 422, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (2450, 2193, 422, 50, 24);
INSERT INTO 'tunespublicationsmap' VALUES (2447, 2195, 422, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7677, 13000, 1615, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7678, 6633, 1615, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7679, 8203, 1615, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7680, 9318, 1615, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7681, 14612, 1615, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7682, 7915, 1615, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7683, 14613, 1615, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7684, 14614, 1615, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7685, 3729, 1615, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7686, 7286, 1615, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7687, 8209, 1615, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7688, 5590, 1615, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7689, 3804, 1615, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7690, 7799, 1615, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7691, 7562, 1615, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7692, 7809, 1615, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (7693, 3309, 1615, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7694, 14615, 1615, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7695, 1523, 1615, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7696, 5600, 1615, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7697, 108, 1615, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (7698, 3609, 1615, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7699, 10154, 1615, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7700, 14616, 1615, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7701, 14617, 1615, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (7702, 7310, 1615, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (7703, 14618, 1615, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (7704, 14619, 1615, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (7705, 14620, 1615, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (7706, 14621, 1615, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (7707, 5597, 1615, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (7708, 12172, 1615, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (7709, 7807, 1615, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (7710, 14622, 1615, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (7711, 14623, 1615, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (7712, 14624, 1615, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (2485, 2275, 422, 10, 68);
INSERT INTO 'tunespublicationsmap' VALUES (7713, 7319, 1616, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7714, 7816, 1616, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7715, 12052, 1616, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7716, 14626, 1616, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7717, 14627, 1616, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7718, 9324, 1616, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7719, 8388, 1616, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7720, 9322, 1616, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7721, 9323, 1616, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7722, 14628, 1616, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7723, 10680, 1616, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7724, 14629, 1616, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7725, 14630, 1616, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7726, 14631, 1616, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7727, 8231, 1616, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7728, 8202, 1616, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (7729, 4108, 1616, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7730, 14632, 1616, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7731, 14633, 1616, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7732, 7811, 1616, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7733, 7307, 1616, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (7734, 7312, 1616, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7735, 2989, 1616, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7736, 14634, 1616, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7737, 7739, 1616, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (7738, 7774, 1616, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (7739, 3465, 1616, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (7740, 6117, 1616, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (7741, 4953, 1616, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (7742, 14288, 1616, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (7743, 2107, 1616, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (7744, 2116, 1616, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (7745, 2166, 1616, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (7746, 9249, 1616, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (7747, 6119, 1616, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (7748, 2234, 1616, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (7749, 2033, 1616, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (7750, 13482, 1616, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (7751, 2523, 1616, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (7752, 13020, 1616, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (7753, 7074, 1616, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (7754, 14635, 1616, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (7755, 2783, 1616, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (7756, 2032, 1616, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (7757, 14636, 1616, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (7758, 89, 1616, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (7759, 14637, 1616, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (7760, 14638, 1616, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (7761, 7925, 1616, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (7762, 7814, 1616, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (7763, 6116, 1616, 10, 51);
INSERT INTO 'tunespublicationsmap' VALUES (7764, 7285, 1616, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (7765, 14639, 1616, 10, 53);
INSERT INTO 'tunespublicationsmap' VALUES (7766, 45, 1616, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (7767, 7317, 1616, 10, 55);
INSERT INTO 'tunespublicationsmap' VALUES (7768, 2190, 1616, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (7769, 12077, 1616, 10, 57);
INSERT INTO 'tunespublicationsmap' VALUES (7770, 4110, 1616, 10, 58);
INSERT INTO 'tunespublicationsmap' VALUES (7771, 5825, 1616, 10, 59);
INSERT INTO 'tunespublicationsmap' VALUES (7772, 14640, 1616, 10, 60);
INSERT INTO 'tunespublicationsmap' VALUES (7773, 8207, 1616, 10, 61);
INSERT INTO 'tunespublicationsmap' VALUES (7774, 5849, 1616, 10, 62);
INSERT INTO 'tunespublicationsmap' VALUES (7775, 10173, 1616, 10, 63);
INSERT INTO 'tunespublicationsmap' VALUES (7776, 7318, 1616, 10, 64);
INSERT INTO 'tunespublicationsmap' VALUES (7777, 11075, 1616, 10, 65);
INSERT INTO 'tunespublicationsmap' VALUES (7778, 2257, 1616, 10, 66);
INSERT INTO 'tunespublicationsmap' VALUES (7779, 14641, 1616, 10, 67);
INSERT INTO 'tunespublicationsmap' VALUES (7780, 12758, 1616, 10, 68);
INSERT INTO 'tunespublicationsmap' VALUES (7781, 12043, 1616, 10, 69);
INSERT INTO 'tunespublicationsmap' VALUES (7782, 851, 1616, 10, 70);
INSERT INTO 'tunespublicationsmap' VALUES (7783, 12750, 1616, 10, 71);
INSERT INTO 'tunespublicationsmap' VALUES (7784, 12703, 1616, 10, 72);
INSERT INTO 'tunespublicationsmap' VALUES (7785, 14642, 1616, 10, 73);
INSERT INTO 'tunespublicationsmap' VALUES (7786, 9253, 1616, 10, 74);
INSERT INTO 'tunespublicationsmap' VALUES (7787, 3372, 1616, 10, 75);
INSERT INTO 'tunespublicationsmap' VALUES (7805, 14643, 1617, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7806, 9024, 1617, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7807, 14644, 1617, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7808, 12075, 1617, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7809, 14645, 1617, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7810, 14646, 1617, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7811, 8418, 1617, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7812, 14647, 1617, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7813, 10177, 1617, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7814, 10681, 1617, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7815, 12051, 1617, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7816, 13610, 1617, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7817, 13609, 1617, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7788, 10684, 1616, 10, 76);
INSERT INTO 'tunespublicationsmap' VALUES (7789, 8464, 1616, 10, 77);
INSERT INTO 'tunespublicationsmap' VALUES (7790, 8208, 1616, 10, 78);
INSERT INTO 'tunespublicationsmap' VALUES (7791, 2649, 1616, 10, 79);
INSERT INTO 'tunespublicationsmap' VALUES (7792, 3288, 1616, 10, 80);
INSERT INTO 'tunespublicationsmap' VALUES (7793, 10217, 1616, 10, 81);
INSERT INTO 'tunespublicationsmap' VALUES (7794, 10573, 1616, 10, 82);
INSERT INTO 'tunespublicationsmap' VALUES (7795, 12755, 1616, 10, 83);
INSERT INTO 'tunespublicationsmap' VALUES (7796, 7581, 1616, 10, 84);
INSERT INTO 'tunespublicationsmap' VALUES (7797, 12761, 1616, 10, 85);
INSERT INTO 'tunespublicationsmap' VALUES (7798, 8190, 1616, 10, 86);
INSERT INTO 'tunespublicationsmap' VALUES (7818, 13163, 1617, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7819, 13786, 1617, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7820, 12695, 1617, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (7821, 12062, 1617, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7822, 14648, 1617, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7823, 10588, 1617, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7824, 14649, 1617, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7825, 12701, 1617, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (7799, 10683, 1616, 10, 87);
INSERT INTO 'tunespublicationsmap' VALUES (7800, 3238, 1616, 10, 88);
INSERT INTO 'tunespublicationsmap' VALUES (7801, 2192, 1616, 10, 89);
INSERT INTO 'tunespublicationsmap' VALUES (7802, 4221, 1616, 10, 90);
INSERT INTO 'tunespublicationsmap' VALUES (7826, 12061, 1617, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (7827, 13991, 1617, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7828, 13896, 1617, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (7803, 83, 1616, 10, 91);
INSERT INTO 'tunespublicationsmap' VALUES (7804, 9325, 1616, 10, 92);
INSERT INTO 'tunespublicationsmap' VALUES (7829, 12170, 1617, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (7830, 12704, 1617, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (7831, 13990, 1617, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (7832, 12080, 1617, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (7833, 12080, 1617, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (7834, 14650, 1617, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (7835, 12697, 1617, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (7836, 12696, 1617, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (7837, 10577, 1617, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (7838, 12708, 1617, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (7839, 12064, 1617, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (7840, 12045, 1617, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (7841, 12081, 1617, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (7842, 13778, 1617, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (7843, 12079, 1617, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (7844, 13772, 1617, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (7845, 13784, 1617, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (7846, 12065, 1617, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (7847, 12707, 1617, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (7848, 14651, 1617, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (7849, 12066, 1617, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (7850, 14652, 1617, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (7851, 12767, 1617, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (7852, 10277, 1617, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (7853, 12078, 1617, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (7854, 9316, 1617, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (7855, 10689, 1617, 10, 51);
INSERT INTO 'tunespublicationsmap' VALUES (7856, 10689, 1617, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (7857, 12067, 1617, 10, 53);
INSERT INTO 'tunespublicationsmap' VALUES (7858, 8464, 1617, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (7859, 12760, 1617, 10, 55);
INSERT INTO 'tunespublicationsmap' VALUES (7860, 12044, 1617, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (7861, 14653, 1617, 10, 57);
INSERT INTO 'tunespublicationsmap' VALUES (7862, 7801, 1617, 10, 58);
INSERT INTO 'tunespublicationsmap' VALUES (7863, 10164, 1617, 10, 59);
INSERT INTO 'tunespublicationsmap' VALUES (7864, 10575, 1617, 10, 60);
INSERT INTO 'tunespublicationsmap' VALUES (7865, 12752, 1617, 10, 61);
INSERT INTO 'tunespublicationsmap' VALUES (7866, 13924, 1617, 10, 62);
INSERT INTO 'tunespublicationsmap' VALUES (7867, 8421, 1617, 10, 63);
INSERT INTO 'tunespublicationsmap' VALUES (7868, 13697, 1617, 10, 64);
INSERT INTO 'tunespublicationsmap' VALUES (7869, 12048, 1617, 10, 65);
INSERT INTO 'tunespublicationsmap' VALUES (220, 3417, 641, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (271, 3489, 641, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (574, 3955, 641, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (646, 4047, 641, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (685, 4102, 641, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1008, 4589, 641, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4590, 1084, 641, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4617, 2152, 641, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6304, 2903, 690, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6305, 1964, 690, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6306, 12915, 690, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7870, 9317, 1617, 10, 66);
INSERT INTO 'tunespublicationsmap' VALUES (7871, 12700, 1617, 10, 67);
INSERT INTO 'tunespublicationsmap' VALUES (7872, 1653, 1617, 10, 68);
INSERT INTO 'tunespublicationsmap' VALUES (7873, 10165, 1617, 10, 69);
INSERT INTO 'tunespublicationsmap' VALUES (7874, 14079, 1617, 10, 70);
INSERT INTO 'tunespublicationsmap' VALUES (7875, 10576, 1617, 10, 71);
INSERT INTO 'tunespublicationsmap' VALUES (7876, 14654, 1617, 10, 72);
INSERT INTO 'tunespublicationsmap' VALUES (7877, 10690, 1617, 10, 73);
INSERT INTO 'tunespublicationsmap' VALUES (7878, 10174, 1617, 10, 74);
INSERT INTO 'tunespublicationsmap' VALUES (7879, 13606, 1617, 10, 75);
INSERT INTO 'tunespublicationsmap' VALUES (7880, 12073, 1617, 10, 76);
INSERT INTO 'tunespublicationsmap' VALUES (7881, 13893, 1617, 10, 77);
INSERT INTO 'tunespublicationsmap' VALUES (7882, 5858, 1617, 10, 78);
INSERT INTO 'tunespublicationsmap' VALUES (7883, 14655, 1617, 10, 79);
INSERT INTO 'tunespublicationsmap' VALUES (4005, 494, 86, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4006, 1783, 86, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7144, 408, 1518, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7145, 230, 1518, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7146, 10638, 1518, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7884, 13808, 1617, 10, 80);
INSERT INTO 'tunespublicationsmap' VALUES (7885, 14656, 1617, 10, 81);
INSERT INTO 'tunespublicationsmap' VALUES (7886, 13767, 1617, 10, 82);
INSERT INTO 'tunespublicationsmap' VALUES (7887, 12699, 1617, 10, 83);
INSERT INTO 'tunespublicationsmap' VALUES (7888, 14657, 1617, 10, 84);
INSERT INTO 'tunespublicationsmap' VALUES (7889, 13891, 1617, 10, 85);
INSERT INTO 'tunespublicationsmap' VALUES (7890, 10682, 1617, 10, 86);
INSERT INTO 'tunespublicationsmap' VALUES (7891, 2052, 1617, 10, 87);
INSERT INTO 'tunespublicationsmap' VALUES (7892, 8205, 1617, 10, 88);
INSERT INTO 'tunespublicationsmap' VALUES (7893, 14658, 1617, 10, 89);
INSERT INTO 'tunespublicationsmap' VALUES (7894, 11664, 1617, 10, 90);
INSERT INTO 'tunespublicationsmap' VALUES (7895, 10173, 1617, 10, 91);
INSERT INTO 'tunespublicationsmap' VALUES (7896, 14659, 1617, 10, 92);
INSERT INTO 'tunespublicationsmap' VALUES (7897, 14660, 1617, 10, 93);
INSERT INTO 'tunespublicationsmap' VALUES (7898, 14661, 1617, 10, 94);
INSERT INTO 'tunespublicationsmap' VALUES (7899, 14662, 1617, 10, 95);
INSERT INTO 'tunespublicationsmap' VALUES (7918, 10546, 1057, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7919, 10547, 1057, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7920, 2655, 1057, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7921, 10549, 1057, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7922, 281, 1057, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7923, 10554, 1057, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7924, 10555, 1057, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7925, 9447, 1057, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7926, 3647, 1057, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7927, 10560, 1057, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7928, 10563, 1057, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7929, 3823, 1057, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7930, 10567, 1057, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7931, 4348, 1057, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7107, 12285, 1492, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (7108, 14016, 1492, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (7109, 13238, 1492, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (7932, 14675, 120, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (2437, 2198, 422, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (2444, 2201, 422, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (2449, 1469, 422, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (2424, 3164, 422, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (2446, 2638, 422, 50, 28);
INSERT INTO 'tunespublicationsmap' VALUES (2432, 2222, 422, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (2434, 2254, 422, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (2448, 1433, 422, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (2441, 2224, 422, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (2451, 2250, 422, 50, 32);
INSERT INTO 'tunespublicationsmap' VALUES (2453, 2251, 422, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (2436, 2253, 422, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (2469, 5, 422, 50, 36);
INSERT INTO 'tunespublicationsmap' VALUES (2455, 2204, 422, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (2470, 2208, 422, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (2465, 2207, 422, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (2459, 3179, 422, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (2457, 3180, 422, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (2458, 2487, 422, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (2488, 1837, 422, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (2467, 1098, 422, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (2463, 852, 422, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (2460, 5598, 422, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (2462, 2366, 422, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (2461, 2261, 422, 50, 42);
INSERT INTO 'tunespublicationsmap' VALUES (7900, 14663, 1617, 10, 96);
INSERT INTO 'tunespublicationsmap' VALUES (7901, 13905, 1617, 10, 97);
INSERT INTO 'tunespublicationsmap' VALUES (7902, 12171, 1617, 10, 98);
INSERT INTO 'tunespublicationsmap' VALUES (7903, 13100, 1617, 10, 99);
INSERT INTO 'tunespublicationsmap' VALUES (7904, 12763, 1617, 10, 100);
INSERT INTO 'tunespublicationsmap' VALUES (7905, 13907, 1617, 10, 101);
INSERT INTO 'tunespublicationsmap' VALUES (7906, 12049, 1617, 10, 102);
INSERT INTO 'tunespublicationsmap' VALUES (7907, 12072, 1617, 10, 103);
INSERT INTO 'tunespublicationsmap' VALUES (7908, 13376, 1617, 10, 104);
INSERT INTO 'tunespublicationsmap' VALUES (7909, 12705, 1617, 10, 105);
INSERT INTO 'tunespublicationsmap' VALUES (7910, 9329, 1617, 10, 106);
INSERT INTO 'tunespublicationsmap' VALUES (7911, 4632, 1617, 10, 107);
INSERT INTO 'tunespublicationsmap' VALUES (7912, 14664, 1617, 10, 108);
INSERT INTO 'tunespublicationsmap' VALUES (7913, 14665, 1617, 10, 109);
INSERT INTO 'tunespublicationsmap' VALUES (7914, 11646, 1617, 10, 110);
INSERT INTO 'tunespublicationsmap' VALUES (2468, 2049, 422, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (2454, 2265, 422, 10, 43);
INSERT INTO 'tunespublicationsmap' VALUES (2466, 2217, 422, 50, 44);
INSERT INTO 'tunespublicationsmap' VALUES (2464, 2221, 422, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (2473, 3186, 422, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (2471, 3187, 422, 10, 47);
INSERT INTO 'tunespublicationsmap' VALUES (2472, 7180, 422, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (2456, 96, 422, 50, 48);
INSERT INTO 'tunespublicationsmap' VALUES (2474, 3175, 422, 10, 49);
INSERT INTO 'tunespublicationsmap' VALUES (2489, 7196, 422, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (2477, 3173, 422, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (2476, 3172, 422, 10, 55);
INSERT INTO 'tunespublicationsmap' VALUES (2487, 3174, 422, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (2479, 7182, 422, 10, 57);
INSERT INTO 'tunespublicationsmap' VALUES (2475, 2273, 422, 10, 58);
INSERT INTO 'tunespublicationsmap' VALUES (2478, 5596, 422, 10, 60);
INSERT INTO 'tunespublicationsmap' VALUES (2480, 5595, 422, 10, 61);
INSERT INTO 'tunespublicationsmap' VALUES (2481, 5594, 422, 10, 62);
INSERT INTO 'tunespublicationsmap' VALUES (2482, 2239, 422, 10, 64);
INSERT INTO 'tunespublicationsmap' VALUES (2483, 2233, 422, 10, 64);
INSERT INTO 'tunespublicationsmap' VALUES (2484, 2237, 422, 10, 65);
INSERT INTO 'tunespublicationsmap' VALUES (2486, 7183, 422, 10, 66);
INSERT INTO 'tunespublicationsmap' VALUES (7915, 14666, 1617, 10, 111);
INSERT INTO 'tunespublicationsmap' VALUES (7916, 13098, 1617, 10, 112);
INSERT INTO 'tunespublicationsmap' VALUES (7917, 14667, 1617, 10, 113);
INSERT INTO 'tunespublicationsmap' VALUES (7951, 14722, 1631, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7952, 2571, 1631, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (7955, 14247, 1632, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7956, 14735, 1632, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7957, 14736, 1632, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7958, 14737, 1632, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7959, 14246, 1632, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3646, 8481, 282, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3647, 8482, 282, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3648, 8483, 282, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7953, 14730, 1631, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (7954, 14719, 1631, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7972, 14720, 1631, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7960, 2829, 1639, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7961, 5837, 1639, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7962, 14755, 1639, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5962, 12098, 1107, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5963, 12101, 1107, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5964, 12105, 1107, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5966, 12108, 1107, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5967, 12116, 1107, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5969, 12126, 1107, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5970, 12131, 1107, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5971, 2957, 1107, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5972, 12139, 1107, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5973, 12143, 1107, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5974, 12144, 1107, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5975, 12146, 1107, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5976, 12150, 1107, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5977, 12152, 1107, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (5978, 12155, 1107, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5979, 12159, 1107, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7016, 1381, 155, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7017, 606, 155, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7018, 943, 155, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7934, 14551, 1625, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (7935, 14706, 1626, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7936, 14707, 1626, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7937, 14708, 1626, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7938, 14709, 1626, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7939, 14710, 1626, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7940, 14711, 1626, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (3721, 8602, 867, 10, 66);
INSERT INTO 'tunespublicationsmap' VALUES (3722, 2489, 867, 50, 66);
INSERT INTO 'tunespublicationsmap' VALUES (5750, 11722, 1089, 50, 1);
INSERT INTO 'tunespublicationsmap' VALUES (5751, 11723, 1089, 50, 2);
INSERT INTO 'tunespublicationsmap' VALUES (5752, 11724, 1089, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5753, 11725, 1089, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (5754, 11726, 1089, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5755, 11727, 1089, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5756, 11728, 1089, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5757, 11729, 1089, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5758, 11730, 1089, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5759, 11731, 1089, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (5760, 11732, 1089, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5761, 11733, 1089, 50, 12);
INSERT INTO 'tunespublicationsmap' VALUES (5762, 11734, 1089, 50, 13);
INSERT INTO 'tunespublicationsmap' VALUES (5763, 11735, 1089, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5764, 11736, 1089, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5765, 11737, 1089, 50, 16);
INSERT INTO 'tunespublicationsmap' VALUES (5766, 11738, 1089, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7963, 14756, 1639, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7964, 13593, 1639, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7965, 122, 1639, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7966, 12546, 1639, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7967, 2050, 1639, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7968, 14757, 1639, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (7971, 13002, 1639, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7970, 5600, 1639, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (7969, 14758, 1639, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (7941, 14712, 1631, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7942, 14723, 1631, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7943, 14727, 1631, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7944, 14716, 1631, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7945, 14726, 1631, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7946, 14734, 1631, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (7947, 14713, 1631, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7948, 14718, 1631, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7949, 14733, 1631, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (7950, 14724, 1631, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7992, 419, 1647, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7993, 700, 1647, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6495, 13167, 1265, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6496, 9246, 1265, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6497, 9244, 1265, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (6498, 13169, 1265, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (6499, 9242, 1265, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6500, 13174, 1265, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (6501, 9245, 1265, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (6502, 9247, 1265, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (6503, 13170, 1265, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (6504, 13171, 1265, 10, 45);
INSERT INTO 'tunespublicationsmap' VALUES (6505, 13172, 1265, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (6506, 9243, 1265, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (6507, 13173, 1265, 10, 59);
INSERT INTO 'tunespublicationsmap' VALUES (6508, 2846, 1265, 10, 64);
INSERT INTO 'tunespublicationsmap' VALUES (7933, 14684, 1440, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7497, 3691, 1579, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7973, 14764, 1640, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (7974, 9119, 1640, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7975, 14765, 1640, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7976, 14766, 1640, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (7977, 14767, 1640, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (7978, 14768, 1640, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (7979, 7191, 1640, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (7980, 14769, 1640, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (7981, 14770, 1640, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7982, 14782, 1640, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (7983, 14771, 1640, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (7984, 14772, 1640, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (7985, 14773, 1640, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (7986, 14774, 1640, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (7987, 14775, 1640, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7988, 14776, 1640, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (7989, 14777, 1640, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (7990, 14778, 1640, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (7991, 14779, 1640, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (7498, 11786, 1579, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (7499, 768, 1579, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (7994, 441, 1658, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7995, 84, 1658, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (7996, 702, 1658, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (7997, 9000, 1658, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (7998, 382, 1658, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (7022, 13846, 1427, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (55, 107, 778, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (56, 130, 778, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (57, 149, 778, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (58, 157, 778, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (59, 463, 778, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (60, 3244, 778, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (61, 3245, 778, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (62, 3246, 778, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (5547, 10572, 1041, 50, 3);
INSERT INTO 'tunespublicationsmap' VALUES (5548, 10578, 1041, 50, 5);
INSERT INTO 'tunespublicationsmap' VALUES (5549, 10583, 1041, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5550, 11557, 1041, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5551, 10588, 1041, 50, 11);
INSERT INTO 'tunespublicationsmap' VALUES (5552, 9267, 1041, 50, 14);
INSERT INTO 'tunespublicationsmap' VALUES (5553, 7628, 1041, 50, 15);
INSERT INTO 'tunespublicationsmap' VALUES (5554, 9317, 1041, 50, 17);
INSERT INTO 'tunespublicationsmap' VALUES (5555, 10580, 1041, 50, 19);
INSERT INTO 'tunespublicationsmap' VALUES (5556, 10586, 1041, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (5557, 9316, 1041, 50, 23);
INSERT INTO 'tunespublicationsmap' VALUES (5558, 10589, 1041, 50, 25);
INSERT INTO 'tunespublicationsmap' VALUES (5559, 10573, 1041, 50, 27);
INSERT INTO 'tunespublicationsmap' VALUES (5560, 2049, 1041, 50, 29);
INSERT INTO 'tunespublicationsmap' VALUES (5561, 2797, 1041, 50, 31);
INSERT INTO 'tunespublicationsmap' VALUES (5562, 2578, 1041, 50, 33);
INSERT INTO 'tunespublicationsmap' VALUES (5563, 5590, 1041, 50, 36);
INSERT INTO 'tunespublicationsmap' VALUES (5564, 7562, 1041, 50, 37);
INSERT INTO 'tunespublicationsmap' VALUES (6281, 12712, 1171, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (6282, 12713, 1171, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6283, 12714, 1171, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (6284, 12715, 1171, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (6285, 12716, 1171, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (6286, 12717, 1171, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6287, 12663, 1171, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (7999, 14857, 1661, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (8000, 14858, 1661, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (8001, 14859, 1661, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (8002, 14860, 1661, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (8003, 14861, 1661, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (8004, 14862, 1661, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (8052, 542, 46, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (8053, 1065, 46, 20, 2);
INSERT INTO 'tunespublicationsmap' VALUES (8054, 427, 46, 30, 3);
INSERT INTO 'tunespublicationsmap' VALUES (8055, 12733, 1325, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (8056, 13290, 1325, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (8057, 13307, 1325, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (8058, 13310, 1325, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (8059, 13311, 1325, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (8060, 5197, 1325, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (8061, 13312, 1325, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (8062, 13313, 1325, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (8063, 13314, 1325, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (8064, 13315, 1325, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (8065, 6411, 1325, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (8066, 13316, 1325, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (8067, 13317, 1325, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (8068, 10368, 1325, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (8069, 4358, 1325, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (8070, 13319, 1325, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (4986, 2523, 724, 50, 6);
INSERT INTO 'tunespublicationsmap' VALUES (4976, 4953, 724, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (4977, 2649, 724, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (4978, 9697, 724, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4979, 7317, 724, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (4980, 9698, 724, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (4981, 8842, 724, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (4982, 5852, 724, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (4983, 9699, 724, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (4984, 9700, 724, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (4985, 9701, 724, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (8072, 13, 1664, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (8071, 41, 1664, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2408, 3706, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3105, 445, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4595, 9569, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (4618, 2152, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2326, 5864, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2327, 4757, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2328, 2451, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2329, 56, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2330, 6167, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2331, 58, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2332, 5286, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2333, 1924, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2334, 1890, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2335, 4800, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2336, 92, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (8005, 14702, 1661, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (8006, 14704, 1661, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (8007, 14863, 1661, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (8008, 14864, 1661, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (8009, 13874, 1661, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (8010, 14865, 1661, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (8011, 14866, 1661, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (8012, 14867, 1661, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (8013, 13944, 1661, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (8014, 14868, 1661, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (8015, 13876, 1661, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (8016, 14869, 1661, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (2337, 103, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2338, 104, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2339, 106, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2340, 109, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2341, 137, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2342, 138, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2343, 2168, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2344, 143, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2345, 5545, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2346, 6278, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2347, 171, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2348, 176, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2349, 177, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2350, 178, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2351, 182, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2352, 183, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2353, 5517, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2354, 3486, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2355, 4005, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2356, 193, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2357, 3495, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2358, 202, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2359, 2111, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2360, 218, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2361, 1995, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2362, 3083, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2363, 228, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2364, 234, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2365, 4746, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2366, 4829, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2367, 4323, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2368, 4220, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2369, 3530, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2370, 255, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2371, 2022, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2372, 5377, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2373, 4652, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2374, 284, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2375, 295, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2376, 2054, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2377, 304, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2378, 308, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2379, 2730, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2380, 2173, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2381, 3358, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2382, 2344, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2383, 318, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2384, 5892, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2385, 1409, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2386, 341, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2387, 347, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2388, 2535, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2389, 6787, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2390, 355, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2391, 3251, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2392, 3932, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2393, 362, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2394, 363, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2395, 374, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2396, 382, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2397, 385, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2398, 388, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2399, 424, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2400, 5524, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2401, 4825, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2402, 447, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2403, 448, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2404, 452, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2405, 456, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2406, 463, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2407, 465, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2490, 2153, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2491, 2572, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2492, 482, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2493, 6041, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2494, 5068, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2495, 5654, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2496, 497, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2497, 515, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2498, 518, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2499, 3761, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2500, 5866, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2501, 2180, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2502, 6040, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2503, 534, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2504, 541, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2505, 3797, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2506, 551, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2507, 2196, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2508, 5369, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2509, 2200, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2510, 5346, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2511, 597, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2512, 598, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2513, 5107, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2514, 2219, 421, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (7387, 14388, 421, 10, 131);
INSERT INTO 'tunespublicationsmap' VALUES (8073, 14900, 421, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (8074, 470, 339, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (8075, 1790, 328, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (8076, 4218, 328, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (8077, 4182, 328, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (8078, 3919, 1665, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (8079, 724, 1665, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (8080, 2806, 1665, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (2023, 6446, 398, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (2021, 6447, 398, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (2004, 6448, 398, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (2016, 6449, 398, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (1995, 2788, 398, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (2019, 6450, 398, 10, 7);
INSERT INTO 'tunespublicationsmap' VALUES (2015, 6451, 398, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (2002, 6452, 398, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (2024, 6453, 398, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (2029, 6454, 398, 10, 11);
INSERT INTO 'tunespublicationsmap' VALUES (2025, 6455, 398, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (682, 2117, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (890, 4469, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (6067, 9645, 1130, 10, 8);
INSERT INTO 'tunespublicationsmap' VALUES (6069, 964, 1130, 10, 12);
INSERT INTO 'tunespublicationsmap' VALUES (6070, 806, 1130, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (6071, 1158, 1130, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (6072, 544, 1130, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (6073, 1364, 1130, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (6074, 9849, 1130, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (6075, 10053, 1130, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (6076, 10054, 1130, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (6077, 11157, 1130, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (6078, 11158, 1130, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (6079, 11168, 1130, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (6080, 10655, 1130, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (6081, 11172, 1130, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (1102, 653, 141, 10, 10);
INSERT INTO 'tunespublicationsmap' VALUES (985, 1486, 141, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (1035, 1217, 141, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (2641, 4478, 82, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2642, 3774, 82, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2643, 3775, 82, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2644, 4570, 82, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2645, 4030, 82, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2646, 2832, 82, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (2017, 6456, 398, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2013, 6457, 398, 10, 14);
INSERT INTO 'tunespublicationsmap' VALUES (2033, 6458, 398, 10, 15);
INSERT INTO 'tunespublicationsmap' VALUES (2018, 6459, 398, 10, 16);
INSERT INTO 'tunespublicationsmap' VALUES (1996, 2657, 398, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (1997, 2060, 398, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (2020, 6460, 398, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (2014, 6461, 398, 10, 20);
INSERT INTO 'tunespublicationsmap' VALUES (2008, 6462, 398, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (2022, 10129, 398, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (2011, 6464, 398, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (2003, 6465, 398, 10, 24);
INSERT INTO 'tunespublicationsmap' VALUES (2031, 6466, 398, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (1998, 5961, 398, 10, 26);
INSERT INTO 'tunespublicationsmap' VALUES (2005, 6467, 398, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (2027, 6468, 398, 10, 28);
INSERT INTO 'tunespublicationsmap' VALUES (1999, 5837, 398, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (2010, 6469, 398, 10, 30);
INSERT INTO 'tunespublicationsmap' VALUES (2000, 1933, 398, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (2012, 6470, 398, 10, 32);
INSERT INTO 'tunespublicationsmap' VALUES (2009, 6471, 398, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (2030, 6472, 398, 10, 34);
INSERT INTO 'tunespublicationsmap' VALUES (2001, 10864, 398, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (2007, 6473, 398, 10, 36);
INSERT INTO 'tunespublicationsmap' VALUES (2032, 6474, 398, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (2028, 6475, 398, 10, 38);
INSERT INTO 'tunespublicationsmap' VALUES (2006, 6476, 398, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (2026, 6477, 398, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (6206, 7588, 529, 1, 27);
INSERT INTO 'tunespublicationsmap' VALUES (6207, 12638, 529, 1, 28);
INSERT INTO 'tunespublicationsmap' VALUES (7136, 14105, 1515, 10, 13);
INSERT INTO 'tunespublicationsmap' VALUES (2691, 3520, 707, 50, 21);
INSERT INTO 'tunespublicationsmap' VALUES (2693, 5778, 707, 10, 22);
INSERT INTO 'tunespublicationsmap' VALUES (2692, 5779, 707, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (26, 2830, 801, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (27, 2832, 801, 50, 4);
INSERT INTO 'tunespublicationsmap' VALUES (6637, 13356, 261, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3653, 2379, 574, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (3654, 8487, 574, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (3655, 8488, 574, 10, 6);
INSERT INTO 'tunespublicationsmap' VALUES (5569, 8489, 574, 50, 7);
INSERT INTO 'tunespublicationsmap' VALUES (5570, 8490, 574, 50, 8);
INSERT INTO 'tunespublicationsmap' VALUES (5571, 8491, 574, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5573, 1964, 574, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (5572, 8492, 574, 50, 9);
INSERT INTO 'tunespublicationsmap' VALUES (6693, 8494, 574, 50, 10);
INSERT INTO 'tunespublicationsmap' VALUES (945, 986, 284, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (114, 299, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (199, 3394, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3545, 3668, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3546, 2138, 284, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3547, 432, 284, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3548, 121, 284, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3549, 1527, 284, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3550, 1037, 284, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3551, 2093, 284, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3552, 2492, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3553, 90, 284, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3554, 4698, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3555, 1619, 284, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3556, 1748, 284, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (556, 3199, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (610, 4019, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (622, 4029, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (623, 4033, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (683, 4101, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (684, 2935, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (774, 2012, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (829, 1391, 284, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (848, 2672, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (849, 3013, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (869, 1329, 284, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (986, 93, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (989, 1331, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1027, 4606, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3541, 1035, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3542, 4272, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3543, 1408, 284, 50, 0);
INSERT INTO 'tunespublicationsmap' VALUES (3544, 3987, 284, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (960, 445, 60, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (954, 408, 60, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (955, 232, 60, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (956, 190, 60, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (957, 1302, 60, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (958, 1177, 60, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (8081, 14976, 1667, 10, 1);
INSERT INTO 'tunespublicationsmap' VALUES (8082, 14977, 1667, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (8083, 14978, 1667, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (534, 3883, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (562, 3933, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (583, 3973, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (621, 4028, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (727, 4200, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1080, 4676, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (1107, 4701, 639, 10, 0);
INSERT INTO 'tunespublicationsmap' VALUES (8103, 8601, 1668, 10, 227);
INSERT INTO 'tunespublicationsmap' VALUES (8104, 4631, 1668, 10, 232);
INSERT INTO 'tunespublicationsmap' VALUES (8105, 4644, 1668, 10, 234);
INSERT INTO 'tunespublicationsmap' VALUES (8106, 4676, 1668, 10, 243);
INSERT INTO 'tunespublicationsmap' VALUES (8107, 4701, 1668, 10, 247);
INSERT INTO 'tunespublicationsmap' VALUES (4603, 9594, 977, 10, 9);
INSERT INTO 'tunespublicationsmap' VALUES (4604, 9595, 977, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (4605, 9596, 977, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (1251, 5708, 386, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (1252, 5709, 386, 10, 3);
INSERT INTO 'tunespublicationsmap' VALUES (1253, 5710, 386, 10, 4);
INSERT INTO 'tunespublicationsmap' VALUES (1254, 5711, 386, 10, 5);
INSERT INTO 'tunespublicationsmap' VALUES (8108, 12099, 1670, 10, 17);
INSERT INTO 'tunespublicationsmap' VALUES (8109, 14980, 1670, 10, 19);
INSERT INTO 'tunespublicationsmap' VALUES (8110, 14981, 1670, 10, 21);
INSERT INTO 'tunespublicationsmap' VALUES (8111, 14982, 1670, 10, 23);
INSERT INTO 'tunespublicationsmap' VALUES (8112, 10456, 1670, 10, 25);
INSERT INTO 'tunespublicationsmap' VALUES (8113, 14983, 1670, 10, 27);
INSERT INTO 'tunespublicationsmap' VALUES (8114, 14985, 1670, 10, 29);
INSERT INTO 'tunespublicationsmap' VALUES (8115, 2503, 1670, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (8116, 14986, 1670, 10, 31);
INSERT INTO 'tunespublicationsmap' VALUES (8117, 3077, 1670, 10, 33);
INSERT INTO 'tunespublicationsmap' VALUES (8118, 14987, 1670, 10, 35);
INSERT INTO 'tunespublicationsmap' VALUES (8119, 14988, 1670, 10, 37);
INSERT INTO 'tunespublicationsmap' VALUES (8120, 9300, 1670, 10, 39);
INSERT INTO 'tunespublicationsmap' VALUES (8121, 14989, 1670, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (8017, 14870, 1661, 10, 44);
INSERT INTO 'tunespublicationsmap' VALUES (8018, 14871, 1661, 10, 46);
INSERT INTO 'tunespublicationsmap' VALUES (8019, 13877, 1661, 10, 48);
INSERT INTO 'tunespublicationsmap' VALUES (8020, 14845, 1661, 10, 50);
INSERT INTO 'tunespublicationsmap' VALUES (8021, 14872, 1661, 10, 52);
INSERT INTO 'tunespublicationsmap' VALUES (8022, 14873, 1661, 10, 54);
INSERT INTO 'tunespublicationsmap' VALUES (8023, 14462, 1661, 10, 56);
INSERT INTO 'tunespublicationsmap' VALUES (8024, 14874, 1661, 10, 58);
INSERT INTO 'tunespublicationsmap' VALUES (8025, 14875, 1661, 10, 60);
INSERT INTO 'tunespublicationsmap' VALUES (8026, 14876, 1661, 10, 62);
INSERT INTO 'tunespublicationsmap' VALUES (8027, 14877, 1661, 10, 64);
INSERT INTO 'tunespublicationsmap' VALUES (8028, 14878, 1661, 10, 66);
INSERT INTO 'tunespublicationsmap' VALUES (8029, 14879, 1661, 10, 68);
INSERT INTO 'tunespublicationsmap' VALUES (8030, 14880, 1661, 10, 70);
INSERT INTO 'tunespublicationsmap' VALUES (8031, 14039, 1661, 10, 72);
INSERT INTO 'tunespublicationsmap' VALUES (8032, 14881, 1661, 10, 75);
INSERT INTO 'tunespublicationsmap' VALUES (8033, 14882, 1661, 10, 76);
INSERT INTO 'tunespublicationsmap' VALUES (8034, 14883, 1661, 10, 78);
INSERT INTO 'tunespublicationsmap' VALUES (8035, 14884, 1661, 10, 80);
INSERT INTO 'tunespublicationsmap' VALUES (8036, 14529, 1661, 10, 82);
INSERT INTO 'tunespublicationsmap' VALUES (8037, 14885, 1661, 10, 84);
INSERT INTO 'tunespublicationsmap' VALUES (8038, 14886, 1661, 10, 86);
INSERT INTO 'tunespublicationsmap' VALUES (8039, 14887, 1661, 10, 88);
INSERT INTO 'tunespublicationsmap' VALUES (8040, 14888, 1661, 10, 90);
INSERT INTO 'tunespublicationsmap' VALUES (8041, 14543, 1661, 10, 92);
INSERT INTO 'tunespublicationsmap' VALUES (8042, 14889, 1661, 10, 94);
INSERT INTO 'tunespublicationsmap' VALUES (8043, 14890, 1661, 10, 96);
INSERT INTO 'tunespublicationsmap' VALUES (8044, 14891, 1661, 10, 99);
INSERT INTO 'tunespublicationsmap' VALUES (8045, 14892, 1661, 10, 101);
INSERT INTO 'tunespublicationsmap' VALUES (8046, 13968, 1661, 10, 103);
INSERT INTO 'tunespublicationsmap' VALUES (8047, 14893, 1661, 10, 106);
INSERT INTO 'tunespublicationsmap' VALUES (8048, 2222, 1661, 10, 108);
INSERT INTO 'tunespublicationsmap' VALUES (8049, 13887, 1661, 10, 110);
INSERT INTO 'tunespublicationsmap' VALUES (8084, 3317, 1668, 10, 2);
INSERT INTO 'tunespublicationsmap' VALUES (8085, 3407, 1668, 10, 18);
INSERT INTO 'tunespublicationsmap' VALUES (8086, 3526, 1668, 10, 40);
INSERT INTO 'tunespublicationsmap' VALUES (8087, 3529, 1668, 10, 41);
INSERT INTO 'tunespublicationsmap' VALUES (8088, 3532, 1668, 10, 42);
INSERT INTO 'tunespublicationsmap' VALUES (8089, 3698, 1668, 10, 61);
INSERT INTO 'tunespublicationsmap' VALUES (8090, 3191, 1668, 10, 93);
INSERT INTO 'tunespublicationsmap' VALUES (8091, 638, 1668, 10, 95);
INSERT INTO 'tunespublicationsmap' VALUES (8092, 3883, 1668, 10, 97);
INSERT INTO 'tunespublicationsmap' VALUES (8093, 3934, 1668, 10, 109);
INSERT INTO 'tunespublicationsmap' VALUES (8094, 3933, 1668, 10, 110);
INSERT INTO 'tunespublicationsmap' VALUES (8095, 3973, 1668, 10, 119);
INSERT INTO 'tunespublicationsmap' VALUES (8096, 4028, 1668, 10, 135);
INSERT INTO 'tunespublicationsmap' VALUES (8097, 4053, 1668, 10, 140);
INSERT INTO 'tunespublicationsmap' VALUES (8098, 4056, 1668, 10, 142);
INSERT INTO 'tunespublicationsmap' VALUES (8099, 4200, 1668, 10, 165);
INSERT INTO 'tunespublicationsmap' VALUES (8100, 4275, 1668, 10, 199);
INSERT INTO 'tunespublicationsmap' VALUES (8101, 4518, 1668, 10, 203);
INSERT INTO 'tunespublicationsmap' VALUES (8102, 4593, 1668, 10, 224);
INSERT INTO 'tunespublicationsmap' VALUES (8050, 14894, 1661, 10, 112);
INSERT INTO 'tunespublicationsmap' VALUES (8051, 13875, 1661, 10, 114);


--
INSERT INTO 'tunesrecordingsmap' VALUES (1, 448, NULL, 72, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2, 2774, NULL, 72, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3, 2986, NULL, 72, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4, 2751, NULL, 72, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5, 2696, NULL, 168, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6, 283, NULL, 50, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7, 2037, NULL, 50, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8, 146, NULL, 50, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9, 760, NULL, 50, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10, 654, NULL, 117, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11, 2017, NULL, 117, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12, 2694, NULL, 117, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13, 834, NULL, 117, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14, 1593, NULL, 290, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15, 2031, NULL, 290, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16, 2101, NULL, 290, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17, 2436, NULL, 290, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18, 534, NULL, 88, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19, 1424, NULL, 88, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20, 1179, NULL, 88, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21, 1655, NULL, 88, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25, 2703, NULL, 350, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26, 790, NULL, 350, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27, 2818, NULL, 350, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28, 1741, NULL, 345, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29, 2940, NULL, 345, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30, 2945, NULL, 345, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31, 588, NULL, 106, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32, 806, NULL, 106, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33, 773, NULL, 106, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34, 1208, NULL, 106, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (35, 926, NULL, 157, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (36, 1410, NULL, 157, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (37, 2622, NULL, 157, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (38, 2431, NULL, 157, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (43, 876, NULL, 149, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (44, 1483, NULL, 149, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (45, 544, NULL, 149, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (46, 2106, NULL, 90, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (47, 1939, NULL, 90, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (48, 1513, NULL, 90, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (49, 123, NULL, 59, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (50, 1962, NULL, 59, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (51, 2055, NULL, 113, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (52, 2520, NULL, 113, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (53, 664, NULL, 113, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (54, 2505, NULL, 113, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (55, 1043, NULL, 186, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (56, 2811, NULL, 186, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (57, 2127, NULL, 186, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (58, 2630, NULL, 186, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (59, 1672, NULL, 103, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (60, 2202, NULL, 103, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (61, 1022, NULL, 103, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (62, 155, NULL, 103, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18851, 7538, NULL, 142, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18850, 9516, NULL, 142, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18848, 9483, NULL, 142, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18849, 7537, NULL, 142, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (67, 989, NULL, 250, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (68, 2489, NULL, 250, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (69, 1707, NULL, 250, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (70, 1219, NULL, 215, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (71, 2759, NULL, 215, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (72, 1987, NULL, 215, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (73, 1917, NULL, 215, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (74, 223, NULL, 41, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (75, 2667, NULL, 41, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (76, 807, NULL, 41, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (77, 2620, NULL, 41, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (78, 2920, NULL, 339, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (79, 2729, NULL, 339, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (80, 920, NULL, 339, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (81, 2118, NULL, 339, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (82, 1041, NULL, 181, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (83, 2241, NULL, 181, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (84, 2063, NULL, 181, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (85, 1911, NULL, 181, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (86, 430, NULL, 267, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (87, 1849, NULL, 267, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (88, 1866, NULL, 267, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (89, 2307, NULL, 267, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (90, 1163, NULL, 28, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (91, 177, NULL, 28, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (92, 951, NULL, 28, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14132, 955, NULL, 4610, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14133, 121, NULL, 4611, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14134, 306, NULL, 4611, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14135, 5387, NULL, 4751, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14136, 1700, NULL, 4752, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14137, 2396, NULL, 4752, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14138, 724, NULL, 4752, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14139, 382, NULL, 4753, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14140, 4085, NULL, 4753, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14141, 1091, NULL, 4753, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14142, 1012, NULL, 4754, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14143, 3093, NULL, 4754, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14144, 5174, NULL, 4755, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19337, 31, NULL, 6086, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19338, 8215, NULL, 6086, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19339, 2550, NULL, 6086, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19340, 807, NULL, 6087, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19341, 9660, NULL, 6087, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19342, 3371, NULL, 6087, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19343, 2858, NULL, 6087, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19344, 781, NULL, 6088, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19345, 73, NULL, 6089, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19346, 63, NULL, 6089, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19347, 5036, NULL, 6089, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19348, 6, NULL, 6089, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19352, 156, NULL, 6091, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19353, 9663, NULL, 6092, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19356, 313, NULL, 6093, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19357, 7276, NULL, 6093, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19358, 4892, NULL, 6093, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19359, 4839, NULL, 6093, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19360, 4057, NULL, 6094, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19361, 9664, NULL, 6094, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19362, 942, NULL, 6094, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19363, 916, NULL, 6095, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19364, 9665, NULL, 6095, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19365, 5436, NULL, 6095, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19366, 9666, NULL, 6095, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19367, 55, NULL, 6096, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19368, 4183, NULL, 6096, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19369, 5368, NULL, 6096, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19370, 2231, NULL, 6096, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19371, 382, NULL, 6097, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28393, 534, NULL, 8847, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28394, 1629, NULL, 8847, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28395, 835, NULL, 8847, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28396, 955, NULL, 8847, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28411, 269, NULL, 1731, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28412, 188, NULL, 1731, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28413, 2945, NULL, 1731, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28435, 1401, NULL, 8852, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28436, 1328, NULL, 8852, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28437, 914, NULL, 8852, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (93, 2534, NULL, 28, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (94, 2289, NULL, 152, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (95, 664, NULL, 152, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (96, 382, NULL, 61, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (97, 1452, NULL, 61, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (98, 1447, NULL, 61, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (99, 2236, NULL, 61, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (100, 1021, NULL, 136, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (101, 2666, NULL, 136, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (102, 1140, NULL, 136, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (103, 109, NULL, 136, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (104, 1111, NULL, 202, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (105, 1153, NULL, 202, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (106, 2197, NULL, 202, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (107, 2770, NULL, 202, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (108, 1290, NULL, 224, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (109, 2399, NULL, 224, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (110, 150, NULL, 224, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (111, 964, NULL, 353, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (112, 299, NULL, 353, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (113, 2418, NULL, 353, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (114, 586, NULL, 353, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (115, 2520, NULL, 353, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (116, 1562, NULL, 353, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (117, 1880, NULL, 353, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (118, 704, NULL, 177, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (119, 2403, NULL, 177, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (120, 882, NULL, 177, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (121, 2944, NULL, 177, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (122, 2609, NULL, 39, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (123, 2419, NULL, 39, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (124, 1295, NULL, 39, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (125, 2427, NULL, 39, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (126, 1293, NULL, 278, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (127, 2845, NULL, 278, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23, 2042, NULL, 337, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24, 652, NULL, 337, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22, 2970, NULL, 337, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (128, 1195, NULL, 148, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (129, 2326, NULL, 148, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (130, 2437, NULL, 148, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (134, 2411, NULL, 114, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (135, 90, NULL, 114, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (136, 894, NULL, 85, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (137, 2495, NULL, 85, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (138, 2654, NULL, 85, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (139, 2424, NULL, 85, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (140, 173, NULL, 53, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (141, 2857, NULL, 53, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (142, 2898, NULL, 53, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (143, 2079, NULL, 53, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (144, 247, NULL, 64, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (145, 2027, NULL, 64, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (146, 2023, NULL, 64, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (147, 2336, NULL, 64, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (148, 1474, NULL, 193, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (149, 403, NULL, 193, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (150, 1707, NULL, 193, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (151, 68, NULL, 193, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (152, 1719, NULL, 257, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (153, 1778, NULL, 257, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (154, 2038, NULL, 257, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (155, 312, NULL, 257, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (156, 759, NULL, 355, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (157, 425, NULL, 355, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (158, 1853, NULL, 355, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (159, 2336, NULL, 355, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (160, 698, NULL, 9, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (161, 2751, NULL, 9, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (162, 599, NULL, 9, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (163, 669, NULL, 234, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (164, 2263, NULL, 234, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (165, 568, NULL, 104, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (166, 2436, NULL, 104, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (167, 2909, NULL, 104, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (168, 631, NULL, 112, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (169, 2597, NULL, 112, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (170, 1068, NULL, 112, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (171, 2279, NULL, 52, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (172, 914, NULL, 52, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (173, 2773, NULL, 52, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (174, 2386, NULL, 52, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (175, 390, NULL, 184, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (176, 2895, NULL, 184, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (177, 625, NULL, 184, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (182, 815, NULL, 139, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (183, 1600, NULL, 139, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (184, 1923, NULL, 139, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (185, 2641, NULL, 139, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14049, 6806, NULL, 4649, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14050, 1318, NULL, 4650, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14051, 6402, NULL, 4650, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14052, 2339, NULL, 4650, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14053, 853, NULL, 4650, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14054, 1173, NULL, 4651, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14055, 1585, NULL, 4651, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14056, 1400, NULL, 4651, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14057, 2369, NULL, 4651, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14058, 68, NULL, 4651, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14059, 1456, NULL, 4651, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14060, 17, NULL, 4651, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (14061, 2992, NULL, 4652, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14062, 2993, NULL, 4652, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14063, 2950, NULL, 4652, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14064, 2952, NULL, 4652, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14065, 2804, NULL, 4653, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14066, 1857, NULL, 4653, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14067, 952, NULL, 4653, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14068, 816, NULL, 4653, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14069, 2482, NULL, 4653, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14070, 1351, NULL, 4654, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14071, 803, NULL, 4654, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14072, 1880, NULL, 4654, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14073, 3026, NULL, 4654, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14074, 2039, NULL, 4655, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14075, 6963, NULL, 4655, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14076, 1732, NULL, 4655, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14077, 312, NULL, 4655, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14078, 1041, NULL, 4684, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14079, 5599, NULL, 4684, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14080, 5390, NULL, 4684, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14081, 7307, NULL, 4684, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14082, 1567, NULL, 4685, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14083, 816, NULL, 4685, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14084, 7308, NULL, 4685, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14085, 7309, NULL, 4685, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14086, 179, NULL, 4686, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14087, 3179, NULL, 4686, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14088, 2262, NULL, 4686, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14089, 5825, NULL, 4686, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14090, 61, NULL, 4687, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28397, 4260, NULL, 8848, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28398, 4323, NULL, 8848, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28399, 3512, NULL, 8848, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28400, 1852, NULL, 8848, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28414, 502, NULL, 1731, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28415, 1659, NULL, 1731, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28416, 1778, NULL, 1731, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (28438, 3195, NULL, 8853, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28439, 1238, NULL, 8853, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28440, 452, NULL, 8853, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (189, 2706, NULL, 228, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (190, 625, NULL, 228, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (191, 2396, NULL, 228, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (192, 271, NULL, 105, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (193, 951, NULL, 105, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (194, 2544, NULL, 105, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (195, 913, NULL, 105, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (196, 2678, NULL, 188, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (197, 2440, NULL, 188, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (198, 2486, NULL, 188, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (199, 1414, NULL, 333, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (204, 186, NULL, 32, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (205, 952, NULL, 32, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (206, 2238, NULL, 32, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (207, 1933, NULL, 32, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (208, 1096, NULL, 38, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (209, 267, NULL, 38, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (210, 1624, NULL, 38, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (211, 553, NULL, 38, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (212, 2353, NULL, 289, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (213, 2227, NULL, 289, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (214, 1865, NULL, 289, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (215, 2228, NULL, 289, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (216, 233, NULL, 49, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (217, 2853, NULL, 49, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (218, 2252, NULL, 49, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (223, 1603, NULL, 315, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (224, 2163, NULL, 315, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (225, 2356, NULL, 315, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (226, 2592, NULL, 315, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (227, 2638, NULL, 217, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (228, 2189, NULL, 217, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (229, 1232, NULL, 217, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (230, 2813, NULL, 217, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (231, 2035, NULL, 326, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (232, 1086, NULL, 326, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (233, 809, NULL, 326, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (234, 2846, NULL, 312, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (235, 787, NULL, 312, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (236, 2702, NULL, 312, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (237, 398, NULL, 312, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (238, 2100, NULL, 140, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (239, 2072, NULL, 140, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (244, 736, NULL, 361, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (245, 1929, NULL, 361, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (246, 1645, NULL, 361, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (247, 614, NULL, 334, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (248, 377, NULL, 281, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (249, 2863, NULL, 281, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (250, 2603, NULL, 281, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (251, 1670, NULL, 273, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (252, 1416, NULL, 56, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (253, 2398, NULL, 56, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (254, 2826, NULL, 56, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (255, 1992, NULL, 37, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (256, 2011, NULL, 37, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (257, 1928, NULL, 37, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (258, 1179, NULL, 79, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (259, 2558, NULL, 79, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (260, 2951, NULL, 79, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (261, 2991, NULL, 79, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (262, 1624, NULL, 180, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (263, 663, NULL, 180, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (264, 2544, NULL, 180, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (269, 1170, NULL, 258, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (270, 2077, NULL, 258, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (271, 620, NULL, 258, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (272, 1830, NULL, 251, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (273, 1644, NULL, 251, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (274, 2504, NULL, 251, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (275, 2973, NULL, 127, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (276, 2650, NULL, 127, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (201, 2010, NULL, 336, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (202, 2171, NULL, 336, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (203, 10864, NULL, 336, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (200, 2862, NULL, 336, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (243, 2105, NULL, 323, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (240, 2113, NULL, 323, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (242, 2199, NULL, 323, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (188, 1985, NULL, 207, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (187, 2180, NULL, 207, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (186, 580, NULL, 207, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (277, 1448, NULL, 247, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14145, 350, NULL, 4756, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14146, 219, NULL, 4756, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14147, 106, NULL, 4756, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14148, 5123, NULL, 4757, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14149, 5371, NULL, 4757, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14150, 7321, NULL, 4757, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14151, 2703, NULL, 4757, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14152, 1838, NULL, 4759, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14153, 6266, NULL, 4759, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14154, 5118, NULL, 4759, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14155, 2920, NULL, 4759, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14156, 295, NULL, 4760, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14157, 2519, NULL, 4760, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14158, 7322, NULL, 4761, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14159, 4670, NULL, 4761, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14160, 6110, NULL, 4761, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14161, 152, NULL, 4762, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14162, 1535, NULL, 4762, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14163, 790, NULL, 4763, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14164, 7276, NULL, 4763, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14165, 6897, NULL, 4763, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14166, 4839, NULL, 4763, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14167, 430, NULL, 4765, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14168, 6101, NULL, 4765, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14169, 7324, NULL, 4766, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14170, 7325, NULL, 4766, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14171, 6180, NULL, 4766, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14172, 1779, NULL, 4766, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14173, 5499, NULL, 4766, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14174, 1329, NULL, 4767, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14175, 1503, NULL, 4767, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14176, 1553, NULL, 4767, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14177, 1374, NULL, 4767, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14178, 835, NULL, 4767, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14179, 687, NULL, 4767, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14180, 430, NULL, 4767, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14181, 2910, NULL, 4767, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (14182, 685, NULL, 4767, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (14183, 4018, NULL, 4768, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14184, 4971, NULL, 4768, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14185, 2719, NULL, 4768, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14186, 4987, NULL, 4768, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28401, 512, NULL, 8849, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28402, 5263, NULL, 8849, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28403, 408, NULL, 8849, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28404, 1112, NULL, 8849, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28417, 1026, NULL, 1731, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (28418, 1329, NULL, 1731, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (28441, 1295, NULL, 8854, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28442, 1126, NULL, 8854, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28443, 916, NULL, 8854, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (278, 688, NULL, 247, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (279, 2752, NULL, 247, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (280, 2492, NULL, 247, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (281, 1158, NULL, 247, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (282, 2356, NULL, 247, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (283, 2922, NULL, 247, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (284, 952, NULL, 247, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (285, 476, NULL, 331, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (286, 2054, NULL, 54, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (287, 2301, NULL, 54, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18847, 9515, NULL, 142, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (289, 2605, NULL, 54, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (290, 320, NULL, 248, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (291, 2159, NULL, 248, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (292, 1687, NULL, 248, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (293, 398, NULL, 248, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (294, 2088, NULL, 342, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (295, 2573, NULL, 342, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (296, 2969, NULL, 342, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (297, 2549, NULL, 342, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (299, 269, NULL, 48, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (300, 1386, NULL, 48, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (301, 2442, NULL, 48, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (302, 188, NULL, 48, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (303, 773, NULL, 48, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (304, 955, NULL, 48, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (305, 1899, NULL, 48, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (306, 378, NULL, 48, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (307, 2149, NULL, 268, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (308, 3002, NULL, 364, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (309, 2031, NULL, 364, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (310, 2669, NULL, 364, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (311, 128, NULL, 22, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (312, 1655, NULL, 22, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (313, 2890, NULL, 22, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (314, 1821, NULL, 22, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (315, 80, NULL, 13, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (316, 2546, NULL, 13, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (317, 1874, NULL, 13, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (318, 2347, NULL, 13, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (319, 1937, NULL, 20, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (320, 2625, NULL, 20, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (321, 168, NULL, 20, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (322, 2278, NULL, 20, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (323, 1031, NULL, 20, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (324, 958, NULL, 260, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (325, 756, NULL, 260, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (326, 2828, NULL, 260, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (327, 2789, NULL, 260, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (332, 1721, NULL, 36, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (333, 188, NULL, 36, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (334, 1629, NULL, 36, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (335, 1424, NULL, 36, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (336, 1091, NULL, 36, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (337, 2774, NULL, 36, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (338, 502, NULL, 36, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (339, 1655, NULL, 36, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (340, 309, NULL, 208, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (341, 2758, NULL, 208, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (342, 2294, NULL, 208, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (343, 2191, NULL, 208, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (344, 431, NULL, 69, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (345, 1578, NULL, 69, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (346, 2834, NULL, 69, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (347, 333, NULL, 69, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (348, 601, NULL, 25, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (353, 2144, NULL, 287, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (354, 2807, NULL, 287, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (355, 2469, NULL, 287, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (356, 2859, NULL, 287, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (357, 819, NULL, 236, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (358, 2597, NULL, 222, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (359, 2416, NULL, 222, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (360, 2526, NULL, 222, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (361, 2153, NULL, 58, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (362, 2534, NULL, 58, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (363, 1890, NULL, 58, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (364, 1311, NULL, 58, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (365, 669, NULL, 241, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (366, 297, NULL, 241, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (367, 1921, NULL, 16, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (368, 1628, NULL, 16, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (369, 2097, NULL, 16, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (370, 1415, NULL, 16, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14091, 7310, NULL, 4687, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14092, 7177, NULL, 4687, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14093, 4614, NULL, 4687, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14094, 1051, NULL, 4688, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14095, 1315, NULL, 4688, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14096, 7312, NULL, 4688, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14097, 4828, NULL, 4688, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (328, 31, NULL, 6, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14103, 960, NULL, 4691, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14104, 7314, NULL, 4691, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14105, 5923, NULL, 4691, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14106, 5924, NULL, 4691, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14111, 1144, NULL, 4693, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14112, 5909, NULL, 4693, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14113, 2213, NULL, 4693, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14114, 2116, NULL, 4693, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (288, 1648, 475, 54, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (298, 388, NULL, 62, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (330, 2219, NULL, 6, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (331, 2397, NULL, 6, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14115, 31, NULL, 4694, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14116, 7316, NULL, 4694, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14117, 7317, NULL, 4694, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14118, 7318, NULL, 4694, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14119, 1590, NULL, 4695, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14120, 2224, NULL, 4695, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14121, 1433, NULL, 4695, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14122, 7319, NULL, 4695, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14098, 1414, NULL, 4689, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (265, 435, NULL, 151, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (267, 2142, NULL, 151, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (268, 2876, NULL, 151, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14123, 435, NULL, 4696, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14124, 914, NULL, 4696, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14125, 133, NULL, 4696, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14126, 433, NULL, 4696, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14127, 1406, NULL, 4696, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14128, 841, NULL, 4696, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14129, 613, NULL, 4696, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14130, 1374, NULL, 4610, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14131, 232, NULL, 4610, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14187, 2001, NULL, 4768, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14188, 6081, NULL, 4769, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28405, 1624, NULL, 8850, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28406, 2559, NULL, 8850, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28419, 720, NULL, 1734, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28420, 1376, NULL, 1734, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28421, 2259, NULL, 1734, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28444, 3568, NULL, 8854, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28445, 1943, NULL, 8854, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28446, 4835, NULL, 8854, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (371, 403, NULL, 5, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (372, 2443, NULL, 5, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (373, 867, NULL, 5, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (374, 2218, NULL, 5, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (375, 14, NULL, 4, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (376, 1914, NULL, 4, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (377, 1918, NULL, 4, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (378, 1687, NULL, 4, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (379, 1368, NULL, 211, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (388, 34, NULL, 7, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (389, 586, NULL, 7, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (390, 1850, NULL, 7, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (391, 2538, NULL, 7, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (392, 1238, NULL, 7, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (393, 2737, NULL, 7, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (394, 2588, NULL, 238, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (395, 2676, NULL, 238, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (396, 791, NULL, 283, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (397, 2514, NULL, 283, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (398, 2040, NULL, 283, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (399, 2473, NULL, 283, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (400, 2119, NULL, 283, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (401, 2231, NULL, 283, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (402, 2512, NULL, 283, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (403, 1861, NULL, 283, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (404, 2045, NULL, 261, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (405, 355, NULL, 261, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (406, 2017, NULL, 261, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (407, 1952, NULL, 255, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (408, 2945, NULL, 255, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (409, 408, NULL, 178, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (410, 1656, NULL, 271, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (411, 2441, NULL, 271, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (412, 2293, NULL, 271, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (413, 1839, NULL, 368, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (414, 1561, NULL, 368, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (415, 2521, NULL, 368, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (416, 2798, NULL, 344, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (417, 2803, NULL, 344, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (418, 2230, NULL, 344, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (419, 610, NULL, 109, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (420, 1917, NULL, 109, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (421, 1739, NULL, 109, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (426, 2158, NULL, 324, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (427, 2229, NULL, 324, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (428, 2745, NULL, 324, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (429, 1631, NULL, 324, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18868, 9524, NULL, 5950, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18870, 2138, NULL, 5951, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18879, 1748, NULL, 5953, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (433, 1814, NULL, 1, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (434, 2877, NULL, 1, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (435, 1821, NULL, 1, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (436, 1238, NULL, 55, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (437, 2601, NULL, 55, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (438, 256, NULL, 55, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (439, 649, NULL, 55, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (443, 806, NULL, 137, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (444, 2179, NULL, 137, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (445, 2683, NULL, 137, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (446, 1729, NULL, 137, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (447, 2677, NULL, 137, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (448, 1870, NULL, 137, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (449, 2587, NULL, 137, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (450, 1360, NULL, 229, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (451, 2031, NULL, 229, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (452, 62, NULL, 229, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (453, 652, NULL, 229, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (454, 1103, NULL, 199, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (455, 1423, NULL, 199, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (456, 1611, NULL, 199, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (457, 770, NULL, 199, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (458, 189, NULL, 354, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (459, 2742, NULL, 354, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (460, 2330, NULL, 354, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (461, 1158, NULL, 256, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (462, 1912, NULL, 256, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14189, 5672, NULL, 4769, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14190, 939, NULL, 4770, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14191, 2696, NULL, 4770, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14192, 1665, NULL, 4770, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14193, 1919, NULL, 4770, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14194, 98, NULL, 4771, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14195, 2882, NULL, 4771, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14196, 7326, NULL, 4771, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14197, 1586, NULL, 4771, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14198, 601, NULL, 4772, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14199, 6203, NULL, 4772, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14200, 5381, NULL, 4772, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14201, 1528, NULL, 4772, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14202, 295, NULL, 4772, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14203, 510, NULL, 4772, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14204, 374, NULL, 4773, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14205, 77, NULL, 4773, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14206, 7327, NULL, 4773, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14207, 7328, NULL, 4773, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14208, 7329, NULL, 4773, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14209, 7330, NULL, 4774, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14210, 5066, NULL, 4774, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14211, 2465, NULL, 4774, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14212, 7331, NULL, 4774, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14213, 183, NULL, 4775, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14214, 7332, NULL, 4775, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14215, 2106, NULL, 4775, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14216, 1431, NULL, 4775, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14217, 2055, NULL, 4776, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14218, 2411, NULL, 4776, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14219, 697, NULL, 4776, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14220, 713, NULL, 4776, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14221, 2304, NULL, 4777, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14222, 2724, NULL, 4777, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14223, 2998, NULL, 4777, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14224, 7333, NULL, 4778, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14225, 691, NULL, 4778, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14226, 5000, NULL, 4778, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14227, 1525, NULL, 4778, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14228, 6322, NULL, 4779, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14229, 3477, NULL, 4779, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14230, 5055, NULL, 4779, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28407, 1621, NULL, 8851, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28408, 8027, NULL, 8851, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28409, 497, NULL, 8851, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28410, 685, NULL, 8851, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28422, 4348, NULL, 1735, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28423, 2626, NULL, 1735, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28424, 11937, NULL, 1735, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28447, 382, NULL, 8855, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28448, 1503, NULL, 8855, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28449, 19, NULL, 8855, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (463, 2637, NULL, 256, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (464, 2291, NULL, 256, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (465, 1257, NULL, 221, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (466, 2710, NULL, 221, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (467, 2414, NULL, 221, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (468, 2631, NULL, 221, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (469, 2533, NULL, 221, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (470, 2266, NULL, 221, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (471, 2017, NULL, 221, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (472, 2321, NULL, 221, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (473, 1781, NULL, 175, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (474, 320, NULL, 175, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (475, 398, NULL, 175, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (476, 890, NULL, 319, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (423, 951, NULL, 317, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (424, 2531, NULL, 317, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (425, 2780, NULL, 317, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (383, 544, NULL, 226, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (387, 660, NULL, 226, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (381, 1226, NULL, 226, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (380, 1319, NULL, 226, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (485, 749, NULL, 130, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (486, 1536, NULL, 130, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (487, 2724, NULL, 130, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (488, 2382, NULL, 130, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (489, 2842, NULL, 130, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (490, 2409, NULL, 130, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (491, 2311, NULL, 130, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (492, 2169, NULL, 130, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (493, 2884, NULL, 108, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (494, 2926, NULL, 108, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (495, 2814, NULL, 108, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (496, 2343, NULL, 108, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (501, 1113, NULL, 203, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (502, 2406, NULL, 203, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (503, 2026, NULL, 203, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (504, 2972, NULL, 203, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (505, 2041, NULL, 203, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (506, 1059, NULL, 187, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (508, 1485, NULL, 187, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (509, 1756, NULL, 187, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (510, 2467, NULL, 187, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (511, 98, NULL, 187, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (512, 906, NULL, 155, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (513, 2597, NULL, 155, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (514, 699, NULL, 155, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (515, 2299, NULL, 155, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (520, 949, NULL, 161, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (521, 2568, NULL, 161, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (522, 2181, NULL, 161, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (523, 1122, NULL, 161, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (524, 2976, NULL, 362, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (525, 792, NULL, 362, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (526, 2036, NULL, 362, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (527, 2191, NULL, 362, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (528, 2022, NULL, 46, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (529, 2646, NULL, 46, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (530, 2318, NULL, 46, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (531, 2872, NULL, 46, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (539, 880, NULL, 150, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (540, 1920, NULL, 150, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (541, 2698, NULL, 150, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (542, 2621, NULL, 150, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (547, 2648, NULL, 214, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (548, 2524, NULL, 214, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (549, 799, NULL, 214, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (550, 2385, NULL, 154, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (551, 2775, NULL, 154, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (552, 2433, NULL, 154, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (553, 971, NULL, 154, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (558, 91, NULL, 14, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (559, 2716, NULL, 14, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (560, 2653, NULL, 14, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (561, 2415, NULL, 14, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (562, 2994, NULL, 366, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (563, 2848, NULL, 366, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (564, 2989, NULL, 366, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (565, 2732, NULL, 366, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (566, 2523, NULL, 34, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (567, 2867, NULL, 34, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (568, 1031, NULL, 34, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (569, 2116, NULL, 34, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (570, 743, NULL, 128, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (571, 566, NULL, 128, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (572, 2649, NULL, 128, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14231, 6777, NULL, 4779, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14232, 2786, NULL, 4780, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14233, 2063, NULL, 4780, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14234, 4381, NULL, 4780, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14235, 7334, NULL, 4781, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14236, 430, NULL, 4782, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14237, 857, NULL, 4782, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14238, 687, NULL, 4782, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14239, 297, NULL, 4782, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14240, 6607, NULL, 4783, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14241, 4740, NULL, 4783, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14242, 6901, NULL, 4783, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14243, 4101, NULL, 4784, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14244, 4104, NULL, 4784, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14245, 7335, NULL, 4784, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14246, 1997, NULL, 4785, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14247, 2442, NULL, 4785, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14248, 39, NULL, 4785, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14249, 19, NULL, 4785, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14250, 6337, NULL, 4786, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14251, 7336, NULL, 4786, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14252, 132, NULL, 4787, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14253, 295, NULL, 4788, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14254, 7337, NULL, 4788, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14255, 7338, NULL, 4788, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14256, 5583, NULL, 4789, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14257, 1101, NULL, 4789, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14258, 186, NULL, 4789, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14259, 2870, NULL, 4790, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14260, 2118, NULL, 4790, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14261, 4616, NULL, 4790, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14262, 1772, NULL, 4791, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14263, 7339, NULL, 4791, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28425, 239, NULL, 1732, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28426, 12040, NULL, 1732, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28450, 1329, NULL, 8855, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28451, 497, NULL, 8855, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (573, 2257, NULL, 128, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (574, 2779, NULL, 91, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (575, 2388, NULL, 91, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (576, 2086, NULL, 91, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (577, 1853, NULL, 91, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (582, 1135, NULL, 286, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (583, 1456, NULL, 286, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (584, 492, NULL, 147, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (585, 2476, NULL, 147, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (586, 2887, NULL, 147, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (587, 2101, NULL, 147, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (602, 490, NULL, 82, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (603, 2570, NULL, 82, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (604, 1863, NULL, 82, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (605, 2712, NULL, 82, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (606, 2475, NULL, 293, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (607, 2901, NULL, 293, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (608, 2283, NULL, 293, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (609, 152, NULL, 318, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (610, 1164, NULL, 318, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (611, 326, NULL, 318, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (612, 2614, NULL, 318, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (617, 2791, NULL, 17, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (618, 2206, NULL, 17, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (619, 2597, NULL, 166, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (620, 1906, NULL, 166, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (621, 2642, NULL, 166, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (622, 685, NULL, 268, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (623, 19, NULL, 268, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (624, 171, NULL, 303, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (625, 2831, NULL, 303, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (594, 78, NULL, 83, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (592, 2170, NULL, 83, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (588, 2087, NULL, 116, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (589, 2162, NULL, 116, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (590, 2345, NULL, 116, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (591, 2971, NULL, 116, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (578, 2019, NULL, 45, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (581, 2331, NULL, 45, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (580, 2493, NULL, 45, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (499, 2362, NULL, 363, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (500, 2580, NULL, 363, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (498, 2956, NULL, 363, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (497, 1813, NULL, 363, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (546, 2349, NULL, 21, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (544, 2522, NULL, 21, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (543, 8177, NULL, 21, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (545, 2939, NULL, 21, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (626, 2774, NULL, 303, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (627, 2240, NULL, 303, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (632, 1461, NULL, 310, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (633, 1950, NULL, 310, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (634, 403, NULL, 310, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (635, 2462, NULL, 310, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (636, 2744, NULL, 297, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (637, 2814, NULL, 297, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (639, 1871, NULL, 348, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (644, 2182, NULL, 300, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (645, 766, NULL, 300, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (646, 1894, NULL, 300, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (647, 2446, NULL, 86, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (648, 2492, NULL, 304, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (649, 955, NULL, 304, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (650, 2211, NULL, 304, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (651, 2358, NULL, 304, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (556, 2107, NULL, 8, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (554, 2166, NULL, 8, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (555, 2346, NULL, 8, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (557, 2930, NULL, 8, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (614, 2628, NULL, 322, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (615, 2772, NULL, 322, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (613, 1621, NULL, 322, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (616, 2903, NULL, 322, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (629, 1925, NULL, 299, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (628, 2083, NULL, 299, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (631, 2223, NULL, 299, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (630, 2246, NULL, 299, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (519, 2328, NULL, 97, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (517, 2405, NULL, 97, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (516, 1518, NULL, 97, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (518, 2897, NULL, 97, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (652, 2321, NULL, 198, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (653, 2402, NULL, 198, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (654, 2988, NULL, 198, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (655, 19, NULL, 198, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (656, 2096, NULL, 295, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (657, 2726, NULL, 295, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (658, 2194, NULL, 295, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (659, 2998, NULL, 295, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (660, 2220, NULL, 308, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (661, 2734, NULL, 308, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (662, 1908, NULL, 308, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (663, 2836, NULL, 308, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (664, 104, NULL, 15, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14264, 2479, NULL, 4791, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14265, 7340, NULL, 4791, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14266, 987, NULL, 4792, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14267, 2541, NULL, 4792, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14268, 7341, NULL, 4792, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14269, 7020, NULL, 4792, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14270, 534, NULL, 4793, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14271, 955, NULL, 4793, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14272, 378, NULL, 4793, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14273, 34, NULL, 4794, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14274, 1049, NULL, 4794, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14275, 1661, NULL, 4794, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14276, 597, NULL, 4795, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14277, 7342, NULL, 4795, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14278, 7343, NULL, 4795, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14279, 3600, NULL, 4796, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14280, 7344, NULL, 4796, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14281, 1629, NULL, 4796, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14282, 2696, NULL, 4797, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14283, 2786, NULL, 4797, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14284, 1700, NULL, 4797, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14285, 7345, NULL, 4798, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14286, 4727, NULL, 4798, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14287, 372, NULL, 4798, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14288, 3744, NULL, 4799, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14289, 100, NULL, 4799, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14290, 1655, NULL, 4800, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14291, 382, NULL, 4800, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14292, 171, NULL, 4800, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14293, 877, NULL, 4801, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14294, 2879, NULL, 4802, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14295, 727, NULL, 4802, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14296, 2927, NULL, 4802, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14297, 5387, NULL, 4803, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14301, 199, NULL, 4805, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14302, 2442, NULL, 4805, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14303, 1005, NULL, 4806, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14304, 2822, NULL, 4807, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14305, 5123, NULL, 4807, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28427, 3679, NULL, 1739, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28428, 4239, NULL, 1739, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28452, 1882, NULL, 8856, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28453, 12041, NULL, 8856, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28454, 2576, NULL, 8856, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (665, 1067, NULL, 15, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (666, 3, NULL, 15, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (667, 1349, NULL, 30, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (668, 178, NULL, 30, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (669, 199, NULL, 119, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (670, 1845, NULL, 119, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (671, 1131, NULL, 144, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (672, 157, NULL, 144, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (673, 1030, NULL, 144, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (674, 941, NULL, 160, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (675, 2664, NULL, 160, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (676, 2384, NULL, 160, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (677, 232, NULL, 195, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (678, 914, NULL, 195, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (679, 2749, NULL, 195, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (680, 190, NULL, 183, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (681, 405, NULL, 183, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (684, 2681, NULL, 210, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (685, 1646, NULL, 284, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (686, 330, NULL, 284, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (687, 1393, NULL, 284, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (688, 445, NULL, 314, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (689, 91, NULL, 35, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (690, 1042, NULL, 35, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (695, 998, NULL, 171, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (696, 2485, NULL, 171, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (697, 2393, NULL, 171, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (700, 234, NULL, 196, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (701, 857, NULL, 196, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (702, 948, NULL, 223, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (703, 2885, NULL, 223, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (704, 295, NULL, 244, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (705, 697, NULL, 244, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (706, 1263, NULL, 275, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (707, 2773, NULL, 275, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (708, 1770, NULL, 279, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (709, 2387, NULL, 279, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (710, 2133, NULL, 279, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (711, 230, NULL, 277, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (714, 1095, NULL, 194, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (715, 423, NULL, 194, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (716, 232, NULL, 194, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (717, 123, NULL, 194, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (721, 2544, NULL, 331, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (722, 951, NULL, 331, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (723, 2565, NULL, 331, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (724, 1882, NULL, 70, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (725, 2519, NULL, 70, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (726, 2225, NULL, 70, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (727, 2421, NULL, 70, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (728, 1077, NULL, 216, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (729, 2128, NULL, 216, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (730, 1745, NULL, 216, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (731, 2608, NULL, 227, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (732, 2018, NULL, 227, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (733, 2651, NULL, 227, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (734, 2478, NULL, 227, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (735, 415, NULL, 328, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (736, 547, NULL, 328, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (737, 2287, NULL, 328, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (738, 2934, NULL, 328, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (739, 2913, NULL, 233, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (740, 2196, NULL, 233, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (741, 2636, NULL, 233, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (742, 2709, NULL, 236, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (743, 2226, NULL, 236, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (744, 2984, NULL, 236, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (745, 292, NULL, 213, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (746, 2520, NULL, 213, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (747, 1010, NULL, 10, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (748, 2321, NULL, 10, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (749, 2974, NULL, 358, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (750, 943, NULL, 358, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (751, 1858, NULL, 358, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (752, 1751, NULL, 346, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (753, 2540, NULL, 346, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (754, 2760, NULL, 346, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (755, 1311, NULL, 319, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (756, 913, NULL, 319, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (757, 2966, NULL, 319, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14306, 993, NULL, 4807, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14307, 482, NULL, 4808, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14308, 1048, NULL, 4808, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14309, 6379, NULL, 4808, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14310, 1444, NULL, 4809, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14311, 1823, NULL, 4809, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (692, 2425, NULL, 133, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (691, 2685, NULL, 133, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (638, 2464, NULL, 3, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (640, 1225, NULL, 307, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (642, 2790, NULL, 307, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14312, 7346, NULL, 4809, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14313, 2716, NULL, 4809, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14314, 1210, NULL, 4810, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14315, 7072, NULL, 4810, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14316, 2165, NULL, 4810, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14317, 2007, NULL, 4810, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14318, 392, NULL, 4811, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14319, 7347, NULL, 4811, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14320, 7348, NULL, 4811, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14321, 2524, NULL, 4811, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14322, 1094, NULL, 4812, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14323, 2123, NULL, 4812, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14324, 4809, NULL, 4812, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14325, 5777, NULL, 4812, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14326, 222, NULL, 4813, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14327, 375, NULL, 4813, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14328, 2134, NULL, 4813, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14329, 552, NULL, 4814, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14330, 1934, NULL, 4814, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14331, 4313, NULL, 4814, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14332, 2583, NULL, 4814, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14333, 1017, NULL, 4815, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14334, 2563, NULL, 4815, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14335, 1379, NULL, 4815, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14336, 3528, NULL, 4815, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14300, 1232, NULL, 4804, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14298, 1380, NULL, 4804, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (719, 2594, NULL, 347, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (718, 1201, NULL, 347, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (720, 2810, NULL, 347, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14337, 1361, NULL, 4816, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14338, 942, NULL, 4816, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14339, 4815, NULL, 4816, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14340, 4342, NULL, 4816, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14341, 1580, NULL, 4817, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14342, 4103, NULL, 4817, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14343, 1901, NULL, 4817, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14344, 2692, NULL, 4817, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14345, 907, NULL, 4818, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14346, 5879, NULL, 4818, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14347, 7349, NULL, 4818, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28429, 419, NULL, 1738, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28430, 951, NULL, 1738, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28455, 1112, NULL, 8856, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28456, 1460, NULL, 8856, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18883, 2880, NULL, 5954, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (761, 1876, NULL, 211, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (762, 333, NULL, 211, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (763, 1818, NULL, 211, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (764, 1567, NULL, 285, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (765, 2269, NULL, 285, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (766, 687, NULL, 285, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (767, 2967, NULL, 285, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (768, 1053, NULL, 273, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (769, 480, NULL, 77, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (770, 1969, NULL, 77, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (771, 2527, NULL, 77, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (772, 1494, NULL, 265, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (773, 1568, NULL, 265, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (774, 2436, NULL, 168, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (775, 1974, NULL, 168, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (683, 468, NULL, 197, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (682, 1302, NULL, 197, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (776, 2520, NULL, 168, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (777, 1586, NULL, 192, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (778, 1705, NULL, 192, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (779, 2964, NULL, 192, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (784, 295, NULL, 98, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (785, 2333, NULL, 98, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (786, 132, NULL, 23, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (787, 2304, NULL, 131, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (788, 2998, NULL, 131, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (789, 2823, NULL, 280, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (790, 2489, NULL, 121, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (791, 445, NULL, 121, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (792, 2443, NULL, 121, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (793, 2413, NULL, 121, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (794, 2395, NULL, 334, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (795, 3004, NULL, 334, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (796, 124, NULL, 19, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (797, 1716, NULL, 19, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (798, 2961, NULL, 19, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (799, 187, NULL, 19, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (800, 2928, NULL, 340, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (801, 955, NULL, 225, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (802, 2247, NULL, 225, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (803, 389, NULL, 225, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (804, 1946, NULL, 349, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (805, 2722, NULL, 349, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (806, 2075, NULL, 349, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (807, 2073, NULL, 349, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (808, 1457, NULL, 126, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (809, 1957, NULL, 126, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (810, 2336, NULL, 126, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (811, 1731, NULL, 231, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (812, 1585, NULL, 231, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (813, 939, NULL, 159, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (814, 803, NULL, 159, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (815, 1984, NULL, 159, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (816, 1889, NULL, 2, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (817, 2354, NULL, 2, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (818, 2205, NULL, 93, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (819, 2151, NULL, 93, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (820, 2707, NULL, 145, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (821, 2820, NULL, 145, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (822, 2914, NULL, 145, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (823, 2724, NULL, 190, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (824, 2978, NULL, 190, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (825, 2382, NULL, 190, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (826, 1519, NULL, 173, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (827, 1533, NULL, 357, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (828, 2991, NULL, 301, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (829, 2936, NULL, 301, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (830, 1744, NULL, 301, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (831, 1689, NULL, 201, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (832, 337, NULL, 201, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (833, 2414, NULL, 201, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (834, 66, NULL, 201, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (835, 2177, NULL, 201, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (836, 2474, NULL, 201, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (837, 2243, NULL, 191, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (838, 2900, NULL, 191, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (839, 2719, NULL, 239, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (840, 1443, NULL, 246, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (841, 396, NULL, 65, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (842, 2564, NULL, 65, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (843, 355, NULL, 65, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (844, 2004, NULL, 204, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (845, 156, NULL, 27, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (846, 267, NULL, 47, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (847, 2782, NULL, 51, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (848, 2302, NULL, 51, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (849, 840, NULL, 51, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14348, 2196, NULL, 4818, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14349, 1167, NULL, 4819, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14350, 3573, NULL, 4819, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14351, 4003, NULL, 4819, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14352, 468, NULL, 4819, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14353, 1062, NULL, 4820, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14354, 2644, NULL, 4820, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14355, 3071, NULL, 4820, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14356, 3629, NULL, 4820, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14358, 4892, NULL, 3808, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14359, 374, NULL, 4821, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14360, 2876, NULL, 4821, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14361, 7437, NULL, 4821, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14362, 2951, NULL, 4821, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14363, 220, NULL, 4046, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14364, 7438, NULL, 4046, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14365, 7439, NULL, 4046, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14366, 132, NULL, 4822, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14367, 7440, NULL, 4823, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14368, 2880, NULL, 4823, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14369, 1544, NULL, 4823, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14370, 209, NULL, 4824, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14371, 7441, NULL, 4824, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14372, 7442, NULL, 4824, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14373, 1600, NULL, 4825, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14374, 2662, NULL, 4825, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14375, 2877, NULL, 4825, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14376, 4556, NULL, 4826, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14377, 652, NULL, 4826, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14378, 2918, NULL, 4826, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14379, 180, NULL, 4827, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14380, 1462, NULL, 4827, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14381, 7443, NULL, 4827, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14382, 890, NULL, 4827, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14383, 1037, NULL, 4828, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14384, 501, NULL, 4828, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14385, 670, NULL, 4828, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14386, 757, NULL, 4828, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14387, 768, NULL, 4829, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14388, 7444, NULL, 4829, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14389, 1787, NULL, 4829, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14390, 7446, NULL, 4830, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28431, 49, NULL, 1736, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28432, 2016, NULL, 1736, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28433, 1385, NULL, 1736, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28457, 1368, NULL, 8857, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28460, 333, NULL, 8857, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28459, 955, NULL, 8857, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28458, 2851, NULL, 8857, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (850, 2705, NULL, 51, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (852, 39, NULL, 80, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (780, 2001, NULL, 92, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (782, 2465, NULL, 92, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (853, 1629, NULL, 80, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (854, 424, NULL, 80, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (855, 1091, NULL, 80, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (856, 1655, NULL, 80, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (857, 2541, NULL, 356, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (858, 2178, NULL, 356, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (859, 1056, NULL, 356, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (860, 2871, NULL, 44, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (861, 1848, NULL, 44, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (862, 2827, NULL, 296, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (863, 2063, NULL, 296, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (864, 2309, NULL, 296, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (865, 1025, NULL, 174, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (866, 2156, NULL, 174, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (867, 2292, NULL, 174, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (868, 2593, NULL, 174, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (869, 2260, NULL, 245, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (870, 2977, NULL, 118, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (871, 2314, NULL, 118, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (872, 1989, NULL, 118, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (873, 2174, NULL, 118, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (874, 2854, NULL, 205, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (875, 2740, NULL, 205, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (876, 2194, NULL, 205, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (877, 2880, NULL, 111, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (878, 2285, NULL, 135, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (879, 2029, NULL, 135, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (880, 2053, NULL, 135, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (881, 2313, NULL, 325, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (882, 2902, NULL, 29, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (883, 708, NULL, 125, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (884, 1922, NULL, 125, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (885, 1994, NULL, 262, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (886, 2739, NULL, 262, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (887, 2277, NULL, 262, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (888, 2955, NULL, 262, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (889, 961, NULL, 162, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (890, 488, NULL, 162, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (891, 1917, NULL, 162, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (892, 179, NULL, 31, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (893, 2029, NULL, 31, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (894, 1898, NULL, 31, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (895, 2480, NULL, 73, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (896, 2214, NULL, 73, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (897, 598, NULL, 87, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (898, 2212, NULL, 87, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (899, 1219, NULL, 87, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (900, 2746, NULL, 87, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (901, 419, NULL, 67, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (902, 1311, NULL, 67, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (903, 2544, NULL, 67, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (904, 1402, NULL, 67, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (905, 2482, NULL, 156, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (906, 1448, NULL, 156, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (907, 2553, NULL, 156, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (908, 1915, NULL, 156, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (909, 1549, NULL, 276, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18892, 2989, NULL, 5957, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20239, 8145, NULL, 6365, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2231, 1193, NULL, 716, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (914, 2596, NULL, 143, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (915, 2973, NULL, 143, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2228, 2644, NULL, 716, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (917, 2995, NULL, 143, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (918, 2029, NULL, 309, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (919, 2566, NULL, 309, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (920, 403, NULL, 309, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (921, 1497, NULL, 272, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (922, 1933, NULL, 272, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (923, 2788, NULL, 272, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (924, 2297, NULL, 272, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (925, 2935, NULL, 341, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (926, 2255, NULL, 134, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (927, 318, NULL, 134, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (928, 181, NULL, 343, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (929, 2624, NULL, 343, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (930, 2990, NULL, 343, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (931, 1875, NULL, 343, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (932, 1665, NULL, 163, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (933, 2188, NULL, 163, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (934, 1942, NULL, 163, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (935, 1455, NULL, 163, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (936, 512, NULL, 124, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (937, 1112, NULL, 124, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (938, 2421, NULL, 124, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (939, 1638, NULL, 129, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (940, 1225, NULL, 129, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (941, 2988, NULL, 129, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (942, 76, NULL, 129, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14391, 6422, NULL, 4830, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14392, 1261, NULL, 4830, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14393, 503, NULL, 4830, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14394, 4307, NULL, 4831, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14395, 3380, NULL, 4831, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14396, 1289, NULL, 4831, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14397, 3710, NULL, 4829, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14398, 705, NULL, 4832, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14399, 1015, NULL, 4832, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14400, 2536, NULL, 4832, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14401, 7447, NULL, 4833, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14402, 3767, NULL, 4833, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14403, 3843, NULL, 4833, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14404, 3252, NULL, 4833, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14405, 1658, NULL, 4833, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14406, 1662, NULL, 4834, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14407, 7448, NULL, 4834, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14408, 665, NULL, 4834, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14409, 1875, NULL, 4834, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14418, 7450, NULL, 4838, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14419, 6768, NULL, 4838, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14420, 7451, NULL, 4838, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28434, 2469, NULL, 1736, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28461, 1003, NULL, 8858, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28462, 1181, NULL, 8858, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28463, 4578, NULL, 8858, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (943, 1316, NULL, 42, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (944, 2017, NULL, 42, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (949, 411, NULL, 305, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (950, 1744, NULL, 305, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (951, 1938, NULL, 305, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (952, 2374, NULL, 305, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (953, 1565, NULL, 164, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (954, 299, NULL, 164, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (955, 1084, NULL, 164, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (956, 2080, NULL, 81, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (957, 2478, NULL, 81, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (958, 857, NULL, 81, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (959, 685, NULL, 81, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (960, 2259, NULL, 81, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (961, 1503, NULL, 81, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (962, 835, NULL, 81, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (963, 497, NULL, 81, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (964, 382, NULL, 81, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (965, 374, NULL, 59, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (966, 982, NULL, 166, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (967, 2696, NULL, 169, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (968, 1880, NULL, 169, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (969, 697, NULL, 169, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (970, 2776, NULL, 169, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (972, 313, NULL, 350, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (973, 982, NULL, 167, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (974, 2908, NULL, 167, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (975, 2468, NULL, 167, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (976, 1919, NULL, 167, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (977, 1009, NULL, 218, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (978, 2024, NULL, 218, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (979, 2755, NULL, 218, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (980, 2431, NULL, 218, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (981, 78, NULL, 152, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (982, 1450, NULL, 152, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (983, 121, NULL, 18, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (984, 1585, NULL, 18, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (985, 1955, NULL, 18, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (986, 1982, NULL, 18, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (987, 1371, NULL, 294, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (988, 2497, NULL, 294, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (989, 1964, NULL, 294, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (990, 626, NULL, 114, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (991, 2766, NULL, 114, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (910, 77, NULL, 11, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (992, 2021, NULL, 184, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (993, 1590, NULL, 188, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (994, 2822, NULL, 326, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (995, 133, NULL, 326, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (996, 614, NULL, 335, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (997, 2923, NULL, 335, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (998, 2639, NULL, 335, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (999, 224, NULL, 273, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1000, 1063, NULL, 273, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1001, 476, NULL, 332, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1002, 2660, NULL, 332, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1003, 1864, NULL, 332, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1004, 1291, NULL, 332, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1005, 103, NULL, 332, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1006, 2544, NULL, 332, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (1007, 1311, NULL, 332, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (1008, 2654, NULL, 332, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (1009, 413, NULL, 232, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1010, 2503, NULL, 232, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1011, 2077, NULL, 232, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1012, 388, NULL, 63, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1013, 1875, NULL, 63, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1014, 2336, NULL, 63, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1015, 2081, NULL, 63, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1016, 2841, NULL, 63, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1017, 2375, NULL, 63, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (1018, 2968, NULL, 63, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (1019, 2210, NULL, 63, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (1020, 1515, NULL, 270, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1021, 2502, NULL, 270, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1022, 1940, NULL, 270, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1023, 2149, NULL, 270, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1025, 819, NULL, 237, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1026, 952, NULL, 237, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1027, 573, NULL, 237, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1028, 2551, NULL, 237, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1033, 1603, NULL, 316, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1034, 2332, NULL, 316, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1035, 2391, NULL, 316, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1036, 2383, NULL, 316, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1037, 2108, NULL, 316, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1038, 116, NULL, 316, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (1039, 2203, NULL, 316, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (1040, 1458, NULL, 253, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1041, 2890, NULL, 253, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1042, 2938, NULL, 253, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1043, 2258, NULL, 253, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1044, 1652, NULL, 253, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1045, 2199, NULL, 253, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (1046, 206, NULL, 253, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (1047, 2407, NULL, 253, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (1048, 1368, NULL, 212, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1049, 2264, NULL, 212, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1050, 2176, NULL, 212, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1051, 2904, NULL, 212, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1052, 2805, NULL, 212, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1053, 1964, NULL, 212, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (1054, 1184, NULL, 212, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (1055, 1578, NULL, 212, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (1056, 2155, NULL, 78, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1057, 686, NULL, 78, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1058, 1699, NULL, 78, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14413, 7449, NULL, 4836, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14414, 1685, NULL, 4836, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14417, 6576, NULL, 4837, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14415, 1646, NULL, 4837, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14416, 2324, NULL, 4837, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14421, 7452, NULL, 4839, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14425, 98, NULL, 4840, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14423, 3433, NULL, 4840, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14426, 318, NULL, 4841, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14428, 1447, NULL, 4841, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14427, 4578, NULL, 4841, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14429, 31, NULL, 4842, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14430, 5635, NULL, 4842, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14431, 7445, NULL, 4843, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14432, 799, NULL, 4843, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (945, 350, NULL, 298, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (947, 2538, NULL, 298, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (946, 2590, NULL, 298, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1059, 839, NULL, 78, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1060, 2159, NULL, 175, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1061, 186, NULL, 33, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14441, 6898, NULL, 4847, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14442, 671, NULL, 4847, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14443, 7457, NULL, 4848, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14444, 3589, NULL, 4848, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14445, 2285, NULL, 4848, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14446, 7458, NULL, 4849, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14447, 1514, NULL, 4849, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14448, 3363, NULL, 4849, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14449, 4740, NULL, 4850, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14450, 724, NULL, 4850, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14451, 5123, NULL, 4850, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14452, 7459, NULL, 4850, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14453, 7460, NULL, 4851, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14454, 7461, NULL, 4852, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14455, 7462, NULL, 4852, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14456, 3056, NULL, 4852, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14457, 2957, NULL, 4853, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14458, 2399, NULL, 4853, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28464, 2399, NULL, 8858, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1062, 318, NULL, 33, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1063, 709, NULL, 33, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1064, 2256, NULL, 33, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1065, 122, NULL, 33, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1066, 890, NULL, 320, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1067, 913, NULL, 320, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1068, 2587, NULL, 320, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1069, 68, NULL, 320, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1070, 1657, NULL, 320, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1071, 1578, NULL, 320, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (1072, 2368, NULL, 320, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (1073, 599, NULL, 320, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (1075, 2296, NULL, 141, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1076, 2167, NULL, 141, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1083, 2082, NULL, 84, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1084, 1869, NULL, 84, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1085, 2892, NULL, 84, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1086, 2675, NULL, 84, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1087, 1371, NULL, 293, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1089, 2960, NULL, 369, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1090, 121, NULL, 17, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1091, 1515, NULL, 268, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1092, 2819, NULL, 370, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1093, 8, NULL, 300, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1094, 2554, NULL, 371, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1095, 1978, NULL, 371, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1096, 2131, NULL, 371, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1097, 2316, NULL, 371, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1098, 1340, NULL, 76, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1099, 408, NULL, 179, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1100, 601, NULL, 26, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1102, 2232, NULL, 378, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1103, 933, NULL, 378, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1104, 900, NULL, 233, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1105, 1241, NULL, 213, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1106, 1662, NULL, 213, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1107, 1479, NULL, 265, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1112, 415, NULL, 329, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1113, 1450, NULL, 329, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1114, 425, NULL, 329, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1115, 695, NULL, 102, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1116, 669, NULL, 373, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1117, 2592, NULL, 373, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1118, 2383, NULL, 373, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1119, 1503, NULL, 80, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1120, 382, NULL, 80, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1121, 497, NULL, 80, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (1122, 1942, NULL, 330, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1123, 1528, NULL, 330, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1124, 1455, NULL, 330, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1125, 2786, NULL, 330, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1126, 374, NULL, 60, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1127, 220, NULL, 60, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1128, 2635, NULL, 60, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1129, 313, NULL, 351, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1130, 3003, NULL, 351, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1131, 2286, NULL, 351, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1132, 2708, NULL, 351, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1133, 686, NULL, 101, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1134, 709, NULL, 101, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1135, 1376, NULL, 101, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1136, 2743, NULL, 379, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1137, 2998, NULL, 374, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1138, 2304, NULL, 374, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1139, 750, NULL, 374, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1140, 923, NULL, 219, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1141, 1331, NULL, 219, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1142, 971, NULL, 219, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1143, 372, NULL, 292, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1144, 1525, NULL, 292, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1145, 1961, NULL, 292, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1146, 2680, NULL, 365, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1147, 1880, NULL, 365, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1148, 2846, NULL, 313, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1149, 2284, NULL, 313, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1101, 768, NULL, 133, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1030, 51, NULL, 359, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1031, 1927, NULL, 359, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1032, 1951, NULL, 359, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1029, 1533, NULL, 359, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1150, 1590, NULL, 313, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1151, 626, NULL, 115, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1152, 1988, NULL, 115, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1153, 2505, NULL, 115, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14459, 4578, NULL, 4853, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14460, 5098, NULL, 4854, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14461, 7463, NULL, 4854, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14462, 7464, NULL, 4855, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14463, 7465, NULL, 4856, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14464, 503, NULL, 4856, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14465, 7466, NULL, 4856, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14466, 937, NULL, 4857, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14467, 6929, NULL, 4857, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14468, 7467, NULL, 4857, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14469, 6761, NULL, 4858, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14470, 4988, NULL, 4859, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14471, 7468, NULL, 4859, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14472, 7469, NULL, 4859, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14473, 6924, NULL, 4859, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14474, 4316, NULL, 4860, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14475, 7470, NULL, 4860, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14476, 2945, NULL, 4860, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14477, 7471, NULL, 4860, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14478, 7472, NULL, 4861, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14479, 7473, NULL, 4861, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14480, 32, NULL, 4861, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14481, 1386, NULL, 4861, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14482, 3859, NULL, 4862, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14483, 2456, NULL, 4862, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2226, 1456, NULL, 716, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14485, 1, NULL, 4863, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14487, 1148, NULL, 4863, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14488, 749, NULL, 4864, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14489, 2382, NULL, 4864, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1074, 1241, NULL, 254, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (1082, 1126, NULL, 230, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1088, 1533, NULL, 360, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14490, 1775, NULL, 4864, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14491, 1707, NULL, 4865, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14492, 182, NULL, 4865, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14493, 1026, NULL, 4865, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14494, 1997, NULL, 4865, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14495, 7474, NULL, 4866, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14496, 106, NULL, 4866, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14497, 7475, NULL, 4866, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14498, 850, NULL, 4866, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14499, 943, NULL, 4867, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14500, 1857, NULL, 4867, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14501, 297, NULL, 4867, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28465, 5390, NULL, 8859, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28466, 1241, NULL, 8859, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28467, 5272, NULL, 8859, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1154, 2943, NULL, 115, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1155, 2917, NULL, 264, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1156, 2340, NULL, 264, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1157, 1894, NULL, 264, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1158, 1514, NULL, 306, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1159, 2274, NULL, 306, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1160, 2039, NULL, 306, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1161, 2747, NULL, 306, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1162, 1334, NULL, 302, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1163, 1146, NULL, 302, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1164, 2592, NULL, 302, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1165, 806, NULL, 138, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1166, 781, NULL, 96, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1167, 1118, NULL, 138, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1168, 2962, NULL, 138, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1169, 1636, NULL, 138, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1170, 920, NULL, 138, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1171, 2218, NULL, 138, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (1172, 2327, NULL, 138, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14434, 333, NULL, 4844, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14437, 7454, NULL, 4845, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14438, 7455, NULL, 4846, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14440, 2554, NULL, 4846, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14439, 7456, NULL, 4846, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1109, 425, NULL, 338, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1110, 2336, NULL, 338, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1173, 1590, NULL, 189, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1174, 1905, NULL, 189, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1175, 2814, NULL, 189, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1176, 778, NULL, 189, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1177, 1515, NULL, 269, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1178, 2109, NULL, 269, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1179, 2046, NULL, 269, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1180, 1941, NULL, 269, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1181, 1781, NULL, 176, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1182, 2357, NULL, 176, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1183, 2159, NULL, 176, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1184, 1904, NULL, 176, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1185, 419, NULL, 68, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1186, 2571, NULL, 68, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1187, 2305, NULL, 68, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1188, 2585, NULL, 68, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1189, 1847, NULL, 288, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1190, 2047, NULL, 288, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1191, 1995, NULL, 99, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1192, 2295, NULL, 99, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1193, 2021, NULL, 185, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1194, 1687, NULL, 185, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1195, 2584, NULL, 185, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1196, 799, NULL, 185, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1197, 396, NULL, 66, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1198, 2489, NULL, 66, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1199, 2369, NULL, 66, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1200, 1888, NULL, 100, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1201, 1838, NULL, 100, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1202, 2738, NULL, 100, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1203, 13, NULL, 94, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1204, 186, NULL, 94, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1205, 2471, NULL, 94, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1206, 41, NULL, 94, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1207, 1450, NULL, 153, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1208, 78, NULL, 153, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1209, 398, NULL, 153, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1210, 2270, NULL, 122, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1211, 61, NULL, 381, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1212, 296, NULL, 381, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1213, 298, NULL, 381, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1214, 301, NULL, 381, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1215, 2442, NULL, 382, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1216, 311, NULL, 382, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1217, 370, NULL, 382, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1221, 1578, NULL, 384, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1222, 504, NULL, 384, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1223, 556, NULL, 384, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1224, 607, NULL, 385, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1225, 1821, NULL, 385, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1226, 754, NULL, 385, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1227, 785, NULL, 385, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1228, 858, NULL, 385, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1229, 868, NULL, 385, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (1230, 956, NULL, 385, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (1231, 1102, NULL, 385, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (32287, 1580, NULL, 10019, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20733, 10120, NULL, 6507, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1238, 1356, NULL, 388, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1239, 2631, NULL, 388, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1240, 1409, NULL, 388, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1241, 915, NULL, 388, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1242, 1154, NULL, 389, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1243, 238, NULL, 389, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1244, 1417, NULL, 389, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1245, 1543, NULL, 389, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1246, 1563, NULL, 390, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14538, 7482, NULL, 1468, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14539, 425, NULL, 1468, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14540, 7483, NULL, 1468, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14541, 1917, NULL, 1468, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14542, 929, NULL, 2149, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14543, 3232, NULL, 2149, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1237, 1390, NULL, 387, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14503, 2576, NULL, 4868, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14502, 1421, NULL, 4868, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14504, 2442, NULL, 4869, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14505, 1091, NULL, 4869, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14506, 3440, NULL, 4870, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14507, 7476, NULL, 4870, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14508, 7477, NULL, 4871, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14509, 487, NULL, 4872, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14510, 1386, NULL, 4872, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14486, 1648, 475, 4863, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14519, 405, NULL, 4875, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14518, 755, NULL, 4875, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14520, 1263, NULL, 4875, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14521, 4310, NULL, 4876, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14522, 6850, NULL, 4876, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14514, 1942, NULL, 4874, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14516, 1455, NULL, 4874, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14517, 2786, NULL, 4874, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14526, 790, NULL, 4878, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14528, 7479, NULL, 4878, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14527, 3131, NULL, 4878, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14530, 2304, NULL, 4879, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14531, 750, NULL, 4879, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14529, 2998, NULL, 4879, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14533, 1880, NULL, 4880, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14534, 1958, NULL, 4880, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14513, 6257, NULL, 4873, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14511, 7478, NULL, 4873, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14512, 6256, NULL, 4873, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14524, 3957, NULL, 4877, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14525, 4767, NULL, 4877, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1233, 510, NULL, 386, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1232, 1150, NULL, 386, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28468, 2559, NULL, 8860, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28469, 1118, NULL, 8860, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28470, 2151, NULL, 8860, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1247, 1601, NULL, 390, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1248, 1622, NULL, 391, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1249, 1630, NULL, 391, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1250, 247, NULL, 392, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1251, 281, NULL, 392, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1252, 2584, NULL, 392, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1253, 2294, NULL, 392, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1254, 128, NULL, 393, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1255, 1514, NULL, 393, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1256, 1148, NULL, 393, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1257, 1716, NULL, 393, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1258, 1742, NULL, 394, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1259, 1664, NULL, 394, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1260, 1643, NULL, 394, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1261, 1660, NULL, 394, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1262, 1684, NULL, 395, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1263, 1690, NULL, 395, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1264, 1708, NULL, 395, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1265, 122, NULL, 395, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1269, 267, NULL, 397, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1270, 1846, NULL, 397, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1271, 1089, NULL, 397, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1272, 1851, NULL, 397, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1273, 1852, NULL, 397, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1274, 1855, NULL, 397, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (1275, 1856, NULL, 397, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (1276, 1859, NULL, 397, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (1277, 1860, NULL, 398, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1278, 1862, NULL, 399, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1279, 1867, NULL, 399, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1281, 206, NULL, 399, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1282, 309, NULL, 400, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1283, 1787, NULL, 400, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1284, 1872, NULL, 400, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1285, 1873, NULL, 400, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1286, 1877, NULL, 401, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1287, 1878, NULL, 401, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1288, 1879, NULL, 401, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1292, 510, NULL, 403, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1293, 1265, NULL, 403, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1294, 1885, NULL, 404, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1295, 1886, NULL, 404, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1296, 1887, NULL, 404, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1302, 1902, NULL, 407, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1303, 1903, NULL, 407, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1313, 2918, NULL, 321, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1314, 2520, NULL, 321, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1315, 488, NULL, 321, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1316, 106, NULL, 321, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1317, 216, NULL, 375, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1318, 596, NULL, 375, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1319, 33, NULL, 375, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1320, 1567, NULL, 376, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1321, 119, NULL, 376, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1322, 1263, NULL, 376, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1323, 2492, NULL, 376, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1324, 199, NULL, 377, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1325, 1099, NULL, 409, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1326, 134, NULL, 409, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1327, 1628, NULL, 409, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1328, 1762, NULL, 410, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1329, 1647, NULL, 410, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1330, 153, NULL, 410, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1333, 350, NULL, 412, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1334, 219, NULL, 412, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1335, 245, NULL, 412, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1336, 1559, NULL, 413, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1337, 279, NULL, 413, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1338, 1462, NULL, 414, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1307, 1665, NULL, 75, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14536, 7480, NULL, 4881, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14535, 5316, NULL, 4881, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14544, 3881, NULL, 2149, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14545, 536, NULL, 2149, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14546, 3628, NULL, 2149, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14547, 2966, NULL, 2149, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14548, 4055, NULL, 2149, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14549, 760, NULL, 2150, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14550, 1267, NULL, 2150, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14551, 5207, NULL, 2150, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14552, 1862, NULL, 2150, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14557, 7484, NULL, 2763, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14558, 3876, NULL, 2763, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14559, 2503, NULL, 2763, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14560, 1707, NULL, 2763, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14565, 7402, NULL, 2765, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14566, 2918, NULL, 2765, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14567, 2968, NULL, 2765, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14568, 242, NULL, 2765, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14569, 7487, NULL, 4594, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14570, 7488, NULL, 4594, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14571, 5560, NULL, 4594, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14572, 1140, NULL, 4594, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14573, 7489, NULL, 4595, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14574, 1725, NULL, 4595, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14575, 7490, NULL, 4596, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14576, 3027, NULL, 4596, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14577, 3885, NULL, 4596, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14578, 2758, NULL, 4596, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14579, 7491, NULL, 4597, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14580, 1213, NULL, 4597, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14581, 7072, NULL, 4597, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14582, 2979, NULL, 4597, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14583, 7492, NULL, 4597, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14584, 7493, NULL, 4598, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14585, 6576, NULL, 4598, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28471, 803, NULL, 8861, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28472, 12042, NULL, 8861, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28473, 590, NULL, 8861, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1339, 286, NULL, 414, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1340, 379, NULL, 414, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1341, 434, NULL, 415, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1342, 511, NULL, 415, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1343, 529, NULL, 415, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1344, 993, NULL, 416, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1345, 1876, NULL, 416, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1346, 1198, NULL, 417, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1347, 531, NULL, 417, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1348, 587, NULL, 419, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1349, 1501, NULL, 420, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1350, 651, NULL, 420, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1351, 2247, NULL, 420, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1352, 1467, NULL, 421, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1353, 655, NULL, 421, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1354, 674, NULL, 421, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1355, 802, NULL, 422, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1356, 352, NULL, 422, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1357, 822, NULL, 423, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1358, 1005, NULL, 423, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1359, 669, NULL, 424, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1360, 156, NULL, 425, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21176, 3131, NULL, 6641, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1368, 202, NULL, 428, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1369, 220, NULL, 428, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1370, 1121, NULL, 429, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1371, 189, NULL, 430, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1372, 1242, NULL, 430, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1373, 1460, NULL, 430, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1374, 90, NULL, 430, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1375, 1401, NULL, 431, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1376, 369, NULL, 431, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1377, 2860, NULL, 431, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1378, 123, NULL, 431, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1379, 1462, NULL, 432, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1380, 275, NULL, 432, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1381, 1430, NULL, 432, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1382, 1238, NULL, 433, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1383, 242, NULL, 433, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1384, 608, NULL, 433, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1362, 1016, NULL, 426, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1361, 389, NULL, 426, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1363, 686, NULL, 426, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1291, 1881, NULL, 402, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1289, 1510, NULL, 402, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1290, 1649, NULL, 402, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1266, 1743, NULL, 396, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1267, 1815, NULL, 396, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1305, 2238, NULL, 408, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1306, 1334, NULL, 408, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1304, 1907, NULL, 408, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1298, 1892, NULL, 405, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1299, 1895, NULL, 405, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1297, 1891, NULL, 405, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1385, 1434, NULL, 434, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1386, 1498, NULL, 434, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1387, 503, NULL, 434, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1388, 1702, NULL, 434, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1389, 164, NULL, 435, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1390, 1659, NULL, 435, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1391, 1423, NULL, 435, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1392, 1629, NULL, 435, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1393, 614, NULL, 436, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1394, 1722, NULL, 436, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1395, 1782, NULL, 436, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1396, 1537, NULL, 436, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1398, 1850, NULL, 187, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1402, 1916, NULL, 438, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1403, 1102, NULL, 438, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1404, 607, NULL, 438, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1405, 1924, NULL, 438, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1406, 315, NULL, 439, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1407, 1930, NULL, 439, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1408, 1931, NULL, 439, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1409, 1932, NULL, 439, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1410, 1624, NULL, 440, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1411, 2534, NULL, 440, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1412, 1205, NULL, 440, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1417, 1603, NULL, 442, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1418, 1944, NULL, 442, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1419, 1945, NULL, 442, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1420, 1947, NULL, 442, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1421, 204, NULL, 443, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1422, 861, NULL, 443, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1423, 333, NULL, 443, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1424, 1701, NULL, 443, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1425, 1533, NULL, 444, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1426, 1881, NULL, 444, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1427, 1949, NULL, 444, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1428, 2399, NULL, 444, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1429, 1095, NULL, 496, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1430, 1896, NULL, 496, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1310, 76, NULL, 220, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1308, 283, NULL, 220, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1311, 497, NULL, 220, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1309, 1909, NULL, 220, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1413, 97, NULL, 441, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1414, 1934, NULL, 441, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1416, 1936, NULL, 441, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1415, 1935, NULL, 441, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1399, 544, NULL, 437, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1401, 2256, NULL, 437, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1397, 1850, NULL, 437, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1400, 1913, NULL, 437, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14562, 4171, NULL, 2764, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14561, 7485, NULL, 2764, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14564, 7486, NULL, 2764, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14563, 2786, NULL, 2764, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1301, 1897, NULL, 406, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1431, 1401, NULL, 496, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14586, 7494, NULL, 4598, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14587, 1965, NULL, 4598, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14588, 923, NULL, 4882, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14589, 51, NULL, 4882, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14590, 1031, NULL, 4882, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14591, 2790, NULL, 4882, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14592, 7495, NULL, 4882, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14593, 7496, NULL, 4882, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14594, 7497, NULL, 4882, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14595, 568, NULL, 4883, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14596, 7498, NULL, 4883, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14597, 7499, NULL, 4883, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14598, 179, NULL, 4884, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14599, 7500, NULL, 4884, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14600, 2531, NULL, 4884, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14601, 3232, NULL, 4884, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14602, 7503, NULL, 4884, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14603, 7501, NULL, 4884, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14604, 7502, NULL, 4884, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (14605, 7504, NULL, 4884, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14606, 1497, NULL, 4885, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14607, 5497, NULL, 4885, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14608, 2752, NULL, 4885, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14609, 2800, NULL, 4885, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14610, 1497, NULL, 4886, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14611, 1481, NULL, 4886, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14612, 2434, NULL, 4886, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14613, 7505, NULL, 4886, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14614, 230, NULL, 4887, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14615, 7506, NULL, 4887, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14616, 1638, NULL, 4888, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14617, 116, NULL, 4888, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14618, 7507, NULL, 4888, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14619, 7508, NULL, 4888, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14620, 7509, NULL, 4889, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14621, 5333, NULL, 4889, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14622, 7510, NULL, 4889, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14623, 430, NULL, 4890, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14624, 6464, NULL, 4890, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14625, 3007, NULL, 4890, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14626, 7511, NULL, 4890, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14627, 2055, NULL, 4891, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28474, 3381, NULL, 8862, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28475, 1809, NULL, 8862, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28476, 1374, NULL, 8862, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1432, 1956, NULL, 496, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1433, 55, NULL, 497, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1434, 1875, NULL, 497, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1435, 1958, NULL, 497, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1436, 792, NULL, 497, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1441, 937, NULL, 500, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1442, 1691, NULL, 500, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1443, 1664, NULL, 500, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1444, 1965, NULL, 500, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1445, 695, NULL, 501, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1446, 1527, NULL, 501, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1447, 1368, NULL, 501, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1448, 533, NULL, 501, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1449, 1966, NULL, 502, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1450, 1390, NULL, 502, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1451, 1967, NULL, 502, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1452, 1332, NULL, 502, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1453, 1968, NULL, 503, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1454, 309, NULL, 504, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1455, 1970, NULL, 504, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1456, 1971, NULL, 504, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1457, 1972, NULL, 504, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1458, 1973, NULL, 505, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1459, 81, NULL, 506, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1460, 1655, NULL, 506, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1461, 1386, NULL, 506, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1462, 1647, NULL, 506, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1463, 1620, NULL, 507, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1464, 1975, NULL, 507, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1465, 1976, NULL, 507, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1466, 2340, NULL, 507, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1467, 1689, NULL, 508, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1468, 337, NULL, 508, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1469, 141, NULL, 508, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1470, 1977, NULL, 508, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1471, 812, NULL, 508, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1472, 2231, NULL, 508, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (1473, 1979, NULL, 508, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (1474, 614, NULL, 508, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (1475, 804, NULL, 509, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1476, 1981, NULL, 509, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1477, 2625, NULL, 509, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1478, 1986, NULL, 509, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1482, 1146, NULL, 572, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1483, 1114, NULL, 572, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1484, 2163, NULL, 572, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1485, 1725, NULL, 572, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1486, 263, NULL, 573, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1487, 1598, NULL, 573, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1488, 1232, NULL, 573, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1489, 78, NULL, 573, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1490, 1574, NULL, 574, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1491, 1777, NULL, 574, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1492, 1827, NULL, 574, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1493, 51, NULL, 574, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1494, 632, NULL, 575, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1495, 671, NULL, 575, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1496, 1993, NULL, 575, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1497, 2480, NULL, 575, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1498, 1537, NULL, 576, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1499, 973, NULL, 576, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1500, 1999, NULL, 576, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1501, 2000, NULL, 576, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1502, 976, NULL, 577, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1503, 2002, NULL, 577, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1504, 2003, NULL, 577, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1505, 2005, NULL, 577, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1510, 2008, NULL, 579, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1511, 750, NULL, 579, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1512, 1977, NULL, 579, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1513, 1742, NULL, 579, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1514, 2635, NULL, 580, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1515, 2009, NULL, 580, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1516, 1981, NULL, 580, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1517, 2199, NULL, 580, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1518, 1206, NULL, 581, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1519, 2012, NULL, 581, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1520, 599, NULL, 581, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1521, 1576, NULL, 582, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1522, 2014, NULL, 582, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1523, 2015, NULL, 582, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1524, 1952, NULL, 582, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1525, 2020, NULL, 583, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1526, 1529, NULL, 583, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1527, 2025, NULL, 583, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1529, 217, NULL, 584, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1530, 2028, NULL, 584, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1531, 2407, NULL, 584, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1532, 2030, NULL, 584, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1533, 2294, NULL, 214, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1538, 636, NULL, 586, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1539, 1575, NULL, 586, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1540, 1976, NULL, 586, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1541, 2034, NULL, 586, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1542, 2043, NULL, 587, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1543, 2044, NULL, 587, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1544, 2048, NULL, 587, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1545, 2049, NULL, 587, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1546, 2050, NULL, 588, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1547, 2197, NULL, 588, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1548, 2051, NULL, 588, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1549, 1562, NULL, 588, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1550, 913, NULL, 589, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1551, 2052, NULL, 589, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1552, 2056, NULL, 589, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1553, 2057, NULL, 589, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1554, 823, NULL, 590, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1555, 2059, NULL, 590, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14628, 7512, NULL, 4891, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14629, 7513, NULL, 4891, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14630, 7514, NULL, 4891, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14631, 448, NULL, 4892, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14632, 2356, NULL, 4892, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14633, 2332, NULL, 4892, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14638, 964, NULL, 4894, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14639, 1873, NULL, 4894, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14640, 7515, NULL, 4894, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14641, 7516, NULL, 4894, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14642, 7517, NULL, 4894, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14643, 7241, NULL, 4894, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14644, 5017, NULL, 4894, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14645, 1741, NULL, 4895, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14646, 2619, NULL, 4895, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14647, 7518, NULL, 4895, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14648, 7519, NULL, 4895, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14649, 7520, NULL, 4896, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1556, 2060, NULL, 590, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1557, 2061, NULL, 590, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1558, 886, NULL, 591, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1559, 2966, NULL, 591, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1560, 2522, NULL, 591, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1439, 2144, NULL, 498, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1437, 997, NULL, 498, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1438, 1959, NULL, 498, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1561, 834, NULL, 591, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1562, 887, NULL, 592, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1563, 2709, NULL, 592, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1564, 2258, NULL, 592, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1565, 2064, NULL, 592, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1566, 912, NULL, 593, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1567, 2065, NULL, 593, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1568, 164, NULL, 593, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1569, 1943, NULL, 593, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1570, 962, NULL, 594, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1571, 2473, NULL, 594, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1572, 2066, NULL, 594, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1573, 2067, NULL, 594, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1574, 1565, NULL, 595, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1575, 2068, NULL, 595, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1576, 2069, NULL, 595, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1577, 2070, NULL, 595, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1578, 1289, NULL, 596, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1579, 1235, NULL, 596, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1580, 1289, NULL, 173, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1581, 1351, NULL, 597, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1582, 2071, NULL, 597, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1583, 526, NULL, 597, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1584, 1988, NULL, 597, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1585, 1478, NULL, 598, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1586, 2074, NULL, 598, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1587, 2531, NULL, 598, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1588, 1585, NULL, 598, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1589, 1508, NULL, 599, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1590, 2084, NULL, 599, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1591, 2318, NULL, 599, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1592, 2847, NULL, 599, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1593, 1010, NULL, 600, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1594, 2321, NULL, 601, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1596, 2063, NULL, 602, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1597, 2089, NULL, 602, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1598, 292, NULL, 602, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1599, 594, NULL, 603, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1600, 902, NULL, 603, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1601, 1099, NULL, 603, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1602, 251, NULL, 604, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1603, 2093, NULL, 604, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1604, 2094, NULL, 604, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1605, 1916, NULL, 604, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1606, 898, NULL, 605, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1607, 834, NULL, 605, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1608, 2095, NULL, 605, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1609, 2144, NULL, 605, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1610, 71, NULL, 607, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1611, 182, NULL, 607, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1612, 2102, NULL, 607, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1613, 2103, NULL, 607, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1614, 346, NULL, 608, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1615, 889, NULL, 608, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1616, 2104, NULL, 608, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1617, 2017, NULL, 608, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1618, 1355, NULL, 609, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1619, 2110, NULL, 609, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1620, 697, NULL, 609, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1621, 2112, NULL, 609, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1622, 1454, NULL, 610, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1623, 2114, NULL, 610, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1624, 2115, NULL, 610, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1625, 2117, NULL, 610, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1626, 347, NULL, 611, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1627, 2120, NULL, 611, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1628, 2121, NULL, 611, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1629, 1447, NULL, 611, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1630, 396, NULL, 612, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1631, 2122, NULL, 612, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1632, 2077, NULL, 612, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1633, 177, NULL, 612, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1638, 1425, NULL, 615, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1639, 2413, NULL, 615, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1640, 1118, NULL, 615, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1641, 2218, NULL, 615, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1642, 1829, NULL, 616, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1643, 425, NULL, 616, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1644, 1403, NULL, 616, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1645, 699, NULL, 616, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1646, 623, NULL, 617, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1647, 2125, NULL, 617, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14650, 7521, NULL, 4896, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14651, 7522, NULL, 4896, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14652, 7523, NULL, 4896, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14653, 84, NULL, 4897, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14654, 3198, NULL, 4897, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14655, 2445, NULL, 4897, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14656, 1067, NULL, 4897, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14657, 7524, NULL, 4898, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14658, 7525, NULL, 4898, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14659, 7526, NULL, 4898, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14660, 7527, NULL, 4898, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14661, 469, NULL, 4899, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14662, 2625, NULL, 4899, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14663, 168, NULL, 4899, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14664, 5885, NULL, 4899, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14666, 3018, NULL, 4899, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14667, 1386, NULL, 4899, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14668, 1929, NULL, 4899, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (14669, 1540, NULL, 4656, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14670, 2063, NULL, 4656, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14671, 7528, NULL, 4656, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14672, 7529, NULL, 4656, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14673, 1942, NULL, 4656, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14674, 7240, NULL, 4656, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14675, 2786, NULL, 4656, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14676, 2742, NULL, 4656, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (14677, 1629, NULL, 4666, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14678, 1638, NULL, 4666, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14679, 1541, NULL, 4666, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14680, 1091, NULL, 4666, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14681, 2091, NULL, 4666, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14682, 1329, NULL, 4666, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14683, 497, NULL, 4666, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14684, 382, NULL, 4666, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (14685, 129, NULL, 4660, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14686, 4101, NULL, 4660, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14687, 6558, NULL, 4660, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14688, 7530, NULL, 4660, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14689, 389, NULL, 4669, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14690, 2492, NULL, 4669, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14636, 1066, NULL, 4893, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32808, 5442, NULL, 10162, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1595, 181, NULL, 602, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1537, 2033, NULL, 585, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1534, 896, NULL, 585, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1536, 2032, NULL, 585, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14691, 760, NULL, 4669, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28477, 1527, NULL, 8863, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28478, 3113, NULL, 8863, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28479, 4026, NULL, 8863, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1648, 2327, NULL, 617, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1649, 2130, NULL, 617, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1650, 1487, NULL, 618, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1651, 440, NULL, 618, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1652, 2132, NULL, 618, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1653, 2134, NULL, 618, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1654, 1229, NULL, 619, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1655, 2918, NULL, 619, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1656, 2135, NULL, 619, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1657, 2396, NULL, 619, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1658, 533, NULL, 621, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1659, 1578, NULL, 621, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1660, 1368, NULL, 621, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1661, 2136, NULL, 621, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1666, 2141, NULL, 624, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1667, 1095, NULL, 625, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1668, 2143, NULL, 625, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1669, 1725, NULL, 625, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1670, 2145, NULL, 625, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1671, 1813, NULL, 626, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1672, 2146, NULL, 626, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1673, 2554, NULL, 626, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1674, 1929, NULL, 626, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1675, 1662, NULL, 627, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1676, 2520, NULL, 627, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1677, 1965, NULL, 627, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1678, 152, NULL, 627, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1679, 1610, NULL, 628, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1680, 2147, NULL, 628, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1681, 2531, NULL, 628, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1682, 2148, NULL, 628, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1683, 825, NULL, 629, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1684, 1386, NULL, 629, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1685, 2152, NULL, 629, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1686, 650, NULL, 629, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1687, 973, NULL, 630, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1688, 2154, NULL, 630, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1689, 713, NULL, 630, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1690, 2157, NULL, 630, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1691, 2160, NULL, 631, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1692, 2161, NULL, 631, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1693, 2164, NULL, 631, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1694, 2165, NULL, 631, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1695, 2168, NULL, 632, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1696, 2172, NULL, 632, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1697, 2173, NULL, 632, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1698, 2175, NULL, 632, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1699, 2183, NULL, 633, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1700, 841, NULL, 633, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1701, 2184, NULL, 633, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1702, 613, NULL, 633, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1703, 2185, NULL, 634, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1704, 2186, NULL, 634, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1705, 1289, NULL, 634, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1706, 1081, NULL, 634, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1707, 901, NULL, 635, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1708, 2190, NULL, 635, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1709, 2192, NULL, 635, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1710, 2193, NULL, 636, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1711, 2195, NULL, 636, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1712, 2198, NULL, 636, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1713, 2201, NULL, 636, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1714, 5, NULL, 637, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1715, 2204, NULL, 637, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1716, 2207, NULL, 637, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1717, 2208, NULL, 637, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1718, 2209, NULL, 638, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1719, 2213, NULL, 638, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1720, 2215, NULL, 638, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1721, 2216, NULL, 638, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1722, 2217, NULL, 639, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1723, 2221, NULL, 639, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1724, 2638, NULL, 640, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1725, 2222, NULL, 640, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1726, 2224, NULL, 640, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1730, 2242, NULL, 642, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1731, 2244, NULL, 642, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1732, 2245, NULL, 642, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1733, 2248, NULL, 642, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1734, 2250, NULL, 643, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1735, 2251, NULL, 643, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1736, 2253, NULL, 643, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1737, 2254, NULL, 643, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1738, 2261, NULL, 644, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1739, 2049, NULL, 644, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1740, 2262, NULL, 644, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14692, 1386, NULL, 4669, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14693, 1066, NULL, 4657, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14694, 457, NULL, 4657, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14695, 1701, NULL, 4657, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1664, 51, NULL, 623, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1665, 58, NULL, 623, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1663, 2118, NULL, 623, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14696, 5123, NULL, 4657, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14697, 318, NULL, 4657, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14698, 624, NULL, 4657, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14699, 4656, NULL, 4657, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14700, 1622, NULL, 4657, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (14701, 763, NULL, 4658, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14702, 7531, NULL, 4658, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14703, 6464, NULL, 4658, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14704, 4738, NULL, 4658, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14705, 152, NULL, 4662, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14706, 2138, NULL, 4662, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14707, 2491, NULL, 4662, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14708, 4176, NULL, 4662, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14709, 1592, NULL, 4663, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14710, 2534, NULL, 4663, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14711, 2981, NULL, 4663, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14712, 324, NULL, 4661, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14713, 555, NULL, 4661, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14714, 2151, NULL, 4661, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14715, 4073, NULL, 4661, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14716, 2517, NULL, 4661, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14717, 3324, NULL, 4661, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14718, 2438, NULL, 4661, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14719, 6691, NULL, 4661, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (14720, 1400, NULL, 4661, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (14721, 3358, NULL, 4661, 10);
INSERT INTO 'tunesrecordingsmap' VALUES (14722, 1379, NULL, 4661, 11);
INSERT INTO 'tunesrecordingsmap' VALUES (14723, 2957, NULL, 4661, 12);
INSERT INTO 'tunesrecordingsmap' VALUES (14724, 914, NULL, 4661, 13);
INSERT INTO 'tunesrecordingsmap' VALUES (14725, 4815, NULL, 4661, 14);
INSERT INTO 'tunesrecordingsmap' VALUES (14726, 4702, NULL, 4661, 15);
INSERT INTO 'tunesrecordingsmap' VALUES (14727, 2290, NULL, 4661, 16);
INSERT INTO 'tunesrecordingsmap' VALUES (14728, 452, NULL, 4665, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14729, 2691, NULL, 4665, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14730, 488, NULL, 4665, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14731, 1481, NULL, 4665, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14732, 302, NULL, 4665, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14733, 320, NULL, 4665, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (28480, 124, NULL, 8864, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28481, 1732, NULL, 8864, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28482, 318, NULL, 8864, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1741, 2265, NULL, 644, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1742, 2267, NULL, 645, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1743, 2268, NULL, 645, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1744, 2271, NULL, 645, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1745, 2272, NULL, 645, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1749, 523, NULL, 647, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1750, 166, NULL, 647, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1751, 133, NULL, 647, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1752, 2386, NULL, 647, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1753, 2608, NULL, 648, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1754, 2276, NULL, 648, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1755, 503, NULL, 648, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1756, 2280, NULL, 648, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1757, 1316, NULL, 649, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1758, 1636, NULL, 649, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1759, 109, NULL, 649, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1760, 604, NULL, 649, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1761, 1727, NULL, 650, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1762, 753, NULL, 650, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1763, 2281, NULL, 650, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1764, 697, NULL, 650, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1765, 2282, NULL, 651, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1766, 2300, NULL, 651, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1767, 857, NULL, 651, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1768, 2303, NULL, 651, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1769, 610, NULL, 652, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1770, 2306, NULL, 652, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1771, 2310, NULL, 652, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1772, 2312, NULL, 653, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1773, 2315, NULL, 653, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1774, 1155, NULL, 653, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1775, 920, NULL, 653, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1776, 1839, NULL, 654, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1777, 1561, NULL, 654, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1778, 1596, NULL, 654, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1779, 730, NULL, 654, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1780, 1497, NULL, 655, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1781, 2317, NULL, 655, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1782, 1328, NULL, 655, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1783, 943, NULL, 655, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1784, 1173, NULL, 656, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1785, 2320, NULL, 656, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1786, 2565, NULL, 656, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1787, 2322, NULL, 656, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1788, 1801, NULL, 657, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1789, 2324, NULL, 657, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1790, 1971, NULL, 657, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1791, 8, NULL, 657, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1792, 1711, NULL, 658, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1793, 284, NULL, 658, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1794, 916, NULL, 658, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1795, 2235, NULL, 658, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1796, 1488, NULL, 659, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1797, 2325, NULL, 659, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1798, 2329, NULL, 659, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1799, 2334, NULL, 659, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1800, 1733, NULL, 660, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1801, 2335, NULL, 660, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1802, 2811, NULL, 660, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1803, 2337, NULL, 660, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1804, 1241, NULL, 661, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1805, 2597, NULL, 661, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1806, 1202, NULL, 662, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1807, 1156, NULL, 662, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1808, 2338, NULL, 662, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1809, 2339, NULL, 662, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1810, 1402, NULL, 662, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1811, 2342, NULL, 662, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (1812, 2344, NULL, 662, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (1813, 2798, NULL, 663, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1814, 2350, NULL, 663, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1815, 2973, NULL, 664, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1816, 2351, NULL, 664, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1817, 2352, NULL, 664, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1818, 2355, NULL, 665, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1819, 2428, NULL, 665, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1820, 2359, NULL, 665, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1821, 1158, NULL, 666, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1822, 2360, NULL, 666, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1823, 2211, NULL, 666, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1824, 2363, NULL, 666, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1825, 2364, NULL, 667, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1826, 2367, NULL, 667, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1827, 2388, NULL, 667, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1828, 2370, NULL, 668, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1829, 2371, NULL, 668, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1830, 2373, NULL, 668, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1831, 2376, NULL, 668, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1832, 2377, NULL, 669, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14734, 792, NULL, 4665, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14735, 1241, NULL, 4665, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (14736, 1101, NULL, 4664, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14737, 1544, NULL, 4664, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14738, 7532, NULL, 4664, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14739, 7533, NULL, 4664, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14740, 7534, NULL, 4664, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14741, 7535, NULL, 4664, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14742, 5189, NULL, 4664, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14743, 7536, NULL, 4664, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (14744, 1659, NULL, 4667, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14745, 1636, NULL, 4667, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14746, 812, NULL, 4667, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14747, 2531, NULL, 4667, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14748, 1557, NULL, 4659, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14749, 3009, NULL, 4659, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14750, 2031, NULL, 4659, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14751, 5931, NULL, 4659, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14752, 206, NULL, 4668, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14753, 3001, NULL, 4668, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14754, 7537, NULL, 4668, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14755, 3005, NULL, 4668, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14756, 7538, NULL, 4668, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14757, 2979, NULL, 4668, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14758, 2905, NULL, 4668, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14759, 7539, NULL, 4668, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (14760, 14, NULL, 4900, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14761, 2138, NULL, 4900, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14762, 2081, NULL, 4900, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14763, 351, NULL, 4901, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14764, 773, NULL, 4901, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14765, 1026, NULL, 4901, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14766, 1979, NULL, 4901, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14767, 2534, NULL, 4901, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14768, 1707, NULL, 4901, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14769, 3012, NULL, 4901, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14770, 762, NULL, 4902, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14771, 488, NULL, 4902, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14772, 1917, NULL, 4902, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14773, 429, NULL, 4902, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14774, 1029, NULL, 4903, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14775, 7540, NULL, 4903, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14776, 7541, NULL, 4903, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28483, 2757, NULL, 8865, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28484, 106, NULL, 8865, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28485, 7557, NULL, 8865, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1833, 2309, NULL, 669, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1834, 62, NULL, 669, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1835, 2289, NULL, 669, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1836, 1179, NULL, 670, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1837, 1498, NULL, 670, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1838, 2378, NULL, 670, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1839, 2379, NULL, 670, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1840, 1293, NULL, 671, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1841, 2380, NULL, 671, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1842, 2389, NULL, 671, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1843, 189, NULL, 672, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1844, 2390, NULL, 672, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1845, 2401, NULL, 672, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1846, 698, NULL, 673, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1847, 2834, NULL, 673, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1848, 2404, NULL, 673, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1849, 2155, NULL, 674, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1850, 2408, NULL, 674, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1851, 63, NULL, 674, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1852, 2021, NULL, 675, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1853, 2410, NULL, 675, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1854, 649, NULL, 675, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1855, 2412, NULL, 676, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1856, 2417, NULL, 676, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32810, 2047, NULL, 10163, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1862, 1560, NULL, 678, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1863, 8, NULL, 678, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1864, 537, NULL, 678, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1865, 90, NULL, 678, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1866, 1736, NULL, 679, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1867, 1814, NULL, 679, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1872, 1709, NULL, 681, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1873, 2489, NULL, 681, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1874, 1707, NULL, 681, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1875, 1431, NULL, 681, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1880, 1754, NULL, 683, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1881, 2439, NULL, 683, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1882, 1294, NULL, 683, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1883, 2445, NULL, 683, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1884, 2447, NULL, 683, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1885, 2448, NULL, 683, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (1886, 239, NULL, 683, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (1887, 1099, NULL, 683, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (1888, 619, NULL, 684, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1889, 1093, NULL, 684, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1890, 2449, NULL, 684, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1891, 2450, NULL, 684, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1892, 703, NULL, 685, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1893, 2966, NULL, 685, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1894, 2065, NULL, 685, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1895, 2451, NULL, 685, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1896, 2531, NULL, 685, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1897, 812, NULL, 685, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (1898, 2452, NULL, 685, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (1899, 2534, NULL, 685, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (1900, 315, NULL, 686, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1901, 219, NULL, 686, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1902, 2692, NULL, 686, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1903, 792, NULL, 686, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1904, 684, NULL, 687, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1905, 2454, NULL, 687, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1906, 2455, NULL, 687, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1907, 1118, NULL, 687, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1908, 78, NULL, 688, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1909, 2456, NULL, 688, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1910, 1132, NULL, 688, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1911, 2285, NULL, 689, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1912, 2029, NULL, 689, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1913, 2053, NULL, 689, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1914, 1744, NULL, 690, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1915, 2457, NULL, 690, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1916, 1264, NULL, 690, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1917, 1785, NULL, 691, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1918, 963, NULL, 691, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1919, 431, NULL, 692, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1921, 333, NULL, 692, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1922, 1146, NULL, 693, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1923, 2458, NULL, 693, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1858, 2422, NULL, 677, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20729, 10116, NULL, 6507, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20735, 3563, NULL, 6507, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (1924, 2459, NULL, 693, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1925, 32, NULL, 693, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14777, 670, NULL, 4903, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14778, 969, NULL, 4904, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14779, 1118, NULL, 4904, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14780, 403, NULL, 4904, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14781, 2559, NULL, 4904, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14782, 355, NULL, 4904, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14783, 2489, NULL, 4904, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14784, 1554, NULL, 4905, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14785, 1789, NULL, 4905, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14786, 586, NULL, 4905, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14787, 2436, NULL, 4905, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14788, 2706, NULL, 4905, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14789, 2089, NULL, 4905, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14790, 425, NULL, 4905, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14791, 103, NULL, 4906, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14792, 141, NULL, 4906, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14793, 3846, NULL, 4906, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14794, 951, NULL, 4906, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14795, 2065, NULL, 4906, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14796, 3463, NULL, 4906, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14805, 476, NULL, 4908, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14806, 2451, NULL, 4908, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14807, 2531, NULL, 4908, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14808, 2438, NULL, 4908, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14813, 435, NULL, 4910, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14814, 7542, NULL, 4910, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14815, 389, NULL, 4910, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14816, 2317, NULL, 4910, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14817, 1082, NULL, 4911, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14818, 686, NULL, 4911, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28486, 121, NULL, 8866, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28487, 12043, NULL, 8866, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28488, 989, NULL, 8866, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1920, 5634, 284, 692, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1926, 1790, NULL, 694, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1927, 2309, NULL, 694, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1928, 2461, NULL, 694, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1929, 2463, NULL, 694, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1930, 819, NULL, 695, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1931, 389, NULL, 695, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1932, 1148, NULL, 695, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1933, 2466, NULL, 696, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1934, 2470, NULL, 696, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1935, 55, NULL, 697, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1936, 2692, NULL, 697, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1937, 1403, NULL, 697, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1938, 1283, NULL, 698, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1939, 2472, NULL, 698, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1879, 2435, NULL, 682, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1878, 302, NULL, 682, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1876, 862, NULL, 682, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1877, 2434, NULL, 682, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1869, 1896, NULL, 680, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1870, 2430, NULL, 680, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1868, 1532, NULL, 680, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1940, 2477, NULL, 698, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1941, 51, NULL, 699, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1942, 1291, NULL, 699, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1943, 1334, NULL, 699, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1944, 958, NULL, 700, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1945, 2479, NULL, 700, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1946, 2481, NULL, 700, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1947, 2366, NULL, 702, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1948, 1295, NULL, 702, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1949, 2644, NULL, 702, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1950, 1943, NULL, 702, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1951, 1898, NULL, 702, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1952, 2381, NULL, 702, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (1953, 863, NULL, 56, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1954, 2780, NULL, 703, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1955, 2483, NULL, 703, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1956, 2487, NULL, 703, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1957, 2488, NULL, 703, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1958, 2491, NULL, 704, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1959, 2494, NULL, 704, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1960, 2496, NULL, 704, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1961, 693, NULL, 705, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1962, 2498, NULL, 705, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1963, 2499, NULL, 705, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1964, 2500, NULL, 705, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1965, 2565, NULL, 707, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1966, 812, NULL, 707, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1967, 1364, NULL, 707, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1968, 2438, NULL, 707, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1969, 1345, NULL, 264, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1970, 203, NULL, 708, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1971, 613, NULL, 708, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1972, 1424, NULL, 708, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1973, 1656, NULL, 708, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1974, 243, NULL, 709, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1975, 2507, NULL, 709, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1976, 2508, NULL, 709, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1977, 1345, NULL, 710, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1978, 2942, NULL, 710, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1979, 2766, NULL, 710, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1980, 2200, NULL, 710, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1981, 1303, NULL, 711, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1982, 2623, NULL, 711, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1983, 2438, NULL, 711, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1984, 2537, NULL, 711, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1989, 54, NULL, 713, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1990, 2516, NULL, 713, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1991, 2517, NULL, 713, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1992, 2518, NULL, 713, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1993, 329, NULL, 714, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1994, 2525, NULL, 714, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1995, 2528, NULL, 714, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1996, 1429, NULL, 715, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1997, 2529, NULL, 715, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1998, 2285, NULL, 715, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1999, 2530, NULL, 715, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2000, 248, NULL, 228, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2001, 1036, NULL, 717, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2002, 2535, NULL, 717, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2003, 2536, NULL, 717, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2004, 1655, NULL, 717, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2005, 1356, NULL, 718, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2006, 1636, NULL, 718, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2007, 1624, NULL, 718, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2008, 773, NULL, 718, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2009, 437, NULL, 719, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2010, 806, NULL, 719, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2011, 1311, NULL, 719, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2012, 68, NULL, 719, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2013, 1234, NULL, 720, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2014, 2539, NULL, 720, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2015, 256, NULL, 720, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2016, 2031, NULL, 720, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2021, 273, NULL, 723, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2022, 425, NULL, 723, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2023, 2312, NULL, 723, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2027, 1557, NULL, 725, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2028, 664, NULL, 725, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2029, 2918, NULL, 725, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2033, 1228, NULL, 727, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2034, 1745, NULL, 727, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2035, 2545, NULL, 727, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2036, 2442, NULL, 727, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2037, 1624, NULL, 727, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2038, 2218, NULL, 727, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2039, 1117, NULL, 727, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2040, 1077, NULL, 727, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (2041, 1285, NULL, 729, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2042, 2547, NULL, 729, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2043, 2550, NULL, 729, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2044, 1890, NULL, 729, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2045, 1804, NULL, 730, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2046, 2552, NULL, 730, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2047, 2202, NULL, 730, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2048, 2555, NULL, 730, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2049, 1001, NULL, 731, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2050, 2556, NULL, 731, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2051, 2045, NULL, 731, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14819, 119, NULL, 4911, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14820, 1857, NULL, 4911, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14828, 7545, NULL, 4914, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14829, 4474, NULL, 4914, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1988, 2515, NULL, 712, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1987, 2513, NULL, 712, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14799, 1876, NULL, 4907, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14798, 453, NULL, 4907, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14803, 471, NULL, 4907, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14800, 6896, NULL, 4907, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14830, 2945, NULL, 4914, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14831, 2860, NULL, 4914, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14832, 7546, NULL, 4915, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14833, 1049, NULL, 4915, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14834, 7555, NULL, 4915, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14835, 7547, NULL, 4916, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14836, 109, NULL, 4916, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14837, 1140, NULL, 4916, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28489, 857, NULL, 8867, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2052, 2557, NULL, 731, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2053, 2559, NULL, 731, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2054, 2560, NULL, 731, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2055, 2561, NULL, 731, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2056, 274, NULL, 732, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2057, 536, NULL, 732, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2058, 2369, NULL, 732, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2059, 1445, NULL, 732, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2060, 1019, NULL, 733, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2061, 728, NULL, 733, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2062, 608, NULL, 733, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2063, 2416, NULL, 733, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2064, 1100, NULL, 734, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2065, 2151, NULL, 734, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2066, 2563, NULL, 734, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2067, 2636, NULL, 734, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2068, 2569, NULL, 734, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2069, 2103, NULL, 734, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2070, 306, NULL, 734, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2071, 363, NULL, 606, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2072, 1989, NULL, 606, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2073, 2300, NULL, 606, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2074, 2572, NULL, 606, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2079, 56, NULL, 735, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2080, 2016, NULL, 735, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2081, 1423, NULL, 735, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2082, 2062, NULL, 735, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2083, 236, NULL, 736, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2084, 2076, NULL, 736, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2085, 2111, NULL, 736, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2086, 2706, NULL, 736, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2087, 909, NULL, 737, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2088, 2582, NULL, 737, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2089, 2790, NULL, 737, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2090, 2312, NULL, 737, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2091, 1147, NULL, 738, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2092, 1232, NULL, 738, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2093, 2394, NULL, 738, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2094, 2514, NULL, 738, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2095, 810, NULL, 739, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2096, 1192, NULL, 739, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2097, 1352, NULL, 739, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2098, 2559, NULL, 739, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2099, 1659, NULL, 739, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2100, 1069, NULL, 739, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2101, 2516, NULL, 739, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2102, 97, NULL, 740, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2103, 1958, NULL, 740, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2104, 2429, NULL, 740, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2105, 2188, NULL, 740, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2106, 2542, NULL, 741, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2107, 39, NULL, 741, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2108, 1421, NULL, 742, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2109, 2943, NULL, 742, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2024, 57, NULL, 724, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2026, 1003, NULL, 724, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2025, 1181, NULL, 724, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14821, 7543, NULL, 4912, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14822, 1926, NULL, 4912, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2110, 2576, NULL, 742, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2111, 1283, NULL, 743, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2112, 2578, NULL, 743, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2113, 305, NULL, 743, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2114, 1269, NULL, 743, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2115, 114, NULL, 744, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2116, 2579, NULL, 744, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2117, 2581, NULL, 744, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2118, 2862, NULL, 744, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2119, 792, NULL, 745, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2120, 2583, NULL, 745, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2121, 2586, NULL, 745, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2122, 2591, NULL, 746, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2123, 2595, NULL, 746, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2124, 2599, NULL, 746, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2129, 2604, NULL, 748, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2130, 920, NULL, 748, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2131, 2606, NULL, 749, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2132, 2610, NULL, 750, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2133, 1955, NULL, 750, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2134, 2611, NULL, 750, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2135, 2163, NULL, 751, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2136, 2211, NULL, 751, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2137, 2615, NULL, 751, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2138, 2617, NULL, 752, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2139, 403, NULL, 752, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2140, 1026, NULL, 752, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2141, 1997, NULL, 752, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2142, 2618, NULL, 753, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2143, 2619, NULL, 753, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2144, 1505, NULL, 753, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14838, 3628, NULL, 4916, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14839, 7548, NULL, 4917, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14840, 1875, NULL, 4917, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14841, 3057, NULL, 4917, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14842, 792, NULL, 4917, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14847, 7550, NULL, 4919, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14848, 2010, NULL, 4919, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14849, 973, NULL, 4919, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14850, 2892, NULL, 4919, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14851, 7556, NULL, 4919, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14852, 7551, NULL, 4920, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14853, 3270, NULL, 4920, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14854, 2007, NULL, 4920, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14855, 2625, NULL, 4920, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14856, 7552, NULL, 4921, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14857, 7553, NULL, 4921, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14858, 340, NULL, 4922, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14859, 3009, NULL, 4922, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14860, 1880, NULL, 4922, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14861, 1442, NULL, 4923, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14862, 320, NULL, 4923, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14863, 5581, NULL, 4923, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14864, 765, NULL, 4923, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14825, 8, NULL, 4913, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14827, 3622, NULL, 4913, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14826, 5786, NULL, 4913, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14824, 7544, NULL, 4913, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14865, 1735, NULL, 4924, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14866, 1238, NULL, 4924, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14867, 452, NULL, 4924, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14868, 2943, NULL, 4924, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14869, 7423, NULL, 4925, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14870, 7557, NULL, 4925, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14871, 219, NULL, 4925, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14872, 1175, NULL, 4926, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14873, 1777, NULL, 4926, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14874, 2478, NULL, 4926, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14875, 1472, NULL, 4926, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14876, 1307, NULL, 4927, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14877, 2931, NULL, 4927, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14878, 7558, NULL, 4927, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14879, 2163, NULL, 4927, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28490, 1091, NULL, 8867, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28491, 770, NULL, 8867, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2145, 2626, NULL, 753, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2146, 2632, NULL, 754, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2147, 2633, NULL, 754, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2148, 2647, NULL, 755, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2149, 2655, NULL, 755, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2150, 2656, NULL, 755, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2151, 452, NULL, 756, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2152, 792, NULL, 756, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2153, 2657, NULL, 756, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2154, 2658, NULL, 756, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2158, 1625, NULL, 758, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2159, 2659, NULL, 758, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2160, 2661, NULL, 758, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2161, 2662, NULL, 758, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2162, 1777, NULL, 758, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2163, 1463, NULL, 759, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2164, 2663, NULL, 759, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2165, 2665, NULL, 759, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2166, 2668, NULL, 759, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2167, 2672, NULL, 760, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2168, 2673, NULL, 760, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2169, 2674, NULL, 760, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2170, 2682, NULL, 760, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2171, 2684, NULL, 761, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2172, 769, NULL, 762, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2173, 2688, NULL, 762, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2174, 655, NULL, 762, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2175, 2691, NULL, 762, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2176, 2571, NULL, 763, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2177, 2693, NULL, 763, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2178, 93, NULL, 763, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2179, 2695, NULL, 764, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2180, 1485, NULL, 764, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2181, 2697, NULL, 764, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2182, 2699, NULL, 764, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2183, 1970, NULL, 765, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2156, 773, NULL, 757, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2157, 1311, NULL, 757, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2155, 1609, NULL, 757, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14843, 7549, NULL, 4918, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14845, 2399, NULL, 4918, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14846, 1181, NULL, 4918, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14844, 4578, NULL, 4918, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2184, 2197, NULL, 765, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2185, 932, NULL, 765, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2186, 2700, NULL, 765, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2187, 1462, NULL, 766, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2188, 141, NULL, 766, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2189, 346, NULL, 766, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2190, 1997, NULL, 766, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2191, 2701, NULL, 767, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2192, 1374, NULL, 768, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2193, 2704, NULL, 768, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2194, 1219, NULL, 768, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2195, 364, NULL, 769, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2225, 103, NULL, 716, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2197, 2711, NULL, 769, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2198, 1389, NULL, 770, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2199, 2713, NULL, 770, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2200, 2714, NULL, 770, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2201, 2715, NULL, 770, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2206, 180, NULL, 772, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2207, 2718, NULL, 772, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2208, 2196, NULL, 772, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2209, 1159, NULL, 773, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2210, 2721, NULL, 773, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2211, 1740, NULL, 773, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2212, 1186, NULL, 774, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2213, 1030, NULL, 774, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2214, 1221, NULL, 774, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2215, 1191, NULL, 775, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2216, 1898, NULL, 775, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2217, 2556, NULL, 775, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2218, 432, NULL, 778, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2219, 1347, NULL, 778, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2220, 456, NULL, 778, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2221, 1019, NULL, 613, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2222, 376, NULL, 613, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2223, 1664, NULL, 613, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2224, 398, NULL, 613, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2232, 2159, NULL, 728, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2233, 320, NULL, 728, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2234, 2727, NULL, 728, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2235, 1786, NULL, 728, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2236, 206, NULL, 786, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14880, 1054, NULL, 4928, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14881, 312, NULL, 4928, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14882, 688, NULL, 4928, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14883, 1716, NULL, 4928, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14884, 485, NULL, 4929, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14885, 7559, NULL, 4929, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14886, 2379, NULL, 4929, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14887, 2407, NULL, 4929, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14888, 1682, NULL, 4930, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14889, 2808, NULL, 4930, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14890, 2492, NULL, 4930, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14891, 1956, NULL, 4930, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14892, 1194, NULL, 4931, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14893, 1313, NULL, 4931, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14894, 2616, NULL, 4931, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14895, 302, NULL, 4931, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14896, 5620, NULL, 4931, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14897, 2730, NULL, 2958, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14898, 1421, NULL, 2958, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14899, 6898, NULL, 4932, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14902, 1257, NULL, 372, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14903, 1257, NULL, 1435, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14904, 1257, NULL, 3446, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14905, 3516, NULL, 3737, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14906, 3516, NULL, 1846, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14907, 423, NULL, 1127, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14908, 423, NULL, 2847, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14909, 423, NULL, 1244, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14910, 433, 243, 2707, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14912, 1732, NULL, 3816, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14913, 1732, NULL, 3219, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14914, 1732, NULL, 3000, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2229, 2349, NULL, 716, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2230, 1089, NULL, 716, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2227, 1135, NULL, 716, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14920, 3261, NULL, 1377, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28493, 2822, NULL, 8868, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28494, 967, NULL, 8868, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28501, 12044, NULL, 8871, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28502, 12045, NULL, 8871, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28503, 12046, NULL, 8871, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28557, 1621, NULL, 8884, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28558, 857, NULL, 8884, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28559, 19, NULL, 8884, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28560, 2821, NULL, 8884, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28613, 1578, NULL, 8857, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28693, 1450, NULL, 8918, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28694, 12179, NULL, 8918, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28695, 12180, NULL, 8918, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28745, 12207, NULL, 6239, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28746, 104, NULL, 6239, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28747, 12208, NULL, 6239, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28748, 1216, NULL, 6239, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28749, 12207, NULL, 6239, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28750, 12209, NULL, 6240, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2237, 2735, NULL, 786, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2238, 2736, NULL, 786, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2239, 2748, NULL, 787, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2240, 2750, NULL, 787, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2241, 2524, NULL, 787, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2242, 1767, NULL, 788, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2243, 1653, NULL, 788, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2244, 394, NULL, 788, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2245, 1270, NULL, 789, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2246, 68, NULL, 789, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2247, 2438, NULL, 789, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2248, 218, NULL, 789, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2249, 1826, NULL, 790, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2250, 1370, NULL, 790, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2251, 2753, NULL, 790, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2252, 282, NULL, 791, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2253, 16, NULL, 791, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2254, 441, NULL, 792, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2255, 188, NULL, 792, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2256, 1385, NULL, 792, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14919, 380, NULL, 1864, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14911, 1732, NULL, 1036, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14900, 5552, NULL, 4933, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14901, 4381, NULL, 4933, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2257, 1670, NULL, 793, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2258, 1063, NULL, 793, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2259, 224, NULL, 793, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2260, 1053, NULL, 793, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2261, 1475, NULL, 794, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2262, 287, NULL, 794, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2263, 318, NULL, 795, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2264, 232, NULL, 795, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2265, 1263, NULL, 795, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2266, 943, NULL, 795, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2267, 939, NULL, 796, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2268, 2754, NULL, 796, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2269, 2089, NULL, 796, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2270, 2895, NULL, 796, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2271, 1504, NULL, 797, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2272, 1208, NULL, 797, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2273, 403, NULL, 797, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2274, 2413, NULL, 797, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2275, 791, NULL, 798, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2276, 2416, NULL, 798, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2277, 608, NULL, 798, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2278, 1458, NULL, 455, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2279, 2761, NULL, 455, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2280, 2773, NULL, 455, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2281, 1541, NULL, 455, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2282, 733, NULL, 457, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2283, 652, NULL, 457, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2284, 1691, NULL, 457, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2285, 2757, NULL, 457, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2286, 1103, NULL, 458, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2287, 1447, NULL, 458, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2288, 1423, NULL, 458, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2289, 2762, NULL, 458, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2290, 1942, NULL, 460, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2291, 1528, NULL, 460, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2292, 2763, NULL, 460, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2293, 278, NULL, 460, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2294, 1540, NULL, 462, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2295, 2188, NULL, 462, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2296, 2429, NULL, 462, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2297, 1958, NULL, 462, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2298, 598, NULL, 463, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2299, 706, NULL, 463, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2300, 19, NULL, 463, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2301, 2259, NULL, 463, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14915, 160, NULL, 242, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2196, 9714, 479, 769, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32817, 13848, NULL, 10165, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32816, 13847, NULL, 10165, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32818, 13849, NULL, 10165, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2310, 1768, NULL, 445, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2311, 2671, NULL, 445, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2312, 1452, NULL, 445, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2313, 2670, NULL, 445, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2314, 696, NULL, 446, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2315, 2765, NULL, 446, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2316, 2767, NULL, 446, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2317, 2768, NULL, 446, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2318, 1154, NULL, 447, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2319, 2996, NULL, 447, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2320, 2616, NULL, 447, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2321, 2929, NULL, 447, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2322, 469, NULL, 448, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2323, 2769, NULL, 448, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2324, 2771, NULL, 448, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2325, 2777, NULL, 448, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14929, 1416, NULL, 1455, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14930, 863, NULL, 1455, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14931, 2996, NULL, 1455, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14932, 2506, NULL, 1455, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14933, 7182, NULL, 1456, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14934, 7196, NULL, 1456, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14935, 7177, NULL, 1457, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14936, 4614, NULL, 1457, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14937, 7178, NULL, 1457, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14938, 1651, NULL, 1459, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14939, 5905, NULL, 1459, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14940, 5503, NULL, 1459, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14941, 5519, NULL, 1459, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14948, 5920, NULL, 1461, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14949, 5919, NULL, 1461, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14950, 5921, NULL, 1461, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14951, 5922, NULL, 1461, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14952, 7183, NULL, 1462, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14953, 5923, NULL, 1464, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14954, 5924, NULL, 1464, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14955, 5913, NULL, 1464, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14956, 1882, NULL, 4717, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14957, 7560, NULL, 2052, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14958, 182, NULL, 2163, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14959, 5126, NULL, 4469, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14960, 5126, NULL, 2603, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14961, 563, NULL, 2513, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14962, 1152, NULL, 2513, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32821, 2281, NULL, 10166, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28495, 520, NULL, 8869, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28496, 388, NULL, 8869, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28497, 1506, NULL, 8869, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28561, 2680, NULL, 8885, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28562, 5931, NULL, 8885, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28563, 5956, NULL, 8885, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28564, 2952, NULL, 8885, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28505, 12048, NULL, 8871, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28696, 9533, NULL, 8918, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28751, 1687, NULL, 6240, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28752, 376, NULL, 6240, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2330, 1287, NULL, 450, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2331, 1192, NULL, 450, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2332, 2778, NULL, 450, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2333, 2781, NULL, 450, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2334, 1144, NULL, 451, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2335, 2165, NULL, 451, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2336, 2783, NULL, 451, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2337, 2784, NULL, 451, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2338, 197, NULL, 452, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2339, 708, NULL, 452, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2340, 2785, NULL, 452, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2341, 2787, NULL, 452, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2342, 1467, NULL, 799, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2343, 2792, NULL, 799, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33087, 2806, NULL, 10228, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2344, 2793, NULL, 799, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2345, 1835, NULL, 799, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2346, 1480, NULL, 800, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2347, 785, NULL, 800, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2348, 829, NULL, 800, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2349, 2794, NULL, 800, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2350, 1218, NULL, 801, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2351, 1026, NULL, 801, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2352, 1542, NULL, 801, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2353, 1814, NULL, 801, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2354, 1401, NULL, 802, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2355, 2856, NULL, 802, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2356, 2577, NULL, 802, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2357, 1435, NULL, 803, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2358, 2786, NULL, 803, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2359, 2285, NULL, 803, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2360, 2742, NULL, 803, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2361, 1559, NULL, 804, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2362, 943, NULL, 804, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2363, 1288, NULL, 805, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2364, 2795, NULL, 805, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2365, 2796, NULL, 805, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2366, 2797, NULL, 805, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2367, 1286, NULL, 806, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2368, 2692, NULL, 806, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2369, 1901, NULL, 806, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2370, 2720, NULL, 806, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2371, 451, NULL, 807, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2372, 2399, NULL, 807, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2373, 1424, NULL, 807, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2374, 1778, NULL, 807, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2375, 446, NULL, 808, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2376, 2799, NULL, 808, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2377, 1890, NULL, 808, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2378, 456, NULL, 808, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2383, 349, NULL, 810, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2384, 2804, NULL, 810, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2385, 2806, NULL, 810, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2386, 2808, NULL, 810, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2387, 1757, NULL, 811, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2388, 304, NULL, 811, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2389, 2809, NULL, 811, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2390, 2812, NULL, 811, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2391, 1809, NULL, 812, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2392, 2815, NULL, 812, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2393, 2386, NULL, 812, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2394, 2492, NULL, 812, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2395, 771, NULL, 813, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2396, 2104, NULL, 813, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2397, 2816, NULL, 813, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2398, 1550, NULL, 813, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2399, 1592, NULL, 814, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2400, 2517, NULL, 814, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2401, 2796, NULL, 814, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2402, 1208, NULL, 814, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2403, 1513, NULL, 815, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2404, 2903, NULL, 815, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2405, 2817, NULL, 815, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2406, 2821, NULL, 815, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2407, 854, NULL, 819, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2408, 2849, NULL, 819, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2409, 2850, NULL, 819, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2410, 2851, NULL, 819, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2411, 2012, NULL, 819, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2412, 2136, NULL, 819, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2413, 2852, NULL, 819, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2414, 809, NULL, 819, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (2415, 2655, NULL, 818, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2416, 2844, NULL, 818, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2417, 2867, NULL, 818, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2418, 1986, NULL, 818, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2419, 1604, NULL, 817, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2420, 2843, NULL, 817, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2421, 2347, NULL, 817, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14964, 987, NULL, 3745, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14965, 403, NULL, 432, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14966, 497, NULL, 4241, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14968, 1778, NULL, 134, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14969, 1732, NULL, 134, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14970, 6764, NULL, 1470, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14971, 6764, NULL, 2600, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14972, 6764, NULL, 1262, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14973, 858, NULL, 4673, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14974, 2300, NULL, 4673, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14922, 5912, NULL, 1453, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14925, 117, NULL, 1454, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14926, 929, NULL, 1454, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14927, 985, NULL, 1454, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2327, 2234, NULL, 449, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2328, 2567, NULL, 449, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2326, 1530, NULL, 449, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14942, 3519, NULL, 1460, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14945, 5776, NULL, 1460, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14943, 3520, NULL, 1460, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14946, 1249, NULL, 1460, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32819, 973, NULL, 10166, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32820, 9505, 283, 10166, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2379, 171, NULL, 809, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2380, 1949, NULL, 809, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2307, 228, NULL, 465, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2306, 1108, NULL, 465, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2308, 2764, NULL, 465, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2309, 1385, NULL, 465, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28618, 12101, NULL, 8901, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28619, 10357, NULL, 8901, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28620, 12103, NULL, 8901, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14975, 2555, NULL, 4673, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14976, 5567, NULL, 4673, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14977, 1862, NULL, 4673, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14982, 234, NULL, 4678, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14983, 4726, NULL, 4678, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14984, 2534, NULL, 4678, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14985, 2413, NULL, 4678, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14989, 1687, NULL, 4680, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14990, 2538, NULL, 4680, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14991, 2968, NULL, 4680, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14992, 2576, NULL, 4680, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14993, 1659, NULL, 4672, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14994, 7576, NULL, 4672, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14995, 3236, NULL, 4679, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14996, 1406, NULL, 4679, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14997, 1219, NULL, 4679, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14998, 688, NULL, 4679, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14999, 7577, NULL, 4675, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15000, 2522, NULL, 4675, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15001, 5666, NULL, 4675, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15002, 2309, NULL, 4677, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15003, 2461, NULL, 4677, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15004, 2463, NULL, 4677, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15005, 398, NULL, 4677, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15006, 542, NULL, 4676, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15007, 1732, NULL, 4676, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15008, 7578, NULL, 4676, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15009, 5634, NULL, 4681, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15010, 333, NULL, 4681, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15011, 1578, NULL, 4681, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15012, 599, NULL, 4681, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15013, 7579, NULL, 4671, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15014, 90, NULL, 4671, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15015, 7059, NULL, 4671, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15016, 2411, NULL, 4671, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15017, 329, NULL, 4682, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2422, 2657, NULL, 817, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2423, 608, NULL, 817, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2424, 1169, NULL, 821, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2425, 2864, NULL, 821, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2426, 2865, NULL, 821, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2427, 2855, NULL, 820, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2428, 2858, NULL, 820, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2429, 2861, NULL, 820, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2430, 1945, NULL, 820, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2431, 1472, NULL, 822, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2432, 682, NULL, 822, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2433, 2868, NULL, 822, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2434, 2873, NULL, 822, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2437, 2927, NULL, 824, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2438, 2875, NULL, 824, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2439, 2878, NULL, 824, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2440, 727, NULL, 824, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2441, 2879, NULL, 824, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2442, 2881, NULL, 824, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2443, 2882, NULL, 824, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2444, 2883, NULL, 825, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2445, 1528, NULL, 825, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2446, 2786, NULL, 825, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2447, 2886, NULL, 825, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2448, 2888, NULL, 825, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2453, 2896, NULL, 827, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2454, 233, NULL, 827, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2455, 2906, NULL, 827, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2456, 2369, NULL, 827, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2457, 1042, NULL, 827, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2458, 1852, NULL, 827, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (14967, 497, NULL, 2286, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2469, 2798, NULL, 832, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2470, 2931, NULL, 832, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2471, 2932, NULL, 832, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2472, 763, NULL, 832, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2473, 419, NULL, 833, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2474, 2074, NULL, 833, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2475, 1657, NULL, 833, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2476, 2369, NULL, 833, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2477, 1113, NULL, 834, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2478, 2933, NULL, 834, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2479, 2937, NULL, 834, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2480, 2912, NULL, 834, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2481, 2340, NULL, 834, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2482, 1099, NULL, 835, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2483, 2941, NULL, 835, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2484, 812, NULL, 835, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2485, 2946, NULL, 835, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2486, 2947, NULL, 835, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2487, 890, NULL, 836, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2488, 465, NULL, 836, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2489, 1588, NULL, 836, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2490, 2948, NULL, 836, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2491, 2949, NULL, 837, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2492, 2950, NULL, 837, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2493, 2952, NULL, 837, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2494, 1198, NULL, 838, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2495, 2954, NULL, 838, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2496, 2958, NULL, 838, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2497, 2963, NULL, 838, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2498, 2965, NULL, 839, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2499, 284, NULL, 839, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2500, 2103, NULL, 839, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2501, 2975, NULL, 840, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2502, 532, NULL, 840, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2503, 2979, NULL, 840, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2504, 2980, NULL, 840, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2505, 1585, NULL, 841, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2506, 2981, NULL, 841, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2507, 2982, NULL, 841, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2512, 2999, NULL, 844, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2513, 2897, NULL, 844, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2514, 3000, NULL, 844, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2515, 3001, NULL, 844, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2516, 2614, NULL, 661, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2517, 3005, NULL, 418, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2518, 3007, NULL, 418, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2519, 3008, NULL, 418, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2520, 649, NULL, 511, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2521, 3009, NULL, 511, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2522, 792, NULL, 511, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2523, 2294, NULL, 511, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2524, 1898, NULL, 512, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2525, 1117, NULL, 512, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2526, 2218, NULL, 512, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2527, 1865, NULL, 513, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2528, 2278, NULL, 513, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2529, 3010, NULL, 513, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2530, 3011, NULL, 513, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2531, 2609, NULL, 514, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2532, 2489, NULL, 514, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2533, 3012, NULL, 514, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2435, 400, NULL, 823, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2436, 2214, NULL, 823, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2461, 2910, NULL, 828, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2459, 783, NULL, 828, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2460, 1448, NULL, 828, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2468, 2925, NULL, 830, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2466, 2921, NULL, 830, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2534, 164, NULL, 514, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2535, 1026, NULL, 514, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2536, 1542, NULL, 514, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2537, 3014, NULL, 514, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2538, 902, NULL, 514, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (2539, 615, NULL, 515, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2540, 123, NULL, 515, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2541, 2332, NULL, 515, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2542, 1334, NULL, 515, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2543, 1595, NULL, 516, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2544, 434, NULL, 516, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2545, 3015, NULL, 516, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2546, 3016, NULL, 516, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2547, 115, NULL, 517, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2548, 3017, NULL, 517, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2549, 3018, NULL, 517, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15018, 1385, NULL, 4682, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15019, 914, NULL, 4682, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15020, 1179, NULL, 4682, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15021, 1404, NULL, 4683, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15022, 8, NULL, 4683, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15023, 1460, NULL, 4683, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15024, 488, NULL, 4683, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15025, 2561, NULL, 1277, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15026, 584, NULL, 662, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (15027, 891, NULL, 1582, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15028, 1594, NULL, 1167, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15029, 1917, NULL, 2417, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15032, 1785, NULL, 4937, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14987, 1929, NULL, 4670, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14988, 2549, NULL, 4670, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14986, 7575, NULL, 4670, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2449, 2316, NULL, 826, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2451, 2893, NULL, 826, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2450, 2889, NULL, 826, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15033, 1511, NULL, 4938, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15034, 6101, NULL, 4938, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15035, 3301, NULL, 4940, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2550, 1929, NULL, 517, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2551, 204, NULL, 518, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2552, 3019, NULL, 518, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2553, 975, NULL, 518, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2554, 3020, NULL, 518, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2555, 90, NULL, 519, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2556, 2496, NULL, 519, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2557, 3021, NULL, 519, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2558, 3022, NULL, 519, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2559, 1114, NULL, 520, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2560, 3023, NULL, 520, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2561, 2255, NULL, 520, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2562, 709, NULL, 520, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2563, 2532, NULL, 520, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2564, 3013, NULL, 520, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2565, 686, NULL, 520, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2566, 122, NULL, 520, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (2571, 1808, NULL, 522, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2572, 3026, NULL, 522, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2573, 3027, NULL, 522, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2574, 2657, NULL, 522, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2575, 645, NULL, 523, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2576, 3028, NULL, 523, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2577, 2145, NULL, 523, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2578, 2430, NULL, 523, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2583, 2022, NULL, 847, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2584, 3035, NULL, 847, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2585, 3036, NULL, 847, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2586, 3037, NULL, 847, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2587, 3038, NULL, 848, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2588, 3039, NULL, 848, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2589, 3040, NULL, 848, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2590, 3041, NULL, 848, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2591, 97, NULL, 849, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2592, 3042, NULL, 849, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2593, 1906, NULL, 849, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2594, 3043, NULL, 850, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2595, 1059, NULL, 851, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2596, 3044, NULL, 851, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2597, 709, NULL, 851, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2598, 3045, NULL, 851, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2599, 687, NULL, 851, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2600, 3046, NULL, 851, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2601, 1485, NULL, 851, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2602, 806, NULL, 852, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2603, 3047, NULL, 852, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2604, 602, NULL, 852, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2605, 3048, NULL, 852, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2606, 2202, NULL, 853, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2607, 1858, NULL, 853, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2608, 3049, NULL, 853, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2609, 2857, NULL, 853, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2610, 2706, NULL, 854, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2611, 3030, NULL, 854, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2612, 3050, NULL, 854, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2613, 3051, NULL, 854, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2618, 3055, NULL, 856, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2619, 757, NULL, 857, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2620, 1926, NULL, 857, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2621, 688, NULL, 857, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2622, 3056, NULL, 857, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2623, 1345, NULL, 858, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2624, 2294, NULL, 858, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2625, 2753, NULL, 858, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2626, 3057, NULL, 858, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2627, 1294, NULL, 859, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2628, 2445, NULL, 859, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2629, 2447, NULL, 859, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2630, 377, NULL, 860, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2631, 618, NULL, 860, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2632, 1730, NULL, 860, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2633, 3060, NULL, 860, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2582, 3031, NULL, 845, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2570, 3025, NULL, 521, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2569, 3024, NULL, 521, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2568, 2144, NULL, 521, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2567, 1588, NULL, 521, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2634, 3061, NULL, 861, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2635, 665, NULL, 861, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2636, 398, NULL, 861, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2637, 1445, NULL, 862, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2638, 2305, NULL, 862, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2639, 2522, NULL, 862, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2640, 220, NULL, 863, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2641, 2752, NULL, 863, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2642, 1541, NULL, 863, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15036, 3302, NULL, 4940, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15037, 3303, NULL, 4940, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15038, 3304, NULL, 4940, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15039, 273, NULL, 1080, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15040, 855, NULL, 1080, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15041, 7123, NULL, 4946, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15042, 7119, NULL, 4946, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15043, 7582, NULL, 4947, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15044, 7583, NULL, 4948, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15045, 1655, NULL, 4948, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15046, 1091, NULL, 4948, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15047, 1629, NULL, 4948, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15048, 7584, NULL, 4949, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15049, 2645, NULL, 4949, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15050, 7585, NULL, 4949, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15051, 7586, NULL, 4949, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15052, 7587, NULL, 4950, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15053, 577, NULL, 4950, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15054, 2668, NULL, 4950, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15055, 2285, NULL, 4950, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15056, 7588, NULL, 4951, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15057, 234, NULL, 4951, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15058, 1542, NULL, 4951, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15059, 91, NULL, 4951, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15060, 7589, NULL, 4952, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15061, 7590, NULL, 4952, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15062, 7591, NULL, 4952, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15063, 7592, NULL, 4952, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15064, 2129, NULL, 4953, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15065, 7593, NULL, 4954, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15066, 7594, NULL, 4955, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15067, 7595, NULL, 4955, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15068, 1687, NULL, 4955, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15069, 78, NULL, 4955, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15070, 7596, NULL, 4956, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15071, 318, NULL, 4956, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15072, 1732, NULL, 4956, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15073, 76, NULL, 4956, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15074, 2871, NULL, 4957, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15075, 805, NULL, 4957, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15076, 2814, NULL, 4958, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15077, 7189, NULL, 4958, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28498, 864, NULL, 8870, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28499, 482, NULL, 8870, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28500, 171, NULL, 8870, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28506, 12049, NULL, 8872, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28507, 10217, NULL, 8872, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28508, 10682, NULL, 8872, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28565, 7547, NULL, 8886, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28566, 12084, NULL, 8886, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28567, 7317, NULL, 8886, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28697, 206, NULL, 8919, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28698, 12181, NULL, 8919, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28699, 5979, NULL, 8919, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28753, 692, NULL, 8932, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28754, 771, NULL, 8932, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28755, 450, NULL, 8932, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28759, 188, NULL, 6242, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28760, 2379, NULL, 6242, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28761, 12210, NULL, 6242, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28762, 2555, NULL, 6242, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2643, 1514, NULL, 863, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2644, 1505, NULL, 863, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2645, 3062, NULL, 864, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2646, 1241, NULL, 864, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2647, 452, NULL, 864, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2648, 2706, NULL, 864, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2649, 1585, NULL, 865, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2650, 2095, NULL, 865, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2651, 285, NULL, 865, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2652, 1386, NULL, 866, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2653, 2860, NULL, 866, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2654, 152, NULL, 867, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2655, 3064, NULL, 867, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2656, 3065, NULL, 867, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2657, 3066, NULL, 867, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2658, 1093, NULL, 868, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2659, 2449, NULL, 868, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2660, 532, NULL, 868, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2661, 1821, NULL, 868, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2674, 3068, NULL, 12, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2675, 3069, NULL, 12, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2676, 3070, NULL, 12, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2677, 385, NULL, 71, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2678, 3071, NULL, 71, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2679, 2117, NULL, 71, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2680, 3072, NULL, 71, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2684, 964, NULL, 249, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2685, 299, NULL, 249, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2686, 295, NULL, 249, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2687, 3079, NULL, 252, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2688, 757, NULL, 274, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2689, 3080, NULL, 274, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2690, 1800, NULL, 274, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2694, 2076, NULL, 367, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2695, 1238, NULL, 367, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2696, 182, NULL, 372, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2697, 2298, NULL, 372, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2698, 1518, NULL, 456, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2699, 2511, NULL, 456, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2700, 347, NULL, 456, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2701, 2628, NULL, 456, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2702, 2614, NULL, 367, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2703, 326, NULL, 459, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2704, 3059, NULL, 459, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2705, 2627, NULL, 459, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2706, 3081, NULL, 459, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2707, 1200, NULL, 461, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2708, 3082, NULL, 461, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2709, 3083, NULL, 461, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2710, 3084, NULL, 461, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2711, 992, NULL, 466, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2712, 3085, NULL, 466, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2713, 3086, NULL, 466, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2714, 979, NULL, 466, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2715, 35, NULL, 871, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2716, 3087, NULL, 871, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2717, 1370, NULL, 871, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2718, 328, NULL, 871, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2719, 967, NULL, 872, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2720, 1701, NULL, 872, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2721, 3088, NULL, 872, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2722, 3089, NULL, 872, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2723, 864, NULL, 873, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2724, 3090, NULL, 873, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2725, 3091, NULL, 873, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2726, 1656, NULL, 873, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2727, 179, NULL, 874, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2728, 3092, NULL, 874, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2729, 3093, NULL, 874, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2730, 463, NULL, 874, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2731, 1721, NULL, 875, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2732, 2641, NULL, 875, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2733, 3094, NULL, 875, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2734, 3095, NULL, 875, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15078, 7597, NULL, 4959, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15079, 2644, NULL, 4959, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15080, 2349, NULL, 4959, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15081, 1135, NULL, 4959, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15082, 3613, NULL, 4960, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15083, 7598, NULL, 4960, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15084, 4721, NULL, 4960, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15085, 685, NULL, 4960, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15090, 5855, NULL, 4962, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15091, 7601, NULL, 4962, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15092, 2413, NULL, 4962, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15093, 7602, NULL, 4963, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15094, 7603, NULL, 4963, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15095, 7604, NULL, 4963, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15096, 7605, NULL, 4963, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15097, 1603, NULL, 4964, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15098, 7606, NULL, 4964, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15099, 7607, NULL, 4964, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15100, 7608, NULL, 4964, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15101, 7609, NULL, 4965, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15102, 5674, NULL, 4965, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15103, 7610, NULL, 4965, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15104, 7611, NULL, 4965, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15105, 1533, NULL, 4966, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15106, 4522, NULL, 4966, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15107, 2054, NULL, 4966, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15108, 7612, NULL, 4966, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15109, 1751, NULL, 4967, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15110, 1686, NULL, 4967, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15111, 7613, NULL, 4967, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15112, 2628, NULL, 4967, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15113, 2511, NULL, 4967, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15114, 248, NULL, 4968, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15115, 7614, NULL, 4968, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15116, 2570, NULL, 4968, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15117, 2411, NULL, 4968, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15118, 1741, NULL, 4969, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15119, 7615, NULL, 4969, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28568, 7739, NULL, 8887, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28569, 3249, NULL, 8887, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28570, 2107, NULL, 8887, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28571, 3164, NULL, 8887, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28509, 117, NULL, 8872, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28625, 12108, NULL, 8903, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28628, 12111, NULL, 8903, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28700, 10148, NULL, 8919, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28756, 1620, NULL, 6241, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28757, 4690, NULL, 6241, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28758, 3853, NULL, 6241, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28763, 2762, NULL, 6242, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2735, 3096, NULL, 875, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2736, 1360, NULL, 876, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2737, 3097, NULL, 876, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2738, 3098, NULL, 876, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2739, 3099, NULL, 876, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2740, 1838, NULL, 877, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2741, 1249, NULL, 877, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2742, 3100, NULL, 877, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2743, 3101, NULL, 877, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2744, 1051, NULL, 878, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2745, 2992, NULL, 878, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2746, 3102, NULL, 878, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2747, 3103, NULL, 878, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2748, 1327, NULL, 879, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2749, 3104, NULL, 879, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2750, 715, NULL, 879, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2751, 1018, NULL, 879, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2752, 1512, NULL, 880, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2753, 3105, NULL, 880, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2754, 2583, NULL, 880, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2755, 3106, NULL, 880, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2756, 411, NULL, 881, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2757, 3107, NULL, 881, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2758, 3108, NULL, 881, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2759, 3109, NULL, 881, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2760, 2379, NULL, 881, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2761, 111, NULL, 881, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2762, 789, NULL, 881, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2763, 3111, NULL, 882, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2764, 21, NULL, 882, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2765, 2556, NULL, 882, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2766, 702, NULL, 883, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2767, 3112, NULL, 883, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2768, 537, NULL, 883, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2769, 1643, NULL, 883, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2770, 1665, NULL, 884, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2771, 1965, NULL, 884, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2772, 78, NULL, 884, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2773, 2191, NULL, 884, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2774, 1689, NULL, 885, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2775, 337, NULL, 885, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2776, 2397, NULL, 885, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2777, 3114, NULL, 885, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2667, 305, NULL, 869, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2669, 1979, NULL, 869, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (2663, 773, NULL, 869, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2662, 915, NULL, 869, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32827, 812, NULL, 10167, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32826, 1138, NULL, 10167, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32828, 11399, NULL, 10167, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2778, 3014, NULL, 885, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2779, 1668, NULL, 885, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2780, 1609, NULL, 885, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2781, 1830, NULL, 886, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2782, 3009, NULL, 886, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2783, 792, NULL, 886, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2784, 3125, NULL, 886, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2785, 628, NULL, 887, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2786, 3118, NULL, 887, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2787, 3119, NULL, 887, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2788, 1386, NULL, 887, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2789, 413, NULL, 888, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2790, 272, NULL, 888, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2791, 3120, NULL, 888, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2794, 937, NULL, 890, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2795, 50, NULL, 890, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2796, 1786, NULL, 890, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2797, 1197, NULL, 891, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2798, 288, NULL, 891, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2799, 3024, NULL, 891, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2800, 1294, NULL, 891, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2801, 34, NULL, 892, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2802, 3122, NULL, 892, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2803, 3123, NULL, 892, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2804, 2434, NULL, 892, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2805, 1414, NULL, 831, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2813, 1731, NULL, 894, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2814, 2120, NULL, 894, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2815, 1024, NULL, 894, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2816, 2349, NULL, 894, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2817, 2448, NULL, 894, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2818, 1166, NULL, 894, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2819, 3113, NULL, 894, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2824, 1488, NULL, 896, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2825, 1649, NULL, 896, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2826, 3126, NULL, 896, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2827, 3127, NULL, 896, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15120, 7616, NULL, 4969, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15121, 1303, NULL, 4970, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15122, 7617, NULL, 4970, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15123, 7618, NULL, 4970, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15124, 7619, NULL, 4970, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15129, 5148, NULL, 4972, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15130, 7624, NULL, 4972, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15131, 1116, NULL, 4973, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15132, 7625, NULL, 4973, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15133, 7626, NULL, 4973, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15134, 7627, NULL, 4973, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15139, 7630, NULL, 4975, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15140, 7631, NULL, 4975, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15141, 7632, NULL, 4975, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15142, 7633, NULL, 4975, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15143, 7634, NULL, 4975, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15144, 913, NULL, 4962, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15145, 3960, NULL, 4976, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15146, 1875, NULL, 4976, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15147, 1643, NULL, 4976, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15148, 41, NULL, 4977, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15149, 4165, NULL, 4977, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15150, 1724, NULL, 4978, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15151, 7636, NULL, 4978, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15152, 733, NULL, 4979, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15153, 4617, NULL, 4979, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15154, 2436, NULL, 4979, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15155, 7637, NULL, 4980, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15156, 7638, NULL, 4980, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15157, 5366, NULL, 4980, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15158, 757, NULL, 4981, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15159, 4315, NULL, 4981, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15160, 210, NULL, 4982, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15161, 4467, NULL, 4982, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28510, 12050, NULL, 8873, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28511, 12051, NULL, 8873, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28512, 12052, NULL, 8873, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28701, 588, NULL, 8920, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28702, 346, 276, 8920, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28703, 692, 277, 8920, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28704, 12182, NULL, 8920, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28764, 12211, NULL, 6242, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (28765, 9488, NULL, 6242, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2832, 1219, NULL, 898, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2833, 3129, NULL, 898, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2834, 2753, NULL, 898, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2835, 2294, NULL, 898, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2836, 3130, NULL, 898, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2837, 3021, NULL, 898, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2838, 2657, NULL, 898, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2839, 2067, NULL, 898, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (2840, 967, NULL, 899, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2841, 556, NULL, 899, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2842, 861, NULL, 899, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2843, 1771, NULL, 899, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2844, 3131, NULL, 899, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2845, 3132, NULL, 900, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2846, 1821, NULL, 900, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2847, 2877, NULL, 900, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2848, 3133, NULL, 900, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2849, 3134, NULL, 900, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2850, 2028, NULL, 900, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2851, 3135, NULL, 900, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2852, 3007, NULL, 900, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (2853, 1785, NULL, 901, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2854, 963, NULL, 901, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2855, 3136, NULL, 901, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2860, 1353, NULL, 700, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2865, 137, NULL, 907, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2866, 1482, NULL, 908, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2867, 3143, NULL, 908, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2868, 3144, NULL, 908, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2869, 3141, NULL, 907, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2870, 3142, NULL, 907, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2875, 1638, NULL, 910, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2876, 570, NULL, 910, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2877, 3146, NULL, 910, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2878, 726, NULL, 910, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2879, 1453, NULL, 911, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2880, 692, NULL, 911, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2881, 921, NULL, 911, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2882, 2631, NULL, 911, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2883, 210, NULL, 912, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2884, 256, NULL, 912, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2885, 649, NULL, 912, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2886, 385, NULL, 913, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2887, 2413, NULL, 913, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2888, 2414, NULL, 913, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2889, 497, NULL, 915, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2890, 576, NULL, 915, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2891, 1190, NULL, 915, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2892, 2536, NULL, 915, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2893, 129, NULL, 916, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2894, 586, NULL, 916, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2895, 2505, NULL, 916, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2896, 209, NULL, 916, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2897, 1535, NULL, 918, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2898, 3148, NULL, 918, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2899, 747, NULL, 918, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2900, 699, NULL, 918, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2901, 487, NULL, 917, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2902, 2922, NULL, 917, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2903, 2492, NULL, 917, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2904, 3147, NULL, 917, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2905, 1650, NULL, 920, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2906, 3149, NULL, 920, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2907, 1919, NULL, 920, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2908, 2786, NULL, 920, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2913, 3151, NULL, 924, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2914, 3152, NULL, 924, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2915, 2652, NULL, 924, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2916, 2410, NULL, 924, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2917, 1503, NULL, 925, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2918, 2628, NULL, 925, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2919, 2717, NULL, 925, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15162, 1533, NULL, 4983, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15163, 317, NULL, 4983, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15164, 1714, NULL, 4983, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15165, 415, NULL, 4984, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15166, 7639, NULL, 4984, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15167, 2646, NULL, 4985, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15127, 7622, NULL, 4971, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15126, 7621, NULL, 4971, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15128, 7623, NULL, 4971, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2859, 3139, NULL, 902, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2856, 1013, 444, 902, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2857, 3137, NULL, 902, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15125, 7620, NULL, 4971, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15136, 7628, NULL, 4974, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15138, 7629, NULL, 4974, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15137, 5893, NULL, 4974, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2830, 88, NULL, 897, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2829, 682, NULL, 897, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2828, 1264, NULL, 897, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2831, 3128, NULL, 897, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2909, 442, NULL, 923, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2912, 2636, NULL, 923, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2910, 1542, NULL, 923, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28572, 340, NULL, 8888, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28574, 12085, NULL, 8888, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28573, 3168, NULL, 8888, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2793, 1352, NULL, 889, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2874, 182, NULL, 909, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2872, 2077, NULL, 909, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2871, 627, NULL, 909, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2873, 3145, NULL, 909, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15168, 551, NULL, 4986, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15169, 7640, NULL, 4986, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15170, 8, NULL, 4986, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15171, 2757, NULL, 4986, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15172, 687, NULL, 4987, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15173, 7641, NULL, 4987, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15174, 7545, NULL, 4997, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15175, 1826, NULL, 4998, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15176, 7643, NULL, 4999, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15177, 7644, NULL, 5000, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15178, 299, NULL, 5002, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15179, 3405, NULL, 5003, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15180, 1113, NULL, 5004, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15182, 719, NULL, 5006, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15183, 4677, NULL, 5007, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15184, 220, NULL, 5008, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15185, 537, NULL, 5009, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15186, 156, NULL, 5010, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15187, 1620, NULL, 5011, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15188, 1427, NULL, 5012, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15189, 1636, NULL, 5023, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15190, 2625, NULL, 5012, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15191, 7653, NULL, 5012, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15192, 1114, NULL, 5012, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15193, 611, NULL, 5013, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15194, 1662, NULL, 5013, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15195, 1687, NULL, 5013, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15196, 78, NULL, 5013, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15197, 7128, NULL, 5014, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15198, 2981, NULL, 5014, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15199, 7212, NULL, 5014, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15200, 1899, NULL, 5014, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15201, 2240, NULL, 5015, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15202, 1862, NULL, 5015, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15203, 5949, NULL, 5015, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15204, 2316, NULL, 5015, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28513, 12053, NULL, 8874, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28514, 12054, NULL, 8874, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28515, 12055, NULL, 8874, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28575, 4260, NULL, 8889, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28576, 12086, NULL, 8889, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28577, 12087, NULL, 8889, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28578, 12088, NULL, 8889, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28705, 7575, NULL, 8921, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28706, 8507, 278, 8921, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28707, 2788, NULL, 8921, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28766, 10125, NULL, 6228, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28767, 12212, NULL, 6228, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28768, 12213, NULL, 6228, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28769, 7155, NULL, 6229, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2920, 541, NULL, 925, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2921, 3153, NULL, 926, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2922, 2017, NULL, 926, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2923, 3154, NULL, 926, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2924, 3155, NULL, 926, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2925, 1734, NULL, 927, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2926, 2093, NULL, 927, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2927, 785, NULL, 927, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2928, 1102, NULL, 927, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2932, 3156, NULL, 929, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2933, 1916, NULL, 929, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2934, 853, NULL, 929, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2935, 3157, NULL, 929, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2936, 850, NULL, 930, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2937, 2652, NULL, 930, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2938, 2112, NULL, 930, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2939, 3158, NULL, 930, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2940, 226, NULL, 931, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2941, 687, NULL, 931, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2942, 2240, NULL, 931, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2943, 2899, NULL, 931, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2944, 2103, NULL, 932, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2945, 2144, NULL, 932, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2946, 500, NULL, 933, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2947, 3159, NULL, 933, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2948, 3160, NULL, 933, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2949, 3161, NULL, 933, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2954, 525, NULL, 468, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2955, 266, NULL, 468, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2956, 3166, NULL, 468, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2957, 2366, NULL, 468, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2958, 683, NULL, 469, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2959, 3167, NULL, 469, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2960, 3168, NULL, 469, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2961, 3169, NULL, 469, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2962, 609, NULL, 470, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2963, 3170, NULL, 470, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2964, 3171, NULL, 470, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2965, 3172, NULL, 471, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2966, 3173, NULL, 471, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2967, 3174, NULL, 471, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2968, 3175, NULL, 472, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2969, 3176, NULL, 473, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2970, 828, NULL, 473, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2971, 3177, NULL, 473, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2862, 3140, NULL, 906, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2972, 3178, NULL, 473, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2973, 96, NULL, 474, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2974, 3179, NULL, 474, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2975, 3180, NULL, 474, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2976, 2487, NULL, 474, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2977, 1353, NULL, 475, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2978, 3181, NULL, 475, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2979, 3182, NULL, 475, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2980, 3183, NULL, 475, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2981, 474, NULL, 476, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2982, 1469, NULL, 477, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2983, 3184, NULL, 477, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2984, 3185, NULL, 477, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2985, 3186, NULL, 478, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2986, 3187, NULL, 478, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2987, 371, NULL, 934, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2988, 1769, NULL, 934, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2989, 3190, NULL, 934, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2990, 3192, NULL, 935, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2991, 3193, NULL, 935, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2992, 457, NULL, 936, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2993, 13, NULL, 936, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2994, 1505, NULL, 936, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2995, 1541, NULL, 936, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3001, 5, NULL, 938, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3002, 3196, NULL, 938, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3003, 3197, NULL, 938, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3004, 3198, NULL, 938, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3005, 532, NULL, 939, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3006, 3199, NULL, 939, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3007, 3200, NULL, 939, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3008, 3201, NULL, 939, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3009, 3224, NULL, 939, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3015, 333, NULL, 941, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3016, 3205, NULL, 941, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3017, 2012, NULL, 941, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3018, 3020, NULL, 941, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3019, 3206, NULL, 941, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3020, 3207, NULL, 942, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3021, 3208, NULL, 942, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3022, 3209, NULL, 942, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3023, 2945, NULL, 942, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3024, 439, NULL, 943, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3025, 1943, NULL, 943, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3026, 3210, NULL, 943, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3027, 1385, NULL, 944, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3028, 3211, NULL, 944, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3029, 3212, NULL, 944, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3030, 1777, NULL, 944, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3031, 3213, NULL, 944, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3032, 3214, NULL, 944, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3033, 3215, NULL, 944, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (3034, 1831, NULL, 945, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3035, 2507, NULL, 945, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3036, 3216, NULL, 945, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3037, 141, NULL, 945, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3038, 1844, NULL, 945, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3039, 2127, NULL, 945, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3040, 3217, NULL, 945, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (3041, 3218, NULL, 945, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (3042, 1514, NULL, 946, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3043, 3219, NULL, 946, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3044, 3220, NULL, 946, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3045, 952, NULL, 946, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20730, 10117, NULL, 6507, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20734, 10121, NULL, 6507, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2931, 2031, NULL, 928, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2930, 2110, NULL, 928, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2929, 539, NULL, 928, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3046, 955, NULL, 946, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3047, 972, NULL, 946, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3048, 2532, NULL, 946, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15205, 1801, NULL, 5016, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15206, 7654, NULL, 5016, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15207, 1085, NULL, 5016, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15208, 2081, NULL, 5016, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15209, 1657, NULL, 5017, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15210, 7130, NULL, 5017, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15211, 7656, NULL, 5017, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15212, 378, NULL, 5018, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15213, 2358, NULL, 5018, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15214, 613, NULL, 5018, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15215, 1148, NULL, 5018, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15216, 1262, NULL, 5019, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15217, 626, NULL, 5019, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15218, 7448, NULL, 5019, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15219, 3957, NULL, 5019, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15220, 1018, NULL, 5020, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15221, 2957, NULL, 5020, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3049, 2932, NULL, 946, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (3050, 533, NULL, 903, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3051, 975, NULL, 903, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3052, 1578, NULL, 903, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3053, 3221, NULL, 903, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3054, 1575, NULL, 905, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3055, 3222, NULL, 905, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3056, 2159, NULL, 905, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3057, 1965, NULL, 905, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3058, 2616, NULL, 905, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3059, 3057, NULL, 905, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3060, 3223, NULL, 905, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (3061, 398, NULL, 905, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (3097, 2308, NULL, 379, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3098, 1855, NULL, 859, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3099, 84, NULL, 882, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3100, 3441, NULL, 487, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3101, 2532, NULL, 487, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3102, 3442, NULL, 487, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3103, 763, NULL, 487, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3104, 796, NULL, 701, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3105, 2364, NULL, 701, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3106, 3443, NULL, 701, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3107, 281, NULL, 701, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3108, 96, NULL, 955, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3109, 3444, NULL, 955, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3110, 2816, NULL, 955, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3111, 27, NULL, 955, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3112, 2379, NULL, 956, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3113, 416, NULL, 956, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3114, 1566, NULL, 956, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3115, 1048, NULL, 956, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3116, 3445, NULL, 957, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3117, 2238, NULL, 957, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3118, 3446, NULL, 957, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3119, 3447, NULL, 957, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3120, 3448, NULL, 958, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3121, 3449, NULL, 958, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3122, 2242, NULL, 958, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3123, 1821, NULL, 958, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3124, 3450, NULL, 959, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3125, 1089, NULL, 959, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3126, 3451, NULL, 959, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3127, 266, NULL, 959, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3128, 3452, NULL, 960, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3129, 3453, NULL, 960, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3130, 2406, NULL, 961, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3131, 2026, NULL, 961, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3132, 2972, NULL, 961, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3133, 2041, NULL, 961, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3134, 3454, NULL, 962, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3135, 1581, NULL, 962, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3136, 3455, NULL, 962, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3137, 1088, NULL, 962, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3138, 3456, NULL, 963, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3139, 3390, NULL, 963, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3140, 1929, NULL, 963, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3141, 2457, NULL, 963, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15222, 150, NULL, 5020, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15223, 389, NULL, 5020, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15224, 2644, NULL, 5020, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15225, 136, NULL, 5020, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15226, 7657, NULL, 5020, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15227, 502, NULL, 5020, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (28644, 12124, NULL, 8906, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15232, 753, NULL, 5022, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15233, 2943, NULL, 5022, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15234, 1880, NULL, 5022, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15235, 2442, NULL, 5023, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15236, 1772, NULL, 5024, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15237, 7003, NULL, 5024, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15238, 4331, NULL, 5024, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15239, 162, NULL, 5024, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15240, 1036, NULL, 5025, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15241, 7126, NULL, 5025, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15242, 7658, NULL, 5025, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15243, 7659, NULL, 5025, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15244, 5666, NULL, 5017, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15245, 3049, NULL, 5026, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15246, 682, NULL, 5026, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15247, 6978, NULL, 5026, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15248, 7612, NULL, 5026, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15249, 7600, NULL, 5027, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15250, 7670, NULL, 5027, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15254, 2769, NULL, 5029, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2998, 1875, NULL, 937, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3013, 3204, NULL, 940, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3012, 3203, NULL, 940, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3014, 3225, NULL, 940, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3010, 543, NULL, 940, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3011, 3202, NULL, 940, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15255, 1696, NULL, 5029, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15256, 7673, NULL, 5029, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15257, 598, NULL, 5029, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15258, 692, NULL, 5029, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15259, 5958, NULL, 5029, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15260, 3884, NULL, 5029, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15261, 2905, NULL, 5029, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (3091, 27, NULL, 953, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3092, 2017, NULL, 953, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28516, 4614, NULL, 8874, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28517, 12056, NULL, 8874, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28518, 12057, NULL, 8874, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (28579, 11479, NULL, 8890, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28580, 424, NULL, 8890, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28581, 685, NULL, 8890, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28708, 12183, NULL, 8922, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28770, 9097, NULL, 6229, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28771, 12214, NULL, 6229, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3142, 1500, NULL, 380, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3143, 2007, NULL, 380, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3144, 259, NULL, 380, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3145, 1687, NULL, 964, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3146, 3610, NULL, 964, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3147, 3611, NULL, 964, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3151, 3613, NULL, 966, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3152, 1331, NULL, 966, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3153, 3614, NULL, 966, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3154, 1600, NULL, 966, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3155, 3615, NULL, 966, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3156, 3616, NULL, 966, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3157, 487, NULL, 966, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15229, 7590, NULL, 5021, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15228, 7589, NULL, 5021, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3075, 3227, NULL, 948, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3074, 3226, NULL, 948, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3073, 2000, NULL, 948, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3084, 177, NULL, 951, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3082, 1192, NULL, 951, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3062, 569, NULL, 914, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3063, 2226, NULL, 914, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3065, 3194, NULL, 914, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3066, 2948, NULL, 919, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3068, 2780, NULL, 919, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3067, 1588, NULL, 919, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3069, 1659, NULL, 919, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3071, 1875, NULL, 921, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3072, 2692, NULL, 921, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3070, 1664, NULL, 921, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3077, 316, NULL, 949, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3078, 1048, NULL, 949, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3079, 2869, NULL, 950, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3080, 3229, NULL, 950, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3083, 1311, NULL, 951, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3081, 2939, NULL, 951, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3086, 2042, NULL, 952, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3087, 2285, NULL, 952, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3088, 2895, NULL, 952, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3085, 3150, NULL, 952, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32839, 2181, NULL, 10171, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28642, 2037, NULL, 8906, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28645, 12125, NULL, 8906, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3094, 32, NULL, 954, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3093, 369, NULL, 954, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3096, 1031, NULL, 954, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3095, 3230, NULL, 954, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3089, 2559, NULL, 953, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3148, 403, NULL, 965, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3150, 1067, NULL, 965, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3149, 3612, NULL, 965, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3158, 522, NULL, 967, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3159, 1894, NULL, 967, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3160, 2992, NULL, 967, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3161, 1934, NULL, 967, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3162, 1624, NULL, 968, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3163, 1707, NULL, 968, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3164, 920, NULL, 968, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3165, 943, NULL, 969, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3166, 3617, NULL, 969, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3167, 3618, NULL, 969, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3168, 1826, NULL, 970, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3169, 3619, NULL, 970, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3170, 3620, NULL, 970, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3171, 1488, NULL, 971, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3172, 3270, NULL, 971, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3173, 3135, NULL, 971, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3174, 1096, NULL, 972, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3175, 3198, NULL, 972, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3176, 1609, NULL, 972, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3177, 3566, NULL, 973, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3178, 3621, NULL, 973, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3179, 3622, NULL, 973, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3180, 3623, NULL, 973, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3181, 3624, NULL, 973, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3182, 3625, NULL, 973, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3183, 3626, NULL, 973, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (3184, 1401, NULL, 974, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3185, 2931, NULL, 974, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3186, 688, NULL, 974, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3187, 3627, NULL, 975, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3188, 3628, NULL, 975, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3189, 741, NULL, 975, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3190, 3071, NULL, 975, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3191, 3629, NULL, 975, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3192, 3630, NULL, 975, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3193, 2644, NULL, 975, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (3194, 1085, NULL, 976, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3195, 3631, NULL, 976, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3196, 3632, NULL, 976, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3197, 470, NULL, 741, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3198, 1400, NULL, 748, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3199, 2711, NULL, 414, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3200, 1086, NULL, 935, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3201, 1421, NULL, 249, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3202, 297, NULL, 424, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3205, 4109, NULL, 978, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3206, 1249, NULL, 978, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3207, 4110, NULL, 978, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3208, 2265, NULL, 978, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3209, 4111, NULL, 979, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3210, 4112, NULL, 979, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3211, 4113, NULL, 980, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3212, 4114, NULL, 980, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3213, 4115, NULL, 980, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3218, 4117, NULL, 982, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3219, 4118, NULL, 982, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3220, 4119, NULL, 983, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3221, 4120, NULL, 983, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3222, 4121, NULL, 984, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3223, 4122, NULL, 984, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3224, 4136, NULL, 985, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3225, 4123, NULL, 985, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3226, 4124, NULL, 985, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3227, 4125, NULL, 985, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15270, 7662, NULL, 5032, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15271, 7678, NULL, 5032, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15272, 326, NULL, 5032, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15273, 7663, NULL, 5033, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15277, 7664, NULL, 5035, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15278, 6443, NULL, 5035, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15279, 2192, NULL, 5035, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15280, 7665, NULL, 5036, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15281, 7680, NULL, 5036, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15282, 3036, NULL, 5036, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15283, 7681, NULL, 5037, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15284, 2134, NULL, 5037, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15285, 5286, NULL, 5037, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15286, 7682, NULL, 5037, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15287, 1637, NULL, 5037, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15288, 4778, NULL, 5037, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15289, 2017, NULL, 5037, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15290, 6377, NULL, 5037, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (15291, 7683, NULL, 5037, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (15302, 7668, NULL, 5041, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15303, 7669, NULL, 5041, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15304, 7704, NULL, 5046, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15305, 2155, NULL, 5042, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3232, 857, NULL, 987, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3233, 4137, NULL, 987, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28519, 12058, NULL, 8874, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (28520, 7310, NULL, 8874, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (28582, 2748, NULL, 8891, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28583, 2473, NULL, 8891, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28584, 4828, NULL, 8891, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28585, 4242, NULL, 8891, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28709, 1041, NULL, 8923, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28710, 10864, NULL, 8923, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28711, 2347, 279, 8923, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28712, 6376, NULL, 8923, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28775, 1702, NULL, 6231, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28776, 12216, NULL, 6231, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28777, 1048, NULL, 6231, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28778, 12217, NULL, 6232, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3236, 4131, NULL, 989, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3237, 4132, NULL, 990, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3238, 4133, NULL, 990, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3239, 4134, NULL, 991, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3240, 4135, NULL, 991, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3241, 3158, NULL, 742, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3242, 3032, NULL, 846, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3243, 3033, NULL, 846, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3244, 109, NULL, 846, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3245, 3034, NULL, 846, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3246, 4532, NULL, 704, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3247, 3749, NULL, 255, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3248, 730, NULL, 368, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3249, 1899, NULL, 603, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3250, 1554, NULL, 992, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3251, 962, NULL, 992, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3252, 879, NULL, 992, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3253, 145, NULL, 992, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3254, 964, NULL, 992, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3255, 4716, NULL, 992, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3256, 10195, NULL, 993, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3257, 3706, NULL, 993, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3258, 4719, NULL, 993, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3259, 4720, NULL, 993, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3260, 568, NULL, 994, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3261, 960, NULL, 994, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3262, 344, NULL, 995, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3263, 4721, NULL, 995, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3264, 1095, NULL, 996, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3265, 433, NULL, 996, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3266, 435, NULL, 996, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3267, 4727, NULL, 995, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3268, 4722, NULL, 997, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3269, 4723, NULL, 998, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3270, 1152, NULL, 998, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3271, 1751, NULL, 999, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3272, 1686, NULL, 999, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3273, 1839, NULL, 1000, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3274, 4724, NULL, 1000, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3275, 4725, NULL, 1000, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3276, 1553, NULL, 1001, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3277, 440, NULL, 1001, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3278, 2572, NULL, 1001, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3279, 1508, NULL, 1001, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3280, 20, NULL, 1002, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3281, 4726, NULL, 1002, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3282, 961, NULL, 1002, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3283, 906, NULL, 1002, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3284, 2310, NULL, 1002, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3285, 129, NULL, 1002, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3286, 730, NULL, 159, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3287, 37, NULL, 988, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3288, 4402, NULL, 190, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3289, 993, NULL, 1004, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3290, 1884, NULL, 1004, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3291, 960, NULL, 291, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3292, 1373, NULL, 291, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3293, 4728, NULL, 291, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3294, 1893, NULL, 1004, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3295, 186, NULL, 1006, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3296, 2212, NULL, 1006, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3297, 839, NULL, 1006, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3298, 709, NULL, 1006, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3299, 4729, NULL, 1005, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3300, 4730, NULL, 1005, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3301, 4731, NULL, 1005, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3302, 2294, NULL, 1005, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3303, 1707, NULL, 1007, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3304, 1542, NULL, 1007, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3305, 4732, NULL, 1007, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3306, 430, NULL, 1008, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3307, 119, NULL, 1008, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3308, 2527, NULL, 1008, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3309, 405, NULL, 1008, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3310, 4733, NULL, 1009, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3311, 4734, NULL, 1009, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15298, 7655, NULL, 5040, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15300, 789, NULL, 5040, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15301, 3242, NULL, 5040, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15299, 2903, NULL, 5040, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3203, 2949, NULL, 977, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3204, 4108, NULL, 977, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3229, 4127, NULL, 986, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3231, 4129, NULL, 986, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3228, 4126, NULL, 986, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15296, 518, NULL, 5039, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15297, 2181, NULL, 5039, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15295, 7667, NULL, 5039, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15292, 7666, NULL, 5038, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15294, 2827, NULL, 5038, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15293, 1565, NULL, 5038, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15276, 7679, NULL, 5034, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15274, 3050, NULL, 5034, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15275, 2614, NULL, 5034, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3312, 4735, NULL, 1009, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3317, 857, NULL, 1011, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3318, 2536, NULL, 1011, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3319, 789, NULL, 1011, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3320, 1112, NULL, 1012, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3321, 2031, NULL, 1012, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3322, 4114, NULL, 1012, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3323, 4737, NULL, 1013, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3324, 4738, NULL, 1013, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3325, 2258, NULL, 1013, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3326, 2662, NULL, 1013, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15306, 405, NULL, 5042, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15307, 687, NULL, 5042, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15308, 2240, NULL, 5042, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15309, 271, NULL, 5043, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15310, 141, NULL, 5043, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15311, 741, NULL, 5043, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15312, 1943, NULL, 5043, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15313, 1801, NULL, 5044, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15314, 4176, NULL, 5044, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15315, 2231, NULL, 5044, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15316, 7718, NULL, 5044, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15317, 1332, NULL, 5045, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15318, 3749, NULL, 5045, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15319, 1967, NULL, 5045, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15320, 7719, NULL, 5045, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15321, 51, NULL, 5046, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15322, 5282, NULL, 5046, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15323, 4996, NULL, 5046, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15324, 2830, NULL, 5047, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15325, 4904, NULL, 5047, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15326, 1940, NULL, 5047, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15327, 200, NULL, 5047, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15328, 2144, NULL, 4904, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15329, 2144, NULL, 4651, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15330, 2144, NULL, 5048, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15331, 285, NULL, 5048, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15332, 5895, NULL, 5048, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15333, 1389, NULL, 5049, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15334, 2514, NULL, 5049, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15335, 2658, NULL, 5049, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15336, 5961, NULL, 5049, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15337, 923, NULL, 5050, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15338, 1681, NULL, 5050, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15339, 5534, NULL, 5050, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15340, 2278, NULL, 5050, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15341, 3513, NULL, 5050, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15342, 1785, NULL, 5051, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15343, 963, NULL, 5051, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15344, 3136, NULL, 5051, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15345, 1683, NULL, 5052, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15346, 7720, NULL, 5052, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15347, 7721, NULL, 5052, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28586, 3244, NULL, 8892, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28587, 5779, NULL, 8892, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28713, 923, NULL, 8924, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28714, 12184, NULL, 8924, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28715, 8521, 280, 8924, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28716, 12185, NULL, 8924, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28779, 12218, NULL, 6232, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28780, 2597, NULL, 6232, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3327, 794, NULL, 1015, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3328, 1971, NULL, 1015, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3329, 3009, NULL, 1015, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3330, 2159, NULL, 1015, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3331, 4034, NULL, 1016, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3332, 4740, NULL, 1016, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3333, 4741, NULL, 1016, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3334, 1876, NULL, 1016, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3335, 4739, NULL, 1014, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3336, 239, NULL, 1014, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3337, 1099, NULL, 1014, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3338, 220, NULL, 1017, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3339, 914, NULL, 1017, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3340, 13, NULL, 1017, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3341, 1648, NULL, 1017, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3342, 2948, NULL, 1018, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3343, 4742, NULL, 1018, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3344, 4743, NULL, 1018, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3345, 4744, NULL, 1018, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28652, 12131, NULL, 8908, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3234, 182, NULL, 987, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28649, 12128, NULL, 8907, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28648, 1971, NULL, 8907, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3235, 4130, NULL, 987, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3346, 1902, NULL, 1019, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3347, 2871, NULL, 1019, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3348, 283, NULL, 1020, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3349, 955, NULL, 1020, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3350, 1179, NULL, 1020, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3351, 1728, NULL, 1020, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3352, 360, NULL, 1021, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3353, 2138, NULL, 1021, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3354, 3315, NULL, 1021, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3355, 1965, NULL, 1021, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3356, 138, NULL, 1237, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3357, 3914, NULL, 1237, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3358, 4745, NULL, 1237, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3359, 4746, NULL, 1237, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3360, 824, NULL, 1238, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3361, 4175, NULL, 1238, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3362, 4747, NULL, 1238, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3363, 4748, NULL, 1238, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3364, 486, NULL, 1239, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3365, 4561, NULL, 1239, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3366, 1890, NULL, 1239, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3367, 2507, NULL, 1239, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3368, 1015, NULL, 1240, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3369, 2903, NULL, 1240, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3370, 19, NULL, 1240, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3371, 1352, NULL, 1241, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3372, 1621, NULL, 1241, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3373, 382, NULL, 1242, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3374, 497, NULL, 1242, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3375, 835, NULL, 1242, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3376, 1503, NULL, 1242, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3377, 2259, NULL, 1242, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3378, 685, NULL, 1242, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3379, 857, NULL, 1242, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (3380, 2478, NULL, 1242, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (3381, 2080, NULL, 1242, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (3385, 1553, NULL, 1244, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3386, 816, NULL, 1244, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3387, 1179, NULL, 1244, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3388, 974, NULL, 1245, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3389, 2623, NULL, 1245, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3390, 2095, NULL, 1245, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3391, 4751, NULL, 1245, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3392, 732, NULL, 1246, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3393, 2416, NULL, 1246, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3394, 3150, NULL, 1246, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3395, 466, NULL, 1246, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3396, 1329, NULL, 1247, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3397, 2094, NULL, 1247, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3398, 2772, NULL, 1247, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3399, 4752, NULL, 1247, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3400, 234, NULL, 1248, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3401, 915, NULL, 1248, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3402, 2120, NULL, 1248, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3403, 2104, NULL, 1248, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33090, 13956, NULL, 10229, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33091, 13957, NULL, 10230, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32842, 835, 203, 10171, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3404, 918, NULL, 1249, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3405, 3515, NULL, 1249, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3406, 567, NULL, 1249, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3407, 18, NULL, 1249, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3408, 1105, NULL, 1251, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3409, 2802, NULL, 1251, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3410, 2725, NULL, 1251, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3411, 4753, NULL, 1251, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3412, 1692, NULL, 1252, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3413, 68, NULL, 1252, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3414, 4754, NULL, 1252, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3418, 1842, NULL, 1254, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15348, 4509, NULL, 286, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15349, 360, NULL, 5055, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15350, 281, NULL, 5055, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15351, 1789, NULL, 5055, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15352, 2757, NULL, 5055, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15353, 2798, NULL, 5056, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15354, 2482, NULL, 5056, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15355, 1263, NULL, 5056, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15356, 6997, NULL, 5056, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15357, 698, NULL, 5057, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15358, 533, NULL, 5057, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15359, 2822, NULL, 5057, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15360, 1368, NULL, 5057, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15361, 958, NULL, 5058, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15362, 7003, NULL, 5058, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15363, 1096, NULL, 5058, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15364, 430, NULL, 5059, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15365, 389, NULL, 5059, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15366, 2386, NULL, 5059, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15367, 41, NULL, 5059, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15368, 2846, NULL, 5060, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15369, 7742, NULL, 5060, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15370, 2304, NULL, 5060, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3316, 4736, NULL, 1010, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3313, 1646, NULL, 1010, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3315, 2990, NULL, 1010, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15371, 4901, NULL, 5060, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15372, 2918, NULL, 5061, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15373, 1112, NULL, 5061, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15374, 2505, NULL, 5061, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15375, 2943, NULL, 5061, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15376, 239, NULL, 5062, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15377, 1624, NULL, 5062, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15378, 692, NULL, 5062, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15379, 480, NULL, 5063, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15380, 2240, NULL, 5063, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15381, 1699, NULL, 5063, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15382, 405, NULL, 5063, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15383, 1590, NULL, 5064, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15384, 973, NULL, 5064, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15385, 7556, NULL, 5064, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15386, 2702, NULL, 5064, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15387, 1542, NULL, 5065, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15388, 2321, NULL, 5065, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15389, 2285, NULL, 5065, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15390, 1781, NULL, 5065, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32843, 1322, NULL, 10172, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28588, 377, NULL, 8893, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28589, 12089, NULL, 8893, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28590, 12090, NULL, 8893, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28591, 12091, NULL, 8893, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28658, 2957, NULL, 8909, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28659, 2399, NULL, 8909, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28660, 3236, NULL, 8909, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28717, 7587, NULL, 8925, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28718, 7678, 185, 8925, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28719, 9901, NULL, 8925, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28720, 12186, NULL, 8925, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28798, 3207, NULL, 6236, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (28799, 12222, NULL, 6236, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3419, 829, NULL, 1254, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3420, 4401, NULL, 1254, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3421, 1841, NULL, 1256, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3422, 1140, NULL, 1256, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3423, 2816, NULL, 1256, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3424, 2611, NULL, 1256, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3425, 310, NULL, 1257, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3426, 1858, NULL, 1257, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3427, 4756, NULL, 1257, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3428, 1473, NULL, 1258, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3429, 1378, NULL, 1258, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3430, 3524, NULL, 1258, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3431, 242, NULL, 1258, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3432, 183, NULL, 1259, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3433, 2120, NULL, 1259, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3434, 834, NULL, 1259, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3435, 4758, NULL, 1259, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3436, 253, NULL, 1260, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3437, 2525, NULL, 1260, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3438, 4759, NULL, 1260, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3439, 4760, NULL, 1260, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3440, 953, NULL, 1261, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3441, 952, NULL, 1261, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3442, 914, NULL, 1261, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3443, 1825, NULL, 1262, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3444, 445, NULL, 1262, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3445, 761, NULL, 1263, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3446, 90, NULL, 1263, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3447, 850, NULL, 1263, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3448, 986, NULL, 1264, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3449, 2414, NULL, 1264, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3450, 692, NULL, 1264, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3451, 126, NULL, 1265, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3452, 76, NULL, 1265, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3453, 4761, NULL, 1265, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3454, 1717, NULL, 1266, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3455, 1431, NULL, 1266, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3456, 806, NULL, 1266, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3457, 1732, NULL, 1267, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3458, 955, NULL, 1267, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3459, 188, NULL, 1267, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3460, 4663, NULL, 1269, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3461, 1179, NULL, 1269, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3462, 1415, NULL, 1270, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3463, 1665, NULL, 1270, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3464, 1106, NULL, 1270, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3465, 176, NULL, 1271, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3466, 773, NULL, 1271, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3467, 1659, NULL, 1271, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3468, 960, NULL, 1272, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28653, 12132, NULL, 8908, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3469, 378, NULL, 1272, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3470, 1655, NULL, 1272, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3471, 2802, NULL, 1272, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3472, 64, NULL, 1273, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3473, 463, NULL, 1273, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3474, 2718, NULL, 1273, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3475, 341, NULL, 1274, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3476, 1343, NULL, 1274, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3477, 4395, NULL, 1274, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3478, 375, NULL, 1274, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3479, 1814, NULL, 1275, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3480, 773, NULL, 1275, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3481, 4762, NULL, 1275, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3482, 145, NULL, 1276, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3483, 652, NULL, 1276, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3484, 2456, NULL, 1276, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3485, 2031, NULL, 1276, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3486, 1046, NULL, 1277, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3487, 1943, NULL, 1277, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3488, 755, NULL, 1278, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3489, 1956, NULL, 1278, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3490, 3140, NULL, 1278, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3491, 1600, NULL, 1278, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3492, 928, NULL, 1279, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3493, 403, NULL, 1279, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3494, 1955, NULL, 1279, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3495, 4461, NULL, 1280, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3496, 4765, NULL, 1280, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3497, 4766, NULL, 1280, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3498, 1672, NULL, 1281, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3499, 4065, NULL, 1281, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3500, 19, NULL, 1281, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3501, 2772, NULL, 1281, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3502, 873, NULL, 1282, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3503, 1136, NULL, 1282, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3504, 4531, NULL, 1282, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3505, 3841, NULL, 1282, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3506, 1257, NULL, 1283, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3507, 867, NULL, 1283, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3508, 1042, NULL, 1283, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3509, 824, NULL, 1284, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3510, 3546, NULL, 1284, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3511, 425, NULL, 1284, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3512, 4767, NULL, 1284, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3513, 2118, NULL, 1285, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3514, 2816, NULL, 1285, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3515, 2144, NULL, 1285, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3517, 1621, NULL, 1286, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3518, 857, NULL, 1286, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3519, 19, NULL, 1286, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3520, 4566, NULL, 1286, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3521, 4610, NULL, 1287, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3522, 109, NULL, 1287, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3523, 1067, NULL, 1287, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3524, 920, NULL, 1287, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3525, 362, NULL, 1288, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3526, 2544, NULL, 1288, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3416, 3754, NULL, 1253, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3415, 1110, NULL, 1253, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3527, 951, NULL, 1288, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3528, 593, NULL, 1288, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3529, 1262, NULL, 1289, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3530, 1282, NULL, 1289, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3531, 4232, NULL, 1289, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3532, 608, NULL, 1289, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3533, 277, 166, 1290, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3534, 2236, NULL, 1290, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3535, 2278, NULL, 1290, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3536, 2146, NULL, 1290, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3537, 3093, NULL, 1291, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3538, 3232, NULL, 1291, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3539, 1030, NULL, 1291, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3540, 1227, NULL, 1292, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3541, 4473, NULL, 1292, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3542, 943, NULL, 1292, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3543, 622, NULL, 1293, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3544, 2423, NULL, 1293, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3545, 2093, NULL, 1293, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3546, 503, NULL, 1293, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3547, 624, NULL, 1294, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15391, 1603, NULL, 5066, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15392, 1926, NULL, 5066, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15393, 220, NULL, 5066, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15394, 1334, NULL, 5066, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15395, 2956, NULL, 4626, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15396, 7743, NULL, 4626, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15397, 7744, NULL, 4626, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15398, 5184, NULL, 4626, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15399, 3028, NULL, 4627, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15400, 7129, NULL, 4627, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15402, 7745, NULL, 4629, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15403, 1929, NULL, 4630, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15404, 7746, NULL, 4630, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15405, 7747, NULL, 4630, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15406, 3127, NULL, 4630, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15407, 316, NULL, 4631, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3548, 1050, NULL, 1294, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3549, 3323, NULL, 1294, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3550, 770, NULL, 1295, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3551, 3706, NULL, 1295, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3552, 4769, NULL, 1295, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3553, 820, NULL, 1296, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3554, 481, NULL, 1296, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3555, 3154, NULL, 1296, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3556, 2525, NULL, 1296, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3557, 1673, NULL, 1297, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3558, 1400, NULL, 1297, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3559, 1843, NULL, 1298, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3560, 4770, NULL, 1298, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3561, 4771, NULL, 1298, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3562, 578, NULL, 1299, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3563, 743, NULL, 1299, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3564, 1018, NULL, 1299, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3565, 1627, NULL, 1300, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3566, 3524, NULL, 1300, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3567, 3862, NULL, 1300, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3568, 124, NULL, 1301, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3569, 914, NULL, 1301, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3570, 2492, NULL, 1301, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3571, 479, NULL, 1302, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3572, 930, NULL, 1302, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3573, 3373, NULL, 1302, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3574, 872, NULL, 1303, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3575, 2910, NULL, 1303, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3576, 2922, NULL, 1303, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3577, 4772, NULL, 1303, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3578, 1597, NULL, 1304, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3579, 1311, NULL, 1304, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3580, 4773, NULL, 1304, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3581, 843, NULL, 1305, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3582, 2966, NULL, 1305, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3583, 2711, NULL, 1305, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3584, 4551, NULL, 1305, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3585, 344, NULL, 1306, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3586, 1585, NULL, 1306, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3587, 285, NULL, 1306, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3588, 1788, NULL, 1306, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3589, 1000, NULL, 1307, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3590, 3476, NULL, 1307, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3591, 4775, NULL, 1307, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3592, 23, NULL, 1308, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3593, 4777, NULL, 1308, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3594, 4778, NULL, 1308, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3595, 4779, NULL, 1308, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3596, 1506, NULL, 1309, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3597, 4780, NULL, 1309, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3598, 4781, NULL, 1309, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3599, 4782, NULL, 1309, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3600, 1359, NULL, 1310, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3601, 4732, NULL, 1310, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3602, 3145, NULL, 1310, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3603, 4783, NULL, 1310, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3604, 12, NULL, 1311, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3605, 1730, NULL, 1311, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3606, 4784, NULL, 1311, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3607, 4785, NULL, 1311, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3608, 602, NULL, 1312, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3609, 2517, NULL, 1312, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3610, 4786, NULL, 1312, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3611, 4787, NULL, 1312, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3612, 905, NULL, 1313, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3613, 2956, NULL, 1313, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3614, 4788, NULL, 1313, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3615, 4789, NULL, 1313, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3616, 897, NULL, 1314, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3617, 1181, NULL, 1314, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3618, 1031, NULL, 1314, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3619, 4790, NULL, 1314, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3620, 1618, NULL, 1315, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3621, 1348, NULL, 1315, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3622, 773, NULL, 1315, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3623, 2413, NULL, 1315, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3624, 2691, NULL, 1316, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3625, 2340, NULL, 1316, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3626, 4791, NULL, 1316, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3627, 1428, NULL, 1317, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3628, 1349, NULL, 1317, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3629, 2544, NULL, 1317, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3630, 2534, NULL, 1317, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3631, 2544, NULL, 1304, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3632, 1145, NULL, 1318, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3633, 2536, NULL, 1318, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3634, 228, NULL, 1318, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3635, 3140, NULL, 1318, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3636, 1321, NULL, 1319, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3637, 2489, NULL, 1319, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3638, 4323, NULL, 1319, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3639, 424, NULL, 1320, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3640, 1916, NULL, 1320, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15408, 1902, NULL, 4631, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15409, 313, NULL, 4632, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15410, 3003, NULL, 4632, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15411, 5123, NULL, 4632, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15412, 7748, NULL, 4633, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15413, 2741, NULL, 4633, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15414, 7131, NULL, 4633, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15415, 2992, NULL, 4633, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15416, 835, NULL, 4634, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15417, 816, NULL, 4634, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15418, 688, NULL, 4634, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15419, 3023, NULL, 4634, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15420, 7749, NULL, 4635, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15421, 6763, NULL, 4635, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15422, 5499, NULL, 4636, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15423, 6413, NULL, 4636, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15424, 7750, NULL, 4636, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15425, 691, NULL, 4636, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15426, 3846, NULL, 4637, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15427, 812, NULL, 4637, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15428, 141, NULL, 4637, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15429, 2587, NULL, 4637, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15430, 2830, NULL, 4638, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15431, 1903, NULL, 4638, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15432, 7121, NULL, 4639, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15433, 7127, NULL, 4640, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15434, 1936, NULL, 4641, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15435, 1894, NULL, 4641, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15436, 7751, NULL, 4641, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15437, 1854, NULL, 4641, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15438, 3874, NULL, 885, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (15439, 3874, NULL, 2724, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15440, 6160, NULL, 3668, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15442, 445, NULL, 4754, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15443, 1101, NULL, 5075, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15444, 1524, NULL, 5075, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15445, 7780, NULL, 5080, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15446, 7781, NULL, 5080, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15447, 1567, NULL, 5081, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15448, 7782, NULL, 5081, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15449, 5504, NULL, 5081, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28527, 12060, NULL, 8876, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28528, 11664, NULL, 8876, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28529, 10684, NULL, 8876, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28592, 1528, NULL, 8894, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28593, 2524, NULL, 8894, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28594, 398, NULL, 8894, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28721, 926, 281, 8926, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28722, 6589, NULL, 8926, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28723, 570, NULL, 8926, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28724, 12187, NULL, 8926, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28785, 2219, NULL, 6234, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28786, 12219, NULL, 6234, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15441, 445, NULL, 3120, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28787, 1042, NULL, 6234, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28788, 12220, NULL, 6234, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28789, 445, NULL, 6234, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28800, 5288, NULL, 6237, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28801, 5828, NULL, 6237, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28802, 12223, NULL, 6237, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3641, 853, NULL, 1320, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3642, 2318, NULL, 1320, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3643, 1230, NULL, 1321, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3644, 1311, NULL, 1321, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3645, 834, NULL, 1321, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3646, 1192, NULL, 1321, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3647, 1204, NULL, 1322, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3648, 51, NULL, 1322, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3649, 4792, NULL, 1322, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3650, 4793, NULL, 1322, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3651, 24, NULL, 1323, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3652, 234, NULL, 1323, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3653, 2631, NULL, 1323, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3654, 1208, NULL, 1323, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3655, 1930, NULL, 1324, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3656, 2372, NULL, 1324, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3657, 1222, NULL, 1324, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3658, 4794, NULL, 1324, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3659, 825, NULL, 1325, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3660, 317, NULL, 1325, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3661, 2399, NULL, 1325, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3662, 4795, NULL, 1325, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3663, 1226, NULL, 1326, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3664, 4796, NULL, 1326, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3665, 4797, NULL, 1326, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3669, 925, NULL, 1328, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3670, 4799, NULL, 1328, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3671, 4800, NULL, 1328, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3672, 589, NULL, 1329, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3673, 4371, NULL, 1329, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3674, 3709, NULL, 1329, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3675, 1024, NULL, 1330, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3676, 1151, NULL, 1330, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3677, 4801, NULL, 1331, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3678, 4802, NULL, 1331, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3679, 4803, NULL, 1331, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3683, 1587, NULL, 1333, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3684, 2567, NULL, 1333, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3685, 4805, NULL, 1333, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3686, 764, NULL, 1334, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3687, 4055, NULL, 1334, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3688, 4551, NULL, 1334, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3689, 1251, NULL, 1335, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3690, 4806, NULL, 1335, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3691, 4807, NULL, 1335, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3692, 1237, NULL, 1336, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3693, 4808, NULL, 1336, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3694, 4809, NULL, 1336, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3695, 1276, NULL, 1337, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3696, 1196, NULL, 1337, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3697, 1385, NULL, 1337, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3698, 393, NULL, 1338, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3699, 4810, NULL, 1338, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3700, 4811, NULL, 1338, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3701, 1309, NULL, 1339, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3702, 2477, NULL, 1339, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3703, 4812, NULL, 1339, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3704, 1320, NULL, 1340, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3705, 2039, NULL, 1340, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3706, 924, NULL, 1340, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3707, 1739, NULL, 1341, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3708, 4254, NULL, 1341, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3709, 4813, NULL, 1341, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3710, 919, NULL, 1342, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3711, 4537, NULL, 1342, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3712, 4329, NULL, 1342, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3713, 1297, NULL, 1343, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3714, 4814, NULL, 1343, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3715, 3578, NULL, 1343, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3716, 1116, NULL, 1344, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3717, 2339, NULL, 1344, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3718, 1797, NULL, 1344, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3719, 911, NULL, 453, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3720, 4323, NULL, 453, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3721, 254, NULL, 453, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3722, 2122, NULL, 453, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3723, 517, NULL, 1250, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3724, 3358, NULL, 1250, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3725, 2290, NULL, 1250, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3726, 3390, NULL, 1250, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15450, 1590, NULL, 5082, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15451, 7783, NULL, 5082, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15452, 7784, NULL, 5082, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15453, 7785, NULL, 5083, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15454, 992, NULL, 5083, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15455, 5296, NULL, 5083, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15456, 7786, NULL, 5084, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15457, 1752, NULL, 5086, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15458, 1629, NULL, 5086, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15459, 7540, NULL, 5086, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15460, 2967, NULL, 5086, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15461, 794, NULL, 5087, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15462, 1502, NULL, 5087, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15463, 432, NULL, 5088, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15464, 183, NULL, 5088, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15465, 2266, NULL, 5088, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15466, 2729, NULL, 5088, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15467, 7787, NULL, 5088, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15468, 1400, NULL, 5088, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15469, 2321, NULL, 5088, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15470, 7788, NULL, 5089, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15471, 1515, NULL, 5090, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15472, 7789, NULL, 5090, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15473, 1621, NULL, 5090, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15474, 7790, NULL, 5091, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15475, 7791, NULL, 5091, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15476, 6768, NULL, 5091, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15477, 480, NULL, 5093, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15478, 6082, NULL, 5093, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15479, 7792, NULL, 5093, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15480, 3583, NULL, 5094, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15481, 7793, NULL, 5094, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15482, 7794, NULL, 5094, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15483, 7194, NULL, 5094, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15484, 382, NULL, 5095, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15485, 1329, NULL, 5095, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15486, 685, NULL, 5095, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15487, 2903, NULL, 5095, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15488, 857, NULL, 5095, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15489, 7795, NULL, 5095, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15490, 789, NULL, 5095, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15491, 497, NULL, 5095, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (28530, 10016, NULL, 8877, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28531, 12061, NULL, 8877, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28532, 12062, NULL, 8877, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28595, 1303, NULL, 8895, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28596, 11078, NULL, 8895, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28597, 4323, NULL, 8895, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28598, 5887, NULL, 8895, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28725, 179, NULL, 8927, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28726, 1402, 282, 8927, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28727, 68, NULL, 8927, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28728, 456, NULL, 8927, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28790, 10451, NULL, 6234, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (28803, 12224, NULL, 6237, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28804, 12225, NULL, 6237, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32800, 1648, 476, 10159, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33095, 10732, NULL, 10231, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20732, 10119, NULL, 6507, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3743, 1759, NULL, 1347, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3744, 3232, NULL, 1347, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3745, 1943, NULL, 1347, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3746, 2560, NULL, 1347, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3747, 1002, NULL, 1348, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3748, 2119, NULL, 1348, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3749, 2473, NULL, 1348, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3750, 4816, NULL, 1348, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3755, 498, NULL, 1350, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3756, 1989, NULL, 1350, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3757, 2674, NULL, 1350, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3758, 2903, NULL, 1350, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3759, 1644, NULL, 1351, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3760, 4817, NULL, 1351, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3680, 1236, NULL, 1332, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3682, 4804, NULL, 1332, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3681, 1410, NULL, 1332, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3761, 244, NULL, 1351, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3762, 4516, NULL, 1351, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3763, 415, NULL, 1352, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3764, 547, NULL, 1352, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3765, 2287, NULL, 1352, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3766, 2934, NULL, 1352, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3767, 1066, NULL, 1353, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3768, 1825, NULL, 1353, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3769, 1379, NULL, 1353, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3770, 447, NULL, 1354, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3771, 3530, NULL, 1354, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3772, 2590, NULL, 1354, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3773, 51, NULL, 1354, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3774, 1248, NULL, 1355, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3775, 4453, NULL, 1355, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3776, 2687, NULL, 1355, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3777, 2418, NULL, 1355, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3778, 1583, NULL, 1356, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3779, 2757, NULL, 1356, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3780, 4818, NULL, 1356, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3781, 159, NULL, 1357, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3782, 3597, NULL, 1357, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3783, 2431, NULL, 1357, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3784, 895, NULL, 1357, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3785, 342, NULL, 1358, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3786, 4819, NULL, 1358, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3787, 1219, NULL, 1358, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3788, 61, NULL, 1359, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3789, 1376, NULL, 1359, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3790, 2772, NULL, 1359, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3791, 1503, NULL, 1359, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3792, 1280, NULL, 1360, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3793, 2666, NULL, 1360, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3794, 305, NULL, 1360, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3795, 3252, NULL, 1360, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3796, 1497, NULL, 1361, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3797, 2068, NULL, 1361, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3798, 1911, NULL, 1361, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3799, 46, NULL, 1362, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3800, 355, NULL, 1362, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3801, 1099, NULL, 1362, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3802, 4820, NULL, 1362, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3803, 590, NULL, 1363, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3804, 1835, NULL, 1363, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3805, 2031, NULL, 1363, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3806, 4821, NULL, 1363, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3807, 133, NULL, 1364, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3808, 1016, NULL, 1364, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3809, 1060, NULL, 1364, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3810, 3494, NULL, 1364, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3811, 1360, NULL, 1365, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3812, 3662, NULL, 1365, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3813, 581, NULL, 1365, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3814, 2110, NULL, 1365, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3815, 13, NULL, 1366, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3816, 2922, NULL, 1366, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3817, 3850, NULL, 1366, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3818, 166, NULL, 1366, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3819, 661, NULL, 1367, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3820, 90, NULL, 1367, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3821, 429, NULL, 1367, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3822, 4379, NULL, 1367, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3823, 3588, NULL, 1368, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3824, 4188, NULL, 1368, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3825, 829, NULL, 1368, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15492, 19, NULL, 5095, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (15493, 445, NULL, 4342, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15494, 445, NULL, 3199, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15495, 7796, NULL, 5098, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15496, 2519, NULL, 5098, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15497, 510, NULL, 5098, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15498, 3642, NULL, 5098, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15499, 1498, NULL, 5099, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15500, 7132, NULL, 5099, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15501, 259, NULL, 5099, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15502, 7797, NULL, 5099, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15503, 2419, NULL, 5100, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15504, 7284, NULL, 5100, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15505, 2608, NULL, 5100, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15506, 5162, NULL, 5101, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15507, 728, NULL, 5101, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15508, 7798, NULL, 5101, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15509, 1919, NULL, 5101, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15510, 1221, NULL, 5102, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15511, 3804, NULL, 5102, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15512, 7799, NULL, 5102, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15513, 1137, NULL, 5102, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15518, 699, NULL, 5104, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15519, 7802, NULL, 5104, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15520, 3543, NULL, 5104, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15524, 3408, NULL, 5106, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15525, 3358, NULL, 5106, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15526, 168, NULL, 5106, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15527, 7285, NULL, 5107, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15528, 5590, NULL, 5107, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15529, 3288, NULL, 5107, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15530, 7804, NULL, 5107, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15531, 2963, NULL, 5108, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15532, 390, NULL, 5108, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15533, 5408, NULL, 5108, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15534, 106, NULL, 5108, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15535, 2520, NULL, 5108, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15536, 7805, NULL, 5108, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15537, 66, NULL, 5108, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (28533, 12063, NULL, 8877, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28599, 1036, NULL, 8896, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28600, 9516, NULL, 8896, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28601, 3224, NULL, 8896, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28602, 12092, NULL, 8896, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28791, 943, NULL, 6235, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28792, 7023, NULL, 6235, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3826, 4096, NULL, 1368, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3827, 724, NULL, 1369, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3828, 4822, NULL, 1369, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3829, 1437, NULL, 1369, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3830, 457, NULL, 1370, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3831, 1468, NULL, 1370, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3832, 3314, NULL, 1370, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3833, 725, NULL, 1370, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3838, 2986, NULL, 1372, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3839, 3493, NULL, 1372, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3840, 4568, NULL, 1372, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3841, 1505, NULL, 1372, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3752, 68, NULL, 1349, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3751, 640, NULL, 1349, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3753, 2489, NULL, 1349, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3735, 9, NULL, 1345, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3737, 9714, 479, 1345, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3738, 4282, NULL, 1345, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3736, 4314, NULL, 1345, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3846, 55, NULL, 1374, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3847, 1919, NULL, 1374, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3848, 1112, NULL, 1374, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3849, 1213, NULL, 1375, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3850, 4823, NULL, 1375, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3851, 1452, NULL, 1375, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3857, 3810, NULL, 1377, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3858, 3232, NULL, 1377, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3859, 1745, NULL, 1377, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3860, 1117, NULL, 1377, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (3861, 880, NULL, 1378, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3862, 375, NULL, 1378, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3863, 2620, NULL, 1378, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3864, 4003, NULL, 1378, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3865, 3353, NULL, 1380, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3866, 2577, NULL, 1380, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3867, 1832, NULL, 1380, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3868, 166, NULL, 1380, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3869, 2255, NULL, 1380, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3870, 637, NULL, 1381, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3871, 463, NULL, 1381, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3872, 860, NULL, 1381, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3873, 4825, NULL, 1381, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3874, 1515, NULL, 1382, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3875, 4826, NULL, 1382, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3876, 542, NULL, 1384, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3877, 4827, NULL, 1384, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3878, 2860, NULL, 1384, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3879, 2808, NULL, 1384, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3880, 548, NULL, 1385, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3881, 2266, NULL, 1385, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3882, 1099, NULL, 1385, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3883, 2144, NULL, 1385, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3884, 2596, NULL, 1388, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3885, 4313, NULL, 1388, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3837, 4007, NULL, 1371, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3834, 2737, NULL, 1371, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3835, 4390, NULL, 1371, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32803, 3111, NULL, 10160, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28673, 12145, NULL, 8912, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28672, 12144, NULL, 8912, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28670, 12143, NULL, 8912, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3886, 106, NULL, 1388, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3887, 4828, NULL, 1388, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3888, 427, NULL, 1389, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3889, 177, NULL, 1389, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3890, 3711, NULL, 1389, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3891, 3189, NULL, 1389, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3892, 1494, NULL, 1390, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3893, 1479, NULL, 1390, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3894, 1568, NULL, 1390, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3895, 360, NULL, 1392, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3896, 3057, NULL, 1392, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3897, 2031, NULL, 1392, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3898, 324, NULL, 1393, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3899, 555, NULL, 1393, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3900, 2517, NULL, 1393, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3901, 4829, NULL, 1393, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3902, 4830, NULL, 1393, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3903, 4831, NULL, 1393, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3904, 2177, NULL, 1393, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (3905, 2339, NULL, 1393, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (3906, 4832, NULL, 1395, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3907, 1516, NULL, 1395, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3908, 309, NULL, 1396, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3909, 2089, NULL, 1396, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3910, 4833, NULL, 1396, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3911, 103, NULL, 1397, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3912, 3797, NULL, 1397, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3913, 4834, NULL, 1397, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3914, 914, NULL, 1397, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15541, 4371, NULL, 5110, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15542, 3182, NULL, 5110, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15543, 7807, NULL, 5110, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15544, 7808, NULL, 5110, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15545, 7287, NULL, 5111, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15546, 1445, NULL, 5111, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15547, 7809, NULL, 5111, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15548, 2660, NULL, 5111, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15549, 2758, NULL, 5112, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15550, 7810, NULL, 5112, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15551, 7811, NULL, 5112, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15554, 7813, NULL, 5114, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15555, 7814, NULL, 5114, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15556, 7815, NULL, 5115, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15557, 3263, NULL, 5115, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15558, 3467, NULL, 5115, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15559, 7816, NULL, 5115, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15560, 2399, NULL, 4045, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15561, 7263, NULL, 4045, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15562, 7832, NULL, 4045, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15563, 58, NULL, 4045, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15565, 86, NULL, 4934, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15566, 7833, NULL, 4935, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15567, 2048, NULL, 4935, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15568, 6100, NULL, 4935, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15569, 7834, NULL, 4935, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15576, 963, NULL, 4937, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15577, 3136, NULL, 4937, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15578, 7836, NULL, 4937, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15579, 7837, NULL, 4938, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15580, 7541, NULL, 4938, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28534, 12064, NULL, 8878, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28535, 12065, NULL, 8878, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28536, 12066, NULL, 8878, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3853, 1853, NULL, 1376, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3854, 713, NULL, 1376, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3852, 794, NULL, 1376, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3855, 5786, NULL, 1376, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28603, 1154, NULL, 8897, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28604, 6373, NULL, 8897, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28605, 12093, NULL, 8897, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28606, 10605, NULL, 8897, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28733, 3079, NULL, 8929, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3856, 5634, 284, 1377, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28793, 5056, NULL, 6236, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28794, 3601, NULL, 6236, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28795, 2581, NULL, 6236, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28796, 2394, NULL, 6236, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28797, 12221, NULL, 6236, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28805, 78, NULL, 6238, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28806, 12226, NULL, 6238, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28807, 5390, NULL, 6238, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3919, 1008, NULL, 1399, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3920, 3832, NULL, 1399, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3921, 4835, NULL, 1399, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3922, 930, NULL, 1399, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3923, 482, NULL, 1400, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3924, 4360, NULL, 1400, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3925, 76, NULL, 1400, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3926, 955, NULL, 1400, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3927, 1172, NULL, 1401, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3928, 1042, NULL, 1401, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3929, 3438, NULL, 1401, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3930, 1126, NULL, 1401, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3931, 1533, NULL, 1402, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3932, 943, NULL, 1402, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3933, 1858, NULL, 1402, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26656, 11445, NULL, 8259, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26659, 4407, NULL, 8259, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26658, 11446, NULL, 8259, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3944, 1741, NULL, 1409, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3945, 1702, NULL, 1409, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3946, 1020, NULL, 1409, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3947, 1457, NULL, 1226, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3948, 3004, NULL, 1226, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3949, 3002, NULL, 1226, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3950, 1664, NULL, 1226, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3951, 430, NULL, 1227, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3952, 2527, NULL, 1227, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3953, 2899, NULL, 1227, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3954, 2240, NULL, 1227, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3955, 2307, NULL, 1227, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3956, 4836, NULL, 1227, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3957, 1263, NULL, 1227, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (3958, 4837, NULL, 1228, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3959, 4838, NULL, 1228, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3960, 2482, NULL, 1229, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3961, 2492, NULL, 1229, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3962, 312, NULL, 1229, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3963, 2039, NULL, 1229, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3964, 4609, NULL, 1230, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3965, 4839, NULL, 1230, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3966, 4840, NULL, 1230, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28677, 12149, NULL, 8913, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15575, 39, NULL, 4936, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15570, 3700, NULL, 4936, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3941, 2186, NULL, 1404, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3942, 2045, NULL, 1404, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3940, 506, NULL, 1404, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3943, 867, NULL, 1404, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3918, 503, NULL, 1398, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3916, 1020, NULL, 1398, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3915, 1346, NULL, 1398, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3917, 2498, NULL, 1398, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3844, 529, NULL, 1373, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3843, 625, NULL, 1373, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3842, 932, NULL, 1373, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3845, 511, NULL, 1373, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3967, 4841, NULL, 1230, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3968, 2340, NULL, 1231, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3969, 2691, NULL, 1231, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3970, 2929, NULL, 1231, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3971, 11, NULL, 1231, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3976, 1590, NULL, 1233, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3977, 2576, NULL, 1233, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3978, 1112, NULL, 1233, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3979, 4844, NULL, 1233, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3980, 2522, NULL, 1234, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3981, 2966, NULL, 1234, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3982, 2531, NULL, 1234, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3983, 141, NULL, 1234, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3984, 3797, NULL, 1234, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3985, 812, NULL, 1234, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3986, 1192, NULL, 1234, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (3987, 4845, NULL, 1235, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3988, 4846, NULL, 1235, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3989, 4847, NULL, 1235, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3990, 2007, NULL, 1236, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3991, 38, NULL, 1236, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3992, 4849, NULL, 1236, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3993, 1857, NULL, 187, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (3994, 1857, NULL, 802, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3995, 1781, NULL, 24, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3996, 1643, NULL, 24, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3997, 429, NULL, 24, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3998, 2802, NULL, 123, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3999, 1331, NULL, 123, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4000, 789, NULL, 123, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4001, 3812, NULL, 107, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4002, 1998, NULL, 107, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4003, 4671, NULL, 170, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4004, 4853, NULL, 170, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4005, 389, NULL, 235, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4006, 3850, NULL, 235, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15564, 6818, NULL, 4934, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26657, 1897, NULL, 8259, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4007, 4854, NULL, 235, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4008, 1091, NULL, 240, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4009, 586, NULL, 922, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4010, 778, NULL, 922, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4011, 1942, NULL, 922, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4015, 1687, NULL, 1383, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4016, 1437, NULL, 1383, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4017, 3752, NULL, 1383, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4018, 807, NULL, 1386, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4019, 1091, NULL, 1386, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4020, 1261, NULL, 1386, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4021, 1875, NULL, 1387, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4022, 968, NULL, 1387, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4023, 4856, NULL, 1387, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4024, 2737, NULL, 1391, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4025, 1238, NULL, 1391, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4026, 337, NULL, 1391, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4027, 3638, NULL, 1394, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4028, 4857, NULL, 1394, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4029, 3315, NULL, 1405, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4030, 2232, NULL, 1405, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4031, 4858, NULL, 1405, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4032, 608, NULL, 1406, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4033, 4859, NULL, 1406, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4034, 4083, NULL, 1407, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4035, 4861, NULL, 1407, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4036, 1390, NULL, 1407, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4037, 2, NULL, 1653, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4038, 4860, NULL, 1653, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4039, 4862, NULL, 1653, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4040, 4863, NULL, 1653, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4041, 1732, NULL, 1654, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4042, 4422, NULL, 1654, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4043, 4864, NULL, 1654, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4044, 4865, NULL, 1654, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4045, 967, NULL, 1658, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4046, 1087, NULL, 1658, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4047, 579, NULL, 1658, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15581, 7080, NULL, 4044, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15582, 193, NULL, 4813, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15583, 1238, NULL, 4939, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15584, 7838, NULL, 4939, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15585, 4385, NULL, 4939, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15586, 3860, NULL, 4939, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15587, 7839, NULL, 4939, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15588, 688, NULL, 4939, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15589, 2091, NULL, 4939, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15590, 7840, NULL, 4941, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15591, 4615, NULL, 4941, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15592, 857, NULL, 4941, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15593, 7841, NULL, 4942, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15594, 7842, NULL, 4942, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15595, 7843, NULL, 4942, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15596, 7844, NULL, 4943, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4048, 4866, NULL, 1658, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4049, 4867, NULL, 1658, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4053, 103, NULL, 1661, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4054, 4869, NULL, 1661, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4055, 4870, NULL, 1661, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4056, 4871, NULL, 1661, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4057, 38, NULL, 1663, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4058, 4872, NULL, 1663, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4059, 4873, NULL, 1656, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4060, 4874, NULL, 1656, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4061, 4875, NULL, 1656, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4062, 1364, NULL, 1655, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4063, 141, NULL, 1655, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4064, 4876, NULL, 1655, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4070, 4882, NULL, 1662, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4071, 4883, NULL, 1662, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4072, 4884, NULL, 1662, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4073, 4885, NULL, 1664, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4074, 4886, NULL, 1664, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4075, 4887, NULL, 1664, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4076, 807, NULL, 1657, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4077, 3390, NULL, 1657, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4078, 3242, NULL, 1657, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4079, 4888, NULL, 1657, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4080, 4889, NULL, 1665, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4081, 4890, NULL, 1665, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4082, 4891, NULL, 1665, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4083, 4892, NULL, 1666, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4084, 4893, NULL, 1666, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4085, 3145, NULL, 1667, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4086, 4895, NULL, 1667, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4087, 4897, NULL, 1667, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4088, 3881, NULL, 1377, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (4089, 601, NULL, 1158, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4090, 1620, NULL, 1160, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4092, 2822, NULL, 1162, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4093, 1059, NULL, 1163, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4094, 1756, NULL, 1163, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4095, 1705, NULL, 1163, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4096, 1693, NULL, 1163, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4097, 4899, NULL, 1164, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4098, 2699, NULL, 1164, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4099, 123, NULL, 1164, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4100, 783, NULL, 1164, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4101, 19, NULL, 1165, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4102, 4900, NULL, 1165, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4103, 1603, NULL, 1167, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4104, 2391, NULL, 1167, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4105, 2592, NULL, 1167, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4106, 239, NULL, 2332, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4107, 3743, NULL, 2332, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4108, 2846, NULL, 2339, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4109, 4901, NULL, 2339, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4110, 2481, NULL, 2339, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4111, 750, NULL, 2339, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4112, 545, NULL, 2628, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4113, 824, NULL, 2628, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4114, 3657, NULL, 2628, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4115, 4902, NULL, 2628, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4116, 369, NULL, 2629, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4117, 1909, NULL, 2629, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4118, 4903, NULL, 2629, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4119, 4904, NULL, 2629, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4120, 783, NULL, 2630, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4121, 996, NULL, 2630, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4122, 2860, NULL, 2630, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4123, 116, NULL, 2630, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4124, 1785, NULL, 2631, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4125, 4905, NULL, 2631, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4126, 4906, NULL, 2631, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4127, 133, NULL, 2632, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4128, 4907, NULL, 2632, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4129, 4237, NULL, 2632, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4130, 1448, NULL, 2633, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4131, 2240, NULL, 2633, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4132, 4908, NULL, 2633, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4133, 2021, NULL, 2634, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4134, 4909, NULL, 2634, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4135, 4910, NULL, 2634, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4140, 1331, NULL, 2636, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4141, 2897, NULL, 2636, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15597, 6245, NULL, 4943, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15598, 2442, NULL, 4944, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15599, 1042, NULL, 4944, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15600, 7845, NULL, 4944, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15601, 7846, NULL, 4944, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3972, 2921, NULL, 1232, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3974, 4842, NULL, 1232, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3975, 4843, NULL, 1232, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15602, 267, NULL, 4945, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15603, 281, NULL, 5116, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15604, 1954, NULL, 5116, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15605, 1934, NULL, 5116, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15606, 2364, NULL, 5116, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15607, 2948, NULL, 5117, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15608, 3846, NULL, 5117, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15609, 141, NULL, 5117, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15610, 7856, NULL, 5117, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15611, 2392, NULL, 5118, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15612, 2046, NULL, 5118, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15613, 6857, NULL, 5118, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15614, 5331, NULL, 5118, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15615, 7760, NULL, 5119, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15616, 1854, NULL, 5119, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15617, 7857, NULL, 5119, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15618, 5863, NULL, 5119, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15619, 7425, NULL, 5120, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15620, 3198, NULL, 5120, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15621, 96, NULL, 5120, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15622, 3179, NULL, 5120, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15623, 2204, NULL, 5120, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15624, 7858, NULL, 5120, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15625, 3797, NULL, 5120, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15626, 3115, NULL, 5121, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15627, 7819, NULL, 5121, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15628, 2985, NULL, 5121, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15629, 2800, NULL, 5121, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15630, 2562, NULL, 5122, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15631, 6576, NULL, 5122, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15632, 7859, NULL, 5122, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15633, 7494, NULL, 5122, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15634, 536, NULL, 5123, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15635, 3145, NULL, 5123, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15636, 7860, NULL, 5123, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4137, 4911, NULL, 2635, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4136, 854, NULL, 2635, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4139, 4912, NULL, 2635, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32814, 6443, NULL, 10164, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32815, 1021, NULL, 10164, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4013, 424, NULL, 1379, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4014, 4855, NULL, 1379, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15637, 2428, NULL, 5123, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15638, 6109, NULL, 5124, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28537, 12067, NULL, 8878, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28607, 8846, NULL, 8898, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28608, 12094, NULL, 8898, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28734, 2582, NULL, 8930, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28735, 9018, NULL, 8930, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28736, 6806, NULL, 8930, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28737, 9505, NULL, 8930, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28808, 12228, NULL, 4012, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28810, 197, NULL, 8933, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28811, 9429, NULL, 8933, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28827, 12241, NULL, 8942, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28828, 4923, NULL, 8942, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28829, 899, NULL, 8943, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28830, 2093, NULL, 8943, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28831, 8098, NULL, 8943, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28832, 1978, NULL, 8943, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28833, 12242, NULL, 8943, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28837, 807, NULL, 8945, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28838, 3481, NULL, 8945, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4142, 200, NULL, 2636, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4143, 4913, NULL, 2637, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4144, 4914, NULL, 2637, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4145, 4915, NULL, 2637, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4146, 4916, NULL, 2638, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4147, 4917, NULL, 2638, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4148, 2001, NULL, 2638, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4149, 1435, NULL, 1656, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4150, 127, NULL, 2639, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4151, 4918, NULL, 2639, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4152, 4919, NULL, 2639, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4153, 4920, NULL, 2639, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4154, 548, NULL, 2640, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4155, 1042, NULL, 2640, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4156, 3843, NULL, 2640, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4157, 4924, NULL, 2640, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4158, 797, NULL, 2641, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4159, 1385, NULL, 2641, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4160, 576, NULL, 2641, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4161, 4925, NULL, 2641, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4162, 633, NULL, 2642, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4163, 581, NULL, 2642, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4164, 4926, NULL, 2642, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4165, 4927, NULL, 2642, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4170, 1090, NULL, 2644, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4171, 4921, NULL, 2644, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4172, 4929, NULL, 2644, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4173, 4930, NULL, 2644, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28839, 1834, NULL, 8945, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4179, 2043, NULL, 2646, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4180, 3373, NULL, 2646, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4181, 743, NULL, 2646, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4182, 318, NULL, 2647, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4183, 4922, NULL, 2647, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4184, 1040, NULL, 2647, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4185, 4934, NULL, 2647, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4186, 1642, NULL, 2648, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4187, 1600, NULL, 2648, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4188, 1379, NULL, 2648, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4189, 1447, NULL, 2648, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4190, 390, NULL, 2649, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4191, 3662, NULL, 2649, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4192, 4936, NULL, 2649, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4193, 4935, NULL, 2649, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4194, 1795, NULL, 2650, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4195, 4937, NULL, 2650, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4196, 4938, NULL, 2650, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4197, 3254, NULL, 2650, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4198, 4923, NULL, 2651, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4199, 382, NULL, 2727, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4200, 1629, NULL, 2727, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4201, 685, NULL, 2727, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4202, 586, NULL, 2728, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4203, 4940, NULL, 2728, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4204, 1059, NULL, 2729, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4205, 320, NULL, 2730, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4206, 1781, NULL, 2730, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4207, 398, NULL, 2730, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4208, 441, NULL, 1424, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4209, 4257, NULL, 1424, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4210, 364, NULL, 1426, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4211, 2531, NULL, 1426, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4212, 381, NULL, 1426, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4213, 601, NULL, 1421, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4214, 807, NULL, 1425, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4215, 1447, NULL, 1425, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4216, 1656, NULL, 1425, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32813, 7069, NULL, 10164, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23773, 5666, NULL, 7338, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4220, 1389, NULL, 1420, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4221, 90, NULL, 1420, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4222, 242, NULL, 1420, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4226, 1167, NULL, 1582, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4227, 706, NULL, 1582, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4228, 1401, NULL, 1583, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4229, 133, NULL, 1583, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4230, 4006, NULL, 1583, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4231, 392, NULL, 1488, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4232, 2706, NULL, 1488, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4233, 1370, NULL, 1488, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15639, 6271, NULL, 5124, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15640, 4105, NULL, 5124, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15641, 5207, NULL, 5124, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15642, 7861, NULL, 5124, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15643, 1929, NULL, 5124, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15644, 3201, NULL, 5124, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15645, 6612, NULL, 5125, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15646, 765, NULL, 5125, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15647, 3026, NULL, 5125, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15648, 7862, NULL, 5125, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15649, 247, NULL, 1097, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15650, 2983, NULL, 842, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15651, 2987, NULL, 842, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15652, 2992, NULL, 842, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15653, 2993, NULL, 842, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15654, 4361, NULL, 3885, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15655, 4657, NULL, 2487, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15656, 62, NULL, 2487, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15657, 2031, NULL, 2487, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15658, 4658, NULL, 2531, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15659, 2532, NULL, 2531, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15660, 4659, NULL, 4384, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15661, 1701, NULL, 4384, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15662, 861, NULL, 4384, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15663, 7288, NULL, 4388, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15664, 7863, NULL, 4388, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15665, 7864, NULL, 4388, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15666, 7865, NULL, 4388, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15667, 7867, NULL, 5097, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15668, 5637, NULL, 5097, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15669, 6307, NULL, 5097, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4174, 398, NULL, 2645, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4175, 4931, NULL, 2645, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4176, 4932, NULL, 2645, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4167, 178, NULL, 2643, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4169, 4928, NULL, 2643, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4168, 3252, NULL, 2643, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4166, 1636, NULL, 2643, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15670, 7866, NULL, 5097, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15671, 7868, NULL, 5126, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15672, 4500, NULL, 5126, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15673, 6426, NULL, 5126, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15674, 861, NULL, 5126, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15675, 7289, NULL, 5127, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15676, 7289, NULL, 5128, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15677, 7290, NULL, 5129, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15678, 7870, NULL, 5129, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15679, 7869, NULL, 5129, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15680, 7291, NULL, 5130, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4178, 12082, NULL, 2646, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28609, 815, NULL, 8899, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28610, 12095, NULL, 8899, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28611, 12096, NULL, 8899, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28612, 770, NULL, 8899, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20731, 10118, NULL, 6507, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28668, 12141, NULL, 8911, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28738, 382, NULL, 8931, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28739, 497, NULL, 8931, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28740, 12189, NULL, 8931, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28741, 685, NULL, 8931, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28742, 12190, NULL, 8931, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28809, 12229, NULL, 4010, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28812, 1672, NULL, 8934, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28813, 1385, NULL, 8934, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28834, 1457, NULL, 8944, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28835, 1665, NULL, 8944, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28836, 1415, NULL, 8944, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4234, 907, NULL, 1586, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4235, 1080, NULL, 1586, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4236, 1221, NULL, 1586, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4237, 377, NULL, 1580, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4238, 1267, NULL, 1580, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28684, 122, NULL, 8915, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28681, 12152, NULL, 8915, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4239, 1003, NULL, 1580, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4240, 1062, NULL, 1584, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4241, 566, NULL, 1584, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4242, 1137, NULL, 1584, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4243, 512, NULL, 1579, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4244, 1164, NULL, 1579, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4245, 1296, NULL, 1579, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4246, 1741, NULL, 1433, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4247, 4085, NULL, 1433, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4248, 2910, NULL, 1433, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4249, 1229, NULL, 1431, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4250, 4942, NULL, 1431, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4251, 4943, NULL, 1431, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4252, 4944, NULL, 1431, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4253, 3111, NULL, 1435, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4254, 2413, NULL, 1435, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4255, 4945, NULL, 1435, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4256, 568, NULL, 1429, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4257, 1580, NULL, 1429, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4258, 4946, NULL, 1429, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4259, 378, NULL, 1427, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4260, 2399, NULL, 1427, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4261, 1700, NULL, 1428, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4262, 3722, NULL, 1428, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4263, 4947, NULL, 1428, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4264, 4948, NULL, 1428, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4265, 1425, NULL, 1434, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4266, 798, NULL, 1434, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4267, 4635, NULL, 1434, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4268, 2312, NULL, 1434, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4269, 937, NULL, 1430, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4270, 3159, NULL, 1430, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4271, 4949, NULL, 1430, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4272, 4950, NULL, 1430, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4273, 598, NULL, 1432, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4274, 4395, NULL, 1432, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4275, 1611, NULL, 1432, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4276, 4941, NULL, 1432, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4280, 2973, NULL, 1466, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4281, 3602, NULL, 1466, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4282, 3853, NULL, 1467, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4283, 717, NULL, 1467, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4284, 65, NULL, 1476, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4285, 3660, NULL, 1476, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4286, 2327, NULL, 1476, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4287, 128, NULL, 1470, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4288, 957, NULL, 1470, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4291, 669, NULL, 1474, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4292, 1023, NULL, 1474, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4296, 1533, NULL, 1472, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4297, 2974, NULL, 1472, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4298, 4954, NULL, 1472, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4303, 4957, NULL, 1477, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4304, 1257, NULL, 1494, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4305, 2816, NULL, 1494, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4306, 920, NULL, 1494, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4307, 274, NULL, 1493, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4308, 773, NULL, 1493, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4309, 4408, NULL, 1493, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4310, 1511, NULL, 1492, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4314, 823, NULL, 1491, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4315, 227, NULL, 1491, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4316, 1138, NULL, 1491, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4317, 812, NULL, 1495, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4318, 1042, NULL, 1495, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4319, 1117, NULL, 1495, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4320, 534, NULL, 1490, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4321, 1834, NULL, 1490, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4322, 150, NULL, 1490, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4323, 1458, NULL, 1609, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4324, 2761, NULL, 1609, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4325, 1401, NULL, 1609, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28540, 12070, NULL, 8879, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28539, 12069, NULL, 8879, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28538, 12068, NULL, 8879, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4289, 981, NULL, 1471, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4290, 2850, NULL, 1471, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4301, 4955, NULL, 1473, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4300, 1967, NULL, 1473, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4278, 4951, NULL, 1469, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4279, 4952, NULL, 1469, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4277, 1360, NULL, 1469, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4326, 568, NULL, 1605, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15681, 7871, NULL, 5130, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15682, 7872, NULL, 5130, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15683, 7882, NULL, 5131, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15684, 7883, NULL, 5131, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15685, 7884, NULL, 5131, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15686, 7885, NULL, 5131, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15687, 7762, NULL, 5132, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15688, 7886, NULL, 5132, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15689, 7887, NULL, 5132, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15690, 1943, NULL, 5132, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15691, 1881, NULL, 5133, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15692, 5266, NULL, 5133, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15693, 3324, NULL, 5133, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15694, 3234, NULL, 5133, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15695, 7888, NULL, 5134, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15696, 7889, NULL, 5134, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15697, 7220, NULL, 5134, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15698, 7890, NULL, 5134, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15699, 7891, NULL, 5134, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15700, 7892, NULL, 5134, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15701, 7893, NULL, 5134, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15702, 333, NULL, 5135, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15703, 1771, NULL, 5135, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15704, 1087, NULL, 5135, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15705, 790, NULL, 5135, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15706, 498, NULL, 5136, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15707, 2259, NULL, 5136, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15708, 19, NULL, 5136, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15709, 7894, NULL, 5136, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15710, 4615, NULL, 5136, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15711, 6401, NULL, 5136, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15712, 857, NULL, 5136, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15713, 1469, NULL, 5137, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15714, 7895, NULL, 5137, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15715, 7896, NULL, 5137, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15716, 1748, NULL, 5138, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15717, 5979, NULL, 5138, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15718, 7897, NULL, 5138, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15719, 7898, NULL, 5138, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15720, 7899, NULL, 5138, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15721, 2867, NULL, 5138, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15722, 3132, NULL, 5138, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (28743, 12191, NULL, 8931, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (28744, 12192, NULL, 8931, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (28814, 7547, NULL, 8935, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28840, 12243, NULL, 8945, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28841, 2661, NULL, 8945, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4327, 1322, NULL, 1605, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4328, 4960, NULL, 1605, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4329, 1504, NULL, 1611, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4330, 1311, NULL, 1611, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4331, 4961, NULL, 1611, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4332, 1829, NULL, 1607, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4333, 3713, NULL, 1607, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4337, 2410, NULL, 1606, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4338, 728, NULL, 1606, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4339, 4963, NULL, 1606, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4340, 1724, NULL, 1610, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4341, 2489, NULL, 1610, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4342, 4964, NULL, 1610, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4343, 377, NULL, 1604, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4344, 2180, NULL, 1604, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4345, 4965, NULL, 1604, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4346, 819, NULL, 1673, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4347, 112, NULL, 1673, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4348, 4264, NULL, 1673, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4352, 2680, NULL, 1669, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4353, 1238, NULL, 1669, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4354, 4077, NULL, 1669, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4355, 1600, NULL, 1670, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4356, 3682, NULL, 1670, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4357, 1941, NULL, 1676, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4358, 4967, NULL, 1676, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4359, 1842, NULL, 1672, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4360, 2536, NULL, 1672, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4361, 723, NULL, 1672, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4365, 923, NULL, 1671, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4366, 51, NULL, 1671, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4367, 289, NULL, 1671, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4368, 408, NULL, 1843, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4369, 2492, NULL, 1847, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4370, 3733, NULL, 1847, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4371, 6, NULL, 1846, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4372, 3354, NULL, 1846, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4313, 4959, NULL, 1489, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4311, 724, NULL, 1489, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4312, 4833, NULL, 1489, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4364, 64, NULL, 1674, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4363, 654, NULL, 1674, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4362, 1214, NULL, 1674, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4336, 4962, NULL, 1608, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4335, 4403, NULL, 1608, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4373, 1331, NULL, 1845, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4374, 2945, NULL, 1845, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4375, 389, NULL, 1845, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4376, 3025, NULL, 1848, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4377, 4167, NULL, 1848, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4378, 624, NULL, 1848, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4379, 1781, NULL, 1842, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4381, 1313, NULL, 1842, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4382, 3744, NULL, 1844, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4383, 3521, NULL, 1844, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4384, 1422, NULL, 1838, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4385, 586, NULL, 2501, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4386, 512, NULL, 2501, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4387, 2696, NULL, 2501, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4388, 3901, NULL, 2501, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4389, 430, NULL, 2502, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4390, 4112, NULL, 2502, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4391, 4939, NULL, 2502, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4392, 771, NULL, 2504, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4393, 833, NULL, 2504, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4394, 1017, NULL, 2504, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4395, 313, NULL, 2505, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4396, 275, NULL, 2505, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4397, 1818, NULL, 2505, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4398, 4958, NULL, 2505, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4399, 1059, NULL, 2506, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4400, 687, NULL, 2506, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4401, 1586, NULL, 2506, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4402, 1263, NULL, 2506, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4403, 1527, NULL, 2507, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4404, 91, NULL, 2507, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4405, 1609, NULL, 2507, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4406, 3915, NULL, 2508, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4407, 2519, NULL, 2508, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4408, 848, NULL, 2509, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4409, 4917, NULL, 2509, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4410, 993, NULL, 2509, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4411, 939, NULL, 2510, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4412, 209, NULL, 2510, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4413, 713, NULL, 2510, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4414, 4968, NULL, 2510, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4415, 100, NULL, 2511, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4416, 4940, NULL, 2511, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4417, 122, NULL, 2513, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4418, 378, NULL, 2513, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15723, 3132, NULL, 4560, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15724, 7283, NULL, 5139, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15725, 7900, NULL, 5139, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15726, 7901, NULL, 5139, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15727, 5381, NULL, 5140, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15728, 7207, NULL, 5140, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15729, 7902, NULL, 5140, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15730, 1648, NULL, 5141, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15731, 503, NULL, 5141, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15732, 1821, NULL, 5141, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15733, 1102, NULL, 5141, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15734, 506, NULL, 5142, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15735, 284, NULL, 5142, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15736, 2518, NULL, 5142, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15737, 1218, NULL, 5142, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15738, 7903, NULL, 5142, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15739, 4800, NULL, 5142, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15740, 463, NULL, 5142, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15741, 2862, NULL, 5143, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15742, 7904, NULL, 5143, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15743, 7905, NULL, 5143, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15744, 7906, NULL, 5143, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15745, 7907, NULL, 5143, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15746, 7908, NULL, 5143, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15747, 7909, NULL, 5143, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15756, 6492, NULL, 2283, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15757, 6493, NULL, 5147, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15758, 7915, NULL, 5147, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15759, 489, NULL, 5147, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15760, 6633, NULL, 5147, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15761, 6494, NULL, 5148, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15762, 6496, NULL, 5148, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15763, 6495, NULL, 5148, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15764, 6497, NULL, 5148, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15765, 3305, NULL, 5149, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28542, 11469, NULL, 8880, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28543, 12072, NULL, 8880, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28544, 12073, NULL, 8880, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28815, 1662, NULL, 8936, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28816, 1875, NULL, 8936, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28842, 2596, NULL, 8946, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28843, 9661, NULL, 8946, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28844, 425, NULL, 8946, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4349, 3457, NULL, 1675, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28845, 2468, NULL, 8946, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28864, 2614, NULL, 8952, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28865, 1282, NULL, 8952, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28866, 5490, NULL, 8952, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28867, 1241, NULL, 8952, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28868, 1448, NULL, 8953, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28869, 1809, NULL, 8953, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28870, 12247, NULL, 8953, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28871, 709, NULL, 8953, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4419, 713, NULL, 2731, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4420, 1880, NULL, 2731, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4421, 4970, NULL, 2732, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4422, 305, NULL, 2732, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4423, 267, NULL, 2732, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4424, 1059, NULL, 2733, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4425, 709, NULL, 2733, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4426, 2544, NULL, 2733, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4427, 2719, NULL, 2734, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4428, 3919, NULL, 2734, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4429, 4971, NULL, 2734, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4430, 4972, NULL, 2734, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4431, 448, NULL, 2735, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4432, 1406, NULL, 2735, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4433, 4973, NULL, 2735, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4434, 425, NULL, 2736, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4435, 730, NULL, 2736, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4436, 687, NULL, 2737, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4437, 389, NULL, 2737, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4438, 1638, NULL, 2737, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4439, 448, NULL, 1677, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4440, 77, NULL, 1677, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4441, 4490, NULL, 1677, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4442, 1592, NULL, 1678, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4443, 403, NULL, 1678, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4444, 201, NULL, 1678, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4445, 1261, NULL, 1679, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4446, 760, NULL, 1679, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4447, 1949, NULL, 1679, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4448, 4975, NULL, 1668, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4449, 3460, NULL, 1680, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4450, 4976, NULL, 1680, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4451, 534, NULL, 1681, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4452, 1956, NULL, 1681, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4453, 4977, NULL, 1681, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4454, 374, NULL, 1682, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4455, 2790, NULL, 1682, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4456, 4978, NULL, 1682, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4457, 4979, NULL, 1684, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4458, 4980, NULL, 1684, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4459, 4981, NULL, 1684, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4460, 1095, NULL, 1685, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4461, 369, NULL, 1685, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4462, 2860, NULL, 1685, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4463, 4982, NULL, 1686, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4464, 3600, NULL, 2739, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4465, 952, NULL, 2739, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4466, 4983, NULL, 2739, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15748, 6491, NULL, 5144, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4467, 487, NULL, 2740, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4468, 3257, NULL, 2740, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4469, 1849, NULL, 2740, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4470, 4984, NULL, 2741, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4471, 283, NULL, 2742, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4472, 1821, NULL, 2742, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4473, 1809, NULL, 2743, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4474, 2774, NULL, 2743, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4475, 389, NULL, 2743, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4476, 1885, NULL, 2744, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4477, 4985, NULL, 2744, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4478, 4986, NULL, 2745, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4479, 4987, NULL, 2745, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4480, 4988, NULL, 2745, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4481, 1540, NULL, 2746, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4482, 2063, NULL, 2746, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4483, 4989, NULL, 2746, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4484, 1290, NULL, 2747, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4485, 4990, NULL, 2747, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4486, 4991, NULL, 2747, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4487, 1930, NULL, 2748, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4488, 1643, NULL, 2748, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4489, 8, NULL, 2748, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4490, 1000, NULL, 2749, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4491, 834, NULL, 2749, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4492, 1745, NULL, 2749, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15755, 6492, NULL, 5146, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15751, 7912, NULL, 5145, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15752, 2268, NULL, 5145, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15753, 7913, NULL, 5145, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15754, 7914, NULL, 5145, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4493, 1043, NULL, 2750, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4494, 1943, NULL, 2750, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4495, 439, NULL, 2750, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4496, 1926, NULL, 2751, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4497, 220, NULL, 2751, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4498, 376, NULL, 2752, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4499, 398, NULL, 2752, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4500, 4993, NULL, 2752, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4501, 4994, NULL, 2752, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4502, 179, NULL, 2753, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4503, 239, NULL, 2753, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4504, 2017, NULL, 2753, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4505, 2379, NULL, 2754, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4506, 4995, NULL, 2754, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4507, 4996, NULL, 2754, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4508, 2364, NULL, 2755, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4509, 2995, NULL, 2755, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4510, 2650, NULL, 2755, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4511, 186, NULL, 2756, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4512, 686, NULL, 2756, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4513, 122, NULL, 2756, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4514, 3056, NULL, 2756, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4515, 1261, NULL, 2757, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4516, 2605, NULL, 2757, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4517, 1146, NULL, 2757, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4518, 1386, NULL, 2757, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4519, 973, NULL, 1121, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4520, 3536, NULL, 1121, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4521, 3436, NULL, 1121, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4522, 3920, NULL, 1121, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4523, 364, NULL, 1122, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4524, 1192, NULL, 1122, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4525, 2438, NULL, 1122, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4526, 1550, NULL, 1122, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4527, 626, NULL, 1123, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4528, 2000, NULL, 1123, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4529, 730, NULL, 1123, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4530, 1834, NULL, 1124, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4531, 853, NULL, 1124, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4532, 3199, NULL, 1124, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4533, 2202, NULL, 1124, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4534, 552, NULL, 1125, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4535, 2750, NULL, 1125, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4536, 4380, NULL, 1125, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4537, 4189, NULL, 1125, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4538, 1086, NULL, 1126, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4539, 4500, NULL, 1126, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4540, 3942, NULL, 1126, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4541, 718, NULL, 1126, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4542, 81, NULL, 1127, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4543, 783, NULL, 1127, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4544, 1408, NULL, 1128, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4545, 1196, NULL, 1128, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4546, 2104, NULL, 1128, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4547, 2563, NULL, 1128, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4548, 749, NULL, 1129, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15766, 2468, NULL, 5149, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15767, 6027, NULL, 5149, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15768, 5109, NULL, 5149, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15769, 1042, NULL, 5150, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15770, 604, NULL, 5150, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15771, 867, NULL, 5150, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15776, 5855, NULL, 5150, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15777, 6499, NULL, 5152, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15778, 1602, NULL, 5152, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15779, 7918, NULL, 5152, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15780, 7919, NULL, 5152, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15781, 2724, NULL, 5153, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4549, 4997, NULL, 1129, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4550, 4998, NULL, 1129, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4551, 4999, NULL, 1129, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (4552, 5000, NULL, 1129, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (4557, 1619, NULL, 1131, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4558, 284, NULL, 1131, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4559, 4191, NULL, 1131, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4560, 71, NULL, 1131, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4561, 457, NULL, 1132, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4562, 4316, NULL, 1132, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4563, 571, NULL, 1132, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4564, 660, NULL, 1132, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4565, 3192, NULL, 1133, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4566, 1368, NULL, 1133, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4567, 2176, NULL, 1133, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4568, 1508, NULL, 1134, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4569, 4065, NULL, 1134, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4570, 3813, NULL, 1134, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4571, 3909, NULL, 1134, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4572, 1428, NULL, 1135, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4573, 3256, NULL, 1135, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4574, 3908, NULL, 1135, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4575, 3832, NULL, 1135, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4576, 1687, NULL, 1136, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4577, 4457, NULL, 1136, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4578, 5002, NULL, 1136, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4579, 5003, NULL, 1136, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4580, 3959, NULL, 1137, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4581, 1691, NULL, 1138, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4582, 1437, NULL, 1138, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4583, 2579, NULL, 1138, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4584, 5004, NULL, 1138, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4585, 432, NULL, 1139, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4586, 2507, NULL, 1139, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4587, 2777, NULL, 1139, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4588, 5005, NULL, 1139, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4589, 397, NULL, 1140, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4590, 4546, NULL, 1140, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4591, 3940, NULL, 1140, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4592, 104, NULL, 1141, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4593, 2094, NULL, 1141, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4594, 2278, NULL, 1141, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (4595, 5007, NULL, 1141, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4596, 451, NULL, 1143, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4597, 3392, NULL, 1143, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4598, 5008, NULL, 1143, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4599, 5009, NULL, 1143, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4600, 2920, NULL, 1142, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4601, 4327, NULL, 1142, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4602, 3257, NULL, 1142, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4603, 3092, NULL, 1142, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4604, 145, NULL, 1144, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4605, 5010, NULL, 1144, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4606, 3782, NULL, 1144, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4607, 2862, NULL, 1144, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4610, 1389, NULL, 1626, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4611, 3152, NULL, 1626, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4612, 1687, NULL, 1626, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4613, 78, NULL, 1626, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4614, 430, NULL, 1630, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4615, 3744, NULL, 1630, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4616, 73, NULL, 1630, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4617, 2899, NULL, 1630, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4618, 1609, NULL, 1633, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4619, 456, NULL, 1633, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4620, 1898, NULL, 1633, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4621, 1607, NULL, 1632, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4622, 1374, NULL, 1632, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4623, 457, NULL, 1632, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4624, 389, NULL, 1632, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4625, 5011, NULL, 1635, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4626, 1431, NULL, 1623, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4627, 1059, NULL, 1631, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4628, 1586, NULL, 1631, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4629, 5013, NULL, 1631, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4630, 537, NULL, 1624, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4631, 196, NULL, 1624, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4632, 1527, NULL, 1634, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4633, 2547, NULL, 1634, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4634, 295, NULL, 1625, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4635, 778, NULL, 1625, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4636, 749, NULL, 1628, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4638, 5015, NULL, 1628, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4639, 5016, NULL, 1628, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15782, 7920, NULL, 5153, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15783, 7921, NULL, 5153, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15784, 687, NULL, 5154, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15785, 688, NULL, 5154, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15786, 3023, NULL, 5154, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15787, 7922, NULL, 5155, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15788, 779, NULL, 5155, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15789, 7923, NULL, 5155, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15790, 7924, NULL, 5155, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15791, 231, NULL, 5156, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15792, 544, NULL, 5156, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15793, 839, NULL, 5156, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15794, 2145, NULL, 5156, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15795, 482, NULL, 5157, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15796, 7925, NULL, 5157, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15797, 7926, NULL, 5157, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15798, 7927, NULL, 5157, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15799, 7928, NULL, 5157, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15772, 6498, NULL, 5151, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15775, 793, NULL, 5151, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15774, 7917, NULL, 5151, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15773, 7916, NULL, 5151, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4609, 1952, NULL, 1145, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4608, 521, NULL, 1145, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15805, 688, NULL, 410, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15806, 73, NULL, 5159, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15807, 119, NULL, 5159, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15808, 171, NULL, 5159, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15809, 1154, NULL, 5160, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15810, 147, NULL, 5160, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15811, 2440, NULL, 5160, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15812, 3234, NULL, 5161, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15813, 2054, NULL, 5161, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15814, 5315, NULL, 5161, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15815, 1544, NULL, 5163, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15816, 2514, NULL, 5164, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15817, 1238, NULL, 5164, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15818, 2042, NULL, 5164, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15819, 1515, NULL, 5165, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15820, 1329, NULL, 5165, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15821, 1696, NULL, 5165, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15822, 890, NULL, 5167, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15823, 2414, NULL, 5167, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28545, 12074, NULL, 8881, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28546, 3178, NULL, 8881, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28547, 12075, NULL, 8881, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28817, 926, NULL, 8937, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28818, 1198, NULL, 8937, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4642, 2964, NULL, 1627, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4643, 122, NULL, 1627, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4644, 1834, NULL, 2766, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4645, 382, NULL, 2766, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4646, 1629, NULL, 2766, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4647, 1638, NULL, 2766, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4648, 2377, NULL, 2767, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4649, 4449, NULL, 2767, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4650, 5017, NULL, 2767, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4651, 4727, NULL, 2768, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4652, 3440, NULL, 2768, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4653, 1748, NULL, 2768, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4654, 3390, NULL, 2768, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4655, 5018, NULL, 2769, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4656, 5019, NULL, 2769, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4657, 5020, NULL, 2769, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4661, 1892, NULL, 2771, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4662, 5026, NULL, 2772, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4663, 5027, NULL, 2772, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4664, 5028, NULL, 2772, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4665, 5024, NULL, 2771, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4666, 5025, NULL, 2771, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4667, 1997, NULL, 2773, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4668, 5029, NULL, 2773, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4669, 5030, NULL, 2774, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4670, 5031, NULL, 2774, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4671, 5032, NULL, 2774, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4672, 4365, NULL, 2775, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4673, 1041, NULL, 2775, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4674, 1781, NULL, 2775, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4675, 593, NULL, 2776, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4676, 923, NULL, 2776, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4677, 5033, NULL, 2776, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4678, 1116, NULL, 2777, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4679, 2342, NULL, 2777, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4680, 1518, NULL, 2777, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4681, 1721, NULL, 2777, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4682, 5034, NULL, 2777, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4683, 915, NULL, 1691, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4684, 2017, NULL, 1691, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4685, 4240, NULL, 1691, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4686, 5035, NULL, 1691, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4687, 1223, NULL, 1141, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4688, 3406, NULL, 1141, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4689, 430, NULL, 1692, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4690, 100, NULL, 1692, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4691, 1699, NULL, 1692, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4692, 5036, NULL, 1692, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4693, 1882, NULL, 1688, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4694, 2421, NULL, 1688, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4695, 713, NULL, 1688, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4696, 1257, NULL, 1695, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4697, 4167, NULL, 1695, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4698, 5037, NULL, 1695, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4699, 2582, NULL, 1693, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4700, 1329, NULL, 1693, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4701, 5038, NULL, 1693, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4702, 5039, NULL, 1693, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4703, 355, NULL, 1689, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4704, 857, NULL, 1689, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4705, 183, NULL, 1689, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4706, 789, NULL, 1689, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4707, 2103, NULL, 1689, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4708, 2106, NULL, 1690, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4709, 2104, NULL, 1690, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4710, 685, NULL, 1690, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4711, 1513, NULL, 1690, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28874, 12248, NULL, 8954, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28873, 2822, NULL, 8954, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15803, 283, NULL, 5158, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15800, 382, NULL, 5158, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15802, 588, NULL, 5158, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4658, 5021, NULL, 2770, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4659, 5022, NULL, 2770, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4660, 5023, NULL, 2770, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4712, 382, NULL, 1694, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4713, 1329, NULL, 1694, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4714, 685, NULL, 1694, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4715, 2903, NULL, 1694, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4716, 374, NULL, 1439, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4717, 5016, NULL, 1439, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4718, 1893, NULL, 1439, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4719, 5040, NULL, 1439, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4720, 939, NULL, 1438, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4721, 1575, NULL, 1438, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4722, 1222, NULL, 1438, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4723, 62, NULL, 1438, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4724, 5041, NULL, 1438, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4725, 448, NULL, 1440, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4726, 2399, NULL, 1440, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4727, 3789, NULL, 1440, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4728, 2240, NULL, 1440, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4729, 955, NULL, 1440, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4730, 5043, NULL, 1444, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4731, 5044, NULL, 1444, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4732, 5045, NULL, 1444, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4733, 644, NULL, 1436, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15824, 692, NULL, 5167, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15825, 188, NULL, 5168, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15826, 2628, NULL, 5168, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15828, 5918, NULL, 1458, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15829, 7180, NULL, 1463, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15834, 7877, NULL, 5171, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15835, 2625, NULL, 5171, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15836, 6949, NULL, 5171, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15837, 2554, NULL, 5171, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15842, 7878, NULL, 5173, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15843, 803, NULL, 5173, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15844, 5229, NULL, 5173, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15845, 3106, NULL, 5173, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15846, 2975, NULL, 5174, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15847, 5214, NULL, 5174, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15848, 51, NULL, 5174, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15849, 58, NULL, 5174, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15850, 7409, NULL, 5175, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15851, 7930, NULL, 5175, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15852, 2045, NULL, 5175, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15853, 2010, NULL, 5176, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15854, 2154, NULL, 5176, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15855, 713, NULL, 5176, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15856, 2000, NULL, 5176, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15857, 973, NULL, 5176, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15862, 7879, NULL, 5178, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15863, 2514, NULL, 5178, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15864, 1875, NULL, 5178, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15865, 2912, NULL, 5178, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28548, 12076, NULL, 8881, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28819, 1368, NULL, 8938, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28820, 1578, NULL, 8938, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28849, 926, NULL, 8948, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28850, 11848, NULL, 8948, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28851, 770, NULL, 8948, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28852, 9510, NULL, 8948, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28853, 5496, NULL, 8948, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28876, 3068, NULL, 8955, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28877, 8225, NULL, 8955, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28878, 1958, NULL, 8955, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28891, 1041, NULL, 8961, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28892, 1241, NULL, 8961, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28893, 2601, NULL, 8961, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28934, 12250, NULL, 8974, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28950, 6541, NULL, 8980, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15832, 1965, NULL, 5170, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15831, 2520, NULL, 5170, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15830, 7876, NULL, 5170, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15833, 2758, NULL, 5170, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28951, 10900, NULL, 8980, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28985, 1431, NULL, 8994, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28986, 1059, NULL, 8994, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4734, 382, NULL, 1442, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4735, 760, NULL, 1442, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4736, 2890, NULL, 1442, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4737, 1956, NULL, 1442, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4738, 2492, NULL, 1442, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4739, 3117, NULL, 1437, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4740, 2584, NULL, 1437, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4741, 3116, NULL, 1437, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4742, 652, NULL, 1437, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4743, 1732, NULL, 1441, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4744, 2258, NULL, 1441, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4745, 1655, NULL, 1441, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4746, 5046, NULL, 1441, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4747, 5047, NULL, 1441, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4748, 1010, NULL, 1443, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4749, 3876, NULL, 1443, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4750, 2503, NULL, 1443, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4751, 1707, NULL, 1443, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4752, 626, NULL, 2779, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4753, 655, NULL, 2779, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4754, 1875, NULL, 2779, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4755, 434, NULL, 2779, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4756, 1146, NULL, 2780, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4757, 781, NULL, 2781, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4758, 756, NULL, 2782, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4759, 1779, NULL, 2782, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4760, 2479, NULL, 2782, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4761, 1772, NULL, 2782, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4762, 1401, NULL, 2783, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4763, 2577, NULL, 2783, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4764, 5048, NULL, 2783, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4765, 5049, NULL, 2783, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4766, 791, NULL, 2784, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4767, 3015, NULL, 2784, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4768, 2072, NULL, 2784, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4769, 5050, NULL, 2784, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4770, 1059, NULL, 2785, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4771, 2738, NULL, 2785, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4772, 1756, NULL, 2785, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4773, 186, NULL, 2785, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4774, 1781, NULL, 2786, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4775, 803, NULL, 2786, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4776, 2000, NULL, 2786, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4777, 973, NULL, 2786, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4778, 1527, NULL, 2787, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4779, 1846, NULL, 2787, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4780, 5051, NULL, 2787, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4781, 5052, NULL, 2787, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4782, 1376, NULL, 2788, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4783, 601, NULL, 2789, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4784, 749, NULL, 2790, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4785, 2467, NULL, 2790, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4786, 5053, NULL, 2790, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4787, 5054, NULL, 2790, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4788, 5055, NULL, 2790, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4789, 81, NULL, 2791, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4790, 4243, NULL, 2791, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4791, 563, NULL, 2057, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4792, 2525, NULL, 2057, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4793, 1858, NULL, 2057, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4794, 1447, NULL, 2057, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4795, 1970, NULL, 2059, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4796, 4054, NULL, 2059, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4797, 4242, NULL, 2059, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4798, 5056, NULL, 2059, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4799, 4382, NULL, 2065, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4800, 3501, NULL, 2065, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4801, 350, NULL, 2065, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4802, 5057, NULL, 2065, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4803, 5058, NULL, 2072, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4804, 5059, NULL, 2072, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4805, 823, NULL, 2792, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4806, 5060, NULL, 2792, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4807, 5061, NULL, 2792, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4808, 614, NULL, 2793, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4809, 1575, NULL, 2793, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4810, 4994, NULL, 2793, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4811, 5062, NULL, 2795, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4812, 5063, NULL, 2795, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4813, 5064, NULL, 2796, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4814, 628, NULL, 2797, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4815, 2837, NULL, 2797, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4816, 3394, NULL, 2797, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4817, 4264, NULL, 2798, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4818, 100, NULL, 2798, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4819, 181, NULL, 2799, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4820, 2652, NULL, 2799, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4821, 2627, NULL, 2799, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4822, 5065, NULL, 2800, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4823, 400, NULL, 2800, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4824, 1171, NULL, 2801, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4825, 8, NULL, 2801, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4826, 3004, NULL, 2801, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15869, 7880, NULL, 5180, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15870, 1291, NULL, 5180, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15871, 834, NULL, 5180, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15872, 2966, NULL, 5180, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15876, 3484, NULL, 5182, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15877, 2399, NULL, 5182, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15878, 2152, NULL, 5182, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15858, 239, NULL, 5177, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15859, 1851, NULL, 5177, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15860, 2458, NULL, 5177, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28896, 93, NULL, 8962, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28897, 5524, NULL, 8962, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28894, 476, NULL, 8962, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28895, 892, NULL, 8962, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15879, 650, NULL, 5182, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15880, 7945, NULL, 5183, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15881, 3037, NULL, 5183, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15882, 7946, NULL, 5183, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15883, 1842, NULL, 5183, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15884, 1195, NULL, 5184, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15885, 1236, NULL, 5184, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15886, 7805, NULL, 5184, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15887, 7947, NULL, 5184, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15888, 1008, NULL, 5185, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15889, 4561, NULL, 5185, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15890, 7948, NULL, 5185, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15891, 7949, NULL, 5185, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15892, 358, NULL, 5186, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15893, 7950, NULL, 5186, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15894, 3157, NULL, 5186, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15895, 6936, NULL, 5186, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15896, 3035, NULL, 5186, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15897, 490, NULL, 5187, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15898, 7951, NULL, 5187, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15899, 7952, NULL, 5187, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15900, 1052, NULL, 5187, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15901, 1086, NULL, 5188, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15902, 7953, NULL, 5188, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15903, 7954, NULL, 5188, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15904, 378, NULL, 5189, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15905, 7955, NULL, 5189, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15906, 7956, NULL, 5189, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15907, 7957, NULL, 5189, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28549, 12077, NULL, 8882, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28550, 11075, NULL, 8882, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28551, 3238, NULL, 8882, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28821, 2748, NULL, 8939, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28822, 787, NULL, 8939, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28854, 2822, NULL, 8949, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28855, 993, NULL, 8949, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28879, 1670, NULL, 8956, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28880, 284, NULL, 8956, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28898, 2242, NULL, 8963, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28899, 5567, NULL, 8963, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28900, 858, NULL, 8963, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28935, 12251, NULL, 8975, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28936, 12252, NULL, 8975, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28937, 12253, NULL, 8975, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28952, 12259, NULL, 8981, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28953, 12260, NULL, 8981, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28987, 833, NULL, 8994, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28988, 842, NULL, 8994, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28989, 12276, NULL, 8994, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4827, 2264, NULL, 2802, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4828, 2645, NULL, 2802, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4829, 5066, NULL, 2802, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4830, 1235, NULL, 2803, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4831, 687, NULL, 2805, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4832, 789, NULL, 2805, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4833, 5069, NULL, 2805, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4834, 2180, NULL, 2807, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4835, 4522, NULL, 2807, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4836, 5071, NULL, 2807, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4837, 3033, NULL, 2808, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4838, 834, NULL, 2808, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4839, 1588, NULL, 2808, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4840, 2614, NULL, 2809, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4841, 3601, NULL, 2809, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4842, 1497, NULL, 2809, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4843, 2115, NULL, 2810, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4844, 3947, NULL, 2810, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4845, 2322, NULL, 2810, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4846, 3399, NULL, 2811, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4847, 5072, NULL, 2811, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4848, 3956, NULL, 2812, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4849, 182, NULL, 2812, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4850, 2312, NULL, 2812, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4851, 724, NULL, 2813, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4852, 1241, NULL, 2813, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4853, 5073, NULL, 2813, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4854, 4164, NULL, 2814, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4855, 1585, NULL, 2814, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4856, 1542, NULL, 2814, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4857, 1319, NULL, 2815, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4858, 952, NULL, 2815, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4859, 1148, NULL, 2815, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4860, 5074, NULL, 2816, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4861, 2986, NULL, 2817, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4862, 133, NULL, 2817, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4863, 2808, NULL, 2817, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4864, 5079, NULL, 2817, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4865, 497, NULL, 2818, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4866, 3706, NULL, 2818, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4867, 5080, NULL, 2818, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4868, 5081, NULL, 2818, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4869, 152, NULL, 2819, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4870, 5082, NULL, 2819, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4871, 5083, NULL, 2819, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4872, 5084, NULL, 2820, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4873, 1409, NULL, 2821, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4874, 4616, NULL, 2821, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4875, 5085, NULL, 2821, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4880, 4780, NULL, 2824, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4881, 5087, NULL, 2824, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4882, 5088, NULL, 2824, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4883, 2596, NULL, 1445, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4884, 629, NULL, 1445, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4885, 1232, NULL, 1445, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4886, 1571, NULL, 1450, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4887, 289, NULL, 1450, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4888, 789, NULL, 1450, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4889, 5089, NULL, 1450, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4891, 333, NULL, 2825, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4892, 579, NULL, 2825, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4893, 4465, NULL, 2825, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33092, 539, NULL, 10231, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33093, 8619, NULL, 10231, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4901, 890, NULL, 1452, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4902, 951, NULL, 1452, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4903, 2531, NULL, 1452, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4904, 964, NULL, 1447, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4905, 3004, NULL, 1447, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4906, 2809, NULL, 1447, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4907, 716, NULL, 1447, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4908, 369, NULL, 866, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4909, 369, NULL, 345, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4910, 3700, NULL, 2826, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4911, 5092, NULL, 2826, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4912, 5094, NULL, 2828, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4915, 996, NULL, 2830, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4916, 2386, NULL, 2830, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4917, 1926, NULL, 2830, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4918, 5097, NULL, 2831, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15908, 1002, NULL, 5190, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15909, 728, NULL, 5190, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15910, 5932, NULL, 5190, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15911, 5265, NULL, 5190, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15912, 757, NULL, 5191, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15913, 7958, NULL, 5191, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15914, 7959, NULL, 5191, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15915, 7960, NULL, 5191, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15916, 476, NULL, 5192, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15917, 2577, NULL, 5192, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15918, 7961, NULL, 5192, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15919, 1295, NULL, 5192, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15920, 7962, NULL, 5193, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15921, 7963, NULL, 5193, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15922, 7964, NULL, 5193, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15923, 382, NULL, 5193, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15924, 6046, NULL, 5194, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15925, 5237, NULL, 5194, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15926, 5235, NULL, 5194, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15927, 1621, NULL, 1667, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15928, 382, NULL, 5195, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15929, 188, NULL, 5195, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15930, 1629, NULL, 5195, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15931, 1424, NULL, 5195, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15932, 1091, NULL, 5195, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15933, 2774, NULL, 5195, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15934, 502, NULL, 5195, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15935, 1655, NULL, 5195, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (15936, 1329, NULL, 5195, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (15937, 2104, NULL, 5196, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15938, 2533, NULL, 5196, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15939, 2120, NULL, 5196, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15940, 3581, NULL, 5196, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15941, 430, NULL, 5197, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15942, 405, NULL, 5197, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15943, 1699, NULL, 5197, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15944, 119, NULL, 5197, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15945, 1849, NULL, 5197, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15946, 4264, NULL, 5197, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15947, 687, NULL, 5197, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15948, 1041, NULL, 5198, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15949, 7777, NULL, 5198, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15950, 4896, NULL, 5198, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28552, 8207, NULL, 8882, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4890, 5634, 284, 2825, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28856, 1842, NULL, 8950, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28857, 12244, NULL, 8950, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28858, 12245, NULL, 8950, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28859, 12246, NULL, 8950, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28881, 1813, NULL, 8957, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28882, 6374, NULL, 8957, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28901, 1781, NULL, 8964, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28902, 8348, NULL, 8964, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28903, 1872, NULL, 8964, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28938, 12254, NULL, 8976, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28954, 5154, NULL, 8982, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28955, 5204, NULL, 8982, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28990, 534, NULL, 8995, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28991, 955, NULL, 8995, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28992, 482, NULL, 8995, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28993, 171, NULL, 8995, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4919, 5098, NULL, 2831, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4920, 1313, NULL, 2832, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4921, 787, NULL, 2832, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4922, 5099, NULL, 2832, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4923, 4034, NULL, 2833, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4924, 5100, NULL, 2833, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4925, 5101, NULL, 2833, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4926, 2161, NULL, 2834, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4927, 2655, NULL, 2834, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4928, 5102, NULL, 2834, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4929, 429, NULL, 2835, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4930, 5103, NULL, 2835, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4931, 5104, NULL, 2835, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4932, 5105, NULL, 2835, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4933, 2285, NULL, 2819, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4934, 152, NULL, 2836, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4935, 2696, NULL, 2836, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4936, 1460, NULL, 2836, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4937, 209, NULL, 2836, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4938, 850, NULL, 2836, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4939, 1553, NULL, 2837, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4940, 872, NULL, 2837, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4941, 2399, NULL, 2837, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (4942, 661, NULL, 2838, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4943, 337, NULL, 2838, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4944, 1106, NULL, 2838, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4945, 1111, NULL, 2838, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (4946, 1700, NULL, 2838, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (4951, 1727, NULL, 2188, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4952, 753, NULL, 2188, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4953, 4251, NULL, 2188, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4954, 23, NULL, 2191, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4955, 76, NULL, 2191, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4956, 1541, NULL, 2191, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4957, 295, NULL, 2187, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4958, 4258, NULL, 2187, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4959, 4290, NULL, 2187, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4960, 2609, NULL, 2194, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4961, 2565, NULL, 2194, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4962, 1208, NULL, 2194, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4963, 5107, NULL, 2194, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4964, 1179, NULL, 2190, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4965, 2387, NULL, 2190, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4949, 368, NULL, 2192, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4950, 3458, NULL, 2192, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4966, 4464, NULL, 2190, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4967, 1506, NULL, 2189, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4968, 2770, NULL, 2189, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4969, 2031, NULL, 2189, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4970, 4527, NULL, 2189, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4971, 68, NULL, 1784, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4972, 2711, NULL, 1784, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4973, 5108, NULL, 1784, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4974, 2773, NULL, 1781, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4975, 2492, NULL, 1781, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4976, 491, NULL, 1778, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28824, 2162, NULL, 8940, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28823, 825, NULL, 8940, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4914, 5096, NULL, 2829, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4913, 5095, NULL, 2829, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4977, 1984, NULL, 1778, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4978, 5109, NULL, 1778, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4979, 3014, NULL, 1787, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4980, 2349, NULL, 1787, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4981, 5110, NULL, 1787, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4982, 1319, NULL, 1782, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4983, 2263, NULL, 1782, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4984, 1226, NULL, 1782, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4985, 1541, NULL, 1780, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4986, 2860, NULL, 1780, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4991, 601, NULL, 1779, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4992, 1542, NULL, 1785, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4993, 2029, NULL, 1785, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4994, 2179, NULL, 1785, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4995, 41, NULL, 1783, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4996, 186, NULL, 1783, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4997, 749, NULL, 1870, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4998, 2724, NULL, 1870, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4999, 2382, NULL, 1870, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5000, 5113, NULL, 1870, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5001, 1511, NULL, 1872, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5002, 2761, NULL, 1872, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5003, 4288, NULL, 1872, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5004, 1019, NULL, 1867, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5005, 1241, NULL, 1867, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5006, 2309, NULL, 1867, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5007, 245, NULL, 1867, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5008, 1013, NULL, 1871, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5009, 767, NULL, 1871, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5010, 305, NULL, 1875, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5011, 2443, NULL, 1875, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5012, 2413, NULL, 1875, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5013, 790, NULL, 1876, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5014, 1373, NULL, 1876, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5015, 4656, NULL, 1876, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5016, 5115, NULL, 1876, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5020, 2561, NULL, 1869, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5021, 1979, NULL, 1869, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5022, 188, NULL, 1869, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5023, 722, NULL, 1877, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5024, 3993, NULL, 1877, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5025, 2249, NULL, 1877, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5026, 4821, NULL, 1877, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5027, 589, NULL, 1791, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5028, 4413, NULL, 1791, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5029, 1748, NULL, 1791, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5030, 1391, NULL, 1795, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5031, 2816, NULL, 1795, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5032, 183, NULL, 1795, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5033, 81, NULL, 1790, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5034, 610, NULL, 1788, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5035, 1880, NULL, 1788, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5036, 1006, NULL, 1788, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5037, 5116, NULL, 1788, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5038, 872, NULL, 1792, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5039, 76, NULL, 1792, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5040, 4360, NULL, 1792, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5041, 1198, NULL, 1794, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5042, 1943, NULL, 1794, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5043, 2235, NULL, 1794, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5044, 692, NULL, 1789, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5045, 382, NULL, 1789, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5046, 1513, NULL, 1789, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5047, 1226, NULL, 1793, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5048, 2205, NULL, 1793, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15951, 7773, NULL, 5198, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15952, 1059, NULL, 5199, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15953, 6048, NULL, 5199, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15954, 3433, NULL, 5199, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15955, 1046, NULL, 5199, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15956, 1832, NULL, 5199, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (15957, 660, NULL, 5199, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (15958, 441, NULL, 5200, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15959, 1963, NULL, 5200, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15960, 3247, NULL, 5200, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15961, 5165, NULL, 5200, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15962, 5165, NULL, 792, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15963, 5165, NULL, 1599, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15964, 5165, NULL, 1528, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15965, 5165, NULL, 3537, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15966, 5165, NULL, 3075, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5049, 648, NULL, 1793, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5050, 5117, NULL, 1793, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5051, 1401, NULL, 2240, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5052, 2774, NULL, 2240, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5053, 3013, NULL, 2240, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5056, 664, NULL, 2237, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5057, 1296, NULL, 2237, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5058, 1371, NULL, 2243, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5059, 2136, NULL, 2243, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5060, 1184, NULL, 2243, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5061, 786, NULL, 2239, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5062, 784, NULL, 2239, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5063, 952, NULL, 2241, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5064, 1046, NULL, 2241, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5065, 313, NULL, 2245, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5066, 624, NULL, 2245, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5067, 932, NULL, 2245, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5068, 5118, NULL, 2245, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5069, 360, NULL, 2238, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5070, 4507, NULL, 2238, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5071, 3752, NULL, 2238, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5072, 781, NULL, 2242, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5073, 1700, NULL, 2236, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5074, 4042, NULL, 2236, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5075, 2231, NULL, 2236, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5076, 4183, NULL, 2236, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5077, 2050, NULL, 2839, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5078, 429, NULL, 2839, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5079, 5119, NULL, 2839, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5080, 1290, NULL, 2840, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5081, 317, NULL, 2840, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5082, 4073, NULL, 2840, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5083, 967, NULL, 2841, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5084, 861, NULL, 2841, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5085, 333, NULL, 2841, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5086, 1506, NULL, 2842, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5087, 4007, NULL, 2842, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5088, 2520, NULL, 2842, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5089, 786, NULL, 2843, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5090, 784, NULL, 2843, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5091, 295, NULL, 2844, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5092, 4700, NULL, 2844, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5093, 1457, NULL, 2845, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5094, 3440, NULL, 2845, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5095, 4599, NULL, 2845, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5096, 31, NULL, 2846, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5097, 1311, NULL, 2846, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5098, 2531, NULL, 2846, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5099, 389, NULL, 2847, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5100, 978, NULL, 2847, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5101, 613, NULL, 2847, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5102, 1721, NULL, 2848, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5103, 1503, NULL, 2848, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5104, 1331, NULL, 2848, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5105, 5120, NULL, 2848, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4987, 431, NULL, 1786, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4990, 533, NULL, 1786, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4989, 1368, NULL, 1786, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5130, 2945, NULL, 2864, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5131, 2945, NULL, 2866, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5132, 2332, NULL, 2869, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5133, 1926, NULL, 2869, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5134, 2369, NULL, 2870, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5135, 1609, NULL, 2870, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5136, 3628, NULL, 2870, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5137, 741, NULL, 2870, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5138, 5127, NULL, 2869, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5139, 647, NULL, 2871, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5140, 2943, NULL, 2871, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5141, 2191, NULL, 2871, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15967, 5165, NULL, 2715, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15968, 2838, NULL, 5201, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15969, 5632, NULL, 5201, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15970, 2055, NULL, 5202, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15971, 765, NULL, 5202, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15972, 491, NULL, 5202, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15973, 7966, NULL, 5202, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15974, 448, NULL, 5203, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15975, 3056, NULL, 5203, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15976, 2945, NULL, 5203, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15977, 4236, NULL, 5203, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15978, 7967, NULL, 5204, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15979, 1458, NULL, 5205, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15980, 1386, NULL, 5205, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15981, 389, NULL, 5205, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15982, 32, NULL, 5205, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15983, 3150, NULL, 5206, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15984, 2908, NULL, 5206, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15985, 7968, NULL, 5206, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15986, 3657, NULL, 5206, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15987, 374, NULL, 5207, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15988, 13, NULL, 5207, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15989, 1926, NULL, 5207, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15990, 1778, NULL, 5207, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15991, 6691, NULL, 3466, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15992, 5322, NULL, 5208, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15993, 2360, NULL, 5208, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15994, 5097, NULL, 2340, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15995, 6189, NULL, 2340, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15996, 2505, NULL, 2340, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15997, 8013, NULL, 5209, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15998, 8014, NULL, 5209, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15999, 5285, NULL, 5210, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16000, 8015, NULL, 5211, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16001, 3874, NULL, 5213, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16002, 3002, NULL, 5213, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16003, 8036, NULL, 5213, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16004, 2918, NULL, 5213, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16005, 7931, NULL, 5214, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16006, 4358, NULL, 5214, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16007, 2780, NULL, 5214, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16008, 7932, NULL, 5215, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16009, 2165, NULL, 5215, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16010, 8037, NULL, 5215, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16011, 8038, NULL, 5215, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32851, 1362, NULL, 10163, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33094, 10124, NULL, 10231, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5142, 292, NULL, 2871, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5143, 2531, NULL, 2872, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5144, 3496, NULL, 2872, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5145, 3643, NULL, 2872, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5146, 5128, NULL, 2872, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5150, 417, NULL, 2874, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5151, 1437, NULL, 2874, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5152, 5129, NULL, 2874, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5153, 5130, NULL, 2874, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5154, 1042, NULL, 2875, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5155, 2140, NULL, 2875, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5156, 867, NULL, 2875, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5157, 2587, NULL, 2875, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5158, 1778, NULL, 2876, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5159, 13, NULL, 2876, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5160, 1505, NULL, 2876, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5161, 5131, NULL, 2876, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5162, 261, NULL, 2877, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5163, 1642, NULL, 2877, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5164, 1166, NULL, 2877, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5165, 2473, NULL, 2878, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5166, 209, NULL, 2878, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5167, 2538, NULL, 2878, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5168, 1380, NULL, 2878, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5169, 1488, NULL, 1799, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5170, 467, NULL, 1799, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5171, 5133, NULL, 1799, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5172, 5132, NULL, 1799, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5173, 593, NULL, 1804, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5174, 4800, NULL, 1804, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5175, 93, NULL, 1804, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5176, 71, NULL, 1804, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5177, 1229, NULL, 1797, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5178, 2918, NULL, 1797, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5179, 5134, NULL, 1797, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5180, 5135, NULL, 1797, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5181, 5136, NULL, 1797, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5182, 3706, NULL, 1801, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5183, 2646, NULL, 1801, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5184, 693, NULL, 1801, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5185, 5137, NULL, 1801, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5186, 1741, NULL, 1798, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5187, 32, NULL, 1798, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5188, 369, NULL, 1798, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5189, 598, NULL, 1800, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5190, 3156, NULL, 1800, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5191, 3761, NULL, 1800, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5192, 5138, NULL, 1800, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5193, 1008, NULL, 1803, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5194, 5139, NULL, 1803, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5195, 5140, NULL, 1803, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5196, 5141, NULL, 1803, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5197, 2418, NULL, 1796, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5198, 3152, NULL, 1796, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5199, 2766, NULL, 1796, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5200, 103, NULL, 1802, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5201, 3033, NULL, 1802, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5202, 4255, NULL, 1802, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5203, 534, NULL, 1880, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5204, 2399, NULL, 1880, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5205, 482, NULL, 1880, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5206, 1041, NULL, 1879, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5207, 1942, NULL, 1879, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5208, 5143, NULL, 1879, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5209, 1118, NULL, 1884, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5210, 2550, NULL, 1884, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5211, 2307, NULL, 1884, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5212, 923, NULL, 1882, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5213, 3109, NULL, 1882, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5214, 5144, NULL, 1882, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5215, 5145, NULL, 1882, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5216, 5146, NULL, 1886, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5217, 5147, NULL, 1886, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5218, 5148, NULL, 1886, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5106, 76, NULL, 2849, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5108, 730, NULL, 2850, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5107, 2396, NULL, 2850, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5110, 234, NULL, 2851, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5111, 1400, NULL, 2851, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5109, 1707, NULL, 2851, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5113, 5121, NULL, 2852, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5112, 377, NULL, 2852, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5114, 5122, NULL, 2852, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5115, 2611, NULL, 2853, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5116, 2536, NULL, 2853, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5123, 2336, NULL, 2856, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5122, 3003, NULL, 2856, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5124, 1585, NULL, 2857, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5121, 955, NULL, 2855, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5120, 1780, NULL, 2855, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5119, 5123, NULL, 2854, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5117, 1373, NULL, 2854, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5125, 4675, NULL, 2857, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5126, 186, NULL, 2858, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5127, 5124, NULL, 2858, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5128, 3428, NULL, 2859, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5129, 2964, NULL, 2859, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5219, 5149, NULL, 1886, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5220, 5150, NULL, 1886, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5221, 3357, NULL, 384, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5222, 1022, NULL, 1883, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5223, 650, NULL, 1883, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5224, 2236, NULL, 1883, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5225, 1565, NULL, 1878, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5226, 1628, NULL, 1878, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5227, 4, NULL, 1878, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5228, 1618, NULL, 1885, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5229, 1352, NULL, 1885, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5230, 3848, NULL, 1885, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5231, 1672, NULL, 1881, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5232, 1655, NULL, 1881, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5233, 4404, NULL, 1881, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16022, 7935, NULL, 5219, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16023, 3989, NULL, 5219, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16024, 8041, NULL, 5219, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16025, 7936, NULL, 5220, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16026, 2397, NULL, 5220, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16027, 2516, NULL, 5220, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16028, 8042, NULL, 5220, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16029, 7937, NULL, 5221, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16030, 5796, NULL, 5221, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16031, 2494, NULL, 5221, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16032, 6576, NULL, 5221, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16033, 802, NULL, 5222, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16034, 596, NULL, 5222, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16035, 4311, NULL, 5222, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16036, 128, NULL, 5223, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16037, 1896, NULL, 5223, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16038, 688, NULL, 5223, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16039, 146, NULL, 5224, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16040, 8043, NULL, 5224, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16041, 8044, NULL, 5224, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16042, 1944, NULL, 5224, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16043, 8054, NULL, 5225, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16044, 8055, NULL, 5225, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16045, 8056, NULL, 5226, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16046, 8057, NULL, 5227, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16047, 8058, NULL, 5227, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16048, 4043, NULL, 5227, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5149, 146, NULL, 2873, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5147, 3545, 624, 2873, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5148, 2554, NULL, 2873, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16049, 8059, NULL, 5227, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16050, 8060, NULL, 5228, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16051, 1582, NULL, 5228, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16052, 8061, NULL, 5228, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16053, 2554, NULL, 5228, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16058, 7761, NULL, 5231, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16059, 8062, NULL, 5231, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16060, 5534, NULL, 5231, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16061, 8063, NULL, 5231, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28553, 12078, NULL, 8883, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28554, 12079, NULL, 8883, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2617, 3054, NULL, 855, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28555, 12080, NULL, 8883, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28825, 1270, NULL, 8941, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28826, 2571, NULL, 8941, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28860, 1284, NULL, 8951, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28861, 5856, NULL, 8951, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28862, 9913, NULL, 8951, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28863, 5524, NULL, 8951, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28883, 1882, NULL, 8958, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28884, 7189, NULL, 8958, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32852, 2827, NULL, 10173, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28904, 1257, NULL, 8965, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28905, 1659, NULL, 8965, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28906, 445, NULL, 8965, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28907, 2559, NULL, 8965, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28939, 3009, NULL, 8977, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28940, 1854, NULL, 8977, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28941, 12255, NULL, 8977, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28942, 8300, NULL, 8977, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28956, 3697, NULL, 8983, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28957, 12261, NULL, 8983, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28958, 12262, NULL, 8983, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5234, 39, NULL, 1881, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5235, 448, NULL, 2087, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5236, 1541, NULL, 2087, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5237, 378, NULL, 2087, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5241, 450, NULL, 2090, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5242, 1149, NULL, 2090, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5243, 807, NULL, 2089, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5244, 2431, NULL, 2089, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5245, 2078, NULL, 2089, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5246, 3470, NULL, 2089, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5247, 1721, NULL, 2088, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5248, 2511, NULL, 2088, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5249, 971, NULL, 2088, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5250, 3603, NULL, 2088, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5251, 3932, NULL, 2088, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5252, 967, NULL, 2091, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5253, 1066, NULL, 2091, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5254, 3131, NULL, 2091, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5255, 1373, NULL, 2091, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5256, 5006, NULL, 2091, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5257, 1853, NULL, 2084, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5258, 2110, NULL, 2084, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5259, 3159, NULL, 2084, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5260, 3484, NULL, 2086, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5261, 3358, NULL, 2086, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5262, 942, NULL, 2086, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5263, 686, NULL, 2211, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5264, 1926, NULL, 2211, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5265, 304, NULL, 2208, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5266, 390, NULL, 2208, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5267, 4664, NULL, 2209, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5268, 19, NULL, 2209, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5269, 1400, NULL, 2209, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5270, 5035, NULL, 2209, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5271, 5042, NULL, 2209, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5272, 2808, NULL, 2212, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5273, 2815, NULL, 2212, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5274, 166, NULL, 2212, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5275, 5111, NULL, 2213, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5276, 5126, NULL, 2213, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5277, 5142, NULL, 2213, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5280, 3384, NULL, 2214, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5281, 2544, NULL, 2214, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5282, 5151, NULL, 2214, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5283, 503, NULL, 2210, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5284, 1093, NULL, 2210, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5285, 2449, NULL, 2210, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5286, 152, NULL, 1888, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5287, 5152, NULL, 1888, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5288, 1809, NULL, 1892, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5289, 1629, NULL, 1892, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5290, 128, NULL, 1892, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5291, 1046, NULL, 1894, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5292, 949, NULL, 1894, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5293, 2799, NULL, 1894, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5294, 5153, NULL, 1894, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5295, 430, NULL, 1891, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5296, 4264, NULL, 1891, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5297, 2871, NULL, 1891, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5298, 1329, NULL, 1890, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5299, 1849, NULL, 1890, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5300, 2150, NULL, 1890, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5301, 1882, NULL, 1887, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5302, 5154, NULL, 1887, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5303, 5155, NULL, 1887, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5304, 183, NULL, 1893, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5305, 1542, NULL, 1893, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5306, 798, NULL, 1893, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5307, 2397, NULL, 1893, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5308, 318, NULL, 1889, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5309, 1424, NULL, 1889, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5310, 2136, NULL, 1889, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5311, 377, NULL, 2215, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5312, 4611, NULL, 2215, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5313, 2898, NULL, 2215, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5314, 5156, NULL, 2215, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5315, 3713, NULL, 2216, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5316, 5157, NULL, 2216, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5321, 512, NULL, 2217, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5322, 2970, NULL, 2217, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5323, 5158, NULL, 2217, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5324, 2042, NULL, 2218, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5325, 2776, NULL, 2218, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5326, 5159, NULL, 2218, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16062, 8064, NULL, 5231, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16063, 8065, NULL, 5232, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16064, 4754, NULL, 5232, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16065, 2177, NULL, 5232, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16066, 8066, NULL, 5233, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16067, 8067, NULL, 5233, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16068, 8068, NULL, 5233, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16069, 2375, NULL, 5233, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16070, 8069, NULL, 5234, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16071, 482, NULL, 5234, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16072, 2151, NULL, 5234, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16073, 435, NULL, 5234, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16078, 8073, NULL, 5236, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16079, 8074, NULL, 5236, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16080, 8075, NULL, 5236, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16081, 8076, NULL, 5236, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16082, 4449, NULL, 5236, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16083, 2377, NULL, 5236, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16084, 7949, NULL, 5237, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16085, 2419, NULL, 5237, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16086, 2636, NULL, 5237, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16087, 8077, NULL, 5237, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16088, 8078, NULL, 5238, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16089, 2897, NULL, 5238, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16090, 2379, NULL, 5238, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16091, 2661, NULL, 5238, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16092, 8079, NULL, 5239, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16093, 1084, NULL, 526, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16094, 1084, NULL, 1920, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16095, 5268, NULL, 2070, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16096, 8100, NULL, 5240, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16097, 5953, NULL, 5240, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16098, 8101, NULL, 5240, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16099, 6374, NULL, 5240, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16100, 8102, NULL, 5241, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16101, 2691, NULL, 5241, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16102, 8103, NULL, 5241, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16103, 8104, NULL, 5241, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28556, 12081, NULL, 8883, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28908, 601, NULL, 8966, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28943, 9043, NULL, 8978, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28944, 10472, NULL, 8978, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28945, 11520, NULL, 8978, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28946, 9613, NULL, 8978, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28959, 12263, NULL, 8984, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28994, 3383, NULL, 8996, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28995, 2480, NULL, 8996, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5239, 384, NULL, 2085, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5238, 2490, NULL, 2085, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5240, 577, NULL, 2085, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16056, 450, NULL, 5229, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16055, 1855, NULL, 5229, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16057, 1193, NULL, 5229, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16054, 1294, NULL, 5229, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16076, 2235, NULL, 5235, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16075, 8071, NULL, 5235, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16074, 1707, NULL, 5235, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5327, 2386, NULL, 2220, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5328, 2804, NULL, 2220, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5329, 1148, NULL, 2220, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5330, 156, NULL, 2221, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5331, 1086, NULL, 2221, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5332, 2634, NULL, 2219, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5333, 106, NULL, 2219, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5334, 78, NULL, 2219, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5335, 441, NULL, 1528, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5336, 1179, NULL, 1528, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5337, 2155, NULL, 1528, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5338, 4264, NULL, 1528, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5339, 84, NULL, 1530, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5340, 2489, NULL, 1530, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5341, 4544, NULL, 1530, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5342, 448, NULL, 1527, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5343, 2332, NULL, 1527, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5344, 2391, NULL, 1527, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5345, 2383, NULL, 1527, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5346, 937, NULL, 1524, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5347, 625, NULL, 1524, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5348, 5160, NULL, 1524, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5349, 2054, NULL, 1526, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5350, 1181, NULL, 1526, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5351, 4073, NULL, 1526, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5352, 382, NULL, 1529, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5353, 1503, NULL, 1529, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5354, 39, NULL, 1529, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5355, 1629, NULL, 1529, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5356, 424, NULL, 1529, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5357, 1072, NULL, 1531, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5358, 1745, NULL, 1531, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5359, 902, NULL, 1531, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5360, 3983, NULL, 1531, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5361, 4579, NULL, 1525, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5362, 5161, NULL, 1525, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5363, 5162, NULL, 1525, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5364, 4362, NULL, 1525, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5365, 3335, NULL, 2112, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5366, 3336, NULL, 2112, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5367, 408, NULL, 2110, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5368, 1293, NULL, 2115, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5369, 4615, NULL, 2115, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5370, 5164, NULL, 2120, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5371, 601, NULL, 2109, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5372, 3507, NULL, 2117, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5373, 403, NULL, 2117, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5374, 1609, NULL, 2117, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5375, 1446, NULL, 2117, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5376, 245, NULL, 2108, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5377, 3061, NULL, 2108, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5378, 445, NULL, 2118, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5379, 1542, NULL, 2118, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5384, 3325, NULL, 2107, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5385, 4594, NULL, 2107, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5386, 3840, NULL, 2107, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5387, 104, NULL, 2111, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5388, 857, NULL, 2111, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5389, 2821, NULL, 2111, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5390, 3674, NULL, 2114, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5391, 2205, NULL, 2114, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5392, 941, NULL, 2116, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5393, 2774, NULL, 2116, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5394, 4621, NULL, 2116, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5395, 4288, NULL, 2116, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5396, 232, NULL, 2116, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (5397, 628, NULL, 2758, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5398, 4069, NULL, 2758, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5399, 1371, NULL, 2759, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5400, 4353, NULL, 2759, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5401, 1775, NULL, 2759, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5402, 1775, NULL, 2216, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5403, 441, NULL, 2760, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5404, 4163, NULL, 2760, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5405, 5166, NULL, 2761, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5406, 5167, NULL, 2761, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5407, 1059, NULL, 2879, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5408, 2878, NULL, 2879, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5409, 588, NULL, 2880, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5410, 148, NULL, 2880, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5411, 4277, NULL, 2880, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5412, 805, NULL, 2880, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5413, 1404, NULL, 2881, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5414, 5169, NULL, 2881, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5415, 5170, NULL, 2881, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5416, 1435, NULL, 2882, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5417, 5115, NULL, 2882, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5418, 5171, NULL, 2882, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16104, 8105, NULL, 5242, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16105, 1652, NULL, 5242, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16106, 4690, NULL, 5243, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16107, 8106, NULL, 5244, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16108, 8107, NULL, 5244, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16109, 8049, NULL, 5245, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16110, 5767, NULL, 5245, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16111, 8108, NULL, 5245, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16112, 2892, NULL, 5245, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16113, 8109, NULL, 5246, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16114, 452, NULL, 5247, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16115, 713, NULL, 5247, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16116, 2576, NULL, 5247, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16117, 1241, NULL, 5247, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16118, 1198, NULL, 5248, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16119, 136, NULL, 5248, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16120, 7507, NULL, 5248, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16121, 423, NULL, 5248, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16122, 6136, NULL, 5249, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16123, 8110, NULL, 5250, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16124, 8111, NULL, 5250, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16125, 8112, NULL, 5251, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16126, 4658, NULL, 5252, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16127, 8113, NULL, 5252, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16128, 2064, NULL, 5252, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16129, 3747, NULL, 5252, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16130, 8114, NULL, 5253, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16131, 2421, NULL, 5253, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16132, 8115, NULL, 5254, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16133, 8116, NULL, 5255, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16134, 8117, NULL, 5255, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16135, 8118, NULL, 5255, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16136, 8119, NULL, 5255, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16137, 8120, NULL, 5255, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16138, 8121, NULL, 5256, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16139, 6284, NULL, 5256, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16140, 8122, NULL, 5257, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16141, 8123, NULL, 5257, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16142, 6848, NULL, 5257, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16143, 360, NULL, 5258, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16144, 5933, NULL, 5258, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16145, 8124, NULL, 5258, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16146, 7204, NULL, 5258, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28890, 12249, NULL, 8960, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28909, 179, NULL, 8967, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28910, 773, NULL, 8967, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28911, 2711, NULL, 8967, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28912, 1311, NULL, 8967, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28947, 12256, NULL, 8979, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28948, 12257, NULL, 8979, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28949, 12258, NULL, 8979, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28960, 12264, NULL, 8985, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28961, 12265, NULL, 8985, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5380, 2113, NULL, 2113, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5383, 3199, NULL, 2113, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5382, 1631, NULL, 2113, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5381, 1821, NULL, 2113, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28996, 2846, NULL, 8997, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28997, 4901, NULL, 8997, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28998, 2304, NULL, 8997, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28999, 2998, NULL, 8997, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5419, 5172, NULL, 2882, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5420, 128, NULL, 2883, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5421, 1319, NULL, 2883, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5422, 1226, NULL, 2883, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5423, 13, NULL, 2884, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5424, 2899, NULL, 2884, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5425, 5173, NULL, 2884, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5426, 2596, NULL, 2885, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5427, 728, NULL, 2885, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5428, 3935, NULL, 2885, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5429, 534, NULL, 2886, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5430, 171, NULL, 2886, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5431, 482, NULL, 2886, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5432, 512, NULL, 2887, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5433, 4434, NULL, 2887, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5434, 601, NULL, 2887, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5435, 2974, NULL, 2888, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5436, 3400, NULL, 2888, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5437, 1181, NULL, 2888, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5438, 5174, NULL, 2889, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5439, 722, NULL, 2890, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5440, 3685, NULL, 2890, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5441, 5175, NULL, 2890, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5442, 967, NULL, 2891, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5443, 4385, NULL, 2891, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5444, 5176, NULL, 2891, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5445, 5177, NULL, 2892, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5469, 1329, NULL, 2905, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5470, 785, NULL, 2905, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5450, 94, NULL, 2895, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5451, 335, NULL, 2895, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5448, 95, NULL, 2894, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5449, 5179, NULL, 2894, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5452, 1549, NULL, 2896, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5453, 753, NULL, 2897, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5454, 1811, NULL, 2897, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5455, 240, NULL, 2898, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5457, 460, NULL, 2899, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5458, 1397, NULL, 2899, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5461, 462, NULL, 2900, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5460, 1589, NULL, 2900, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5462, 1438, NULL, 2901, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5463, 205, NULL, 2902, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5464, 5181, NULL, 2902, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5465, 878, NULL, 2903, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5466, 931, NULL, 2904, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5467, 1495, NULL, 2904, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5471, 5183, NULL, 2905, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5472, 5184, NULL, 2905, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5473, 1565, NULL, 2906, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5474, 1664, NULL, 2906, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5475, 5185, NULL, 2906, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5476, 1955, NULL, 2907, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5477, 2611, NULL, 2907, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5479, 259, NULL, 2907, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5480, 598, NULL, 2909, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5481, 2536, NULL, 2909, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5482, 2318, NULL, 2909, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5483, 3242, NULL, 2909, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5484, 1401, NULL, 2910, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5485, 2625, NULL, 2910, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5486, 1981, NULL, 2910, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5487, 1540, NULL, 2911, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5488, 750, NULL, 2911, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5489, 2081, NULL, 2911, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5490, 720, NULL, 2232, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5491, 3390, NULL, 2232, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5492, 2258, NULL, 2232, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5493, 350, NULL, 2230, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5494, 1687, NULL, 2230, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32853, 2766, NULL, 10173, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5496, 226, NULL, 2233, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5497, 687, NULL, 2233, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5498, 2240, NULL, 2233, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5499, 1593, NULL, 2229, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5500, 1875, NULL, 2229, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5501, 2456, NULL, 2229, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5502, 2189, NULL, 2228, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5503, 5186, NULL, 2228, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5504, 5187, NULL, 2228, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5505, 2883, NULL, 2914, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5506, 2886, NULL, 2914, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5507, 5188, NULL, 2914, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5508, 5189, NULL, 2915, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5509, 5190, NULL, 2915, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5510, 5191, NULL, 2915, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5511, 4790, NULL, 2916, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5512, 5192, NULL, 2916, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5513, 5193, NULL, 2916, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5514, 5194, NULL, 2916, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5515, 416, NULL, 2917, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5516, 2903, NULL, 2917, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5517, 4065, NULL, 2917, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5518, 5195, NULL, 2918, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5519, 1042, NULL, 2919, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5520, 2342, NULL, 2919, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5521, 5196, NULL, 2919, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5522, 5197, NULL, 2920, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5523, 4104, NULL, 2921, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5524, 5198, NULL, 2921, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5525, 1917, NULL, 2922, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5526, 2309, NULL, 2922, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5527, 5199, NULL, 2922, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5528, 872, NULL, 2923, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5529, 688, NULL, 2923, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5530, 1926, NULL, 2923, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16147, 8125, NULL, 5259, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16148, 8126, NULL, 5259, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16149, 8127, NULL, 5260, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16150, 5584, NULL, 5261, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16151, 591, NULL, 5261, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16152, 6808, NULL, 5262, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16153, 8128, NULL, 5262, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16154, 2672, NULL, 5262, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16155, 2837, NULL, 5262, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16156, 1553, NULL, 5263, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16157, 1225, NULL, 5263, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16158, 2790, NULL, 5263, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16159, 3669, NULL, 5263, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16160, 6713, NULL, 1406, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16161, 6713, NULL, 798, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5560, 2536, NULL, 2924, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5561, 2318, NULL, 2924, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5562, 3242, NULL, 2924, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5567, 267, NULL, 2926, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5568, 2874, NULL, 2926, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5569, 5202, NULL, 2926, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5570, 5203, NULL, 2927, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5571, 5204, NULL, 2927, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5572, 162, NULL, 2928, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5573, 1772, NULL, 2928, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5574, 756, NULL, 2928, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5575, 5205, NULL, 2928, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5576, 5206, NULL, 2929, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5577, 1431, NULL, 2930, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5578, 806, NULL, 2930, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5579, 1997, NULL, 2930, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5580, 1198, NULL, 2931, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5581, 4983, NULL, 2931, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5582, 1716, NULL, 2931, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5583, 5011, NULL, 2933, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5584, 1535, NULL, 2934, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5585, 608, NULL, 2934, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5586, 1540, NULL, 2936, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5587, 750, NULL, 2936, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5588, 2081, NULL, 2936, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5589, 188, NULL, 1817, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5590, 2921, NULL, 1817, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5591, 2877, NULL, 1817, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5592, 1472, NULL, 1817, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5593, 2846, NULL, 1814, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5594, 2110, NULL, 1814, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5545, 32, NULL, 1808, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5544, 4663, NULL, 1808, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5546, 3571, NULL, 1808, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5547, 424, NULL, 1810, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5542, 652, NULL, 1807, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5541, 1691, NULL, 1807, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5543, 2943, NULL, 1807, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5540, 1830, NULL, 1807, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5536, 2017, NULL, 1812, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5535, 346, NULL, 1812, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5537, 355, NULL, 1812, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5538, 2104, NULL, 1812, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5550, 5200, NULL, 1810, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5548, 1331, NULL, 1810, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5549, 2016, NULL, 1810, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5552, 2375, NULL, 1806, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5551, 1355, NULL, 1806, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5554, 806, NULL, 1811, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5555, 1997, NULL, 1811, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5553, 1659, NULL, 1811, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5564, 425, NULL, 2925, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5565, 2336, NULL, 2925, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5566, 5786, NULL, 2925, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5595, 3504, NULL, 1814, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5596, 3524, NULL, 1814, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5597, 749, NULL, 1816, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5598, 2368, NULL, 1816, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5599, 2467, NULL, 1816, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5600, 1044, NULL, 1816, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5601, 890, NULL, 1822, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5602, 1311, NULL, 1822, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5603, 2544, NULL, 1822, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5604, 2507, NULL, 1822, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5609, 1221, NULL, 1821, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5610, 3528, NULL, 1821, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5611, 1044, NULL, 1821, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5612, 1788, NULL, 1821, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5613, 1435, NULL, 1813, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5614, 1971, NULL, 1813, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5615, 4546, NULL, 1813, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5616, 2375, NULL, 1813, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5623, 904, NULL, 1818, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5624, 3513, NULL, 1818, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5625, 1821, NULL, 1818, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5626, 1748, NULL, 1818, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5627, 701, NULL, 2422, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5628, 1112, NULL, 2422, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5629, 2421, NULL, 2422, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5630, 470, NULL, 2427, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5620, 4105, NULL, 1819, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5621, 111, NULL, 1819, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5619, 280, NULL, 1819, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5622, 5207, NULL, 1819, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5617, 3398, NULL, 1815, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5618, 1956, NULL, 1815, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5606, 116, NULL, 1820, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5608, 1940, NULL, 1820, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5607, 503, NULL, 1820, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5631, 232, NULL, 2427, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5632, 2922, NULL, 2427, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5633, 952, NULL, 2427, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5634, 2017, NULL, 2431, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5635, 1988, NULL, 2425, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5636, 1880, NULL, 2425, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5637, 2270, NULL, 2421, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5638, 226, NULL, 2428, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5639, 1505, NULL, 2428, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5640, 2532, NULL, 2428, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5641, 128, NULL, 2428, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16163, 247, NULL, 5264, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16164, 2597, NULL, 5264, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16165, 1917, NULL, 5264, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16166, 1068, NULL, 5264, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16167, 1228, NULL, 5265, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16168, 8157, NULL, 5265, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16169, 6718, NULL, 5265, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16170, 2428, NULL, 5265, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16171, 3581, NULL, 5266, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16172, 785, NULL, 5266, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16173, 2555, NULL, 5266, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16174, 2300, NULL, 5266, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16175, 295, NULL, 5267, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16176, 2696, NULL, 5267, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16177, 850, NULL, 5267, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16178, 803, NULL, 5267, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16187, 8016, NULL, 5269, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16188, 8158, NULL, 5269, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16189, 8159, NULL, 5269, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16190, 8160, NULL, 5269, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16191, 781, NULL, 5270, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16192, 3253, NULL, 5271, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16193, 5853, NULL, 5271, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16194, 5973, NULL, 5271, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16195, 8161, NULL, 5271, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16196, 1219, NULL, 5272, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16197, 649, NULL, 5272, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16198, 2514, NULL, 5272, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16199, 219, NULL, 5272, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16200, 1714, NULL, 5273, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16201, 8162, NULL, 5273, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16202, 2276, NULL, 5273, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16203, 2373, NULL, 5273, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16204, 1257, NULL, 5274, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28913, 757, NULL, 8968, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28914, 2332, NULL, 8968, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28915, 709, NULL, 8968, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28916, 1821, NULL, 8968, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28962, 12266, NULL, 8986, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28963, 2442, NULL, 8986, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28964, 12267, NULL, 8986, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29000, 11436, NULL, 8998, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29001, 12277, NULL, 8998, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29029, 2106, NULL, 9010, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29030, 1673, NULL, 9010, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29031, 2106, NULL, 9011, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29032, 230, NULL, 9011, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29033, 2106, NULL, 9012, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29041, 5865, NULL, 9020, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29042, 12281, NULL, 9020, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29043, 3618, NULL, 9020, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29044, 3617, NULL, 9020, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29045, 38, NULL, 9020, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29046, 8165, NULL, 9020, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (29047, 12281, NULL, 9020, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (29048, 5949, NULL, 9021, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5642, 872, NULL, 2429, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5643, 2899, NULL, 2429, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5644, 1699, NULL, 2429, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5645, 405, NULL, 2429, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32854, 2411, NULL, 10173, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32855, 1455, NULL, 10173, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5650, 915, NULL, 2950, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5651, 1542, NULL, 2950, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5652, 2559, NULL, 2950, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5653, 1825, NULL, 2950, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5654, 1765, NULL, 2951, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5655, 3992, NULL, 2951, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5656, 4578, NULL, 2951, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5657, 955, NULL, 2951, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5660, 62, NULL, 2953, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5661, 219, NULL, 2953, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5662, 1958, NULL, 2953, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5663, 1880, NULL, 2953, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5664, 445, NULL, 2954, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5665, 867, NULL, 2954, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5666, 3438, NULL, 2954, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5667, 1943, NULL, 2954, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5668, 709, NULL, 2955, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5669, 3013, NULL, 2955, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5670, 3318, NULL, 2955, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5671, 5210, NULL, 2955, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5672, 100, NULL, 2956, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5673, 3744, NULL, 2956, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5674, 451, NULL, 2957, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5675, 2240, NULL, 2957, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5676, 687, NULL, 2957, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5677, 1699, NULL, 2957, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5678, 152, NULL, 2958, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5679, 588, NULL, 2959, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5680, 1026, NULL, 2959, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5681, 2442, NULL, 2959, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5682, 63, NULL, 2960, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5683, 5211, NULL, 2960, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5684, 497, NULL, 2961, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5685, 992, NULL, 2961, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5686, 3140, NULL, 2961, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5691, 1875, NULL, 2963, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5692, 2411, NULL, 2963, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5693, 534, NULL, 2964, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5694, 146, NULL, 2964, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5695, 955, NULL, 2964, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5696, 318, NULL, 2965, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5697, 4085, NULL, 2965, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5698, 682, NULL, 2965, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5702, 1762, NULL, 1546, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5703, 5213, NULL, 1546, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5704, 5214, NULL, 1546, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5708, 1377, NULL, 1550, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5709, 811, NULL, 1550, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5710, 5215, NULL, 1550, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5711, 1171, NULL, 1544, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5712, 5216, NULL, 1544, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5713, 5217, NULL, 1544, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5714, 719, NULL, 1551, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5715, 1070, NULL, 1551, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5716, 5219, NULL, 1547, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5717, 1398, NULL, 1543, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5718, 3607, NULL, 1543, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5719, 5220, NULL, 1543, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5720, 413, NULL, 1549, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5721, 5221, NULL, 1549, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5722, 3484, NULL, 1549, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5723, 1112, NULL, 1545, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5724, 3110, NULL, 1545, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5725, 1331, NULL, 1548, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5726, 200, NULL, 1548, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5727, 5222, NULL, 1548, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5728, 1458, NULL, 2967, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5729, 5223, NULL, 2967, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5730, 4497, NULL, 2967, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5731, 722, NULL, 2968, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5732, 5224, NULL, 2968, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5733, 5225, NULL, 2968, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16205, 4643, NULL, 5274, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16206, 3612, NULL, 5274, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16207, 8163, NULL, 5274, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16211, 411, NULL, 5276, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16212, 3135, NULL, 5276, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16213, 8164, NULL, 5276, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16214, 4903, NULL, 5276, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16215, 807, NULL, 5277, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16216, 5528, NULL, 5277, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16217, 4047, NULL, 5277, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16218, 4738, NULL, 5277, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16219, 657, NULL, 5277, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16220, 2947, NULL, 5277, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16221, 8165, NULL, 5277, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16222, 2576, NULL, 5278, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16223, 1112, NULL, 5278, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16224, 2129, NULL, 5278, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16225, 8166, NULL, 5278, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16226, 1445, NULL, 5279, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16227, 620, NULL, 5279, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5659, 5209, NULL, 2952, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5658, 11299, NULL, 2952, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5689, 39, NULL, 2962, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5687, 807, NULL, 2962, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5690, 857, NULL, 2962, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5688, 4615, NULL, 2962, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16228, 8167, NULL, 5279, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16229, 346, NULL, 5279, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16230, 1714, NULL, 5280, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16231, 2747, NULL, 5280, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16232, 1716, NULL, 5280, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16233, 2356, NULL, 5280, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16234, 1664, NULL, 5281, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16235, 1575, NULL, 5281, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16236, 2294, NULL, 5281, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16237, 8019, NULL, 5282, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16238, 2904, NULL, 5282, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16239, 8168, NULL, 5282, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16240, 8169, NULL, 5282, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16241, 8170, NULL, 5283, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16242, 5573, NULL, 5283, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16243, 8171, NULL, 5283, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16244, 3367, NULL, 5283, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16245, 411, NULL, 5284, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16246, 5486, NULL, 5284, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28917, 1665, NULL, 8969, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28918, 2696, NULL, 8969, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28919, 5933, NULL, 8969, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28965, 12268, NULL, 8987, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28966, 12269, NULL, 8987, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28967, 2864, NULL, 8987, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28968, 2657, NULL, 8987, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29002, 12278, NULL, 8999, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29034, 2106, NULL, 9013, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29049, 1498, NULL, 9021, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29050, 12282, NULL, 9021, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29051, 8848, NULL, 9021, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5734, 1618, NULL, 2969, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5735, 5226, NULL, 2969, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5736, 2587, NULL, 2969, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5737, 1389, NULL, 2970, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5738, 2505, NULL, 2970, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5739, 2730, NULL, 2970, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5740, 4363, NULL, 2970, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5741, 3771, NULL, 2970, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5742, 4899, NULL, 2971, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5743, 5214, NULL, 2971, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5744, 5227, NULL, 2971, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5745, 5229, NULL, 2972, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5746, 1570, NULL, 2972, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5747, 14, NULL, 2973, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5748, 1819, NULL, 2973, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5749, 3964, NULL, 2973, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5750, 408, NULL, 1959, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5751, 374, NULL, 1962, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5752, 5232, NULL, 1962, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5753, 5233, NULL, 1962, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5754, 1744, NULL, 1962, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5755, 441, NULL, 1965, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5756, 146, NULL, 1965, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5757, 3424, NULL, 1965, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5758, 702, NULL, 1957, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5759, 2101, NULL, 1957, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5760, 537, NULL, 1957, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5761, 1059, NULL, 1966, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5762, 389, NULL, 1966, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5763, 1792, NULL, 1966, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5764, 2140, NULL, 1960, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5765, 1118, NULL, 1960, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5766, 39, NULL, 1960, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5767, 2511, NULL, 1960, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5768, 1882, NULL, 1955, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5769, 5234, NULL, 1955, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5770, 382, NULL, 1963, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5771, 1331, NULL, 1963, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5772, 200, NULL, 1963, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5773, 1705, NULL, 1954, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5774, 1586, NULL, 1954, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5775, 5238, NULL, 1954, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5776, 5131, NULL, 2974, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5777, 5239, NULL, 2974, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5778, 5240, NULL, 2974, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5779, 5242, NULL, 2975, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5780, 5243, NULL, 2975, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32856, 993, NULL, 10174, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5782, 5244, NULL, 2976, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5783, 4048, NULL, 2976, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5784, 1986, NULL, 2977, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5785, 5245, NULL, 2977, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5786, 2858, NULL, 2977, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5787, 1574, NULL, 2977, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5788, 1455, NULL, 2978, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5789, 2285, NULL, 2978, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5790, 5246, NULL, 2978, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5791, 2456, NULL, 2978, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5792, 384, NULL, 2979, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5793, 316, NULL, 2979, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5794, 382, NULL, 2979, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5795, 2037, NULL, 2980, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5796, 1510, NULL, 2980, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5797, 1091, NULL, 2980, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5798, 749, NULL, 2981, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5799, 1536, NULL, 2981, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5800, 2724, NULL, 2981, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5801, 2382, NULL, 2981, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5802, 2842, NULL, 2981, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5803, 1772, NULL, 2982, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5804, 958, NULL, 2982, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5805, 756, NULL, 2982, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5806, 2789, NULL, 2982, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5807, 4924, NULL, 2982, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5808, 403, NULL, 2983, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5809, 1462, NULL, 2983, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5810, 1775, NULL, 2983, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5811, 1368, NULL, 2983, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5812, 2364, NULL, 2984, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5813, 2616, NULL, 2984, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5814, 5247, NULL, 2984, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5819, 2532, NULL, 2986, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5820, 2605, NULL, 2986, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5821, 295, NULL, 2987, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5822, 2008, NULL, 2987, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5823, 2744, NULL, 2987, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5824, 2210, NULL, 2987, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5825, 5248, NULL, 2988, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5826, 1588, NULL, 2988, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16247, 32, NULL, 5284, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16248, 1867, NULL, 5284, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16249, 3132, NULL, 5284, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16250, 2554, NULL, 5284, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16251, 1929, NULL, 5284, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16252, 295, NULL, 5285, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16253, 1958, NULL, 5285, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16254, 792, NULL, 5285, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16255, 2340, NULL, 5285, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16256, 1894, NULL, 5285, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16257, 1618, NULL, 5286, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16258, 2561, NULL, 5286, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16259, 2118, NULL, 5286, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16260, 2144, NULL, 5286, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16261, 1823, NULL, 5286, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16262, 2531, NULL, 5286, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16263, 812, NULL, 5286, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16264, 1855, NULL, 5286, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (16265, 282, NULL, 5287, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16266, 8173, NULL, 5287, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16267, 7507, NULL, 5288, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16268, 16, NULL, 5288, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16269, 3930, NULL, 5289, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16270, 8174, NULL, 5289, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16271, 540, NULL, 5289, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16272, 8020, NULL, 5290, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16273, 310, NULL, 5290, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16274, 1858, NULL, 5290, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16275, 8175, NULL, 5290, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16276, 1662, NULL, 5291, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16277, 649, NULL, 5291, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16278, 3225, NULL, 5291, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16279, 2972, NULL, 5291, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16280, 8178, NULL, 5292, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16281, 8005, NULL, 5293, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16180, 692, NULL, 5268, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16185, 685, NULL, 5268, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16184, 867, NULL, 5268, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16210, 661, NULL, 5275, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16282, 8006, NULL, 5294, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16283, 2201, NULL, 5296, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16284, 3613, NULL, 5297, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16285, 8008, NULL, 5298, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16286, 8009, NULL, 5299, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16287, 8010, NULL, 5300, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16288, 8011, NULL, 5301, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28920, 923, NULL, 8970, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28921, 5646, NULL, 8970, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28922, 12245, NULL, 8970, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28923, 12246, NULL, 8970, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28924, 1553, NULL, 8970, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28969, 12270, NULL, 8988, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28970, 12271, NULL, 8988, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29003, 10908, NULL, 9000, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29004, 4838, NULL, 9000, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29035, 2106, NULL, 9014, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32857, 5123, NULL, 10174, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32858, 4740, NULL, 10174, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32859, 790, NULL, 10174, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32860, 5070, NULL, 10175, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32861, 13861, NULL, 10175, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32862, 13862, NULL, 10175, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29072, 12286, NULL, 9026, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29073, 7558, NULL, 9026, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29074, 9931, NULL, 9026, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29075, 11052, NULL, 9026, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29080, 12288, NULL, 9028, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29081, 10417, NULL, 9028, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5827, 5249, NULL, 2988, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5828, 5250, NULL, 2988, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5829, 1294, NULL, 2988, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5830, 2650, NULL, 2989, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5831, 3015, NULL, 2989, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29053, 288, NULL, 9022, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5832, 3367, NULL, 2989, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5833, 671, NULL, 2990, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5834, 5252, NULL, 2990, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5835, 3056, NULL, 2991, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5836, 1926, NULL, 2991, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5837, 1146, NULL, 2991, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5838, 1107, NULL, 2992, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5839, 2418, NULL, 2992, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5840, 939, NULL, 2992, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5841, 5254, NULL, 2992, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5842, 456, NULL, 2993, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5843, 920, NULL, 2993, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5844, 2816, NULL, 2993, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5845, 692, NULL, 2993, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5846, 989, NULL, 2993, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5847, 523, NULL, 2994, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5848, 133, NULL, 2994, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5849, 13, NULL, 2994, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5850, 1283, NULL, 2995, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5851, 305, NULL, 2995, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5852, 1504, NULL, 2995, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5853, 65, NULL, 2995, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5854, 2369, NULL, 2995, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5855, 819, NULL, 2996, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5856, 1503, NULL, 2996, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5857, 122, NULL, 2996, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5858, 835, NULL, 2996, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5859, 1834, NULL, 2996, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5860, 1717, NULL, 2997, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5861, 381, NULL, 2997, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5862, 806, NULL, 2997, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5863, 1542, NULL, 2997, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5864, 1979, NULL, 2997, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5865, 1229, NULL, 2998, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5866, 2706, NULL, 2998, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5867, 78, NULL, 2998, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5868, 1643, NULL, 2998, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5869, 4726, NULL, 2999, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5870, 1659, NULL, 2999, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5871, 1731, NULL, 2999, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5872, 68, NULL, 2999, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5873, 234, NULL, 2999, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (5874, 2746, NULL, 3000, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5875, 1148, NULL, 3000, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5876, 2362, NULL, 3000, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5877, 1789, NULL, 3001, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5878, 320, NULL, 3001, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5879, 2737, NULL, 3001, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5880, 3383, NULL, 3002, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5881, 41, NULL, 3003, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5882, 312, NULL, 3003, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5883, 246, NULL, 3004, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5884, 3976, NULL, 3004, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5885, 5163, NULL, 3004, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5886, 2214, NULL, 3005, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5887, 4202, NULL, 3005, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5888, 1464, NULL, 3006, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5889, 2264, NULL, 3006, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5890, 2465, NULL, 3006, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5891, 5235, NULL, 3006, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5892, 4067, NULL, 3007, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5893, 3057, NULL, 3007, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5894, 2031, NULL, 3007, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5895, 2138, NULL, 3007, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5896, 1840, NULL, 3008, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5897, 2482, NULL, 3008, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5898, 2386, NULL, 3008, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5899, 1850, NULL, 3008, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5900, 408, NULL, 3009, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5901, 2964, NULL, 3010, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5902, 1693, NULL, 3010, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5903, 1586, NULL, 3010, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5908, 3158, NULL, 1534, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5909, 1006, NULL, 1534, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5910, 2069, NULL, 1534, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5911, 3025, NULL, 1540, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5912, 1624, NULL, 1540, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5913, 2559, NULL, 1540, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5914, 1059, NULL, 1539, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5915, 5149, NULL, 1539, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5916, 709, NULL, 1539, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5917, 5256, NULL, 1539, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5918, 777, NULL, 1532, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16289, 2576, NULL, 7, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16290, 2576, NULL, 2958, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16291, 2576, NULL, 3690, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16292, 2576, NULL, 1888, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16293, 2576, NULL, 1996, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16294, 2576, NULL, 3847, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16295, 3568, NULL, 698, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16296, 1135, NULL, 1, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16297, 1135, NULL, 525, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16298, 372, NULL, 4783, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16299, 607, NULL, 2042, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16300, 8188, NULL, 5312, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16301, 7558, NULL, 5312, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16302, 2332, NULL, 5312, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16303, 2263, NULL, 5312, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16304, 688, NULL, 5312, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16305, 2592, NULL, 5312, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16306, 1334, NULL, 5312, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16307, 7558, NULL, 3537, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16308, 7558, NULL, 3625, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16309, 2862, NULL, 5310, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32863, 1043, NULL, 10176, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32864, 951, NULL, 10176, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32865, 13863, NULL, 10176, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32866, 13864, NULL, 10176, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16314, 6429, NULL, 5319, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16315, 8191, NULL, 5319, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16316, 1481, NULL, 5319, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16317, 6639, NULL, 5319, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16318, 6430, NULL, 5320, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16319, 1639, NULL, 5320, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16320, 8192, NULL, 5320, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16321, 6431, NULL, 5321, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16322, 2993, NULL, 5321, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16323, 2081, NULL, 5321, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16324, 6432, NULL, 5322, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16325, 8193, NULL, 5322, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16326, 7191, NULL, 5322, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16327, 8194, NULL, 5323, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16328, 1102, NULL, 5323, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16329, 8195, NULL, 5323, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16330, 8196, NULL, 5324, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16331, 8197, NULL, 5324, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28925, 413, NULL, 8971, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28926, 346, NULL, 8971, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28971, 171, NULL, 8989, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28972, 10248, NULL, 8989, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28973, 12272, NULL, 8989, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28974, 12273, NULL, 8989, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29005, 10931, NULL, 9001, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29006, 727, NULL, 9001, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29007, 2878, NULL, 9001, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29008, 2879, NULL, 9001, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29036, 2106, NULL, 9015, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29059, 9853, NULL, 9023, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29060, 7678, NULL, 9023, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29061, 699, NULL, 9023, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29062, 2597, NULL, 9023, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29063, 5390, NULL, 9023, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29064, 10346, NULL, 9023, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (29082, 12289, NULL, 9028, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5919, 1802, NULL, 1532, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5920, 1875, NULL, 1532, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5921, 5257, NULL, 1532, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5922, 923, NULL, 1538, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5923, 32, NULL, 1538, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5924, 116, NULL, 1538, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5925, 2877, NULL, 1538, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5926, 1257, NULL, 1541, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5927, 267, NULL, 1541, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5928, 1527, NULL, 1541, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5929, 239, NULL, 1541, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5930, 461, NULL, 1533, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5931, 1664, NULL, 1533, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5932, 2456, NULL, 1533, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5933, 5258, NULL, 1533, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5934, 448, NULL, 1537, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5935, 5259, NULL, 1537, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5936, 220, NULL, 1537, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5937, 1903, NULL, 1535, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5938, 200, NULL, 1535, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5939, 13, NULL, 3011, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5940, 182, NULL, 3012, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5941, 2455, NULL, 3012, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5942, 2063, NULL, 3013, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5943, 5143, NULL, 3013, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5944, 3779, NULL, 3014, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5945, 2492, NULL, 3014, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5946, 5035, NULL, 3015, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5947, 789, NULL, 3015, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5948, 758, NULL, 3016, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5949, 2413, NULL, 3016, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5950, 3876, NULL, 3016, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5951, 5260, NULL, 3017, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5952, 1455, NULL, 3017, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5953, 2908, NULL, 3017, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5954, 5261, NULL, 3018, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5955, 1858, NULL, 3018, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5956, 2180, NULL, 3018, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5957, 1732, NULL, 3019, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5958, 3912, NULL, 3019, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5959, 1148, NULL, 3019, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5960, 179, NULL, 3020, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5961, 2544, NULL, 3020, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5962, 920, NULL, 3020, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5963, 2218, NULL, 3020, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5964, 614, NULL, 3021, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5965, 5262, NULL, 3021, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5966, 5263, NULL, 3021, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5967, 1956, NULL, 3022, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5968, 5264, NULL, 3022, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5969, 551, NULL, 3023, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5970, 5265, NULL, 3023, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5971, 1222, NULL, 3023, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5972, 3643, NULL, 3024, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5973, 1624, NULL, 3024, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5974, 267, NULL, 3024, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5975, 239, NULL, 3024, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5976, 2886, NULL, 3025, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5977, 2827, NULL, 3025, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5978, 757, NULL, 3026, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5979, 2399, NULL, 3026, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5980, 4236, NULL, 3026, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5981, 1665, NULL, 3027, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5982, 2943, NULL, 3027, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5983, 652, NULL, 3027, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5990, 169, NULL, 1994, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5991, 2597, NULL, 1994, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5992, 2579, NULL, 1994, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5993, 2862, NULL, 1994, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5994, 628, NULL, 2000, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5995, 5266, NULL, 2000, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5996, 317, NULL, 2000, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5997, 5267, NULL, 2000, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5998, 932, NULL, 1996, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5999, 2692, NULL, 1996, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6000, 2031, NULL, 1996, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6004, 1341, NULL, 1995, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6005, 2119, NULL, 1995, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6006, 2473, NULL, 1995, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6007, 3125, NULL, 1995, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6008, 1209, NULL, 1999, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6009, 5268, NULL, 1999, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6010, 2725, NULL, 1999, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6011, 1111, NULL, 1997, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6012, 699, NULL, 1997, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6013, 2505, NULL, 1997, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6014, 2943, NULL, 1997, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6015, 548, NULL, 2002, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6016, 4026, NULL, 2002, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6017, 1126, NULL, 2002, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6018, 1445, NULL, 2002, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6022, 769, NULL, 2043, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6023, 2576, NULL, 2043, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6024, 4114, NULL, 2043, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6025, 216, NULL, 2050, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6026, 2728, NULL, 2050, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6027, 807, NULL, 2049, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6028, 3394, NULL, 2049, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6029, 2790, NULL, 2049, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6030, 155, NULL, 2049, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6031, 685, NULL, 2049, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6032, 1813, NULL, 2046, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6033, 99, NULL, 2046, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6034, 1449, NULL, 2046, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6035, 977, NULL, 2045, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6036, 242, NULL, 2045, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6037, 2730, NULL, 2045, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6038, 476, NULL, 2052, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6039, 2966, NULL, 2052, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6040, 403, NULL, 2052, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6041, 1311, NULL, 2052, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6042, 1624, NULL, 2052, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6043, 1672, NULL, 2047, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6044, 4112, NULL, 2047, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6045, 1447, NULL, 2047, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6046, 1781, NULL, 2044, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6047, 1006, NULL, 2044, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6048, 1787, NULL, 2044, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16332, 8198, NULL, 5324, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16333, 6434, NULL, 5325, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16334, 858, NULL, 5325, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16335, 5567, NULL, 5325, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16336, 283, NULL, 5326, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16337, 4663, NULL, 5326, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16338, 1656, NULL, 5326, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16339, 4198, NULL, 5327, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16340, 4387, NULL, 5327, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16341, 8199, NULL, 5327, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16342, 8200, NULL, 5327, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16343, 8201, NULL, 5328, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16344, 2212, NULL, 5328, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16345, 6061, NULL, 5328, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16346, 6435, NULL, 5329, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16347, 8202, NULL, 5329, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6049, 1361, NULL, 2315, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6050, 2152, NULL, 2315, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6051, 650, NULL, 2315, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6052, 1744, NULL, 2315, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6053, 186, NULL, 2314, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6054, 686, NULL, 2314, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6055, 122, NULL, 2314, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6056, 700, NULL, 2313, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6057, 2456, NULL, 2313, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6058, 652, NULL, 2313, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6059, 1781, NULL, 2313, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6060, 1814, NULL, 2318, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6061, 1431, NULL, 2318, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6062, 1979, NULL, 2318, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6063, 1527, NULL, 2318, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6064, 1448, NULL, 2316, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6065, 1857, NULL, 2316, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6066, 1485, NULL, 2316, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6067, 662, NULL, 2316, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6068, 1882, NULL, 2311, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6069, 778, NULL, 2311, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6070, 1789, NULL, 2311, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6071, 320, NULL, 2311, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6072, 1462, NULL, 2317, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6073, 2300, NULL, 2317, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6074, 1096, NULL, 2317, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6075, 1846, NULL, 2317, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6076, 552, NULL, 2312, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6077, 398, NULL, 2312, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6078, 3367, NULL, 2312, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6079, 374, NULL, 3040, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6080, 369, NULL, 3040, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6081, 297, NULL, 3040, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6082, 333, NULL, 3041, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6084, 1464, NULL, 3041, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6085, 382, NULL, 3042, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6086, 3390, NULL, 3042, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6087, 1386, NULL, 3042, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6088, 2129, NULL, 3043, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6089, 5269, NULL, 3043, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6090, 5270, NULL, 3044, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6091, 232, NULL, 3045, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6092, 2646, NULL, 3045, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6093, 1059, NULL, 3045, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6094, 5271, NULL, 3045, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6100, 425, NULL, 1762, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6101, 2410, NULL, 1762, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6102, 5272, NULL, 1762, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6099, 1450, NULL, 1762, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6103, 5273, NULL, 1769, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29076, 12522, NULL, 9027, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29078, 10864, NULL, 9027, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29077, 2952, NULL, 9027, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5988, 2144, NULL, 2003, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5989, 1099, NULL, 2003, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5987, 3590, NULL, 2003, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6020, 1979, NULL, 2051, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6021, 1707, NULL, 2051, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6019, 1753, NULL, 2051, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6001, 3312, NULL, 2001, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6002, 3876, NULL, 2001, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6129, 236, NULL, 3047, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6130, 1616, NULL, 3047, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6131, 664, NULL, 3047, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6132, 1659, NULL, 3048, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6133, 3568, NULL, 3048, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6134, 164, NULL, 3048, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6135, 415, NULL, 3049, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6136, 1514, NULL, 3050, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6137, 1406, NULL, 3050, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6138, 3912, NULL, 3050, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6139, 232, NULL, 3050, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6140, 1019, NULL, 3051, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6141, 968, NULL, 3051, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16348, 8203, NULL, 5329, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16349, 8204, NULL, 5329, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16350, 8205, NULL, 5330, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16351, 8206, NULL, 5330, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16352, 8207, NULL, 5330, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16353, 7562, NULL, 5330, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16354, 8208, NULL, 5330, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16355, 985, NULL, 5330, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16356, 8209, NULL, 5330, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16361, 1152, NULL, 5332, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16362, 8211, NULL, 5332, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16363, 3709, NULL, 5332, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16364, 8038, NULL, 5332, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16365, 1721, NULL, 5333, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16366, 570, NULL, 5333, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16367, 8212, NULL, 5333, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16368, 770, NULL, 5333, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16369, 382, NULL, 5334, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16370, 1457, NULL, 5334, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16371, 377, NULL, 5334, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16372, 220, NULL, 5303, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16373, 423, NULL, 5303, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16374, 8213, NULL, 5303, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16375, 8214, NULL, 5303, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16376, 1456, NULL, 5304, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16377, 5783, NULL, 5304, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16378, 8215, NULL, 5304, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16379, 433, NULL, 5305, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16380, 5173, NULL, 5305, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16381, 312, NULL, 5305, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16382, 2967, NULL, 5305, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16383, 371, NULL, 5306, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16384, 1769, NULL, 5306, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16385, 3405, NULL, 5307, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16386, 1099, NULL, 5307, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16387, 1024, NULL, 5307, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16388, 8216, NULL, 5307, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16389, 669, NULL, 5308, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6083, 5634, 284, 3041, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28927, 1672, NULL, 8972, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28928, 570, NULL, 8972, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28929, 789, NULL, 8972, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28930, 2903, NULL, 8972, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28975, 12274, NULL, 8990, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29009, 6820, NULL, 9002, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29037, 5346, NULL, 9016, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29083, 259, NULL, 9029, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29084, 6057, NULL, 9029, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29085, 5853, NULL, 9029, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29086, 12290, NULL, 9029, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29087, 11479, NULL, 9030, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29088, 12291, NULL, 9030, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29089, 2674, NULL, 9030, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29090, 857, NULL, 9030, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29091, 2259, NULL, 9030, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29092, 2903, NULL, 9030, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (29093, 19, NULL, 9030, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (6142, 1460, NULL, 3051, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6143, 864, NULL, 3052, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6144, 1158, NULL, 3052, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6145, 2492, NULL, 3052, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6146, 4165, NULL, 3052, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6147, 3321, NULL, 3053, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6148, 5275, NULL, 3053, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6149, 5276, NULL, 3053, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6150, 122, NULL, 3054, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6151, 1636, NULL, 3054, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6152, 497, NULL, 3054, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6153, 1005, NULL, 3055, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6154, 717, NULL, 3055, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6155, 1059, NULL, 3056, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6156, 1448, NULL, 3056, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6157, 5277, NULL, 3056, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6158, 648, NULL, 3056, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6159, 771, NULL, 3057, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6160, 1609, NULL, 3057, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6161, 1624, NULL, 3057, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6162, 1997, NULL, 3057, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6163, 4740, NULL, 3058, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6164, 624, NULL, 3058, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6165, 932, NULL, 3058, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6166, 1219, NULL, 3059, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6167, 256, NULL, 3059, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6168, 1700, NULL, 3059, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6169, 448, NULL, 3060, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6170, 312, NULL, 3060, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6171, 423, NULL, 3060, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6172, 955, NULL, 3060, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6173, 5278, NULL, 3061, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6174, 850, NULL, 3061, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6175, 1958, NULL, 3061, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6176, 183, NULL, 3062, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6177, 4323, NULL, 3062, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6178, 2816, NULL, 3062, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6179, 1095, NULL, 3063, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6180, 952, NULL, 3063, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6181, 1046, NULL, 3063, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6182, 1527, NULL, 3064, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6183, 267, NULL, 3064, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6184, 1041, NULL, 3065, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6185, 2706, NULL, 3065, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6186, 601, NULL, 3065, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6187, 374, NULL, 3066, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6188, 4983, NULL, 3066, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6189, 952, NULL, 3066, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6190, 13, NULL, 3066, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6191, 2532, NULL, 3066, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6192, 996, NULL, 3066, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (6193, 497, NULL, 3067, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6194, 2259, NULL, 3067, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6195, 857, NULL, 3067, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6196, 2821, NULL, 3067, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6197, 19, NULL, 3067, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (6198, 2903, NULL, 3067, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (6199, 3142, NULL, 3068, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6200, 2144, NULL, 3068, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6201, 1099, NULL, 3068, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6202, 2303, NULL, 3068, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6203, 770, NULL, 3068, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6204, 1257, NULL, 3069, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6205, 2414, NULL, 3069, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6206, 3550, NULL, 3069, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6207, 773, NULL, 3069, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6208, 2489, NULL, 3069, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6209, 68, NULL, 3069, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (6210, 1026, NULL, 3069, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (6211, 1059, NULL, 3070, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6212, 1915, NULL, 3070, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6213, 2704, NULL, 3070, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6214, 709, NULL, 3070, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6215, 771, NULL, 3070, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6216, 186, NULL, 3070, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (6217, 1756, NULL, 3070, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (6218, 430, NULL, 3071, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6219, 119, NULL, 3071, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6220, 2804, NULL, 3071, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6221, 3013, NULL, 3071, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6222, 405, NULL, 3071, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6223, 2240, NULL, 3071, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (6224, 122, NULL, 3071, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (6225, 448, NULL, 3072, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6110, 3914, NULL, 1767, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6107, 904, NULL, 1767, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6108, 1116, NULL, 1767, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6114, 405, NULL, 1765, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6113, 2145, NULL, 1765, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6111, 1448, NULL, 1765, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6117, 1853, NULL, 1763, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6118, 417, NULL, 1763, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6115, 761, NULL, 1763, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6116, 1590, NULL, 1763, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6122, 3438, NULL, 1768, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6119, 432, NULL, 1768, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6120, 1166, NULL, 1768, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6121, 1430, NULL, 1768, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6124, 66, NULL, 1764, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6126, 2792, NULL, 1764, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6125, 2396, NULL, 1764, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6226, 914, NULL, 3072, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6227, 2361, NULL, 3072, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6228, 312, NULL, 3072, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6229, 1374, NULL, 3072, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6230, 1179, NULL, 3072, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (6231, 1896, NULL, 3072, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (6232, 958, NULL, 3073, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6233, 5279, NULL, 3073, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16390, 1485, NULL, 5308, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16391, 8217, NULL, 5308, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29065, 12198, NULL, 9024, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29067, 12284, NULL, 9024, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16359, 8210, NULL, 5331, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16357, 3433, NULL, 5331, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16360, 1462, NULL, 5331, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16392, 1585, NULL, 5309, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16393, 1133, NULL, 5309, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16394, 4255, NULL, 5309, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16395, 90, NULL, 5310, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16396, 6806, NULL, 5310, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16397, 4405, NULL, 5310, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16398, 431, NULL, 5311, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16399, 861, NULL, 5311, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16400, 267, NULL, 5311, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16401, 599, NULL, 5311, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16402, 975, NULL, 5311, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16403, 4912, NULL, 5311, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16404, 854, NULL, 5311, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16405, 713, NULL, 5313, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16406, 2135, NULL, 5313, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16407, 189, NULL, 5313, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16408, 3066, NULL, 5313, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16409, 977, NULL, 5313, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16410, 3469, NULL, 5314, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16411, 1017, NULL, 5314, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16412, 1846, NULL, 5314, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16413, 372, NULL, 5315, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16414, 2738, NULL, 5315, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16415, 6014, NULL, 5315, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16416, 5304, NULL, 5315, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16417, 6013, NULL, 5315, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16418, 6012, NULL, 5315, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16419, 1687, NULL, 5316, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16420, 8218, NULL, 5316, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16421, 1875, NULL, 5316, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16422, 3631, NULL, 5316, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16423, 3749, NULL, 5317, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16424, 6626, NULL, 5317, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16425, 8219, NULL, 5317, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16426, 8220, NULL, 5317, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16427, 8221, NULL, 5317, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16428, 5330, NULL, 2034, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16429, 2555, NULL, 5335, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16430, 2300, NULL, 5335, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16431, 858, NULL, 5335, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28931, 2645, NULL, 8973, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28932, 4134, NULL, 8973, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28933, 1622, NULL, 8973, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28976, 5739, NULL, 8991, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28977, 5142, NULL, 8991, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29038, 5346, NULL, 9017, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29068, 9050, NULL, 9025, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29069, 5666, NULL, 9025, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29070, 2853, NULL, 9025, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29071, 12285, NULL, 9025, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29094, 2821, NULL, 9030, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (29095, 2772, NULL, 9030, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (6234, 5280, NULL, 3074, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6235, 441, NULL, 3075, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6236, 146, NULL, 3075, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6237, 1225, NULL, 3075, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6238, 150, NULL, 3075, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6239, 4663, NULL, 3075, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (6240, 682, NULL, 3075, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (6246, 4567, NULL, 3077, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6247, 232, NULL, 3077, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6248, 2910, NULL, 3077, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6249, 1956, NULL, 3077, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6250, 2999, NULL, 3077, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6251, 5281, NULL, 3077, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (6252, 5282, NULL, 3077, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (6253, 5283, NULL, 2652, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6254, 1922, NULL, 2652, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6255, 3508, NULL, 2652, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6256, 71, NULL, 2653, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6257, 476, NULL, 2653, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6258, 5151, NULL, 2653, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6259, 5284, NULL, 2654, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6260, 5077, NULL, 2655, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6261, 1979, NULL, 2656, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6262, 5018, NULL, 2656, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6263, 5286, NULL, 2656, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6264, 5076, NULL, 2657, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6265, 206, NULL, 2657, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6266, 5288, NULL, 2658, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6267, 5289, NULL, 2658, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6268, 2162, NULL, 2658, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32867, 5154, NULL, 10177, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32868, 968, NULL, 10177, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6271, 5290, NULL, 2660, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6272, 5078, NULL, 2661, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6273, 5291, NULL, 2661, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6274, 503, NULL, 2661, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6275, 2397, NULL, 2662, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6276, 453, NULL, 2662, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6277, 4702, NULL, 2662, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6278, 5292, NULL, 2662, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6279, 5293, NULL, 2663, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6280, 5294, NULL, 2663, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6281, 411, NULL, 2326, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6282, 1748, NULL, 2326, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6283, 3390, NULL, 2326, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6284, 1386, NULL, 2326, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6285, 239, NULL, 2329, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6286, 2017, NULL, 2329, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6287, 730, NULL, 2320, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6288, 1875, NULL, 2320, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6289, 62, NULL, 2320, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6290, 1853, NULL, 2320, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6291, 790, NULL, 2330, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6292, 5115, NULL, 2330, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6293, 4034, NULL, 2330, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6294, 5295, NULL, 2330, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6295, 2874, NULL, 2330, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6296, 5296, NULL, 2322, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6297, 2458, NULL, 2322, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6298, 81, NULL, 2323, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6299, 220, NULL, 2323, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6300, 3853, NULL, 2319, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6303, 3492, NULL, 2324, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6304, 2037, NULL, 2324, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6305, 332, NULL, 2324, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6306, 5298, NULL, 2328, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6307, 141, NULL, 2328, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6308, 5299, NULL, 2328, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6309, 3559, NULL, 2328, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6310, 3364, NULL, 2325, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6311, 389, NULL, 2325, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6312, 996, NULL, 2325, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6313, 2860, NULL, 2325, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6314, 753, NULL, 2321, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6315, 78, NULL, 2321, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6316, 2730, NULL, 2321, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6317, 5300, NULL, 2572, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6318, 3589, NULL, 2572, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6319, 5301, NULL, 2572, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6320, 86, NULL, 2572, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6321, 128, NULL, 2574, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6322, 1057, NULL, 2574, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6323, 5302, NULL, 2585, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6324, 5303, NULL, 2585, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6325, 2465, NULL, 2585, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6326, 1101, NULL, 2581, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16432, 5567, NULL, 5335, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16433, 1102, NULL, 5335, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16434, 7548, NULL, 5336, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16435, 5064, NULL, 5336, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16436, 1984, NULL, 5336, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16437, 8225, NULL, 5336, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16438, 20, NULL, 5337, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16439, 437, NULL, 5337, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16440, 8226, NULL, 5337, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16441, 2424, NULL, 5337, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16442, 1138, NULL, 5338, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16443, 8227, NULL, 5338, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16444, 8228, NULL, 5338, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16445, 6876, NULL, 5338, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16446, 8229, NULL, 5339, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16447, 8230, NULL, 5339, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16448, 8231, NULL, 5339, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16449, 8232, NULL, 5339, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16450, 694, NULL, 5340, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16451, 4213, NULL, 5340, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16452, 389, NULL, 5340, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29151, 12319, NULL, 9067, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16454, 2181, NULL, 5341, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16455, 8233, NULL, 5341, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16456, 2442, NULL, 5341, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29011, 10900, NULL, 9003, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29010, 12279, NULL, 9003, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16457, 1448, NULL, 5342, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16458, 171, NULL, 5342, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16459, 482, NULL, 5342, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16460, 963, NULL, 5343, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16461, 8234, NULL, 5343, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16462, 3136, NULL, 5343, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16463, 419, NULL, 5344, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16464, 8235, NULL, 5344, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16465, 1683, NULL, 5344, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16466, 7213, NULL, 4566, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16468, 430, NULL, 5345, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16469, 200, NULL, 5345, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16470, 2855, NULL, 5345, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16471, 1232, NULL, 5346, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16472, 8236, NULL, 5346, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16473, 1601, NULL, 5346, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16453, 5634, 284, 5341, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28978, 958, NULL, 8992, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28979, 4331, NULL, 8992, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16467, 7566, NULL, 4571, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (28980, 162, NULL, 8992, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29012, 186, NULL, 9004, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29013, 6091, NULL, 9004, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29014, 1485, NULL, 9004, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29015, 1059, NULL, 9004, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29039, 5346, NULL, 9018, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29096, 5346, NULL, 9031, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29100, 5126, NULL, 9035, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29105, 1154, NULL, 9055, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29106, 12292, NULL, 9055, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29107, 12293, NULL, 9055, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29108, 11074, NULL, 9055, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29128, 753, NULL, 9061, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29129, 12308, NULL, 9061, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29130, 12309, NULL, 9061, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29152, 12320, NULL, 9067, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6327, 5304, NULL, 2581, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6328, 2738, NULL, 2581, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6329, 5305, NULL, 2581, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6330, 355, NULL, 2584, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6331, 2646, NULL, 2584, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6332, 757, NULL, 2579, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6333, 2332, NULL, 2579, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6334, 1778, NULL, 2579, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6339, 4913, NULL, 2582, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6340, 3025, NULL, 2582, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6341, 2118, NULL, 2582, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6342, 1331, NULL, 2580, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6343, 2203, NULL, 2580, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6344, 1447, NULL, 2580, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6345, 5308, NULL, 2580, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6346, 958, NULL, 2571, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6347, 161, NULL, 2571, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6348, 1585, NULL, 2583, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6349, 812, NULL, 2583, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6350, 4237, NULL, 2583, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6351, 3679, NULL, 2583, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6352, 1158, NULL, 2577, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6353, 1219, NULL, 2577, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6354, 5309, NULL, 2577, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6355, 1457, NULL, 2573, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6356, 1880, NULL, 2573, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6357, 1958, NULL, 2573, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6358, 534, NULL, 2578, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6359, 2774, NULL, 2578, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6360, 378, NULL, 2578, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6361, 5310, NULL, 2578, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6362, 1707, NULL, 3078, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6363, 1205, NULL, 3078, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6364, 2559, NULL, 3078, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6365, 2489, NULL, 3078, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6366, 2973, NULL, 2467, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6367, 4397, NULL, 2467, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6368, 1319, NULL, 2473, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6369, 1226, NULL, 2473, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6370, 5311, NULL, 2473, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6371, 2808, NULL, 2473, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6372, 431, NULL, 2475, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6373, 1613, NULL, 2475, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6374, 430, NULL, 2664, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6375, 5312, NULL, 2664, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6376, 1777, NULL, 2664, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6377, 5313, NULL, 2665, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6380, 408, NULL, 2466, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6381, 1148, NULL, 2469, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6382, 5315, NULL, 2469, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6383, 5316, NULL, 2469, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6384, 4611, NULL, 2469, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6391, 241, NULL, 2464, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6392, 2456, NULL, 2464, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6393, 3859, NULL, 2464, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6394, 377, NULL, 2470, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6395, 5317, NULL, 2470, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6396, 5318, NULL, 2470, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6397, 2457, NULL, 2470, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6398, 202, NULL, 2468, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6399, 226, NULL, 2468, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6400, 648, NULL, 2468, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6401, 1219, NULL, 2331, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6402, 4384, NULL, 2331, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6403, 534, NULL, 2333, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6404, 2762, NULL, 2333, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6405, 4404, NULL, 2333, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6406, 5323, NULL, 2334, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6407, 2703, NULL, 2334, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6408, 4727, NULL, 2334, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6409, 872, NULL, 2335, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6410, 2430, NULL, 2335, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6411, 2163, NULL, 2335, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6412, 398, NULL, 2336, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6413, 1687, NULL, 2336, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6414, 2995, NULL, 2336, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6418, 5327, NULL, 1166, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16474, 7213, NULL, 4449, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16475, 6639, NULL, 5347, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16476, 3026, NULL, 5347, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16477, 2864, NULL, 5347, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16478, 3225, NULL, 5347, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16479, 480, NULL, 5348, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16480, 1027, NULL, 5348, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16481, 8250, NULL, 5348, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16482, 6409, NULL, 5348, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32869, 13865, NULL, 10178, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16484, 1855, NULL, 5349, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16485, 1294, NULL, 5349, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16486, 834, NULL, 5349, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16487, 2531, NULL, 5349, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16488, 951, NULL, 5349, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16489, 1291, NULL, 5349, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16490, 2226, NULL, 784, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16491, 8265, NULL, 784, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16492, 1857, NULL, 784, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16493, 1334, NULL, 784, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16498, 8257, NULL, 4612, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16499, 861, NULL, 4612, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16500, 809, NULL, 4612, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16501, 8267, NULL, 5350, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16502, 8268, NULL, 5350, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16503, 3018, NULL, 5350, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16504, 8269, NULL, 5350, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16505, 534, NULL, 5350, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16506, 5312, NULL, 5350, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16507, 2988, NULL, 5350, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16508, 122, NULL, 5350, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (16509, 8258, NULL, 5351, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16510, 8259, NULL, 5352, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16511, 1588, NULL, 5352, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16512, 5249, NULL, 5352, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16513, 5250, NULL, 5352, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16514, 8270, NULL, 5352, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16515, 5215, NULL, 5352, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16516, 1294, NULL, 5352, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16517, 833, NULL, 5352, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (16518, 8260, NULL, 5353, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16519, 1896, NULL, 5353, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16520, 2577, NULL, 5353, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16521, 1146, NULL, 5353, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6419, 912, NULL, 2341, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6420, 2565, NULL, 2341, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6421, 1311, NULL, 2341, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16497, 8266, NULL, 4605, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6428, 981, NULL, 2494, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6427, 1778, NULL, 2494, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6430, 305, NULL, 2499, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6432, 2413, NULL, 2499, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6337, 727, NULL, 2576, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6338, 5307, NULL, 2576, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6389, 2576, NULL, 2465, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6390, 1112, NULL, 2465, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6387, 5786, NULL, 2465, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29134, 5026, NULL, 9062, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29132, 12311, NULL, 9062, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29131, 12310, NULL, 9062, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29133, 5071, NULL, 9062, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16524, 2063, NULL, 5354, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16522, 3894, NULL, 5354, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16525, 5246, NULL, 5354, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16527, 1971, NULL, 5354, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (6431, 2443, NULL, 2499, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6436, 601, NULL, 2492, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6437, 2266, NULL, 2493, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6439, 676, NULL, 2493, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6438, 5330, NULL, 2493, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16483, 9714, 479, 5349, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6379, 372, NULL, 2666, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6378, 5314, NULL, 2666, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32870, 6267, NULL, 10179, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32871, 13866, NULL, 10179, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32872, 8855, NULL, 10180, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32873, 13867, NULL, 10180, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6457, 5338, NULL, 2599, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6458, 1042, NULL, 2599, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6459, 652, NULL, 2599, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6460, 497, NULL, 2599, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6461, 156, NULL, 2605, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6462, 2822, NULL, 2605, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6463, 186, NULL, 2603, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6464, 1655, NULL, 2603, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6465, 122, NULL, 2603, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6466, 413, NULL, 2604, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6467, 1197, NULL, 2604, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6468, 5340, NULL, 2607, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6469, 5066, NULL, 2607, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6470, 2264, NULL, 2607, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6471, 5341, NULL, 2598, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6472, 3149, NULL, 2598, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6473, 1942, NULL, 2598, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6474, 5342, NULL, 2602, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6475, 5343, NULL, 2602, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6476, 5344, NULL, 2606, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6477, 1067, NULL, 2606, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6478, 915, NULL, 2606, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6479, 1482, NULL, 2601, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6480, 955, NULL, 2601, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6481, 1329, NULL, 2601, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6482, 171, NULL, 2601, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6483, 5346, NULL, 2600, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6484, 289, NULL, 2600, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6485, 3614, NULL, 2600, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6486, 5199, NULL, 3079, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6487, 3862, NULL, 3079, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6488, 483, NULL, 3079, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6489, 5347, NULL, 3079, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6490, 669, NULL, 3080, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6491, 3716, NULL, 3080, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6492, 1371, NULL, 3081, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6493, 533, NULL, 3081, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6494, 5006, NULL, 3081, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6495, 5348, NULL, 3081, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6496, 4249, NULL, 3081, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6497, 1620, NULL, 524, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6498, 1870, NULL, 525, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6499, 5349, NULL, 525, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6500, 5350, NULL, 526, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6501, 5351, NULL, 526, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6502, 84, NULL, 527, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6503, 1943, NULL, 527, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6504, 1814, NULL, 527, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6505, 1662, NULL, 528, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6506, 5352, NULL, 528, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6507, 2757, NULL, 528, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6512, 313, NULL, 531, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6513, 4740, NULL, 531, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6514, 5118, NULL, 531, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6515, 1373, NULL, 531, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6516, 152, NULL, 3082, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6517, 1112, NULL, 3082, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6518, 3600, NULL, 3083, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6519, 3850, NULL, 3083, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6520, 2205, NULL, 3083, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6521, 5355, NULL, 3085, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6522, 955, NULL, 3085, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6523, 2626, NULL, 3085, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6524, 923, NULL, 3086, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6525, 1503, NULL, 3086, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6526, 685, NULL, 3086, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6527, 1043, NULL, 3088, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6528, 920, NULL, 3088, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6529, 2559, NULL, 3088, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6530, 1042, NULL, 3088, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6531, 534, NULL, 3089, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6532, 1956, NULL, 3089, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6533, 1406, NULL, 3089, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6534, 1091, NULL, 3090, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6535, 1655, NULL, 3090, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6536, 188, NULL, 3090, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6537, 1351, NULL, 3091, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6538, 664, NULL, 3091, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6539, 1296, NULL, 3091, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6540, 5356, NULL, 3092, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6541, 234, NULL, 3092, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6542, 1400, NULL, 3092, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6543, 773, NULL, 3092, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6544, 1770, NULL, 3093, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6545, 457, NULL, 3093, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6546, 1046, NULL, 3093, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6547, 3979, NULL, 3094, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6548, 5357, NULL, 3094, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16533, 8261, NULL, 5356, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16534, 2659, NULL, 5356, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16535, 3215, NULL, 5356, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16536, 1867, NULL, 5356, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16537, 8271, NULL, 5357, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16538, 2294, NULL, 5357, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16539, 7942, NULL, 5357, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16540, 8272, NULL, 5357, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16541, 674, NULL, 5357, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16542, 8273, NULL, 5357, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16543, 5247, NULL, 5357, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (6549, 5358, NULL, 3094, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6550, 665, NULL, 3095, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6551, 5359, NULL, 3095, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6552, 5360, NULL, 3095, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6553, 171, NULL, 3096, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6554, 835, NULL, 3096, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6555, 3779, NULL, 3096, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6556, 613, NULL, 3096, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6557, 55, NULL, 3097, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6558, 512, NULL, 3097, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6559, 1112, NULL, 3097, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6562, 5362, NULL, 3099, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6563, 1435, NULL, 3099, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6564, 1401, NULL, 3100, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6565, 2774, NULL, 3100, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6566, 3013, NULL, 3100, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6570, 1000, NULL, 2383, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6571, 867, NULL, 2383, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6572, 1979, NULL, 2383, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6573, 388, NULL, 2376, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6574, 5364, NULL, 2376, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6575, 790, NULL, 2384, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6576, 5365, NULL, 2384, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6577, 5366, NULL, 2384, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6578, 5295, NULL, 2384, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6579, 601, NULL, 2378, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6580, 41, NULL, 2381, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6581, 4316, NULL, 2381, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6582, 1830, NULL, 2377, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6583, 3320, NULL, 2377, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6584, 4543, NULL, 2377, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6585, 364, NULL, 2382, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6586, 305, NULL, 2382, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6587, 1140, NULL, 2382, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6588, 1659, NULL, 2382, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6589, 382, NULL, 2380, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6590, 4085, NULL, 2380, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6591, 2536, NULL, 2380, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6592, 5367, NULL, 2375, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6593, 90, NULL, 2375, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6594, 429, NULL, 2375, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6595, 661, NULL, 1603, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6596, 4183, NULL, 1603, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6597, 5368, NULL, 1603, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6598, 872, NULL, 2373, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6599, 76, NULL, 2373, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6600, 4360, NULL, 2373, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6601, 432, NULL, 2374, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6602, 1943, NULL, 2374, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6603, 5369, NULL, 2374, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6604, 1659, NULL, 2374, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6605, 1389, NULL, 2369, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6606, 219, NULL, 2369, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6607, 1415, NULL, 2369, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6440, 5331, NULL, 2493, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6442, 5332, NULL, 2495, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6447, 267, NULL, 2498, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6446, 1431, NULL, 2498, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6450, 5335, NULL, 2491, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6449, 5334, NULL, 2491, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6448, 3838, NULL, 2491, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6452, 829, NULL, 2496, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6451, 923, NULL, 2496, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6454, 971, NULL, 2496, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6453, 1503, NULL, 2496, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6456, 5337, NULL, 2500, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16529, 1861, NULL, 5354, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (16528, 3574, NULL, 5354, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (6434, 652, NULL, 2489, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6433, 3305, NULL, 2489, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6455, 5336, NULL, 2500, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6567, 3381, NULL, 2379, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6568, 4444, NULL, 2379, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6569, 1647, NULL, 2379, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6561, 767, NULL, 3098, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6560, 1013, NULL, 3098, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6608, 3719, NULL, 2369, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6609, 1512, NULL, 2370, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6610, 106, NULL, 2370, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6611, 3347, NULL, 2370, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6612, 1437, NULL, 2370, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6613, 226, NULL, 2372, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6614, 119, NULL, 2372, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6615, 648, NULL, 2372, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6616, 3713, NULL, 2367, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6617, 1006, NULL, 2367, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6618, 2945, NULL, 2367, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6619, 962, NULL, 2368, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6620, 2309, NULL, 2368, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6621, 1241, NULL, 2368, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6622, 5370, NULL, 2368, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6623, 374, NULL, 2371, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6624, 405, NULL, 2371, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6625, 1541, NULL, 2371, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6626, 2365, NULL, 2366, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6627, 78, NULL, 2366, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6628, 179, NULL, 2474, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6629, 68, NULL, 2474, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6630, 1402, NULL, 2474, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6631, 2349, NULL, 2474, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6632, 152, NULL, 3029, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6633, 5371, NULL, 3029, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6634, 4656, NULL, 3029, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6635, 5115, NULL, 3029, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6636, 5361, NULL, 3030, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6637, 5372, NULL, 3030, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6638, 5373, NULL, 3030, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6639, 1491, NULL, 3031, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6640, 651, NULL, 3031, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6641, 709, NULL, 3031, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16544, 4363, NULL, 5357, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (16545, 1372, NULL, 5358, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16546, 98, NULL, 5358, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16547, 1705, NULL, 5358, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16548, 1948, NULL, 5358, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16549, 1046, NULL, 5358, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16550, 1693, NULL, 5358, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16551, 1514, NULL, 5358, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16552, 3433, NULL, 5358, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (16553, 8262, NULL, 5359, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16554, 2029, NULL, 5359, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16555, 1855, NULL, 5359, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16556, 602, NULL, 5359, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16557, 806, NULL, 5359, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16558, 109, NULL, 5359, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16559, 1117, NULL, 5359, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16560, 2442, NULL, 5359, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (16561, 8264, NULL, 5360, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16562, 2576, NULL, 5360, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16563, 1112, NULL, 5360, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16564, 4114, NULL, 5360, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16565, 32, NULL, 5361, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16566, 1821, NULL, 5361, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16567, 8274, NULL, 5361, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16568, 1929, NULL, 5361, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16569, 8263, NULL, 5362, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16570, 8275, NULL, 5362, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16571, 8276, NULL, 5362, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16572, 8277, NULL, 5362, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16573, 8245, NULL, 5364, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16574, 188, NULL, 2116, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16575, 2650, NULL, 5371, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16576, 1660, NULL, 5371, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16577, 2364, NULL, 5371, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16578, 8278, NULL, 5372, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16579, 8279, NULL, 5372, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16580, 8280, NULL, 5372, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16581, 8281, NULL, 5372, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16582, 8282, NULL, 5373, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16583, 8169, NULL, 5373, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16584, 8283, NULL, 5373, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16585, 8284, NULL, 5373, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28981, 6827, NULL, 8993, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28982, 7089, NULL, 8993, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28983, 12275, NULL, 8993, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28984, 5501, NULL, 8993, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29016, 11284, NULL, 9005, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29017, 5148, NULL, 9005, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29018, 987, NULL, 9005, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29019, 4987, NULL, 9005, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29040, 5346, NULL, 9019, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29097, 5346, NULL, 9032, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29101, 5126, NULL, 9036, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29135, 91, NULL, 9063, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29136, 1100, NULL, 9063, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29137, 12312, NULL, 9063, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29153, 12321, NULL, 9067, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6642, 982, NULL, 3034, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6643, 5160, NULL, 3034, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6644, 630, NULL, 3034, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6645, 5374, NULL, 3034, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6646, 1729, NULL, 3035, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6647, 1728, NULL, 3035, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6648, 1300, NULL, 3037, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6649, 5375, NULL, 3037, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6650, 5376, NULL, 3037, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6651, 1431, NULL, 3038, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6652, 833, NULL, 3038, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6653, 1026, NULL, 3038, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6654, 5377, NULL, 3038, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6655, 1805, NULL, 3038, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32874, 13868, NULL, 10180, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32875, 13869, NULL, 10180, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32876, 13870, NULL, 10180, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6659, 1540, NULL, 3101, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6660, 3149, NULL, 3101, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6661, 1942, NULL, 3101, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6662, 1528, NULL, 3101, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6663, 419, NULL, 3102, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6664, 596, NULL, 3102, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6665, 5378, NULL, 3103, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6666, 512, NULL, 3104, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6667, 5379, NULL, 3104, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6668, 4514, NULL, 3104, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6669, 5380, NULL, 3104, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6670, 1535, NULL, 3106, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6671, 1970, NULL, 3106, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6672, 5381, NULL, 3106, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6673, 5382, NULL, 3106, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6674, 156, NULL, 3107, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6675, 5186, NULL, 3108, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6676, 4607, NULL, 3108, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6677, 5383, NULL, 3108, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6678, 1021, NULL, 1602, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6679, 773, NULL, 1602, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6680, 2442, NULL, 1602, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6681, 1042, NULL, 1602, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6682, 520, NULL, 1595, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6683, 209, NULL, 1595, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6684, 1590, NULL, 1595, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6685, 1006, NULL, 1595, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6686, 876, NULL, 1600, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6687, 1226, NULL, 1600, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6688, 441, NULL, 1599, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6689, 396, NULL, 1601, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6690, 692, NULL, 1601, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6691, 1979, NULL, 1601, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6692, 964, NULL, 1596, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6693, 299, NULL, 1596, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6694, 1628, NULL, 1596, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6695, 1809, NULL, 1598, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6696, 378, NULL, 1598, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6697, 312, NULL, 1598, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6698, 1732, NULL, 1594, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6699, 3381, NULL, 1594, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6700, 1158, NULL, 1594, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6705, 5384, NULL, 3110, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6706, 5385, NULL, 3110, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6707, 5386, NULL, 3111, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6708, 5375, NULL, 3111, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6709, 5376, NULL, 3111, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6710, 3744, NULL, 3114, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6711, 306, NULL, 3116, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6712, 5387, NULL, 3117, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6713, 2396, NULL, 3118, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6714, 724, NULL, 3118, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6715, 4085, NULL, 3119, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6716, 1091, NULL, 3119, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6717, 5174, NULL, 3121, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6718, 219, NULL, 3122, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6719, 106, NULL, 3122, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6720, 2922, NULL, 3123, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6721, 2961, NULL, 3123, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6722, 4312, NULL, 3124, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6723, 2151, NULL, 3124, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6724, 4972, NULL, 3125, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6725, 4670, NULL, 3125, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6726, 1957, NULL, 3126, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6727, 2336, NULL, 3126, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6702, 1919, NULL, 3109, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6703, 2188, NULL, 3109, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6731, 63, NULL, 3128, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6732, 209, NULL, 3128, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6733, 1628, NULL, 3128, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16586, 8285, NULL, 5374, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16587, 8286, NULL, 5374, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16588, 8287, NULL, 5374, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16589, 7620, NULL, 5375, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16590, 7621, NULL, 5375, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16591, 7622, NULL, 5375, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16592, 7623, NULL, 5375, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16597, 8288, NULL, 5377, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16598, 8289, NULL, 5377, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16599, 8290, NULL, 5377, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16600, 8291, NULL, 5377, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16601, 8292, NULL, 5377, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16602, 8293, NULL, 5378, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16603, 8294, NULL, 5378, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16604, 7500, NULL, 5378, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16609, 8298, NULL, 5380, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16610, 8299, NULL, 5380, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16611, 8300, NULL, 5380, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16612, 6652, NULL, 5380, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16613, 8301, NULL, 5381, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16614, 2531, NULL, 5381, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16615, 8302, NULL, 5381, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16616, 8303, NULL, 5381, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16617, 8304, NULL, 5382, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16618, 8305, NULL, 5382, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16619, 8306, NULL, 5382, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16620, 8307, NULL, 5382, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16621, 1781, NULL, 5383, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16622, 1965, NULL, 5383, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16623, 7654, NULL, 5383, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16624, 398, NULL, 5383, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16625, 8308, NULL, 5384, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16626, 2637, NULL, 5384, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16627, 1392, NULL, 5384, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29020, 1527, NULL, 9006, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29021, 4277, NULL, 9006, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29022, 1588, NULL, 9006, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29098, 5346, NULL, 9033, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29102, 5126, NULL, 9037, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29113, 444, NULL, 9057, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29114, 12298, NULL, 9057, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29115, 1187, NULL, 9057, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29138, 2829, NULL, 9064, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29139, 12313, NULL, 9064, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29140, 12314, NULL, 9064, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29141, 12315, NULL, 9064, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29154, 1497, NULL, 9068, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29155, 9552, NULL, 9068, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29156, 12322, NULL, 9068, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29157, 12323, NULL, 9068, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29164, 12327, NULL, 9071, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29165, 12328, NULL, 9071, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29177, 12337, NULL, 9076, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29178, 12338, NULL, 9077, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29179, 12339, NULL, 9077, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29180, 12340, NULL, 9077, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29181, 1374, NULL, 9078, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6734, 586, NULL, 3128, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6735, 588, NULL, 3129, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6736, 915, NULL, 3129, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6737, 806, NULL, 3129, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6738, 2442, NULL, 3129, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6739, 430, NULL, 3130, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6740, 119, NULL, 3130, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6741, 1263, NULL, 3130, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6742, 1238, NULL, 3131, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6743, 2737, NULL, 3131, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6747, 4578, NULL, 3014, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6748, 4578, NULL, 224, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6749, 4578, NULL, 2837, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6751, 692, NULL, 3133, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6752, 382, NULL, 3133, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6753, 1513, NULL, 3133, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6754, 790, NULL, 3134, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6755, 1373, NULL, 3134, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6756, 152, NULL, 3134, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6757, 382, NULL, 3135, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6758, 1655, NULL, 3135, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6759, 1638, NULL, 3135, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6760, 1834, NULL, 3135, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6761, 1329, NULL, 3135, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6762, 1106, NULL, 2397, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6763, 3488, NULL, 2397, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6764, 5389, NULL, 2397, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6765, 192, NULL, 2402, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6766, 540, NULL, 2402, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6767, 1310, NULL, 2402, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6772, 1613, NULL, 2403, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6773, 2774, NULL, 2403, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6774, 3765, NULL, 2403, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6775, 2634, NULL, 2399, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6776, 2175, NULL, 2399, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6777, 5390, NULL, 2399, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6778, 5390, NULL, 661, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6779, 5390, NULL, 1356, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6780, 1003, NULL, 2396, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6781, 502, NULL, 2396, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6782, 1827, NULL, 2396, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6783, 3498, NULL, 2398, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6784, 5391, NULL, 2398, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6785, 1222, NULL, 2398, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6786, 1193, NULL, 2404, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6787, 5392, NULL, 2404, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6788, 5393, NULL, 2404, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6789, 109, NULL, 2404, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6790, 76, NULL, 2401, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6791, 2165, NULL, 2401, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6792, 5394, NULL, 2401, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6793, 5395, NULL, 2401, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32877, 10778, NULL, 10181, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32878, 555, NULL, 10182, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32879, 13871, NULL, 10182, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6797, 1481, NULL, 3144, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6798, 5397, NULL, 3144, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6799, 5398, NULL, 3144, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6800, 71, NULL, 3145, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6801, 5399, NULL, 3145, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6802, 68, NULL, 3145, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6803, 458, NULL, 3146, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6804, 317, NULL, 3146, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6805, 3199, NULL, 3146, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6812, 1459, NULL, 3149, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6813, 5401, NULL, 3149, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6814, 1271, NULL, 3150, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6815, 1503, NULL, 3150, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6816, 807, NULL, 3150, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6817, 1475, NULL, 3151, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6818, 287, NULL, 3151, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6819, 2731, NULL, 2533, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6820, 1904, NULL, 2533, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6821, 2733, NULL, 2533, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6822, 2118, NULL, 2539, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6823, 3017, NULL, 2539, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6824, 1609, NULL, 2542, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6825, 1585, NULL, 2542, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6826, 2095, NULL, 2542, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16628, 8309, NULL, 5384, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16632, 8311, NULL, 5386, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16633, 8312, NULL, 5387, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16634, 8313, NULL, 5387, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16635, 8314, NULL, 5387, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16636, 8315, NULL, 5387, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16637, 8316, NULL, 5001, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16638, 1065, NULL, 5388, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16639, 1965, NULL, 5388, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16640, 2524, NULL, 5388, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16641, 6483, NULL, 5388, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16642, 324, NULL, 5389, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16643, 555, NULL, 5389, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16644, 8317, NULL, 5389, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16645, 2240, NULL, 5389, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16646, 2571, NULL, 5389, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16647, 2773, NULL, 5389, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16648, 812, NULL, 5389, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16649, 996, NULL, 5389, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (16650, 309, NULL, 5390, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16651, 649, NULL, 5390, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16652, 1875, NULL, 5390, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6809, 476, NULL, 3148, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6810, 1024, NULL, 3148, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6811, 1042, NULL, 3148, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16593, 4030, NULL, 5376, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16594, 5869, NULL, 5376, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16596, 5870, NULL, 5376, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16595, 2136, NULL, 5376, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16653, 1528, NULL, 5390, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16654, 1008, NULL, 5391, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16655, 1743, NULL, 5391, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16656, 5018, NULL, 5391, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6769, 3067, NULL, 2400, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6768, 1485, NULL, 2400, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6771, 2945, NULL, 2400, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6750, 4578, NULL, 724, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16657, 7509, NULL, 5391, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16658, 2544, NULL, 5391, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6807, 649, NULL, 3147, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6745, 2399, NULL, 3132, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6806, 2614, NULL, 3147, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6808, 5400, NULL, 3147, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16659, 2543, NULL, 5391, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16660, 2151, NULL, 5391, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16661, 1515, NULL, 5392, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16662, 5774, NULL, 5392, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16663, 2165, NULL, 5392, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16664, 1531, NULL, 5392, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16665, 1368, NULL, 5393, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16666, 1578, NULL, 5393, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16667, 2850, NULL, 5393, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16668, 8319, NULL, 5393, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16669, 8320, NULL, 5393, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (29023, 2411, NULL, 9007, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29024, 12280, NULL, 9007, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29025, 1238, NULL, 9007, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29026, 2766, NULL, 9007, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29099, 5346, NULL, 9034, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29103, 5126, NULL, 9038, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29116, 1687, NULL, 9058, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29117, 5136, NULL, 9058, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29118, 12299, NULL, 9058, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29119, 9473, NULL, 9058, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29142, 1059, NULL, 9065, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29143, 12316, NULL, 9065, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29144, 817, NULL, 9065, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29145, 186, NULL, 9065, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29158, 804, NULL, 9069, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29159, 12324, NULL, 9069, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29160, 12325, NULL, 9069, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29161, 12326, NULL, 9069, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29166, 12329, NULL, 9072, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29167, 12330, NULL, 9072, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29168, 12331, NULL, 9072, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29169, 12332, NULL, 9072, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29182, 12341, NULL, 9078, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6827, 285, NULL, 2542, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6828, 4323, NULL, 2542, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (6829, 234, NULL, 2542, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (6830, 1293, NULL, 2540, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6831, 1916, NULL, 2540, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6832, 601, NULL, 2532, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6833, 2692, NULL, 2532, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6834, 923, NULL, 2536, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6835, 1472, NULL, 2536, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6836, 1064, NULL, 2536, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6837, 5403, NULL, 2536, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6838, 926, NULL, 2538, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6839, 4395, NULL, 2538, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6840, 1666, NULL, 2538, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6841, 242, NULL, 2534, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6842, 1378, NULL, 2534, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6843, 5404, NULL, 2534, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6844, 625, NULL, 2534, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6845, 2442, NULL, 2535, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6846, 19, NULL, 2535, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6847, 1513, NULL, 2535, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6848, 1086, NULL, 2541, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6849, 141, NULL, 2541, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6850, 2531, NULL, 2541, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6851, 4239, NULL, 2541, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6852, 1748, NULL, 2537, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6853, 1702, NULL, 2537, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6854, 942, NULL, 2537, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6855, 1570, NULL, 620, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6856, 2505, NULL, 620, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6857, 2943, NULL, 620, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6858, 1429, NULL, 622, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6859, 2137, NULL, 622, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6860, 2138, NULL, 622, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6861, 485, NULL, 1850, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6862, 155, NULL, 1850, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6863, 1986, NULL, 1850, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6864, 5405, NULL, 1850, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6865, 5406, NULL, 1851, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6866, 3149, NULL, 1851, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6867, 1942, NULL, 1851, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6868, 757, NULL, 1853, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6869, 2752, NULL, 1853, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6870, 220, NULL, 1853, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6871, 1171, NULL, 1854, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6872, 5408, NULL, 1854, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6873, 3160, NULL, 1854, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6874, 5409, NULL, 1854, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6883, 1781, NULL, 1856, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6884, 5411, NULL, 1856, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6885, 5010, NULL, 1856, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6886, 2034, NULL, 1856, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6891, 73, NULL, 1858, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6892, 2527, NULL, 1858, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6893, 5415, NULL, 1858, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6894, 148, NULL, 1417, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6895, 4551, NULL, 1417, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6896, 1658, NULL, 1417, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6897, 5419, NULL, 1417, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6898, 694, NULL, 1412, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6899, 4382, NULL, 1412, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6900, 1413, NULL, 1412, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6901, 5420, NULL, 1412, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6902, 1554, NULL, 1411, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6903, 2468, NULL, 1411, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6904, 5421, NULL, 1411, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6905, 1403, NULL, 1411, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6906, 5422, NULL, 1413, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6907, 5423, NULL, 1413, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6912, 2556, NULL, 1418, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6913, 134, NULL, 1418, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6914, 1030, NULL, 1418, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6915, 2312, NULL, 1418, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6916, 5430, NULL, 1415, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6917, 317, NULL, 1415, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6918, 1655, NULL, 1415, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16674, 8321, NULL, 5393, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16675, 504, NULL, 5393, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16676, 2270, NULL, 1858, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16677, 2270, NULL, 4443, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16678, 8322, NULL, 5212, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16679, 8323, NULL, 5395, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16680, 8324, NULL, 5395, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16681, 382, NULL, 5396, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16682, 171, NULL, 5396, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16683, 2860, NULL, 5396, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16684, 1374, NULL, 5396, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16685, 1541, NULL, 5396, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16686, 1655, NULL, 5396, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16687, 232, NULL, 5396, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16688, 955, NULL, 5396, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (16689, 188, NULL, 5396, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (16690, 835, NULL, 5396, 10);
INSERT INTO 'tunesrecordingsmap' VALUES (16691, 1593, NULL, 5397, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16692, 850, NULL, 5397, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16693, 1971, NULL, 5397, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16694, 4258, NULL, 5397, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16695, 4290, NULL, 5397, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16696, 313, NULL, 5398, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16697, 5115, NULL, 5398, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16698, 3919, NULL, 5398, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16699, 4740, NULL, 5398, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16700, 283, NULL, 5399, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16701, 1505, NULL, 5399, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16702, 2910, NULL, 5399, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16703, 2055, NULL, 5400, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16704, 6685, NULL, 5400, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16705, 2601, NULL, 5400, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16706, 1232, NULL, 5400, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16707, 2418, NULL, 5400, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16708, 906, NULL, 5400, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16709, 1238, NULL, 5400, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16710, 3315, NULL, 5400, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (16711, 588, NULL, 5401, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16712, 239, NULL, 5401, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29027, 5346, NULL, 9008, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29104, 5126, NULL, 9039, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29120, 12300, NULL, 9059, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29121, 12301, NULL, 9059, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29122, 12302, NULL, 9059, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29123, 12303, NULL, 9059, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29146, 1237, NULL, 9066, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29147, 3048, NULL, 9066, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29148, 12317, NULL, 9066, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29149, 1343, NULL, 9066, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29150, 12318, NULL, 9066, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29162, 12230, NULL, 9070, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29163, 12231, NULL, 9070, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29170, 11837, NULL, 9073, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29171, 73, NULL, 9073, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29183, 11528, NULL, 9078, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29184, 709, NULL, 9078, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6919, 4376, NULL, 1415, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6887, 2123, NULL, 1857, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6888, 463, NULL, 1857, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6889, 5412, NULL, 1857, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6890, 5413, NULL, 1857, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6877, 285, NULL, 1855, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6876, 329, NULL, 1855, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6881, 4210, NULL, 1855, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (6920, 2481, NULL, 1511, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6921, 709, NULL, 1517, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6922, 5431, NULL, 1517, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6923, 98, NULL, 1517, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6924, 5432, NULL, 1511, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6925, 5433, NULL, 1519, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6926, 5434, NULL, 1519, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6927, 5435, NULL, 1519, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6928, 1586, NULL, 1520, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6929, 5436, NULL, 1521, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6930, 3033, NULL, 1521, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6931, 2414, NULL, 1521, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6935, 5437, NULL, 1510, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6936, 5439, NULL, 1510, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6937, 1225, NULL, 1510, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6941, 644, NULL, 1513, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6942, 1460, NULL, 1513, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6943, 993, NULL, 1514, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6944, 3752, NULL, 1515, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6945, 1872, NULL, 1515, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6946, 1415, NULL, 1515, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32881, 3589, NULL, 10183, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6952, 2802, NULL, 3152, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6953, 2772, NULL, 3152, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6954, 789, NULL, 3152, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6955, 5212, NULL, 3153, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6956, 4323, NULL, 3153, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6957, 4034, NULL, 3153, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6958, 1506, NULL, 3154, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6959, 8, NULL, 3154, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6960, 4376, NULL, 3154, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6961, 13, NULL, 3155, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6962, 41, NULL, 3155, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6963, 5343, NULL, 3155, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6964, 1705, NULL, 3155, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6965, 967, NULL, 3156, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6966, 232, NULL, 3156, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6967, 861, NULL, 3156, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6968, 1553, NULL, 3157, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6969, 2399, NULL, 3157, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6970, 1423, NULL, 3157, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6971, 5460, NULL, 209, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6972, 1462, NULL, 209, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6973, 1834, NULL, 530, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6974, 1721, NULL, 530, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6975, 1091, NULL, 530, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6976, 1458, NULL, 532, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6977, 1655, NULL, 532, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6978, 441, NULL, 532, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6979, 415, NULL, 3028, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6980, 5462, NULL, 3028, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6981, 2287, NULL, 3028, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6982, 5463, NULL, 3028, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6983, 166, NULL, 2135, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6984, 1406, NULL, 2135, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6985, 1219, NULL, 2135, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6986, 688, NULL, 2135, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6987, 713, NULL, 2136, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6988, 1052, NULL, 2136, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6989, 292, NULL, 2136, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6990, 2436, NULL, 2136, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6991, 2834, NULL, 2137, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6992, 1578, NULL, 2137, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6993, 599, NULL, 2137, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6994, 1916, NULL, 2138, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6995, 2662, NULL, 2138, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6996, 19, NULL, 2138, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6997, 55, NULL, 2139, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6998, 2786, NULL, 2139, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6999, 429, NULL, 2139, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7000, 1585, NULL, 2140, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7001, 346, NULL, 2140, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7002, 1731, NULL, 2140, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7007, 933, NULL, 158, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7008, 1515, NULL, 2142, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7009, 4753, NULL, 2142, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7010, 2240, NULL, 2142, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7011, 1463, NULL, 2143, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7012, 3589, NULL, 2143, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7013, 1096, NULL, 2144, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7014, 5466, NULL, 2144, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7015, 1775, NULL, 2144, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7018, 1965, NULL, 2146, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7019, 1977, NULL, 2146, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7023, 1179, NULL, 2148, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7024, 1385, NULL, 2148, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7025, 914, NULL, 2148, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7026, 644, NULL, 1158, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7027, 156, NULL, 1162, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7028, 939, NULL, 3105, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7029, 2943, NULL, 3105, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7030, 4168, NULL, 3105, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7031, 5468, NULL, 3159, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7032, 5469, NULL, 3159, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7033, 5470, NULL, 3159, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7034, 565, NULL, 3159, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7035, 5471, NULL, 3160, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7036, 2622, NULL, 3160, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7037, 921, NULL, 3160, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7038, 5472, NULL, 3160, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7039, 5473, NULL, 3161, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7040, 5474, NULL, 3161, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7041, 5475, NULL, 3161, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7042, 5476, NULL, 3162, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7043, 4939, NULL, 3162, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7044, 5477, NULL, 3162, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7045, 5479, NULL, 3163, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7046, 5480, NULL, 3164, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7047, 5481, NULL, 3164, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7048, 5482, NULL, 3164, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16713, 2118, NULL, 5401, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16714, 8325, NULL, 5401, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16715, 7787, NULL, 5401, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16716, 8326, NULL, 5401, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16717, 8327, NULL, 5401, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16718, 8328, NULL, 5401, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (16719, 374, NULL, 5402, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16720, 687, NULL, 5402, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16721, 1995, NULL, 5402, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16722, 1586, NULL, 5403, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16723, 1705, NULL, 5403, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16724, 1101, NULL, 5403, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16725, 1527, NULL, 5403, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16726, 833, NULL, 5403, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16727, 8329, NULL, 5404, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16728, 8330, NULL, 5404, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7049, 5483, NULL, 3165, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7050, 5484, NULL, 3165, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7051, 5485, NULL, 3165, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7052, 2696, NULL, 3166, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7053, 1313, NULL, 3166, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7054, 2434, NULL, 3166, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7055, 295, NULL, 3166, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7056, 51, NULL, 3167, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7057, 5486, NULL, 3167, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7058, 5487, NULL, 3167, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7059, 5488, NULL, 3167, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7060, 498, NULL, 3168, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7061, 4578, NULL, 3168, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7062, 2774, NULL, 3168, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7063, 1329, NULL, 3067, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7064, 1329, NULL, 80, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7065, 1329, NULL, 2513, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7066, 1329, NULL, 2961, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7067, 1329, NULL, 36, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (7068, 1329, NULL, 2848, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7069, 791, NULL, 3169, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7070, 2154, NULL, 3169, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7071, 1006, NULL, 3169, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7072, 5229, NULL, 3169, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7073, 1257, NULL, 3170, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7074, 2489, NULL, 3170, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7075, 1012, NULL, 3170, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7076, 4173, NULL, 3170, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7077, 1140, NULL, 3170, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7078, 81, NULL, 3171, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7079, 2091, NULL, 3171, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7080, 122, NULL, 3171, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6948, 1967, NULL, 1516, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6951, 5442, NULL, 1516, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6950, 3749, NULL, 1516, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2615, 3052, NULL, 855, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2616, 3053, NULL, 855, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2614, 1834, NULL, 855, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7081, 1435, NULL, 3172, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7082, 1106, NULL, 3172, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7083, 1561, NULL, 3172, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7084, 606, NULL, 3172, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7085, 3498, NULL, 3172, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7086, 320, NULL, 890, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7087, 2383, NULL, 1537, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7088, 935, NULL, 3172, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7089, 936, NULL, 3172, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7090, 413, NULL, 74, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7091, 2565, NULL, 74, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7092, 4055, NULL, 74, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7006, 369, NULL, 2141, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7005, 5465, NULL, 2141, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7093, 1643, NULL, 1159, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7094, 129, NULL, 1159, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7095, 2538, NULL, 1159, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7096, 3548, NULL, 1159, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7097, 2473, NULL, 1159, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7098, 1965, NULL, 1159, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7099, 1293, NULL, 1161, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7100, 2845, NULL, 1161, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7101, 890, NULL, 1168, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7102, 346, NULL, 1168, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7103, 914, NULL, 1168, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7104, 1618, NULL, 1168, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7105, 381, NULL, 1168, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7106, 2531, NULL, 1168, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7107, 1620, NULL, 2430, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7108, 1458, NULL, 2476, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7109, 2761, NULL, 2476, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7110, 1956, NULL, 2476, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7111, 1553, NULL, 2476, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7112, 1809, NULL, 2861, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7113, 77, NULL, 2861, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7114, 688, NULL, 2861, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7115, 2860, NULL, 2861, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7116, 1041, NULL, 3036, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7117, 5143, NULL, 3036, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7118, 452, NULL, 3036, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7119, 1942, NULL, 3036, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7120, 1636, NULL, 3158, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7121, 1069, NULL, 3158, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7122, 430, NULL, 3173, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7123, 2871, NULL, 3173, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7124, 1424, NULL, 3173, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7125, 4264, NULL, 3173, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7126, 2151, NULL, 827, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7127, 2151, NULL, 2542, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7128, 2151, NULL, 3129, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7129, 2151, NULL, 1353, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7130, 2151, NULL, 1283, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7131, 1457, NULL, 3174, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7132, 219, NULL, 3174, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7133, 488, NULL, 3174, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7134, 649, NULL, 3174, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7135, 152, NULL, 3175, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7136, 3642, NULL, 3175, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7137, 3977, NULL, 3175, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7138, 2576, NULL, 3175, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7139, 952, NULL, 3176, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7140, 2971, NULL, 3176, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7141, 2482, NULL, 3176, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16729, 8331, NULL, 5404, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16730, 8332, NULL, 5404, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16731, 1458, NULL, 5405, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16732, 76, NULL, 5405, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16733, 1721, NULL, 5405, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16734, 8333, NULL, 5405, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16735, 424, NULL, 5405, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16736, 939, NULL, 5406, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16737, 1873, NULL, 5406, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16738, 8334, NULL, 5406, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16739, 7505, NULL, 5406, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16740, 469, NULL, 5407, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16741, 5165, NULL, 5407, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16742, 2258, NULL, 5407, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16743, 32, NULL, 5407, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16744, 2897, NULL, 5407, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16745, 8335, NULL, 5407, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16746, 3224, NULL, 5407, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (16747, 8336, NULL, 5407, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (16751, 6079, NULL, 4953, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16752, 4833, NULL, 5363, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16753, 7204, NULL, 5363, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16754, 8338, NULL, 5363, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16755, 5933, NULL, 5363, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16756, 456, NULL, 5364, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16757, 201, NULL, 5364, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16758, 424, NULL, 5364, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16759, 8244, NULL, 5365, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16760, 2661, NULL, 5365, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16761, 8339, NULL, 5365, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16762, 972, NULL, 5365, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16763, 8246, NULL, 5366, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16764, 8340, NULL, 5366, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16765, 8341, NULL, 5366, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16766, 2668, NULL, 5366, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16767, 4801, NULL, 5367, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16768, 2544, NULL, 5367, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16769, 305, NULL, 5367, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16770, 5560, NULL, 5367, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29028, 5346, NULL, 9009, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29124, 12304, NULL, 9060, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29125, 12305, NULL, 9060, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29126, 12306, NULL, 9060, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29127, 12307, NULL, 9060, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29172, 5363, NULL, 9074, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29185, 12342, NULL, 9079, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29192, 898, NULL, 9083, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29193, 1152, NULL, 9083, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29194, 12347, NULL, 9083, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29195, 12348, NULL, 9083, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29199, 1455, NULL, 9085, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29200, 1769, NULL, 9085, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29201, 6929, NULL, 9085, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29202, 3894, NULL, 9085, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29203, 1942, NULL, 9085, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29204, 12350, NULL, 9086, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29205, 12351, NULL, 9086, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29206, 12352, NULL, 9086, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29209, 12355, NULL, 9088, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29210, 12356, NULL, 9088, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29211, 12357, NULL, 9088, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7142, 5131, NULL, 3176, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7143, 179, NULL, 3177, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7144, 109, NULL, 3177, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7145, 2907, NULL, 3177, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7146, 3628, NULL, 3177, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7147, 1745, NULL, 3177, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7148, 1588, NULL, 3177, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7149, 1732, NULL, 3178, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7150, 686, NULL, 3178, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7151, 1926, NULL, 3178, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7152, 405, NULL, 3178, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7153, 534, NULL, 3179, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7154, 955, NULL, 3179, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7155, 232, NULL, 3179, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7156, 482, NULL, 3179, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7157, 1195, NULL, 3180, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7158, 3114, NULL, 3180, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7159, 5490, NULL, 3180, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7160, 1241, NULL, 3180, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7161, 84, NULL, 3181, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7162, 3628, NULL, 3181, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7163, 2587, NULL, 3181, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7164, 247, NULL, 3182, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7165, 4388, NULL, 3182, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7166, 5491, NULL, 3182, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7167, 1586, NULL, 3183, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7168, 3437, NULL, 3183, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7169, 295, NULL, 3183, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7170, 4618, NULL, 3183, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7171, 1670, NULL, 3184, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7172, 1063, NULL, 3184, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7173, 224, NULL, 3184, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7174, 1053, NULL, 3184, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7175, 512, NULL, 3185, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7176, 1112, NULL, 3185, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7177, 5381, NULL, 3185, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7178, 2730, NULL, 3185, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7179, 548, NULL, 3186, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7180, 2104, NULL, 3186, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7181, 1046, NULL, 3186, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7182, 1352, NULL, 3186, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7183, 2219, NULL, 3186, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7184, 1352, NULL, 3158, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7185, 923, NULL, 3187, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7186, 51, NULL, 3187, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7187, 4539, NULL, 3187, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7188, 1022, NULL, 3187, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7189, 682, NULL, 3187, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7190, 4240, NULL, 3187, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7191, 1386, NULL, 3187, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7192, 722, NULL, 3188, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7193, 5489, NULL, 3188, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7194, 5492, NULL, 3188, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7195, 1897, NULL, 3188, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7196, 1603, NULL, 1022, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7197, 709, NULL, 1022, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7198, 497, NULL, 1022, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7199, 2383, NULL, 1022, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7200, 369, NULL, 1022, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7201, 3635, NULL, 1023, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7202, 2988, NULL, 1023, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7203, 537, NULL, 1024, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7204, 5262, NULL, 1024, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7205, 431, NULL, 1025, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7206, 861, NULL, 1025, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7207, 2136, NULL, 1025, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7208, 5493, NULL, 1025, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7209, 4092, NULL, 1025, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7210, 1771, NULL, 1025, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7211, 3569, NULL, 1025, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7212, 769, NULL, 1026, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7213, 219, NULL, 1026, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7214, 2730, NULL, 1026, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7215, 543, NULL, 1026, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7216, 300, NULL, 1027, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7217, 5494, NULL, 1027, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7218, 3572, NULL, 1027, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7219, 1942, NULL, 1027, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7223, 808, NULL, 1029, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7224, 2165, NULL, 1029, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7225, 3570, NULL, 1029, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7226, 3715, NULL, 1029, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7227, 84, NULL, 1030, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7228, 4310, NULL, 1030, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7222, 3311, NULL, 1028, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7221, 1294, NULL, 1028, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7220, 1683, NULL, 1028, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7229, 5496, NULL, 1030, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7233, 55, NULL, 1941, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16771, 37, NULL, 5368, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16772, 8342, NULL, 5368, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16773, 4789, NULL, 5368, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16774, 8343, NULL, 5368, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16775, 6422, NULL, 5369, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16776, 1581, NULL, 5369, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16777, 4048, NULL, 5369, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16778, 5956, NULL, 5369, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16779, 8248, NULL, 5370, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16780, 1745, NULL, 5370, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16781, 2489, NULL, 5370, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16782, 1707, NULL, 5370, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16783, 613, NULL, 3549, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16784, 613, NULL, 4676, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16785, 613, NULL, 1236, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16786, 613, NULL, 1192, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16787, 613, NULL, 5315, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16789, 613, NULL, 2308, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16790, 3946, NULL, 5409, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16791, 3433, NULL, 5409, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16792, 283, NULL, 5410, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16793, 8344, NULL, 5410, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16794, 7511, NULL, 5410, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16795, 8345, NULL, 5410, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16796, 8346, NULL, 5411, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16797, 8347, NULL, 5412, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16798, 374, NULL, 5413, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16799, 534, NULL, 5413, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16800, 3394, NULL, 5413, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16801, 1472, NULL, 5413, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16802, 146, NULL, 5413, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16803, 5499, NULL, 5414, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16804, 8348, NULL, 5414, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16805, 8349, NULL, 5414, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16806, 2910, NULL, 5415, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16807, 5442, NULL, 5415, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16808, 7719, NULL, 5415, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16809, 1332, NULL, 5415, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16810, 8350, NULL, 5416, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16811, 8351, NULL, 5416, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16812, 8352, NULL, 5416, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29173, 12333, NULL, 9075, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29174, 12334, NULL, 9075, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29175, 12335, NULL, 9075, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29176, 12336, NULL, 9075, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29186, 6345, NULL, 9080, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29187, 5557, NULL, 9080, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29188, 12343, NULL, 9080, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29196, 648, NULL, 9084, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29197, 12349, NULL, 9084, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29198, 1099, NULL, 9084, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29207, 12353, NULL, 9087, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29208, 12354, NULL, 9087, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29212, 12358, NULL, 9088, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7234, 2757, NULL, 1941, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7235, 78, NULL, 1941, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7236, 1603, NULL, 1942, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7237, 2752, NULL, 1942, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7238, 5497, NULL, 1942, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7239, 4764, NULL, 1937, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7240, 5498, NULL, 1937, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7241, 534, NULL, 1945, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7242, 1956, NULL, 1945, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7243, 685, NULL, 1945, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7244, 1392, NULL, 1945, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7245, 2259, NULL, 1943, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7246, 19, NULL, 1943, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7247, 2903, NULL, 1943, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7248, 2821, NULL, 1943, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7249, 5499, NULL, 1947, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7250, 5500, NULL, 1947, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7251, 5501, NULL, 1947, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7252, 5502, NULL, 1947, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7253, 3223, NULL, 1939, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7254, 2650, NULL, 1939, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7255, 3015, NULL, 1939, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7256, 1691, NULL, 1940, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7257, 2171, NULL, 1940, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7258, 3016, NULL, 1940, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7259, 374, NULL, 1944, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7260, 220, NULL, 1944, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7261, 3550, NULL, 3189, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7262, 2118, NULL, 3189, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7263, 829, NULL, 3189, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7264, 1015, NULL, 3189, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7265, 1513, NULL, 3189, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7266, 430, NULL, 3190, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7267, 1263, NULL, 3190, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7268, 6, NULL, 3190, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7269, 1540, NULL, 3191, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7270, 2504, NULL, 3191, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7271, 2473, NULL, 3191, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7272, 2802, NULL, 3192, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7273, 914, NULL, 3192, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7274, 378, NULL, 3192, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7275, 2332, NULL, 3192, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7276, 2945, NULL, 3192, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7277, 1778, NULL, 3192, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7278, 1066, NULL, 3192, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7279, 5256, NULL, 3192, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (7280, 835, NULL, 3192, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (7288, 730, NULL, 3082, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7292, 5506, NULL, 3195, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7293, 3912, NULL, 3195, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7294, 5507, NULL, 3195, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7295, 73, NULL, 3195, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7300, 408, NULL, 3197, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7301, 73, NULL, 2251, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7302, 5343, NULL, 2251, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7303, 100, NULL, 2251, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7304, 2442, NULL, 2254, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7305, 3252, NULL, 2254, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7306, 638, NULL, 2246, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7307, 1431, NULL, 2246, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7308, 953, NULL, 2252, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7309, 1279, NULL, 2252, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7310, 4692, NULL, 2252, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7311, 1741, NULL, 2249, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7312, 5512, NULL, 2249, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7313, 932, NULL, 2248, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7314, 586, NULL, 2248, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7315, 4171, NULL, 2248, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7316, 2609, NULL, 2253, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7317, 4323, NULL, 2253, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7318, 4555, NULL, 2253, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7319, 1482, NULL, 2250, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7320, 1003, NULL, 2250, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7321, 2857, NULL, 2250, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7322, 1450, NULL, 2247, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7323, 3498, NULL, 2247, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7324, 765, NULL, 2247, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16813, 8353, NULL, 5416, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16814, 8354, NULL, 5417, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16815, 5809, NULL, 5417, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16816, 993, NULL, 5418, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16817, 1799, NULL, 5418, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16818, 372, NULL, 5418, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16819, 8355, NULL, 5419, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16820, 8356, NULL, 5419, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16821, 8357, NULL, 5419, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16822, 2883, NULL, 5420, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16823, 6749, NULL, 5420, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16824, 1942, NULL, 5420, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16825, 8358, NULL, 5420, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16830, 4728, NULL, 5423, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16831, 8360, NULL, 5423, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16832, 8361, NULL, 5424, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16833, 8362, NULL, 5424, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16788, 613, NULL, 1815, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7291, 3642, NULL, 3194, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7290, 510, NULL, 3194, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7289, 2519, NULL, 3194, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7287, 687, NULL, 3193, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7284, 771, NULL, 3193, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7286, 1066, NULL, 3193, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7299, 5509, NULL, 3196, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7297, 333, NULL, 3196, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7298, 4912, NULL, 3196, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7296, 5508, NULL, 3196, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16835, 807, NULL, 5426, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16836, 6462, NULL, 5426, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16837, 8363, NULL, 5426, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16838, 2549, NULL, 5426, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16839, 8364, NULL, 5427, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16840, 8365, NULL, 5427, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16841, 5246, NULL, 5428, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16842, 8366, NULL, 5428, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16843, 8367, NULL, 5428, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16844, 8368, NULL, 5428, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16845, 8369, NULL, 4997, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16846, 3850, NULL, 4997, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16847, 2922, NULL, 4997, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16848, 2309, NULL, 4998, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16849, 5364, NULL, 4998, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16850, 3320, NULL, 4998, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16851, 355, NULL, 4999, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16852, 2017, NULL, 4999, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16853, 8370, NULL, 5000, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16854, 2623, NULL, 5000, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29189, 12344, NULL, 9081, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29190, 12345, NULL, 9081, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29213, 1526, NULL, 9102, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29214, 11976, NULL, 9102, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29215, 697, NULL, 9102, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29216, 1214, NULL, 9105, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29217, 9508, NULL, 9105, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29218, 4561, NULL, 9105, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29219, 10163, NULL, 9105, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29233, 12365, NULL, 9110, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29234, 12366, NULL, 9110, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29235, 5144, NULL, 9110, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29236, 10135, NULL, 9110, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29237, 12367, NULL, 9110, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29238, 10533, NULL, 9111, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29239, 1344, NULL, 9111, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29240, 1184, NULL, 9111, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29246, 12369, NULL, 9115, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29248, 835, NULL, 9117, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29249, 1857, NULL, 9117, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29250, 11528, NULL, 9117, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29251, 1648, NULL, 9117, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29252, 10364, NULL, 9117, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7351, 2645, NULL, 3200, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7352, 1448, NULL, 2526, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7353, 3521, NULL, 2526, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7354, 2240, NULL, 2526, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7355, 1514, NULL, 2526, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7356, 982, NULL, 2524, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7357, 2416, NULL, 2524, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7358, 699, NULL, 2524, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7359, 5521, NULL, 2524, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7360, 1704, NULL, 2530, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7361, 1408, NULL, 2530, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7362, 693, NULL, 2527, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7363, 5522, NULL, 2527, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7364, 19, NULL, 2527, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7365, 1763, NULL, 2523, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7366, 1526, NULL, 2523, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7367, 3068, NULL, 2523, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7368, 2076, NULL, 2523, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7369, 5523, NULL, 2529, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7370, 5524, NULL, 2529, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7371, 1192, NULL, 2529, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32884, 6903, NULL, 10184, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32885, 1125, NULL, 10184, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32886, 2465, NULL, 10184, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32887, 13872, NULL, 10184, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32888, 2379, NULL, 10185, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32889, 4404, NULL, 10185, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7378, 4478, NULL, 1646, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7379, 1238, NULL, 1646, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7380, 652, NULL, 1646, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7381, 2943, NULL, 1646, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7382, 2505, NULL, 1646, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7383, 2336, NULL, 1646, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7384, 2737, NULL, 1646, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7385, 3774, NULL, 1647, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7386, 3775, NULL, 1647, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7387, 123, NULL, 1647, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7388, 3145, NULL, 1647, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7389, 5525, NULL, 1647, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7390, 272, NULL, 1647, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7391, 4550, NULL, 1648, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7392, 503, NULL, 1648, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7393, 1225, NULL, 1648, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7394, 807, NULL, 1648, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7395, 2853, NULL, 1649, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7396, 3438, NULL, 1649, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7397, 2397, NULL, 1649, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7398, 2122, NULL, 1649, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7399, 3111, NULL, 1649, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7400, 4570, NULL, 1650, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7401, 2832, NULL, 1652, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7402, 2692, NULL, 1652, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7403, 2031, NULL, 1652, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7408, 13, NULL, 1905, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7409, 1505, NULL, 1905, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7410, 2626, NULL, 1905, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7411, 1146, NULL, 1905, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7412, 1506, NULL, 1901, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7413, 2520, NULL, 1901, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7414, 5258, NULL, 1901, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7415, 1241, NULL, 1901, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7416, 5526, NULL, 1896, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7417, 1685, NULL, 1896, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7418, 4976, NULL, 1895, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16855, 2159, NULL, 5000, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16856, 2957, NULL, 5001, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16857, 2399, NULL, 5001, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16858, 803, NULL, 5002, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16859, 730, NULL, 5002, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16860, 488, NULL, 5002, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16861, 68, NULL, 5003, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16862, 1140, NULL, 5003, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16863, 1624, NULL, 5003, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16864, 90, NULL, 5004, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16865, 1787, NULL, 5004, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16866, 4183, NULL, 5004, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16867, 5368, NULL, 5004, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16869, 1070, NULL, 5006, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16870, 5161, NULL, 5007, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16871, 1687, NULL, 5007, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16872, 1437, NULL, 5007, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16873, 8371, NULL, 5008, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16874, 2185, NULL, 5009, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16875, 1628, NULL, 5009, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16876, 3662, NULL, 5009, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16877, 8400, NULL, 5045, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16878, 8401, NULL, 5053, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16879, 3791, NULL, 5053, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16880, 8402, NULL, 5053, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16881, 5979, NULL, 5053, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16882, 8403, NULL, 5053, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16883, 1898, NULL, 5054, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16884, 2448, NULL, 5054, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16885, 2559, NULL, 5054, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16886, 7930, NULL, 5054, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16887, 1140, NULL, 5054, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16834, 6907, NULL, 5425, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16888, 8404, NULL, 5429, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16889, 8405, NULL, 5429, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16890, 8406, NULL, 5429, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16891, 8407, NULL, 5429, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16892, 8408, NULL, 5430, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16893, 8409, NULL, 5430, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16894, 8410, NULL, 5430, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16895, 8411, NULL, 5430, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16896, 4093, NULL, 5431, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16897, 8007, NULL, 5431, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29191, 12346, NULL, 9082, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29220, 12360, NULL, 9106, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29221, 1601, NULL, 9106, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29241, 926, NULL, 9113, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29242, 6375, NULL, 9113, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29243, 5889, NULL, 9113, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7407, 1363, NULL, 1899, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29244, 843, NULL, 9113, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29247, 12370, NULL, 9116, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29253, 4522, NULL, 9117, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7419, 5190, NULL, 1895, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7420, 5527, NULL, 1895, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7421, 374, NULL, 1904, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7422, 168, NULL, 1904, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7423, 688, NULL, 1904, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7424, 1219, NULL, 1904, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7425, 3514, NULL, 1900, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7426, 5198, NULL, 1900, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7427, 2054, NULL, 1903, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7428, 1181, NULL, 1903, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7429, 4954, NULL, 1903, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7430, 2152, NULL, 1903, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7431, 3215, NULL, 3201, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7432, 5528, NULL, 3201, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7433, 2105, NULL, 3201, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7434, 5529, NULL, 3202, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7435, 982, NULL, 3202, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7436, 5530, NULL, 3202, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7437, 5531, NULL, 3203, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7438, 3780, NULL, 3203, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7439, 5532, NULL, 3203, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7440, 4323, NULL, 3204, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7332, 183, NULL, 1865, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7331, 3377, NULL, 1860, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7334, 5516, NULL, 1865, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7335, 773, NULL, 1865, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7333, 3033, NULL, 1865, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7337, 2423, NULL, 1863, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7336, 953, NULL, 1863, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7338, 4578, NULL, 1863, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7339, 3766, NULL, 1859, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7340, 3714, NULL, 1859, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7341, 524, NULL, 1859, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7342, 1995, NULL, 1862, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7344, 3521, NULL, 1862, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7343, 3738, NULL, 1862, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7347, 5517, NULL, 1866, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7346, 4191, NULL, 1866, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7345, 1186, NULL, 1866, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7348, 388, NULL, 1861, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7349, 1164, NULL, 1861, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16868, 767, NULL, 5005, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7441, 4665, NULL, 3204, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7442, 5533, NULL, 3204, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7443, 534, NULL, 3205, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7444, 1329, NULL, 3205, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7445, 497, NULL, 3205, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7446, 1091, NULL, 3205, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7447, 5534, NULL, 3206, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7448, 2278, NULL, 3206, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7449, 5535, NULL, 3206, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7450, 1503, NULL, 3206, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7451, 5536, NULL, 3206, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7452, 5537, NULL, 3207, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7453, 5538, NULL, 3207, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7454, 1526, NULL, 3207, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7455, 5539, NULL, 3208, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7456, 2024, NULL, 3208, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7457, 5540, NULL, 3208, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7458, 692, NULL, 3209, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7459, 5541, NULL, 3209, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7460, 5542, NULL, 3209, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7461, 5543, NULL, 3210, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7462, 3236, NULL, 3210, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7463, 5544, NULL, 3210, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7464, 5545, NULL, 3211, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7465, 5546, NULL, 3211, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7466, 5547, NULL, 3211, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7467, 1721, NULL, 3211, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7468, 4006, NULL, 1951, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7469, 4608, NULL, 1951, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7470, 3192, NULL, 1951, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7471, 992, NULL, 1950, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7472, 1710, NULL, 1950, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7473, 5548, NULL, 1950, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7474, 967, NULL, 1953, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7475, 861, NULL, 1953, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7476, 275, NULL, 1953, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7477, 179, NULL, 1952, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7478, 1184, NULL, 1952, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7479, 1979, NULL, 1952, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7480, 1219, NULL, 1948, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7481, 1455, NULL, 1948, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7482, 5549, NULL, 1948, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7483, 3595, NULL, 2196, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7484, 5278, NULL, 2196, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7485, 5551, NULL, 2196, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7486, 1462, NULL, 2197, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7487, 920, NULL, 2197, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7488, 1026, NULL, 2197, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7489, 1670, NULL, 2199, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7490, 1636, NULL, 2199, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7491, 2017, NULL, 2199, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7492, 2631, NULL, 2199, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7493, 1670, NULL, 2584, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7494, 1670, NULL, 1875, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7495, 1670, NULL, 3002, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7496, 4071, NULL, 2201, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7497, 5552, NULL, 2201, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7498, 5553, NULL, 2201, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7499, 4464, NULL, 2202, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7500, 955, NULL, 2202, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7501, 5554, NULL, 2202, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7502, 548, NULL, 2203, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7503, 5555, NULL, 2203, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7504, 2508, NULL, 2203, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7505, 2322, NULL, 2203, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7506, 100, NULL, 2204, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7507, 5556, NULL, 2204, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7508, 687, NULL, 2204, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7509, 5557, NULL, 2204, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7510, 3360, NULL, 2206, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7511, 4959, NULL, 2206, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7512, 766, NULL, 2206, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7513, 5558, NULL, 2206, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7514, 14, NULL, 2305, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7515, 3320, NULL, 2305, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7516, 2159, NULL, 2305, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7517, 969, NULL, 2310, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7518, 2120, NULL, 2310, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7519, 1024, NULL, 2310, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7520, 2349, NULL, 2310, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7521, 519, NULL, 2310, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7522, 5559, NULL, 2310, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7523, 5560, NULL, 2310, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7524, 435, NULL, 2309, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7525, 2527, NULL, 2309, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7526, 2971, NULL, 2309, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7527, 4444, NULL, 2309, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7528, 1514, NULL, 2309, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7529, 1328, NULL, 2309, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32890, 4136, NULL, 10185, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7543, 1082, NULL, 2307, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7544, 1915, NULL, 2307, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7545, 2386, NULL, 2307, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7546, 5562, NULL, 2307, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7547, 1895, NULL, 2307, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7548, 5563, NULL, 2307, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16898, 3661, NULL, 5431, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16899, 3734, NULL, 5432, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16900, 8412, NULL, 5432, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16901, 8413, NULL, 5432, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16902, 2254, NULL, 5433, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16903, 8414, NULL, 5433, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16904, 8415, NULL, 5433, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16905, 8416, NULL, 5434, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16906, 8417, NULL, 5434, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16907, 8419, NULL, 5434, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16908, 4776, NULL, 5435, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16909, 8420, NULL, 5435, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16910, 8421, NULL, 5435, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16911, 4034, NULL, 5436, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16912, 8422, NULL, 5436, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16913, 1266, NULL, 5436, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7549, 123, NULL, 2307, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7550, 423, NULL, 2307, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (7551, 408, NULL, 2306, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7552, 1809, NULL, 2308, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7553, 76, NULL, 2308, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7554, 369, NULL, 2308, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7555, 1881, NULL, 2308, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7556, 1649, NULL, 2308, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7557, 1020, NULL, 2308, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7558, 512, NULL, 2302, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7559, 5564, NULL, 2302, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7560, 2138, NULL, 2302, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7561, 2069, NULL, 2302, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7562, 278, NULL, 2302, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7563, 647, NULL, 2302, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7568, 3930, NULL, 2289, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7569, 1409, NULL, 2289, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7570, 2413, NULL, 2289, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7571, 2555, NULL, 2290, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7572, 5567, NULL, 2290, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7573, 5114, NULL, 2290, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7574, 295, NULL, 2291, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7575, 5568, NULL, 2291, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7576, 5263, NULL, 2291, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7577, 698, NULL, 2292, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7578, 5569, NULL, 2292, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7579, 2404, NULL, 2292, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7580, 480, NULL, 2293, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7581, 3744, NULL, 2293, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7582, 1849, NULL, 2293, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7583, 3912, NULL, 2293, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7584, 4771, NULL, 2294, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7585, 923, NULL, 2295, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7586, 1472, NULL, 2295, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7587, 2661, NULL, 2295, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7588, 5571, NULL, 2295, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7589, 1659, NULL, 2296, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7590, 1707, NULL, 2296, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7591, 281, NULL, 2297, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7592, 5572, NULL, 2297, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7593, 5573, NULL, 2297, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7594, 4392, NULL, 2298, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7595, 503, NULL, 2298, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7596, 1940, NULL, 2298, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7597, 5574, NULL, 2298, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7598, 5575, NULL, 2299, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7599, 4646, NULL, 2299, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7600, 55, NULL, 2300, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7601, 5576, NULL, 2300, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7602, 5577, NULL, 2300, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7603, 5578, NULL, 2300, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7604, 4208, NULL, 2235, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7605, 952, NULL, 2235, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7606, 3013, NULL, 2235, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7607, 2307, NULL, 2235, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7608, 673, NULL, 2267, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7609, 5579, NULL, 2267, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7610, 2754, NULL, 2267, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7611, 5580, NULL, 2267, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7615, 5582, NULL, 2269, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7614, 1101, NULL, 2269, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7542, 1861, NULL, 2303, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (7536, 1911, NULL, 2303, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7538, 3572, NULL, 2303, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7535, 722, NULL, 2303, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7541, 2512, NULL, 2303, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7618, 1351, NULL, 2270, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7619, 3741, NULL, 2270, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7620, 5004, NULL, 2270, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7621, 135, NULL, 2271, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7622, 3371, NULL, 2271, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7623, 3564, NULL, 2271, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7624, 1858, NULL, 2271, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7625, 588, NULL, 2272, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7626, 183, NULL, 2272, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7627, 1624, NULL, 2272, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7628, 1814, NULL, 2272, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7629, 2559, NULL, 2274, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7630, 109, NULL, 2274, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7631, 2115, NULL, 2274, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7632, 2725, NULL, 2275, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7633, 4005, NULL, 2275, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7634, 5585, NULL, 2275, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7635, 1014, NULL, 2275, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7636, 5586, NULL, 1982, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32891, 7001, NULL, 10185, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16914, 8423, NULL, 5436, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16915, 8424, NULL, 5437, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16916, 8425, NULL, 5437, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16917, 8426, NULL, 5437, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16918, 8427, NULL, 5437, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16921, 7436, NULL, 5439, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16922, 8428, NULL, 5439, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16923, 8429, NULL, 5439, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16924, 4125, NULL, 5440, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16925, 8430, NULL, 5440, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16926, 8431, NULL, 5440, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16927, 8432, NULL, 5440, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16928, 8433, NULL, 5440, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16929, 8434, NULL, 5440, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16935, 8438, NULL, 5443, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16936, 8439, NULL, 5443, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16937, 3290, NULL, 5444, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16938, 8441, NULL, 5444, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16939, 8442, NULL, 5444, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16940, 8443, NULL, 5444, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16941, 8444, NULL, 5444, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16942, 8308, NULL, 5445, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16943, 8445, NULL, 5445, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16944, 8446, NULL, 5445, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16945, 821, NULL, 5446, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16946, 8245, NULL, 5446, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16947, 8447, NULL, 5446, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16948, 8448, NULL, 5446, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16949, 4715, NULL, 5447, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16950, 8449, NULL, 5447, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16951, 8450, NULL, 5447, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29222, 1600, NULL, 9107, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29223, 2242, NULL, 9107, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29224, 8518, NULL, 9107, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29225, 12361, NULL, 9107, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29245, 12368, NULL, 9114, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29254, 9707, NULL, 9117, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (29255, 5571, NULL, 9117, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (29256, 1392, NULL, 9117, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (7652, 5600, NULL, 1992, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7653, 1266, NULL, 1992, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7654, 3858, NULL, 1992, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7655, 198, NULL, 1759, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7656, 4045, NULL, 1759, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7657, 4612, NULL, 1759, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7658, 390, NULL, 1756, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7659, 2692, NULL, 1756, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7660, 5601, NULL, 1756, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7661, 1732, NULL, 1754, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7662, 5320, NULL, 1754, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7663, 4288, NULL, 1754, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7664, 1593, NULL, 1755, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7665, 5602, NULL, 1755, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7666, 5603, NULL, 1755, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7667, 343, NULL, 1760, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7668, 5604, NULL, 1760, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7669, 5605, NULL, 1760, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7670, 5606, NULL, 1760, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7671, 958, NULL, 1752, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7672, 1802, NULL, 1752, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7673, 5607, NULL, 1752, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7674, 952, NULL, 1761, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7675, 5608, NULL, 1761, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7676, 5609, NULL, 1761, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7677, 512, NULL, 1753, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7678, 3935, NULL, 1753, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7679, 5610, NULL, 1753, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7680, 1741, NULL, 1757, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7681, 171, NULL, 1757, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7682, 5611, NULL, 1757, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7683, 350, NULL, 1751, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7684, 152, NULL, 1751, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7685, 2793, NULL, 1751, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7686, 5612, NULL, 1758, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7687, 155, NULL, 1758, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7688, 4214, NULL, 1750, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7689, 5613, NULL, 1750, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7690, 4348, NULL, 2030, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7691, 955, NULL, 2030, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7692, 2480, NULL, 2032, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7693, 1685, NULL, 2032, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7694, 1665, NULL, 2033, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7695, 750, NULL, 2033, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7696, 1748, NULL, 2036, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7697, 3390, NULL, 2036, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7698, 3513, NULL, 2036, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7699, 369, NULL, 2036, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7700, 1821, NULL, 2042, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7701, 979, NULL, 2042, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7702, 231, NULL, 3228, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7703, 3919, NULL, 3228, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7638, 5590, NULL, 1984, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7637, 3309, NULL, 1984, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7641, 3270, NULL, 1988, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7642, 3181, NULL, 1988, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7643, 5597, NULL, 1988, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7647, 5598, NULL, 1989, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7646, 852, NULL, 1989, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7644, 1098, NULL, 1989, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7648, 52, NULL, 1991, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7649, 5599, NULL, 1991, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7650, 1433, NULL, 1991, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7651, 4094, NULL, 1991, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16953, 8452, NULL, 5448, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16955, 3734, NULL, 5448, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16952, 8451, NULL, 5448, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7704, 133, NULL, 3228, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7705, 952, NULL, 3228, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7710, 4375, NULL, 3230, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7711, 1196, NULL, 3230, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7712, 2044, NULL, 3230, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7713, 5617, NULL, 3230, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7714, 5618, NULL, 3231, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7715, 724, NULL, 3231, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7716, 728, NULL, 3231, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7717, 124, NULL, 3232, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7718, 2255, NULL, 3232, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7719, 13, NULL, 3232, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7720, 1802, NULL, 3233, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7721, 3003, NULL, 3233, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7612, 121, NULL, 2268, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7613, 1542, NULL, 2268, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16932, 7926, NULL, 5441, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16930, 7927, NULL, 5441, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16931, 8435, NULL, 5441, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16934, 8437, NULL, 5442, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7722, 5620, NULL, 3233, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7723, 5621, NULL, 3234, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7724, 5622, NULL, 3235, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7725, 150, NULL, 3235, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7726, 467, NULL, 3235, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7727, 4484, NULL, 3236, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7728, 1020, NULL, 3236, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7729, 138, NULL, 3236, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7730, 1241, NULL, 3237, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7731, 1282, NULL, 3237, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7732, 3601, NULL, 3237, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7733, 226, NULL, 1196, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16956, 8454, NULL, 5449, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16957, 8455, NULL, 5449, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16958, 8456, NULL, 5449, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16968, 1066, NULL, 111, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32880, 6761, NULL, 10183, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32882, 778, NULL, 10183, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32883, 5956, NULL, 10183, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32801, 686, NULL, 10159, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16988, 944, NULL, 485, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16989, 3224, NULL, 485, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16990, 2346, NULL, 485, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16991, 8498, NULL, 485, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16992, 5, NULL, 486, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16993, 2204, NULL, 486, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16994, 2207, NULL, 486, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16995, 2208, NULL, 486, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16996, 2418, NULL, 488, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16997, 401, NULL, 488, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29226, 12362, NULL, 9108, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29227, 12363, NULL, 9108, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29228, 6406, NULL, 9108, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7709, 5616, NULL, 3229, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7706, 4713, NULL, 3229, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29257, 12372, NULL, 9118, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7734, 687, NULL, 1196, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7735, 2240, NULL, 1196, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7736, 5623, NULL, 1197, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7737, 5624, NULL, 1197, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7738, 5625, NULL, 1197, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7739, 1639, NULL, 1198, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7740, 5626, NULL, 1198, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7741, 5627, NULL, 1198, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7742, 5628, NULL, 1199, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7743, 2480, NULL, 1200, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7744, 5629, NULL, 1200, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7745, 1592, NULL, 1201, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7746, 3550, NULL, 1201, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7747, 2816, NULL, 1201, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7748, 1386, NULL, 1202, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7749, 4101, NULL, 1203, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7750, 4397, NULL, 1203, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7751, 1462, NULL, 1204, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7752, 1775, NULL, 1204, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7753, 1368, NULL, 1204, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7754, 5630, NULL, 1205, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7755, 5631, NULL, 1205, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7756, 5633, NULL, 1207, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7757, 5186, NULL, 1208, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7758, 2189, NULL, 1208, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7759, 5187, NULL, 1208, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7760, 81, NULL, 1093, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7761, 312, NULL, 1093, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7762, 613, NULL, 1093, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7763, 2399, NULL, 1093, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7764, 673, NULL, 1094, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7765, 652, NULL, 1094, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7766, 3859, NULL, 1094, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7767, 2529, NULL, 1094, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7768, 890, NULL, 1095, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7769, 1311, NULL, 1095, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7770, 5635, NULL, 1095, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7771, 2327, NULL, 1095, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7776, 2616, NULL, 1097, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7777, 5638, NULL, 1097, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7778, 78, NULL, 1097, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7779, 749, NULL, 1098, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7780, 1536, NULL, 1098, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7781, 5113, NULL, 1098, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7782, 2382, NULL, 1098, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7783, 128, NULL, 1099, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7784, 1158, NULL, 1099, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7785, 3501, NULL, 1099, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7786, 1334, NULL, 1099, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7787, 1021, NULL, 1100, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7788, 1943, NULL, 1100, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7789, 68, NULL, 1100, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7790, 5639, NULL, 1100, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7791, 4677, NULL, 1101, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7792, 2191, NULL, 1101, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7793, 5640, NULL, 1101, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7794, 5641, NULL, 1101, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7795, 2986, NULL, 1102, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7796, 4983, NULL, 1102, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7797, 952, NULL, 1102, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7798, 2967, NULL, 1102, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7799, 654, NULL, 1103, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7800, 3628, NULL, 1103, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7801, 1745, NULL, 1103, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7802, 1118, NULL, 1103, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7803, 1540, NULL, 1104, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7804, 1958, NULL, 1104, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7805, 5642, NULL, 1104, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7806, 1528, NULL, 1104, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7807, 5643, NULL, 3238, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7808, 1077, NULL, 3238, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7809, 5644, NULL, 3238, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7810, 1280, NULL, 3238, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7811, 2903, NULL, 3238, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7812, 853, NULL, 3238, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7813, 497, NULL, 3238, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7814, 5645, NULL, 3239, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7815, 3932, NULL, 3239, 10);
INSERT INTO 'tunesrecordingsmap' VALUES (7816, 5646, NULL, 3239, 11);
INSERT INTO 'tunesrecordingsmap' VALUES (7817, 5647, NULL, 3239, 12);
INSERT INTO 'tunesrecordingsmap' VALUES (7818, 5648, NULL, 3239, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7819, 2457, NULL, 3239, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7820, 347, NULL, 3239, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7821, 5649, NULL, 3239, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7822, 5650, NULL, 3239, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7823, 2609, NULL, 3239, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (7824, 5651, NULL, 3240, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7825, 5652, NULL, 3240, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7826, 3310, NULL, 3240, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16998, 3178, NULL, 488, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16999, 8499, NULL, 488, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17000, 760, NULL, 489, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17001, 2358, NULL, 489, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17002, 2975, NULL, 489, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17003, 7704, NULL, 489, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17004, 8380, NULL, 490, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17005, 5560, NULL, 490, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17006, 4907, NULL, 490, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17007, 3629, NULL, 490, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17008, 8472, NULL, 491, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17009, 8500, NULL, 491, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17010, 8501, NULL, 491, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17011, 8502, NULL, 491, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17012, 8473, NULL, 492, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17013, 8503, NULL, 492, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16974, 283, NULL, 480, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16976, 6672, NULL, 480, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16975, 1261, NULL, 480, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16978, 4236, NULL, 481, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16977, 1648, NULL, 481, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16979, 8495, NULL, 481, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16980, 124, NULL, 482, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16982, 2577, NULL, 482, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16983, 4955, NULL, 483, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16984, 8496, NULL, 483, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16986, 1514, NULL, 484, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16985, 7458, NULL, 484, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16987, 3363, NULL, 484, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16969, 1012, NULL, 3120, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17014, 5953, NULL, 492, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17015, 8504, NULL, 492, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17016, 8474, NULL, 493, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17017, 20, NULL, 493, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17018, 7069, NULL, 493, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17019, 8505, NULL, 493, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17020, 2980, NULL, 494, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17021, 3243, NULL, 494, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17022, 8507, NULL, 494, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17023, 3330, NULL, 495, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17024, 1722, NULL, 495, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17025, 8508, NULL, 495, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17026, 8509, NULL, 495, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17027, 7436, NULL, 1714, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17028, 6396, NULL, 1714, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17029, 5933, NULL, 1714, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17030, 1782, NULL, 1714, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7775, 760, NULL, 1096, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7772, 3980, NULL, 1096, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17031, 5837, NULL, 2037, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17032, 4904, NULL, 2037, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7773, 5636, NULL, 1096, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7774, 1020, NULL, 1096, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16959, 8457, NULL, 5450, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16965, 8462, NULL, 5452, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16964, 8461, NULL, 5452, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16967, 8464, NULL, 5452, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17035, 8510, NULL, 2908, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17036, 2221, NULL, 2908, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17037, 2531, NULL, 2908, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17038, 812, NULL, 2908, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29229, 10230, NULL, 9109, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29230, 10864, NULL, 9109, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29231, 12180, NULL, 9109, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29232, 12364, NULL, 9109, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29258, 12373, NULL, 9119, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29259, 12374, NULL, 9119, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7827, 423, NULL, 3241, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7828, 5653, NULL, 3241, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7829, 1319, NULL, 3241, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7830, 4382, NULL, 3241, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32802, 2492, NULL, 10159, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7835, 236, NULL, 1636, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7836, 5656, NULL, 1636, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7837, 78, NULL, 1636, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7838, 318, NULL, 1637, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7839, 1328, NULL, 1637, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7840, 1219, NULL, 1637, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7841, 1788, NULL, 1638, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7842, 2544, NULL, 1638, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7843, 562, NULL, 1639, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7844, 5657, NULL, 1639, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7845, 5658, NULL, 1639, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7846, 1687, NULL, 1640, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7847, 5659, NULL, 1640, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7848, 1589, NULL, 1640, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7849, 3912, NULL, 1641, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7850, 5078, NULL, 1641, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7851, 312, NULL, 1641, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7852, 1226, NULL, 1642, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7853, 5660, NULL, 1643, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7854, 5661, NULL, 1643, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7855, 3068, NULL, 1643, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7856, 5075, NULL, 1645, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7857, 5663, NULL, 1645, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7887, 2981, NULL, 3251, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7886, 2369, NULL, 3251, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7888, 5666, NULL, 3251, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17046, 8515, NULL, 4124, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7878, 3745, NULL, 3248, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7879, 3746, NULL, 3248, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7880, 3745, NULL, 3249, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7881, 5664, NULL, 3249, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7882, 4650, NULL, 3250, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7883, 320, NULL, 3250, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7884, 761, NULL, 3250, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7885, 1581, NULL, 3250, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7890, 757, NULL, 3252, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7891, 5667, NULL, 3252, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7892, 2532, NULL, 3252, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7893, 123, NULL, 3252, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7901, 2680, NULL, 3255, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7902, 5671, NULL, 3255, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7903, 3642, NULL, 3255, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7904, 2167, NULL, 3255, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7905, 5672, NULL, 3256, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7906, 2973, NULL, 3257, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7907, 3016, NULL, 3257, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7908, 2577, NULL, 3239, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7909, 2577, NULL, 2309, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (7910, 1009, NULL, 3263, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7911, 2024, NULL, 3263, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7912, 2755, NULL, 3263, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7913, 2431, NULL, 3263, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7914, 897, NULL, 1742, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7915, 2180, NULL, 1742, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7916, 4350, NULL, 1742, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7917, 332, NULL, 1742, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7918, 3553, NULL, 1742, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17052, 1527, NULL, 5467, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17053, 186, NULL, 5467, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17058, 8240, NULL, 5469, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17059, 8517, NULL, 5469, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17060, 8518, NULL, 5469, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17061, 8519, NULL, 5469, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17062, 1046, NULL, 5470, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17063, 164, NULL, 5470, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17064, 2381, NULL, 5470, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17065, 2366, NULL, 5470, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17066, 7067, NULL, 5471, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17067, 674, NULL, 5471, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17068, 8520, NULL, 5471, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17069, 7942, NULL, 5471, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17070, 5778, NULL, 5472, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17071, 5779, NULL, 5472, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17072, 188, NULL, 5473, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17073, 1264, NULL, 5473, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17074, 8521, NULL, 5473, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17075, 8522, NULL, 5473, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17076, 8523, NULL, 5474, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17077, 8524, NULL, 5474, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17078, 8525, NULL, 5474, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17079, 2319, NULL, 5474, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17080, 1462, NULL, 3291, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17081, 7914, NULL, 271, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17083, 1291, NULL, 4702, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29260, 12375, NULL, 9120, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29261, 12376, NULL, 9120, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7919, 650, NULL, 1742, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7920, 2162, NULL, 1742, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7921, 1782, NULL, 821, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7922, 1371, NULL, 3332, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7923, 2497, NULL, 3332, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7924, 1964, NULL, 3332, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7925, 5712, NULL, 3289, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7926, 2430, NULL, 3289, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7927, 2532, NULL, 3289, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7932, 4555, NULL, 3291, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7933, 2550, NULL, 3291, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7861, 312, NULL, 3243, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7860, 688, NULL, 3243, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7858, 864, NULL, 3243, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7859, 1716, NULL, 3243, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7866, 141, NULL, 3245, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7868, 5185, NULL, 3245, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7869, 664, NULL, 3245, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7872, 78, NULL, 3246, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7870, 614, NULL, 3246, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7871, 1049, NULL, 3246, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7873, 2702, NULL, 3246, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7875, 1940, NULL, 3247, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7876, 4746, NULL, 3247, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7877, 2536, NULL, 3247, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7874, 1329, NULL, 3247, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17043, 8238, NULL, 4124, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17044, 8514, NULL, 4124, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27275, 11760, NULL, 8406, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27274, 11759, NULL, 8406, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8074, 5757, NULL, 2697, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8073, 2249, NULL, 2697, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7934, 949, NULL, 3291, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7935, 377, NULL, 3292, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7936, 2037, NULL, 3292, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7937, 317, NULL, 3292, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7938, 2180, NULL, 3292, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7939, 1882, NULL, 3293, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7940, 1988, NULL, 3293, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7941, 2538, NULL, 3293, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7942, 3027, NULL, 3293, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7943, 1585, NULL, 3294, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7944, 3830, NULL, 3294, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7945, 3014, NULL, 3294, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7946, 5714, NULL, 3295, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7947, 5715, NULL, 3295, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7948, 958, NULL, 3296, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7949, 2481, NULL, 3296, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7950, 5716, NULL, 3296, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7951, 1781, NULL, 3297, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7952, 2691, NULL, 3297, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7953, 1976, NULL, 3297, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7954, 3222, NULL, 3297, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33078, 13932, NULL, 10225, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17041, 8512, NULL, 3915, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17040, 8511, NULL, 3915, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7833, 93, NULL, 3242, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7832, 5654, NULL, 3242, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7831, 3884, NULL, 3242, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17034, 6462, NULL, 2037, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17033, 2788, NULL, 2037, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17039, 4176, NULL, 3915, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7955, 698, NULL, 3298, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7956, 5717, NULL, 3298, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7957, 599, NULL, 3298, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7958, 5718, NULL, 3298, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7959, 825, NULL, 3299, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7960, 711, NULL, 3299, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7961, 332, NULL, 3299, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7962, 58, NULL, 3299, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7963, 1096, NULL, 3300, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7964, 2556, NULL, 3300, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7965, 3145, NULL, 3300, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7966, 5719, NULL, 3300, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7967, 128, NULL, 3301, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7968, 914, NULL, 3301, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7969, 5525, NULL, 3301, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7970, 2945, NULL, 3301, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7971, 216, NULL, 3302, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7972, 3113, NULL, 3302, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7973, 3832, NULL, 3302, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7974, 448, NULL, 3303, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7975, 2332, NULL, 3303, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7976, 4772, NULL, 3303, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7977, 5720, NULL, 3303, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7978, 5721, NULL, 3303, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7979, 5563, NULL, 3303, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7980, 3363, NULL, 3303, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32804, 773, NULL, 10160, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7982, 3028, NULL, 3272, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7983, 3363, NULL, 3272, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7984, 2592, NULL, 3272, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7985, 4382, NULL, 3272, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7986, 698, NULL, 3273, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7987, 5722, NULL, 3273, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7988, 1578, NULL, 3273, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7989, 533, NULL, 3273, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7990, 1567, NULL, 3274, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7991, 1778, NULL, 3274, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7992, 688, NULL, 3274, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7993, 1485, NULL, 3274, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7994, 876, NULL, 3275, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7995, 1319, NULL, 3275, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7996, 1226, NULL, 3275, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7997, 2454, NULL, 3276, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17082, 1291, NULL, 5216, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17057, 3632, NULL, 5468, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17054, 3713, NULL, 5468, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17056, 8516, NULL, 5468, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17055, 2929, NULL, 5468, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7931, 803, NULL, 3290, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7929, 5786, NULL, 3290, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7930, 219, NULL, 3290, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7900, 5670, NULL, 3254, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7898, 5668, NULL, 3254, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7899, 5669, NULL, 3254, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17051, 1897, NULL, 5466, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7998, 2571, NULL, 3276, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7999, 5723, NULL, 3276, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8000, 128, NULL, 3277, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8001, 648, NULL, 3277, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8002, 4374, NULL, 3277, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8003, 187, NULL, 3277, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8004, 1590, NULL, 3278, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8005, 1988, NULL, 3278, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8006, 1781, NULL, 3278, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8007, 281, NULL, 3278, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8008, 3600, NULL, 3279, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8009, 5724, NULL, 3279, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8010, 1514, NULL, 3279, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8011, 5131, NULL, 3279, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8012, 113, NULL, 3280, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8013, 4642, NULL, 3280, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8014, 1115, NULL, 3281, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8015, 2263, NULL, 3281, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8016, 626, NULL, 3282, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8017, 664, NULL, 3282, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8018, 652, NULL, 3282, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8019, 5725, NULL, 3334, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8020, 664, NULL, 3334, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8021, 5726, NULL, 3335, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8022, 5727, NULL, 3335, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8023, 220, NULL, 3337, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8024, 1926, NULL, 3337, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8025, 5728, NULL, 3339, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8026, 4112, NULL, 3340, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8027, 5729, NULL, 3340, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8028, 5730, NULL, 3341, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8029, 5731, NULL, 3341, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8030, 5732, NULL, 3341, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8031, 5733, NULL, 3341, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8032, 5734, NULL, 3341, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8033, 1781, NULL, 3342, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8034, 1965, NULL, 3342, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8035, 1880, NULL, 3342, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8036, 2336, NULL, 3342, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8037, 5735, NULL, 3343, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8038, 1042, NULL, 3343, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8039, 2442, NULL, 3343, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8040, 5736, NULL, 3344, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8041, 5737, NULL, 3344, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8042, 5738, NULL, 3346, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8043, 5739, NULL, 3346, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8044, 5740, NULL, 3347, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8045, 5741, NULL, 3348, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8046, 1503, NULL, 3348, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8047, 5742, NULL, 3349, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8048, 5743, NULL, 3350, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17084, 1291, NULL, 4906, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17087, 2762, NULL, 3532, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17088, 2762, NULL, 3213, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17089, 6839, NULL, 2438, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17090, 2635, NULL, 1912, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17091, 2635, NULL, 1194, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17092, 1464, NULL, 3200, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17093, 5773, NULL, 5434, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17094, 6115, NULL, 5443, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17095, 1171, NULL, 5475, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17096, 1238, NULL, 5475, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17097, 8748, NULL, 5475, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17098, 8749, NULL, 5475, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17099, 5490, NULL, 5475, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29262, 10783, NULL, 9121, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8049, 5744, NULL, 2696, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8050, 5745, NULL, 2696, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8051, 5746, NULL, 2696, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8052, 5747, NULL, 2696, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8053, 2323, NULL, 3352, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8054, 5748, NULL, 3352, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8055, 283, NULL, 2693, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8056, 5749, NULL, 2693, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8057, 5750, NULL, 2693, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8058, 5751, NULL, 2693, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8059, 993, NULL, 2575, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8060, 4741, NULL, 2575, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8061, 5752, NULL, 2575, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8062, 4034, NULL, 2575, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8063, 750, NULL, 3354, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8064, 5753, NULL, 3354, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8065, 90, NULL, 3354, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8066, 5754, NULL, 3354, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8067, 5755, NULL, 3355, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8068, 5756, NULL, 3355, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8069, 448, NULL, 2695, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8070, 2773, NULL, 2695, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8071, 2386, NULL, 2695, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8072, 757, NULL, 2695, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8077, 5759, NULL, 2694, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8078, 5760, NULL, 2694, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8079, 5761, NULL, 2694, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8080, 3650, NULL, 2698, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8081, 5762, NULL, 2698, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8082, 5763, NULL, 2698, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8083, 5764, NULL, 2698, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8084, 5765, NULL, 1823, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8085, 2554, NULL, 1823, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8086, 2661, NULL, 1823, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8087, 2113, NULL, 1823, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8088, 5766, NULL, 1824, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8089, 5767, NULL, 1824, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8090, 5768, NULL, 1824, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8091, 5380, NULL, 1824, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8092, 4109, NULL, 1825, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8093, 1527, NULL, 1825, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8094, 3113, NULL, 1825, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8095, 4026, NULL, 1825, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8096, 5769, NULL, 1826, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8097, 5770, NULL, 1826, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8098, 5308, NULL, 1826, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8099, 3394, NULL, 1826, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8100, 5771, NULL, 1827, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8101, 5772, NULL, 1827, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8102, 5773, NULL, 1827, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8103, 890, NULL, 1827, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8104, 609, NULL, 1828, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8105, 5774, NULL, 1828, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8106, 5775, NULL, 1828, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8107, 2317, NULL, 1828, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8108, 474, NULL, 1829, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8109, 3519, NULL, 1830, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8110, 3520, NULL, 1830, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8111, 2218, NULL, 1830, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8112, 2721, NULL, 1830, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8113, 2177, NULL, 1830, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8114, 3157, NULL, 1830, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (8115, 5776, NULL, 1830, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (8116, 5777, NULL, 1830, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32805, 1208, NULL, 10160, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33075, 3612, NULL, 10224, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8119, 5780, NULL, 1832, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8120, 5781, NULL, 1832, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8121, 5782, NULL, 1832, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8122, 5783, NULL, 1833, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8123, 104, NULL, 1833, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8124, 2057, NULL, 1833, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8125, 4494, NULL, 1834, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8126, 5784, NULL, 1834, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8127, 5785, NULL, 1834, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8128, 4221, NULL, 1835, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8129, 1067, NULL, 1835, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8130, 3568, NULL, 1835, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8131, 1118, NULL, 1835, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8132, 3465, NULL, 1836, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8133, 1386, NULL, 1836, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8134, 2399, NULL, 1836, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8135, 1181, NULL, 1836, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8136, 4520, NULL, 1837, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8137, 1722, NULL, 1837, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8138, 3885, NULL, 1837, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8139, 5786, NULL, 2413, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8140, 4637, NULL, 2413, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8141, 3021, NULL, 2413, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17100, 8750, NULL, 5475, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17101, 8751, NULL, 5475, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17102, 206, NULL, 5476, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17103, 8752, NULL, 5476, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17104, 8753, NULL, 5476, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17105, 8754, NULL, 5476, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17106, 8755, NULL, 5476, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17107, 7537, NULL, 5476, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17108, 8756, NULL, 5476, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17119, 8761, NULL, 5479, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17120, 8762, NULL, 5479, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17121, 8763, NULL, 5479, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17136, 3749, NULL, 5483, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17137, 8772, NULL, 5483, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17138, 8773, NULL, 5483, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17139, 8774, NULL, 5483, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17140, 6378, NULL, 5483, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17141, 8775, NULL, 5484, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29263, 10907, NULL, 9121, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8142, 318, NULL, 2414, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8143, 5787, NULL, 2414, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8144, 5788, NULL, 2414, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8145, 2218, NULL, 2414, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8146, 179, NULL, 2415, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8147, 1301, NULL, 2415, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8148, 2791, NULL, 2415, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8149, 1122, NULL, 2415, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8154, 2021, NULL, 2417, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8155, 1068, NULL, 2417, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8156, 5790, NULL, 2417, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8157, 1154, NULL, 2417, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8158, 4216, NULL, 2418, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8159, 1348, NULL, 2418, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8160, 2151, NULL, 2418, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8161, 2312, NULL, 2418, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8162, 992, NULL, 2419, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8163, 5791, NULL, 2419, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8164, 5792, NULL, 2419, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8165, 5793, NULL, 2420, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8166, 5794, NULL, 2420, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8167, 5795, NULL, 2420, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8168, 1084, NULL, 1581, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8169, 679, NULL, 1581, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8170, 892, NULL, 2530, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8171, 4088, NULL, 2530, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8172, 5043, NULL, 3200, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8173, 1965, NULL, 1683, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8174, 2524, NULL, 1683, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8175, 1535, NULL, 1687, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8176, 803, NULL, 1687, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8177, 5796, NULL, 1687, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8178, 778, NULL, 1687, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8179, 5797, NULL, 3360, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8180, 5798, NULL, 3360, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8181, 5271, NULL, 3360, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8182, 5799, NULL, 3360, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8183, 5800, NULL, 3361, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8188, 4913, NULL, 3363, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8189, 5803, NULL, 3363, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8190, 5804, NULL, 3363, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8191, 98, NULL, 3364, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8192, 709, NULL, 3364, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8193, 5805, NULL, 3364, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8194, 152, NULL, 3365, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8195, 295, NULL, 3365, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8196, 3915, NULL, 3365, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8197, 2730, NULL, 3365, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8198, 5806, NULL, 3366, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8199, 2178, NULL, 3366, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8200, 4740, NULL, 3366, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8201, 1588, NULL, 3367, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8202, 5807, NULL, 3367, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8203, 1814, NULL, 3367, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8204, 408, NULL, 3368, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8205, 1443, NULL, 3369, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8206, 382, NULL, 3370, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8207, 1553, NULL, 3370, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8208, 5808, NULL, 3370, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8209, 1942, NULL, 3371, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8210, 2786, NULL, 3371, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8211, 750, NULL, 3371, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8212, 82, NULL, 3372, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8213, 2806, NULL, 3372, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8214, 4317, NULL, 3372, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8215, 5123, NULL, 3373, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8216, 1373, NULL, 3373, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8217, 1884, NULL, 3373, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8218, 132, NULL, 3374, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8219, 5262, NULL, 3375, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8220, 833, NULL, 3375, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8221, 1091, NULL, 3375, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8222, 727, NULL, 3376, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8223, 2879, NULL, 3376, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8224, 2878, NULL, 3376, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8225, 188, NULL, 3376, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8226, 100, NULL, 538, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8227, 405, NULL, 538, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8228, 5036, NULL, 538, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8229, 3744, NULL, 538, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8230, 2668, NULL, 539, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8231, 2063, NULL, 539, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8232, 1455, NULL, 539, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8233, 3572, NULL, 539, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17149, 2279, NULL, 5487, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17150, 5562, NULL, 5487, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17151, 3865, NULL, 5487, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17152, 1328, NULL, 5487, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17135, 8771, NULL, 5482, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17134, 8770, NULL, 5482, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17133, 8769, NULL, 5482, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17156, 1672, NULL, 5489, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17157, 5416, NULL, 5489, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17158, 8782, NULL, 5489, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17159, 4401, NULL, 5489, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17160, 8602, NULL, 5489, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17161, 8783, NULL, 5489, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17162, 2903, NULL, 5489, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17168, 807, NULL, 5491, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17169, 6467, NULL, 5491, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17170, 8498, NULL, 5491, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17171, 8790, NULL, 5491, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17172, 1748, NULL, 5491, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17173, 3199, NULL, 5491, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17174, 8791, NULL, 5491, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17175, 5207, NULL, 5491, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (17181, 4677, NULL, 5493, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17182, 792, NULL, 5493, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17183, 1241, NULL, 5493, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17142, 8776, NULL, 5485, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17143, 5103, NULL, 5485, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17144, 8777, NULL, 5485, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17155, 4113, NULL, 5488, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17153, 2241, NULL, 5488, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17154, 8781, NULL, 5488, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8184, 199, NULL, 3362, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8185, 1845, 568, 3362, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8186, 5801, NULL, 3362, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8151, 3400, NULL, 2416, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8153, 1395, NULL, 2416, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8152, 5789, NULL, 2416, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8150, 1744, NULL, 2416, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17126, 338, NULL, 5480, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17125, 728, NULL, 5480, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17124, 932, NULL, 5480, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17184, 8794, NULL, 5493, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8234, 1902, NULL, 540, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8235, 5809, NULL, 540, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8236, 5671, NULL, 541, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8237, 5810, NULL, 542, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8238, 5811, NULL, 542, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8239, 5812, NULL, 542, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8240, 2178, NULL, 542, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8241, 5813, NULL, 542, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8242, 1334, NULL, 543, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8243, 5312, NULL, 543, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8244, 2635, NULL, 543, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8245, 650, NULL, 543, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8246, 2635, NULL, 1944, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8247, 958, NULL, 544, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8248, 2998, NULL, 544, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8249, 5814, NULL, 544, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8250, 2304, NULL, 544, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8251, 1389, NULL, 545, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8252, 608, NULL, 545, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8253, 90, NULL, 545, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8254, 5815, NULL, 545, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8255, 4134, NULL, 546, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8256, 872, NULL, 547, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8257, 123, NULL, 547, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8258, 2532, NULL, 547, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8259, 688, NULL, 547, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32822, 13850, NULL, 10166, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8263, 5816, NULL, 549, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8264, 5466, NULL, 549, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8265, 2855, NULL, 549, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8266, 360, NULL, 550, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8267, 3436, NULL, 550, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8268, 4833, NULL, 550, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8269, 2418, NULL, 550, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8270, 589, NULL, 551, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8271, 206, NULL, 551, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8272, 2113, NULL, 551, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8273, 2379, NULL, 551, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8274, 4597, NULL, 3377, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8275, 4596, NULL, 3378, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8276, 283, NULL, 3379, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8277, 4598, NULL, 3380, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8278, 5817, NULL, 3381, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8279, 5716, NULL, 1511, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8281, 5738, NULL, 1518, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8282, 73, NULL, 1518, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8283, 81, NULL, 3382, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17179, 2452, NULL, 5492, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17177, 3077, NULL, 5492, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17178, 8792, NULL, 5492, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29268, 5667, NULL, 9122, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29267, 12378, NULL, 9122, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29265, 12377, NULL, 9122, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29266, 1505, NULL, 9122, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17164, 892, NULL, 5490, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17163, 8784, NULL, 5490, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17165, 8786, NULL, 5490, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17167, 1194, NULL, 5490, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17166, 8787, NULL, 5490, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8284, 426, NULL, 3382, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8285, 5818, NULL, 3382, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8286, 548, NULL, 3383, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8287, 2104, NULL, 3383, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8288, 355, NULL, 3383, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8289, 1830, NULL, 3384, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8290, 1880, NULL, 3384, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8291, 3591, NULL, 3384, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8292, 628, NULL, 3385, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8293, 2203, NULL, 3385, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8294, 32, NULL, 3385, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8295, 761, NULL, 3386, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8296, 1687, NULL, 3386, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8297, 398, NULL, 3386, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8298, 5819, NULL, 3387, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8299, 5820, NULL, 3388, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8300, 251, NULL, 3389, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8301, 307, NULL, 3389, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8302, 2379, NULL, 3389, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8303, 2963, NULL, 3390, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8304, 5822, NULL, 3390, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8305, 5823, NULL, 3390, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8306, 958, NULL, 3391, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8307, 5824, NULL, 3391, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8308, 4219, NULL, 3283, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8309, 5826, NULL, 3283, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8310, 5827, NULL, 3283, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8311, 3307, NULL, 3284, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8312, 4194, NULL, 3285, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8313, 5828, NULL, 3285, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8314, 5088, NULL, 3285, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8315, 4475, NULL, 3286, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8316, 3990, NULL, 3287, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8317, 2223, NULL, 3287, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8318, 5829, NULL, 3287, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8319, 3856, NULL, 3288, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8320, 5830, NULL, 3288, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8321, 2442, NULL, 3288, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8322, 5831, NULL, 3233, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8323, 3525, NULL, 2305, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8324, 1585, NULL, 2310, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (8325, 5832, NULL, 2309, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8326, 3246, NULL, 3392, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17185, 1036, NULL, 5494, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17186, 2641, NULL, 5494, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17187, 2641, NULL, 4147, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17188, 3754, NULL, 5494, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17189, 7094, NULL, 5494, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17190, 2948, NULL, 5495, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17191, 1745, NULL, 5495, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17192, 8795, NULL, 5495, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17193, 4283, NULL, 5495, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17194, 1020, NULL, 5496, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17195, 2762, NULL, 5496, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17196, 1566, NULL, 5496, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17197, 8796, NULL, 5496, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17198, 8788, NULL, 5496, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8280, 1843, NULL, 1522, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17207, 749, NULL, 5499, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17208, 6962, NULL, 5499, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17209, 8800, NULL, 5499, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17210, 6090, NULL, 5499, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17211, 8801, NULL, 5499, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17212, 4402, NULL, 5499, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17213, 7021, NULL, 5499, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17214, 8802, NULL, 5499, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (17215, 7548, NULL, 5500, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17216, 8803, NULL, 5500, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17217, 8804, NULL, 5500, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17218, 5581, NULL, 5500, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17223, 3613, NULL, 5502, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17224, 8806, NULL, 5502, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17225, 8807, NULL, 5502, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17226, 8808, NULL, 5502, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29269, 12379, NULL, 9123, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29270, 12380, NULL, 9123, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8327, 5833, NULL, 3392, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8328, 5834, NULL, 3392, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8329, 5835, NULL, 3392, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8330, 1533, NULL, 3393, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8331, 2202, NULL, 3393, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8332, 2203, NULL, 3393, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8333, 4490, NULL, 3393, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8334, 261, NULL, 3394, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8335, 1609, NULL, 3394, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8336, 2489, NULL, 3394, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8337, 834, NULL, 3394, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17202, 8797, NULL, 5497, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17201, 7305, NULL, 5497, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17200, 7293, NULL, 5497, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8338, 769, NULL, 3395, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8339, 5161, NULL, 3395, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8340, 1894, NULL, 3395, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8341, 1158, NULL, 3396, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8342, 38, NULL, 3396, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8343, 5836, NULL, 3396, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8344, 2060, NULL, 3396, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8345, 5837, NULL, 3396, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8346, 3910, NULL, 3397, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8347, 2031, NULL, 3397, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8348, 2990, NULL, 3397, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8349, 5838, NULL, 3397, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8350, 544, NULL, 3398, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8351, 2399, NULL, 3398, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8352, 5840, NULL, 3398, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8353, 1391, NULL, 3399, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8354, 403, NULL, 3399, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8355, 2544, NULL, 3399, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8356, 3033, NULL, 3399, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8357, 408, NULL, 3400, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8358, 5841, NULL, 3401, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8359, 5842, NULL, 3401, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8360, 5843, NULL, 3401, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8361, 5844, NULL, 3401, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8362, 5845, NULL, 3401, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8364, 5154, NULL, 541, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8365, 1781, NULL, 3402, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8366, 3885, NULL, 3402, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8367, 1954, NULL, 3402, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8368, 5846, NULL, 3402, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8369, 1059, NULL, 3403, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8370, 1514, NULL, 3403, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8371, 660, NULL, 3403, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8372, 133, NULL, 3403, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8373, 1485, NULL, 3403, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8374, 709, NULL, 3403, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (8375, 5847, NULL, 3403, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (8376, 5024, NULL, 3403, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (8377, 1651, NULL, 783, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8378, 5848, NULL, 783, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8379, 1413, NULL, 783, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8380, 3245, NULL, 783, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8381, 149, NULL, 2528, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8382, 4094, NULL, 2528, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8383, 3246, NULL, 2528, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8384, 2577, NULL, 3422, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8385, 5849, NULL, 3422, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8386, 477, NULL, 3422, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8387, 3384, NULL, 3422, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8388, 135, NULL, 3423, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8389, 2877, NULL, 3423, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8390, 2921, NULL, 3423, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8391, 3199, NULL, 3423, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8392, 401, NULL, 3424, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8393, 3178, NULL, 3424, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8394, 3265, NULL, 3424, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8395, 658, NULL, 3424, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8396, 3257, NULL, 3425, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8397, 996, NULL, 3425, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8398, 157, NULL, 3426, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8399, 3244, NULL, 3426, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8404, 1212, NULL, 3428, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8405, 985, NULL, 3428, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8406, 266, NULL, 3428, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8407, 1249, NULL, 3428, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8408, 1626, NULL, 3429, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8409, 1755, NULL, 3429, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8410, 1810, NULL, 3429, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8411, 4558, NULL, 3429, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8412, 1085, NULL, 3430, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8413, 5851, NULL, 3430, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8414, 11, NULL, 3430, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8415, 1403, NULL, 3430, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8416, 2850, NULL, 3431, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8417, 463, NULL, 3431, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8418, 5852, NULL, 3431, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17227, 281, NULL, 5503, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17228, 3536, NULL, 5503, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17229, 4457, NULL, 5503, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17230, 5511, NULL, 5503, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17231, 203, NULL, 5504, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17232, 1651, NULL, 5504, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17233, 5905, NULL, 5504, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17234, 3262, NULL, 5504, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17235, 243, NULL, 5505, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17236, 8810, NULL, 5505, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17237, 8811, NULL, 5505, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17238, 8812, NULL, 5505, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8402, 2980, NULL, 3427, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8403, 2378, NULL, 3427, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8401, 5850, NULL, 3427, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17246, 1303, NULL, 5507, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17247, 4830, NULL, 5507, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17248, 1359, NULL, 5507, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17249, 2516, NULL, 5507, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17250, 4974, NULL, 5507, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17251, 2623, NULL, 5507, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17252, 2517, NULL, 5507, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17253, 1714, NULL, 5508, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17254, 2863, NULL, 5508, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17255, 4413, NULL, 5508, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17256, 2152, NULL, 5508, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17257, 7263, NULL, 5508, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17258, 2525, NULL, 5508, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17259, 8815, NULL, 5508, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17260, 54, NULL, 5509, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17261, 1024, NULL, 5509, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17262, 743, NULL, 5509, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17263, 8816, NULL, 5509, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17264, 4551, NULL, 5509, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17265, 8817, NULL, 5509, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17266, 285, NULL, 5509, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17267, 329, NULL, 5510, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17268, 8818, NULL, 5510, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29271, 12381, NULL, 9124, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8419, 1311, NULL, 3431, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8424, 4632, NULL, 3433, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8425, 2939, NULL, 3433, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8426, 1663, NULL, 3434, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8427, 2066, NULL, 3434, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8428, 5187, NULL, 3434, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8429, 796, NULL, 3434, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8430, 38, NULL, 3435, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8431, 3247, NULL, 3435, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8432, 1095, NULL, 3436, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8433, 914, NULL, 3436, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8434, 133, NULL, 3436, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8435, 2386, NULL, 3436, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8440, 4260, NULL, 3438, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8441, 2257, NULL, 3438, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8442, 5855, NULL, 3438, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8443, 5856, NULL, 3438, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8444, 1672, NULL, 3439, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8445, 3431, NULL, 3439, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8446, 4615, NULL, 3439, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8447, 5857, NULL, 3439, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8448, 1154, NULL, 3440, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8449, 2996, NULL, 3440, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8450, 2616, NULL, 3440, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8451, 2929, NULL, 3440, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33074, 9913, NULL, 10224, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33073, 13931, NULL, 10224, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32849, 13859, NULL, 10161, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8075, 13969, NULL, 2697, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8456, 1741, NULL, 3442, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8457, 2061, NULL, 3442, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8458, 1498, NULL, 3442, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8459, 382, NULL, 3443, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8460, 497, NULL, 3443, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8461, 1091, NULL, 3443, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8462, 1629, NULL, 3443, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8463, 1329, NULL, 3443, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8464, 424, NULL, 3443, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (8465, 1503, NULL, 3443, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (8466, 49, NULL, 3443, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (8467, 598, NULL, 3443, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (8468, 1293, NULL, 3444, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8469, 1261, NULL, 3444, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8470, 2021, NULL, 3445, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8471, 5860, NULL, 3445, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8472, 5861, NULL, 3445, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8473, 1624, NULL, 3446, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8474, 182, NULL, 3446, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8475, 4323, NULL, 3446, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8476, 904, NULL, 3447, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8477, 1472, NULL, 3447, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8478, 2930, NULL, 3447, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8479, 5862, NULL, 3447, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8363, 5154, NULL, 43, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8436, 248, NULL, 3437, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8439, 4716, NULL, 3437, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8438, 5390, NULL, 3437, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8484, 84, NULL, 3449, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8485, 4635, NULL, 3449, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8486, 1117, NULL, 3449, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8487, 923, NULL, 3450, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8488, 5864, NULL, 3450, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8489, 5865, NULL, 3450, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8490, 5866, NULL, 3450, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8491, 705, NULL, 3451, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8492, 1020, NULL, 3451, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8493, 2093, NULL, 3451, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8494, 1447, NULL, 3451, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8495, 31, NULL, 3452, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8496, 1636, NULL, 3452, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8497, 1979, NULL, 3452, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8498, 2728, NULL, 3452, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8499, 1209, NULL, 3453, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8500, 5867, NULL, 3453, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8501, 5850, NULL, 3453, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8502, 5868, NULL, 3453, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8503, 381, NULL, 3454, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8504, 5869, NULL, 3454, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8505, 2136, NULL, 3454, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8506, 5870, NULL, 3454, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8507, 1662, NULL, 3455, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8508, 2864, NULL, 3455, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8509, 1875, NULL, 3455, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8510, 3195, NULL, 3455, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8511, 1223, NULL, 3456, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8512, 290, NULL, 3456, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8513, 1624, NULL, 3456, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8514, 3394, NULL, 3456, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8515, 456, NULL, 3456, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8516, 1472, NULL, 3456, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (8517, 2413, NULL, 3456, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (8518, 146, NULL, 3456, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (8519, 720, NULL, 3457, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8520, 3076, NULL, 3457, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8521, 5871, NULL, 3457, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8522, 5872, NULL, 3457, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8523, 5873, NULL, 3457, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8524, 5874, NULL, 3457, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (8525, 5875, NULL, 3457, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (8526, 614, NULL, 3458, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8527, 5876, NULL, 3458, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8528, 5877, NULL, 3458, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8529, 5878, NULL, 3458, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8530, 1317, NULL, 3459, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8531, 5879, NULL, 3459, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8532, 2516, NULL, 3459, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8533, 2428, NULL, 3459, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8534, 1188, NULL, 3460, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8535, 5880, NULL, 3460, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8536, 5881, NULL, 3460, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8537, 2405, NULL, 3460, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8538, 1171, NULL, 3461, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8539, 4833, NULL, 3461, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8540, 90, NULL, 3461, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8541, 2089, NULL, 3461, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8546, 899, NULL, 3463, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8547, 4401, NULL, 3463, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8548, 3154, NULL, 3463, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17269, 8819, NULL, 5510, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17270, 4065, NULL, 5510, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17271, 1429, NULL, 5511, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17272, 3794, NULL, 5511, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17273, 8820, NULL, 5511, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17274, 8821, NULL, 5511, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17275, 8822, NULL, 5511, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17276, 2579, NULL, 5511, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17277, 8823, NULL, 5511, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17278, 1497, NULL, 5512, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17279, 8824, NULL, 5512, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17280, 8825, NULL, 5512, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17281, 2387, NULL, 5512, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17282, 1173, NULL, 5513, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17283, 888, NULL, 5513, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17284, 2568, NULL, 5513, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29272, 12382, NULL, 9125, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8549, 3018, NULL, 3463, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8550, 1284, NULL, 3464, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8551, 2192, NULL, 3464, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8552, 5855, NULL, 3464, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8553, 5856, NULL, 3464, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8554, 3601, NULL, 3465, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8555, 3152, NULL, 3465, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8556, 4959, NULL, 3465, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8557, 377, NULL, 3466, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8558, 5883, NULL, 3466, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8559, 3237, NULL, 3466, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33069, 13930, NULL, 10223, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8564, 169, NULL, 3468, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8565, 5860, NULL, 3468, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8566, 3207, NULL, 3468, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8567, 5886, NULL, 3468, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8568, 1419, NULL, 3468, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8569, 29, NULL, 3469, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8570, 5887, NULL, 3469, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8571, 5888, NULL, 3469, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8572, 5889, NULL, 3469, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8573, 512, NULL, 3470, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8574, 586, NULL, 3470, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8575, 1971, NULL, 3470, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8576, 5890, NULL, 3470, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8581, 1499, NULL, 3472, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8582, 4828, NULL, 3472, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8583, 5854, NULL, 3472, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8584, 238, NULL, 3472, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8585, 1214, NULL, 3473, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8586, 5825, NULL, 3473, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8587, 2057, NULL, 3473, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8588, 2764, NULL, 3473, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8589, 49, NULL, 3474, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8590, 2379, NULL, 3474, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8591, 3513, NULL, 3474, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8592, 5853, NULL, 3474, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8593, 5707, NULL, 3475, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8594, 1880, NULL, 3475, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8595, 2069, NULL, 3475, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8596, 5708, NULL, 3476, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8597, 5891, NULL, 3476, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8598, 816, NULL, 3476, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8599, 5709, NULL, 3477, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8600, 834, NULL, 3477, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8601, 2611, NULL, 3477, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8602, 5892, NULL, 3477, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8603, 5710, NULL, 3478, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8604, 3157, NULL, 3478, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8605, 1920, NULL, 3478, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8606, 1867, NULL, 3478, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8607, 5711, NULL, 3479, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8608, 4103, NULL, 3479, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8609, 5893, NULL, 3479, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8610, 3766, NULL, 3479, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8611, 2829, NULL, 3480, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8612, 1537, NULL, 3480, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8613, 3670, NULL, 3480, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8614, 5894, NULL, 3480, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8615, 1544, NULL, 3481, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8616, 2880, NULL, 3481, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8617, 695, NULL, 3481, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8618, 2830, NULL, 3482, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8619, 1666, NULL, 3482, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8620, 5895, NULL, 3482, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8621, 5896, NULL, 3482, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8630, 1312, NULL, 3485, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8631, 2321, NULL, 3485, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8632, 5899, NULL, 3485, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8633, 2369, NULL, 3485, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8634, 1533, NULL, 3486, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8635, 2037, NULL, 3486, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8636, 2152, NULL, 3486, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8637, 1003, NULL, 3486, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8638, 551, NULL, 3487, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8639, 5900, NULL, 3487, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8640, 5901, NULL, 3487, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8641, 5902, NULL, 3487, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17285, 7949, NULL, 5513, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17286, 2419, NULL, 5513, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17287, 5274, NULL, 5513, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17288, 2415, NULL, 5513, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17289, 1801, NULL, 5514, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17290, 1315, NULL, 5514, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8543, 5882, NULL, 3462, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8542, 997, NULL, 3462, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8544, 3628, NULL, 3462, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8480, 360, NULL, 3448, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8483, 5863, NULL, 3448, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8481, 1575, NULL, 3448, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8482, 2892, NULL, 3448, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8624, 2688, NULL, 3483, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8623, 2912, NULL, 3483, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8625, 3116, NULL, 3483, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17291, 5278, NULL, 5514, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17292, 8826, NULL, 5514, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17293, 8095, NULL, 5514, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17294, 2785, NULL, 5514, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17295, 8827, NULL, 5514, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17296, 1711, NULL, 5515, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17297, 773, NULL, 5515, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17298, 806, NULL, 5515, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17299, 920, NULL, 5515, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17300, 2151, NULL, 5515, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17301, 1825, NULL, 5515, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17302, 3832, NULL, 5515, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17303, 1488, NULL, 5516, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17304, 8828, NULL, 5516, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17305, 8829, NULL, 5516, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17306, 8830, NULL, 5516, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17307, 1733, NULL, 5517, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17308, 8831, NULL, 5517, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17309, 8832, NULL, 5517, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17310, 8833, NULL, 5517, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17311, 8834, NULL, 5517, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17312, 2578, NULL, 5517, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17313, 8835, NULL, 5517, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17314, 2614, NULL, 5518, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17315, 8836, NULL, 5518, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17316, 3207, NULL, 5518, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17317, 2581, NULL, 5518, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17318, 1202, NULL, 5519, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17319, 1156, NULL, 5519, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17320, 898, NULL, 5519, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17321, 2431, NULL, 5519, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17322, 895, NULL, 5519, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17323, 8837, NULL, 5519, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17324, 2427, NULL, 5519, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17325, 327, NULL, 5519, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (17326, 8838, NULL, 5520, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29273, 11227, NULL, 9125, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8642, 1637, NULL, 3488, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8643, 2327, NULL, 3488, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8644, 5903, NULL, 3488, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8645, 1745, NULL, 3488, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8629, 5898, NULL, 3484, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8626, 597, NULL, 3484, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8627, 5897, NULL, 3484, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8628, 1681, NULL, 3484, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8646, 374, NULL, 3532, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8647, 4578, NULL, 3532, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8648, 3390, NULL, 3532, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8649, 2790, NULL, 3532, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8650, 382, NULL, 3533, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8651, 1778, NULL, 3533, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8652, 2773, NULL, 3533, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8653, 2039, NULL, 3533, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8654, 914, NULL, 3533, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8655, 613, NULL, 3533, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (8656, 1648, NULL, 3533, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (8657, 2006, NULL, 3533, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (8658, 2091, NULL, 3533, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (8659, 2321, NULL, 3534, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8660, 2017, NULL, 3534, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8661, 1513, NULL, 3534, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8662, 2016, NULL, 3534, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8663, 2259, NULL, 3534, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8664, 19, NULL, 3534, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (8665, 2321, NULL, 42, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8666, 2321, NULL, 2431, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8667, 2321, NULL, 1297, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8669, 2321, NULL, 2383, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8670, 1528, NULL, 3535, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8671, 2576, NULL, 3535, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8672, 1112, NULL, 3535, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8673, 1638, NULL, 3536, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8674, 4348, NULL, 3536, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8675, 168, NULL, 3536, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8676, 2258, NULL, 3536, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8677, 469, NULL, 3537, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8678, 405, NULL, 3537, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8679, 1041, NULL, 3538, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8680, 2319, NULL, 3538, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8681, 4828, NULL, 3538, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8682, 4176, NULL, 3538, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8683, 430, NULL, 3539, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8684, 4904, NULL, 3539, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8685, 1940, NULL, 3539, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8686, 200, NULL, 3539, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8687, 448, NULL, 3540, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8688, 2954, NULL, 3540, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8689, 2958, NULL, 3540, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8690, 2963, NULL, 3540, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8691, 1593, NULL, 3541, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8692, 2546, NULL, 3541, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8693, 184, NULL, 3541, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8694, 652, NULL, 3541, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8695, 313, NULL, 3542, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8696, 5925, NULL, 3542, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8697, 2178, NULL, 3542, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8698, 5926, NULL, 3542, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8699, 1059, NULL, 3543, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8700, 1514, NULL, 3543, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8701, 3640, NULL, 3543, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8702, 133, NULL, 3543, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8703, 1485, NULL, 3543, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8704, 709, NULL, 3543, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (8705, 5927, NULL, 3543, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (8706, 958, NULL, 3544, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8707, 5928, NULL, 3544, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8709, 162, NULL, 3544, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8710, 1458, NULL, 3545, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8711, 2747, NULL, 3545, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8712, 1896, NULL, 3545, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8713, 3140, NULL, 3545, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8714, 2999, NULL, 3546, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8715, 2897, NULL, 3546, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8716, 3000, NULL, 3546, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8717, 3001, NULL, 3546, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8718, 5929, NULL, 3547, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8719, 2665, NULL, 3547, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8720, 4365, NULL, 3547, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8721, 5930, NULL, 3547, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8722, 3222, NULL, 3489, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8723, 5931, NULL, 3489, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8724, 5932, NULL, 3489, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8725, 5933, NULL, 3489, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8726, 5934, NULL, 3490, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8727, 1386, NULL, 3490, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8728, 389, NULL, 3490, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8729, 996, NULL, 3490, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8730, 2065, NULL, 3491, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8731, 1140, NULL, 3491, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8732, 159, NULL, 3491, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8733, 5935, NULL, 3491, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17327, 3027, NULL, 5520, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17328, 787, NULL, 5520, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17333, 8841, NULL, 5522, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17334, 8842, NULL, 5522, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17335, 8843, NULL, 5522, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17336, 8844, NULL, 5523, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17337, 4833, NULL, 5523, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17338, 3057, NULL, 5523, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17339, 8845, NULL, 5523, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17340, 8846, NULL, 5524, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17341, 1067, NULL, 5524, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17342, 916, NULL, 5524, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17343, 8847, NULL, 5525, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17344, 8848, NULL, 5525, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17345, 8849, NULL, 5526, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17346, 4828, NULL, 5526, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17347, 8850, NULL, 5526, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17348, 8851, NULL, 5526, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17349, 8852, NULL, 5527, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17350, 8853, NULL, 5527, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17351, 8854, NULL, 5528, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17352, 8855, NULL, 5528, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17353, 8856, NULL, 5529, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17354, 6081, NULL, 5544, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17355, 8859, NULL, 5544, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17356, 2827, NULL, 5545, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17357, 2063, NULL, 5545, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17358, 4902, NULL, 5545, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17359, 6762, NULL, 5546, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17360, 6016, NULL, 5546, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17361, 5236, NULL, 5546, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17362, 5212, NULL, 5547, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17363, 5204, NULL, 5547, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17364, 441, NULL, 5548, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17365, 5165, NULL, 5548, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17366, 2155, NULL, 5548, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17367, 644, NULL, 5549, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17368, 1363, NULL, 5549, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17369, 3124, NULL, 5550, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29274, 3682, NULL, 9126, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29275, 12383, NULL, 9126, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29276, 12384, NULL, 9126, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29277, 10214, NULL, 9126, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29278, 12385, NULL, 9126, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8738, 5940, NULL, 3493, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8739, 5941, NULL, 3493, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8740, 1878, NULL, 3494, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8741, 355, NULL, 3494, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8742, 1520, NULL, 3494, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8747, 5945, NULL, 3496, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8748, 5946, NULL, 3496, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8749, 5947, NULL, 3496, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8750, 5948, NULL, 3496, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8751, 1021, NULL, 3497, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8752, 1042, NULL, 3497, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8753, 1707, NULL, 3497, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8754, 2624, NULL, 3498, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8755, 1481, NULL, 3498, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8756, 302, NULL, 3498, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8757, 4791, NULL, 3498, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8762, 1198, NULL, 866, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8764, 3063, NULL, 3500, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8765, 5951, NULL, 3501, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8766, 5826, NULL, 3501, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8767, 5952, NULL, 3501, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8768, 1872, NULL, 3501, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8769, 5953, NULL, 3502, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8770, 3394, NULL, 3502, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8771, 5955, NULL, 3502, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8772, 3033, NULL, 3503, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8773, 2118, NULL, 3503, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8774, 5956, NULL, 3503, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8779, 1457, NULL, 3548, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8780, 1971, NULL, 3548, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8781, 5961, NULL, 3548, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8782, 1660, NULL, 3548, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8783, 389, NULL, 3549, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8784, 312, NULL, 3549, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8785, 76, NULL, 3549, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8786, 1711, NULL, 3550, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8787, 2718, NULL, 3550, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8788, 2534, NULL, 3550, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8789, 1311, NULL, 3550, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8791, 206, NULL, 3552, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8792, 1566, NULL, 3552, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8793, 3215, NULL, 3552, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8794, 2258, NULL, 3552, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8795, 487, NULL, 2004, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17332, 8840, NULL, 5521, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8668, 2321, NULL, 2003, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8760, 5950, NULL, 3499, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8759, 1000, NULL, 3499, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8761, 2615, NULL, 3499, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8758, 5949, NULL, 3499, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8796, 186, NULL, 2004, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8797, 3992, NULL, 2004, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8798, 5963, NULL, 2013, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8799, 5964, NULL, 2013, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8800, 1830, NULL, 2008, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8801, 1691, NULL, 2008, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8802, 652, NULL, 2008, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8803, 2943, NULL, 2008, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8804, 520, NULL, 2009, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8805, 5965, NULL, 2009, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8806, 5966, NULL, 2009, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8807, 5967, NULL, 2012, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8808, 5968, NULL, 2012, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8809, 5969, NULL, 2006, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8810, 5970, NULL, 2006, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8811, 337, NULL, 2006, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8812, 179, NULL, 2014, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8813, 4985, NULL, 2014, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8814, 239, NULL, 2014, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8815, 3853, NULL, 2005, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8816, 601, NULL, 2010, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8817, 355, NULL, 2011, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8818, 5971, NULL, 2011, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8819, 2480, NULL, 2011, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8820, 5972, NULL, 2011, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8821, 488, NULL, 2007, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8822, 1481, NULL, 2007, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8823, 804, NULL, 1696, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8824, 1020, NULL, 1696, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8825, 1225, NULL, 1696, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8826, 5973, NULL, 1696, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17370, 5235, NULL, 5550, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17371, 8860, NULL, 5550, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17372, 6028, NULL, 5550, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17373, 8861, NULL, 5551, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17374, 8862, NULL, 5551, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17375, 755, NULL, 5552, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17376, 1263, NULL, 5552, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17377, 2626, NULL, 5552, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17378, 8250, NULL, 5553, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17379, 5526, NULL, 5553, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17380, 8863, NULL, 5554, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17381, 8864, NULL, 5554, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17382, 8865, NULL, 5554, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17383, 7331, NULL, 5554, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17384, 287, NULL, 5555, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17385, 1475, NULL, 5555, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17386, 5066, NULL, 5556, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17387, 697, NULL, 5556, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17388, 11966, NULL, 5556, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17396, 8880, NULL, 5557, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17397, 8881, NULL, 5557, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17398, 6932, NULL, 5557, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17399, 8882, NULL, 5557, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17400, 8850, NULL, 5558, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17401, 5390, NULL, 5558, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17402, 8883, NULL, 5558, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17403, 3207, NULL, 5558, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17404, 8884, NULL, 5558, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17405, 8885, NULL, 5559, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17406, 8886, NULL, 5559, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17407, 8887, NULL, 5559, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17408, 8888, NULL, 5559, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17395, 8879, NULL, 4114, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17393, 1565, NULL, 4114, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17394, 8878, NULL, 4114, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29279, 12386, NULL, 9127, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8827, 3627, NULL, 1697, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8828, 2545, NULL, 1697, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8829, 2559, NULL, 1697, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8830, 1118, NULL, 1697, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8834, 410, NULL, 1699, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8835, 2518, NULL, 1699, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8836, 101, NULL, 1700, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8837, 2289, NULL, 1700, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8838, 2396, NULL, 1700, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8839, 189, NULL, 1701, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8840, 2456, NULL, 1701, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8841, 1942, NULL, 1701, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8842, 2456, NULL, 3282, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8843, 2456, NULL, 3395, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8844, 2456, NULL, 153, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8845, 2456, NULL, 3475, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8846, 493, NULL, 1702, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8847, 1711, NULL, 1702, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8848, 403, NULL, 1702, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8849, 4026, NULL, 1702, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8850, 4614, NULL, 1703, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8851, 1261, NULL, 1703, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8852, 1881, NULL, 1703, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8853, 3394, NULL, 1703, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8854, 1075, NULL, 1704, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8855, 5643, NULL, 1704, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8856, 471, NULL, 1704, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8857, 582, NULL, 1705, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8858, 1471, NULL, 1705, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8859, 2730, NULL, 1705, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8860, 698, NULL, 3553, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8861, 975, NULL, 3553, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8862, 1413, NULL, 3553, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8863, 3460, NULL, 3553, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8864, 1181, NULL, 3554, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8865, 1858, NULL, 3554, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8866, 760, NULL, 3554, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8867, 977, NULL, 3555, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8868, 2741, NULL, 3555, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8869, 2691, NULL, 3555, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8870, 5975, NULL, 3555, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8871, 5960, NULL, 3556, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8872, 2371, NULL, 3556, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8873, 4708, NULL, 3556, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8874, 3077, NULL, 3556, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8875, 329, NULL, 3557, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8876, 5283, NULL, 3557, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8877, 1922, NULL, 3557, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8878, 2226, NULL, 3557, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8879, 1785, NULL, 3558, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8880, 5976, NULL, 3558, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8881, 4906, NULL, 3558, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8882, 5977, NULL, 3558, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8883, 1431, NULL, 3559, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8884, 842, NULL, 3559, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8743, 5942, NULL, 3495, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8744, 2809, NULL, 3495, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8746, 5944, NULL, 3495, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8745, 5943, NULL, 3495, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8885, 713, NULL, 3559, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8886, 62, NULL, 3559, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8887, 3507, NULL, 3560, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8888, 1899, NULL, 3560, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8889, 5978, NULL, 3560, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8890, 5560, NULL, 3560, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8891, 73, NULL, 3561, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8892, 3744, NULL, 3561, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8893, 100, NULL, 3561, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8894, 405, NULL, 3561, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8895, 98, NULL, 3563, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8896, 2882, NULL, 3563, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8897, 5980, NULL, 3563, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8898, 231, NULL, 3562, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8899, 5981, NULL, 3562, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8900, 2806, NULL, 3562, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8901, 806, NULL, 3564, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8902, 3033, NULL, 3564, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8903, 3848, NULL, 3564, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8904, 1448, NULL, 3565, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8905, 995, NULL, 3565, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8906, 5982, NULL, 3565, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8907, 431, NULL, 3566, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8908, 5983, NULL, 3566, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8909, 1368, NULL, 3566, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8910, 1544, NULL, 3566, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8911, 1757, NULL, 3567, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8912, 2289, NULL, 3567, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8913, 3389, NULL, 3567, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8914, 5984, NULL, 3567, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8915, 138, NULL, 3568, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8916, 2152, NULL, 3568, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8917, 5985, NULL, 3568, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8918, 5986, NULL, 3568, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17412, 8892, NULL, 5561, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32812, 685, NULL, 10163, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32811, 789, NULL, 10163, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17421, 6818, NULL, 5564, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17422, 8899, NULL, 5564, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17423, 4381, NULL, 5564, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17424, 5080, NULL, 5565, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17425, 3052, NULL, 5565, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17426, 2555, NULL, 5565, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17427, 8900, NULL, 5565, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17428, 8901, NULL, 5566, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17429, 8475, NULL, 494, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17434, 2596, NULL, 5568, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17435, 1691, NULL, 5568, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17436, 9010, NULL, 5568, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17437, 3289, NULL, 5569, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17438, 9011, NULL, 5569, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17439, 9012, NULL, 5569, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17440, 1024, NULL, 5569, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17441, 1882, NULL, 5570, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17442, 7189, NULL, 5570, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17443, 4008, NULL, 5570, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17444, 9013, NULL, 5571, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17445, 7551, NULL, 5572, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17446, 7023, NULL, 5572, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17447, 2661, NULL, 5572, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17448, 2221, NULL, 5573, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17449, 821, NULL, 5573, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17450, 7664, NULL, 5573, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17451, 964, NULL, 5574, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17452, 299, NULL, 5574, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17453, 384, NULL, 5574, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29280, 11111, NULL, 9128, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8919, 1672, NULL, 3569, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8920, 5987, NULL, 3569, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8921, 5815, NULL, 3569, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8922, 964, NULL, 3570, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8923, 299, NULL, 3570, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8924, 3700, NULL, 3570, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8925, 610, NULL, 3571, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8926, 2310, NULL, 3571, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8927, 2514, NULL, 3571, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8928, 2365, NULL, 3571, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8929, 1051, NULL, 3572, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8930, 384, NULL, 3572, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8931, 1315, NULL, 3572, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8932, 1741, NULL, 3573, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8933, 328, NULL, 3573, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8934, 1103, NULL, 3574, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8935, 5988, NULL, 3574, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8936, 2988, NULL, 3574, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8937, 5989, NULL, 3574, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8938, 5432, NULL, 3575, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8939, 5990, NULL, 3575, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8940, 5991, NULL, 3575, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8941, 824, NULL, 3576, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8942, 1643, NULL, 3576, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8943, 3004, NULL, 3576, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8944, 1971, NULL, 3576, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8945, 1504, NULL, 3577, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8946, 2718, NULL, 3577, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8947, 1379, NULL, 3577, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8948, 346, NULL, 3578, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8949, 5992, NULL, 3578, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8950, 2414, NULL, 3578, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8951, 1293, NULL, 3579, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8952, 3431, NULL, 3579, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8953, 1371, NULL, 3580, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8954, 4269, NULL, 3580, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8955, 5993, NULL, 3580, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8956, 4912, NULL, 3580, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8957, 1195, NULL, 3581, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8958, 2918, NULL, 3581, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8959, 5994, NULL, 3581, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8960, 3320, NULL, 3581, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8961, 1005, NULL, 3582, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8962, 537, NULL, 3583, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8963, 5995, NULL, 3583, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8964, 2665, NULL, 3583, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8965, 128, NULL, 3584, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8966, 5996, NULL, 3584, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17414, 8894, NULL, 5562, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17415, 2513, NULL, 5562, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17413, 8893, NULL, 5562, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8832, 90, NULL, 1698, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8831, 522, NULL, 1698, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8833, 5974, NULL, 1698, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8967, 5997, NULL, 3584, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8968, 1995, NULL, 3585, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8969, 3428, NULL, 3585, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8970, 347, NULL, 3585, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8971, 4452, NULL, 3586, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8972, 5998, NULL, 3586, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8973, 14, NULL, 3587, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8974, 765, NULL, 3587, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8975, 5370, NULL, 3587, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8976, 351, NULL, 3588, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8977, 5999, NULL, 3588, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8978, 1344, NULL, 3588, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8979, 6000, NULL, 3588, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8980, 762, NULL, 3589, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8981, 697, NULL, 3589, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8982, 2110, NULL, 3589, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8983, 2754, NULL, 3589, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8984, 1554, NULL, 3590, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8985, 66, NULL, 3590, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8986, 3026, NULL, 3590, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8987, 78, NULL, 3590, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8992, 6001, NULL, 3592, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8993, 453, NULL, 3592, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8994, 4548, NULL, 3592, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8995, 6002, NULL, 3592, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8996, 6003, NULL, 3592, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8997, 2532, NULL, 3592, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (8998, 6004, NULL, 3592, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (8999, 5173, NULL, 3592, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (9000, 476, NULL, 3593, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9001, 913, NULL, 3593, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9002, 6005, NULL, 3593, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9003, 68, NULL, 3593, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9004, 722, NULL, 3594, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9005, 6006, NULL, 3594, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9006, 6007, NULL, 3594, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9007, 590, NULL, 3594, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9008, 1082, NULL, 3595, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9009, 1263, NULL, 3595, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9010, 3067, NULL, 3595, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9011, 119, NULL, 3595, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9012, 1821, NULL, 3596, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9013, 979, NULL, 3596, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9014, 1458, NULL, 3596, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9015, 1647, NULL, 3596, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9016, 3067, NULL, 3596, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9017, 4939, NULL, 3212, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9018, 1091, NULL, 3213, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9019, 6009, NULL, 3213, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9020, 6010, NULL, 3214, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9021, 2827, NULL, 3214, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9022, 2063, NULL, 3214, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9023, 6011, NULL, 3214, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9024, 6012, NULL, 3215, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9025, 6013, NULL, 3215, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9026, 6014, NULL, 3215, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17432, 9008, NULL, 5567, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17431, 1093, NULL, 5567, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17433, 9009, NULL, 5567, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32831, 2980, NULL, 10168, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32832, 576, NULL, 10168, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32830, 2921, NULL, 10168, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9027, 6015, NULL, 3216, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9028, 6016, NULL, 3216, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9029, 6017, NULL, 3216, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9030, 171, NULL, 3217, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9031, 6018, NULL, 3217, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9032, 4360, NULL, 3217, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9033, 1805, NULL, 3218, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9034, 6019, NULL, 3218, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9035, 6020, NULL, 3218, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9036, 5304, NULL, 3598, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9037, 512, NULL, 3598, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9038, 4913, NULL, 3599, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9039, 6021, NULL, 3599, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9040, 337, NULL, 3220, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9041, 6022, NULL, 3220, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9042, 6023, NULL, 3220, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9043, 4101, NULL, 3601, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9044, 6024, NULL, 3221, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9045, 6025, NULL, 3221, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9046, 2249, NULL, 3222, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9047, 4858, NULL, 3222, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9048, 6027, NULL, 3222, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17454, 2436, NULL, 5574, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17455, 1293, NULL, 5575, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17456, 1003, NULL, 5575, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17457, 5567, NULL, 5575, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17462, 7548, NULL, 5577, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17463, 9016, NULL, 5577, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17464, 9017, NULL, 5577, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17465, 9018, NULL, 5577, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17466, 1284, NULL, 5578, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17467, 654, NULL, 5578, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17468, 9019, NULL, 5578, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17469, 9020, NULL, 5578, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29281, 12387, NULL, 9129, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9049, 1066, NULL, 3603, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9050, 4656, NULL, 3603, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9051, 1622, NULL, 3603, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9052, 3732, NULL, 1612, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9053, 711, NULL, 1612, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9054, 332, NULL, 1612, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9055, 6029, NULL, 1612, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9057, 6030, NULL, 1613, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9058, 6031, NULL, 1613, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9056, 3497, NULL, 1613, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9064, 3433, NULL, 1615, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9065, 6035, NULL, 1615, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9066, 6036, NULL, 1615, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9067, 3428, NULL, 1615, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9068, 2738, NULL, 1615, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9069, 5963, NULL, 1615, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9070, 6037, NULL, 1615, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9071, 611, NULL, 1616, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9072, 3794, NULL, 1616, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9073, 3081, NULL, 1616, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9074, 6038, NULL, 1616, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33067, 11164, NULL, 10222, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33065, 13929, NULL, 10222, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33068, 4775, NULL, 10222, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33066, 3093, NULL, 10222, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9086, 1282, NULL, 1619, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9087, 6044, NULL, 1619, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9088, 5056, NULL, 1619, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9089, 1247, NULL, 1619, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8076, 5758, NULL, 2697, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28666, 12139, NULL, 8911, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9092, 4181, NULL, 1621, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9093, 2356, NULL, 1621, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9094, 1800, NULL, 1621, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9095, 2383, NULL, 1621, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9096, 6046, NULL, 1622, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9097, 6047, NULL, 1622, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9098, 6048, NULL, 2475, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9101, 191, NULL, 210, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9102, 1554, NULL, 3611, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9103, 787, NULL, 3611, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9104, 6050, NULL, 3611, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9105, 1669, NULL, 3611, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9106, 6051, NULL, 3611, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9107, 6052, NULL, 3611, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9108, 1781, NULL, 3611, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9109, 523, NULL, 3612, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9110, 6053, NULL, 3612, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9111, 6054, NULL, 3612, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9112, 1800, NULL, 3612, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9113, 1725, NULL, 3612, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9114, 1399, NULL, 3612, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9115, 6055, NULL, 3612, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9116, 2971, NULL, 3612, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (9117, 141, NULL, 3613, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9118, 2488, NULL, 3613, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9119, 4311, NULL, 3613, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9120, 5299, NULL, 3613, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9121, 97, NULL, 3614, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9122, 6056, NULL, 3614, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9123, 626, NULL, 3614, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9124, 664, NULL, 3614, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9125, 470, NULL, 3615, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9126, 6057, NULL, 3615, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9127, 5883, NULL, 3615, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9128, 4489, NULL, 3615, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9131, 363, NULL, 3617, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9132, 1920, NULL, 3617, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9133, 2938, NULL, 3617, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9134, 2162, NULL, 3617, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9135, 1533, NULL, 3620, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9136, 6058, NULL, 3620, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9137, 6059, NULL, 3620, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9138, 6060, NULL, 3620, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9139, 2159, NULL, 3621, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9140, 320, NULL, 3621, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9141, 2727, NULL, 3621, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17470, 1091, NULL, 5579, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17471, 2078, NULL, 5579, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17472, 3470, NULL, 5579, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17473, 9021, NULL, 5579, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17474, 9022, NULL, 5580, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17476, 281, NULL, 5530, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9099, 398, NULL, 3076, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17477, 8103, NULL, 5530, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17478, 5187, NULL, 5530, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17479, 8803, NULL, 5530, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17480, 2035, NULL, 5531, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17481, 9030, NULL, 5531, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17482, 9031, NULL, 5531, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17483, 9032, NULL, 5532, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17484, 9033, NULL, 5532, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17485, 1865, NULL, 5532, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17486, 9034, NULL, 5532, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17487, 55, NULL, 5533, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17488, 2031, NULL, 5533, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17489, 2396, NULL, 5533, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17490, 1565, NULL, 5533, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17491, 1166, NULL, 5534, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17492, 806, NULL, 5534, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17493, 2196, NULL, 5534, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17494, 1021, NULL, 5534, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17495, 377, NULL, 5535, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17496, 2510, NULL, 5535, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17497, 4522, NULL, 5535, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17498, 5544, NULL, 5535, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17499, 803, NULL, 5536, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17500, 3885, NULL, 5536, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17501, 9035, NULL, 5536, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17502, 2584, NULL, 5536, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17503, 6, NULL, 5537, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17504, 1263, NULL, 5537, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17505, 119, NULL, 5537, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17506, 5036, NULL, 5537, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17507, 419, NULL, 5538, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17508, 7656, NULL, 5538, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17509, 9036, NULL, 5538, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17510, 2417, NULL, 5538, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17511, 1875, NULL, 5539, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17512, 2319, NULL, 5539, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17513, 2892, NULL, 5539, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17514, 1894, NULL, 5539, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17515, 872, NULL, 5540, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17516, 2039, NULL, 5540, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17517, 952, NULL, 5540, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17518, 2773, NULL, 5540, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17519, 1683, NULL, 5541, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17520, 9037, NULL, 5541, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17521, 7163, NULL, 5541, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17522, 1557, NULL, 5542, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9083, 3020, NULL, 1618, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9085, 6043, NULL, 1618, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (29282, 12388, NULL, 9129, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9142, 1786, NULL, 3621, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9143, 4288, NULL, 3219, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9144, 6061, NULL, 3219, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9145, 3005, NULL, 3163, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9146, 6062, NULL, 3163, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9147, 6063, NULL, 3163, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9148, 614, NULL, 2514, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9149, 1112, NULL, 2514, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9150, 850, NULL, 2514, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9158, 6067, NULL, 2516, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9159, 1062, NULL, 2517, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9160, 1791, NULL, 2517, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9161, 6068, NULL, 2517, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9162, 3232, NULL, 2517, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9163, 6069, NULL, 2518, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9164, 562, NULL, 2518, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9168, 6072, NULL, 2520, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9169, 6073, NULL, 2520, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9170, 6074, NULL, 2520, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9171, 6075, NULL, 2520, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9172, 6076, NULL, 2521, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9173, 2918, NULL, 2522, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9174, 78, NULL, 2522, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9175, 1435, NULL, 2522, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9176, 3315, NULL, 2522, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9177, 6077, NULL, 3622, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9178, 6078, NULL, 3622, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9179, 5980, NULL, 1439, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9180, 1832, NULL, 1439, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9181, 1775, NULL, 1439, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9182, 6048, NULL, 1439, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (9183, 2793, NULL, 1438, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9184, 1502, NULL, 1438, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9185, 757, NULL, 1440, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9186, 1857, NULL, 1440, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9187, 1647, NULL, 1440, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (9188, 6079, NULL, 1436, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9189, 171, NULL, 1442, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9190, 1179, NULL, 1442, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9191, 6080, NULL, 1442, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (9192, 3138, NULL, 1442, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (9193, 2943, NULL, 1437, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9194, 2505, NULL, 1437, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9195, 2336, NULL, 1437, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (9196, 4817, NULL, 1441, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9197, 2922, NULL, 1441, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9129, 3846, NULL, 3616, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9130, 2318, NULL, 3616, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17475, 1466, NULL, 347, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9100, 6049, NULL, 1614, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9063, 6034, NULL, 1614, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9078, 6041, NULL, 1617, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9077, 6040, NULL, 1617, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9076, 6039, NULL, 1617, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9075, 1582, NULL, 1617, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9198, 6081, NULL, 1565, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9199, 6082, NULL, 1565, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9200, 2442, NULL, 1566, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9201, 6083, NULL, 1566, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9202, 663, NULL, 1566, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9203, 5346, NULL, 1566, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9204, 5263, NULL, 1567, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9205, 3440, NULL, 1567, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9206, 161, NULL, 1568, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9207, 3685, NULL, 1568, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9208, 6084, NULL, 1568, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9209, 132, NULL, 1570, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9210, 4795, NULL, 1571, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9211, 6085, NULL, 1571, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9212, 32, NULL, 1571, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9213, 3749, NULL, 1572, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9214, 6086, NULL, 1572, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9215, 5440, NULL, 1572, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9216, 6087, NULL, 1572, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9217, 6088, NULL, 1572, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9218, 749, NULL, 1573, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9219, 6089, NULL, 1573, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9220, 6090, NULL, 1573, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9221, 2382, NULL, 1573, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9222, 709, NULL, 1574, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9223, 6091, NULL, 1574, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9224, 2577, NULL, 1574, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9225, 3919, NULL, 1574, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9226, 1950, NULL, 1576, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9227, 1989, NULL, 1576, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9228, 6092, NULL, 1576, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9229, 1799, NULL, 1577, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9230, 4134, NULL, 1577, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9231, 2719, NULL, 1577, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9232, 2717, NULL, 1510, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9233, 1502, NULL, 2302, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17523, 5577, NULL, 5542, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17524, 9038, NULL, 5542, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17525, 9039, NULL, 5542, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17526, 1179, NULL, 5543, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17527, 9040, NULL, 5543, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17528, 9041, NULL, 5543, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17529, 9042, NULL, 5543, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17530, 9043, NULL, 5581, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17531, 1945, NULL, 5581, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17532, 5528, NULL, 5581, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17533, 5955, NULL, 5581, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17540, 9046, NULL, 5584, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17541, 599, NULL, 5584, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17542, 3192, NULL, 5584, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17543, 1087, NULL, 5584, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17544, 9047, NULL, 5585, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17545, 8514, NULL, 5585, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17546, 9048, NULL, 5585, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17547, 9049, NULL, 5585, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17548, 9050, NULL, 5586, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17549, 3639, NULL, 5586, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17550, 852, NULL, 5586, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17551, 3180, NULL, 5586, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29283, 12389, NULL, 9129, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9234, 1313, NULL, 2246, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9235, 1313, NULL, 109, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9236, 1313, NULL, 1941, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9238, 6092, NULL, 1907, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9239, 2598, NULL, 1907, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9240, 4988, NULL, 1907, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9241, 5438, NULL, 1897, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9242, 4323, NULL, 1897, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9243, 5366, NULL, 1908, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9244, 2849, NULL, 1908, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9245, 4370, NULL, 1908, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9246, 5565, NULL, 1902, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9247, 5068, NULL, 1898, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9250, 1280, NULL, 1802, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9252, 1727, NULL, 2273, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9253, 697, NULL, 2273, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9254, 1627, NULL, 2273, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9255, 753, NULL, 2273, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9249, 7530, NULL, 3601, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9256, 2421, NULL, 2276, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9257, 425, NULL, 2276, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9258, 5273, NULL, 2277, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9259, 6096, NULL, 2277, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9260, 602, NULL, 2277, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9261, 6097, NULL, 2277, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9262, 939, NULL, 2278, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9263, 1112, NULL, 2278, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9264, 3158, NULL, 2278, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9265, 209, NULL, 2278, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9266, 1834, NULL, 2279, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9267, 1225, NULL, 2279, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9268, 6098, NULL, 2279, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9269, 6099, NULL, 2279, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9270, 1620, NULL, 2280, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9271, 1672, NULL, 2281, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9272, 2651, NULL, 2281, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9273, 6100, NULL, 2281, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9274, 6101, NULL, 2281, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9275, 91, NULL, 2282, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9276, 2544, NULL, 2282, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9277, 2196, NULL, 2282, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9278, 6102, NULL, 2282, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9279, 3849, NULL, 2284, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9280, 6103, NULL, 2284, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9281, 1929, NULL, 2284, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9282, 6104, NULL, 2284, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17555, 1880, NULL, 5587, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17564, 8848, NULL, 5589, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17565, 9053, NULL, 5589, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17538, 4896, NULL, 5583, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17537, 9045, NULL, 5583, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17539, 7773, NULL, 5583, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9283, 1665, NULL, 2285, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9284, 6105, NULL, 2285, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9285, 6106, NULL, 2285, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9286, 6107, NULL, 2285, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9291, 6110, NULL, 3125, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9292, 5587, NULL, 1983, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9293, 5588, NULL, 1983, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9294, 5589, NULL, 1983, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32838, 8343, NULL, 10170, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32836, 13853, NULL, 10170, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32837, 12839, NULL, 10170, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9302, 6111, NULL, 1987, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9303, 6112, NULL, 1987, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9316, 1329, NULL, 1529, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9317, 497, NULL, 1529, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9318, 1091, NULL, 1529, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (9319, 1655, NULL, 1529, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (9320, 2882, NULL, 3623, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9322, 98, NULL, 3623, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9323, 2661, NULL, 2742, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9324, 2661, NULL, 316, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9325, 162, NULL, 1922, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9326, 2945, NULL, 1922, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17567, 9055, NULL, 5590, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17568, 7972, NULL, 5591, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17569, 9056, NULL, 5591, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17570, 8244, NULL, 5591, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17571, 7022, NULL, 5591, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17572, 9057, NULL, 5592, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17573, 4183, NULL, 5592, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17574, 1481, NULL, 5592, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17575, 219, NULL, 5592, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17576, 302, NULL, 5592, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17577, 7970, NULL, 5593, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17578, 2099, NULL, 5593, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17579, 6043, NULL, 5593, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17580, 2012, NULL, 5593, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17581, 7973, NULL, 5594, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17582, 2138, NULL, 5594, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17583, 1971, NULL, 5594, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17584, 5933, NULL, 5594, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17585, 9058, NULL, 5595, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17586, 1311, NULL, 5595, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17587, 2451, NULL, 5595, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17588, 9059, NULL, 5595, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17589, 5362, NULL, 1123, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17590, 9060, NULL, 1129, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17591, 4645, NULL, 1129, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17592, 806, NULL, 5600, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17593, 2076, NULL, 5596, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17594, 90, NULL, 5596, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17595, 4128, NULL, 5596, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17596, 1008, NULL, 5597, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17597, 654, NULL, 5597, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17598, 2219, NULL, 5597, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17599, 5648, NULL, 5597, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17600, 3032, NULL, 5597, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17601, 3251, NULL, 5597, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17602, 1995, NULL, 5598, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17603, 9062, NULL, 5598, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9289, 382, NULL, 2286, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9288, 534, NULL, 2286, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9237, 5964, NULL, 1899, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17604, 9063, NULL, 5598, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17605, 424, NULL, 5598, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17606, 9064, NULL, 5598, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17607, 9065, NULL, 5607, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29284, 958, NULL, 9130, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29285, 4331, NULL, 9130, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29286, 12390, NULL, 9130, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9327, 2479, NULL, 1922, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9328, 6124, NULL, 1923, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9329, 4734, NULL, 1923, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9330, 1882, NULL, 1923, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9331, 400, NULL, 1924, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9332, 2870, NULL, 1924, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9333, 1265, NULL, 1925, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9334, 5388, NULL, 1925, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9335, 1665, NULL, 1926, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9336, 6125, NULL, 1926, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9337, 6126, NULL, 1926, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9338, 6127, NULL, 1926, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9339, 2973, NULL, 1927, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9340, 398, NULL, 1927, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9341, 6128, NULL, 1928, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9342, 6129, NULL, 1929, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9343, 369, NULL, 1929, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9345, 6131, NULL, 1929, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9346, 374, NULL, 1930, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9347, 1148, NULL, 1930, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9348, 186, NULL, 1930, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9349, 5311, NULL, 1930, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9350, 5716, NULL, 1930, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9351, 749, NULL, 1931, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9352, 1536, NULL, 1931, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9353, 6132, NULL, 1931, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9354, 6133, NULL, 1931, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9355, 2467, NULL, 1931, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9356, 848, NULL, 1931, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9357, 1044, NULL, 1931, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9358, 1729, NULL, 1933, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9359, 1745, NULL, 1933, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9360, 6134, NULL, 1933, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9361, 2001, NULL, 1934, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9362, 6135, NULL, 1934, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9363, 5118, NULL, 1934, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9364, 2645, NULL, 1934, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9365, 6136, NULL, 1935, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9366, 6137, NULL, 2970, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9367, 1238, NULL, 2970, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9368, 1662, NULL, 2972, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9369, 1571, NULL, 3625, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9370, 5230, NULL, 3625, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9371, 1181, NULL, 2459, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9372, 2037, NULL, 2459, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9373, 1744, NULL, 2459, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9374, 533, NULL, 2461, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9375, 3019, NULL, 2461, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9376, 790, NULL, 2461, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9377, 2054, NULL, 2458, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9378, 4409, NULL, 2458, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9379, 6138, NULL, 2458, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9380, 3673, NULL, 2458, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9384, 1625, NULL, 2460, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9385, 6139, NULL, 2460, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9386, 6140, NULL, 2460, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9387, 6141, NULL, 2460, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9392, 655, NULL, 2456, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9393, 674, NULL, 2456, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9394, 2357, NULL, 2456, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9395, 5187, NULL, 2456, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9396, 121, NULL, 2462, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9397, 1042, NULL, 2462, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9398, 306, NULL, 2462, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9399, 1609, NULL, 2462, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9404, 1106, NULL, 2276, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9405, 2307, NULL, 1291, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9406, 2307, NULL, 2529, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9407, 914, NULL, 1790, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9408, 914, NULL, 428, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9409, 914, NULL, 2837, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9410, 5107, NULL, 2254, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9411, 713, NULL, 3638, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9412, 1971, NULL, 3638, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9413, 1687, NULL, 3638, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9414, 1926, NULL, 3639, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9415, 3056, NULL, 3639, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9165, 5059, NULL, 2519, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9167, 6071, NULL, 2519, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9166, 6070, NULL, 2519, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9416, 3853, NULL, 3640, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9417, 3231, NULL, 3642, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9418, 744, NULL, 3642, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17608, 2306, NULL, 5599, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17609, 5790, NULL, 5599, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17610, 2596, NULL, 5599, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17611, 1068, NULL, 5599, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17612, 773, NULL, 5600, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9295, 3362, NULL, 1985, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9301, 5596, NULL, 1986, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9300, 5595, NULL, 1986, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9299, 5594, NULL, 1986, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9310, 6119, NULL, 1578, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9309, 6118, NULL, 1578, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9311, 5463, NULL, 1993, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9308, 6117, NULL, 1990, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9306, 6115, NULL, 1990, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9305, 6114, NULL, 1990, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9313, 6121, NULL, 1993, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9314, 6122, NULL, 1993, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9312, 6120, NULL, 1993, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9315, 6123, NULL, 2778, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9344, 1648, 478, 1929, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9290, 3093, NULL, 3120, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17613, 9066, NULL, 5600, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17614, 3033, NULL, 5600, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17615, 2816, NULL, 5600, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17616, 2312, NULL, 5600, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17617, 9067, NULL, 5601, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17618, 971, NULL, 5602, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17619, 9068, NULL, 5602, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17620, 9069, NULL, 5602, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17621, 8716, NULL, 5602, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17622, 1077, NULL, 5603, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17623, 1409, NULL, 5603, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17624, 93, NULL, 5603, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17625, 2534, NULL, 5603, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17626, 9070, NULL, 5603, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17627, 9071, NULL, 5604, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17628, 430, NULL, 5605, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17629, 1940, NULL, 5605, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17630, 19, NULL, 5605, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17631, 3013, NULL, 5605, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17632, 3723, NULL, 5608, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17633, 7545, NULL, 5609, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17634, 3023, NULL, 5609, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17635, 7134, NULL, 5609, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17636, 187, NULL, 5609, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17637, 2418, NULL, 5610, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17638, 9097, NULL, 5610, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17639, 2081, NULL, 5610, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17640, 536, NULL, 5611, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17641, 2545, NULL, 5611, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17642, 3232, NULL, 5611, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17643, 2556, NULL, 5611, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17644, 1413, NULL, 5612, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17645, 2932, NULL, 5612, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17646, 6801, NULL, 5612, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17647, 281, NULL, 5613, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17648, 9098, NULL, 5613, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17649, 1894, NULL, 5613, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29287, 12391, NULL, 9131, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29288, 12392, NULL, 9131, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29289, 12393, NULL, 9131, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9419, 1007, NULL, 3643, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9420, 1034, NULL, 3643, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9421, 1097, NULL, 3643, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9422, 4018, NULL, 3644, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9423, 5228, NULL, 3644, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9424, 5329, NULL, 3644, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9425, 1091, NULL, 3646, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9426, 1261, NULL, 3648, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9427, 2258, NULL, 3648, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9428, 4288, NULL, 3648, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2075, 563, NULL, 721, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2078, 1129, 526, 721, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2076, 1152, NULL, 721, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9438, 2973, NULL, 2020, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9439, 5068, NULL, 2020, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9440, 1291, NULL, 2022, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9441, 2478, NULL, 2022, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9442, 448, NULL, 2023, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9443, 1909, NULL, 2023, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9444, 220, NULL, 2023, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9445, 5511, NULL, 3650, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9446, 6095, NULL, 3650, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9447, 6142, NULL, 3650, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9403, 78, NULL, 2455, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9402, 2010, NULL, 2455, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9400, 256, NULL, 2455, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9389, 3442, NULL, 2457, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9388, 763, NULL, 2457, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9390, 2592, NULL, 2457, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9448, 2029, NULL, 3651, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9449, 1354, NULL, 3651, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9450, 6143, NULL, 3652, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9451, 6144, NULL, 3653, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9452, 6145, NULL, 3653, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9453, 6146, NULL, 3653, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9454, 6147, NULL, 3653, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9455, 6148, NULL, 3654, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9456, 6149, NULL, 3654, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9457, 6150, NULL, 3655, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9458, 6151, NULL, 3656, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9459, 5655, NULL, 3656, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9460, 2084, NULL, 3656, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9461, 6152, NULL, 3656, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9462, 405, NULL, 3011, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9463, 1761, NULL, 3015, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9464, 318, NULL, 3011, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9465, 1062, NULL, 3012, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9466, 55, NULL, 3013, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9467, 378, NULL, 3014, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9468, 992, NULL, 3015, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9469, 1021, NULL, 3016, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9470, 1528, NULL, 3017, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9471, 40, NULL, 3018, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9472, 374, NULL, 3657, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9473, 1744, NULL, 3657, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9474, 6153, NULL, 3657, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9475, 76, NULL, 3657, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9476, 1655, NULL, 3657, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29290, 12394, NULL, 9132, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9478, 2782, NULL, 3659, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9479, 2302, NULL, 3659, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9480, 840, NULL, 3659, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9481, 2705, NULL, 3659, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9482, 2724, NULL, 3660, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9483, 6090, NULL, 3660, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9484, 5319, NULL, 3660, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9485, 6155, NULL, 3661, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9487, 3642, NULL, 3662, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9488, 5381, NULL, 3662, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9489, 430, NULL, 3663, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9490, 312, NULL, 3663, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9491, 1020, NULL, 3663, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9492, 687, NULL, 3663, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9493, 4264, NULL, 3663, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9494, 122, NULL, 3663, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9495, 551, NULL, 3664, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9496, 278, NULL, 3664, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9497, 4449, NULL, 3664, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9498, 278, NULL, 1361, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9499, 448, NULL, 3665, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9500, 709, NULL, 3665, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9501, 1374, NULL, 3665, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9502, 6028, NULL, 3667, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9503, 6157, NULL, 3667, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9504, 6158, NULL, 3667, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9505, 6159, NULL, 3668, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9506, 1002, NULL, 3668, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9507, 6161, NULL, 3669, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9508, 4838, NULL, 3669, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9509, 1707, NULL, 3670, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9510, 6162, NULL, 3670, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9511, 6163, NULL, 3670, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9512, 6164, NULL, 3671, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9513, 1598, NULL, 3671, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9514, 6165, NULL, 3671, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9515, 3128, NULL, 3672, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9516, 4522, NULL, 3672, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9517, 4784, NULL, 3672, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9518, 1282, NULL, 3673, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9519, 657, NULL, 3673, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9520, 3942, NULL, 3673, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9521, 6166, NULL, 3673, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9522, 472, NULL, 3673, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9523, 6167, NULL, 3673, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9524, 6169, NULL, 3673, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (9525, 1514, NULL, 3674, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9526, 675, NULL, 3674, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9527, 382, NULL, 3674, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9528, 238, NULL, 3675, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9529, 295, NULL, 3675, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9530, 6170, NULL, 3676, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9531, 771, NULL, 3676, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9532, 842, NULL, 3676, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9533, 6171, NULL, 3677, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9534, 4770, NULL, 3677, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9535, 1884, NULL, 3677, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9536, 3359, NULL, 3678, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9537, 1629, NULL, 3679, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9538, 1329, NULL, 3679, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9539, 6172, NULL, 3679, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9540, 448, NULL, 3680, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9541, 914, NULL, 3680, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9542, 4382, NULL, 3680, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9543, 2696, NULL, 3681, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9544, 452, NULL, 3681, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9545, 5390, NULL, 3681, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9546, 6173, NULL, 3682, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9547, 6174, NULL, 3682, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9548, 6175, NULL, 3682, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17650, 5, NULL, 5614, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17651, 2571, NULL, 5614, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17652, 9099, NULL, 5614, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17653, 3180, NULL, 5614, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17654, 5118, NULL, 5615, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17655, 2645, NULL, 5615, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17656, 9100, NULL, 5615, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17657, 5371, NULL, 5615, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17658, 8473, NULL, 5616, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17659, 1219, NULL, 5616, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17660, 1334, NULL, 5616, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17661, 2986, NULL, 5616, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17662, 9101, NULL, 5617, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17663, 2950, NULL, 5617, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17664, 9102, NULL, 5617, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9435, 179, NULL, 2027, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9437, 239, NULL, 2027, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9436, 4985, NULL, 2027, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9477, 2906, NULL, 3658, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9549, 6176, NULL, 3683, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9550, 3003, NULL, 3684, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9551, 1622, NULL, 3684, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9552, 1818, NULL, 3684, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9553, 411, NULL, 3685, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9554, 1511, NULL, 3685, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9555, 1600, NULL, 3685, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9556, 111, NULL, 3685, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9557, 295, NULL, 3686, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9558, 6177, NULL, 3686, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9559, 313, NULL, 3687, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9560, 1373, NULL, 3687, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9561, 993, NULL, 3687, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9562, 2719, NULL, 3689, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9563, 152, NULL, 3690, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9564, 5125, NULL, 3690, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9565, 981, NULL, 3691, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9566, 81, NULL, 3693, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9567, 914, NULL, 3693, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9568, 220, NULL, 3693, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9569, 6178, NULL, 3694, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9570, 1876, NULL, 3695, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9571, 1622, NULL, 3695, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9572, 374, NULL, 3696, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9573, 6179, NULL, 3697, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9574, 6180, NULL, 3697, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9575, 6181, NULL, 3697, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9576, 717, NULL, 3698, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9577, 1586, NULL, 3698, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9578, 2442, NULL, 3699, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9579, 1091, NULL, 3699, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9580, 3700, NULL, 3700, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9581, 968, NULL, 3700, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9582, 2400, NULL, 3700, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9583, 1979, NULL, 3701, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9584, 1376, NULL, 3701, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9585, 6182, NULL, 3702, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9586, 2399, NULL, 3702, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9587, 6184, NULL, 3703, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9588, 6185, NULL, 1932, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9589, 3317, NULL, 1932, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9590, 6186, NULL, 1932, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9591, 6187, NULL, 1932, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9592, 179, NULL, 2287, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9593, 2140, NULL, 2287, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9594, 6188, NULL, 2827, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9595, 4670, NULL, 2827, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9596, 5591, NULL, 2788, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9597, 1876, NULL, 2334, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9598, 5729, NULL, 2342, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9599, 497, NULL, 3135, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9600, 188, NULL, 3135, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9601, 1629, NULL, 3135, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (9602, 1091, NULL, 3135, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (9603, 6190, NULL, 3705, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9604, 687, NULL, 3705, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9605, 122, NULL, 3705, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9606, 220, NULL, 3708, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9607, 5324, NULL, 3708, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9608, 378, NULL, 3708, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9609, 1066, NULL, 3709, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9610, 848, NULL, 3709, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9611, 3919, NULL, 3709, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9612, 5126, NULL, 3709, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9613, 739, NULL, 3710, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9614, 6191, NULL, 3710, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9615, 6192, NULL, 3711, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9616, 2264, NULL, 3711, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9617, 2822, NULL, 3711, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9618, 939, NULL, 3712, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9619, 2668, NULL, 3712, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9620, 2624, NULL, 3712, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9625, 6196, NULL, 3716, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9626, 6197, NULL, 3716, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9627, 6198, NULL, 3716, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9628, 1265, NULL, 3717, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9629, 4366, NULL, 3717, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9630, 6199, NULL, 3717, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9631, 2725, NULL, 3718, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9632, 289, NULL, 3718, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9633, 872, NULL, 3718, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9634, 6200, NULL, 3718, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9635, 4436, NULL, 3719, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9636, 2308, NULL, 3719, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9637, 1401, NULL, 3720, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9638, 1374, NULL, 3720, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9639, 6201, NULL, 3720, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9640, 6202, NULL, 3721, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9641, 6203, NULL, 3722, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17669, 804, NULL, 5619, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17670, 9104, NULL, 5619, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17671, 9105, NULL, 5619, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17672, 9106, NULL, 5619, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17673, 216, NULL, 5620, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17674, 7130, NULL, 5620, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17675, 5666, NULL, 5620, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17676, 248, NULL, 5621, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17677, 5599, NULL, 5621, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17678, 52, NULL, 5621, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17679, 41, NULL, 5622, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17680, 13, NULL, 5622, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17681, 8998, NULL, 5623, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17682, 9107, NULL, 5623, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17683, 9108, NULL, 5623, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17684, 9109, NULL, 5623, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17685, 8998, NULL, 5624, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17686, 9110, NULL, 5624, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17687, 9111, NULL, 5624, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17688, 4782, NULL, 5624, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2077, 853, NULL, 721, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33063, 8160, NULL, 10221, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33064, 1873, NULL, 10221, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33062, 13928, NULL, 10221, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17700, 3865, NULL, 5627, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17701, 9001, NULL, 5627, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17702, 9002, NULL, 5627, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17703, 3865, NULL, 5628, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17704, 6042, NULL, 5628, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17705, 6738, NULL, 5628, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17706, 9120, NULL, 5628, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29291, 12395, NULL, 9132, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9642, 6204, NULL, 3722, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9643, 3149, NULL, 3722, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9644, 2214, NULL, 3723, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9645, 6205, NULL, 3723, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9646, 6206, NULL, 3724, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9647, 4075, NULL, 3724, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9648, 5628, NULL, 3725, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9649, 6207, NULL, 3726, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9650, 6208, NULL, 3726, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9651, 6209, NULL, 3726, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9652, 1464, NULL, 3727, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9653, 357, NULL, 3727, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9654, 6210, NULL, 3728, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9655, 2531, NULL, 3728, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9656, 812, NULL, 3728, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9657, 6211, NULL, 3729, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9658, 2818, NULL, 3730, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9659, 4987, NULL, 3730, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9660, 5171, NULL, 3730, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9661, 534, NULL, 3731, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9662, 1956, NULL, 3731, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9663, 378, NULL, 3731, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9664, 787, NULL, 3732, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17694, 9115, NULL, 5625, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17691, 7191, NULL, 5625, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17692, 9759, NULL, 5625, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17689, 8999, NULL, 5625, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9665, 3027, NULL, 3732, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9666, 5379, NULL, 3732, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9667, 6212, NULL, 3733, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9668, 6213, NULL, 3733, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9669, 6214, NULL, 3733, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9670, 6215, NULL, 3734, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9671, 6216, NULL, 3734, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9672, 372, NULL, 3735, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9673, 6217, NULL, 3735, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9674, 6218, NULL, 3735, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9675, 1118, NULL, 3737, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9676, 188, NULL, 3737, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9677, 6219, NULL, 3738, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9678, 6220, NULL, 3739, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9679, 1779, NULL, 3739, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9680, 5499, NULL, 3739, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9681, 654, NULL, 3740, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9682, 2414, NULL, 3740, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9683, 2711, NULL, 3740, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9684, 2640, NULL, 3741, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9685, 6221, NULL, 3741, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9686, 388, NULL, 3741, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9687, 6046, NULL, 3742, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9688, 6222, NULL, 3742, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9689, 5202, NULL, 3742, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9621, 835, NULL, 3713, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17707, 9003, NULL, 5629, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9690, 6223, NULL, 3743, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9691, 2696, NULL, 3745, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9692, 935, NULL, 3745, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9693, 1970, NULL, 3745, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9694, 6224, NULL, 3746, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9695, 1586, NULL, 3747, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9696, 6048, NULL, 3747, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9697, 6225, NULL, 3747, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9698, 2964, NULL, 3747, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9700, 1620, NULL, 1451, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9701, 2152, NULL, 2758, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9702, 5165, NULL, 2760, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9703, 6226, NULL, 1936, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9704, 4793, NULL, 1936, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9705, 3236, NULL, 1936, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9706, 576, NULL, 2565, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9707, 857, NULL, 2565, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9708, 3397, NULL, 2565, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9711, 1665, NULL, 2567, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9712, 6227, NULL, 2567, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9713, 1565, NULL, 2567, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9714, 2706, NULL, 2567, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9715, 2652, NULL, 2567, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9716, 2410, NULL, 2567, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9717, 962, NULL, 2567, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9718, 1748, NULL, 2569, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9719, 3870, NULL, 2569, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9720, 3682, NULL, 2569, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9721, 868, NULL, 2569, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9722, 858, NULL, 2569, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9723, 5495, NULL, 2570, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9724, 6228, NULL, 2570, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9725, 6229, NULL, 2056, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9726, 3516, NULL, 2056, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9727, 2743, NULL, 2058, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9728, 6230, NULL, 2060, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9729, 5154, NULL, 2061, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9730, 4104, NULL, 2061, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9731, 6231, NULL, 2062, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9732, 5202, NULL, 2062, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9733, 6232, NULL, 2062, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17709, 9121, NULL, 5630, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17710, 9122, NULL, 5630, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17711, 4911, NULL, 5630, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17712, 1566, NULL, 5630, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17713, 9005, NULL, 5631, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17714, 1164, NULL, 5631, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17715, 1194, NULL, 5631, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17716, 7494, NULL, 5631, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17717, 9006, NULL, 5632, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17718, 9123, NULL, 5632, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17719, 9124, NULL, 5632, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17720, 9125, NULL, 5632, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17721, 1852, NULL, 5633, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17722, 9126, NULL, 5633, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17723, 9127, NULL, 5633, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17724, 1409, NULL, 5634, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17725, 4555, NULL, 5634, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17726, 1636, NULL, 5634, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17727, 9007, NULL, 5635, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17728, 9128, NULL, 5635, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17729, 9129, NULL, 5635, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17730, 9130, NULL, 5635, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17731, 1466, NULL, 5636, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17732, 9131, NULL, 5636, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17733, 1526, NULL, 5636, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17734, 9132, NULL, 5637, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17735, 9133, NULL, 5637, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17736, 9134, NULL, 5637, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17737, 388, NULL, 5638, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17738, 1421, NULL, 5638, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17739, 2442, NULL, 5639, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17740, 1624, NULL, 5639, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17741, 1745, NULL, 5639, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17742, 2545, NULL, 5639, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17747, 2399, NULL, 5641, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17748, 2054, NULL, 5641, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17749, 156, NULL, 5642, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17750, 601, NULL, 5643, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29292, 12396, NULL, 9133, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29293, 12397, NULL, 9133, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29295, 2455, NULL, 9135, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29296, 2703, NULL, 9135, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29297, 1373, NULL, 9135, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29298, 9517, NULL, 9135, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9734, 6233, NULL, 2062, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9735, 6234, NULL, 2063, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9736, 6235, NULL, 2063, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9737, 2270, NULL, 2064, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9738, 2149, NULL, 2064, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9739, 4374, NULL, 2065, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9740, 6236, NULL, 2066, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9741, 5174, NULL, 2066, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9742, 6237, NULL, 3748, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9743, 1101, NULL, 3748, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9744, 6238, NULL, 2067, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9745, 6239, NULL, 2067, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9746, 6240, NULL, 2069, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9747, 6241, NULL, 2069, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9748, 6242, NULL, 2070, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9749, 6243, NULL, 2070, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9750, 2308, NULL, 2071, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9751, 6245, NULL, 2226, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9752, 5313, NULL, 2223, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9753, 6246, NULL, 2223, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9754, 6247, NULL, 2231, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9755, 2871, NULL, 2227, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9756, 1848, NULL, 2227, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9757, 6249, NULL, 2234, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9758, 6248, NULL, 2224, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9759, 1502, NULL, 2224, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9760, 6250, NULL, 2912, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9761, 6251, NULL, 2913, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9762, 1334, NULL, 2974, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9763, 1108, NULL, 3749, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9764, 2572, NULL, 3749, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9765, 1396, NULL, 3749, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9766, 1257, NULL, 3750, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9767, 758, NULL, 3750, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9768, 68, NULL, 3750, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9769, 1830, NULL, 3751, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9770, 4305, NULL, 3751, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9771, 2696, NULL, 3751, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9772, 5066, NULL, 3752, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9773, 5118, NULL, 3752, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9774, 6252, NULL, 3753, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9775, 2918, NULL, 3753, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9776, 5130, NULL, 3753, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9777, 1785, NULL, 3754, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9778, 963, NULL, 3754, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9779, 3136, NULL, 3754, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9780, 989, NULL, 3755, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9781, 2816, NULL, 3755, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9782, 2489, NULL, 3755, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9783, 909, NULL, 3756, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9784, 1423, NULL, 3756, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9785, 5315, NULL, 3756, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9786, 761, NULL, 3757, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9787, 1084, NULL, 3757, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9788, 730, NULL, 3757, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9789, 5718, NULL, 3758, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9790, 963, NULL, 3758, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9791, 5241, NULL, 3758, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9792, 6253, NULL, 3758, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9793, 330, NULL, 3759, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9794, 1370, NULL, 3759, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9795, 2737, NULL, 3760, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9796, 1238, NULL, 3760, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9797, 1665, NULL, 3760, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9798, 4361, NULL, 3761, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9799, 2516, NULL, 3761, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9800, 267, NULL, 3761, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9801, 3992, NULL, 3761, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9802, 421, NULL, 3761, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9803, 773, NULL, 3761, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9804, 3744, NULL, 3762, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9805, 6254, NULL, 3762, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20162, 9859, NULL, 6291, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17708, 9004, NULL, 5629, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17751, 968, NULL, 5644, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17752, 186, NULL, 5645, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17753, 2899, NULL, 5645, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17754, 5036, NULL, 5645, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17755, 1367, NULL, 5646, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17756, 6206, NULL, 5646, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17757, 3702, NULL, 5647, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17758, 1707, NULL, 5647, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17759, 2369, NULL, 5647, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17760, 239, NULL, 5647, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17761, 760, NULL, 5648, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17762, 1594, NULL, 5648, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17763, 76, NULL, 5648, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17764, 4444, NULL, 5649, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17765, 6101, NULL, 5649, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17766, 3321, NULL, 5650, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17767, 400, NULL, 5650, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17768, 316, NULL, 5650, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17769, 757, NULL, 5651, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17770, 9135, NULL, 5651, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17771, 1386, NULL, 5651, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17772, 4348, NULL, 5652, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17773, 757, NULL, 5652, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17778, 8045, NULL, 5654, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17779, 2903, NULL, 5654, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17780, 9147, NULL, 5654, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29294, 12398, NULL, 9134, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29299, 2106, NULL, 9136, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29300, 4167, NULL, 9136, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29301, 1513, NULL, 9136, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9828, 724, NULL, 2761, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9848, 6260, NULL, 3778, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9849, 6261, NULL, 3778, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9850, 6262, NULL, 3779, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9851, 724, NULL, 622, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9852, 724, NULL, 3675, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9853, 724, NULL, 3334, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9855, 724, NULL, 3058, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9856, 724, NULL, 3695, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9857, 413, NULL, 231, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17790, 8387, NULL, 5659, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17791, 8388, NULL, 5659, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17792, 9148, NULL, 5659, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9858, 2798, NULL, 2751, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9859, 2798, NULL, 1202, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9860, 2798, NULL, 3639, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9861, 2798, NULL, 2780, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9862, 2798, NULL, 3289, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9863, 13, NULL, 3780, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9864, 405, NULL, 3780, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9865, 1263, NULL, 3780, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9866, 624, NULL, 3781, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9867, 1026, NULL, 3781, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9868, 1997, NULL, 3781, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9869, 6263, NULL, 3782, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9870, 1125, NULL, 3782, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9871, 5302, NULL, 3782, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9872, 6264, NULL, 3782, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9873, 451, NULL, 3783, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9874, 816, NULL, 3783, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9875, 77, NULL, 3783, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9876, 4310, NULL, 3784, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9877, 805, NULL, 3784, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9878, 5263, NULL, 3785, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9879, 5568, NULL, 3785, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9880, 6265, NULL, 3786, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9881, 5739, NULL, 3787, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9882, 3516, NULL, 3787, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9883, 1843, NULL, 3788, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9884, 12, NULL, 3789, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9885, 1181, NULL, 3789, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9886, 2124, NULL, 3789, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9887, 555, NULL, 3790, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9888, 3579, NULL, 3790, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9889, 3931, NULL, 3790, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9890, 3598, NULL, 3791, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9891, 1041, NULL, 3792, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9892, 1781, NULL, 3792, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9893, 2285, NULL, 3792, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9894, 1592, NULL, 3795, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9895, 1542, NULL, 3795, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9896, 1814, NULL, 3795, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9897, 2140, NULL, 3795, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9898, 1458, NULL, 3798, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9899, 2761, NULL, 3798, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9900, 1374, NULL, 3798, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9901, 923, NULL, 3799, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9902, 51, NULL, 3799, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9903, 682, NULL, 3799, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9904, 1592, NULL, 3800, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9905, 456, NULL, 3800, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9906, 421, NULL, 3800, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9907, 960, NULL, 3801, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9908, 6266, NULL, 3801, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9909, 1948, NULL, 3801, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9910, 761, NULL, 3802, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9911, 320, NULL, 3802, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9912, 337, NULL, 3802, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9913, 1458, NULL, 3803, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9914, 146, NULL, 3803, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9915, 1225, NULL, 3803, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9916, 6254, NULL, 3804, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9917, 2139, NULL, 3804, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9918, 132, NULL, 3805, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17794, 8386, NULL, 5658, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17795, 9149, NULL, 5658, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17796, 9150, NULL, 5658, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17797, 3761, NULL, 5658, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17798, 8389, NULL, 5660, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17799, 9142, NULL, 5660, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33060, 13815, NULL, 10220, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33061, 2571, NULL, 10220, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33059, 13927, NULL, 10220, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17807, 9153, NULL, 5663, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17808, 2653, NULL, 5663, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17809, 9154, NULL, 5663, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17810, 9155, NULL, 5663, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17815, 9156, NULL, 5665, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17816, 9139, NULL, 5665, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17817, 9143, NULL, 5665, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17818, 9146, NULL, 5665, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17827, 58, NULL, 781, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17829, 570, NULL, 781, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17830, 2536, NULL, 781, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17828, 9166, NULL, 781, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9815, 555, NULL, 3766, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9814, 6257, NULL, 3766, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9813, 6256, NULL, 3766, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17802, 3232, NULL, 5661, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17801, 9138, NULL, 5661, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9807, 293, NULL, 3763, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9808, 1052, NULL, 3763, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9806, 1455, NULL, 3763, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9809, 6255, NULL, 3764, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9812, 2790, NULL, 3765, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9810, 1748, NULL, 3765, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9816, 1662, NULL, 3767, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9818, 6035, NULL, 3768, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9820, 2997, NULL, 3768, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9819, 1690, NULL, 3768, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9826, 1948, NULL, 3771, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9827, 724, NULL, 3771, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9825, 3919, NULL, 3771, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9831, 128, NULL, 3772, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9829, 451, NULL, 3772, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9830, 3013, NULL, 3772, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9832, 162, NULL, 3773, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9835, 756, NULL, 3773, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9833, 5205, NULL, 3773, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9836, 236, NULL, 3774, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9839, 652, NULL, 3774, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9837, 1006, NULL, 3774, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9841, 806, NULL, 3775, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9842, 1997, NULL, 3775, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9840, 1431, NULL, 3775, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9843, 6258, NULL, 3776, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9845, 2138, NULL, 3777, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9846, 6259, NULL, 3777, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9823, 503, NULL, 3770, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9822, 955, NULL, 3770, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9821, 1553, NULL, 3770, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9844, 614, NULL, 3777, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9847, 5265, NULL, 3777, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9854, 724, NULL, 1698, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17789, 9145, NULL, 5657, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17787, 4848, NULL, 5657, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17786, 485, 656, 5656, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17785, 2651, NULL, 5656, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17784, 8395, NULL, 5656, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17800, 8046, NULL, 5661, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17811, 8390, NULL, 5664, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17813, 2153, NULL, 5664, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17812, 3672, NULL, 5664, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17788, 9144, NULL, 5657, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29302, 448, NULL, 9137, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29303, 2037, NULL, 9137, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29304, 220, NULL, 9137, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29305, 1424, NULL, 9137, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17777, 1906, NULL, 5653, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17775, 9136, NULL, 5653, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17774, 8399, NULL, 5653, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17776, 9137, NULL, 5653, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9919, 2696, NULL, 3806, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9920, 586, NULL, 3806, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9921, 1880, NULL, 3806, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9922, 396, NULL, 3807, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9923, 2564, NULL, 3807, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9924, 355, NULL, 3807, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9925, 5752, NULL, 3808, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9926, 231, NULL, 3808, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9927, 129, NULL, 3809, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9928, 4625, NULL, 3809, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9929, 3321, NULL, 3810, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9930, 755, NULL, 3811, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9931, 2482, NULL, 3811, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9932, 503, NULL, 3811, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9933, 601, NULL, 3812, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9934, 6267, NULL, 3813, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9935, 411, NULL, 3814, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9936, 503, NULL, 3814, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9937, 1225, NULL, 3814, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9938, 179, NULL, 3815, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9939, 1624, NULL, 3815, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9940, 1042, NULL, 3815, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9941, 914, NULL, 3816, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9942, 2967, NULL, 3816, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9943, 1586, NULL, 3817, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9944, 1101, NULL, 3817, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9945, 283, NULL, 3818, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9946, 2957, NULL, 3818, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9947, 76, NULL, 3818, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9948, 350, NULL, 3819, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9949, 1528, NULL, 3819, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9950, 4543, NULL, 3819, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9951, 374, NULL, 3820, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9952, 2399, NULL, 3820, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9953, 6268, NULL, 3820, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9962, 1329, NULL, 3821, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9963, 1198, NULL, 3821, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9964, 232, NULL, 3821, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9965, 1319, NULL, 3821, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9966, 1226, NULL, 3821, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9967, 1511, NULL, 3822, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9968, 423, NULL, 3822, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9969, 346, NULL, 3823, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9970, 1542, NULL, 3823, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9971, 182, NULL, 3823, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9972, 2489, NULL, 3823, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9973, 171, NULL, 3824, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9974, 1655, NULL, 3824, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9975, 2399, NULL, 3824, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9976, 1095, NULL, 2549, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9977, 1857, NULL, 2549, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9978, 123, NULL, 2549, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9979, 2945, NULL, 2549, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9980, 1147, NULL, 2546, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9981, 1232, NULL, 2546, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9982, 5379, NULL, 2546, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9983, 434, NULL, 2546, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9984, 419, NULL, 2552, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9985, 951, NULL, 2552, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9986, 834, NULL, 2552, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9987, 1511, NULL, 2551, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9988, 1334, NULL, 2551, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9989, 453, NULL, 2551, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9990, 1406, NULL, 2551, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9991, 1450, NULL, 2545, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9992, 3894, NULL, 2545, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9993, 2138, NULL, 2545, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9994, 2191, NULL, 2545, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9995, 1290, NULL, 2550, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17793, 8398, NULL, 5659, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9957, 5418, NULL, 1414, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9955, 5416, NULL, 1414, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9956, 5417, NULL, 1414, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9996, 618, NULL, 2550, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9997, 1730, NULL, 2550, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9998, 3060, NULL, 2550, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9999, 1670, NULL, 2554, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10000, 540, NULL, 2554, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10001, 1360, NULL, 2544, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10002, 537, NULL, 2544, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10003, 8, NULL, 2544, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10004, 792, NULL, 2544, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10005, 1021, NULL, 2553, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10006, 2448, NULL, 2553, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10007, 239, NULL, 2553, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10008, 1099, NULL, 2553, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10009, 1707, NULL, 2553, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10010, 109, NULL, 2553, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (10011, 267, NULL, 2553, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (10012, 318, NULL, 2548, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10013, 3215, NULL, 2548, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10014, 5749, NULL, 2548, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10015, 6270, NULL, 2548, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10016, 49, NULL, 3825, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10017, 2318, NULL, 3825, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10018, 2458, NULL, 3825, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10019, 534, NULL, 3826, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10020, 6271, NULL, 3826, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10021, 1696, NULL, 3826, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10022, 6272, NULL, 3826, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10023, 6273, NULL, 3827, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10024, 4727, NULL, 3827, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10025, 6274, NULL, 3827, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10026, 1141, NULL, 3828, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10027, 2434, NULL, 3828, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10028, 81, NULL, 3829, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10029, 3937, NULL, 3829, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10030, 4105, NULL, 3829, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10031, 512, NULL, 3830, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10032, 6275, NULL, 3830, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10033, 3650, NULL, 3830, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10034, 121, NULL, 3831, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10035, 3876, NULL, 3831, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10036, 306, NULL, 3831, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10037, 6276, NULL, 3831, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10038, 2506, NULL, 3832, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10039, 2996, NULL, 3832, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10040, 3195, NULL, 3832, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10041, 886, NULL, 3833, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10042, 2939, NULL, 3833, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10043, 1364, NULL, 3833, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10044, 1137, NULL, 3833, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10045, 899, NULL, 3834, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10046, 1385, NULL, 3834, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10047, 3249, NULL, 3834, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10048, 1882, NULL, 3835, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29306, 671, NULL, 9138, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10049, 6277, NULL, 3835, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10050, 2289, NULL, 3835, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10051, 730, NULL, 3835, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10052, 179, NULL, 3836, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10053, 6278, NULL, 3836, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10054, 2415, NULL, 3836, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10055, 895, NULL, 3836, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10056, 1095, NULL, 3837, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10057, 914, NULL, 3837, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10058, 1328, NULL, 3837, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10059, 924, NULL, 3837, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10060, 722, NULL, 3838, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10061, 6279, NULL, 3838, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10062, 106, NULL, 3838, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10063, 196, NULL, 3838, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10064, 1082, NULL, 1781, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10065, 1394, NULL, 1780, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10066, 6280, NULL, 3839, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10067, 3564, NULL, 3841, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10068, 4954, NULL, 3841, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10069, 5266, NULL, 3841, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10070, 6281, NULL, 3842, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10071, 6282, NULL, 3842, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10072, 6283, NULL, 3842, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10073, 6284, NULL, 3843, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10074, 6285, NULL, 3843, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10075, 6286, NULL, 3845, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10076, 6287, NULL, 3845, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10077, 346, NULL, 3846, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17832, 8836, NULL, 782, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17833, 5790, NULL, 782, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17831, 5390, NULL, 782, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17842, 109, NULL, 5667, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17841, 916, NULL, 5667, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17843, 9170, NULL, 5667, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17835, 9167, NULL, 4505, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17834, 156, NULL, 4505, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17836, 9168, NULL, 4505, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17837, 1995, NULL, 5666, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17840, 347, NULL, 5666, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17838, 9169, NULL, 5666, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17845, 3713, NULL, 5668, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17846, 2652, NULL, 5668, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17848, 1345, NULL, 5668, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10078, 1311, NULL, 3846, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10079, 2696, NULL, 3847, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10080, 586, NULL, 3847, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10081, 482, NULL, 3848, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10082, 1696, NULL, 3848, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10083, 1956, NULL, 3848, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10084, 5256, NULL, 3849, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10085, 1106, NULL, 3849, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10086, 238, NULL, 3849, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9961, 5424, NULL, 1416, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9959, 5427, NULL, 1416, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32895, 589, NULL, 10187, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10087, 6288, NULL, 3849, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10088, 181, NULL, 3850, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10089, 6289, NULL, 3850, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10090, 1643, NULL, 3850, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10091, 1535, NULL, 3851, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10092, 1238, NULL, 3851, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10093, 2309, NULL, 3851, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10094, 962, NULL, 3852, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10095, 2436, NULL, 3852, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10096, 1380, NULL, 3852, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10097, 872, NULL, 3853, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10098, 4578, NULL, 3853, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10099, 2774, NULL, 3853, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10100, 4022, NULL, 3855, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10101, 995, NULL, 3855, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10102, 2671, NULL, 3855, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10103, 4106, NULL, 3856, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10104, 6290, NULL, 3856, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10105, 6291, NULL, 3856, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10106, 4939, NULL, 3857, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10107, 6292, NULL, 3857, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10108, 6293, NULL, 3857, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10109, 3321, NULL, 3859, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10110, 5189, NULL, 3861, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10111, 1544, NULL, 3861, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10112, 5191, NULL, 3861, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10113, 1884, NULL, 3862, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10114, 5115, NULL, 3862, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10115, 4034, NULL, 3862, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10116, 4841, NULL, 3862, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10117, 2818, NULL, 3862, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10118, 5962, NULL, 3862, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (10119, 6294, NULL, 3863, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10120, 6295, NULL, 3865, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10121, 6296, NULL, 3867, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10122, 6297, NULL, 3867, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10123, 6298, NULL, 3867, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10124, 923, NULL, 3868, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10125, 1331, NULL, 3868, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10126, 971, NULL, 3868, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10127, 1673, NULL, 3869, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10128, 692, NULL, 3869, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10129, 1997, NULL, 3869, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10130, 755, NULL, 3870, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10131, 1511, NULL, 3870, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10132, 2399, NULL, 3870, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10133, 2957, NULL, 3870, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10134, 939, NULL, 3871, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10135, 1380, NULL, 3871, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10136, 1781, NULL, 3871, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10137, 320, NULL, 3871, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10138, 3124, NULL, 3872, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10139, 987, NULL, 3872, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10140, 6299, NULL, 3872, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10141, 2874, NULL, 3872, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17862, 3521, NULL, 5673, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17863, 5036, NULL, 5673, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17864, 9175, NULL, 5673, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17865, 451, NULL, 5674, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17866, 3242, NULL, 5674, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17867, 5528, NULL, 5674, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17868, 1696, NULL, 5674, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17869, 9176, NULL, 5675, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17870, 6413, NULL, 5675, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17871, 5499, NULL, 5675, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17872, 6405, NULL, 5675, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17873, 9177, NULL, 5676, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17874, 9178, NULL, 5676, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17875, 9179, NULL, 5677, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17876, 9180, NULL, 5677, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17877, 8331, NULL, 5677, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17878, 7167, NULL, 5677, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17879, 5895, NULL, 5677, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17880, 9181, NULL, 5678, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17881, 9182, NULL, 5678, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17882, 2680, NULL, 5679, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17883, 7529, NULL, 5679, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17884, 2908, NULL, 5679, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17885, 9183, NULL, 5679, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17886, 9184, NULL, 5680, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17887, 162, NULL, 5680, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17888, 9185, NULL, 5680, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17889, 9186, NULL, 5680, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17890, 9187, NULL, 5681, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17891, 9188, NULL, 5681, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17892, 9189, NULL, 5681, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29307, 4913, NULL, 9138, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29308, 12399, NULL, 9138, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10142, 6300, NULL, 3872, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10143, 415, NULL, 3873, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10144, 3795, NULL, 3873, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10145, 6301, NULL, 3873, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10146, 1707, NULL, 3874, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10147, 1979, NULL, 3874, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10148, 1026, NULL, 3874, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10149, 842, NULL, 3874, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10150, 534, NULL, 3875, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10151, 688, NULL, 3875, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10152, 2091, NULL, 3875, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10153, 6302, NULL, 3875, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10154, 2883, NULL, 3876, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10155, 278, NULL, 3876, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10156, 6303, NULL, 3876, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10157, 1540, NULL, 3876, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10158, 4382, NULL, 3877, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10159, 6124, NULL, 3877, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10160, 41, NULL, 3877, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10161, 220, NULL, 3877, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10162, 372, NULL, 3878, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10163, 6304, NULL, 3878, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10164, 2818, NULL, 3878, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10165, 790, NULL, 3878, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10166, 1389, NULL, 3879, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10167, 219, NULL, 3879, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10168, 1450, NULL, 3879, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10169, 2737, NULL, 3879, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10170, 687, NULL, 3880, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10171, 156, NULL, 3880, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10172, 510, NULL, 3880, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10179, 5490, NULL, 3882, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10180, 2246, NULL, 3882, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10181, 3894, NULL, 3882, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10182, 6305, NULL, 3882, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10183, 6306, NULL, 3882, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10184, 186, NULL, 3884, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10185, 996, NULL, 3884, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10186, 98, NULL, 3884, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10187, 2136, NULL, 3884, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10188, 1624, NULL, 3885, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10189, 2543, NULL, 3885, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10190, 1721, NULL, 3886, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10191, 2511, NULL, 3886, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10192, 6308, NULL, 3886, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10193, 2552, NULL, 3886, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10194, 5958, NULL, 3886, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10195, 6309, NULL, 3887, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10196, 624, NULL, 3887, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10197, 6310, NULL, 3888, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10198, 430, NULL, 3888, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10199, 709, NULL, 3888, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10200, 6311, NULL, 3890, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10201, 2816, NULL, 3890, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10202, 424, NULL, 3890, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10203, 1013, NULL, 3892, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10204, 6312, NULL, 3892, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10205, 2202, NULL, 3892, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10206, 6314, NULL, 3893, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10207, 6315, NULL, 3893, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10208, 6316, NULL, 3894, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10209, 3318, NULL, 3894, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10210, 6317, NULL, 3894, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10211, 1460, NULL, 3894, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10212, 6318, NULL, 3895, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10213, 6319, NULL, 3895, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10214, 6320, NULL, 3895, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10215, 6321, NULL, 3896, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10216, 555, NULL, 3896, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10217, 4571, NULL, 3896, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17859, 9173, NULL, 5671, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17860, 778, NULL, 5671, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17857, 937, NULL, 5671, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17858, 9172, NULL, 5671, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17861, 9174, NULL, 5672, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10175, 384, NULL, 3881, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10174, 497, NULL, 3881, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10178, 503, NULL, 3881, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (10218, 650, NULL, 3896, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10219, 6322, NULL, 3896, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10220, 451, NULL, 3897, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10221, 2554, NULL, 3897, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10222, 2458, NULL, 3897, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10223, 4541, NULL, 3897, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10224, 2743, NULL, 3898, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10225, 4982, NULL, 3898, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10226, 2798, NULL, 3899, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10227, 2163, NULL, 3899, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10228, 1700, NULL, 3900, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10229, 730, NULL, 3900, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10230, 2691, NULL, 3900, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10231, 1198, NULL, 3901, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10232, 1699, NULL, 3901, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10233, 220, NULL, 3901, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17893, 9190, NULL, 5681, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17894, 9191, NULL, 5682, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17895, 9192, NULL, 5682, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17896, 6908, NULL, 5683, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17897, 6263, NULL, 5683, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17898, 9193, NULL, 5683, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17899, 9194, NULL, 5683, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17900, 1789, NULL, 5684, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17901, 2063, NULL, 5684, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17902, 2089, NULL, 5684, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17903, 5152, NULL, 5684, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17904, 6128, NULL, 5685, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17905, 9195, NULL, 5686, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17906, 9196, NULL, 5686, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17907, 2458, NULL, 5686, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17909, 4260, NULL, 216, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17910, 9197, NULL, 5687, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17911, 9198, NULL, 5687, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17912, 9199, NULL, 5687, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17913, 9200, NULL, 5687, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17914, 9201, NULL, 5688, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17915, 9202, NULL, 5688, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17916, 9203, NULL, 5688, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17917, 9204, NULL, 5688, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17918, 9205, NULL, 5689, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17919, 9206, NULL, 5689, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17920, 9207, NULL, 5689, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17921, 9208, NULL, 5690, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17922, 9209, NULL, 5690, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17927, 9213, NULL, 5692, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17928, 9214, NULL, 5692, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17929, 9215, NULL, 5692, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17930, 9216, NULL, 5693, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17931, 9217, NULL, 5693, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17932, 9218, NULL, 5694, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17933, 9219, NULL, 5694, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17934, 9220, NULL, 5695, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17935, 9221, NULL, 5695, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29309, 7156, NULL, 9139, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29310, 2874, NULL, 9139, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29311, 5148, NULL, 9139, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10234, 1926, NULL, 3901, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10235, 6323, NULL, 3902, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10236, 6324, NULL, 3902, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10237, 6325, NULL, 3902, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10238, 6326, NULL, 3903, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10239, 973, NULL, 3903, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10240, 5189, NULL, 3904, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10241, 1544, NULL, 3904, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10242, 5191, NULL, 3904, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10243, 6327, NULL, 3905, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10244, 2458, NULL, 3906, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10245, 6328, NULL, 3907, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10246, 1590, NULL, 3907, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10247, 4199, NULL, 3906, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10248, 6329, NULL, 3906, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10249, 51, NULL, 3906, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10250, 124, NULL, 3908, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10251, 2399, NULL, 3908, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10252, 6124, NULL, 3908, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10253, 6330, NULL, 2432, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10254, 6331, NULL, 2432, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10255, 6332, NULL, 2432, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10256, 6081, NULL, 2547, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10257, 2766, NULL, 2568, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17908, 7796, NULL, 3194, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33040, 13244, NULL, 10215, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33041, 10122, NULL, 10215, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10258, 3642, NULL, 2568, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10259, 6333, NULL, 3033, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10260, 6334, NULL, 3084, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10261, 6035, NULL, 3084, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10262, 5665, NULL, 3084, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10263, 382, NULL, 3087, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10264, 702, NULL, 3087, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10265, 1329, NULL, 3087, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10266, 497, NULL, 3087, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10267, 380, NULL, 3087, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10268, 424, NULL, 3087, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (10269, 3199, NULL, 3087, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (10270, 4854, NULL, 3087, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (10271, 1514, NULL, 3087, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (10272, 6335, NULL, 3793, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10273, 2673, NULL, 3793, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10274, 1721, NULL, 3793, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10275, 1503, NULL, 3793, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10276, 2802, NULL, 3793, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10277, 789, NULL, 3793, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (10278, 1513, NULL, 3793, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (10279, 2818, NULL, 3794, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10280, 6336, NULL, 3794, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10281, 3919, NULL, 3794, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10282, 1041, NULL, 3796, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10283, 1875, NULL, 3796, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10284, 397, NULL, 3796, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10285, 106, NULL, 3796, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10286, 1241, NULL, 3797, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10287, 2076, NULL, 3797, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10288, 2597, NULL, 3797, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10289, 3601, NULL, 3797, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10290, 805, NULL, 3858, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10291, 2214, NULL, 3858, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10292, 448, NULL, 3860, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10293, 1003, NULL, 3860, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10294, 1181, NULL, 3860, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10295, 757, NULL, 3860, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10296, 220, NULL, 3864, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10297, 1849, NULL, 3864, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10298, 6206, NULL, 3864, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10299, 1263, NULL, 3864, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10300, 6337, NULL, 3864, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10301, 1638, NULL, 3866, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10302, 2180, NULL, 3866, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10303, 6338, NULL, 3866, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10304, 6339, NULL, 3866, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10305, 4395, NULL, 3866, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10306, 6340, NULL, 3883, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10307, 2773, NULL, 3883, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10308, 3013, NULL, 3883, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10309, 6341, NULL, 3883, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10310, 998, NULL, 3909, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10311, 6342, NULL, 3909, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10312, 6343, NULL, 3909, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10313, 778, NULL, 3910, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10314, 429, NULL, 3910, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10315, 1958, NULL, 3910, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10316, 2827, NULL, 3910, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10317, 3149, NULL, 3910, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10318, 2001, NULL, 3911, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10319, 4727, NULL, 3911, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10320, 2874, NULL, 3911, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10321, 1059, NULL, 3912, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10322, 1101, NULL, 3912, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10323, 2806, NULL, 3912, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10324, 1226, NULL, 3912, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10325, 6344, NULL, 3913, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10326, 510, NULL, 3913, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17936, 9222, NULL, 5695, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17937, 9223, NULL, 5695, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17942, 9228, NULL, 5697, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17943, 9229, NULL, 5698, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17944, 9230, NULL, 5698, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17945, 9231, NULL, 5699, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17946, 9232, NULL, 5699, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17947, 9233, NULL, 5699, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17948, 9234, NULL, 5700, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17949, 9235, NULL, 5700, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17950, 9236, NULL, 5700, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17951, 9237, NULL, 5700, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17952, 9238, NULL, 5701, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17953, 696, NULL, 5702, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17954, 2765, NULL, 5702, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17955, 9165, NULL, 5702, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17956, 2768, NULL, 5702, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17957, 1530, NULL, 5703, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17958, 2234, NULL, 5703, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17959, 89, NULL, 5703, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17960, 2953, NULL, 5703, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17961, 1287, NULL, 5704, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17962, 20, NULL, 5704, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17963, 1352, NULL, 5704, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17964, 1192, NULL, 5704, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17969, 197, NULL, 5706, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17970, 708, NULL, 5706, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17971, 515, NULL, 5706, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17972, 2787, NULL, 5706, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17973, 7797, NULL, 5707, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17974, 9251, NULL, 5707, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17975, 754, NULL, 5707, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17968, 2107, NULL, 5705, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17966, 9249, NULL, 5705, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17965, 1144, NULL, 5705, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17967, 9250, NULL, 5705, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17976, 8707, NULL, 5707, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17977, 1126, NULL, 5708, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29312, 1882, NULL, 9140, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29313, 209, NULL, 9140, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29314, 1628, NULL, 9140, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29315, 586, NULL, 9140, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10327, 430, NULL, 3914, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10328, 6345, NULL, 3914, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10329, 405, NULL, 3914, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10330, 5506, NULL, 3914, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10331, 4382, NULL, 2723, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10332, 914, NULL, 2723, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10333, 2967, NULL, 2723, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10334, 1926, NULL, 2723, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10335, 1328, NULL, 2723, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10336, 1328, NULL, 1358, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10337, 1328, NULL, 125, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10338, 2596, NULL, 3916, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10339, 196, NULL, 3916, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10340, 5965, NULL, 3916, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10341, 3241, NULL, 3917, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10342, 6346, NULL, 3917, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10343, 6347, NULL, 3917, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10344, 6348, NULL, 3917, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10345, 6349, NULL, 3918, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10346, 6350, NULL, 3918, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10347, 6351, NULL, 3918, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10348, 2686, NULL, 3919, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10349, 3235, NULL, 3920, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10350, 6352, NULL, 3920, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10351, 6353, NULL, 3920, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10352, 6354, NULL, 3920, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10353, 6355, NULL, 3921, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10354, 4273, NULL, 3921, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10355, 6356, NULL, 3921, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10356, 6357, NULL, 3921, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10357, 1059, NULL, 3922, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10358, 1462, NULL, 3922, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10359, 3919, NULL, 3922, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10360, 5126, NULL, 3922, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10361, 6358, NULL, 3923, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10362, 6359, NULL, 3923, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10363, 6360, NULL, 3924, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10364, 6361, NULL, 3924, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10365, 6362, NULL, 3924, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10366, 6363, NULL, 3925, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10367, 6364, NULL, 3925, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10368, 6365, NULL, 3925, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10369, 6366, NULL, 3925, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10370, 430, NULL, 3926, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10371, 687, NULL, 3926, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10372, 100, NULL, 3926, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10373, 498, NULL, 3926, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10374, 6367, NULL, 3319, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10375, 6368, NULL, 3319, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10376, 6369, NULL, 3319, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10377, 534, NULL, 3320, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10378, 3086, NULL, 3320, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10379, 868, NULL, 3320, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10380, 6370, NULL, 3320, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10381, 1008, NULL, 3321, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10382, 6371, NULL, 3321, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10383, 1356, NULL, 3321, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10384, 3550, NULL, 3321, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10385, 1748, NULL, 3322, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10386, 3199, NULL, 3322, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10387, 2921, NULL, 3322, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10388, 3870, NULL, 3322, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10389, 248, NULL, 3323, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10390, 1919, NULL, 3323, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10391, 6372, NULL, 3323, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10392, 3622, NULL, 3323, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10393, 413, NULL, 3324, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10394, 71, NULL, 3324, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10395, 3072, NULL, 3324, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10396, 807, NULL, 3325, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10397, 3053, NULL, 3325, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10398, 1014, NULL, 3325, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10399, 1721, NULL, 3325, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10400, 1154, NULL, 3326, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10401, 6373, NULL, 3326, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10402, 90, NULL, 3326, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10403, 5956, NULL, 3326, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10408, 382, NULL, 3328, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10409, 497, NULL, 3328, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10410, 685, NULL, 3328, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10411, 6374, NULL, 3328, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10412, 6375, NULL, 3328, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10413, 3146, NULL, 3328, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (10414, 56, NULL, 3328, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (10415, 769, NULL, 3329, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10416, 6376, NULL, 3329, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10417, 661, NULL, 3329, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10418, 1433, NULL, 3329, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17978, 5471, NULL, 5708, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17979, 9028, NULL, 5708, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17980, 106, NULL, 5709, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17981, 9025, NULL, 5709, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17982, 9252, NULL, 5709, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17983, 8840, NULL, 5710, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17984, 2717, NULL, 5710, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17985, 6589, NULL, 5710, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17986, 2498, NULL, 5710, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17987, 7779, NULL, 5711, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17988, 7581, NULL, 5711, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17989, 2335, NULL, 5711, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17990, 9253, NULL, 5711, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17991, 7773, NULL, 5712, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17992, 9254, NULL, 5712, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17993, 9255, NULL, 5712, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17994, 9256, NULL, 5712, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18005, 7774, NULL, 5716, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18006, 9260, NULL, 5716, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18007, 9258, NULL, 5716, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18008, 9261, NULL, 5716, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18012, 7772, NULL, 5718, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18013, 8674, NULL, 5718, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18014, 6458, NULL, 5718, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18015, 9263, NULL, 5718, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18029, 2594, NULL, 5723, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18030, 9267, NULL, 5723, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29316, 10990, NULL, 9141, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10419, 806, NULL, 3330, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10420, 6377, NULL, 3330, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10421, 463, NULL, 3330, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10422, 141, NULL, 3330, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10423, 6378, NULL, 3331, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10424, 1329, NULL, 3331, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10425, 1834, NULL, 3331, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10426, 19, NULL, 3331, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10427, 448, NULL, 3927, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10428, 648, NULL, 3927, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10429, 5142, NULL, 3927, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10430, 2559, NULL, 3928, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10431, 1542, NULL, 3928, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10432, 346, NULL, 3928, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10433, 188, NULL, 3929, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10434, 5011, NULL, 3930, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10435, 372, NULL, 3930, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10436, 1893, NULL, 3930, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10437, 5109, NULL, 3931, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10438, 850, NULL, 3931, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10439, 5738, NULL, 2511, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10440, 372, NULL, 3933, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10441, 6222, NULL, 3933, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10442, 2645, NULL, 3933, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10443, 1497, NULL, 3934, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10444, 2279, NULL, 3934, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10445, 5738, NULL, 2960, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10446, 6379, NULL, 2965, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10447, 6259, NULL, 2532, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10448, 6381, NULL, 3649, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10449, 1995, NULL, 3649, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10450, 6382, NULL, 3649, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10451, 1919, NULL, 3936, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30677, 12864, NULL, 9571, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30678, 12865, NULL, 9571, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30676, 12863, NULL, 9571, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30675, 12533, NULL, 9571, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10452, 5260, NULL, 3936, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10453, 3859, NULL, 3936, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10454, 1455, NULL, 3936, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10455, 5240, NULL, 3936, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10456, 2786, NULL, 3936, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (10457, 5246, NULL, 3936, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (10458, 749, NULL, 3938, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10459, 1536, NULL, 3938, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10460, 2382, NULL, 3938, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10461, 6384, NULL, 3941, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10462, 4571, NULL, 3941, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10463, 3402, NULL, 3941, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10464, 6323, NULL, 3943, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10465, 6385, NULL, 3943, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10466, 6386, NULL, 3943, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10467, 1527, NULL, 3944, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18010, 9262, NULL, 5717, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18009, 2057, NULL, 5717, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18011, 4732, NULL, 5717, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10468, 4134, NULL, 3944, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10469, 1448, NULL, 3944, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10470, 297, NULL, 3944, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10471, 6267, NULL, 3945, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10472, 6387, NULL, 3945, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10473, 5346, NULL, 3947, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10474, 5126, NULL, 3948, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10475, 2104, NULL, 3948, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10476, 2106, NULL, 3946, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10477, 3025, NULL, 3946, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10478, 2054, NULL, 3950, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10479, 750, NULL, 3951, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10480, 6343, NULL, 3952, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10481, 2967, NULL, 3953, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10482, 601, NULL, 3954, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10483, 687, NULL, 3955, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10484, 1673, NULL, 3957, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10485, 1257, NULL, 3957, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10486, 1513, NULL, 3957, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10487, 382, NULL, 3958, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10488, 1329, NULL, 3958, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10489, 685, NULL, 3958, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10490, 789, NULL, 3958, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10491, 497, NULL, 3958, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10492, 835, NULL, 3958, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (10493, 1834, NULL, 3958, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (10494, 2903, NULL, 3958, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (10495, 5123, NULL, 3959, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10496, 6389, NULL, 3959, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10497, 1460, NULL, 3960, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10498, 295, NULL, 3960, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10499, 2696, NULL, 3960, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10500, 152, NULL, 3960, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10501, 6390, NULL, 3960, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10502, 724, NULL, 3960, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (10503, 100, NULL, 3961, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10504, 1989, NULL, 3961, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10505, 6391, NULL, 3961, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10506, 1620, NULL, 3962, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10507, 1091, NULL, 3963, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10508, 2823, NULL, 3964, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10509, 4414, NULL, 3965, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10510, 105, NULL, 3966, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10511, 2270, NULL, 3967, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10512, 374, NULL, 3968, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10513, 1541, NULL, 3968, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10514, 1374, NULL, 3968, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10515, 981, NULL, 3970, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10516, 717, NULL, 3971, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10517, 5177, NULL, 3972, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10518, 6392, NULL, 3973, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10519, 124, NULL, 3136, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10520, 2492, NULL, 3136, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10521, 952, NULL, 3136, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10522, 1778, NULL, 3136, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10523, 679, NULL, 3137, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10524, 8, NULL, 3137, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10525, 1875, NULL, 3137, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10526, 803, NULL, 3137, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10527, 872, NULL, 3138, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10528, 76, NULL, 3138, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10529, 2399, NULL, 3138, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10530, 2761, NULL, 3138, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10531, 761, NULL, 3139, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10532, 664, NULL, 3139, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10533, 302, NULL, 3139, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18002, 9259, NULL, 5715, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18001, 2388, NULL, 5715, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18022, 9024, NULL, 5721, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18025, 9266, NULL, 5721, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18024, 9029, NULL, 5721, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18023, 8851, NULL, 5721, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18017, 2048, NULL, 5719, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18016, 1137, NULL, 5719, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18018, 7778, NULL, 5720, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18019, 9264, NULL, 5720, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18021, 9265, NULL, 5720, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33042, 13947, NULL, 10215, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33039, 13923, NULL, 10215, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10534, 1481, NULL, 3139, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10535, 283, NULL, 3140, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10536, 1181, NULL, 3140, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10537, 1716, NULL, 3140, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10538, 4578, NULL, 3140, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10539, 1374, NULL, 3141, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10540, 2626, NULL, 3141, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10541, 2532, NULL, 3141, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10542, 1841, NULL, 3142, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29317, 6409, NULL, 9141, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10544, 2611, NULL, 3142, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10545, 812, NULL, 3142, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10546, 5738, NULL, 3974, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10547, 3517, NULL, 3974, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10548, 146, NULL, 3974, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18031, 9268, NULL, 5723, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18033, 9269, NULL, 5724, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18034, 2016, NULL, 5724, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18035, 4395, NULL, 5724, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18036, 2269, NULL, 5724, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18037, 2209, NULL, 5725, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18038, 2213, NULL, 5725, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18039, 2215, NULL, 5725, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18040, 2216, NULL, 5725, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18045, 939, NULL, 5727, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18046, 1598, NULL, 5727, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10543, 12082, NULL, 3142, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10549, 6383, NULL, 3975, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10550, 588, NULL, 3976, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10551, 915, NULL, 3976, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10552, 806, NULL, 3976, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10553, 2818, NULL, 3977, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10554, 5115, NULL, 3977, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10555, 1373, NULL, 3977, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10556, 6388, NULL, 3978, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10557, 4167, NULL, 3978, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10558, 2106, NULL, 3978, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10559, 534, NULL, 3979, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10560, 1655, NULL, 3979, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10561, 2492, NULL, 3979, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10562, 6393, NULL, 3980, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10563, 6394, NULL, 3980, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10564, 5500, NULL, 3980, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10565, 6395, NULL, 3980, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10566, 2696, NULL, 3981, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10567, 6396, NULL, 3981, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10568, 1958, NULL, 3981, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10569, 350, NULL, 1587, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10570, 1687, NULL, 1587, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10571, 1457, NULL, 1587, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10572, 1880, NULL, 1587, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10573, 451, NULL, 1590, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10574, 503, NULL, 1590, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10575, 3157, NULL, 1590, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10576, 1386, NULL, 1590, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10581, 534, NULL, 1591, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10582, 3013, NULL, 1591, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10583, 1696, NULL, 1591, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10584, 128, NULL, 1591, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10585, 1930, NULL, 1589, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10586, 713, NULL, 1589, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10587, 2806, NULL, 1589, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10588, 209, NULL, 1589, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10589, 1454, NULL, 1593, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10590, 6134, NULL, 1593, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10591, 1659, NULL, 1593, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10592, 2559, NULL, 1593, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10593, 1329, NULL, 1592, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10594, 1179, NULL, 1592, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10595, 2798, NULL, 1592, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10596, 648, NULL, 1592, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10597, 1620, NULL, 1868, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10598, 3321, NULL, 1874, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10599, 596, NULL, 1874, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10600, 4311, NULL, 1874, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10601, 4311, NULL, 3102, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10602, 2505, NULL, 3982, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10603, 1643, NULL, 3982, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10604, 242, NULL, 3982, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10605, 8, NULL, 3982, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10606, 1323, NULL, 3983, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10607, 1942, NULL, 3984, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10608, 1958, NULL, 3984, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10609, 1650, NULL, 3984, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10610, 1528, NULL, 3984, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10611, 750, NULL, 3984, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10612, 1779, NULL, 3985, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10613, 1876, NULL, 3985, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10614, 993, NULL, 3985, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10615, 6180, NULL, 3985, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10616, 6397, NULL, 3986, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10617, 1181, NULL, 3988, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10618, 760, NULL, 3988, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10619, 146, NULL, 3988, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10620, 2399, NULL, 3988, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32908, 2561, NULL, 10192, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32907, 9984, NULL, 10191, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10621, 156, NULL, 3989, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10622, 400, NULL, 3990, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10623, 778, NULL, 3990, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10624, 1331, NULL, 3990, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10625, 2878, NULL, 3991, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10626, 727, NULL, 3991, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10627, 2879, NULL, 3991, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10628, 5307, NULL, 3991, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10629, 6398, NULL, 3992, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10630, 1823, NULL, 3993, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10631, 2531, NULL, 3993, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10632, 812, NULL, 3993, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10633, 2822, NULL, 3994, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10634, 1077, NULL, 3994, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10635, 51, NULL, 3994, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10636, 3600, NULL, 3995, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10637, 119, NULL, 3995, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10638, 2804, NULL, 3995, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10639, 1778, NULL, 3995, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10640, 6399, NULL, 3996, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10641, 2688, NULL, 3996, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18047, 2473, NULL, 5727, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18048, 2294, NULL, 5727, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18053, 271, NULL, 5729, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18054, 2939, NULL, 5729, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18055, 9270, NULL, 5729, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18056, 910, NULL, 5729, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18057, 2534, NULL, 5729, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18058, 103, NULL, 5729, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18059, 5887, NULL, 5729, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (18060, 1457, NULL, 5730, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18061, 491, NULL, 5730, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18062, 8404, NULL, 5730, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18063, 8406, NULL, 5730, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18068, 967, NULL, 5732, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18069, 9272, NULL, 5732, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18070, 3428, NULL, 5732, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18071, 9273, NULL, 5732, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18072, 309, NULL, 5733, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18073, 1664, NULL, 5733, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18074, 1575, NULL, 5733, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18075, 5861, NULL, 5733, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18079, 1154, NULL, 5735, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18080, 2996, NULL, 5735, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18081, 2616, NULL, 5735, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18082, 2929, NULL, 5735, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18083, 1331, NULL, 5736, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18084, 9275, NULL, 5736, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18085, 9276, NULL, 5736, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18086, 770, NULL, 5736, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29318, 1527, NULL, 9142, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29319, 91, NULL, 9142, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29320, 1609, NULL, 9142, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29345, 12400, NULL, 9151, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29346, 12401, NULL, 9151, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29444, 812, NULL, 9187, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29445, 1291, NULL, 9187, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29446, 8316, NULL, 9187, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29447, 188, NULL, 9187, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29471, 2081, NULL, 9194, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29472, 2138, NULL, 9194, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29473, 1664, NULL, 9194, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29474, 376, NULL, 9194, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29531, 12416, NULL, 9217, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29532, 7159, NULL, 9217, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29533, 12417, NULL, 9217, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29534, 6898, NULL, 9218, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29536, 9552, NULL, 9220, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29542, 86, NULL, 9223, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29543, 1091, NULL, 9223, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29547, 1744, NULL, 9225, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18052, 3358, NULL, 5728, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18050, 5883, NULL, 5728, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18051, 1181, NULL, 5728, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18088, 2501, NULL, 706, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18087, 1459, NULL, 706, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18076, 84, NULL, 5734, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18078, 9274, NULL, 5734, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18077, 1117, NULL, 5734, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10642, 6400, NULL, 3996, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10643, 4859, NULL, 3996, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10644, 6401, NULL, 3997, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10645, 5034, NULL, 3997, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10646, 6402, NULL, 3997, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10647, 4003, NULL, 3997, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10648, 6403, NULL, 3998, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10649, 6404, NULL, 3998, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10650, 6405, NULL, 3998, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10651, 3383, NULL, 3999, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10652, 1848, NULL, 3999, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10653, 5118, NULL, 4000, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10654, 3158, NULL, 4001, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10655, 1106, NULL, 4001, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10656, 1038, NULL, 4001, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10657, 6406, NULL, 4002, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10658, 4208, NULL, 4003, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10659, 5256, NULL, 4003, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10660, 4444, NULL, 4003, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10661, 2922, NULL, 4003, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10662, 1046, NULL, 4003, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10663, 952, NULL, 4003, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (10664, 1989, NULL, 4003, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (10665, 100, NULL, 4003, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (10666, 6407, NULL, 4004, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10667, 4901, NULL, 4004, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10668, 6408, NULL, 4004, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10669, 5814, NULL, 4004, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10670, 750, NULL, 4004, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10671, 6409, NULL, 4005, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10672, 6410, NULL, 4005, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10673, 3795, NULL, 4005, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10674, 3140, NULL, 4005, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10675, 6047, NULL, 2139, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10676, 6047, NULL, 3809, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10678, 6047, NULL, 4005, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10679, 6411, NULL, 4006, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10680, 5201, NULL, 4007, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10681, 6412, NULL, 4007, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10682, 182, NULL, 4007, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10683, 6413, NULL, 4008, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10684, 5000, NULL, 4008, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10685, 2707, NULL, 4008, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10686, 6414, NULL, 4009, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10687, 5204, NULL, 4009, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10688, 6415, NULL, 4011, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10689, 2720, NULL, 4011, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10690, 6416, NULL, 4011, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10691, 3190, NULL, 4011, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10692, 408, NULL, 4013, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10693, 4363, NULL, 4013, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10694, 6418, NULL, 4014, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10695, 6417, NULL, 4014, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10696, 921, NULL, 4014, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10697, 347, NULL, 4014, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10698, 2455, NULL, 4015, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10699, 697, NULL, 4015, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10700, 2576, NULL, 4015, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10701, 6419, NULL, 4015, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10702, 2719, NULL, 4016, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10703, 6180, NULL, 4016, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10704, 1622, NULL, 4016, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10705, 952, NULL, 4018, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10706, 6420, NULL, 4018, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10707, 2945, NULL, 4018, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10708, 13, NULL, 4020, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10709, 6421, NULL, 4020, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10710, 10, NULL, 4020, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10711, 13, NULL, 93, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10712, 3156, NULL, 4021, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10713, 1940, NULL, 4021, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10714, 503, NULL, 4021, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10715, 411, NULL, 4025, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10716, 554, NULL, 4025, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10717, 6422, NULL, 4025, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10718, 357, NULL, 4027, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10719, 6423, NULL, 4027, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10720, 4986, NULL, 4030, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10721, 4987, NULL, 4030, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10722, 4988, NULL, 4030, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10723, 2129, NULL, 4032, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10724, 2900, NULL, 4032, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10725, 1067, NULL, 4034, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10726, 2186, NULL, 4034, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10727, 1666, NULL, 4034, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10728, 1376, NULL, 4034, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10729, 1672, NULL, 4035, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10730, 1701, NULL, 4035, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10731, 457, NULL, 4035, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10732, 388, NULL, 4036, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10733, 1665, NULL, 4036, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18091, 3137, NULL, 5737, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18092, 7282, NULL, 5737, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18093, 9278, NULL, 5737, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18094, 7797, NULL, 5737, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18095, 9279, NULL, 5738, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18096, 8499, NULL, 5738, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18097, 9280, NULL, 5738, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18098, 1894, NULL, 5738, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18099, 9281, NULL, 5739, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18100, 9282, NULL, 5739, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18101, 9283, NULL, 5739, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18102, 7903, NULL, 5739, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18103, 1922, NULL, 5740, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18104, 5283, NULL, 5740, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18105, 6055, NULL, 5740, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18106, 2971, NULL, 5740, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18107, 9284, NULL, 5741, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18108, 850, NULL, 5741, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18109, 1643, NULL, 5741, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18110, 1875, NULL, 5741, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18111, 2522, NULL, 5742, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18112, 812, NULL, 5742, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18113, 2544, NULL, 5742, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18114, 2451, NULL, 5742, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18119, 9286, NULL, 5744, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18120, 9287, NULL, 5744, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18121, 9288, NULL, 5744, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18122, 3061, NULL, 5745, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18123, 2992, NULL, 5745, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18124, 9289, NULL, 5745, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18125, 9290, NULL, 5745, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18126, 9291, NULL, 5746, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18127, 9292, NULL, 5746, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18128, 9293, NULL, 5746, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18129, 9294, NULL, 5746, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29321, 2645, NULL, 9143, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29322, 987, NULL, 9143, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29323, 5235, NULL, 9143, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29324, 6562, NULL, 9143, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29347, 12400, NULL, 9152, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29348, 12401, NULL, 9152, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29349, 4337, NULL, 9152, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29448, 12407, NULL, 9188, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29449, 3520, NULL, 9188, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29450, 3828, NULL, 9188, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (29451, 1118, NULL, 9188, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29452, 2442, NULL, 9188, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29453, 867, NULL, 9188, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29475, 1903, NULL, 9195, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29476, 6267, NULL, 9195, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29535, 12003, NULL, 9219, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29537, 12418, NULL, 9221, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29544, 5249, NULL, 9224, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29545, 11251, NULL, 9224, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29546, 6079, NULL, 9224, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29548, 497, NULL, 9226, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29549, 1513, NULL, 9226, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10734, 1598, NULL, 4036, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10735, 133, NULL, 4037, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10736, 2986, NULL, 4037, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10737, 1401, NULL, 4038, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10738, 497, NULL, 4038, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10739, 816, NULL, 4038, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10740, 955, NULL, 4039, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10741, 482, NULL, 4039, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10742, 396, NULL, 4040, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10743, 915, NULL, 4040, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10744, 199, NULL, 4041, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10745, 55, NULL, 4042, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10746, 3957, NULL, 4042, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10747, 3420, NULL, 4042, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10748, 3381, NULL, 4043, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10749, 3584, NULL, 4043, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10750, 318, NULL, 4043, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10751, 1389, NULL, 2690, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10752, 1415, NULL, 2690, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10753, 2396, NULL, 2690, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10754, 152, NULL, 2685, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10755, 1535, NULL, 2685, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10756, 63, NULL, 2685, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10757, 1106, NULL, 2689, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10758, 452, NULL, 2689, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10759, 1957, NULL, 2689, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10760, 1041, NULL, 2688, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10761, 2706, NULL, 2688, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10762, 601, NULL, 2688, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10763, 430, NULL, 2692, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10764, 448, NULL, 2684, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10765, 2922, NULL, 2684, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10766, 2961, NULL, 2684, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10767, 1458, NULL, 2691, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10768, 2761, NULL, 2691, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10774, 3600, NULL, 2687, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10775, 171, NULL, 2687, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10776, 2423, NULL, 2687, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10777, 423, NULL, 1790, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10778, 6427, NULL, 4044, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10779, 81, NULL, 4047, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10780, 1541, NULL, 4047, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10781, 91, NULL, 4047, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10782, 1505, NULL, 4047, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10783, 614, NULL, 4048, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10784, 2040, NULL, 4048, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10785, 1880, NULL, 4048, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10786, 320, NULL, 4048, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10787, 771, NULL, 4049, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10788, 239, NULL, 4049, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10789, 1997, NULL, 4049, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10790, 267, NULL, 4049, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10791, 3002, NULL, 4050, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10792, 1781, NULL, 4050, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10793, 803, NULL, 4050, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10794, 850, NULL, 4050, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10795, 6048, NULL, 4051, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10796, 15, NULL, 4051, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10797, 2480, NULL, 4052, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10798, 6444, NULL, 4053, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10799, 2161, NULL, 4053, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10800, 3565, NULL, 4053, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10801, 1095, NULL, 4054, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10802, 688, NULL, 4054, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10803, 2945, NULL, 4054, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10804, 952, NULL, 4054, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32910, 13880, NULL, 10192, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32909, 4255, NULL, 10192, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10809, 5926, NULL, 4056, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10810, 2645, NULL, 4056, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10811, 2001, NULL, 4056, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10812, 5237, NULL, 4056, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10813, 3433, NULL, 4057, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10814, 2882, NULL, 4057, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10815, 4039, NULL, 4057, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10816, 98, NULL, 4057, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10817, 1223, NULL, 4058, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10818, 3138, NULL, 4058, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10819, 68, NULL, 4058, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10820, 4085, NULL, 4058, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10821, 1662, NULL, 4059, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10822, 219, NULL, 4059, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10823, 425, NULL, 4059, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10824, 579, NULL, 2292, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10825, 542, NULL, 1449, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10826, 542, NULL, 1547, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33044, 12766, NULL, 10216, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33045, 9319, NULL, 10216, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29325, 939, NULL, 9144, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29326, 256, NULL, 9144, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29327, 5790, NULL, 9144, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29350, 12402, NULL, 9153, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29351, 5952, NULL, 9153, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29352, 12403, NULL, 9153, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29454, 10142, NULL, 9189, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29455, 1067, NULL, 9189, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29456, 3188, NULL, 9189, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29457, 12404, NULL, 9189, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29477, 7119, NULL, 9196, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18136, 9296, NULL, 4989, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18135, 2800, NULL, 4989, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18134, 1567, NULL, 4989, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18137, 3363, NULL, 4989, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18138, 2153, NULL, 4990, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18140, 9297, NULL, 4990, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18141, 913, NULL, 4990, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18142, 248, NULL, 4991, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18143, 488, NULL, 4991, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18144, 9298, NULL, 4991, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18145, 2714, NULL, 4991, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18148, 2532, NULL, 4992, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18149, 1334, NULL, 4992, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18146, 2798, NULL, 4992, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18147, 2860, NULL, 4992, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18151, 8287, NULL, 4993, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18152, 206, NULL, 4993, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18153, 3132, NULL, 4993, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18155, 9299, NULL, 4994, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18154, 1154, NULL, 4994, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18156, 4242, NULL, 4994, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18157, 9300, NULL, 4994, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18160, 423, NULL, 95, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18158, 1648, NULL, 95, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18161, 2954, NULL, 95, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18159, 1778, NULL, 95, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18165, 76, NULL, 4995, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18164, 220, NULL, 4995, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18162, 448, NULL, 4995, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18170, 9304, NULL, 259, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18169, 9303, NULL, 259, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18168, 9302, NULL, 259, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18167, 1779, NULL, 259, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18172, 9306, NULL, 4996, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18171, 9305, NULL, 4996, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10769, 382, NULL, 2686, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10773, 1329, NULL, 2686, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10771, 1638, NULL, 2686, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10770, 1655, NULL, 2686, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29478, 7123, NULL, 9196, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29479, 7129, NULL, 9196, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29538, 12419, NULL, 9222, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29539, 12420, NULL, 9222, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29540, 12421, NULL, 9222, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29541, 1934, NULL, 9222, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29551, 1748, NULL, 9226, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10827, 1647, NULL, 1449, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10828, 3412, NULL, 1449, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10829, 571, NULL, 1449, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10830, 4306, NULL, 1452, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10832, 2788, NULL, 3398, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10833, 430, NULL, 2385, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10834, 1263, NULL, 2385, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10835, 1778, NULL, 2385, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10837, 2696, NULL, 2386, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10838, 586, NULL, 2386, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10839, 2285, NULL, 2386, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10840, 429, NULL, 2386, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10841, 5123, NULL, 2387, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10842, 4839, NULL, 2387, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10843, 1884, NULL, 2387, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10844, 2822, NULL, 2387, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10848, 374, NULL, 2389, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10849, 1541, NULL, 2389, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10850, 1374, NULL, 2389, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10851, 1505, NULL, 2389, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10852, 448, NULL, 2390, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10853, 312, NULL, 2390, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10854, 378, NULL, 2390, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10855, 1424, NULL, 2390, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10856, 1942, NULL, 2391, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10857, 1528, NULL, 2391, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10858, 1455, NULL, 2391, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10859, 2786, NULL, 2391, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10860, 100, NULL, 2392, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10861, 2911, NULL, 2392, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10862, 1458, NULL, 2393, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10863, 2492, NULL, 2393, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10864, 2910, NULL, 2393, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10865, 171, NULL, 2393, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10866, 1431, NULL, 2394, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10867, 1997, NULL, 2394, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10868, 283, NULL, 2395, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10869, 955, NULL, 2395, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10870, 3912, NULL, 2395, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10871, 1629, NULL, 2395, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10874, 4090, NULL, 4061, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10875, 5091, NULL, 4061, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10876, 5839, NULL, 4061, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10877, 6324, NULL, 4062, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10878, 6325, NULL, 4062, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10879, 6478, NULL, 4063, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10880, 6479, NULL, 4063, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10881, 6480, NULL, 4064, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10882, 6481, NULL, 4064, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10883, 6482, NULL, 4064, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10884, 5283, NULL, 4064, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10885, 3676, NULL, 4065, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10886, 1665, NULL, 4066, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10887, 6483, NULL, 4066, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10888, 425, NULL, 4066, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10889, 6484, NULL, 4066, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10890, 1401, NULL, 4067, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10891, 2212, NULL, 4067, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10892, 2226, NULL, 4067, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10893, 6485, NULL, 4068, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10896, 3026, NULL, 4071, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10897, 6488, NULL, 4071, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10898, 6489, NULL, 4071, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10899, 692, NULL, 4072, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10900, 382, NULL, 4072, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10901, 408, NULL, 4073, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10902, 152, NULL, 4074, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10903, 5620, NULL, 4074, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10904, 1876, NULL, 4074, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10905, 1622, NULL, 4074, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10906, 3874, NULL, 4075, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10907, 2336, NULL, 4075, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10908, 935, NULL, 4075, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10909, 2719, NULL, 4078, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10910, 5738, NULL, 4079, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10911, 73, NULL, 4079, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10912, 6, NULL, 4079, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10913, 1351, NULL, 2237, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10914, 512, NULL, 552, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10915, 1826, NULL, 552, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10916, 5974, NULL, 552, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10917, 6505, NULL, 552, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10918, 283, NULL, 554, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32914, 143, NULL, 10194, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18187, 378, NULL, 5749, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18188, 9316, NULL, 5749, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18189, 9317, NULL, 5749, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18190, 6462, NULL, 5749, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18191, 1697, NULL, 5750, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18192, 9318, NULL, 5750, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18193, 3026, NULL, 5750, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18194, 8619, NULL, 5750, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18195, 436, NULL, 5751, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18196, 680, NULL, 5751, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18197, 1252, NULL, 5751, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18198, 513, NULL, 5751, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18202, 1255, NULL, 5753, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18203, 139, NULL, 5753, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18204, 4173, NULL, 5753, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18205, 8154, NULL, 5753, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18206, 9320, NULL, 5753, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18207, 9321, NULL, 5753, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18208, 5018, NULL, 5753, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (18209, 3224, NULL, 5753, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (18210, 284, NULL, 5753, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (18211, 2278, NULL, 5753, 10);
INSERT INTO 'tunesrecordingsmap' VALUES (29328, 790, NULL, 9145, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29329, 1373, NULL, 9145, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29330, 152, NULL, 9145, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29353, 6713, NULL, 9154, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29354, 5109, NULL, 9154, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29355, 796, NULL, 9154, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29458, 812, NULL, 9190, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29459, 1291, NULL, 9190, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29460, 12407, NULL, 9190, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29461, 3520, NULL, 9190, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29480, 1981, NULL, 9197, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29481, 2625, NULL, 9197, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29482, 168, NULL, 9197, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29483, 259, NULL, 9197, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29552, 448, NULL, 9227, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29553, 1374, NULL, 9227, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29554, 2430, NULL, 9227, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29555, 77, NULL, 9227, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29577, 2189, NULL, 9238, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29578, 12442, NULL, 9238, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29579, 5187, NULL, 9238, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29580, 12443, NULL, 9238, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10919, 1261, NULL, 554, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10920, 6507, NULL, 554, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10921, 5853, NULL, 554, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10922, 6508, NULL, 554, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10923, 6509, NULL, 555, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10894, 6486, NULL, 4069, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10895, 6487, NULL, 4069, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10836, 1648, 478, 2385, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10928, 6510, NULL, 557, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10929, 586, NULL, 558, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10930, 6422, NULL, 558, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10931, 6511, NULL, 558, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10932, 1903, NULL, 559, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10933, 3938, NULL, 559, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10934, 4734, NULL, 560, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10935, 4733, NULL, 560, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10936, 6512, NULL, 560, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10937, 6513, NULL, 560, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10938, 132, NULL, 561, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10939, 6514, NULL, 562, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10940, 6515, NULL, 563, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10941, 6516, NULL, 564, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10942, 2541, NULL, 564, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10943, 6517, NULL, 564, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10944, 2977, NULL, 564, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10945, 685, NULL, 565, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10946, 1834, NULL, 565, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10947, 1091, NULL, 565, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10948, 1503, NULL, 565, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10949, 382, NULL, 565, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10950, 424, NULL, 565, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18173, 9307, NULL, 4996, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18174, 9308, NULL, 4996, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18181, 9314, NULL, 5747, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18179, 774, NULL, 5747, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10845, 2336, NULL, 2388, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10847, 1006, NULL, 2388, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10846, 5786, NULL, 2388, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18213, 3184, NULL, 5754, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18215, 9324, NULL, 5754, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18212, 9322, NULL, 5754, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18183, 495, NULL, 5748, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18186, 1039, NULL, 5748, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18185, 1329, NULL, 5748, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10831, 10129, NULL, 828, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10954, 6521, NULL, 567, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10955, 1977, NULL, 568, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10956, 5068, NULL, 568, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10957, 5932, NULL, 568, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10958, 750, NULL, 568, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10959, 1401, NULL, 569, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10960, 6522, NULL, 569, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10961, 6523, NULL, 570, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10962, 6524, NULL, 570, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10963, 6180, NULL, 570, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10964, 1525, NULL, 571, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10965, 3679, NULL, 571, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10966, 1462, NULL, 571, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10967, 152, NULL, 571, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10968, 1095, NULL, 2220, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10969, 6525, NULL, 4080, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10970, 6526, NULL, 4080, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10971, 2662, NULL, 4080, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10972, 6527, NULL, 4081, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10973, 6528, NULL, 4081, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10974, 4779, NULL, 4081, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10975, 5621, NULL, 4082, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10976, 6529, NULL, 4082, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10977, 6530, NULL, 4082, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10978, 6531, NULL, 4083, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10979, 6532, NULL, 4083, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10980, 6036, NULL, 4083, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10981, 2596, NULL, 4084, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10982, 6533, NULL, 4084, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10983, 6534, NULL, 4084, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10984, 1068, NULL, 4084, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10985, 5629, NULL, 4085, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10986, 6535, NULL, 4085, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10987, 6536, NULL, 4085, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10988, 4493, NULL, 4086, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10989, 2807, NULL, 4086, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10990, 6537, NULL, 4087, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10991, 6538, NULL, 4087, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10992, 1167, NULL, 4088, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10993, 4785, NULL, 4088, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10994, 1022, NULL, 4088, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10995, 3513, NULL, 4088, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10996, 6539, NULL, 4089, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10997, 6253, NULL, 4089, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10998, 6540, NULL, 4089, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10999, 673, NULL, 4090, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11000, 3486, NULL, 4090, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11001, 2197, NULL, 4090, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11002, 6541, NULL, 4091, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11003, 6545, NULL, 4092, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11004, 6546, NULL, 4092, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11005, 6014, NULL, 4093, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11006, 6547, NULL, 4093, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11007, 6542, NULL, 4094, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11008, 6543, NULL, 4094, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11009, 6544, NULL, 4094, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11010, 2317, NULL, 2030, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11011, 424, NULL, 2191, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11012, 12, NULL, 2193, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11013, 5488, NULL, 2193, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11014, 150, NULL, 2193, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11015, 3324, NULL, 2193, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11016, 1597, NULL, 2195, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11017, 305, NULL, 2195, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11018, 306, NULL, 2195, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11019, 902, NULL, 2195, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10953, 6520, NULL, 566, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10951, 6518, NULL, 566, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10952, 6519, NULL, 566, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11020, 1329, NULL, 4095, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11021, 2698, NULL, 4095, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11022, 807, NULL, 4095, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11023, 1331, NULL, 4095, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11024, 2802, NULL, 4095, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11025, 1621, NULL, 4095, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11026, 6548, NULL, 4096, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11027, 1979, NULL, 4096, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11028, 789, NULL, 4096, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11029, 6549, NULL, 4096, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11030, 2055, NULL, 4097, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11031, 2055, NULL, 1545, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11032, 2055, NULL, 2731, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11033, 2055, NULL, 2738, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11035, 2055, NULL, 2963, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11036, 2055, NULL, 1012, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11037, 2055, NULL, 3535, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11039, 2055, NULL, 1683, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11040, 2055, NULL, 3131, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11041, 2055, NULL, 3001, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11042, 412, NULL, 4097, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11043, 642, NULL, 4097, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11044, 5106, NULL, 4097, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11045, 1970, NULL, 4097, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11046, 1700, NULL, 4097, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (11047, 256, NULL, 4097, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (11048, 6550, NULL, 4097, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18220, 981, NULL, 5756, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18221, 1926, NULL, 5756, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18222, 2391, NULL, 5756, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32915, 867, NULL, 10194, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33043, 13924, NULL, 10216, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33046, 13948, NULL, 10216, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18230, 73, NULL, 5759, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18231, 2967, NULL, 5759, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11049, 441, NULL, 4098, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11050, 5165, NULL, 4098, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11051, 1423, NULL, 4098, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11052, 3400, NULL, 4098, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11053, 5486, NULL, 4098, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11054, 3324, NULL, 4098, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11055, 2399, NULL, 4098, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (11056, 146, NULL, 4098, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (11057, 955, NULL, 4098, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (11058, 448, NULL, 4099, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11059, 220, NULL, 4099, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11060, 312, NULL, 4099, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11061, 2773, NULL, 4099, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11062, 132, NULL, 4099, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11063, 503, NULL, 4099, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11064, 188, NULL, 4099, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (11065, 3912, NULL, 4099, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (11066, 77, NULL, 4099, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (11067, 1593, NULL, 4100, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11068, 2737, NULL, 4100, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11069, 6551, NULL, 4100, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11070, 1628, NULL, 4100, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11071, 1112, NULL, 4100, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11072, 5549, NULL, 4100, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11073, 6552, NULL, 4100, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (11074, 6553, NULL, 4100, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (11075, 6127, NULL, 4100, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (11076, 430, NULL, 4101, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11077, 100, NULL, 4101, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11078, 5738, NULL, 4101, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11079, 1849, NULL, 4101, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11080, 5557, NULL, 4101, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11081, 6554, NULL, 4101, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11082, 1638, NULL, 4102, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11083, 4003, NULL, 4102, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11084, 6555, NULL, 4102, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11085, 6556, NULL, 4102, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11086, 857, NULL, 4102, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11087, 3242, NULL, 4102, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11088, 3146, NULL, 4102, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (11089, 5268, NULL, 4102, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (11090, 2582, NULL, 4102, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (11091, 230, NULL, 2119, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11092, 2837, NULL, 2633, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9709, 2543, NULL, 2566, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11093, 5955, NULL, 2636, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11094, 6557, NULL, 2638, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11095, 6558, NULL, 4103, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11096, 6314, NULL, 4103, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11097, 6559, NULL, 4104, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11098, 6560, NULL, 4104, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11099, 6561, NULL, 4105, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11100, 4986, NULL, 4105, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11101, 6562, NULL, 4105, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11102, 5302, NULL, 4105, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11103, 1662, NULL, 4106, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11104, 3123, NULL, 4106, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11105, 732, NULL, 4106, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11106, 278, NULL, 4106, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11107, 1830, NULL, 4107, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11108, 2692, NULL, 4107, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11109, 1378, NULL, 4107, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11110, 6563, NULL, 4108, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11111, 6564, NULL, 4108, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11112, 6565, NULL, 4109, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11113, 6566, NULL, 4110, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11114, 6567, NULL, 4110, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11115, 6568, NULL, 4110, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11116, 6135, NULL, 1597, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11117, 6014, NULL, 1597, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11118, 6092, NULL, 1597, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11122, 6571, NULL, 2034, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11123, 5151, NULL, 2038, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11124, 6572, NULL, 2038, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11125, 1708, NULL, 2038, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11126, 1651, NULL, 1552, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11127, 3247, NULL, 1552, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11128, 6573, NULL, 1552, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11129, 215, NULL, 1552, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11034, 2055, NULL, 3076, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11130, 2299, NULL, 1553, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11131, 2892, NULL, 1553, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11132, 6574, NULL, 1553, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11133, 6575, NULL, 1553, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11134, 1689, NULL, 1554, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11135, 337, NULL, 1554, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11136, 1042, NULL, 1554, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11137, 2081, NULL, 1554, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11138, 141, NULL, 1554, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11139, 6576, NULL, 1554, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11140, 68, NULL, 1554, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (11141, 1052, NULL, 1554, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (18232, 5904, NULL, 5759, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18233, 1179, NULL, 5759, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18234, 1781, NULL, 5760, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18235, 9330, NULL, 5760, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18236, 2491, NULL, 5760, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18237, 9331, NULL, 5760, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18238, 7538, NULL, 5761, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18239, 8240, NULL, 5761, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18240, 5979, NULL, 5761, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18241, 1585, NULL, 5762, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18242, 1208, NULL, 5762, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18243, 2151, NULL, 5762, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18244, 402, NULL, 5763, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18245, 2773, NULL, 5763, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18246, 2386, NULL, 5763, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18247, 2358, NULL, 5763, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18248, 1355, NULL, 5764, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18249, 1988, NULL, 5764, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18250, 935, NULL, 5764, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18251, 3057, NULL, 5764, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18252, 3242, NULL, 5765, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18253, 840, NULL, 5766, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18254, 1748, NULL, 5767, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18255, 425, NULL, 5768, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18256, 867, NULL, 5770, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18257, 1331, NULL, 5771, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18258, 320, NULL, 5772, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18259, 1426, NULL, 5773, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18260, 201, NULL, 5774, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18261, 1592, NULL, 5774, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18262, 816, NULL, 5775, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18263, 122, NULL, 5776, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18264, 2821, NULL, 5765, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18265, 9333, NULL, 5765, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18266, 785, NULL, 5765, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18267, 182, NULL, 5766, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18268, 445, NULL, 5766, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18269, 2554, NULL, 5767, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18270, 9334, NULL, 5767, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18271, 7492, NULL, 5767, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18272, 2766, NULL, 5768, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18273, 4730, NULL, 5768, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29331, 3634, NULL, 9146, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29332, 1993, NULL, 9146, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29356, 3188, NULL, 9155, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29357, 12404, NULL, 9155, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29462, 6713, NULL, 9191, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11119, 819, NULL, 2029, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11120, 2290, NULL, 2029, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11121, 6569, NULL, 2029, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18227, 93, NULL, 5758, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18228, 9328, NULL, 5758, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18229, 9329, NULL, 5758, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29463, 5109, NULL, 9191, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29464, 796, NULL, 9191, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29484, 6251, NULL, 9198, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29556, 6081, NULL, 9228, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29557, 3383, NULL, 9228, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29581, 12444, NULL, 9238, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29582, 2757, NULL, 9238, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (29583, 2612, NULL, 9238, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (29584, 803, NULL, 9238, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (11142, 1995, NULL, 1555, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11143, 347, NULL, 1555, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11144, 2536, NULL, 1555, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11145, 481, NULL, 1555, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11146, 685, NULL, 1555, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11147, 2851, NULL, 1556, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11148, 6578, NULL, 1556, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11149, 6579, NULL, 1556, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11150, 2511, NULL, 1556, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11159, 3378, NULL, 1559, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11160, 305, NULL, 1559, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11161, 5859, NULL, 1559, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11162, 3033, NULL, 1559, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11163, 49, NULL, 1560, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11164, 3393, NULL, 1560, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11165, 2084, NULL, 1560, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11166, 5312, NULL, 1560, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11167, 371, NULL, 1561, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11168, 1769, NULL, 1561, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11169, 3405, NULL, 1562, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11170, 2118, NULL, 1562, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11171, 2522, NULL, 1562, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11172, 951, NULL, 1562, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11176, 6580, NULL, 1564, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11180, 4267, NULL, 652, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11181, 4267, NULL, 112, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11182, 4267, NULL, 2208, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11184, 3449, NULL, 2433, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11185, 589, NULL, 2433, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11186, 2064, NULL, 2433, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11187, 6459, NULL, 2433, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11188, 4280, NULL, 2434, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11189, 3601, NULL, 2434, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11190, 2546, NULL, 2434, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11191, 6582, NULL, 2434, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11192, 3427, NULL, 2435, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11193, 1636, NULL, 2435, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11194, 2448, NULL, 2435, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11195, 4462, NULL, 2436, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11196, 6302, NULL, 2436, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11197, 2957, NULL, 2436, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11198, 2165, NULL, 2436, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11199, 5515, NULL, 2436, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11200, 4583, NULL, 2437, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11201, 2496, NULL, 2437, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11202, 2691, NULL, 2437, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11203, 2347, NULL, 2437, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11204, 3226, NULL, 2438, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11205, 434, NULL, 2438, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11206, 973, NULL, 2438, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11207, 6581, NULL, 2438, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11208, 6583, NULL, 2439, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11209, 6584, NULL, 2439, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11210, 1392, NULL, 2439, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11211, 3816, NULL, 2440, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11212, 6585, NULL, 2440, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11213, 3798, NULL, 2440, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11214, 6586, NULL, 2440, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11215, 2253, NULL, 2441, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11216, 1282, NULL, 2441, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11217, 6587, NULL, 2441, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11218, 1722, NULL, 2441, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11219, 266, NULL, 2442, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11220, 3832, NULL, 2442, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11221, 1943, NULL, 2442, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11222, 2095, NULL, 2442, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11223, 4436, NULL, 2443, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11224, 4437, NULL, 2443, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11225, 1009, NULL, 2041, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11226, 2024, NULL, 2041, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11227, 2755, NULL, 2041, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11228, 2431, NULL, 2041, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11229, 2920, NULL, 4023, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11230, 2729, NULL, 4023, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11231, 920, NULL, 4023, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11232, 2118, NULL, 4023, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11233, 1219, NULL, 4028, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18274, 5931, NULL, 5768, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18275, 5837, NULL, 5769, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18276, 1020, NULL, 5769, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18277, 8343, NULL, 5769, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18278, 1814, NULL, 5770, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18279, 2448, NULL, 5770, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18280, 3507, NULL, 5770, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18281, 9335, NULL, 5770, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18282, 3113, NULL, 5770, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18283, 7212, NULL, 5770, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (18284, 346, NULL, 5770, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (18285, 4202, NULL, 5771, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18286, 1885, NULL, 5771, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18287, 3614, NULL, 5771, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18288, 3670, NULL, 5772, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18289, 2865, NULL, 5772, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18290, 1782, NULL, 5772, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18291, 9337, NULL, 5773, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18292, 2661, NULL, 5773, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18293, 4843, NULL, 5773, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18294, 1446, NULL, 5774, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18295, 4836, NULL, 5775, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18296, 1263, NULL, 5775, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18297, 2240, NULL, 5775, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18298, 2536, NULL, 5776, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18299, 1629, NULL, 5776, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11179, 4267, NULL, 1859, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11183, 5490, NULL, 1861, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11177, 5665, NULL, 3254, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11155, 2253, NULL, 1558, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18300, 2910, NULL, 5776, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18301, 247, NULL, 5777, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18302, 3601, NULL, 5777, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18303, 5187, NULL, 5777, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18304, 247, NULL, 5778, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18305, 2613, NULL, 5778, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18306, 2375, NULL, 5778, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18307, 173, NULL, 5779, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18308, 4413, NULL, 5779, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18309, 317, NULL, 5779, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18310, 1474, NULL, 5780, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18311, 1067, NULL, 5780, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18312, 1673, NULL, 5780, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18313, 2489, NULL, 5780, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18314, 1719, NULL, 5781, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18315, 312, NULL, 5781, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29333, 6286, NULL, 9147, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29334, 6287, NULL, 9147, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29358, 8316, NULL, 9156, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29359, 188, NULL, 9156, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29360, 173, NULL, 9156, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29465, 12405, NULL, 9192, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29466, 12406, NULL, 9192, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29467, 9829, NULL, 9192, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29485, 7031, NULL, 9199, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29558, 687, NULL, 9229, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29585, 833, NULL, 9239, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29586, 1527, NULL, 9239, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29587, 1431, NULL, 9239, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29623, 2724, NULL, 9251, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29624, 11963, NULL, 9251, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29629, 12456, NULL, 9253, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29630, 12457, NULL, 9253, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29631, 12458, NULL, 9253, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29632, 12459, NULL, 9254, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29633, 12460, NULL, 9254, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11234, 2759, NULL, 4028, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11235, 1987, NULL, 4028, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11236, 1917, NULL, 4028, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11237, 465, NULL, 1280, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11241, 2821, NULL, 2049, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11242, 2903, NULL, 2049, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (11243, 267, NULL, 2052, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (11244, 687, NULL, 3114, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11245, 4827, NULL, 1547, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11246, 1508, NULL, 4111, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11247, 2218, NULL, 4111, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11248, 2536, NULL, 4111, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11249, 1147, NULL, 4112, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11250, 1232, NULL, 4112, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11251, 62, NULL, 4112, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11252, 6046, NULL, 4113, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11253, 4727, NULL, 4113, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11254, 372, NULL, 4113, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11255, 1464, NULL, 4113, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11256, 962, NULL, 4115, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11257, 2436, NULL, 4115, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11258, 1380, NULL, 4115, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11259, 872, NULL, 4116, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11175, 1929, NULL, 1563, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11174, 2837, NULL, 1563, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11173, 1179, NULL, 1563, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11260, 4578, NULL, 4116, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11261, 2774, NULL, 4116, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11262, 1421, NULL, 4117, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11263, 1880, NULL, 4117, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11264, 1958, NULL, 4117, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11265, 132, NULL, 4118, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11266, 594, NULL, 4119, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11267, 2369, NULL, 4119, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11268, 1898, NULL, 4119, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11269, 1091, NULL, 4120, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11270, 4073, NULL, 4120, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11271, 992, NULL, 4120, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11272, 124, NULL, 4121, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11273, 952, NULL, 4121, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11274, 1406, NULL, 4121, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11275, 346, NULL, 4122, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11276, 1311, NULL, 4122, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11277, 5165, NULL, 4123, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11278, 146, NULL, 4123, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11279, 3424, NULL, 4123, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11284, 3035, NULL, 2354, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11285, 6589, NULL, 2354, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11286, 570, NULL, 2354, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11287, 6590, NULL, 2354, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11288, 6439, NULL, 2355, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11289, 2312, NULL, 2355, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11290, 6440, NULL, 2356, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11291, 6591, NULL, 2356, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11292, 6592, NULL, 2356, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11293, 6593, NULL, 2356, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11294, 5123, NULL, 2357, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11295, 601, NULL, 2357, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11296, 295, NULL, 2357, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11297, 724, NULL, 2357, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11298, 3289, NULL, 2358, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11299, 6594, NULL, 2358, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11300, 6595, NULL, 2358, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11301, 1208, NULL, 2358, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11302, 1882, NULL, 1437, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11303, 1882, NULL, 2077, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11304, 6596, NULL, 4125, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11305, 1373, NULL, 4125, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11306, 960, NULL, 4125, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11307, 1525, NULL, 4125, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11308, 283, NULL, 4127, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11309, 6302, NULL, 4127, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11310, 188, NULL, 4127, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11311, 3517, NULL, 4128, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11312, 73, NULL, 4128, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11313, 408, NULL, 4129, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11314, 4134, NULL, 4129, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11315, 6164, NULL, 4129, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11316, 448, NULL, 4130, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11317, 2773, NULL, 4130, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11318, 220, NULL, 4130, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11319, 3243, NULL, 2359, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11320, 6597, NULL, 2359, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11321, 443, NULL, 2359, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11322, 6438, NULL, 2360, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11323, 6598, NULL, 2360, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11324, 6599, NULL, 2360, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11325, 6600, NULL, 2360, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11326, 6437, NULL, 2361, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18316, 996, NULL, 5781, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18317, 4842, NULL, 5781, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18322, 698, NULL, 5783, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18323, 9287, NULL, 5783, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18324, 9288, NULL, 5783, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18325, 9341, NULL, 5783, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18326, 1583, NULL, 5784, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18327, 3009, NULL, 5784, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18328, 3158, NULL, 5784, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18329, 3002, NULL, 5784, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18330, 159, NULL, 5785, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18331, 68, NULL, 5785, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18332, 1864, NULL, 5785, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18333, 9342, NULL, 5785, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18334, 342, NULL, 5786, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18335, 76, NULL, 5786, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18336, 457, NULL, 5786, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18337, 1505, NULL, 5786, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18338, 808, NULL, 5787, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18339, 2399, NULL, 5787, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18340, 1424, NULL, 5787, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18341, 2860, NULL, 5787, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18351, 622, NULL, 5790, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18352, 9343, NULL, 5790, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18353, 9344, NULL, 5790, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18354, 9345, NULL, 5790, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18355, 624, NULL, 5791, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18356, 5480, NULL, 5791, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18357, 8817, NULL, 5791, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29335, 10295, NULL, 9148, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29336, 320, NULL, 9148, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29338, 2285, NULL, 9148, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29361, 12405, NULL, 9157, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29362, 12406, NULL, 9157, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29363, 9829, NULL, 9157, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29468, 812, NULL, 9193, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29469, 1291, NULL, 9193, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29470, 12408, NULL, 9193, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29486, 12411, NULL, 9200, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29487, 12412, NULL, 9200, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29488, 12413, NULL, 9200, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29489, 12414, NULL, 9200, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29559, 3646, NULL, 9230, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29560, 2442, NULL, 9230, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29561, 807, NULL, 9230, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29588, 12445, NULL, 9240, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29589, 12446, NULL, 9240, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29590, 12447, NULL, 9240, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29625, 512, NULL, 9252, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29626, 12455, NULL, 9252, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11282, 5218, NULL, 2353, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11281, 4013, NULL, 2353, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11280, 6442, NULL, 2353, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11283, 6588, NULL, 2353, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29634, 5304, NULL, 9255, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11327, 1318, NULL, 2361, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11328, 6601, NULL, 2361, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11329, 2670, NULL, 2361, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11330, 6443, NULL, 2362, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11331, 6602, NULL, 2362, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11332, 6603, NULL, 2362, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11333, 301, NULL, 2363, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11334, 5535, NULL, 2363, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11335, 3932, NULL, 2363, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11336, 297, NULL, 2363, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11337, 6441, NULL, 2364, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11338, 1322, NULL, 2364, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11339, 5663, NULL, 2364, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11340, 6436, NULL, 2365, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11341, 374, NULL, 2712, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11342, 3192, NULL, 2712, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11343, 6604, NULL, 2712, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11344, 1424, NULL, 2712, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11348, 2988, NULL, 2718, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11349, 1553, NULL, 2718, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11350, 318, NULL, 2718, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11352, 423, NULL, 2718, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11353, 789, NULL, 2718, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11354, 312, NULL, 2718, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (11355, 3156, NULL, 2718, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (11356, 77, NULL, 2718, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (11357, 1042, NULL, 2719, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11358, 2559, NULL, 2719, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11359, 867, NULL, 2719, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11360, 1091, NULL, 2719, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11361, 1329, NULL, 2719, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11362, 1503, NULL, 2719, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11363, 424, NULL, 2719, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (11364, 6606, NULL, 4131, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11365, 1525, NULL, 4131, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11366, 6607, NULL, 4131, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11367, 2055, NULL, 2720, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11368, 6551, NULL, 2720, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11369, 425, NULL, 2720, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11370, 2505, NULL, 2720, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11371, 2289, NULL, 2721, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11372, 1457, NULL, 2721, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11373, 2514, NULL, 2721, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11374, 6608, NULL, 2721, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11375, 448, NULL, 2716, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11376, 389, NULL, 2716, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11377, 220, NULL, 2716, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11378, 4076, NULL, 2716, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11379, 3785, NULL, 2717, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11380, 173, NULL, 2717, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11381, 6609, NULL, 2717, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11382, 3481, NULL, 2717, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11383, 2696, NULL, 2725, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11384, 2396, NULL, 2725, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11385, 850, NULL, 2725, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11386, 256, NULL, 2725, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11387, 1942, NULL, 2726, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11388, 1528, NULL, 2726, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11389, 6610, NULL, 2726, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11390, 6611, NULL, 2726, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11391, 146, NULL, 2714, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11392, 2307, NULL, 2714, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11393, 3324, NULL, 2714, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11394, 4085, NULL, 2714, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11395, 441, NULL, 2715, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11396, 2671, NULL, 2715, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11397, 1198, NULL, 2715, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11398, 156, NULL, 4132, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11399, 3433, NULL, 4132, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11400, 3946, NULL, 4132, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11401, 1593, NULL, 2724, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11402, 452, NULL, 2724, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11403, 1238, NULL, 2724, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11408, 430, NULL, 2722, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11409, 1027, NULL, 2722, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11410, 3912, NULL, 2722, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11411, 2240, NULL, 2722, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11417, 757, NULL, 4135, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11418, 4360, NULL, 4135, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18358, 3093, NULL, 5791, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18359, 770, NULL, 5792, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18360, 9346, NULL, 5792, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18361, 9347, NULL, 5792, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18362, 9348, NULL, 5792, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18363, 820, NULL, 5793, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18364, 6613, NULL, 5793, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18365, 9349, NULL, 5793, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18366, 9350, NULL, 5793, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18367, 1673, NULL, 5794, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18368, 9351, NULL, 5794, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18369, 2631, NULL, 5794, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18370, 355, NULL, 5794, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18371, 872, NULL, 5795, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18372, 9352, NULL, 5795, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18373, 1716, NULL, 5795, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18374, 2961, NULL, 5795, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18375, 1843, NULL, 5796, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18376, 9353, NULL, 5796, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18377, 578, NULL, 5797, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18378, 2427, NULL, 5797, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18379, 9354, NULL, 5797, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18380, 9355, NULL, 5797, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18381, 1627, NULL, 5798, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18382, 2809, NULL, 5798, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18383, 242, NULL, 5798, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18384, 6929, NULL, 5798, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18385, 124, NULL, 5799, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18386, 914, NULL, 5799, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18387, 2482, NULL, 5799, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18388, 6340, NULL, 5799, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18389, 479, NULL, 5800, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18390, 7657, NULL, 5800, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18391, 2344, NULL, 5800, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18392, 9046, NULL, 5800, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18393, 1041, NULL, 5801, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18394, 5995, NULL, 5801, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18395, 9356, NULL, 5801, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18396, 9357, NULL, 5801, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18397, 4365, NULL, 5596, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18398, 8596, NULL, 5802, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18399, 7944, NULL, 5802, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18400, 453, NULL, 5802, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29339, 5620, NULL, 9149, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29340, 6776, NULL, 9149, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29341, 6136, NULL, 9149, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29342, 5118, NULL, 9149, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29364, 12407, NULL, 9158, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29365, 3520, NULL, 9158, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29366, 3828, NULL, 9158, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29490, 9100, NULL, 9201, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29562, 1005, NULL, 9231, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29591, 644, NULL, 9241, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29592, 6079, NULL, 9241, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29627, 2069, NULL, 9252, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29628, 2576, NULL, 9252, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29635, 11327, NULL, 9255, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11419, 2988, NULL, 4135, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11420, 1926, NULL, 4135, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11421, 1462, NULL, 4136, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11422, 1089, NULL, 4136, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11423, 6614, NULL, 4136, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11424, 1294, NULL, 4136, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11425, 461, NULL, 4137, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11426, 793, NULL, 4137, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11427, 1664, NULL, 4137, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11428, 6615, NULL, 4137, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11429, 6616, NULL, 4138, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11430, 6617, NULL, 4138, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11431, 6618, NULL, 4138, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11432, 6619, NULL, 4139, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11433, 6620, NULL, 4139, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11434, 6621, NULL, 4139, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11435, 6622, NULL, 4139, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11436, 512, NULL, 4140, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11437, 5262, NULL, 4140, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11438, 1977, NULL, 4140, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11439, 6623, NULL, 4140, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11440, 1685, NULL, 4141, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11441, 6624, NULL, 4141, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11442, 448, NULL, 4142, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11443, 2165, NULL, 4142, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11444, 6061, NULL, 4142, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11445, 2889, NULL, 4142, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11450, 2798, NULL, 4144, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11451, 6626, NULL, 4144, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11452, 2038, NULL, 4144, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11453, 220, NULL, 4144, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11454, 81, NULL, 4145, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11455, 6627, NULL, 4145, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11456, 6628, NULL, 4145, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11457, 6629, NULL, 4145, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11458, 1662, NULL, 4146, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11404, 678, NULL, 4133, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11405, 1155, NULL, 4133, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11407, 1481, NULL, 4133, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11406, 1691, NULL, 4133, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11345, 1962, NULL, 2713, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11346, 2399, NULL, 2713, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11347, 4854, NULL, 2713, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11459, 2900, NULL, 4146, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11460, 5269, NULL, 4146, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11461, 2129, NULL, 4146, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11462, 2772, NULL, 1689, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11463, 1735, NULL, 2343, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11464, 6630, NULL, 2343, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11465, 6631, NULL, 2343, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11466, 2101, NULL, 2343, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11467, 1442, NULL, 2344, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11468, 6632, NULL, 2344, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11469, 6633, NULL, 2344, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11470, 196, NULL, 2344, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11471, 6634, NULL, 2345, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11472, 6635, NULL, 2345, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11473, 5615, NULL, 2345, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11474, 6636, NULL, 2345, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11475, 340, NULL, 2346, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11476, 6637, NULL, 2346, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11477, 5278, NULL, 2346, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11478, 1238, NULL, 2346, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11479, 1682, NULL, 2347, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11480, 2808, NULL, 2347, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11481, 5905, NULL, 2347, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11482, 955, NULL, 2347, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11483, 1194, NULL, 2348, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11484, 6638, NULL, 2348, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11485, 4267, NULL, 2348, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11486, 6639, NULL, 2348, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11487, 485, NULL, 2349, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11488, 905, NULL, 2349, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11489, 6640, NULL, 2349, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11490, 155, NULL, 2349, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11491, 1054, NULL, 2350, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11492, 1003, NULL, 2350, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11493, 2039, NULL, 2350, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11494, 1401, NULL, 2350, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11495, 1307, NULL, 2352, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11496, 1158, NULL, 2352, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11497, 914, NULL, 2352, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11498, 3268, NULL, 2352, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11499, 1585, NULL, 1644, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11500, 4164, NULL, 1644, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11501, 5662, NULL, 1644, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11502, 6644, NULL, 3057, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11503, 6645, NULL, 3062, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11504, 1566, NULL, 4147, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11505, 3431, NULL, 4147, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11506, 2847, NULL, 4147, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11507, 6646, NULL, 4148, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11508, 665, NULL, 4148, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11509, 5379, NULL, 4148, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11510, 2483, NULL, 4149, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11511, 951, NULL, 4149, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11512, 1291, NULL, 4149, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11513, 155, NULL, 4150, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11514, 6647, NULL, 4150, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11515, 3393, NULL, 4150, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11516, 4795, NULL, 4150, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11517, 156, NULL, 4151, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11518, 1052, NULL, 4152, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11519, 4365, NULL, 4152, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11520, 6011, NULL, 4152, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11521, 6648, NULL, 4152, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11522, 220, NULL, 4153, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11523, 1926, NULL, 4153, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11524, 2455, NULL, 4154, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11525, 1118, NULL, 4154, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11526, 1311, NULL, 4154, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11527, 1937, NULL, 4155, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11528, 1093, NULL, 4155, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11529, 2449, NULL, 4155, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11530, 2450, NULL, 4155, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11531, 6649, NULL, 4155, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11532, 6650, NULL, 4156, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11533, 6651, NULL, 4156, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11534, 6652, NULL, 4156, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11535, 489, NULL, 4156, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11536, 2214, NULL, 4157, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11537, 3903, NULL, 4157, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11545, 601, NULL, 4170, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11546, 5236, NULL, 4172, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11547, 5237, NULL, 4172, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11548, 5202, NULL, 4172, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18401, 1406, NULL, 5802, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18402, 828, NULL, 5803, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18403, 6534, NULL, 5803, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18404, 9359, NULL, 5803, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18405, 9360, NULL, 5803, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18406, 3826, NULL, 5804, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18407, 7283, NULL, 5804, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18408, 9341, NULL, 5804, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18409, 9288, NULL, 5804, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18410, 975, NULL, 5804, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18411, 3019, NULL, 5804, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18412, 9361, NULL, 5804, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (18413, 144, NULL, 5805, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18414, 1956, NULL, 5805, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18415, 2152, NULL, 5805, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18416, 3060, NULL, 5805, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11549, 4987, NULL, 4172, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11550, 6660, NULL, 2710, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11551, 6661, NULL, 2710, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11552, 6662, NULL, 2710, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11553, 6663, NULL, 2710, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11554, 6664, NULL, 2711, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11555, 6665, NULL, 2711, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11556, 6666, NULL, 2711, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11557, 6667, NULL, 2711, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11558, 4653, NULL, 2709, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11559, 6668, NULL, 2709, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11560, 652, NULL, 2709, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11561, 6669, NULL, 2709, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11562, 374, NULL, 2707, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11563, 1673, NULL, 2707, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11564, 1732, 65, 2707, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11565, 1401, NULL, 2708, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11566, 312, NULL, 2708, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11567, 133, NULL, 2708, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11568, 1263, NULL, 2708, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11569, 952, NULL, 2708, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11570, 5343, NULL, 2708, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11571, 6671, NULL, 2708, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (11572, 6672, NULL, 2708, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (11573, 382, NULL, 2708, 10);
INSERT INTO 'tunesrecordingsmap' VALUES (11577, 6673, NULL, 2500, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11578, 6674, NULL, 2033, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11579, 520, NULL, 533, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11580, 209, NULL, 533, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11581, 1590, NULL, 533, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11582, 1006, NULL, 533, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11583, 876, NULL, 534, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11584, 1226, NULL, 534, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11585, 964, NULL, 537, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11586, 299, NULL, 537, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11587, 2185, NULL, 537, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11588, 1628, NULL, 537, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11589, 6675, NULL, 1750, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11590, 876, NULL, 535, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11591, 128, NULL, 535, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11592, 1778, NULL, 535, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11593, 2871, NULL, 536, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11594, 6205, NULL, 536, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11595, 1450, NULL, 1956, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11596, 1238, NULL, 1956, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11597, 652, NULL, 1956, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11598, 1884, NULL, 1958, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11599, 730, NULL, 1958, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11600, 724, NULL, 1958, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11601, 5123, NULL, 1958, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11602, 2822, NULL, 1958, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11603, 5816, NULL, 1961, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11604, 6678, NULL, 1961, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11605, 998, NULL, 1964, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11606, 6679, NULL, 1964, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11607, 6680, NULL, 1964, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11608, 3477, NULL, 1967, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11609, 6681, NULL, 1967, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11610, 650, NULL, 1967, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11611, 129, NULL, 1968, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11613, 5154, NULL, 1968, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11614, 2645, NULL, 3112, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11615, 987, NULL, 3112, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11616, 5235, NULL, 3112, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11617, 6562, NULL, 3112, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11618, 1091, NULL, 3707, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11619, 155, NULL, 3707, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11620, 503, NULL, 3707, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11621, 194, NULL, 4019, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11622, 355, NULL, 4019, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11623, 2017, NULL, 4019, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11624, 2308, NULL, 4126, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11625, 6682, NULL, 4126, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11626, 610, NULL, 4159, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11627, 1393, NULL, 4159, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11628, 1147, NULL, 4159, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11629, 1219, NULL, 4159, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11630, 578, NULL, 4160, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11631, 234, NULL, 4160, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11632, 6683, NULL, 4160, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11633, 305, NULL, 4160, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11634, 3003, NULL, 4161, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11635, 691, NULL, 4161, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11636, 1373, NULL, 4161, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11637, 1553, NULL, 4162, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11638, 6676, NULL, 4162, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11639, 1235, NULL, 4162, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11640, 1325, NULL, 4162, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11641, 761, NULL, 4163, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18417, 4677, NULL, 5806, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18418, 1687, NULL, 5806, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18419, 9363, NULL, 5806, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18420, 9362, NULL, 5806, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18424, 1261, NULL, 5808, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18425, 4428, NULL, 5808, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18426, 7824, NULL, 5808, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18427, 8524, NULL, 5809, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18428, 7209, NULL, 5809, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18429, 9035, NULL, 5809, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18430, 9364, NULL, 5809, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18431, 1542, NULL, 5810, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18432, 2644, NULL, 5810, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18433, 2349, NULL, 5810, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18434, 1135, NULL, 5810, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18421, 3507, NULL, 5807, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18423, 2683, NULL, 5807, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18443, 1624, NULL, 5813, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18444, 1219, NULL, 5813, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18445, 7560, NULL, 5813, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18446, 4983, NULL, 5813, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18447, 267, NULL, 5813, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18448, 2165, NULL, 5813, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18449, 1140, NULL, 5813, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (18450, 2860, NULL, 5813, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (18451, 1566, NULL, 5814, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18452, 3394, NULL, 5814, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18453, 1091, NULL, 5814, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18454, 1821, NULL, 5814, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29343, 7157, NULL, 9150, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29344, 5255, NULL, 9150, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29367, 812, NULL, 9159, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29368, 1291, NULL, 9159, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29491, 1106, NULL, 9202, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29492, 2505, NULL, 9202, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29563, 10782, NULL, 9232, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29593, 1095, NULL, 9242, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29594, 2332, NULL, 9242, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29595, 487, NULL, 9242, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33047, 13925, NULL, 10217, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33050, 12709, NULL, 10217, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33049, 13949, NULL, 10217, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29596, 6764, NULL, 9242, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29597, 1448, NULL, 9242, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29636, 1421, NULL, 9256, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29637, 5256, NULL, 9256, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29638, 5068, NULL, 9256, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29684, 2680, NULL, 1730, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29685, 11438, NULL, 1730, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17086, 11201, NULL, 4154, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3516, 194, NULL, 1285, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29686, 7281, NULL, 9261, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29687, 1264, NULL, 9262, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29690, 1091, NULL, 9264, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11642, 1565, NULL, 4163, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11643, 1628, NULL, 4163, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11644, 1562, NULL, 4163, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11645, 1834, NULL, 4164, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11646, 909, NULL, 4164, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11647, 2670, NULL, 4164, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11648, 6677, NULL, 4164, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11649, 6684, NULL, 4165, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11650, 176, NULL, 4165, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11651, 71, NULL, 4165, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11652, 1083, NULL, 4166, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11653, 452, NULL, 4166, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11654, 6685, NULL, 4166, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11655, 1473, NULL, 4166, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11656, 4839, NULL, 4167, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11657, 6686, NULL, 4167, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11658, 6687, NULL, 4167, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11659, 6688, NULL, 2475, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11660, 749, NULL, 2472, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11661, 5015, NULL, 2472, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11662, 5319, NULL, 2472, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11663, 5320, NULL, 2472, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11664, 5321, NULL, 2472, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11665, 198, NULL, 2472, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11666, 6689, NULL, 2472, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (11667, 4541, NULL, 2468, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11668, 1979, NULL, 3170, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11669, 6693, NULL, 553, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18422, 1446, NULL, 5807, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11674, 6695, NULL, 1707, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11677, 5011, NULL, 1707, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11675, 6696, NULL, 1707, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11676, 5303, NULL, 1707, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11681, 1146, NULL, 1708, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11680, 2788, NULL, 1708, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11678, 1603, NULL, 1708, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11683, 1363, NULL, 1709, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11682, 644, NULL, 1709, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11684, 433, NULL, 1710, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11687, 615, NULL, 1710, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11686, 839, NULL, 1710, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11685, 1800, NULL, 1710, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11690, 1880, NULL, 1711, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11689, 2730, NULL, 1711, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11688, 520, NULL, 1711, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11691, 803, NULL, 1711, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11693, 2354, NULL, 1712, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11692, 5142, NULL, 1712, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11695, 2113, NULL, 1713, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11694, 430, NULL, 1713, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11697, 1862, NULL, 1713, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11698, 700, NULL, 1715, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11699, 1691, NULL, 1715, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18441, 9029, NULL, 5812, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18442, 9368, NULL, 5812, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18440, 9367, NULL, 5812, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18456, 834, NULL, 5815, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32924, 3284, NULL, 10197, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18458, 2571, NULL, 5815, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18457, 4239, NULL, 5815, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18455, 7825, NULL, 5815, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9710, 4492, NULL, 2566, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32926, 3286, NULL, 10197, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11720, 6704, NULL, 4173, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11721, 231, NULL, 4174, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11722, 2918, NULL, 433, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11723, 6705, NULL, 4176, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11724, 267, NULL, 4176, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11725, 534, NULL, 4176, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11726, 333, NULL, 4175, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11727, 6706, NULL, 4175, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11728, 3760, NULL, 4177, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11729, 2476, NULL, 4177, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11730, 6707, NULL, 4177, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11731, 3122, NULL, 4177, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11732, 6708, NULL, 4179, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11733, 1208, NULL, 4179, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18460, 3446, NULL, 5816, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18461, 9369, NULL, 5816, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18462, 7022, NULL, 5816, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18463, 9370, NULL, 5816, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18464, 8867, NULL, 5817, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18465, 9371, NULL, 5817, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18466, 4101, NULL, 5817, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18467, 8868, NULL, 5818, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18468, 8869, NULL, 5818, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18469, 8874, NULL, 5819, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18470, 692, NULL, 5819, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18471, 1542, NULL, 5819, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18472, 2413, NULL, 5819, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18473, 122, NULL, 3892, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18474, 122, NULL, 5820, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18475, 3324, NULL, 5820, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18476, 650, NULL, 5820, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18477, 1744, NULL, 5820, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18478, 523, NULL, 5821, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18479, 81, NULL, 5821, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18480, 6313, NULL, 5821, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18481, 1091, NULL, 5821, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18482, 8870, NULL, 5822, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18483, 4050, NULL, 5822, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18484, 9262, NULL, 5822, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18485, 1024, NULL, 5823, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18486, 9099, NULL, 5823, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18487, 8870, NULL, 5823, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18488, 8871, NULL, 5824, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18489, 1152, NULL, 5824, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18490, 563, NULL, 5824, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18491, 8875, NULL, 5825, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18492, 9372, NULL, 5825, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18493, 2792, NULL, 5825, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18494, 1535, NULL, 5825, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18495, 8872, NULL, 5826, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18496, 209, NULL, 5826, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18497, 724, NULL, 5826, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18498, 750, NULL, 5826, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18459, 7656, NULL, 5815, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29369, 1368, NULL, 9160, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29370, 333, NULL, 9160, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29371, 533, NULL, 9160, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29493, 1458, NULL, 9203, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29494, 2492, NULL, 9203, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29495, 2910, NULL, 9203, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29496, 171, NULL, 9203, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29598, 186, NULL, 9242, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (29599, 686, NULL, 9242, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (29600, 11915, NULL, 9242, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (29639, 430, NULL, 9257, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29640, 4752, NULL, 9257, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29641, 2772, NULL, 9257, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29642, 19, NULL, 9257, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29688, 2830, NULL, 9263, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29689, 12468, NULL, 9263, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29691, 9916, NULL, 9265, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11734, 6709, NULL, 4179, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11735, 6710, NULL, 4180, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11736, 6711, NULL, 4180, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11737, 3324, NULL, 4180, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11738, 156, NULL, 4181, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11739, 3582, NULL, 4182, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11740, 6712, NULL, 4182, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11741, 6273, NULL, 4183, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11742, 6713, NULL, 4183, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11743, 3810, NULL, 4183, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11744, 471, NULL, 4184, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11745, 6714, NULL, 4185, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11746, 2545, NULL, 4185, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11747, 6715, NULL, 4185, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11748, 172, NULL, 4186, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11749, 1117, NULL, 4186, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11750, 2620, NULL, 4186, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11751, 4569, NULL, 4187, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11752, 312, NULL, 4187, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11753, 2910, NULL, 4187, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11754, 6716, NULL, 4187, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11755, 4319, NULL, 4188, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11756, 1462, NULL, 4188, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11757, 578, NULL, 4188, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11758, 6717, NULL, 4188, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11759, 6718, NULL, 4188, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11760, 1541, NULL, 4188, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11761, 4685, NULL, 4189, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11762, 6719, NULL, 4189, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11763, 2943, NULL, 4189, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11764, 1628, NULL, 4189, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11765, 220, NULL, 4190, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11766, 914, NULL, 4190, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11767, 3013, NULL, 4190, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11768, 6720, NULL, 4190, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11769, 2696, NULL, 4191, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11770, 2737, NULL, 4191, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11771, 425, NULL, 4191, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11772, 3330, NULL, 4191, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11773, 3322, NULL, 4192, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11774, 2655, NULL, 4192, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11775, 3257, NULL, 4192, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11776, 1514, NULL, 4192, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11777, 4217, NULL, 4193, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11778, 806, NULL, 4193, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11779, 1026, NULL, 4193, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11780, 5037, NULL, 4193, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11781, 2144, NULL, 4193, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11782, 6721, NULL, 4193, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11783, 3012, NULL, 4193, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (11784, 2920, NULL, 4193, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (11785, 4466, NULL, 4194, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11786, 2860, NULL, 4194, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11787, 1926, NULL, 4194, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11788, 2386, NULL, 4194, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11789, 1567, NULL, 4195, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11790, 5211, NULL, 4195, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11791, 3220, NULL, 4195, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11792, 2967, NULL, 4195, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11793, 119, NULL, 4195, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11794, 687, NULL, 4195, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (11795, 6722, NULL, 4195, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11796, 371, NULL, 4196, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11797, 1769, NULL, 4196, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11798, 1540, NULL, 4197, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11799, 2786, NULL, 4197, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11800, 2063, NULL, 4197, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11801, 6723, NULL, 4198, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11802, 3311, NULL, 4198, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11803, 6724, NULL, 4198, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11804, 329, NULL, 4199, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11805, 2980, NULL, 4199, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11806, 6725, NULL, 4199, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11807, 4904, NULL, 4199, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11808, 6726, NULL, 4200, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11809, 6727, NULL, 4200, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11810, 6728, NULL, 4200, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11811, 256, NULL, 4201, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11812, 6729, NULL, 4201, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11813, 6730, NULL, 4201, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11814, 6731, NULL, 4201, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11815, 6732, NULL, 4202, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11816, 403, NULL, 4202, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11817, 3251, NULL, 4202, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11818, 1609, NULL, 4202, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11819, 6733, NULL, 4203, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11820, 6734, NULL, 4203, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11821, 6735, NULL, 4203, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11703, 6697, NULL, 1716, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11705, 2297, NULL, 1716, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11706, 6682, NULL, 3618, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11707, 2502, NULL, 3618, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11708, 6699, NULL, 3619, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11710, 6459, NULL, 4168, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11712, 6700, NULL, 4168, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11709, 1738, NULL, 4168, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11713, 791, NULL, 4169, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11715, 3116, NULL, 4169, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11714, 6701, NULL, 4169, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11716, 1537, NULL, 4169, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11719, 3821, NULL, 4171, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11717, 6702, NULL, 4171, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11718, 6703, NULL, 4171, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18500, 378, NULL, 5827, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18499, 1648, 477, 5827, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11822, 6736, NULL, 4203, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11823, 189, NULL, 4204, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11824, 2706, NULL, 4204, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11825, 1375, NULL, 4204, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11826, 1665, NULL, 4204, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18503, 996, NULL, 5828, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18504, 727, NULL, 5828, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18505, 6048, NULL, 5828, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18506, 9374, NULL, 5828, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18507, 8873, NULL, 5829, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18508, 9375, NULL, 5829, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18509, 189, NULL, 5829, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18510, 1897, NULL, 5829, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18511, 867, NULL, 5292, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18512, 1042, NULL, 5292, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18513, 9376, NULL, 5292, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18514, 1940, NULL, 5297, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18515, 4202, NULL, 5297, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18516, 9377, NULL, 5297, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18517, 7687, NULL, 5830, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18518, 265, NULL, 5831, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18519, 1358, NULL, 5832, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18520, 322, NULL, 5834, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18521, 4471, NULL, 5835, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18522, 4472, NULL, 5835, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18524, 9378, NULL, 5837, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18525, 9379, NULL, 5838, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18526, 9380, NULL, 5839, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18527, 276, NULL, 5840, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18528, 7626, NULL, 5841, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18529, 7896, NULL, 5842, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18531, 9382, NULL, 5844, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18532, 9381, NULL, 5830, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18533, 9383, NULL, 5830, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18534, 9384, NULL, 5830, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18535, 807, NULL, 5830, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18536, 9385, NULL, 5830, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18537, 5699, NULL, 5830, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (18538, 9386, NULL, 5831, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18539, 499, NULL, 5831, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18540, 9387, NULL, 5831, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18541, 2369, NULL, 5831, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18542, 4311, NULL, 5831, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (29372, 1118, NULL, 9161, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29373, 2442, NULL, 9161, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29374, 867, NULL, 9161, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29497, 7124, NULL, 9204, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29568, 6247, NULL, 9234, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29601, 5126, NULL, 9243, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29643, 5365, NULL, 9258, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29644, 2672, NULL, 9258, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29645, 2109, NULL, 9258, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29692, 12469, NULL, 9266, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29716, 11527, NULL, 9284, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29717, 6541, NULL, 9284, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29718, 8521, NULL, 9284, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11827, 1882, NULL, 4205, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11828, 1265, NULL, 4205, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11829, 1530, NULL, 4206, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11830, 2661, NULL, 4206, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11831, 3086, NULL, 4206, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11832, 6737, NULL, 4206, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11833, 1659, NULL, 4207, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11834, 2266, NULL, 4207, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11835, 1042, NULL, 4207, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11836, 1345, NULL, 4208, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11837, 1241, NULL, 4208, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11838, 2570, NULL, 4208, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11839, 2862, NULL, 4208, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11840, 4833, NULL, 4208, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11841, 145, NULL, 4208, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11842, 452, NULL, 4208, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (11843, 533, NULL, 4209, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11844, 333, NULL, 4209, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11845, 6738, NULL, 4209, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11846, 6739, NULL, 4209, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11847, 5017, NULL, 4210, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11848, 6740, NULL, 4210, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11849, 577, NULL, 4210, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11850, 6741, NULL, 4210, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11851, 6742, NULL, 4211, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11852, 2163, NULL, 4211, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11853, 6743, NULL, 4211, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11854, 6744, NULL, 4211, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11855, 6745, NULL, 4212, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11856, 6746, NULL, 4212, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11858, 1542, NULL, 3199, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11859, 5510, NULL, 3199, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11860, 601, NULL, 3198, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11861, 230, NULL, 4227, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11862, 295, NULL, 4228, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11863, 697, NULL, 4228, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11864, 850, NULL, 4228, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11865, 6747, NULL, 1492, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11866, 1496, NULL, 1492, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11867, 806, NULL, 1852, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11868, 1624, NULL, 1852, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11869, 1588, NULL, 1852, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11870, 5407, NULL, 1852, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11871, 5012, NULL, 3200, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11872, 6748, NULL, 1635, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11873, 6048, NULL, 1631, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11875, 6749, NULL, 2397, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11876, 5070, NULL, 2806, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11877, 6750, NULL, 4230, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11878, 6046, NULL, 4230, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11879, 791, NULL, 4231, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11880, 3498, NULL, 4231, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11881, 5056, NULL, 4231, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11882, 6751, NULL, 4232, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11883, 98, NULL, 4232, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11884, 3433, NULL, 4232, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11885, 1711, NULL, 4233, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11886, 986, NULL, 4233, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11887, 464, NULL, 4233, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18530, 1104, NULL, 5843, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11888, 1345, NULL, 4234, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11889, 6752, NULL, 4234, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11890, 2281, NULL, 4234, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11891, 1283, NULL, 4165, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11892, 128, NULL, 4235, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11893, 4075, NULL, 4235, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11894, 146, NULL, 4235, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11895, 724, NULL, 4236, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11896, 6753, NULL, 4236, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11897, 608, NULL, 4236, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11898, 6754, NULL, 4236, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11899, 329, NULL, 4237, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11900, 6755, NULL, 4237, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11901, 6756, NULL, 4237, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11902, 1048, NULL, 4237, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11903, 937, NULL, 4238, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11904, 6757, NULL, 4238, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11905, 778, NULL, 4238, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11906, 6758, NULL, 4238, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11907, 3371, NULL, 4239, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11908, 188, NULL, 4239, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11909, 1368, NULL, 4240, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11910, 698, NULL, 4240, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11911, 533, NULL, 4240, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11912, 382, NULL, 4241, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11913, 1629, NULL, 4241, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11914, 1496, NULL, 1427, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11915, 1902, NULL, 3212, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11916, 1902, NULL, 3865, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11918, 374, NULL, 4242, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18543, 9388, NULL, 5831, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (18544, 9389, NULL, 5832, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18545, 9390, NULL, 5832, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18546, 9391, NULL, 5832, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18547, 9392, NULL, 5832, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18548, 6707, NULL, 5832, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18552, 9396, NULL, 5834, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18553, 4994, NULL, 5834, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18554, 9397, NULL, 5834, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18555, 9398, NULL, 5835, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18556, 9399, NULL, 5835, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18559, 9401, NULL, 5837, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18560, 7858, NULL, 5837, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18561, 9402, NULL, 5837, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18562, 9403, NULL, 5838, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18563, 8908, NULL, 5838, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18564, 9404, NULL, 5838, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18565, 9405, NULL, 5839, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18566, 9406, NULL, 5839, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18567, 9407, NULL, 5839, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18568, 8959, NULL, 5840, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18569, 9408, NULL, 5840, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18570, 9409, NULL, 5840, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18571, 7409, NULL, 5840, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18572, 9410, NULL, 5840, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18550, 9394, NULL, 5833, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18551, 9395, NULL, 5833, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29720, 124, NULL, 9286, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29722, 952, NULL, 9286, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29721, 2492, NULL, 9286, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18573, 834, NULL, 5840, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (18574, 9411, NULL, 5841, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18575, 971, NULL, 5841, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18576, 9412, NULL, 5841, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18577, 803, NULL, 5845, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18578, 8794, NULL, 5845, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18579, 6575, NULL, 5845, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18580, 1894, NULL, 5845, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18581, 3381, NULL, 5846, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18582, 76, NULL, 5846, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18583, 4444, NULL, 5846, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18584, 1514, NULL, 5846, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18585, 673, NULL, 5847, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29375, 812, NULL, 9162, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29376, 1291, NULL, 9162, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29377, 12408, NULL, 9162, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29498, 2871, NULL, 9205, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29499, 1848, NULL, 9205, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29569, 1888, NULL, 9235, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29570, 2006, NULL, 9235, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29571, 5262, NULL, 9235, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29602, 12448, NULL, 9244, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29603, 12449, NULL, 9244, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29604, 12421, NULL, 9244, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29605, 12450, NULL, 9244, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29646, 4104, NULL, 9259, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29647, 4077, NULL, 9259, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29693, 778, NULL, 9267, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29694, 2814, NULL, 9267, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29719, 12476, NULL, 9285, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29724, 12477, NULL, 9287, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11919, 1263, NULL, 4242, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11920, 2387, NULL, 4242, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11921, 230, NULL, 1408, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11922, 448, NULL, 4243, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11923, 3779, NULL, 4243, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11924, 1514, NULL, 4243, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11925, 601, NULL, 4244, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11926, 1043, NULL, 4245, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11927, 1979, NULL, 4245, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11928, 1402, NULL, 4245, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11929, 1095, NULL, 4246, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11930, 2773, NULL, 4246, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11931, 1401, NULL, 4246, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11932, 1586, NULL, 4247, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11933, 5142, NULL, 4247, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11934, 4101, NULL, 4247, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32930, 4894, NULL, 10199, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11936, 6761, NULL, 4248, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11937, 194, NULL, 4249, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11938, 355, NULL, 4249, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11939, 2017, NULL, 4249, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11940, 6562, NULL, 4250, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11941, 6762, NULL, 4250, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11942, 5236, NULL, 4250, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11943, 5235, NULL, 4250, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11944, 4987, NULL, 4250, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11945, 424, NULL, 4251, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11946, 1331, NULL, 4251, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11947, 49, NULL, 4251, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11948, 2696, NULL, 4252, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11949, 2139, NULL, 4252, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11951, 6485, NULL, 4253, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11952, 2136, NULL, 4254, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11953, 2451, NULL, 4254, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11954, 228, NULL, 4254, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11955, 6763, NULL, 4255, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11956, 2139, NULL, 4255, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11957, 470, NULL, 4256, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11958, 4350, NULL, 4256, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11959, 2554, NULL, 4256, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11960, 461, NULL, 3626, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18558, 2281, NULL, 5836, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11961, 1643, NULL, 3626, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11962, 1875, NULL, 3626, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11963, 713, NULL, 3626, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11964, 709, NULL, 3627, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11965, 6764, NULL, 3627, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11966, 2882, NULL, 3627, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11967, 6765, NULL, 3628, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11968, 1525, NULL, 3629, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11969, 2719, NULL, 3629, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11970, 6766, NULL, 3629, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11971, 4077, NULL, 3630, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11972, 3912, NULL, 3631, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11973, 77, NULL, 3631, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11974, 2696, NULL, 3632, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11975, 1882, NULL, 3632, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11976, 778, NULL, 3632, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11977, 1592, NULL, 3633, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11978, 1659, NULL, 3633, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11979, 2587, NULL, 3633, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11980, 822, NULL, 3634, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11981, 1464, NULL, 3635, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11982, 5066, NULL, 3635, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11983, 6768, NULL, 3635, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11984, 5118, NULL, 3635, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11985, 63, NULL, 3636, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11986, 2155, NULL, 3636, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11987, 405, NULL, 3636, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11988, 561, NULL, 3637, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11989, 13, NULL, 3637, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11990, 133, NULL, 3637, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11991, 2957, NULL, 3637, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11992, 2028, NULL, 4257, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11993, 2873, NULL, 4257, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11994, 5872, NULL, 4257, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11995, 3440, NULL, 4258, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11996, 5300, NULL, 4258, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11997, 2081, NULL, 4259, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11998, 292, NULL, 4259, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11999, 1052, NULL, 4259, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12000, 6008, NULL, 4260, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12001, 6767, NULL, 4260, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12002, 6769, NULL, 4261, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12003, 6770, NULL, 4262, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12004, 6771, NULL, 4263, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12005, 6772, NULL, 4263, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12006, 657, NULL, 4264, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12007, 2894, NULL, 4264, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12008, 3682, NULL, 4264, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12009, 6773, NULL, 4265, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12010, 5925, NULL, 4265, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12011, 2997, NULL, 4266, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12012, 6774, NULL, 4266, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12013, 6775, NULL, 4267, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12014, 1582, NULL, 4268, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12015, 2379, NULL, 4268, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12016, 2236, NULL, 4268, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12017, 5204, NULL, 4269, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12018, 6315, NULL, 4269, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12019, 812, NULL, 4270, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12020, 1043, NULL, 4270, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12021, 951, NULL, 4270, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12035, 5620, NULL, 1037, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12036, 6776, NULL, 1037, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12037, 6136, NULL, 1037, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12038, 5118, NULL, 1037, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18586, 652, NULL, 5847, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18587, 2943, NULL, 5847, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18588, 2505, NULL, 5847, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18589, 1460, NULL, 5848, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18590, 2069, NULL, 5848, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18591, 9429, NULL, 5848, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18592, 5901, NULL, 5848, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18597, 238, NULL, 5850, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18598, 9430, NULL, 5850, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18599, 1068, NULL, 5850, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18600, 4242, NULL, 5850, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18601, 152, NULL, 5851, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12050, 6361, NULL, 1254, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12051, 2249, NULL, 904, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12052, 803, NULL, 904, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12053, 2416, NULL, 904, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12054, 6601, NULL, 2657, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12055, 1132, NULL, 2376, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12057, 3513, NULL, 3221, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12058, 3513, NULL, 2569, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12135, 3401, NULL, 4219, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12060, 1198, NULL, 1063, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12061, 4983, NULL, 1063, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12062, 1716, NULL, 1063, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12067, 2611, NULL, 1065, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12068, 1659, NULL, 1065, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12069, 168, NULL, 1065, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12070, 259, NULL, 1065, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12071, 6224, NULL, 1066, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12072, 6256, NULL, 1068, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12073, 6257, NULL, 1068, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12074, 555, NULL, 1068, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12075, 5011, NULL, 1071, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12076, 5303, NULL, 1071, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12077, 1535, NULL, 1072, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12078, 8, NULL, 1072, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12079, 608, NULL, 1072, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12080, 1565, NULL, 1073, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12081, 5185, NULL, 1073, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12082, 1664, NULL, 1073, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12083, 6128, NULL, 1075, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12084, 84, NULL, 1076, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12085, 834, NULL, 1076, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12086, 41, NULL, 1077, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12087, 5343, NULL, 1077, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12088, 2880, NULL, 4273, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12089, 162, NULL, 4274, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12090, 756, NULL, 4274, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12091, 1608, NULL, 4274, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12092, 2838, NULL, 4275, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12093, 448, NULL, 4276, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12094, 955, NULL, 4276, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12095, 378, NULL, 4276, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12096, 2129, NULL, 4279, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12097, 3700, NULL, 4279, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12098, 848, NULL, 4282, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12099, 4740, NULL, 4282, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12100, 3919, NULL, 4282, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12101, 4656, NULL, 4282, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12102, 5053, NULL, 4281, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12103, 2467, NULL, 4281, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12104, 1044, NULL, 4281, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12105, 2840, NULL, 4281, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12106, 6179, NULL, 4283, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12107, 5287, NULL, 4284, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12108, 2696, NULL, 4285, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12109, 1880, NULL, 4285, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12110, 1112, NULL, 4285, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12111, 850, NULL, 4285, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12112, 5366, NULL, 4286, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12113, 5363, NULL, 4287, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12114, 132, NULL, 4288, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12115, 5433, NULL, 4290, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12116, 6779, NULL, 4290, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12117, 6780, NULL, 4290, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12118, 6781, NULL, 4213, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12119, 1001, NULL, 4213, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12120, 3825, NULL, 4214, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12121, 6782, NULL, 4215, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12122, 6783, NULL, 4215, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12123, 1087, NULL, 4215, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12124, 6784, NULL, 4216, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12125, 2712, NULL, 4216, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12126, 1745, NULL, 4217, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12127, 2181, NULL, 4217, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12128, 1311, NULL, 4217, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12129, 5286, NULL, 4217, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12130, 6785, NULL, 4218, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12131, 2888, NULL, 4218, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12132, 1581, NULL, 4218, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12136, 4364, NULL, 4220, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12042, 588, NULL, 1039, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12044, 6777, NULL, 1039, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12043, 4277, NULL, 1039, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12026, 914, NULL, 2054, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12025, 2492, NULL, 2054, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12024, 3600, NULL, 2054, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12045, 152, NULL, 1040, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12046, 6778, NULL, 1040, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12047, 2055, NULL, 1041, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12048, 452, NULL, 1041, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12049, 649, NULL, 1041, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12056, 219, NULL, 829, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12022, 220, NULL, 2053, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12023, 3013, NULL, 2053, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12027, 678, NULL, 2055, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12028, 1155, NULL, 2055, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12031, 1238, NULL, 1035, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12032, 1241, NULL, 1035, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12030, 1593, NULL, 1035, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12033, 755, NULL, 1036, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12034, 1179, NULL, 1036, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12039, 6336, NULL, 1038, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12041, 6393, NULL, 1038, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12040, 5499, NULL, 1038, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12137, 6787, NULL, 4220, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12138, 649, NULL, 4221, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12139, 6788, NULL, 4221, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12140, 6789, NULL, 4221, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12141, 6790, NULL, 4221, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18602, 2806, NULL, 5851, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18603, 9431, NULL, 5851, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18604, 1769, NULL, 5851, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18605, 955, NULL, 5852, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18606, 4983, NULL, 5852, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18607, 1716, NULL, 5852, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18608, 2860, NULL, 5852, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18609, 730, NULL, 5853, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18610, 9432, NULL, 5853, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18611, 625, NULL, 5853, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18612, 4791, NULL, 5853, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18613, 1691, NULL, 5854, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18614, 787, NULL, 5854, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18615, 6050, NULL, 5854, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18616, 9433, NULL, 5854, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18617, 1780, NULL, 5855, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18618, 2492, NULL, 5855, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18619, 9434, NULL, 5855, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18620, 2527, NULL, 5855, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18621, 1435, NULL, 5856, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18622, 697, NULL, 5856, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18623, 1370, NULL, 5856, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18624, 2396, NULL, 5856, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18625, 588, NULL, 4387, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18626, 4277, NULL, 4387, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18627, 6777, NULL, 4387, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18628, 81, NULL, 5857, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18629, 2614, NULL, 5858, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18630, 233, NULL, 5859, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18631, 9158, NULL, 5861, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18632, 9159, NULL, 5861, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18633, 854, NULL, 5862, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18634, 1620, NULL, 5863, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18635, 1331, NULL, 5864, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18636, 2588, NULL, 5865, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18637, 2676, NULL, 5865, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18639, 536, NULL, 5867, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18640, 808, NULL, 5868, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18641, 1361, NULL, 5870, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18642, 2846, NULL, 5871, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29378, 6713, NULL, 9163, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29379, 5109, NULL, 9163, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29572, 6343, NULL, 9236, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29606, 1708, NULL, 9245, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29648, 12461, NULL, 9260, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29649, 12462, NULL, 9260, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29650, 5896, NULL, 9260, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29651, 12463, NULL, 9260, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29695, 9916, NULL, 9268, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29696, 5956, NULL, 9268, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29725, 12478, NULL, 9288, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12145, 6792, NULL, 4223, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12146, 6793, NULL, 4223, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12147, 4757, NULL, 4223, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12148, 2646, NULL, 4223, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12149, 6794, NULL, 4224, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12150, 5573, NULL, 1067, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12151, 6795, NULL, 1067, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12152, 6796, NULL, 1067, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12153, 6797, NULL, 1069, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12154, 6798, NULL, 1069, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12155, 6799, NULL, 1069, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12156, 598, NULL, 1070, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12157, 6800, NULL, 1070, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12158, 6801, NULL, 1070, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12159, 6253, NULL, 1074, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12160, 4988, NULL, 1074, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12161, 6802, NULL, 1074, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12162, 6562, NULL, 1074, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12163, 6803, NULL, 3769, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12164, 6804, NULL, 4291, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12165, 6805, NULL, 4292, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12166, 6806, NULL, 4292, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12167, 6807, NULL, 4292, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12168, 6808, NULL, 4293, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12169, 6809, NULL, 4293, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12170, 6810, NULL, 4293, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12171, 6811, NULL, 4294, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12172, 825, NULL, 4295, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12173, 2093, NULL, 4295, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12174, 6812, NULL, 4295, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12175, 6813, NULL, 4296, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12176, 6814, NULL, 4296, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12177, 6815, NULL, 4297, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12178, 6816, NULL, 4297, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12179, 6817, NULL, 4297, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12180, 5367, NULL, 1206, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12181, 6818, NULL, 1206, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12182, 5632, NULL, 1206, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12183, 333, NULL, 1209, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12184, 5634, NULL, 1209, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12185, 1464, NULL, 1209, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18638, 3330, NULL, 5866, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12143, 430, NULL, 4222, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18643, 3938, NULL, 5869, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12144, 6791, NULL, 4222, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12142, 1775, NULL, 4222, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12187, 857, NULL, 2088, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (12188, 2536, NULL, 2088, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (12189, 4240, NULL, 2088, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (12190, 6819, NULL, 2088, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (12191, 4496, NULL, 2091, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (12192, 1713, NULL, 2091, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (12193, 2151, NULL, 3673, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (12194, 1334, NULL, 1042, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12195, 1146, NULL, 1042, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12196, 2605, NULL, 1042, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12197, 6168, NULL, 1042, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12198, 6820, NULL, 1043, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12199, 6821, NULL, 1044, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12200, 6808, NULL, 1045, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12201, 6822, NULL, 1045, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12202, 6823, NULL, 1045, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12203, 434, NULL, 1046, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12204, 6824, NULL, 1046, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12205, 973, NULL, 1046, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12206, 1660, NULL, 1046, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12207, 6825, NULL, 1047, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12208, 6826, NULL, 1048, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12209, 3477, NULL, 1049, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12210, 6681, NULL, 1049, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12211, 555, NULL, 1049, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12212, 3402, NULL, 1049, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12213, 6827, NULL, 1050, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12214, 5000, NULL, 1050, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12215, 730, NULL, 1050, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12216, 6393, NULL, 1050, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12217, 691, NULL, 1050, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12218, 2798, NULL, 1051, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12219, 2332, NULL, 1051, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12220, 3946, NULL, 1052, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12221, 6828, NULL, 1052, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12222, 1544, NULL, 1052, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12223, 6829, NULL, 1053, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12224, 6830, NULL, 1053, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12225, 6831, NULL, 1054, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12226, 6832, NULL, 1054, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12227, 6833, NULL, 1055, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12228, 6834, NULL, 1055, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12229, 6835, NULL, 1056, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12230, 6836, NULL, 1056, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12231, 6837, NULL, 1056, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12232, 539, NULL, 1057, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12233, 6838, NULL, 1057, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18644, 73, NULL, 5872, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18645, 2973, NULL, 5873, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18646, 2973, NULL, 5874, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18648, 2418, NULL, 5876, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18649, 8847, NULL, 5877, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18650, 601, NULL, 5879, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18651, 430, NULL, 5881, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18652, 156, NULL, 5882, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18653, 7705, NULL, 5885, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18654, 470, NULL, 5890, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18656, 761, NULL, 5892, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18660, 9454, NULL, 5884, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18661, 7336, NULL, 5872, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18662, 9455, NULL, 5872, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18663, 7792, NULL, 5872, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18664, 787, NULL, 5873, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18665, 6208, NULL, 5874, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18666, 1481, NULL, 5874, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18673, 1296, NULL, 5876, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18674, 8095, NULL, 5876, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18675, 5056, NULL, 5876, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18676, 3543, NULL, 5876, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18677, 1349, NULL, 5876, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (18678, 5490, NULL, 5876, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (18679, 4313, NULL, 5876, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18680, 4360, NULL, 1269, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18681, 4360, NULL, 1773, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18682, 2948, NULL, 5906, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18683, 40, NULL, 5907, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18684, 1603, NULL, 5909, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29380, 6713, NULL, 9164, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29381, 5109, NULL, 9164, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12186, 5790, NULL, 1243, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29382, 796, NULL, 9164, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29503, 1942, NULL, 9207, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29504, 1528, NULL, 9207, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29505, 1455, NULL, 9207, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29573, 12438, NULL, 9237, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29574, 12439, NULL, 9237, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29575, 12440, NULL, 9237, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29576, 12441, NULL, 9237, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29607, 650, NULL, 9246, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29608, 2430, NULL, 9246, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29609, 497, NULL, 9246, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29610, 220, NULL, 9246, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29611, 2955, NULL, 9246, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29652, 2214, NULL, 2586, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29653, 6267, NULL, 2586, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29697, 778, NULL, 9269, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29698, 2814, NULL, 9269, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29726, 1421, NULL, 9289, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29727, 8, NULL, 9289, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29728, 9828, NULL, 9289, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12234, 2702, NULL, 1057, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12235, 6839, NULL, 1057, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12236, 3749, NULL, 1058, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12237, 1967, NULL, 1058, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12238, 5440, NULL, 1058, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12239, 6840, NULL, 1058, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12240, 6841, NULL, 1058, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12241, 6842, NULL, 1059, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12242, 6843, NULL, 1060, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12243, 6844, NULL, 1061, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12244, 198, NULL, 1061, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12245, 6845, NULL, 1061, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12246, 6846, NULL, 1061, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12247, 2358, NULL, 1062, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12248, 6847, NULL, 1062, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12249, 2297, NULL, 1062, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12250, 6848, NULL, 1062, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12251, 550, NULL, 2148, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18685, 3284, NULL, 5912, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12252, 6728, NULL, 1555, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (12253, 6728, NULL, 3889, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12254, 555, NULL, 4299, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12255, 6384, NULL, 4299, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12256, 4571, NULL, 4299, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12257, 5467, NULL, 4299, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12258, 1448, NULL, 4300, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12259, 2327, NULL, 4301, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12260, 1472, NULL, 4301, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12261, 1067, NULL, 4302, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12262, 2186, NULL, 4302, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12263, 1666, NULL, 4302, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12264, 1376, NULL, 4302, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12265, 2308, NULL, 4303, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12266, 6577, NULL, 4303, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12267, 1600, NULL, 4303, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12268, 4986, NULL, 4298, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12269, 4987, NULL, 4298, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12270, 4988, NULL, 4298, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12271, 1219, NULL, 1178, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12272, 41, NULL, 1178, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12273, 5343, NULL, 1178, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12274, 3670, NULL, 1179, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12275, 2072, NULL, 1179, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12276, 6849, NULL, 1179, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12277, 6850, NULL, 1180, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12278, 4310, NULL, 1180, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12279, 2055, NULL, 1181, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12280, 6851, NULL, 1181, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12281, 664, NULL, 1181, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12282, 6852, NULL, 1181, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12283, 1334, NULL, 1182, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12284, 3028, NULL, 1182, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12285, 2605, NULL, 1182, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12286, 6853, NULL, 1183, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12287, 448, NULL, 1184, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12288, 1655, NULL, 1184, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12289, 688, NULL, 1184, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12290, 6530, NULL, 1185, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12291, 790, NULL, 1185, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12292, 6854, NULL, 1185, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12293, 6855, NULL, 1185, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12294, 1593, NULL, 1186, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12295, 1590, NULL, 1186, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12296, 320, NULL, 1186, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12297, 4733, NULL, 1187, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12298, 4734, NULL, 1187, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12299, 6856, NULL, 1188, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12300, 6857, NULL, 1188, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12301, 226, NULL, 1189, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12302, 687, NULL, 1189, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12303, 648, NULL, 1189, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12304, 967, NULL, 1190, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12305, 267, NULL, 1190, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12306, 1368, NULL, 1190, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12307, 6858, NULL, 1191, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12308, 755, NULL, 1192, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12309, 2752, NULL, 1192, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12310, 2973, NULL, 1193, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12311, 1313, NULL, 1193, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12312, 1313, NULL, 2007, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12313, 220, NULL, 1194, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12314, 2879, NULL, 1195, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12315, 2878, NULL, 1195, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12316, 727, NULL, 1195, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12317, 5307, NULL, 1195, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12318, 2964, NULL, 1195, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12319, 1458, NULL, 4304, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12320, 4236, NULL, 4304, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12321, 2332, NULL, 4304, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12322, 1778, NULL, 4304, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12323, 5296, NULL, 4305, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12324, 6860, NULL, 4305, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12325, 6861, NULL, 4306, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12326, 357, NULL, 4306, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18688, 1781, NULL, 5913, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18689, 188, NULL, 5914, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18690, 6764, NULL, 5915, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18691, 1154, NULL, 5916, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18692, 1672, NULL, 5917, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18693, 2436, NULL, 5905, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18694, 9465, NULL, 5905, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18695, 2089, NULL, 5905, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18696, 9466, NULL, 5905, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18697, 9467, NULL, 5906, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18698, 1021, NULL, 5906, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18699, 9468, NULL, 5907, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18700, 9469, NULL, 5907, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18701, 9470, NULL, 5907, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32931, 9974, NULL, 10199, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33054, 10577, NULL, 10218, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33051, 13926, NULL, 10218, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33052, 10575, NULL, 10218, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18706, 9471, NULL, 5909, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18707, 4902, NULL, 5909, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18708, 9472, NULL, 5909, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18709, 5753, NULL, 5910, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18710, 9473, NULL, 5910, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18711, 5786, NULL, 5910, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18712, 1027, NULL, 5911, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18713, 2910, NULL, 5911, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18714, 9474, NULL, 5911, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18715, 5004, NULL, 5913, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18716, 9475, NULL, 5913, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18717, 2688, NULL, 5913, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18718, 349, NULL, 5914, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18719, 9476, NULL, 5914, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18720, 9477, NULL, 5914, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18721, 1402, NULL, 5915, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18722, 9478, NULL, 5915, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18723, 1409, NULL, 5915, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18724, 5893, NULL, 5916, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18725, 4453, NULL, 5916, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18726, 9479, NULL, 5916, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18727, 770, NULL, 5917, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29383, 973, NULL, 9165, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29384, 12409, NULL, 9165, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29385, 4859, NULL, 9165, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29507, 5192, NULL, 9208, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29508, 5193, NULL, 9208, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29509, 4790, NULL, 9208, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29510, 5194, NULL, 9208, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29612, 750, NULL, 9247, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29654, 6409, NULL, 2587, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29655, 5204, NULL, 2587, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29699, 9916, NULL, 9270, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29700, 5956, NULL, 9270, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29729, 803, NULL, 9289, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12327, 1279, NULL, 4306, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12328, 4018, NULL, 4307, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12329, 1818, NULL, 4307, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12330, 1622, NULL, 4307, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12331, 5311, NULL, 4308, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12332, 1948, NULL, 4308, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12333, 4022, NULL, 4308, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12334, 4912, NULL, 4051, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12335, 77, NULL, 4309, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12336, 943, NULL, 4309, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12337, 1505, NULL, 4309, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12338, 822, NULL, 4310, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12339, 617, NULL, 4311, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12340, 4077, NULL, 4311, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12341, 430, NULL, 4312, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12342, 2259, NULL, 4312, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12343, 789, NULL, 4312, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12344, 1665, NULL, 4313, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12345, 1965, NULL, 4313, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12346, 2524, NULL, 4313, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12347, 411, NULL, 4314, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12348, 685, NULL, 4314, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12349, 1503, NULL, 4314, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12350, 152, NULL, 4315, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12351, 2294, NULL, 4315, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12352, 3130, NULL, 4315, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12353, 1509, NULL, 1770, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12354, 2986, NULL, 1770, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12355, 1374, NULL, 1770, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12356, 6859, NULL, 1770, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12357, 730, NULL, 1771, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12358, 452, NULL, 1771, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12359, 1380, NULL, 1771, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12360, 850, NULL, 1771, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12361, 1067, NULL, 1776, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12362, 1068, NULL, 2331, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12363, 1068, NULL, 222, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12364, 6862, NULL, 1776, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12365, 1077, NULL, 1776, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12366, 2769, NULL, 1776, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12367, 1638, NULL, 1775, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12368, 2134, NULL, 1775, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12369, 995, NULL, 1775, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12370, 6375, NULL, 1775, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12371, 2444, NULL, 1775, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12372, 3823, NULL, 1774, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12373, 6863, NULL, 1774, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12374, 6864, NULL, 1774, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12375, 1553, NULL, 1773, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12376, 6865, NULL, 1773, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12377, 675, NULL, 1773, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12378, 2413, NULL, 1777, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12379, 6866, NULL, 1777, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12380, 1588, NULL, 1777, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12381, 1890, NULL, 1777, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12382, 624, NULL, 1777, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12383, 961, NULL, 1772, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12384, 6867, NULL, 1772, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12385, 6868, NULL, 1772, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12386, 6869, NULL, 4316, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12387, 6870, NULL, 4317, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12388, 2212, NULL, 4318, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12389, 2615, NULL, 4318, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12390, 2331, NULL, 4318, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12391, 2361, NULL, 4318, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12392, 6871, NULL, 4319, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12393, 6872, NULL, 4319, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12394, 6873, NULL, 4320, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12398, 2680, NULL, 620, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12399, 2680, NULL, 2425, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12400, 2680, NULL, 1581, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12401, 2680, NULL, 2976, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12402, 2680, NULL, 3465, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12403, 2680, NULL, 3832, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12404, 2680, NULL, 364, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12405, 2680, NULL, 2218, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12406, 2680, NULL, 1159, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12407, 2680, NULL, 2146, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12408, 1816, NULL, 4322, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12409, 5280, NULL, 4323, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12410, 6875, NULL, 4324, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12411, 3242, NULL, 4325, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12412, 1513, NULL, 4325, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12413, 2543, NULL, 4326, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12414, 6876, NULL, 741, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12415, 6876, NULL, 4326, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12416, 6877, NULL, 4327, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12417, 2421, NULL, 4328, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12418, 6763, NULL, 4328, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18728, 6647, NULL, 5917, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18729, 6593, NULL, 5917, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18732, 9486, NULL, 5918, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18733, 9487, NULL, 5918, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18734, 858, NULL, 5918, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18735, 724, NULL, 5919, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18736, 4859, NULL, 5919, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18737, 78, NULL, 5919, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18738, 104, NULL, 5920, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18739, 2442, NULL, 5920, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18740, 9488, NULL, 5920, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18741, 4779, NULL, 5920, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18742, 9489, NULL, 5920, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18743, 9490, NULL, 5920, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18744, 1332, NULL, 5921, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18745, 9491, NULL, 5921, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18746, 9492, NULL, 5921, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18747, 9489, NULL, 5921, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18748, 4861, NULL, 5921, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18749, 5260, NULL, 5922, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18750, 608, NULL, 5922, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18751, 9493, NULL, 5922, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18730, 1527, NULL, 2498, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18752, 1208, NULL, 5923, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18753, 2850, NULL, 5923, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18754, 2115, NULL, 5923, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18755, 5665, NULL, 5923, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18756, 1721, NULL, 5924, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18757, 1629, NULL, 5924, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18758, 1329, NULL, 5924, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18759, 1834, NULL, 5924, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18760, 850, NULL, 5925, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18761, 1415, NULL, 5925, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18762, 2055, NULL, 5925, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18763, 9494, NULL, 5926, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18764, 9495, NULL, 5926, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18765, 4878, NULL, 5927, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18766, 4004, NULL, 5927, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18767, 9496, NULL, 5928, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18768, 9497, NULL, 5928, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18769, 9498, NULL, 5928, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18770, 9499, NULL, 5928, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29386, 12402, NULL, 9166, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29387, 5952, NULL, 9166, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29388, 12403, NULL, 9166, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29511, 7477, NULL, 9209, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29613, 5584, NULL, 9248, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29614, 5249, NULL, 9248, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29615, 12451, NULL, 9248, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29616, 10423, NULL, 9248, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29656, 825, NULL, 2588, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29657, 1181, NULL, 2588, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29658, 12464, NULL, 2588, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29659, 1744, NULL, 2588, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29701, 7080, NULL, 9271, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29730, 12479, NULL, 9290, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29731, 2404, NULL, 9290, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29732, 6266, NULL, 9290, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29733, 9552, NULL, 9291, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29734, 12480, NULL, 9291, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29739, 7176, NULL, 9293, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29740, 9815, NULL, 9293, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29741, 5253, NULL, 9294, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29742, 12481, NULL, 9294, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12419, 6878, NULL, 4329, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12420, 6879, NULL, 4329, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12421, 5810, NULL, 4329, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12422, 6880, NULL, 4329, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12423, 6881, NULL, 4330, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12424, 3149, NULL, 4331, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12425, 1919, NULL, 4331, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12426, 2786, NULL, 4331, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12427, 2886, NULL, 4331, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12428, 6882, NULL, 4332, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12429, 6883, NULL, 4332, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12430, 6884, NULL, 4333, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12431, 6885, NULL, 4334, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12432, 6886, NULL, 4335, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12433, 4913, NULL, 4335, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12434, 297, NULL, 4335, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12435, 3791, NULL, 4336, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12436, 1923, NULL, 4336, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12437, 6887, NULL, 4336, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12438, 5973, NULL, 4336, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12439, 1926, NULL, 1184, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12440, 993, NULL, 4337, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12441, 4741, NULL, 4337, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12442, 5752, NULL, 4337, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12443, 4034, NULL, 4337, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12446, 6889, NULL, 3351, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12447, 6890, NULL, 3356, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12448, 6891, NULL, 3356, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12449, 6892, NULL, 3356, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12451, 55, NULL, 1534, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12452, 1360, NULL, 3759, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12453, 926, NULL, 3239, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (12455, 1528, NULL, 1851, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12456, 1528, NULL, 3319, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12457, 1528, NULL, 170, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12458, 2737, NULL, 1878, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12459, 2418, NULL, 1607, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12460, 1481, NULL, 2655, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12461, 1221, NULL, 1319, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12462, 6101, NULL, 2736, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12463, 6101, NULL, 2692, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12464, 1328, NULL, 2708, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (12465, 3477, NULL, 1210, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12466, 650, NULL, 1210, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12467, 3036, NULL, 2294, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12468, 563, NULL, 1423, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12445, 6888, NULL, 3353, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12444, 6860, NULL, 3353, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12469, 3491, NULL, 1423, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12470, 3761, NULL, 1423, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12471, 5165, NULL, 1424, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12472, 5665, NULL, 1496, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12473, 6284, NULL, 1496, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12474, 283, NULL, 1497, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12475, 921, NULL, 1497, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12476, 1116, NULL, 1497, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12477, 4020, NULL, 1497, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12478, 4690, NULL, 1498, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12479, 5255, NULL, 1499, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12480, 5415, NULL, 1499, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12481, 5285, NULL, 1500, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12482, 2129, NULL, 1501, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12483, 5570, NULL, 1501, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12484, 448, NULL, 1502, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12485, 1582, NULL, 1502, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12486, 6670, NULL, 1502, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12487, 1600, NULL, 1502, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12488, 1449, NULL, 1502, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12489, 5198, NULL, 1503, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12490, 86, NULL, 1503, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12491, 6544, NULL, 1503, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12492, 6262, NULL, 1504, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12493, 6896, NULL, 1505, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12494, 6872, NULL, 1505, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12495, 372, NULL, 1506, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12496, 6897, NULL, 1506, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12497, 5100, NULL, 1506, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12498, 1593, NULL, 1507, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12499, 766, NULL, 1507, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12500, 5278, NULL, 1507, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12501, 2476, NULL, 1507, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12502, 6898, NULL, 1508, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12506, 46, NULL, 4340, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12507, 239, NULL, 4340, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12508, 2118, NULL, 4340, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12509, 6900, NULL, 4340, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12510, 232, NULL, 4340, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12511, 6761, NULL, 4340, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (12512, 2646, NULL, 4340, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (12513, 313, NULL, 4341, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12514, 5371, NULL, 4341, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12515, 848, NULL, 4341, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12516, 6901, NULL, 4341, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12517, 1624, NULL, 4342, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12518, 889, NULL, 4342, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12519, 1179, NULL, 4343, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12520, 6902, NULL, 4343, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12521, 295, NULL, 4344, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12522, 1329, NULL, 4344, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12523, 6903, NULL, 4345, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12524, 6904, NULL, 4345, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12525, 6905, NULL, 4346, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12526, 923, NULL, 4347, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12527, 785, NULL, 4347, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12528, 146, NULL, 4347, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12529, 650, NULL, 4347, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12530, 6906, NULL, 4348, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12531, 6907, NULL, 4349, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12532, 6206, NULL, 4350, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12533, 2531, NULL, 4350, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12534, 1744, NULL, 4350, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12535, 6908, NULL, 4351, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12536, 6909, NULL, 4352, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12537, 6910, NULL, 4353, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12538, 6911, NULL, 4354, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12539, 1639, NULL, 4355, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12540, 1639, NULL, 4356, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12541, 382, NULL, 4356, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12542, 88, NULL, 4356, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12544, 1505, NULL, 4357, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12545, 4310, NULL, 4358, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12546, 2830, NULL, 4358, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12547, 1900, NULL, 4359, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12548, 116, NULL, 2538, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18771, 3477, NULL, 5929, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18772, 9500, NULL, 5929, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18773, 1462, NULL, 5929, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18774, 2043, NULL, 5930, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18775, 8316, NULL, 5930, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18776, 650, NULL, 5930, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18777, 682, NULL, 5930, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18778, 4653, NULL, 5931, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18779, 9501, NULL, 5931, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18780, 9502, NULL, 5931, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18781, 9503, NULL, 5931, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18782, 4912, NULL, 5932, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18783, 790, NULL, 5932, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18784, 987, NULL, 5933, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12450, 6893, NULL, 3358, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18785, 9504, NULL, 5933, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18786, 6696, NULL, 5933, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12549, 1360, NULL, 4360, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12550, 5265, NULL, 4360, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12551, 4397, NULL, 4360, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12552, 1789, NULL, 4360, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12553, 2822, NULL, 4361, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12554, 6380, NULL, 4362, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12555, 2555, NULL, 4362, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12556, 1102, NULL, 4362, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12560, 6913, NULL, 2170, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12565, 4662, NULL, 4363, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12566, 6916, NULL, 4363, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12567, 2505, NULL, 4363, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12568, 2766, NULL, 4363, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12569, 3784, NULL, 4364, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12570, 6917, NULL, 4364, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12571, 6918, NULL, 4364, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12572, 3533, NULL, 4365, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12573, 648, NULL, 4365, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12574, 3681, NULL, 4366, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12575, 932, NULL, 4366, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12576, 78, NULL, 4366, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12577, 452, NULL, 4366, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12578, 4197, NULL, 4367, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12579, 6919, NULL, 4367, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12580, 2693, NULL, 4367, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12581, 3740, NULL, 4368, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12582, 6920, NULL, 4368, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12583, 6921, NULL, 4368, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12584, 1005, NULL, 4077, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12585, 313, NULL, 4369, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12586, 1373, NULL, 4369, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12587, 5123, NULL, 4369, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12588, 6276, NULL, 4369, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12589, 6273, NULL, 2330, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (12590, 6922, NULL, 2323, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12591, 512, NULL, 1722, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12592, 803, NULL, 1722, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12593, 3158, NULL, 1722, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12594, 5014, NULL, 1718, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12595, 644, NULL, 1718, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12596, 1884, NULL, 1727, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12597, 5235, NULL, 1727, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12598, 4034, NULL, 1727, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12599, 2645, NULL, 1727, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12600, 6923, NULL, 1720, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12601, 1401, NULL, 1717, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12602, 77, NULL, 1717, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12603, 2626, NULL, 1717, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12604, 408, NULL, 1723, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12605, 1553, NULL, 1725, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12606, 1956, NULL, 1725, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12607, 2957, NULL, 1725, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12608, 6924, NULL, 4370, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12609, 2465, NULL, 4370, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12610, 987, NULL, 4370, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12611, 6925, NULL, 1724, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12612, 2920, NULL, 1726, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12613, 2118, NULL, 1726, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12614, 267, NULL, 1726, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12615, 316, NULL, 1721, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12616, 5297, NULL, 1721, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12617, 6926, NULL, 1719, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12618, 63, NULL, 1719, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12619, 3835, NULL, 4371, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12620, 333, NULL, 4371, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12621, 1086, NULL, 4371, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12622, 3013, NULL, 4372, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12623, 1386, NULL, 4372, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12624, 1725, NULL, 4372, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12631, 1604, NULL, 1971, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12632, 2883, NULL, 1971, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12633, 6929, NULL, 1971, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12634, 2742, NULL, 1971, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12635, 6930, NULL, 1971, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12636, 1569, NULL, 1972, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12637, 2790, NULL, 1972, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12638, 2300, NULL, 1972, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12639, 1585, NULL, 1973, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12640, 5935, NULL, 1973, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12641, 1140, NULL, 1973, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18787, 685, NULL, 5934, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18788, 2762, NULL, 5934, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18789, 1015, NULL, 5934, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18790, 1639, NULL, 5934, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18791, 2083, NULL, 5935, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18793, 1565, NULL, 5935, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18794, 1618, NULL, 5936, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18795, 1352, NULL, 5936, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18796, 495, NULL, 5936, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18797, 9506, NULL, 5936, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18798, 815, NULL, 5937, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18799, 9507, NULL, 5937, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18800, 7680, NULL, 5937, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18801, 1450, NULL, 5938, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18802, 7678, NULL, 5938, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18803, 1068, NULL, 5938, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18804, 5593, NULL, 5938, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18805, 563, NULL, 5939, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18806, 1424, NULL, 5939, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18807, 1458, NULL, 5939, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18808, 613, NULL, 5939, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18809, 271, NULL, 5940, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18810, 1311, NULL, 5940, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18811, 9508, NULL, 5940, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18812, 346, NULL, 5940, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18813, 906, NULL, 5941, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18814, 9509, NULL, 5941, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18815, 5152, NULL, 5941, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18816, 1526, NULL, 5941, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18817, 5273, NULL, 5942, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18818, 2693, NULL, 5942, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18819, 1208, NULL, 5942, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18820, 4555, NULL, 5942, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18825, 2411, NULL, 5944, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12559, 6912, NULL, 2169, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12558, 685, NULL, 2169, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12557, 2104, NULL, 2169, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12543, 88, NULL, 360, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12627, 3056, NULL, 1969, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12625, 186, NULL, 1969, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12626, 6927, NULL, 1969, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18826, 4891, NULL, 5944, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18827, 8225, NULL, 5944, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18792, 9505, 283, 5935, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29389, 12407, NULL, 9167, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29390, 3520, NULL, 9167, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29512, 5313, NULL, 9210, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29513, 7125, NULL, 9210, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29617, 12452, NULL, 9249, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29618, 12453, NULL, 9249, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29619, 1781, NULL, 9249, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29620, 1849, NULL, 9249, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29621, 398, NULL, 9249, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29660, 614, NULL, 2589, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29661, 2138, NULL, 2589, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29662, 1664, NULL, 2589, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29663, 12465, NULL, 2589, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29702, 6284, NULL, 9272, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29735, 872, NULL, 9292, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29736, 76, NULL, 9292, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29737, 2399, NULL, 9292, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29738, 2761, NULL, 9292, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29743, 12482, NULL, 9294, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12642, 867, NULL, 1973, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12643, 2321, NULL, 1973, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12644, 41, NULL, 1974, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12645, 6931, NULL, 1974, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12646, 6932, NULL, 1975, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12647, 926, NULL, 1975, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12648, 1112, NULL, 1976, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12649, 2031, NULL, 1976, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12650, 2576, NULL, 1976, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12651, 3123, NULL, 1976, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12652, 1158, NULL, 1977, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12653, 2247, NULL, 1977, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12654, 2967, NULL, 1977, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12655, 2482, NULL, 1977, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12656, 671, NULL, 1978, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12657, 6933, NULL, 1978, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12658, 765, NULL, 1979, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12659, 2864, NULL, 1979, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12660, 3026, NULL, 1979, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12661, 6934, NULL, 1979, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12666, 189, NULL, 1981, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12667, 4104, NULL, 1981, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12668, 5252, NULL, 1982, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12669, 1112, NULL, 2836, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (12670, 295, NULL, 2836, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (12628, 1089, NULL, 1970, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12630, 3816, NULL, 1970, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12629, 6928, NULL, 1970, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12671, 1732, NULL, 2837, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12672, 220, NULL, 2837, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (12673, 803, NULL, 2838, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12674, 6256, NULL, 2935, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12675, 6257, NULL, 2935, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12676, 555, NULL, 2935, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12677, 1872, NULL, 2655, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12678, 6937, NULL, 209, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12679, 42, NULL, 532, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12680, 313, NULL, 4406, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12681, 1514, NULL, 3822, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12682, 487, NULL, 1213, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12683, 186, NULL, 1213, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12684, 3992, NULL, 1213, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12685, 1673, NULL, 1214, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12686, 3266, NULL, 1214, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12687, 3012, NULL, 1214, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12688, 5461, NULL, 1215, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12689, 6269, NULL, 1215, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12690, 6939, NULL, 1215, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12691, 6780, NULL, 1215, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12692, 6940, NULL, 1216, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12693, 6807, NULL, 1216, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12694, 3222, NULL, 1216, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12695, 5576, NULL, 1216, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12696, 6941, NULL, 1217, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12697, 6942, NULL, 1218, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12698, 6943, NULL, 1218, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12699, 88, NULL, 1218, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12700, 198, NULL, 1219, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12701, 5321, NULL, 1219, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12702, 4134, NULL, 1219, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12703, 5236, NULL, 1221, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12704, 2663, NULL, 1221, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12705, 6944, NULL, 1221, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12706, 1843, NULL, 1222, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12707, 2577, NULL, 2991, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12708, 2634, NULL, 1224, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12709, 1802, NULL, 1224, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12710, 1665, NULL, 1224, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12711, 534, NULL, 1225, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12712, 955, NULL, 1225, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12713, 378, NULL, 1225, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12714, 1267, NULL, 1949, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12715, 3096, NULL, 1949, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12716, 897, NULL, 1949, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12717, 1238, NULL, 2188, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12718, 4263, NULL, 1676, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12719, 5253, NULL, 2794, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12720, 6945, NULL, 2796, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12721, 381, NULL, 4409, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12722, 6946, NULL, 2803, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12723, 5964, NULL, 2804, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12724, 5067, NULL, 2804, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12725, 6947, NULL, 4410, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12726, 480, NULL, 4411, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12727, 400, NULL, 4412, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12728, 4565, NULL, 4413, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12729, 6949, NULL, 4414, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12730, 2614, NULL, 4415, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12731, 1270, NULL, 4416, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12732, 1498, NULL, 4417, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12733, 6950, NULL, 4418, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18841, 3215, NULL, 5948, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18842, 1621, NULL, 5948, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18843, 3224, NULL, 5948, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18844, 9511, NULL, 5948, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18845, 9512, NULL, 5948, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29391, 12405, NULL, 9168, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29392, 12406, NULL, 9168, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29393, 9829, NULL, 9168, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29514, 2827, NULL, 9211, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29515, 5409, NULL, 9211, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29516, 3150, NULL, 9211, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29517, 2668, NULL, 9211, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29622, 12454, NULL, 9250, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29664, 5235, NULL, 2597, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29665, 12466, NULL, 2597, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29666, 10991, NULL, 2597, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29703, 5204, NULL, 9273, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29744, 761, NULL, 9295, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29745, 7557, NULL, 9295, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29746, 302, NULL, 9295, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29747, 1481, NULL, 9295, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29748, 534, NULL, 9296, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29749, 685, NULL, 9296, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29750, 1091, NULL, 9296, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29751, 10395, NULL, 9297, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29752, 332, NULL, 9297, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29765, 350, NULL, 2076, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29766, 850, NULL, 2076, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12734, 1511, NULL, 4419, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12736, 2948, NULL, 4421, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12737, 987, NULL, 4422, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12738, 6951, NULL, 4423, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12739, 6952, NULL, 4424, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12740, 6953, NULL, 4425, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12735, 1112, NULL, 4420, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12741, 1154, NULL, 4426, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12742, 1264, NULL, 3502, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12743, 350, NULL, 1212, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12744, 1917, NULL, 1212, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12745, 5004, NULL, 1212, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12746, 3219, NULL, 1220, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12747, 312, NULL, 1220, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12748, 378, NULL, 1220, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12752, 6955, NULL, 2168, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12753, 6956, NULL, 2168, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12754, 6957, NULL, 2168, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12755, 6958, NULL, 2168, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12756, 6959, NULL, 2168, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12757, 1374, NULL, 4427, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12758, 2423, NULL, 4427, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12759, 6960, NULL, 4427, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12760, 4772, NULL, 4428, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18830, 206, NULL, 5945, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18829, 2628, NULL, 5945, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18828, 9510, NULL, 5945, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12663, 6935, NULL, 1980, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12664, 624, NULL, 1980, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12662, 358, NULL, 1980, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12665, 6936, NULL, 1980, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12761, 3314, NULL, 4428, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12762, 4781, NULL, 4430, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12763, 3572, NULL, 4430, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12764, 2827, NULL, 4430, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12765, 4612, NULL, 4431, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12766, 6961, NULL, 4431, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12767, 3484, NULL, 4432, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12768, 650, NULL, 4432, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12769, 1744, NULL, 4432, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12774, 6963, NULL, 4434, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12775, 6964, NULL, 4434, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12776, 6965, NULL, 4434, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12777, 3411, NULL, 4434, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12778, 6966, NULL, 4435, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12779, 4781, NULL, 4435, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12780, 6967, NULL, 4435, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12781, 6968, NULL, 4435, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12782, 6969, NULL, 4436, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12783, 220, NULL, 4437, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12784, 2752, NULL, 4437, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12785, 2332, NULL, 4437, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12786, 2356, NULL, 4437, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12787, 6970, NULL, 4438, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12788, 5018, NULL, 4439, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12789, 1008, NULL, 4439, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12790, 1122, NULL, 4439, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12791, 1205, NULL, 4439, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18853, 1373, NULL, 243, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18852, 9517, NULL, 243, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18846, 6977, NULL, 243, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18855, 9519, NULL, 3115, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18854, 9518, NULL, 3115, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18856, 9520, NULL, 3115, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18857, 9521, NULL, 3115, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18860, 5006, NULL, 4272, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18858, 9522, NULL, 4272, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18859, 3131, NULL, 4272, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18864, 3682, NULL, 5949, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18862, 2661, NULL, 5949, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18861, 8828, NULL, 5949, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18863, 1821, NULL, 5949, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18865, 9523, NULL, 5950, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18866, 2559, NULL, 5950, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18867, 2571, NULL, 5950, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18869, 9525, NULL, 5951, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12773, 6962, NULL, 4433, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12772, 6090, NULL, 4433, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12770, 749, NULL, 4433, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12771, 5321, NULL, 4433, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12792, 4702, NULL, 4439, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12793, 2875, NULL, 4440, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12794, 727, NULL, 4440, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12795, 2878, NULL, 4440, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12796, 2879, NULL, 4440, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12797, 5307, NULL, 4440, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12804, 3013, NULL, 4443, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12805, 405, NULL, 4443, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12806, 687, NULL, 4443, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12807, 2090, NULL, 4444, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12808, 890, NULL, 4445, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12809, 103, NULL, 4445, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12810, 2531, NULL, 4445, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12811, 812, NULL, 4445, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12812, 6975, NULL, 4446, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12813, 1005, NULL, 4447, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12814, 6976, NULL, 4448, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12815, 1179, NULL, 4449, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12816, 146, NULL, 4449, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12817, 6978, NULL, 4449, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12818, 2442, NULL, 4450, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12819, 1659, NULL, 4450, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12820, 2559, NULL, 4450, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12821, 5369, NULL, 4450, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12822, 4231, NULL, 4450, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12823, 2140, NULL, 4450, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (12825, 6979, NULL, 4452, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12826, 1769, NULL, 4452, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18901, 283, NULL, 5960, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18902, 1261, NULL, 5960, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18903, 6672, NULL, 5960, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18904, 124, NULL, 5961, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18905, 2774, NULL, 5961, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18906, 2577, NULL, 5961, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18907, 4955, NULL, 5962, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18908, 8496, NULL, 5962, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18909, 2840, NULL, 5962, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18910, 9535, NULL, 5962, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18911, 7458, NULL, 5963, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18912, 1514, NULL, 5963, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29394, 3188, NULL, 9169, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29395, 12404, NULL, 9169, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29396, 1264, NULL, 9169, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29518, 6249, NULL, 9212, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29667, 179, NULL, 2596, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29668, 267, NULL, 2596, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29704, 5262, NULL, 9274, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29753, 283, NULL, 9298, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29754, 1181, NULL, 9298, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29755, 1716, NULL, 9298, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29756, 4578, NULL, 9298, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29767, 1609, NULL, 2082, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29768, 1042, NULL, 2082, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29769, 267, NULL, 2082, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12827, 1497, NULL, 4452, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12828, 6980, NULL, 4452, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12829, 6630, NULL, 4452, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12830, 1232, NULL, 4452, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18872, 1880, NULL, 5951, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18871, 1052, NULL, 5951, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18873, 9526, NULL, 5952, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18875, 1683, NULL, 5952, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18874, 975, NULL, 5952, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12869, 6988, NULL, 4469, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12870, 687, NULL, 4469, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12871, 1276, NULL, 4470, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12872, 2093, NULL, 4470, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12873, 3154, NULL, 4470, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12874, 2202, NULL, 4470, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12875, 6989, NULL, 4471, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12876, 6990, NULL, 4471, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12877, 6991, NULL, 4472, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12878, 987, NULL, 4472, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12879, 6992, NULL, 4472, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12880, 807, NULL, 4473, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12881, 2894, NULL, 4473, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12882, 3132, NULL, 4473, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12883, 2661, NULL, 4473, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12884, 1977, NULL, 4474, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12885, 2968, NULL, 4474, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12886, 5956, NULL, 4474, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12887, 750, NULL, 4474, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12888, 1379, NULL, 4475, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12889, 285, NULL, 4475, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12890, 336, NULL, 4475, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12891, 6993, NULL, 4475, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12892, 1511, NULL, 4476, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12893, 6459, NULL, 4476, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12894, 996, NULL, 4476, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12895, 4243, NULL, 4476, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12896, 5620, NULL, 4477, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12897, 2520, NULL, 4477, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12898, 778, NULL, 4477, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12899, 1742, NULL, 4477, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12900, 374, NULL, 4478, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12901, 1505, NULL, 4478, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12750, 5954, NULL, 1223, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12749, 1261, NULL, 1223, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12751, 6954, NULL, 1223, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12803, 6974, NULL, 4442, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12802, 6973, NULL, 4442, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12824, 6262, NULL, 4451, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12841, 6983, NULL, 4456, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12842, 6984, NULL, 4456, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12840, 6982, NULL, 4456, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12843, 6985, NULL, 4456, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12902, 2788, NULL, 4478, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12903, 6994, NULL, 4479, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12904, 1462, NULL, 4479, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12905, 6995, NULL, 4480, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12906, 6996, NULL, 4480, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12907, 1638, NULL, 4481, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12908, 770, NULL, 4481, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12909, 2988, NULL, 4481, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12910, 4746, NULL, 4481, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12911, 6164, NULL, 4482, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12912, 6997, NULL, 4482, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12913, 6998, NULL, 4482, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12914, 236, NULL, 4483, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12915, 3009, NULL, 4483, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12916, 6999, NULL, 4483, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12845, 6679, NULL, 4458, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12847, 295, NULL, 4459, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12848, 510, NULL, 4459, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12849, 1586, NULL, 4460, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12850, 2964, NULL, 4460, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12851, 2106, NULL, 4461, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12853, 6343, NULL, 4463, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12852, 1882, NULL, 4462, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12856, 4167, NULL, 4464, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12855, 5126, NULL, 4464, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12859, 3521, NULL, 4465, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12857, 480, NULL, 4465, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12862, 4034, NULL, 4466, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12860, 156, NULL, 4466, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12861, 2822, NULL, 4466, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12865, 713, NULL, 4467, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12863, 939, NULL, 4467, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12868, 283, NULL, 4468, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12867, 497, NULL, 4468, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12866, 1741, NULL, 4468, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12831, 6981, NULL, 4454, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12832, 4409, NULL, 4454, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12833, 975, NULL, 4454, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18877, 2921, NULL, 5953, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18876, 9527, NULL, 5953, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18878, 2554, NULL, 5953, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18882, 556, NULL, 5954, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18880, 9528, NULL, 5954, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18881, 4496, NULL, 5954, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18885, 9530, NULL, 5955, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18887, 8498, NULL, 5955, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18886, 9531, NULL, 5955, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18884, 9529, NULL, 5955, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18888, 5666, NULL, 5956, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18889, 9532, NULL, 5956, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18890, 744, NULL, 5957, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18893, 9534, NULL, 5957, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18891, 9533, NULL, 5957, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18896, 239, NULL, 5958, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18894, 445, NULL, 5958, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18895, 1588, NULL, 5958, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18897, 2448, NULL, 5958, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18900, 186, NULL, 5959, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18899, 840, NULL, 5959, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18898, 1527, NULL, 5959, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12917, 2294, NULL, 4483, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12918, 1553, NULL, 4484, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18913, 3363, NULL, 5963, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18926, 760, NULL, 5746, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18927, 6036, NULL, 5968, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18928, 9537, NULL, 5968, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18929, 9538, NULL, 5968, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18930, 1888, NULL, 5968, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18931, 9539, NULL, 5969, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18932, 9540, NULL, 5969, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18933, 9541, NULL, 5969, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18934, 780, NULL, 5969, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18935, 4581, NULL, 5970, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18936, 9542, NULL, 5970, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18937, 2029, NULL, 5970, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18938, 9543, NULL, 5970, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18939, 305, NULL, 5970, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18940, 9544, NULL, 5970, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18941, 109, NULL, 5970, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (18942, 1059, NULL, 5971, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18943, 98, NULL, 5971, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18944, 3600, NULL, 5971, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18945, 76, NULL, 5971, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18946, 1699, NULL, 5971, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18947, 318, NULL, 5971, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18948, 312, NULL, 5971, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (18949, 9545, NULL, 5972, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18950, 9546, NULL, 5972, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18951, 78, NULL, 5972, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18952, 2456, NULL, 5972, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33053, 10576, NULL, 10218, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29397, 8316, NULL, 9170, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29398, 188, NULL, 9170, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29399, 173, NULL, 9170, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29519, 727, NULL, 9213, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29520, 2879, NULL, 9213, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29521, 5307, NULL, 9213, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29522, 2878, NULL, 9213, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29523, 12415, NULL, 9213, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29669, 1059, NULL, 2595, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29670, 41, NULL, 2595, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29671, 186, NULL, 2595, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29672, 4382, NULL, 2595, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29705, 12470, NULL, 9275, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29757, 1880, NULL, 9299, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29758, 320, NULL, 9299, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29759, 429, NULL, 9299, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29770, 3383, NULL, 2073, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29771, 316, NULL, 2073, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12919, 1629, NULL, 4484, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12920, 4578, NULL, 4484, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12921, 2399, NULL, 4484, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12922, 5672, NULL, 4485, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12923, 1995, NULL, 4485, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12924, 3005, NULL, 4486, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12925, 7000, NULL, 4486, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12926, 4746, NULL, 4486, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12927, 7001, NULL, 4486, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12928, 958, NULL, 4487, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12929, 7002, NULL, 4487, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12930, 7003, NULL, 4487, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12931, 6084, NULL, 4487, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12932, 1542, NULL, 4488, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12933, 1400, NULL, 4488, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12934, 234, NULL, 4488, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12935, 2029, NULL, 4488, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12936, 7004, NULL, 4489, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12937, 7005, NULL, 4489, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12938, 4700, NULL, 4489, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12939, 7006, NULL, 4490, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12944, 5044, NULL, 4492, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12945, 809, NULL, 4492, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12946, 2967, NULL, 4493, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12947, 1505, NULL, 4493, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12948, 3067, NULL, 4493, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12949, 3329, NULL, 4494, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12950, 2761, NULL, 4494, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12951, 423, NULL, 4494, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12952, 3267, NULL, 4494, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12953, 2399, NULL, 4494, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12954, 7009, NULL, 4495, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12955, 2179, NULL, 4495, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12956, 692, NULL, 4495, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12957, 1979, NULL, 4495, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12958, 7010, NULL, 4496, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12959, 7011, NULL, 4497, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12960, 7012, NULL, 4497, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12961, 7013, NULL, 4497, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12962, 7014, NULL, 4497, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12963, 7015, NULL, 4498, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12964, 7016, NULL, 4498, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12965, 7017, NULL, 4499, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12966, 7018, NULL, 4499, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12967, 5358, NULL, 4499, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12968, 7019, NULL, 4499, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12969, 1799, NULL, 4500, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12970, 7020, NULL, 4500, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12971, 497, NULL, 4501, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12972, 7021, NULL, 4501, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12973, 2379, NULL, 4501, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12974, 644, NULL, 4502, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12975, 1460, NULL, 4502, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12976, 1019, NULL, 4503, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12977, 1241, NULL, 4503, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12978, 2309, NULL, 4503, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12979, 6224, NULL, 4504, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12980, 989, NULL, 4506, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12981, 867, NULL, 4506, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12982, 3014, NULL, 4506, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12983, 109, NULL, 4506, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12984, 23, NULL, 4507, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12985, 3157, NULL, 4507, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12986, 4753, NULL, 4507, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12987, 6905, NULL, 4508, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12988, 1666, NULL, 4508, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12989, 939, NULL, 4509, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12990, 1802, NULL, 4509, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12991, 2943, NULL, 4509, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12992, 3521, NULL, 4411, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12993, 5036, NULL, 4411, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12994, 405, NULL, 4411, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12995, 3816, NULL, 4421, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12996, 2128, NULL, 4421, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12997, 1707, NULL, 4421, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12998, 1823, NULL, 4416, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12999, 3014, NULL, 4416, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13000, 4907, NULL, 4416, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13001, 2728, NULL, 4416, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13002, 2448, NULL, 4416, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13003, 663, NULL, 4416, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (13004, 7022, NULL, 4417, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13005, 7023, NULL, 4417, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13006, 3001, NULL, 4417, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13007, 1639, NULL, 4417, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13008, 7024, NULL, 4414, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13009, 5933, NULL, 4414, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13010, 7025, NULL, 4414, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29800, 3443, NULL, 9303, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29798, 794, NULL, 9303, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29799, 10833, NULL, 9303, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13018, 3401, NULL, 4413, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13019, 1993, NULL, 4412, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13020, 7026, NULL, 4422, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13021, 7027, NULL, 4422, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13022, 5235, NULL, 4422, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13023, 4986, NULL, 4422, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13024, 2931, NULL, 4419, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13025, 5832, NULL, 4419, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13026, 2932, NULL, 4419, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13027, 655, NULL, 4415, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13028, 302, NULL, 4415, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13029, 4168, NULL, 4415, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13030, 4310, NULL, 4425, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13031, 7028, NULL, 4423, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13032, 7029, NULL, 4423, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13033, 7031, NULL, 4510, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13034, 7032, NULL, 4511, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13035, 173, NULL, 4512, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13036, 501, NULL, 4512, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18915, 1016, NULL, 5964, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18916, 725, NULL, 5964, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18914, 1468, NULL, 5964, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18917, 503, NULL, 5965, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18918, 4578, NULL, 5965, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18919, 2957, NULL, 5965, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18920, 3755, NULL, 5966, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18922, 5369, NULL, 5966, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18924, 182, NULL, 5967, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18925, 336, NULL, 5967, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18923, 1445, NULL, 5967, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33085, 13953, NULL, 10227, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33086, 13954, NULL, 10227, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13037, 2890, NULL, 4512, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13038, 317, NULL, 4512, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13039, 5715, NULL, 4513, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13040, 6143, NULL, 4513, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13041, 7033, NULL, 4514, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13042, 7034, NULL, 4514, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13043, 7035, NULL, 4514, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13044, 6284, NULL, 4515, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13045, 6422, NULL, 4515, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13046, 1497, NULL, 4516, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13047, 655, NULL, 4516, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13048, 2691, NULL, 4516, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18960, 9547, NULL, 5974, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18961, 1505, NULL, 5974, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18962, 9548, NULL, 5974, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18963, 4578, NULL, 5974, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18964, 9549, NULL, 5975, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18965, 9550, NULL, 5975, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18966, 9551, NULL, 5975, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18967, 1374, NULL, 5976, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18968, 457, NULL, 5976, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18969, 1541, NULL, 5976, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18970, 13, NULL, 5976, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18971, 430, NULL, 5976, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13049, 3159, NULL, 4516, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13050, 7036, NULL, 4517, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13051, 7037, NULL, 4517, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13052, 6519, NULL, 4518, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13053, 7038, NULL, 4518, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13054, 7039, NULL, 4518, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13055, 669, NULL, 4519, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13056, 7040, NULL, 4519, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13057, 2696, NULL, 4520, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13058, 2375, NULL, 4520, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13059, 2665, NULL, 4520, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13060, 5188, NULL, 4520, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13061, 1848, NULL, 4521, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13062, 6161, NULL, 4521, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13063, 7041, NULL, 4522, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13064, 6282, NULL, 4522, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13065, 171, NULL, 4523, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13066, 3010, NULL, 4523, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13067, 4738, NULL, 4523, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13068, 7042, NULL, 4523, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13069, 691, NULL, 4524, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13070, 6413, NULL, 4524, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13071, 7043, NULL, 4524, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13072, 7044, NULL, 4525, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13073, 7044, NULL, 4289, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13074, 7045, NULL, 4526, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13075, 2054, NULL, 4527, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13076, 7046, NULL, 4527, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13077, 4073, NULL, 4527, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13078, 6085, NULL, 4527, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13079, 7047, NULL, 4528, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13080, 7048, NULL, 4528, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13081, 5933, NULL, 4528, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13082, 5267, NULL, 4528, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13083, 7049, NULL, 4528, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13084, 552, NULL, 4529, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13085, 7050, NULL, 4529, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13086, 6807, NULL, 4529, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13087, 4543, NULL, 4529, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13088, 2316, NULL, 4530, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13089, 7051, NULL, 4530, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13090, 7052, NULL, 4530, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13091, 5331, NULL, 4530, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13092, 7053, NULL, 4531, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13093, 2684, NULL, 4532, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13094, 520, NULL, 4533, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13095, 2285, NULL, 4533, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13096, 1604, NULL, 4533, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13097, 1106, NULL, 4533, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13098, 6326, NULL, 4534, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13099, 7054, NULL, 4535, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13100, 2871, NULL, 4535, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13101, 374, NULL, 4536, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13102, 2661, NULL, 4536, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13103, 7055, NULL, 4536, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13104, 3682, NULL, 4536, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13105, 2554, NULL, 4536, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13106, 7056, NULL, 4536, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13107, 7057, NULL, 2860, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13108, 7058, NULL, 2860, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13109, 1448, NULL, 1909, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13110, 423, NULL, 1909, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13111, 2317, NULL, 1909, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13112, 502, NULL, 1909, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13113, 2443, NULL, 1910, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13114, 1118, NULL, 1910, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13115, 1476, NULL, 1911, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13116, 3498, NULL, 1911, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13117, 664, NULL, 1911, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13118, 429, NULL, 1911, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13119, 532, NULL, 1912, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13120, 1510, NULL, 1912, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13121, 172, NULL, 1913, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13122, 3848, NULL, 1913, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13123, 1368, NULL, 1913, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13124, 2012, NULL, 1913, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13129, 1158, NULL, 1915, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13130, 4541, NULL, 1915, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13131, 6124, NULL, 1915, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13132, 1514, NULL, 1915, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13133, 209, NULL, 1916, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13134, 1502, NULL, 1916, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13135, 4415, NULL, 1916, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13136, 1363, NULL, 1916, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13137, 217, NULL, 1917, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13138, 5207, NULL, 1917, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13139, 4105, NULL, 1917, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13140, 599, NULL, 1918, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13141, 1464, NULL, 1918, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18972, 6224, NULL, 5977, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18973, 6186, NULL, 5977, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18974, 6404, NULL, 5977, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18975, 1553, NULL, 5978, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18976, 77, NULL, 5978, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18977, 5309, NULL, 5978, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18978, 188, NULL, 5978, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18979, 1926, NULL, 5978, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18980, 2430, NULL, 5978, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18981, 2738, NULL, 5978, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (18982, 2988, NULL, 5978, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (18983, 186, NULL, 5978, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (18984, 2538, NULL, 5979, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18985, 2990, NULL, 5979, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18986, 390, NULL, 5979, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18987, 9552, NULL, 5979, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18988, 1095, NULL, 5980, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18989, 378, NULL, 5980, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18990, 1778, NULL, 5980, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18991, 9553, NULL, 5980, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18992, 709, NULL, 5980, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18993, 497, NULL, 5980, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18994, 1148, NULL, 5980, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (18995, 9554, NULL, 5981, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18996, 9555, NULL, 5981, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18997, 9556, NULL, 5981, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18998, 9557, NULL, 5982, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18999, 8182, NULL, 5982, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19000, 9558, NULL, 5982, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19001, 9559, NULL, 5983, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19002, 6046, NULL, 5983, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19003, 4740, NULL, 5983, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19004, 9560, NULL, 5983, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19005, 6164, NULL, 5983, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19006, 1542, NULL, 4942, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19007, 6215, NULL, 6002, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19008, 173, NULL, 5998, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19009, 9566, NULL, 5998, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19010, 2898, NULL, 5998, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19011, 4073, NULL, 5998, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19014, 1326, NULL, 6000, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19015, 1452, NULL, 6000, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19016, 9568, NULL, 6000, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19017, 9569, NULL, 6000, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19018, 3865, NULL, 6001, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19019, 9001, NULL, 6001, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19020, 9570, NULL, 6001, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19021, 3692, NULL, 6003, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19022, 9571, NULL, 6003, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19023, 9572, NULL, 6003, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19024, 9573, NULL, 6004, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13142, 7060, NULL, 1918, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13147, 2031, NULL, 1920, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13148, 3957, NULL, 1920, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13149, 425, NULL, 1920, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13150, 389, NULL, 1921, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13151, 1505, NULL, 1921, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13152, 2626, NULL, 1921, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32892, 702, NULL, 10186, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13153, 1146, NULL, 1921, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33058, 11184, NULL, 10219, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13161, 3301, NULL, 2406, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13162, 806, NULL, 2412, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33056, 9680, NULL, 10219, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13164, 100, NULL, 2409, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13165, 2270, NULL, 2409, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13166, 122, NULL, 2409, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13167, 7065, NULL, 2409, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13168, 1283, NULL, 1476, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13172, 1364, NULL, 2446, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13173, 141, NULL, 2446, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13174, 3566, NULL, 2447, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13175, 7067, NULL, 2447, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13176, 5577, NULL, 2447, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13177, 7068, NULL, 2447, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13178, 1538, NULL, 2448, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13180, 1725, NULL, 2448, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13181, 2482, NULL, 2448, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13182, 3372, NULL, 2449, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13183, 2322, NULL, 2449, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13184, 20, NULL, 2449, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13185, 7069, NULL, 2449, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13186, 2996, NULL, 2450, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13187, 2583, NULL, 2450, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13188, 7070, NULL, 2450, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13189, 1635, NULL, 2451, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13190, 397, NULL, 2451, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13191, 1722, NULL, 2451, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13192, 7071, NULL, 2451, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13193, 3269, NULL, 2452, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13194, 2413, NULL, 2452, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13195, 5777, NULL, 2452, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13196, 3249, NULL, 2453, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13197, 3264, NULL, 2453, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13198, 1498, NULL, 2453, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13199, 7072, NULL, 2453, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13206, 2959, NULL, 2445, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13207, 132, NULL, 3505, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13208, 7075, NULL, 3506, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13209, 7076, NULL, 3507, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13210, 6081, NULL, 3508, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13211, 7077, NULL, 3508, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13212, 7078, NULL, 3509, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13213, 1373, NULL, 3509, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13214, 4656, NULL, 3509, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13215, 5171, NULL, 3509, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13216, 7079, NULL, 3510, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13217, 510, NULL, 3511, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13218, 7080, NULL, 3511, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13219, 6251, NULL, 3512, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13220, 63, NULL, 3513, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13221, 6287, NULL, 3513, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13222, 7081, NULL, 3514, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13223, 232, NULL, 3515, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13224, 2300, NULL, 3515, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13225, 1431, NULL, 3515, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13226, 848, NULL, 3516, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13227, 1772, NULL, 3516, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13228, 756, NULL, 3516, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13229, 2090, NULL, 3517, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13230, 7082, NULL, 3517, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13231, 993, NULL, 3518, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13232, 790, NULL, 3518, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13233, 6336, NULL, 3518, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19025, 9574, NULL, 6004, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19026, 1316, NULL, 2431, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19027, 9575, NULL, 5984, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19028, 1881, NULL, 5985, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19029, 1181, NULL, 5985, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19030, 2974, NULL, 5985, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19031, 317, NULL, 5985, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19032, 1429, NULL, 5986, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19033, 3320, NULL, 5986, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19034, 6044, NULL, 5986, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19035, 1585, NULL, 5987, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19036, 798, NULL, 5987, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19037, 9576, NULL, 5987, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19038, 9000, NULL, 5988, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19039, 4105, NULL, 5988, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19040, 1777, NULL, 5988, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19041, 1582, NULL, 5988, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19042, 506, NULL, 5989, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19043, 9577, NULL, 5989, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19044, 5407, NULL, 5989, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19045, 1289, NULL, 5989, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19046, 3263, NULL, 5990, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19047, 4183, NULL, 5990, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19048, 2937, NULL, 5990, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19049, 9565, NULL, 5991, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19050, 9578, NULL, 5991, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19051, 9579, NULL, 5991, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19052, 2035, NULL, 5992, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19053, 3860, NULL, 5992, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19054, 9580, NULL, 5992, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19055, 3206, NULL, 5992, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19056, 9005, NULL, 5993, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19057, 6806, NULL, 5993, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19058, 1469, NULL, 5993, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19059, 1036, NULL, 5994, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19060, 5853, NULL, 5994, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19061, 1020, NULL, 5994, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19062, 1193, NULL, 5995, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19063, 4924, NULL, 5995, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19064, 2204, NULL, 5995, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19065, 2120, NULL, 5995, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19066, 1557, NULL, 5996, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29400, 1368, NULL, 9171, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29401, 333, NULL, 9171, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29524, 7127, NULL, 9214, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29706, 6809, NULL, 9276, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33057, 10579, NULL, 10219, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33055, 8229, NULL, 10219, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (783, 2645, NULL, 92, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29772, 4839, NULL, 2083, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29773, 1893, NULL, 2083, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29802, 12488, NULL, 9304, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29803, 12489, NULL, 9304, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29804, 6772, NULL, 9304, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29805, 9873, NULL, 9304, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13234, 1884, NULL, 3518, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13235, 7083, NULL, 3519, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13236, 5054, NULL, 3520, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13237, 7084, NULL, 3520, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13238, 7085, NULL, 3520, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13239, 7086, NULL, 3520, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13240, 2098, NULL, 3521, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13241, 7087, NULL, 3522, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13242, 7088, NULL, 3522, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13243, 7089, NULL, 3522, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13244, 5285, NULL, 3523, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13245, 7090, NULL, 3524, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13246, 2828, NULL, 3524, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29812, 12495, NULL, 9307, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13247, 4331, NULL, 3524, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13248, 7003, NULL, 3524, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13249, 7091, NULL, 3525, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13145, 3257, NULL, 1919, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13143, 996, NULL, 1919, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13204, 117, NULL, 2454, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13201, 4953, NULL, 2454, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13200, 266, NULL, 2454, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13205, 7074, NULL, 2454, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13250, 3433, NULL, 3526, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13251, 6048, NULL, 3526, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13252, 1693, NULL, 3526, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13253, 2169, NULL, 3526, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13254, 3598, NULL, 3528, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13255, 1332, NULL, 3529, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13256, 1967, NULL, 3529, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13257, 5440, NULL, 3529, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13258, 5055, NULL, 3529, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13259, 1867, NULL, 3530, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13260, 7092, NULL, 3530, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13261, 7093, NULL, 3530, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13262, 7094, NULL, 3530, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13263, 1622, NULL, 3531, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13264, 2696, NULL, 4393, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13265, 1880, NULL, 4393, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13266, 1112, NULL, 4393, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13267, 1541, NULL, 4394, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13268, 2922, NULL, 4394, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13269, 1505, NULL, 4394, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13270, 4717, NULL, 4395, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13271, 6679, NULL, 2863, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13272, 6680, NULL, 2863, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13273, 6016, NULL, 2863, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13274, 4912, NULL, 4396, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13275, 3598, NULL, 4397, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13154, 4455, NULL, 2405, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13155, 1744, NULL, 2405, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13160, 829, NULL, 2410, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13159, 2339, NULL, 2410, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13158, 4338, NULL, 2410, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29673, 2921, NULL, 2594, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29675, 11937, NULL, 2594, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13276, 7095, NULL, 4398, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13277, 2382, NULL, 4398, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13278, 7096, NULL, 4398, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13279, 7097, NULL, 4399, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13280, 4836, NULL, 4400, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13281, 2967, NULL, 4400, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13282, 7098, NULL, 4401, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13283, 7099, NULL, 4402, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13284, 2138, NULL, 4402, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13285, 7100, NULL, 4403, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13286, 6181, NULL, 4403, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13287, 5499, NULL, 4403, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13288, 4331, NULL, 4404, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13289, 7003, NULL, 4404, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13290, 5432, NULL, 4404, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13291, 534, NULL, 4405, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13292, 955, NULL, 4405, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13293, 378, NULL, 4405, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13294, 219, NULL, 4407, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13295, 803, NULL, 4407, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13296, 2309, NULL, 4407, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13297, 695, NULL, 4408, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13298, 2479, NULL, 2982, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13299, 5205, NULL, 2982, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (13300, 2409, NULL, 2981, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13301, 2311, NULL, 2981, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (13302, 2169, NULL, 2981, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (13303, 267, NULL, 2988, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13304, 1527, NULL, 2988, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (13305, 833, NULL, 2988, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (13306, 398, NULL, 2989, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13307, 5251, NULL, 2773, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13308, 220, NULL, 4380, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13309, 3013, NULL, 4380, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13310, 3600, NULL, 4381, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13311, 2492, NULL, 4381, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13312, 914, NULL, 4381, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13313, 678, NULL, 4382, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13314, 1155, NULL, 4382, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13315, 2624, NULL, 4382, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13316, 1593, NULL, 4383, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13317, 1238, NULL, 4383, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13318, 1241, NULL, 4383, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13319, 5620, NULL, 4385, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13320, 6776, NULL, 4385, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13321, 6136, NULL, 4385, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13322, 5118, NULL, 4385, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13323, 6336, NULL, 4386, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13324, 5499, NULL, 4386, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13325, 6393, NULL, 4386, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13326, 2055, NULL, 4389, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19067, 9581, NULL, 5996, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19068, 8, NULL, 5996, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19069, 203, NULL, 5997, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19070, 9582, NULL, 5997, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19071, 9583, NULL, 5997, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19072, 9258, NULL, 5997, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19073, 545, NULL, 6008, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19074, 2786, NULL, 6008, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19075, 5246, NULL, 6008, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19076, 3716, NULL, 6009, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19077, 19, NULL, 6009, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19078, 416, NULL, 6009, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19079, 1621, NULL, 6009, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32898, 9262, NULL, 10188, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32900, 5369, NULL, 10188, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32901, 13878, NULL, 10188, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19083, 663, NULL, 6011, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19084, 9495, NULL, 6011, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19085, 332, NULL, 6012, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19086, 58, NULL, 6012, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19087, 2004, NULL, 374, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19088, 1196, NULL, 1794, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19089, 1196, NULL, 635, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19090, 825, NULL, 2156, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19091, 1566, NULL, 2156, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19092, 2662, NULL, 2156, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19093, 749, NULL, 2157, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19094, 5015, NULL, 2157, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19095, 2382, NULL, 2157, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19096, 6962, NULL, 2157, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19097, 722, NULL, 2152, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19098, 3752, NULL, 2152, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19099, 2423, NULL, 2155, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19100, 1043, NULL, 2159, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19101, 867, NULL, 2159, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19102, 2816, NULL, 2159, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19103, 2151, NULL, 2159, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19104, 1082, NULL, 2158, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19105, 1857, NULL, 2158, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19106, 952, NULL, 2158, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19107, 429, NULL, 2151, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19108, 2776, NULL, 2151, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29402, 1118, NULL, 9172, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29403, 2442, NULL, 9172, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29404, 867, NULL, 9172, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29525, 5203, NULL, 9215, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29526, 5204, NULL, 9215, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29676, 2680, NULL, 2591, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29677, 2285, NULL, 2591, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29678, 1052, NULL, 2591, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29679, 2188, NULL, 2591, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29707, 10990, NULL, 9277, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29763, 835, NULL, 9301, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29764, 1505, NULL, 9301, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29774, 6178, NULL, 2078, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29818, 1603, NULL, 9308, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29819, 4181, NULL, 9308, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29820, 7176, NULL, 9308, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29821, 1800, NULL, 9308, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13327, 452, NULL, 4389, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13328, 649, NULL, 4389, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13329, 181, NULL, 4374, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13330, 425, NULL, 4374, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13331, 1363, NULL, 4374, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13332, 3600, NULL, 4375, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13333, 1374, NULL, 4375, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13334, 4085, NULL, 4375, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13335, 1848, NULL, 4376, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13336, 2871, NULL, 4376, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13338, 448, NULL, 4377, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13339, 1406, NULL, 4377, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13340, 914, NULL, 4377, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13341, 768, NULL, 4378, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13342, 586, NULL, 4378, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13343, 1112, NULL, 4378, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13344, 1970, NULL, 4378, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13345, 5123, NULL, 4379, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13346, 5752, NULL, 4379, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13347, 2820, NULL, 4379, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13348, 1884, NULL, 4379, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13349, 848, NULL, 4379, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13350, 7102, NULL, 4379, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13351, 2957, NULL, 3702, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13352, 6183, NULL, 3697, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13353, 7103, NULL, 3692, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13354, 7104, NULL, 3692, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13355, 1515, NULL, 2166, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13356, 6071, NULL, 2166, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13357, 4646, NULL, 2166, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13358, 7135, NULL, 2166, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13359, 5738, NULL, 2162, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13360, 4075, NULL, 2162, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13361, 840, NULL, 2163, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13362, 199, NULL, 2163, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13363, 5608, NULL, 2163, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13364, 1665, NULL, 2164, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13365, 84, NULL, 2165, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13366, 2559, NULL, 2165, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13367, 867, NULL, 2165, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13368, 7137, NULL, 2167, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13369, 7138, NULL, 120, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13370, 312, NULL, 120, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13371, 1179, NULL, 120, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13372, 1956, NULL, 120, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13373, 7139, NULL, 146, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13374, 2349, NULL, 146, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13375, 1311, NULL, 146, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13376, 7140, NULL, 2423, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13377, 7141, NULL, 2423, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13378, 5741, NULL, 2423, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13379, 7142, NULL, 2423, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13380, 7143, NULL, 2426, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13381, 7144, NULL, 2426, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13382, 7145, NULL, 2426, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13383, 7146, NULL, 2426, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13384, 7147, NULL, 3264, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13385, 7009, NULL, 3264, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13386, 141, NULL, 3264, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13387, 7148, NULL, 3265, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13388, 2773, NULL, 3265, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13389, 5127, NULL, 3265, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13390, 7149, NULL, 3265, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13391, 7150, NULL, 3266, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13392, 2185, NULL, 3266, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13393, 1628, NULL, 3266, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13394, 3662, NULL, 3266, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13395, 7151, NULL, 3267, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13396, 403, NULL, 3267, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13397, 2140, NULL, 3267, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13398, 867, NULL, 3267, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13399, 7152, NULL, 3268, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13400, 2520, NULL, 3268, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13401, 1643, NULL, 3268, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13402, 1437, NULL, 3268, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13403, 7153, NULL, 3269, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13404, 267, NULL, 3269, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13405, 812, NULL, 3269, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13406, 2544, NULL, 3269, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13407, 7154, NULL, 3270, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13408, 787, NULL, 3270, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13409, 7155, NULL, 3270, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13410, 1481, NULL, 3270, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13411, 2457, NULL, 2260, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13412, 682, NULL, 2260, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13413, 1777, NULL, 2260, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13414, 103, NULL, 2263, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13415, 1067, NULL, 2263, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13416, 1446, NULL, 2263, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13417, 3507, NULL, 2263, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13418, 7156, NULL, 2264, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19109, 292, NULL, 2151, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19110, 376, NULL, 2151, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32899, 2322, NULL, 10188, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24527, 11015, NULL, 7579, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19118, 41, NULL, 2153, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19119, 1485, NULL, 2153, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19120, 3890, NULL, 2871, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19121, 9590, NULL, 6013, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19122, 2899, NULL, 6014, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19123, 2307, NULL, 6014, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19125, 9592, NULL, 6015, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19126, 781, NULL, 6016, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19127, 283, NULL, 6017, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19128, 4836, NULL, 6017, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19129, 181, NULL, 6018, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19130, 1132, NULL, 6018, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19131, 488, NULL, 6018, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19132, 63, NULL, 4762, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19134, 726, NULL, 2408, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19136, 2696, NULL, 6024, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19137, 2152, NULL, 4239, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19138, 2152, NULL, 1413, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19139, 1645, NULL, 4429, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19140, 9514, NULL, 4429, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19141, 5853, NULL, 4429, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19142, 1748, NULL, 4429, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19143, 2187, NULL, 6019, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19144, 1193, NULL, 6019, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19145, 104, NULL, 6019, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19150, 3299, NULL, 6039, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19151, 9610, NULL, 6039, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19133, 600, NULL, 2408, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19135, 1431, NULL, 2408, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29405, 812, NULL, 9173, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29406, 1291, NULL, 9173, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29407, 12408, NULL, 9173, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29527, 598, NULL, 9216, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29528, 2536, NULL, 9216, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29529, 2318, NULL, 9216, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29530, 3242, NULL, 9216, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29680, 236, NULL, 2590, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29681, 730, NULL, 2590, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29682, 1643, NULL, 2590, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29683, 429, NULL, 2590, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29708, 12471, NULL, 9278, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29709, 12472, NULL, 9278, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29776, 1700, NULL, 2077, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13419, 2874, NULL, 2264, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13420, 5148, NULL, 2264, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13421, 5148, NULL, 3667, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13422, 7157, NULL, 2256, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13423, 5255, NULL, 2256, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13424, 1091, NULL, 3113, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13425, 1882, NULL, 2258, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13426, 644, NULL, 2258, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13427, 2918, NULL, 2258, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13428, 1696, NULL, 2261, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13429, 2894, NULL, 2261, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13430, 1264, NULL, 2261, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13431, 1043, NULL, 2262, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13432, 1311, NULL, 2262, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13433, 890, NULL, 2262, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13434, 951, NULL, 2262, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13435, 3664, NULL, 2259, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13436, 4735, NULL, 2259, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13437, 7072, NULL, 2259, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13438, 6325, NULL, 2265, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13439, 6485, NULL, 2265, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13440, 7158, NULL, 2265, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13441, 6036, NULL, 2255, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13442, 5304, NULL, 2255, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13443, 7159, NULL, 2255, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13444, 5361, NULL, 2257, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13445, 5374, NULL, 2257, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13446, 7160, NULL, 2257, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13447, 7161, NULL, 1078, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13448, 7162, NULL, 1078, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13449, 6861, NULL, 1078, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13450, 7163, NULL, 1080, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13451, 7164, NULL, 1080, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13452, 7165, NULL, 1080, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13453, 7166, NULL, 1081, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13454, 7167, NULL, 1081, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13455, 3109, NULL, 1081, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13456, 857, NULL, 1081, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13457, 1513, NULL, 1081, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13458, 173, NULL, 1082, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13459, 2016, NULL, 1082, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13460, 598, NULL, 1082, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13461, 1801, NULL, 1083, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13462, 3129, NULL, 1083, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13463, 3130, NULL, 1083, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13464, 1965, NULL, 1083, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13465, 1445, NULL, 1084, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13466, 7168, NULL, 1084, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13467, 2445, NULL, 1084, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13468, 1533, NULL, 1085, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13469, 5872, NULL, 1085, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13470, 2709, NULL, 1085, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13471, 601, NULL, 1086, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13472, 4048, NULL, 1086, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13473, 2429, NULL, 1086, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13474, 84, NULL, 1087, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13475, 7169, NULL, 1087, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13476, 7170, NULL, 1087, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13477, 2353, NULL, 1088, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19124, 3521, NULL, 6014, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13478, 2203, NULL, 1088, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13479, 5885, NULL, 1088, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13480, 6464, NULL, 1088, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13481, 614, NULL, 1089, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13482, 5900, NULL, 1089, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13483, 7171, NULL, 1089, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13487, 1813, NULL, 1091, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13488, 4330, NULL, 1091, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13489, 2028, NULL, 1091, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13485, 7173, NULL, 1090, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13486, 7174, NULL, 1090, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13484, 7172, NULL, 1090, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19111, 892, NULL, 2160, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19114, 9059, NULL, 2160, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19113, 9588, NULL, 2160, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19112, 1311, NULL, 2160, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13490, 7175, NULL, 1092, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29822, 12501, NULL, 9309, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29823, 11458, NULL, 9309, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13491, 512, NULL, 1169, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13492, 1826, NULL, 1169, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13493, 5974, NULL, 1169, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13494, 6505, NULL, 1169, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13495, 6514, NULL, 1170, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13496, 132, NULL, 1171, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13497, 6693, NULL, 1172, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13498, 2583, NULL, 1173, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13499, 3428, NULL, 1174, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13500, 2264, NULL, 1174, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13501, 6343, NULL, 1174, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13502, 1885, NULL, 1174, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13503, 283, NULL, 1175, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13504, 1261, NULL, 1175, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13505, 6507, NULL, 1175, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13506, 5853, NULL, 1175, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13507, 6508, NULL, 1175, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13508, 685, NULL, 1176, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13509, 1834, NULL, 1176, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13510, 1091, NULL, 1176, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13511, 1503, NULL, 1176, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13512, 382, NULL, 1176, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13513, 424, NULL, 1176, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13514, 7078, NULL, 1177, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13515, 3679, NULL, 1177, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13516, 1462, NULL, 1177, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13517, 152, NULL, 1177, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13518, 2416, NULL, 1596, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13519, 396, NULL, 3666, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13520, 2489, NULL, 3666, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13521, 2369, NULL, 3666, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13522, 372, NULL, 1117, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32896, 1858, NULL, 10187, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13523, 1525, NULL, 1117, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13524, 1961, NULL, 1117, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13525, 448, NULL, 3304, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13526, 914, NULL, 3304, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13527, 2332, NULL, 3304, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13528, 2391, NULL, 3304, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13529, 5174, NULL, 3688, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13530, 807, NULL, 3308, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13531, 757, NULL, 3308, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13532, 2383, NULL, 3308, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13533, 610, NULL, 3309, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13534, 2434, NULL, 3309, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13535, 1313, NULL, 3309, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13536, 350, NULL, 3310, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13537, 256, NULL, 3310, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13538, 1528, NULL, 3310, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13539, 121, NULL, 3311, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13540, 306, NULL, 3311, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13541, 267, NULL, 3311, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13542, 1882, NULL, 3312, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13543, 1628, NULL, 3312, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13544, 1455, NULL, 3312, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13545, 1593, NULL, 3313, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13546, 935, NULL, 3313, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13547, 850, NULL, 3313, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13548, 523, NULL, 3314, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19152, 9611, NULL, 6039, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19153, 2152, NULL, 6040, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19154, 9612, NULL, 6040, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19155, 9613, NULL, 6040, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19156, 2113, NULL, 6040, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19157, 1461, NULL, 6041, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19158, 141, NULL, 6041, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19159, 9614, NULL, 6041, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19160, 916, NULL, 6041, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19161, 6507, NULL, 6042, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19162, 9615, NULL, 6042, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19163, 9616, NULL, 6042, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19164, 9617, NULL, 6042, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19165, 674, NULL, 6043, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19166, 9618, NULL, 6043, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19167, 9619, NULL, 6043, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13549, 1926, NULL, 3314, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13550, 2752, NULL, 3314, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13551, 904, NULL, 3315, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13552, 220, NULL, 3315, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13553, 1257, NULL, 3316, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13554, 1091, NULL, 3316, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13555, 1513, NULL, 3316, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13556, 487, NULL, 3317, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13557, 2492, NULL, 3317, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13558, 7176, NULL, 3317, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13559, 534, NULL, 3318, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13560, 2800, NULL, 3318, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13561, 1505, NULL, 3318, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13562, 1141, NULL, 2366, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13563, 1141, NULL, 1316, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13564, 206, NULL, 418, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13565, 445, NULL, 4076, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13566, 1386, NULL, 3736, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13567, 3253, NULL, 3736, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13568, 3262, NULL, 3736, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13569, 2458, NULL, 3736, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13570, 3199, NULL, 3736, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13571, 2357, NULL, 4537, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13572, 3831, NULL, 4537, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13573, 2574, NULL, 4537, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13574, 7184, NULL, 4538, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13575, 7185, NULL, 4538, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13576, 1898, NULL, 4538, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13577, 812, NULL, 4538, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13578, 502, NULL, 4539, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13579, 650, NULL, 4539, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13580, 332, NULL, 4539, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13581, 1744, NULL, 4539, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13586, 418, NULL, 4541, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13587, 3483, NULL, 4541, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13588, 474, NULL, 4541, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13589, 7187, NULL, 4542, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13590, 2619, NULL, 4542, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13591, 7188, NULL, 4542, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13592, 683, NULL, 4543, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13593, 74, NULL, 4543, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13594, 697, NULL, 4543, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13595, 7189, NULL, 4543, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13596, 1638, NULL, 4544, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13597, 497, NULL, 4544, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13598, 1091, NULL, 4544, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13599, 1655, NULL, 4544, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13600, 320, NULL, 4545, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13601, 1664, NULL, 4545, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13602, 6051, NULL, 4545, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13603, 376, NULL, 4545, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13604, 7190, NULL, 4546, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13605, 1685, NULL, 4546, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13606, 1500, NULL, 4547, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13607, 839, NULL, 4547, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13608, 5165, NULL, 4547, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13609, 4374, NULL, 4547, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13610, 2668, NULL, 4548, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13611, 4891, NULL, 4548, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13612, 2285, NULL, 4548, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13613, 2042, NULL, 4548, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13614, 1624, NULL, 4549, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13615, 7191, NULL, 4549, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13616, 2531, NULL, 4549, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13617, 7192, NULL, 4549, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13618, 3492, NULL, 4550, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13619, 99, NULL, 4550, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13620, 7193, NULL, 4550, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13621, 7194, NULL, 4551, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13622, 7195, NULL, 4551, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13623, 4872, NULL, 4552, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13624, 2975, NULL, 4552, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13625, 7198, NULL, 4552, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13626, 7199, NULL, 4553, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13627, 164, NULL, 4553, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13628, 1042, NULL, 4553, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13629, 2144, NULL, 4553, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13630, 7200, NULL, 4554, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13631, 7201, NULL, 4551, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13632, 7202, NULL, 4551, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13633, 2996, NULL, 4551, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13634, 1945, NULL, 4552, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13635, 2929, NULL, 4554, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13636, 4730, NULL, 4554, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13637, 1861, NULL, 4554, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13638, 3452, NULL, 4555, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13639, 3453, NULL, 4555, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13640, 7203, NULL, 4556, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13641, 259, NULL, 4556, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19168, 9620, NULL, 6043, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19171, 3740, NULL, 6045, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19172, 5862, NULL, 6045, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19173, 3243, NULL, 6045, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19174, 6507, NULL, 6046, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19175, 1146, NULL, 6046, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19176, 2635, NULL, 6046, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19177, 7323, NULL, 6047, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19178, 174, NULL, 6047, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19179, 3835, NULL, 6047, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19180, 3740, NULL, 6048, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19181, 9563, NULL, 6048, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19182, 2554, NULL, 6048, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19183, 1078, NULL, 932, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19184, 2418, NULL, 2152, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19185, 692, NULL, 6049, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19186, 1453, NULL, 6049, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19187, 921, NULL, 6049, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19188, 2631, NULL, 6049, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19189, 385, NULL, 6050, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19190, 2413, NULL, 6050, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19191, 2414, NULL, 6050, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19192, 137, NULL, 6051, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19193, 3141, NULL, 6051, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19194, 3142, NULL, 6051, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19198, 694, NULL, 6053, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19199, 686, NULL, 6053, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19200, 4253, NULL, 6053, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19201, 1665, NULL, 6054, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19202, 2336, NULL, 6054, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19203, 429, NULL, 6054, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19204, 3622, NULL, 6054, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19205, 2187, NULL, 6055, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19206, 1089, NULL, 6055, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19207, 7128, NULL, 6055, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19208, 2074, NULL, 6055, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19209, 2349, NULL, 6055, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29408, 10142, NULL, 9174, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29409, 1067, NULL, 9174, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29410, 1352, NULL, 9174, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29710, 6287, NULL, 9279, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29777, 374, NULL, 2080, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29778, 2626, NULL, 2080, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29779, 1629, NULL, 2080, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29824, 669, NULL, 9310, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19169, 7323, NULL, 6044, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19170, 9597, NULL, 6044, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29825, 686, NULL, 9310, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29826, 709, NULL, 9310, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29827, 6091, NULL, 9310, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13642, 7132, NULL, 4556, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13643, 2625, NULL, 4556, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13644, 2252, NULL, 4557, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13645, 1462, NULL, 4557, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13646, 267, NULL, 4557, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13647, 1624, NULL, 4557, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13648, 7197, NULL, 4558, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13649, 1999, NULL, 4558, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13650, 2912, NULL, 4558, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13651, 7204, NULL, 4558, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13652, 7205, NULL, 4559, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13653, 1146, NULL, 4559, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13654, 2605, NULL, 4559, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13655, 7206, NULL, 4560, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13656, 955, NULL, 4560, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13657, 503, NULL, 4560, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13658, 7208, NULL, 4561, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13659, 206, NULL, 4561, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13660, 1392, NULL, 4561, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13661, 1334, NULL, 4561, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13662, 7209, NULL, 4562, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13663, 7118, NULL, 4562, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13664, 2937, NULL, 4562, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13665, 2081, NULL, 4562, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13666, 7210, NULL, 4563, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13667, 2531, NULL, 4563, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13668, 1542, NULL, 4563, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13669, 1707, NULL, 4563, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13670, 812, NULL, 4563, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13671, 7211, NULL, 4564, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13672, 1067, NULL, 4564, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13673, 2780, NULL, 4564, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13674, 7212, NULL, 4564, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13675, 2702, NULL, 4565, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13676, 3949, NULL, 4565, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13677, 973, NULL, 4565, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13678, 2862, NULL, 4565, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13679, 256, NULL, 4567, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13680, 1585, NULL, 4568, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13682, 1438, NULL, 4572, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13683, 2748, NULL, 4573, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13684, 1544, NULL, 4574, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13685, 628, NULL, 4575, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13686, 722, NULL, 4576, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13687, 1073, NULL, 4577, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13688, 1106, NULL, 4578, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13689, 41, NULL, 4579, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13690, 2873, NULL, 4580, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13691, 1528, NULL, 4581, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13692, 1312, NULL, 4582, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13693, 1331, NULL, 4583, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13695, 1421, NULL, 4587, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13696, 1270, NULL, 4588, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13697, 1554, NULL, 4589, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13698, 1062, NULL, 4590, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13699, 1264, NULL, 4591, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13700, 824, NULL, 4592, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13701, 171, NULL, 4593, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13702, 3006, NULL, 4566, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13703, 7214, NULL, 4567, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13704, 7215, NULL, 4567, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13705, 5956, NULL, 4567, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13706, 7216, NULL, 4568, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13707, 7217, NULL, 4568, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13708, 7218, NULL, 4568, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13709, 7219, NULL, 4568, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13710, 2830, NULL, 4624, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13711, 4550, NULL, 4624, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13712, 5080, NULL, 4624, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13713, 3243, NULL, 4624, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13714, 209, NULL, 4570, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13715, 7220, NULL, 4570, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13716, 7221, NULL, 4570, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13717, 7222, NULL, 4570, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13723, 237, NULL, 4572, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13724, 7227, NULL, 4572, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13725, 7228, NULL, 4572, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13726, 7229, NULL, 4573, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13727, 7230, NULL, 4573, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13728, 7231, NULL, 4573, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13729, 7233, NULL, 4574, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13730, 7234, NULL, 4574, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13731, 1961, NULL, 4574, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13732, 7232, NULL, 4575, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13733, 7235, NULL, 4575, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19210, 1316, NULL, 6055, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19211, 544, NULL, 6056, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19212, 651, NULL, 6056, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19213, 2699, NULL, 6056, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19214, 794, NULL, 6057, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19215, 2191, NULL, 6057, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19216, 799, NULL, 6057, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19217, 2159, NULL, 6057, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19218, 1317, NULL, 6058, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19219, 1624, NULL, 6058, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19220, 9624, NULL, 6058, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19221, 378, NULL, 6059, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19222, 312, NULL, 6059, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19223, 77, NULL, 6059, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19224, 2055, NULL, 6060, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19225, 803, NULL, 6060, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19226, 839, NULL, 6060, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19227, 9625, NULL, 6061, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19228, 3086, NULL, 6062, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19229, 816, NULL, 6062, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19230, 1662, NULL, 6063, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32897, 3324, NULL, 10187, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19232, 434, NULL, 6063, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19233, 398, NULL, 6063, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19234, 958, NULL, 6064, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19235, 756, NULL, 6064, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19236, 2479, NULL, 6064, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19237, 2789, NULL, 6064, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19238, 1597, NULL, 6065, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19239, 3550, NULL, 6065, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19240, 4323, NULL, 6065, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19241, 1082, NULL, 6066, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19242, 2945, NULL, 6066, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19243, 3789, NULL, 6066, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19244, 1329, NULL, 6067, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19245, 1629, NULL, 6067, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19246, 382, NULL, 6067, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19247, 55, NULL, 6068, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19248, 2294, NULL, 6068, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19249, 2524, NULL, 6068, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19250, 1965, NULL, 6068, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19251, 817, NULL, 5199, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29411, 973, NULL, 9175, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29412, 12409, NULL, 9175, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29711, 5039, NULL, 9280, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29712, 1699, NULL, 9280, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29780, 7450, NULL, 3610, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29781, 1464, NULL, 3610, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29782, 12483, NULL, 3610, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13734, 503, NULL, 4575, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13735, 1639, NULL, 4575, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13736, 58, NULL, 4575, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13737, 51, NULL, 4575, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (13738, 682, NULL, 4575, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (13739, 7236, NULL, 4576, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13740, 7237, NULL, 4576, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13741, 1052, NULL, 4576, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13742, 2285, NULL, 4576, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13743, 1502, NULL, 4576, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13744, 4907, NULL, 4577, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13745, 1445, NULL, 4577, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13746, 7238, NULL, 4577, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13747, 7239, NULL, 4578, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13748, 3631, NULL, 4578, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13749, 1971, NULL, 4578, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13750, 376, NULL, 4578, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13751, 320, NULL, 4578, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13752, 2159, NULL, 4578, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (13753, 1514, NULL, 4579, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13754, 1821, NULL, 4580, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13755, 1862, NULL, 4580, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13756, 3390, NULL, 4580, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13757, 5246, NULL, 4581, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13758, 4365, NULL, 4581, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13759, 7240, NULL, 4581, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13760, 2017, NULL, 4582, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13761, 2631, NULL, 4582, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13762, 305, NULL, 4582, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13763, 5892, NULL, 4582, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13764, 2780, NULL, 4582, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13765, 1208, NULL, 4582, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (13766, 1117, NULL, 4582, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (13767, 6728, NULL, 4583, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13768, 676, NULL, 4583, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13769, 2945, NULL, 4583, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13718, 7223, NULL, 4571, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13694, 12, NULL, 4586, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32911, 2281, NULL, 10193, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32912, 491, NULL, 10193, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10926, 6343, NULL, 556, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10925, 2264, NULL, 556, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10924, 3428, NULL, 556, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13780, 2993, NULL, 4587, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13781, 6929, NULL, 4587, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13782, 6930, NULL, 4587, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13783, 2451, NULL, 4588, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13784, 2531, NULL, 4588, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13785, 2438, NULL, 4588, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13786, 68, NULL, 4588, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13787, 1311, NULL, 4588, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13788, 2544, NULL, 4588, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (13789, 812, NULL, 4588, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (13790, 1789, NULL, 4589, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13791, 586, NULL, 4589, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13792, 2436, NULL, 4589, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13793, 2706, NULL, 4589, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13794, 2089, NULL, 4589, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13795, 425, NULL, 4589, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (13796, 1880, NULL, 4589, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (13797, 3232, NULL, 4590, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13798, 1659, NULL, 4590, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13799, 2443, NULL, 4590, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13800, 164, NULL, 4590, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13801, 1099, NULL, 4590, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13802, 2321, NULL, 4590, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (13803, 7243, NULL, 4590, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (13804, 2316, NULL, 4591, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13805, 1941, NULL, 4591, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13806, 5953, NULL, 4591, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13807, 7244, NULL, 4591, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13808, 200, NULL, 4591, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13809, 5188, NULL, 4592, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13810, 2968, NULL, 4592, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13811, 1665, NULL, 4592, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13812, 4983, NULL, 4593, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13813, 1945, NULL, 4593, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13814, 7245, NULL, 4593, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13815, 206, NULL, 4569, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13816, 1665, NULL, 4613, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13817, 1214, NULL, 4614, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13818, 382, NULL, 4616, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13819, 2680, NULL, 4619, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13820, 377, NULL, 4620, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13821, 1368, NULL, 4621, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13822, 248, NULL, 4622, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13823, 923, NULL, 4623, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13824, 3156, NULL, 4569, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13825, 1001, NULL, 4569, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13826, 576, NULL, 4569, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19252, 817, NULL, 2879, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19253, 817, NULL, 3563, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19254, 9626, NULL, 5857, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19255, 2815, NULL, 5857, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19256, 5126, NULL, 5857, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19257, 4384, NULL, 5858, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19258, 302, NULL, 5858, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19259, 6484, NULL, 5858, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19260, 8792, NULL, 5859, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19261, 9627, NULL, 5859, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19266, 9004, NULL, 5862, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19267, 7283, NULL, 5862, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19268, 4912, NULL, 5862, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19269, 2047, NULL, 5864, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19270, 5574, NULL, 5864, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19274, 2545, NULL, 5867, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19275, 2424, NULL, 5867, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19276, 1745, NULL, 5867, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19277, 116, NULL, 5868, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19278, 3126, NULL, 5868, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19279, 1706, NULL, 5868, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19280, 589, NULL, 5870, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19281, 4578, NULL, 5870, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19282, 3236, NULL, 5870, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19283, 9629, NULL, 5871, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19284, 9630, NULL, 5871, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19285, 1595, NULL, 5871, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19287, 2655, NULL, 5877, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19288, 2247, NULL, 5877, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19289, 1503, NULL, 5878, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19290, 829, NULL, 5878, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19291, 685, NULL, 5878, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19292, 4077, NULL, 5880, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19293, 3109, NULL, 5881, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29413, 12402, NULL, 9176, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29414, 5952, NULL, 9176, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29415, 12403, NULL, 9176, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29713, 12473, NULL, 9281, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29783, 3460, NULL, 2075, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29784, 12484, NULL, 2075, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29785, 6035, NULL, 2075, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13827, 1164, NULL, 4613, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13828, 1111, NULL, 4613, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13829, 716, NULL, 4613, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13830, 7069, NULL, 4614, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13831, 6443, NULL, 4614, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13832, 266, NULL, 4614, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13833, 4381, NULL, 4615, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13834, 713, NULL, 4615, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13835, 2628, NULL, 4616, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13836, 5646, NULL, 4616, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13837, 416, NULL, 4616, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13838, 7246, NULL, 4617, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13839, 1448, NULL, 4618, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13840, 3521, NULL, 4618, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13841, 1699, NULL, 4618, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13842, 2240, NULL, 4618, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13843, 196, NULL, 4619, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13844, 2597, NULL, 4619, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13845, 5490, NULL, 4619, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13846, 2510, NULL, 4620, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13847, 4522, NULL, 4620, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13848, 2822, NULL, 4621, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13849, 7247, NULL, 4621, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13850, 1613, NULL, 4621, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13851, 7248, NULL, 4622, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13852, 1403, NULL, 4622, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13853, 2786, NULL, 4622, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13854, 51, NULL, 4623, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13855, 1439, NULL, 4623, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13856, 2134, NULL, 4623, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13857, 7249, NULL, 4625, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13858, 6306, NULL, 4711, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13859, 236, NULL, 4711, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13860, 7261, NULL, 4711, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13861, 6204, NULL, 4711, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13862, 5123, NULL, 4712, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13863, 1961, NULL, 4712, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13864, 993, NULL, 4712, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13865, 1809, NULL, 4713, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13866, 1179, NULL, 4713, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13867, 378, NULL, 4713, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13868, 4727, NULL, 4714, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13869, 920, NULL, 4714, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13870, 2151, NULL, 4714, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13871, 382, NULL, 4715, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13872, 1655, NULL, 4715, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13873, 1091, NULL, 4715, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13874, 1834, NULL, 4715, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13875, 1373, NULL, 4716, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13876, 1818, NULL, 4716, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13877, 1876, NULL, 4716, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13878, 295, NULL, 4717, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13879, 1450, NULL, 4717, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13880, 1622, NULL, 4718, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13881, 7262, NULL, 4719, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13882, 73, NULL, 4719, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19286, 9460, NULL, 5875, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (13883, 825, NULL, 4720, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13884, 7263, NULL, 4720, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13885, 188, NULL, 4720, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13886, 369, NULL, 4720, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13770, 7241, NULL, 4584, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13772, 7242, NULL, 4584, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13771, 6575, NULL, 4584, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13887, 958, NULL, 4721, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13888, 5928, NULL, 4721, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13889, 1096, NULL, 4721, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13890, 267, NULL, 4722, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13891, 5366, NULL, 4722, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13892, 5115, NULL, 4722, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13893, 7264, NULL, 4722, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13894, 7265, NULL, 4723, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13895, 1544, NULL, 4723, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13896, 5190, NULL, 4723, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13897, 730, NULL, 4724, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13898, 2968, NULL, 4724, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13899, 7266, NULL, 4724, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13900, 2069, NULL, 4724, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13901, 1066, NULL, 4725, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13778, 760, NULL, 4586, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13777, 4578, NULL, 4586, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13779, 2957, NULL, 4586, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19271, 434, NULL, 5866, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19273, 3116, NULL, 5866, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19272, 6701, NULL, 5866, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32918, 13881, NULL, 10195, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13902, 2880, NULL, 4725, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13903, 152, NULL, 4726, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13904, 4258, NULL, 4726, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13905, 7267, NULL, 4726, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13906, 2943, NULL, 4726, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13907, 6205, NULL, 4727, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13908, 7268, NULL, 4727, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13909, 7269, NULL, 4728, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13910, 5235, NULL, 4728, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13911, 7270, NULL, 4728, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13912, 6092, NULL, 4728, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13913, 7271, NULL, 4729, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13914, 7272, NULL, 4729, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13915, 2798, NULL, 4730, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13916, 1514, NULL, 4730, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13917, 688, NULL, 4730, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13918, 2860, NULL, 4730, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19294, 857, NULL, 5881, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19295, 1376, NULL, 5881, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19296, 2772, NULL, 5881, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19297, 2469, NULL, 5881, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19299, 9631, NULL, 5881, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (19300, 861, NULL, 5882, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19301, 5006, NULL, 5882, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19302, 5696, NULL, 5882, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19303, 3989, NULL, 5883, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19304, 664, NULL, 5883, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19305, 5082, NULL, 5883, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19306, 608, NULL, 5883, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19307, 7457, NULL, 5883, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19308, 1971, NULL, 5883, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19309, 9632, NULL, 5883, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19310, 9633, NULL, 5883, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (19311, 9613, NULL, 5884, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19312, 9337, NULL, 5884, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19313, 9634, NULL, 5884, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19314, 1379, NULL, 5885, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19315, 5151, NULL, 5885, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19316, 5018, NULL, 5885, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19317, 1786, NULL, 5886, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19318, 2970, NULL, 5886, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19319, 5158, NULL, 5886, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19320, 3123, NULL, 5886, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19321, 9635, NULL, 5887, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19322, 2587, NULL, 5887, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19323, 1294, NULL, 5887, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19324, 1446, NULL, 5887, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19325, 4990, NULL, 5887, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19326, 2683, NULL, 5887, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19327, 2660, NULL, 5887, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19328, 9636, NULL, 5887, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (19329, 3056, NULL, 5888, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19330, 2803, NULL, 5888, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19331, 6801, NULL, 5888, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19333, 981, NULL, 6084, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19334, 9659, NULL, 6084, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19335, 7066, NULL, 6084, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19336, 1620, NULL, 6085, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29416, 6713, NULL, 9177, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29417, 5109, NULL, 9177, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29418, 796, NULL, 9177, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29714, 12474, NULL, 9282, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29786, 533, NULL, 2074, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13919, 7273, NULL, 4731, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13920, 2899, NULL, 4732, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13921, 5036, NULL, 4732, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13922, 7274, NULL, 4732, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13923, 1257, NULL, 4733, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13924, 1042, NULL, 4733, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13925, 68, NULL, 4733, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13926, 3628, NULL, 4733, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13927, 778, NULL, 4734, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13928, 6761, NULL, 4734, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13929, 2786, NULL, 4734, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13930, 7275, NULL, 4734, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13931, 4741, NULL, 4735, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13932, 7276, NULL, 4735, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13933, 431, NULL, 4735, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13934, 5384, NULL, 4735, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13935, 448, NULL, 4736, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13936, 77, NULL, 4736, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13937, 1406, NULL, 4736, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13938, 226, NULL, 4736, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13939, 2871, NULL, 4737, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13940, 7277, NULL, 4737, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13941, 1593, NULL, 4738, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13942, 1628, NULL, 4738, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13943, 1643, NULL, 4738, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13944, 1700, NULL, 4738, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13945, 534, NULL, 4739, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13946, 2773, NULL, 4739, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13947, 2317, NULL, 4739, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13948, 4360, NULL, 4739, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13949, 6548, NULL, 4740, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13950, 2118, NULL, 4740, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13951, 396, NULL, 4740, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13952, 1979, NULL, 4740, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13953, 3093, NULL, 1307, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13954, 2988, NULL, 2848, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13955, 857, NULL, 2848, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (13956, 49, NULL, 2848, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (13957, 289, NULL, 2848, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (13958, 3517, NULL, 1839, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13959, 2922, NULL, 1839, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13960, 182, NULL, 1840, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13961, 1707, NULL, 1840, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13962, 6253, NULL, 1849, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13963, 7278, NULL, 1849, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13964, 7279, NULL, 1849, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13965, 5014, NULL, 1841, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13966, 202, NULL, 3704, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13967, 289, NULL, 3704, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13968, 448, NULL, 3704, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13969, 1503, NULL, 3704, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13970, 41, NULL, 4697, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13971, 13, NULL, 4697, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19332, 9638, NULL, 5956, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13979, 1603, NULL, 4700, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13980, 1146, NULL, 4700, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13981, 1912, NULL, 4700, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13982, 6700, NULL, 4700, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13983, 1141, NULL, 4701, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13984, 2434, NULL, 4701, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13985, 2435, NULL, 4701, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13986, 3222, NULL, 4701, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13987, 1391, NULL, 4702, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13988, 2483, NULL, 4702, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13989, 951, NULL, 4702, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13990, 534, NULL, 4703, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13991, 7295, NULL, 4703, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13992, 7296, NULL, 4703, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13993, 4428, NULL, 4703, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13994, 537, NULL, 4704, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13995, 7297, NULL, 4704, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13996, 7298, NULL, 4704, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13997, 5961, NULL, 4704, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13998, 781, NULL, 4705, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13999, 1181, NULL, 4706, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14000, 2867, NULL, 4706, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14001, 1031, NULL, 4706, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14002, 7299, NULL, 4707, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14003, 2188, NULL, 4707, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14004, 2883, NULL, 4707, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14005, 429, NULL, 4707, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14006, 1089, NULL, 4708, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14007, 1193, NULL, 4708, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14008, 7300, NULL, 4708, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14009, 7301, NULL, 4708, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14010, 7130, NULL, 4708, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14011, 1154, NULL, 4709, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14012, 2968, NULL, 4709, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13975, 7293, NULL, 4698, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13972, 626, NULL, 4698, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13974, 7292, NULL, 4698, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13973, 1872, NULL, 4698, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14013, 1222, NULL, 4709, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14014, 3002, NULL, 4709, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14015, 749, NULL, 4710, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14016, 6656, NULL, 4710, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14017, 6962, NULL, 4710, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14018, 2467, NULL, 4710, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14019, 1329, NULL, 4642, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14020, 7302, NULL, 4642, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14021, 2203, NULL, 4642, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14022, 2554, NULL, 4642, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14023, 2948, NULL, 4643, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14024, 7303, NULL, 4643, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14025, 3846, NULL, 4643, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14026, 7304, NULL, 4643, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14027, 769, NULL, 4644, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14028, 2189, NULL, 4644, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14029, 7305, NULL, 4644, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14030, 1722, NULL, 4644, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14031, 1401, NULL, 4645, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14032, 573, NULL, 4645, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14033, 2747, NULL, 4645, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14034, 2945, NULL, 4645, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14035, 1683, NULL, 4646, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32917, 1421, NULL, 10195, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14036, 533, NULL, 4646, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14037, 2822, NULL, 4646, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14038, 236, NULL, 4647, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14039, 1528, NULL, 4647, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14040, 1875, NULL, 4647, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14041, 2696, NULL, 4647, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14042, 4264, NULL, 4648, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14043, 1821, NULL, 4648, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14044, 1566, NULL, 4648, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14045, 206, NULL, 4648, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14046, 939, NULL, 4649, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14047, 1084, NULL, 4649, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14048, 1628, NULL, 4649, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29419, 6713, NULL, 9178, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29420, 5109, NULL, 9178, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29421, 796, NULL, 9178, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29715, 12475, NULL, 9283, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29787, 534, NULL, 2081, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29788, 7578, NULL, 2081, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29789, 12485, NULL, 2081, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19372, 1503, NULL, 6097, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19373, 482, NULL, 6097, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19374, 1091, NULL, 6097, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19375, 497, NULL, 6097, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19376, 992, NULL, 6097, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19377, 1329, NULL, 6097, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19378, 171, NULL, 6097, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (19379, 1629, NULL, 6097, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (19382, 1511, NULL, 6098, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19383, 914, NULL, 6098, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19384, 1334, NULL, 6098, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19385, 2592, NULL, 6098, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19386, 2696, NULL, 6099, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19387, 2375, NULL, 6099, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19388, 2285, NULL, 6099, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19389, 1977, NULL, 6099, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19396, 3600, NULL, 6102, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19397, 2432, NULL, 6102, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19398, 9667, NULL, 6102, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19399, 1896, NULL, 6102, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19400, 1474, NULL, 6103, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19401, 1042, NULL, 6103, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19402, 1117, NULL, 6103, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19403, 1745, NULL, 6103, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19404, 2545, NULL, 6103, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19405, 2442, NULL, 6103, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19406, 1659, NULL, 6103, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19407, 1013, NULL, 6104, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19408, 168, NULL, 6104, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19409, 259, NULL, 6104, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19410, 3581, NULL, 6104, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19411, 702, NULL, 6112, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19412, 3620, NULL, 6112, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19413, 3619, NULL, 6112, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19414, 2289, NULL, 6112, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19415, 216, NULL, 6105, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19416, 2728, NULL, 6105, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19417, 656, NULL, 6106, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19418, 975, NULL, 6106, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19427, 103, NULL, 6109, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19428, 9668, NULL, 6109, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19429, 5978, NULL, 6109, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19430, 5666, NULL, 6109, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19431, 2952, NULL, 6110, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19432, 9669, NULL, 6110, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19433, 8350, NULL, 6110, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19434, 9364, NULL, 6110, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19421, 3364, NULL, 6107, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19436, 1219, NULL, 6111, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19437, 2145, NULL, 6111, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19438, 839, NULL, 6111, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19439, 1882, NULL, 6113, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19440, 124, NULL, 6114, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19442, 1293, NULL, 6116, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19444, 1491, NULL, 6118, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19445, 2443, NULL, 6119, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19446, 1506, NULL, 6120, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19420, 2379, NULL, 6107, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19448, 568, NULL, 6123, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19449, 1235, NULL, 6124, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19450, 700, NULL, 6125, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19451, 1172, NULL, 6126, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19452, 514, NULL, 6127, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19453, 1091, NULL, 6128, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19454, 5931, NULL, 6113, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19455, 2952, NULL, 6113, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19456, 7457, NULL, 6113, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19457, 9670, NULL, 6114, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19458, 9671, NULL, 6114, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19459, 9672, NULL, 6114, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19463, 9673, NULL, 6116, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29422, 8316, NULL, 9179, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29423, 188, NULL, 9179, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29790, 2879, NULL, 2079, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29791, 727, NULL, 2079, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29792, 2878, NULL, 2079, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29793, 2927, NULL, 2079, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19467, 914, NULL, 6118, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19468, 688, NULL, 6118, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19469, 133, NULL, 6118, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19470, 867, NULL, 6119, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19471, 1745, NULL, 6119, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19472, 2918, NULL, 6120, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19473, 9675, NULL, 6120, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19474, 5929, NULL, 6120, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19475, 1266, NULL, 6121, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19476, 9676, NULL, 6121, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19419, 815, NULL, 6107, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19422, 1264, NULL, 6107, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19481, 2949, NULL, 6123, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19482, 9677, NULL, 6123, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19483, 2750, NULL, 6123, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19484, 9678, NULL, 6123, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19485, 1289, NULL, 6124, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19486, 2081, NULL, 6125, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19487, 7131, NULL, 6125, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19488, 2138, NULL, 6125, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19489, 6732, NULL, 6126, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19490, 9679, NULL, 6126, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19491, 929, NULL, 6126, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19492, 9680, NULL, 6127, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19493, 9681, NULL, 6127, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19494, 3271, NULL, 6127, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19495, 9682, NULL, 6128, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19496, 9683, NULL, 6128, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19497, 8297, NULL, 6128, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19498, 231, NULL, 2613, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19499, 833, NULL, 2613, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19500, 6759, NULL, 2613, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19501, 849, NULL, 2615, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19502, 9684, NULL, 2615, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19503, 3836, NULL, 2615, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19504, 295, NULL, 2608, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19505, 1562, NULL, 2608, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19506, 9621, NULL, 2608, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19507, 1403, NULL, 2608, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19508, 757, NULL, 2612, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19509, 2356, NULL, 2612, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19510, 1785, NULL, 2610, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19381, 152, NULL, 6101, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19393, 2138, NULL, 6101, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19395, 320, NULL, 6101, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19394, 429, NULL, 6101, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29841, 6969, NULL, 9314, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29844, 12509, NULL, 9314, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29845, 12510, NULL, 9314, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29847, 6962, NULL, 9315, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29848, 8800, NULL, 9315, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29846, 749, NULL, 9315, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29849, 12105, NULL, 9315, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29850, 5015, NULL, 9315, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19465, 4543, NULL, 6117, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19466, 9674, NULL, 6117, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19443, 2575, NULL, 6117, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19464, 2992, NULL, 6117, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19511, 963, NULL, 2610, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19512, 9685, NULL, 2610, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19513, 47, NULL, 2614, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19514, 3830, NULL, 2614, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19515, 9686, NULL, 2614, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19516, 1158, NULL, 2611, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19517, 1328, NULL, 2611, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19518, 1528, NULL, 2609, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19519, 2757, NULL, 2609, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19520, 1882, NULL, 2609, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19462, 4323, NULL, 6115, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19441, 9586, NULL, 6115, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19461, 8792, NULL, 6115, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19460, 8174, NULL, 6115, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19435, 1648, 478, 6111, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32921, 13883, NULL, 10196, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32922, 2921, NULL, 10196, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32920, 13882, NULL, 10196, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32923, 13884, NULL, 10196, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19521, 285, NULL, 2555, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19522, 9687, NULL, 2555, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19523, 9688, NULL, 2555, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19530, 1241, NULL, 2556, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19531, 9691, NULL, 2556, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19532, 9692, NULL, 2556, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19539, 1179, NULL, 2559, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19540, 955, NULL, 2559, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19541, 37, NULL, 2559, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19542, 353, NULL, 2557, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19543, 6422, NULL, 2557, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19544, 9693, NULL, 2557, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19545, 363, NULL, 6129, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19546, 368, NULL, 6129, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19547, 1376, NULL, 6129, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19548, 2536, NULL, 6129, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19549, 1285, NULL, 6130, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19550, 2413, NULL, 6130, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19551, 889, NULL, 6130, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19552, 5369, NULL, 6130, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19553, 236, NULL, 6131, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19554, 9025, NULL, 6131, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19555, 5916, NULL, 6131, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19556, 2040, NULL, 6131, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19557, 274, NULL, 6132, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19558, 1042, NULL, 6132, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19559, 1745, NULL, 6132, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19560, 1118, NULL, 6132, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19561, 563, NULL, 6133, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19562, 2555, NULL, 6133, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19563, 3154, NULL, 6133, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19564, 2202, NULL, 6133, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19565, 1019, NULL, 6134, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19566, 1418, NULL, 6134, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19567, 1132, NULL, 6134, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19568, 2309, NULL, 6134, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19569, 1001, NULL, 6135, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19570, 5274, NULL, 6135, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19571, 456, NULL, 6135, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19572, 1140, NULL, 6135, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19573, 1111, NULL, 6136, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29424, 3188, NULL, 9180, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29425, 12404, NULL, 9180, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29426, 1264, NULL, 9180, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19574, 7557, NULL, 6136, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19575, 9703, NULL, 6136, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19576, 2456, NULL, 6136, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19577, 1301, NULL, 6137, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19578, 4220, NULL, 6137, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19579, 306, NULL, 6137, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19580, 902, NULL, 6137, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19581, 56, NULL, 6138, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19582, 7072, NULL, 6138, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19583, 9704, NULL, 6138, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19584, 1385, NULL, 6138, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19585, 1100, NULL, 6139, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19586, 1870, NULL, 6139, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19587, 1955, NULL, 6139, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19588, 4323, NULL, 6139, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19589, 964, NULL, 6140, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19590, 9705, NULL, 6140, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19591, 2992, NULL, 6140, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19592, 376, NULL, 6140, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19593, 9706, NULL, 6140, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19594, 4546, NULL, 6140, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19595, 1722, NULL, 6140, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19596, 371, NULL, 6069, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19597, 1769, NULL, 6069, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19598, 1116, NULL, 6070, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19599, 5885, NULL, 6070, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19600, 9707, NULL, 6070, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19601, 5979, NULL, 6070, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19602, 2316, NULL, 6070, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19603, 5837, NULL, 6070, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19604, 3126, NULL, 6070, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19605, 9708, NULL, 6070, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (19606, 1683, NULL, 6071, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19607, 3077, NULL, 6071, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19608, 9709, NULL, 6071, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19609, 769, NULL, 6072, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19610, 2070, NULL, 6072, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19611, 1988, NULL, 6072, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19612, 9710, NULL, 6072, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19613, 9711, NULL, 6072, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19614, 7697, NULL, 6072, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19615, 4278, NULL, 6072, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19616, 3766, NULL, 6072, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (19617, 377, NULL, 6073, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19618, 1261, NULL, 6073, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19619, 9712, NULL, 6073, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19620, 5883, NULL, 6073, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19621, 9713, NULL, 6073, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19622, 1949, NULL, 6073, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19623, 3358, NULL, 6073, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19624, 1181, NULL, 6073, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (19625, 1284, NULL, 6074, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19626, 9714, NULL, 6074, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19627, 9715, NULL, 6074, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19628, 9716, NULL, 6074, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19629, 9717, NULL, 6074, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19630, 9718, NULL, 6074, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19631, 9719, NULL, 6074, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19632, 7812, NULL, 6074, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (19637, 1201, NULL, 6076, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19638, 9720, NULL, 6076, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19639, 7654, NULL, 6076, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19640, 1931, NULL, 6076, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19641, 1854, NULL, 6076, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19642, 7348, NULL, 6076, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19643, 9721, NULL, 6076, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19644, 8499, NULL, 6076, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (19653, 552, NULL, 6078, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19654, 6807, NULL, 6078, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19655, 9723, NULL, 6078, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19656, 9724, NULL, 6078, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19657, 8513, NULL, 6078, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19658, 9725, NULL, 6078, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19659, 9726, NULL, 6078, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19660, 9727, NULL, 6078, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (19661, 825, NULL, 6079, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19662, 4032, NULL, 6079, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19663, 9728, NULL, 6079, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19664, 9729, NULL, 6079, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19665, 9730, NULL, 6079, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19666, 9731, NULL, 6079, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (29427, 12407, NULL, 9181, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29428, 3520, NULL, 9181, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29429, 3828, NULL, 9181, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19667, 9732, NULL, 6079, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19668, 8498, NULL, 6079, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (19669, 1282, NULL, 6080, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19670, 9733, NULL, 6080, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19671, 9734, NULL, 6080, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19672, 7904, NULL, 6080, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19673, 4828, NULL, 6080, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19674, 9735, NULL, 6080, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19675, 9736, NULL, 6080, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19676, 5390, NULL, 6080, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (19677, 31, NULL, 6081, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19678, 8254, NULL, 6081, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19679, 5882, NULL, 6081, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19680, 9738, NULL, 6081, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19681, 9739, NULL, 6081, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19682, 7500, NULL, 6081, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19683, 2452, NULL, 6081, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (19684, 49, NULL, 6082, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19685, 3669, NULL, 6082, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19686, 6445, NULL, 6082, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19687, 2947, NULL, 6082, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19688, 9740, NULL, 6082, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19689, 1867, NULL, 6082, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19690, 5571, NULL, 6082, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19691, 7537, NULL, 6082, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (19692, 1510, NULL, 6083, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19529, 9690, NULL, 2562, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19527, 3956, NULL, 2562, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19528, 9689, NULL, 2562, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19693, 1146, NULL, 6083, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19694, 2788, NULL, 6083, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19533, 3912, NULL, 2560, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19534, 952, NULL, 2560, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19526, 51, NULL, 2558, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19524, 1027, NULL, 2558, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19525, 1395, NULL, 2558, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19535, 9624, NULL, 2561, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19538, 624, NULL, 2561, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19537, 2443, NULL, 2561, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19536, 9273, NULL, 2561, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19695, 7543, NULL, 6141, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19696, 350, NULL, 6142, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19697, 340, NULL, 6143, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19698, 1528, NULL, 6144, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19699, 1528, NULL, 6145, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19700, 1919, NULL, 6145, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29854, 12511, NULL, 9316, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29855, 12512, NULL, 9316, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19701, 1735, NULL, 6146, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19702, 302, NULL, 6146, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19703, 3381, NULL, 6147, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19704, 2773, NULL, 6147, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19706, 1442, NULL, 6149, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19707, 2886, NULL, 6149, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19708, 13, NULL, 6150, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19709, 312, NULL, 6150, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19710, 1435, NULL, 6151, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19711, 2159, NULL, 6151, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19712, 248, NULL, 6152, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19713, 2597, NULL, 6152, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19714, 8473, NULL, 6153, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19715, 3508, NULL, 6153, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19716, 382, NULL, 6154, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19717, 389, NULL, 6154, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19718, 2890, NULL, 6155, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19719, 1424, NULL, 6155, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19720, 2082, NULL, 6156, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19721, 9741, NULL, 6156, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19722, 448, NULL, 6157, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19723, 2091, NULL, 6157, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19724, 1329, NULL, 6158, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19725, 1821, NULL, 6158, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19730, 1054, NULL, 6161, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19731, 1406, NULL, 6161, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19732, 1450, NULL, 6162, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19733, 2294, NULL, 6162, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19734, 1095, NULL, 6163, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19735, 2910, NULL, 6163, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19736, 520, NULL, 6164, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19737, 2031, NULL, 6164, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19738, 1195, NULL, 6165, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19739, 8850, NULL, 6165, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19740, 1019, NULL, 6166, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19741, 5272, NULL, 6166, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19742, 1828, NULL, 6167, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19743, 2258, NULL, 6167, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19744, 2168, NULL, 6168, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19745, 4578, NULL, 6168, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19746, 5870, NULL, 6081, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19747, 9435, NULL, 6169, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19751, 4545, NULL, 6185, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19752, 9748, NULL, 6185, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19753, 2212, NULL, 6179, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19754, 9749, NULL, 6179, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19755, 8012, NULL, 6179, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19756, 9750, NULL, 6180, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19757, 930, NULL, 6180, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19758, 285, NULL, 6180, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29430, 12407, NULL, 9182, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29431, 3520, NULL, 9182, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29432, 3828, NULL, 9182, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19760, 2968, NULL, 6181, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19761, 9752, NULL, 6181, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19762, 1786, NULL, 6181, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19763, 9753, NULL, 6182, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19764, 4983, NULL, 6182, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19765, 2482, NULL, 6182, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19766, 2419, NULL, 6183, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19767, 4555, NULL, 6183, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19768, 764, NULL, 6183, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19769, 1342, NULL, 6169, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19770, 3536, NULL, 6169, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19771, 3436, NULL, 6169, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19772, 5837, NULL, 6170, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19773, 3682, NULL, 6170, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19774, 2894, NULL, 6170, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19775, 5308, NULL, 6170, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19779, 9755, NULL, 6172, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19780, 5900, NULL, 6172, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19781, 9756, NULL, 6172, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19782, 2063, NULL, 6172, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19783, 2804, NULL, 6173, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19784, 2577, NULL, 6173, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19785, 3257, NULL, 6173, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19786, 4684, NULL, 6174, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19787, 2587, NULL, 6174, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19788, 9757, NULL, 6174, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19789, 2369, NULL, 6174, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19790, 9758, NULL, 6175, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19791, 1481, NULL, 6175, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19792, 488, NULL, 6175, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19793, 7894, NULL, 6176, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19794, 7747, NULL, 6176, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19795, 8704, NULL, 6176, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19799, 52, NULL, 6178, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19800, 2579, NULL, 6178, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19801, 577, NULL, 6178, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19802, 2031, NULL, 6178, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19803, 891, NULL, 6186, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19804, 4395, NULL, 6186, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19805, 2431, NULL, 6186, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19809, 2012, NULL, 6188, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19810, 857, NULL, 6188, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19811, 5672, NULL, 6189, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19812, 9761, NULL, 6189, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19813, 9762, NULL, 6190, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19814, 661, NULL, 6190, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19815, 9763, NULL, 6191, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19816, 2178, NULL, 6191, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19817, 5295, NULL, 6191, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19818, 9764, NULL, 6191, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19819, 4741, NULL, 6191, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19820, 5547, NULL, 6192, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19821, 1225, NULL, 6192, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19822, 2847, NULL, 6192, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19823, 5532, NULL, 6192, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19824, 9765, NULL, 6192, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19825, 497, NULL, 6193, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19826, 1352, NULL, 6194, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19827, 4323, NULL, 6194, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19828, 7243, NULL, 6194, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19829, 560, NULL, 6195, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19830, 5260, NULL, 6195, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19831, 9766, NULL, 6195, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19832, 1052, NULL, 6195, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19833, 1528, NULL, 6195, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19838, 3638, NULL, 6197, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19839, 9008, NULL, 6197, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19846, 2559, NULL, 6200, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19847, 39, NULL, 6200, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19848, 2905, NULL, 5761, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19849, 2383, NULL, 2751, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19850, 2383, NULL, 4437, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29433, 10142, NULL, 9183, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29434, 1067, NULL, 9183, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19852, 7176, NULL, 2869, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19853, 7176, NULL, 4892, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19854, 7176, NULL, 3168, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19855, 7176, NULL, 2612, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19857, 7176, NULL, 5888, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19858, 7176, NULL, 1942, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19859, 3027, NULL, 3004, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19860, 3027, NULL, 1097, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19861, 3027, NULL, 3309, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19862, 3027, NULL, 5873, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19863, 3027, NULL, 4148, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19864, 152, NULL, 6202, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19865, 1882, NULL, 6205, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19866, 2696, NULL, 6207, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19750, 66, NULL, 6184, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19749, 1238, NULL, 6184, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29859, 12513, NULL, 9317, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29857, 5894, NULL, 9317, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29858, 1537, NULL, 9317, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19842, 9768, NULL, 6198, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19840, 1042, NULL, 6198, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19841, 9767, NULL, 6198, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19844, 429, NULL, 6199, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29862, 12516, NULL, 9318, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29860, 12514, NULL, 9318, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29863, 10472, NULL, 9318, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29861, 12515, NULL, 9318, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19843, 1421, 273, 6199, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19845, 1665, NULL, 6199, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19728, 430, NULL, 6160, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19729, 2774, NULL, 6160, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19727, 2514, NULL, 6159, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19726, 1593, NULL, 6159, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19748, 9747, NULL, 6184, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32925, 3285, NULL, 10197, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32937, 2570, NULL, 10201, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32935, 8749, NULL, 10201, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19851, 7176, NULL, 40, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19705, 794, NULL, 6148, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19867, 1371, NULL, 6208, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19868, 923, NULL, 6212, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19869, 382, NULL, 6214, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19871, 1809, NULL, 6220, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19872, 855, NULL, 6221, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19873, 9771, NULL, 6201, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19874, 9772, NULL, 6201, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19875, 5126, NULL, 6201, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19876, 1673, NULL, 6201, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19877, 1112, NULL, 6202, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19878, 9773, NULL, 6202, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19879, 2505, NULL, 6202, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19880, 713, NULL, 6202, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19881, 724, NULL, 6202, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19882, 650, NULL, 6202, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19887, 456, NULL, 6204, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19888, 888, NULL, 6204, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19889, 2489, NULL, 6204, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19890, 3120, NULL, 6204, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19891, 5154, NULL, 6205, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19892, 295, NULL, 6205, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19893, 1354, NULL, 6206, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19894, 2535, NULL, 6206, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19895, 2847, NULL, 6206, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19896, 1064, NULL, 6206, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19897, 1880, NULL, 6207, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19899, 9776, NULL, 6207, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19900, 533, NULL, 6208, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19901, 5006, NULL, 6208, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19902, 5348, NULL, 6208, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19903, 4249, NULL, 6208, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19911, 9779, NULL, 6211, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19912, 5413, NULL, 6211, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19913, 9780, NULL, 6211, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19914, 9781, NULL, 6211, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19915, 2457, NULL, 6212, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19916, 1264, NULL, 6212, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19917, 9782, NULL, 6212, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19918, 9783, NULL, 6213, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19919, 5501, NULL, 6213, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19920, 5499, NULL, 6213, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19921, 1629, NULL, 6214, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19922, 534, NULL, 6214, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19923, 1329, NULL, 6214, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19924, 497, NULL, 6214, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19925, 1091, NULL, 6214, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19926, 1655, NULL, 6214, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (19927, 9784, NULL, 6215, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19928, 4390, NULL, 6215, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19929, 9786, NULL, 6215, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19930, 9785, NULL, 6215, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19935, 9788, NULL, 6217, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19936, 5542, NULL, 6217, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19937, 1696, NULL, 6217, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19938, 5266, NULL, 6217, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19939, 9789, NULL, 6218, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19940, 9790, NULL, 6218, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19941, 9791, NULL, 6218, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19942, 9792, NULL, 6218, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32906, 13879, NULL, 10190, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29435, 812, NULL, 9184, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29436, 1291, NULL, 9184, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29437, 12408, NULL, 9184, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32938, 8748, NULL, 10201, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19946, 4360, NULL, 6220, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19947, 4578, NULL, 6220, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19948, 2492, NULL, 6220, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19949, 5263, NULL, 6221, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19954, 6568, NULL, 6223, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19955, 7159, NULL, 6223, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19956, 9795, NULL, 6224, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19957, 3601, NULL, 6224, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19958, 483, NULL, 6224, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19959, 9796, NULL, 6224, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19960, 2151, NULL, 6225, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19961, 1943, NULL, 6225, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19962, 2587, NULL, 6225, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19967, 9798, NULL, 6227, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19968, 4988, NULL, 6227, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19969, 9799, NULL, 6227, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19970, 3901, NULL, 6243, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19971, 586, NULL, 6243, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19972, 2396, NULL, 6243, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19973, 7661, NULL, 6244, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19974, 4413, NULL, 6244, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19975, 1858, NULL, 6244, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19976, 9815, NULL, 6244, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19980, 481, NULL, 6246, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19981, 567, NULL, 6246, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19982, 1333, NULL, 6246, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19983, 1920, NULL, 6246, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19984, 2123, NULL, 6247, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19985, 1379, NULL, 6247, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19986, 889, NULL, 6247, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19987, 369, NULL, 6248, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19988, 3390, NULL, 6248, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19989, 9514, NULL, 6248, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19990, 3682, NULL, 6248, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19991, 649, NULL, 6249, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19992, 256, NULL, 6249, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19993, 2514, NULL, 6249, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19994, 8, NULL, 6249, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19995, 452, NULL, 6249, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19996, 2365, NULL, 6249, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19997, 4830, NULL, 6250, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19998, 913, NULL, 6250, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19999, 68, NULL, 6250, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20000, 1311, NULL, 6250, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20001, 9813, NULL, 6251, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20002, 5616, NULL, 6251, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20003, 9814, NULL, 6252, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20004, 3231, NULL, 6252, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20005, 3060, NULL, 6252, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20006, 3908, NULL, 6253, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20007, 450, NULL, 6253, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20008, 3832, NULL, 6253, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20009, 3256, NULL, 6253, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20010, 655, NULL, 6254, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20011, 674, NULL, 6254, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20012, 1121, NULL, 6254, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20013, 3497, NULL, 6254, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20014, 5134, NULL, 6255, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20015, 5135, NULL, 6255, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20016, 8074, NULL, 6255, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20017, 9429, NULL, 6255, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20018, 5188, NULL, 6255, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20019, 9827, NULL, 6256, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20020, 1181, NULL, 6256, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20021, 1261, NULL, 6256, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20022, 9828, NULL, 6257, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20023, 4856, NULL, 6257, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20024, 968, NULL, 6257, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20025, 2492, NULL, 6258, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20026, 76, NULL, 6258, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20027, 2922, NULL, 6258, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20028, 1541, NULL, 6258, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20029, 9829, NULL, 6259, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20030, 9008, NULL, 6259, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20031, 9830, NULL, 6259, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20032, 3390, NULL, 6259, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20033, 7600, NULL, 6260, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20034, 4323, NULL, 6260, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20035, 179, NULL, 6260, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20036, 1448, NULL, 6261, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20037, 1462, NULL, 6261, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20038, 687, NULL, 6261, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20039, 9831, NULL, 6261, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20040, 3749, NULL, 6262, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20041, 5055, NULL, 6262, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20042, 5442, NULL, 6262, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20043, 5440, NULL, 6262, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20044, 1967, NULL, 6262, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20045, 1465, NULL, 6262, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20046, 2582, NULL, 6263, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20047, 2696, NULL, 6263, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20048, 90, NULL, 6263, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20049, 238, NULL, 6263, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19884, 9774, NULL, 6203, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19885, 3109, NULL, 6203, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19886, 9775, NULL, 6203, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19883, 2988, NULL, 6203, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19963, 9797, NULL, 6226, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19964, 1136, NULL, 6226, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19966, 1343, NULL, 6226, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19965, 1805, NULL, 6226, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19931, 6410, NULL, 6216, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19856, 7176, NULL, 4912, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19933, 1796, NULL, 6216, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19934, 1024, NULL, 6216, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19932, 9787, NULL, 6216, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19951, 9794, NULL, 6222, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19953, 2012, NULL, 6222, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19950, 9793, NULL, 6222, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19952, 3860, NULL, 6222, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10927, 1885, NULL, 556, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28667, 12140, NULL, 8911, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19945, 336, NULL, 6219, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19870, 7561, NULL, 6219, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20050, 1732, NULL, 6264, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20051, 1505, NULL, 6264, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20052, 1374, NULL, 6264, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20053, 378, NULL, 6264, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20054, 152, NULL, 6265, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20055, 8, NULL, 6265, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20056, 1296, NULL, 6265, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20057, 937, NULL, 6265, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20058, 1684, NULL, 6266, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20059, 9816, NULL, 6267, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20060, 9099, NULL, 6267, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20061, 1294, NULL, 6267, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20062, 867, NULL, 6267, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29438, 1368, NULL, 9185, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29439, 333, NULL, 9185, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29440, 533, NULL, 9185, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20063, 1609, NULL, 6267, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20064, 2571, NULL, 6267, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (20065, 5935, NULL, 6267, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (20066, 9817, NULL, 6268, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20067, 9818, NULL, 6268, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20068, 9819, NULL, 6269, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20069, 9832, NULL, 6269, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20070, 9833, NULL, 6269, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20071, 9820, NULL, 6270, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20072, 5560, NULL, 6270, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20073, 7435, NULL, 6270, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20074, 9821, NULL, 6271, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20075, 171, NULL, 6271, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20076, 188, NULL, 6271, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20077, 955, NULL, 6271, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20078, 5770, NULL, 6271, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20079, 1261, NULL, 6271, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (20080, 1748, NULL, 6271, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (20081, 9822, NULL, 6272, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20082, 4381, NULL, 6272, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20083, 2786, NULL, 6272, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20084, 9823, NULL, 6273, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20092, 9825, NULL, 6275, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20093, 4689, NULL, 6275, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20094, 9835, NULL, 6275, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20095, 5143, NULL, 6275, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20096, 9836, NULL, 6275, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20097, 1041, NULL, 6275, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (20098, 9837, NULL, 6275, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (20099, 9826, NULL, 6276, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20100, 482, NULL, 6276, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20101, 9838, NULL, 6276, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20102, 2821, NULL, 6276, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20103, 1651, NULL, 6276, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20104, 1553, NULL, 6276, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (20106, 2829, NULL, 6277, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20107, 1544, NULL, 6278, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20108, 2830, NULL, 6279, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20109, 2832, NULL, 6280, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20110, 1785, NULL, 6281, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20111, 2596, NULL, 5281, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20112, 129, NULL, 3956, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20113, 129, NULL, 4615, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20114, 129, NULL, 1003, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20115, 129, NULL, 5606, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20116, 129, NULL, 1197, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20118, 987, NULL, 4797, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20119, 987, NULL, 4285, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20120, 987, NULL, 3166, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20121, 2800, NULL, 6282, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20122, 9848, NULL, 6282, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20123, 1907, NULL, 6282, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20124, 9849, NULL, 6282, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20125, 9841, NULL, 6283, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20126, 4500, NULL, 6283, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20127, 9850, NULL, 6283, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20128, 9851, NULL, 6283, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20129, 9161, NULL, 6284, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20130, 9852, NULL, 6284, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20131, 1194, NULL, 6284, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20132, 9853, NULL, 6284, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20133, 2531, NULL, 6285, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20134, 9854, NULL, 6285, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20135, 3612, NULL, 6285, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20136, 2677, NULL, 6285, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20137, 1870, NULL, 6285, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20138, 8253, NULL, 6285, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (20139, 8157, NULL, 6285, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (20140, 9855, NULL, 6285, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (20141, 9842, NULL, 6286, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20142, 943, NULL, 6286, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20143, 9856, NULL, 6286, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20144, 3023, NULL, 6286, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20145, 9843, NULL, 6287, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20146, 71, NULL, 6287, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20147, 5369, NULL, 6287, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20148, 9844, NULL, 6288, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20149, 9857, NULL, 6288, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20150, 66, NULL, 6288, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20151, 2336, NULL, 6288, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20152, 9843, NULL, 6289, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20153, 3014, NULL, 6289, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20154, 9858, NULL, 6289, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29441, 1118, NULL, 9186, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29442, 2442, NULL, 9186, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29443, 867, NULL, 9186, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20164, 7216, NULL, 6292, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20165, 1089, NULL, 6292, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20166, 9342, NULL, 6292, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20167, 3559, NULL, 6292, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20168, 9846, NULL, 6293, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20169, 7505, NULL, 6293, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20170, 5003, NULL, 6293, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20171, 9862, NULL, 6293, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20172, 1198, NULL, 6294, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20173, 2659, NULL, 6294, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20174, 7126, NULL, 6294, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20175, 9863, NULL, 6294, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20176, 1198, NULL, 6295, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20177, 1600, NULL, 6295, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20178, 9864, NULL, 6295, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20179, 9865, NULL, 6295, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20180, 2975, NULL, 6296, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20181, 532, NULL, 6296, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20182, 7025, NULL, 6296, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20183, 2980, NULL, 6296, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20184, 7705, NULL, 6297, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20185, 1379, NULL, 6297, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20186, 5151, NULL, 6297, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20187, 5018, NULL, 6297, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20188, 7094, NULL, 6298, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20189, 2236, NULL, 6298, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20190, 9866, NULL, 6298, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20191, 9867, NULL, 6298, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20192, 9868, NULL, 6298, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20193, 9872, NULL, 6353, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20194, 9873, NULL, 6353, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20195, 9874, NULL, 6353, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20196, 1861, NULL, 6354, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20197, 9875, NULL, 6354, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20198, 1222, NULL, 6354, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20199, 9876, NULL, 6354, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20200, 8189, NULL, 6355, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20201, 861, NULL, 6355, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20202, 8362, NULL, 6355, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20203, 8019, NULL, 6355, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20204, 9877, NULL, 6356, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20205, 9878, NULL, 6356, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20206, 2954, NULL, 6356, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20207, 2963, NULL, 6356, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20208, 9879, NULL, 6357, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32928, 1102, NULL, 10198, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20212, 9883, NULL, 6359, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20213, 201, NULL, 6359, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20214, 1855, NULL, 6359, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20215, 1707, NULL, 6359, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20216, 2753, NULL, 6360, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20217, 6668, NULL, 6360, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20218, 4653, NULL, 6360, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20219, 4541, NULL, 6360, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20220, 6109, NULL, 6361, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20221, 7094, NULL, 6361, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20222, 827, NULL, 6361, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20223, 954, NULL, 6361, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20224, 8170, NULL, 6362, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20225, 2031, NULL, 6362, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20226, 2992, NULL, 6362, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20227, 2347, NULL, 6362, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20228, 1180, NULL, 6363, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32927, 13885, NULL, 10198, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20117, 129, NULL, 386, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32929, 10708, NULL, 10198, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7889, 1542, NULL, 3251, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20157, 9627, NULL, 6290, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20156, 9162, NULL, 6290, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20155, 9845, NULL, 6290, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18319, 9338, NULL, 5782, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20229, 2666, NULL, 6363, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20230, 1280, NULL, 6363, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20231, 4555, NULL, 6363, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20232, 1352, NULL, 6363, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20233, 3145, NULL, 6363, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (20234, 1062, NULL, 6363, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (20235, 2690, NULL, 6364, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20240, 3545, NULL, 6366, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20241, 3700, NULL, 6369, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20242, 8847, NULL, 6371, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20243, 9898, NULL, 6375, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20244, 9899, NULL, 6375, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20245, 9900, NULL, 6375, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20246, 9527, NULL, 6375, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20251, 9904, NULL, 6377, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20252, 3217, NULL, 6377, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20253, 5849, NULL, 6377, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20258, 9907, NULL, 6379, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20259, 7071, NULL, 6379, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20260, 9908, NULL, 6379, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20261, 11, NULL, 6379, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20262, 3845, NULL, 6380, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20263, 1774, NULL, 6380, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18318, 698, NULL, 5782, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18320, 9339, NULL, 5782, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18321, 9340, NULL, 5782, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32905, 9847, NULL, 10190, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20089, 168, NULL, 6274, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20268, 2892, NULL, 6382, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20269, 7293, NULL, 6382, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20270, 5876, NULL, 6382, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20271, 2992, NULL, 6382, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20272, 9910, NULL, 6382, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20276, 9676, NULL, 6384, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20277, 3290, NULL, 6384, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20281, 1651, NULL, 6386, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20282, 2056, NULL, 6386, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20283, 3784, NULL, 6387, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20284, 9912, NULL, 6387, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20285, 9913, NULL, 6387, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20286, 1364, NULL, 6387, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20287, 9914, NULL, 6388, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20288, 9915, NULL, 6388, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20289, 2814, NULL, 6388, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20290, 9916, NULL, 6388, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20291, 1781, NULL, 6339, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20292, 9917, NULL, 6339, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20293, 9918, NULL, 6339, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20298, 1257, NULL, 6341, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20299, 9919, NULL, 6341, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20300, 1550, NULL, 6341, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20301, 9920, NULL, 6341, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20302, 248, NULL, 6342, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20303, 8836, NULL, 6342, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20304, 2410, NULL, 6342, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20305, 2021, NULL, 6342, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20306, 1287, NULL, 6343, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20307, 4555, NULL, 6343, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20308, 9921, NULL, 6343, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20313, 9922, NULL, 6345, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20314, 9923, NULL, 6345, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20315, 9924, NULL, 6345, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20316, 448, NULL, 6345, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20317, 9925, NULL, 6346, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20318, 7678, NULL, 6347, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20319, 9926, NULL, 6347, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20320, 2996, NULL, 6347, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20321, 7904, NULL, 6347, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20326, 923, NULL, 6349, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20327, 1178, NULL, 6349, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20328, 5472, NULL, 6349, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20329, 1439, NULL, 6349, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20333, 9929, NULL, 6351, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20334, 5535, NULL, 6351, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20335, 1189, NULL, 6352, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20336, 3804, NULL, 6394, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20337, 9930, NULL, 6389, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20338, 3009, NULL, 6389, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20339, 2524, NULL, 6389, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20340, 2294, NULL, 6389, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20341, 9931, NULL, 6390, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20342, 1031, NULL, 6390, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20343, 9932, NULL, 6390, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20344, 9933, NULL, 6391, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20345, 9046, NULL, 6391, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20346, 9934, NULL, 6391, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20347, 2692, NULL, 6392, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20348, 1403, NULL, 6392, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20349, 1052, NULL, 6392, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20350, 292, NULL, 6392, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20355, 2348, NULL, 6394, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20356, 4323, NULL, 6394, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20357, 625, NULL, 6395, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20358, 9939, NULL, 6395, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20359, 2952, NULL, 6395, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20360, 5931, NULL, 6395, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20361, 9940, NULL, 6396, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20362, 168, NULL, 6396, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20363, 5464, NULL, 6396, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20364, 5465, NULL, 6396, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20365, 2122, NULL, 6397, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20366, 2477, NULL, 6397, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20367, 3568, NULL, 6397, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20368, 9941, NULL, 6398, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20369, 2197, NULL, 6398, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20370, 787, NULL, 6398, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20371, 4791, NULL, 6398, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20372, 9942, NULL, 6399, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20373, 2362, NULL, 6399, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20374, 9943, NULL, 6400, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20375, 9456, NULL, 6400, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20376, 463, NULL, 6400, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20377, 1745, NULL, 6400, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20378, 9944, NULL, 6401, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20379, 1954, NULL, 6401, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20380, 6576, NULL, 6401, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20381, 2714, NULL, 6401, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20382, 2459, NULL, 6402, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20383, 9434, NULL, 6402, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20384, 2637, NULL, 6402, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20385, 9945, NULL, 6403, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20386, 2445, NULL, 6403, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20387, 5560, NULL, 6403, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20388, 3077, NULL, 6403, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20389, 1511, NULL, 6404, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20390, 952, NULL, 6404, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20391, 232, NULL, 6404, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20392, 9703, NULL, 6405, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20393, 9958, NULL, 6405, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20394, 9959, NULL, 6405, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20395, 3077, NULL, 6406, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20396, 3361, NULL, 6406, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20397, 2369, NULL, 6406, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20398, 2587, NULL, 6406, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20399, 955, NULL, 6407, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20400, 3243, NULL, 6407, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20401, 9960, NULL, 6407, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20402, 2883, NULL, 6408, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20403, 2285, NULL, 6408, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20404, 7528, NULL, 6408, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20405, 9961, NULL, 6408, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20406, 396, NULL, 6409, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20407, 239, NULL, 6409, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20408, 2118, NULL, 6409, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20409, 2321, NULL, 6409, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20410, 755, NULL, 6410, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20411, 4085, NULL, 6410, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20412, 996, NULL, 6410, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20413, 1896, NULL, 6410, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20351, 9935, NULL, 6393, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20352, 9936, NULL, 6393, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20354, 9938, NULL, 6393, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20353, 9937, NULL, 6393, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20237, 1896, NULL, 6365, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20238, 688, NULL, 6365, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20236, 1401, NULL, 6365, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20414, 7678, NULL, 6411, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20249, 9903, NULL, 6376, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20248, 9902, NULL, 6376, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20250, 9677, NULL, 6376, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20247, 9901, NULL, 6376, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20255, 2258, NULL, 6378, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20257, 9906, NULL, 6378, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20254, 1424, NULL, 6378, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20415, 4232, NULL, 6411, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20416, 6636, NULL, 6411, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20417, 7923, NULL, 6411, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20418, 3033, NULL, 6412, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20419, 773, NULL, 6412, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20420, 1289, NULL, 6412, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20421, 1943, NULL, 6412, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20422, 9962, NULL, 6413, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20423, 6312, NULL, 6413, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20424, 2386, NULL, 6413, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20425, 2609, NULL, 6414, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20426, 9577, NULL, 6414, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20427, 1588, NULL, 6414, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20428, 27, NULL, 6414, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20429, 9963, NULL, 6415, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20430, 8807, NULL, 6415, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20431, 7051, NULL, 6415, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20432, 9964, NULL, 6415, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20433, 9965, NULL, 6415, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20434, 403, NULL, 6416, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20435, 5859, NULL, 6416, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20436, 8253, NULL, 6416, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20437, 9099, NULL, 6416, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20438, 470, NULL, 6417, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20439, 2258, NULL, 6417, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20440, 4815, NULL, 6417, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20441, 3446, NULL, 6417, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20445, 651, NULL, 6413, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20446, 2449, NULL, 6366, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20447, 9980, NULL, 6366, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20448, 9981, NULL, 6366, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20449, 1360, NULL, 6367, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20332, 9928, NULL, 6350, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20330, 1203, NULL, 6350, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20331, 9927, NULL, 6350, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20296, 3397, NULL, 6340, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20297, 188, NULL, 6340, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20295, 986, NULL, 6340, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20322, 46, NULL, 6348, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20324, 7681, NULL, 6348, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20323, 5569, NULL, 6348, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20275, 10864, NULL, 6383, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20273, 2347, NULL, 6383, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20274, 9911, NULL, 6383, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20450, 9982, NULL, 6367, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20451, 1575, NULL, 6367, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20452, 9983, NULL, 6367, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20453, 156, NULL, 6368, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20454, 2136, NULL, 6368, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20455, 2012, NULL, 6368, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19777, 2544, NULL, 6171, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19778, 5151, NULL, 6171, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19776, 9754, NULL, 6171, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23929, 3767, NULL, 7375, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20461, 9986, NULL, 6420, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20462, 9987, NULL, 6420, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20463, 2884, NULL, 6369, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20464, 9988, NULL, 6369, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20465, 894, NULL, 6370, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20466, 1067, NULL, 6370, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20467, 2151, NULL, 6370, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20468, 2587, NULL, 6370, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20469, 122, NULL, 6371, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20470, 9989, NULL, 6421, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20471, 9990, NULL, 6421, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20472, 9991, NULL, 6421, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20473, 1670, NULL, 6372, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20474, 3047, NULL, 6372, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20475, 2266, NULL, 6372, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20476, 1620, NULL, 6373, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20477, 9992, NULL, 6373, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20482, 9584, NULL, 6426, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20483, 9996, NULL, 6424, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20484, 9997, NULL, 6424, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20485, 2864, NULL, 6424, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20486, 8797, NULL, 6424, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20487, 9998, NULL, 6425, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20488, 3947, NULL, 6425, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20489, 1456, NULL, 6425, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20490, 763, NULL, 6426, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20491, 5312, NULL, 6426, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20496, 10001, NULL, 6428, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20497, 1294, NULL, 6428, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20498, 10002, NULL, 6428, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20499, 2517, NULL, 6428, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20500, 10003, NULL, 6429, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20501, 2555, NULL, 6429, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20502, 1198, NULL, 6429, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20503, 38, NULL, 6429, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20507, 10006, NULL, 6431, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20508, 3026, NULL, 6431, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20509, 1340, NULL, 6431, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20510, 4384, NULL, 6431, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20511, 10007, NULL, 6432, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20512, 1181, NULL, 6432, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20513, 4954, NULL, 6432, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20514, 2956, NULL, 6432, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20515, 773, NULL, 6433, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20516, 8215, NULL, 6433, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20517, 4751, NULL, 6433, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20518, 3373, NULL, 6433, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20523, 10010, NULL, 6435, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20524, 810, NULL, 6435, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20525, 593, NULL, 6435, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20526, 10011, NULL, 6436, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20527, 971, NULL, 6436, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20528, 607, NULL, 6436, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20529, 10012, NULL, 6436, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20530, 10013, NULL, 6437, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20531, 2691, NULL, 6437, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20532, 1872, NULL, 6437, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20533, 10014, NULL, 6438, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20534, 2683, NULL, 6438, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20535, 2561, NULL, 6438, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20536, 1566, NULL, 6439, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20537, 3215, NULL, 6439, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20538, 1498, NULL, 6439, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20539, 3132, NULL, 6439, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20540, 55, NULL, 6440, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20541, 5263, NULL, 6440, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20542, 10017, NULL, 6440, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20543, 7080, NULL, 6440, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20544, 10018, NULL, 6440, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20545, 9584, NULL, 6441, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20546, 1020, NULL, 6441, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20547, 3669, NULL, 6441, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20548, 7025, NULL, 6441, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20549, 5697, NULL, 6442, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20550, 2369, NULL, 6442, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20551, 3014, NULL, 6442, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20552, 2503, NULL, 6442, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20553, 4334, NULL, 6443, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20554, 5832, NULL, 6443, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20555, 2482, NULL, 6443, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20556, 1725, NULL, 6443, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20557, 371, NULL, 6444, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20558, 1769, NULL, 6444, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20559, 4632, NULL, 6445, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20560, 7317, NULL, 6445, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20561, 9026, NULL, 6445, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20562, 4214, NULL, 6446, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20563, 4910, NULL, 6446, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20564, 1935, NULL, 6446, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20565, 3846, NULL, 6447, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20566, 812, NULL, 6447, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20567, 1291, NULL, 6447, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20568, 3559, NULL, 6447, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20569, 1651, NULL, 6448, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20570, 6061, NULL, 6448, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20571, 7520, NULL, 6448, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20572, 2953, NULL, 6448, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20573, 1831, NULL, 6449, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20574, 10019, NULL, 6449, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20575, 1067, NULL, 6449, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20576, 10020, NULL, 6449, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20577, 1800, NULL, 6450, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20578, 2383, NULL, 6450, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20579, 2332, NULL, 6450, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20580, 10021, NULL, 6450, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20589, 10027, NULL, 6453, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20590, 5142, NULL, 6453, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20591, 7065, NULL, 6453, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20592, 10028, NULL, 6454, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20593, 10029, NULL, 6454, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20598, 10031, NULL, 6456, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20521, 5767, NULL, 6434, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20520, 10009, NULL, 6434, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20519, 10008, NULL, 6434, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20522, 6489, NULL, 6434, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20444, 1881, NULL, 6418, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20443, 2399, NULL, 6418, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20442, 2290, NULL, 6418, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20584, 10024, NULL, 6451, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20582, 10022, NULL, 6451, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20583, 10023, NULL, 6451, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20581, 5702, NULL, 6451, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20481, 9995, NULL, 6374, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20478, 7046, NULL, 6374, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20480, 9994, NULL, 6374, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20599, 10032, NULL, 6456, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20600, 10033, NULL, 6456, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20601, 10034, NULL, 6456, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23930, 1461, NULL, 7375, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20606, 1509, NULL, 6458, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20607, 1587, NULL, 6458, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20608, 150, NULL, 6458, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20609, 613, NULL, 6458, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20610, 1461, NULL, 6459, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20611, 3060, NULL, 6459, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20612, 10036, NULL, 6459, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20613, 10037, NULL, 6459, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20614, 5615, NULL, 6460, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20615, 7678, NULL, 6460, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20616, 2757, NULL, 6460, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20617, 5893, NULL, 6460, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20618, 10038, NULL, 6461, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20619, 10039, NULL, 6462, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20620, 10040, NULL, 6462, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20621, 3269, NULL, 6462, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20622, 2582, NULL, 6463, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20623, 466, NULL, 6463, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20624, 10041, NULL, 6463, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20625, 5278, NULL, 6463, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20626, 8343, NULL, 6464, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20627, 7537, NULL, 6464, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20628, 3215, NULL, 6464, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20629, 3224, NULL, 6464, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20630, 10042, NULL, 6465, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20635, 9240, NULL, 6470, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20640, 10060, NULL, 6467, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20641, 2081, NULL, 6467, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20642, 10061, NULL, 6467, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20643, 5961, NULL, 6467, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20644, 10062, NULL, 6468, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20645, 2683, NULL, 6468, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20646, 8254, NULL, 6468, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20647, 4375, NULL, 6468, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20588, 39, NULL, 6452, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20586, 6613, NULL, 6452, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20585, 1470, NULL, 6452, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20587, 3146, NULL, 6452, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20636, 10058, NULL, 2543, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20639, 1867, NULL, 2543, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20637, 9740, NULL, 2543, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20648, 9239, NULL, 6469, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20649, 8499, NULL, 6469, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20650, 1786, NULL, 6469, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20651, 3610, NULL, 6469, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20652, 10063, NULL, 6470, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20653, 10064, NULL, 6470, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20654, 2316, NULL, 6470, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20661, 1977, NULL, 6488, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23927, 10920, NULL, 7375, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20663, 5623, NULL, 6488, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20664, 1742, NULL, 6488, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20665, 7, NULL, 6489, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20666, 5282, NULL, 6489, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20667, 972, NULL, 6489, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20668, 10074, NULL, 6489, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20669, 1352, NULL, 6490, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20670, 9376, NULL, 6490, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20671, 2369, NULL, 6490, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20672, 2906, NULL, 6490, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20673, 1881, NULL, 6491, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20674, 7094, NULL, 6491, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20675, 8608, NULL, 6491, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20676, 3870, NULL, 6491, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20677, 7511, NULL, 6491, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20682, 7436, NULL, 6493, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20683, 4365, NULL, 6493, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20684, 1455, NULL, 6493, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20685, 5260, NULL, 6493, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20686, 10075, NULL, 6494, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20687, 3474, NULL, 6494, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20688, 10076, NULL, 6494, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20689, 10077, NULL, 6494, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20690, 10078, NULL, 6495, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20691, 10079, NULL, 6495, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20692, 10080, NULL, 6496, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20693, 10081, NULL, 6496, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20694, 10082, NULL, 6496, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20695, 10083, NULL, 6496, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20696, 10084, NULL, 6497, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20697, 10085, NULL, 6497, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20698, 10086, NULL, 6497, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20699, 10087, NULL, 6497, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20704, 10092, NULL, 6499, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20705, 10093, NULL, 6499, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20706, 10094, NULL, 6499, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20707, 10095, NULL, 6499, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20708, 10096, NULL, 6499, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20709, 10097, NULL, 6500, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20710, 10098, NULL, 6501, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20711, 10099, NULL, 6501, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20715, 10103, NULL, 6503, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20716, 10104, NULL, 6503, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20717, 10105, NULL, 6504, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20718, 10106, NULL, 6504, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20719, 701, NULL, 6504, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20720, 10107, NULL, 6504, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20721, 10108, NULL, 6504, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20722, 10109, NULL, 6504, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (20723, 10110, NULL, 6504, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (20724, 10111, NULL, 6504, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (20725, 10112, NULL, 6505, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20726, 10113, NULL, 6505, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20727, 10114, NULL, 6506, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20728, 10115, NULL, 6506, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20736, 10122, NULL, 6508, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20737, 2668, NULL, 6508, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20738, 10123, NULL, 6508, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20739, 10124, NULL, 6508, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20740, 61, NULL, 6509, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20741, 10125, NULL, 6509, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20742, 10126, NULL, 6509, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20743, 10127, NULL, 6509, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20744, 6764, NULL, 6510, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20745, 5346, 140, 6510, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20746, 10128, NULL, 6510, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20747, 2017, 141, 6510, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20748, 757, NULL, 6511, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20749, 10129, NULL, 6511, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20750, 5828, 142, 6511, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20751, 5946, NULL, 6511, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20752, 1624, NULL, 6512, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20753, 10130, NULL, 6512, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20754, 1852, 143, 6512, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20755, 411, 144, 6513, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20756, 10131, NULL, 6513, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20757, 10132, NULL, 6513, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20758, 4991, 145, 6513, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20759, 10133, NULL, 6514, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20760, 1620, 146, 6515, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20761, 9916, NULL, 6515, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20762, 1585, NULL, 6516, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20763, 548, NULL, 6516, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20764, 346, NULL, 6516, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20765, 10134, NULL, 6517, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20766, 8225, NULL, 6517, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20767, 2993, NULL, 6517, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20768, 1863, NULL, 6517, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20631, 10043, NULL, 6466, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20632, 4012, NULL, 6466, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32904, 376, NULL, 10189, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32902, 2862, NULL, 10189, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20773, 3289, NULL, 6519, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20774, 10137, NULL, 6519, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20775, 6443, 147, 6519, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20776, 10138, NULL, 6519, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20777, 1515, NULL, 6520, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20778, 7135, NULL, 6520, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20779, 7281, NULL, 6520, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20780, 2316, NULL, 6520, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20781, 1264, NULL, 6520, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20782, 10139, NULL, 6520, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (20783, 2916, NULL, 6520, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (20784, 2269, NULL, 6521, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20785, 3460, 148, 6521, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20786, 10140, NULL, 6521, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20662, 6818, NULL, 6488, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20602, 6784, NULL, 6457, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20605, 6788, NULL, 6457, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20603, 10035, NULL, 6457, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20634, 10055, NULL, 6422, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32903, 2324, NULL, 10189, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32846, 13856, NULL, 10162, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (28671, 9580, NULL, 8912, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33183, 14028, NULL, 10275, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33184, 14029, NULL, 10275, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33163, 810, NULL, 10269, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33162, 14019, NULL, 10269, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20787, 10141, NULL, 6521, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20788, 1624, NULL, 6522, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20789, 10142, NULL, 6522, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20790, 2151, NULL, 6522, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20791, 7673, 149, 6522, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20712, 10100, NULL, 6502, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20714, 10102, NULL, 6502, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20796, 10146, NULL, 6524, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20797, 10147, NULL, 6524, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20798, 10148, NULL, 6524, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20799, 10149, NULL, 6524, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20800, 10150, NULL, 6525, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20801, 907, NULL, 6525, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20802, 1193, 151, 6525, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20803, 10151, NULL, 6526, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20804, 5490, 152, 6526, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20805, 10152, NULL, 6527, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20806, 9262, 153, 6527, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20807, 10153, NULL, 6527, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20808, 10154, NULL, 6528, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20809, 10155, NULL, 6528, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20810, 10156, NULL, 6528, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20811, 9568, 154, 6528, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20812, 10157, NULL, 6529, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20813, 2117, NULL, 6529, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20814, 10158, NULL, 6530, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20815, 10159, NULL, 6530, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20816, 10160, NULL, 6530, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20817, 10161, NULL, 6530, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20818, 10162, NULL, 6531, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20819, 382, NULL, 6532, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20820, 497, 69, 6532, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20821, 19, NULL, 6532, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20822, 289, NULL, 6532, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20827, 388, 156, 6534, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20828, 5272, NULL, 6534, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20829, 1164, NULL, 6534, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20830, 608, NULL, 6534, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20831, 815, NULL, 6535, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20832, 1498, 157, 6535, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20833, 10164, NULL, 6535, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20656, 749, NULL, 6475, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20657, 317, NULL, 6487, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20824, 10163, NULL, 6533, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20826, 9508, 155, 6533, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20823, 892, NULL, 6533, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20702, 10090, NULL, 6498, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20700, 10088, NULL, 6498, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20701, 10089, NULL, 6498, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20703, 10091, NULL, 6498, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20834, 10165, NULL, 6535, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20835, 1008, NULL, 6536, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20836, 1400, NULL, 6536, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20837, 10166, NULL, 6536, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20838, 4050, 158, 6536, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20839, 1450, NULL, 6537, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20840, 716, NULL, 6537, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20841, 10167, NULL, 6537, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20842, 10168, NULL, 6537, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20843, 819, NULL, 6538, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20844, 10169, NULL, 6538, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20845, 4561, NULL, 6538, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20846, 10170, NULL, 6538, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20847, 1230, 159, 6539, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20848, 9262, NULL, 6539, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20849, 10171, NULL, 6539, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20850, 10172, NULL, 6539, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20851, 702, 160, 6540, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20852, 55, NULL, 6540, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20853, 196, NULL, 6540, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20854, 2959, NULL, 6541, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20855, 9645, NULL, 6542, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20856, 10173, NULL, 6542, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20857, 1515, NULL, 6543, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20858, 10174, NULL, 6543, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20859, 10175, NULL, 6543, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20860, 10176, NULL, 6543, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20861, 1727, NULL, 6544, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20862, 10177, NULL, 6544, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20863, 753, NULL, 6544, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20864, 90, NULL, 6544, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20865, 476, NULL, 6545, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20866, 2577, 161, 6545, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20867, 1352, NULL, 6545, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20868, 10178, NULL, 6545, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20869, 3249, NULL, 6546, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20870, 8456, NULL, 6546, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20871, 7926, NULL, 6546, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20872, 2217, NULL, 6546, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20873, 982, NULL, 6547, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20874, 4267, NULL, 6547, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20875, 7315, NULL, 6547, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20876, 5854, NULL, 6547, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20877, 9700, NULL, 6548, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20878, 3512, 162, 6548, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20879, 1511, NULL, 6549, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20880, 10179, NULL, 6549, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20881, 1711, NULL, 6550, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20882, 10180, NULL, 6550, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20883, 10181, NULL, 6550, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20884, 10182, NULL, 6550, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30432, 5980, NULL, 9330, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20889, 129, NULL, 6552, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20891, 1112, NULL, 6552, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20892, 943, NULL, 6553, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20893, 2808, 164, 6553, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20894, 1364, NULL, 6554, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20895, 141, NULL, 6554, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20900, 873, NULL, 6556, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20901, 3761, NULL, 6556, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20902, 1452, NULL, 6556, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20903, 995, NULL, 6556, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20905, 10185, NULL, 6557, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20907, 2424, 169, 6557, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20908, 824, NULL, 6558, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20909, 10186, NULL, 6558, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20910, 4399, NULL, 6558, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20911, 10187, NULL, 6558, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20912, 194, NULL, 6559, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20913, 10182, NULL, 6559, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20914, 1707, NULL, 6559, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20915, 7834, NULL, 6559, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20916, 1621, NULL, 6560, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20917, 5857, 170, 6560, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20918, 2339, NULL, 6560, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20919, 2536, NULL, 6560, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20920, 362, NULL, 6561, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20921, 2415, NULL, 6561, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20922, 4239, NULL, 6561, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20923, 1291, NULL, 6561, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20924, 1262, NULL, 6562, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20925, 6632, 171, 6562, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20926, 10188, NULL, 6562, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20927, 10189, NULL, 6562, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20928, 277, NULL, 6563, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20929, 503, NULL, 6563, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20930, 2030, 172, 6563, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20931, 2790, NULL, 6563, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20932, 2554, NULL, 6563, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20933, 1031, 173, 6563, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (20934, 10190, NULL, 6563, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (20935, 7797, NULL, 6563, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (20936, 4361, NULL, 6564, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20937, 109, NULL, 6564, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20938, 1344, NULL, 6564, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20939, 5273, NULL, 6564, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20940, 10191, NULL, 6565, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20941, 93, 174, 6565, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20942, 10192, NULL, 6565, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20943, 3113, NULL, 6565, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20948, 1227, NULL, 6567, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20949, 4002, NULL, 6567, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20950, 1858, NULL, 6567, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20951, 2898, NULL, 6567, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20952, 1082, 175, 6568, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20953, 2986, NULL, 6568, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20954, 435, NULL, 6568, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20955, 1514, NULL, 6568, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20956, 8472, NULL, 6569, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20957, 10196, NULL, 6569, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20958, 10188, NULL, 6569, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20959, 10197, NULL, 6569, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20960, 1218, NULL, 6570, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20961, 2442, NULL, 6570, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20962, 1943, NULL, 6570, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20963, 3232, NULL, 6570, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20964, 3257, NULL, 6571, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20965, 996, NULL, 6571, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20966, 1930, NULL, 6572, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20967, 1415, NULL, 6572, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20968, 1628, NULL, 6572, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20969, 1700, 176, 6572, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20970, 1544, NULL, 6573, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20897, 424, NULL, 6555, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20896, 598, NULL, 6555, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20971, 10198, NULL, 6573, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20972, 10199, NULL, 6573, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20973, 10200, NULL, 6573, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20974, 10201, NULL, 6574, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20975, 10202, NULL, 6574, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20976, 10203, NULL, 6574, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20977, 10204, NULL, 6574, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20978, 7747, NULL, 6574, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20979, 14, NULL, 6575, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20980, 10205, NULL, 6575, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20981, 6483, 177, 6575, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20982, 10206, NULL, 6575, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20945, 10193, NULL, 6566, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20946, 10194, NULL, 6566, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20983, 760, NULL, 6576, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20984, 7263, NULL, 6576, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20985, 9713, NULL, 6576, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20986, 317, NULL, 6576, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30429, 817, NULL, 9330, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30431, 2882, NULL, 9330, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20991, 8244, NULL, 6578, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20992, 10209, NULL, 6578, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20993, 10210, NULL, 6578, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20994, 9936, NULL, 6578, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21099, 178, NULL, 6610, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20998, 1590, NULL, 6580, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20999, 10211, NULL, 6580, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21000, 2410, 178, 6580, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21001, 699, 179, 6580, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21002, 705, NULL, 6581, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21003, 10212, NULL, 6581, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21004, 10213, NULL, 6581, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21005, 10214, NULL, 6581, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21010, 1480, NULL, 6583, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21011, 1566, NULL, 6583, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21012, 1611, NULL, 6583, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21013, 10215, NULL, 6583, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21014, 1218, NULL, 6584, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21015, 2561, NULL, 6584, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21016, 4012, NULL, 6584, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21017, 867, NULL, 6584, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21018, 1401, NULL, 6585, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21019, 2774, NULL, 6585, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21020, 996, NULL, 6585, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21021, 3257, NULL, 6585, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21022, 1435, 180, 6586, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21023, 2929, NULL, 6586, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21024, 4730, NULL, 6586, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21025, 1861, NULL, 6586, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21026, 1559, NULL, 6587, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21027, 2860, NULL, 6587, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21028, 1288, NULL, 6588, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21029, 3033, NULL, 6588, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21030, 4323, NULL, 6588, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21031, 10216, NULL, 6588, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21032, 1286, NULL, 6589, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21033, 2081, NULL, 6589, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21034, 7241, NULL, 6589, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21035, 1875, NULL, 6589, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21036, 1559, NULL, 6590, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21037, 2358, NULL, 6590, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21042, 9645, NULL, 6592, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21043, 5590, NULL, 6592, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21044, 10217, NULL, 6592, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21045, 9969, NULL, 6593, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21046, 9530, NULL, 6593, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21047, 9515, NULL, 6593, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21048, 8498, NULL, 6593, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21049, 206, 181, 6594, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21050, 10218, NULL, 6594, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21051, 10219, NULL, 6594, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21052, 10220, NULL, 6595, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21053, 10221, NULL, 6595, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21054, 1670, 182, 6595, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21055, 10222, NULL, 6595, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21056, 757, NULL, 6596, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21057, 10223, NULL, 6596, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21058, 10224, NULL, 6596, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21059, 10225, NULL, 6596, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21062, 10227, NULL, 6598, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21063, 10228, NULL, 6598, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21064, 10229, NULL, 6598, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21065, 347, NULL, 6598, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21070, 10231, NULL, 6600, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21071, 5573, NULL, 6601, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21072, 10232, NULL, 6601, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21073, 7678, 185, 6601, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21074, 10233, NULL, 6601, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21075, 3288, NULL, 6602, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21076, 2424, 169, 6602, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21077, 9270, 186, 6602, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21078, 9913, NULL, 6602, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21079, 5390, 187, 6603, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21080, 10234, NULL, 6603, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21081, 10235, NULL, 6603, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21082, 2781, NULL, 6603, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21083, 10236, NULL, 6603, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21084, 3615, NULL, 6603, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21085, 5145, NULL, 6603, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21086, 894, NULL, 6604, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21087, 5892, 188, 6604, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21088, 814, NULL, 6604, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21089, 10237, NULL, 6605, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21090, 10238, NULL, 6605, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21091, 10239, NULL, 6606, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21092, 344, 189, 6607, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21093, 10240, NULL, 6607, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21094, 10241, NULL, 6608, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21095, 104, NULL, 6609, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21096, 1067, NULL, 6609, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21097, 3, NULL, 6609, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21100, 1340, NULL, 6611, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21101, 2568, NULL, 6611, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21102, 2181, NULL, 6611, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21103, 1122, NULL, 6611, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21104, 199, NULL, 6612, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21105, 1845, NULL, 6612, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21106, 1131, NULL, 6613, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21107, 157, NULL, 6613, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21108, 1030, NULL, 6613, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21109, 941, NULL, 6614, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21110, 2664, NULL, 6614, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21111, 2384, NULL, 6614, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21112, 408, NULL, 6615, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21113, 232, NULL, 6616, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21114, 914, NULL, 6616, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21115, 2749, NULL, 6616, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21116, 190, NULL, 6617, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21117, 405, NULL, 6617, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21118, 1302, NULL, 6618, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21119, 468, NULL, 6618, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21120, 2681, NULL, 6619, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21121, 191, NULL, 6619, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21122, 445, NULL, 6620, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21124, 330, NULL, 6621, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21125, 1393, NULL, 6621, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21126, 1340, NULL, 6622, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21127, 6551, NULL, 6622, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21128, 625, NULL, 6622, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21129, 3061, NULL, 6622, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21130, 601, NULL, 6623, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21131, 91, NULL, 6624, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21132, 1042, NULL, 6624, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21133, 768, NULL, 6625, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21134, 2685, NULL, 6625, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21135, 2425, NULL, 6625, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21136, 10242, NULL, 6625, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21140, 164, NULL, 6628, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21141, 1943, NULL, 6628, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21142, 998, NULL, 6629, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21143, 2485, NULL, 6629, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21144, 2393, NULL, 6629, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21145, 1037, NULL, 6630, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21146, 2620, NULL, 6630, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21147, 948, NULL, 6631, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21148, 2885, NULL, 6631, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21149, 234, NULL, 6632, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21150, 857, NULL, 6632, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21151, 295, NULL, 6633, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21152, 697, NULL, 6633, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21153, 1263, NULL, 6634, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21154, 2773, NULL, 6634, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20989, 10207, NULL, 6577, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20988, 7211, NULL, 6577, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21069, 10230, NULL, 6599, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21066, 2076, 183, 6599, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21068, 1581, NULL, 6599, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21067, 8225, 184, 6599, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21098, 1349, NULL, 6610, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21155, 1770, NULL, 6635, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21156, 2387, NULL, 6635, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21157, 2133, NULL, 6635, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21158, 230, NULL, 6636, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21161, 3691, NULL, 6638, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21162, 5308, NULL, 6638, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21163, 5207, NULL, 6638, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21164, 2802, NULL, 6638, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21165, 10243, NULL, 6639, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21166, 10244, NULL, 6639, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21167, 10245, NULL, 6639, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21168, 10246, NULL, 6639, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21169, 2894, NULL, 6639, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21007, 6505, NULL, 6582, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21009, 1971, NULL, 6582, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21178, 1575, NULL, 6642, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21179, 106, NULL, 6642, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21180, 9552, NULL, 6642, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21181, 1802, NULL, 6642, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21231, 2021, NULL, 6655, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21234, 10264, NULL, 6655, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21232, 10263, NULL, 6655, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21233, 906, NULL, 6655, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21187, 6023, NULL, 6645, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21188, 10250, NULL, 6645, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21189, 10251, NULL, 6645, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21190, 10252, NULL, 6645, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21191, 10253, NULL, 6646, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21192, 10254, NULL, 6646, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21193, 4571, NULL, 6646, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21194, 10255, NULL, 6646, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21197, 1461, NULL, 6648, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21199, 743, NULL, 6648, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21200, 1018, NULL, 6648, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21201, 1890, NULL, 6648, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21202, 445, NULL, 6648, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21203, 456, NULL, 6648, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21204, 1024, NULL, 6648, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (21205, 2873, NULL, 6649, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21206, 10256, NULL, 6649, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21207, 10257, NULL, 6649, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21208, 8043, NULL, 6649, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21209, 10258, NULL, 6649, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21210, 10259, NULL, 6649, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21211, 10260, NULL, 6649, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21221, 7323, NULL, 6652, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21222, 9597, NULL, 6652, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21223, 7551, NULL, 6653, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21224, 10261, NULL, 6653, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21225, 9334, NULL, 6653, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21226, 1777, NULL, 6653, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21227, 1456, NULL, 6654, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21228, 7856, NULL, 6654, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21229, 2981, NULL, 6654, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21230, 10262, NULL, 6654, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21235, 9969, NULL, 6656, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21236, 10213, NULL, 6656, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21237, 9936, NULL, 6656, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21138, 2232, NULL, 6627, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21139, 933, NULL, 6627, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21137, 933, NULL, 6626, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21171, 326, NULL, 6640, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21173, 9005, NULL, 6640, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21172, 5893, NULL, 6640, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21170, 2614, NULL, 6640, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21238, 9483, NULL, 6656, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21239, 7548, NULL, 6657, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21198, 12082, NULL, 6648, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21240, 10265, NULL, 6657, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21241, 10266, NULL, 6657, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21242, 10267, NULL, 6657, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21243, 12, NULL, 6658, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21244, 9515, NULL, 6658, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21245, 8507, NULL, 6658, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21246, 1929, NULL, 6658, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21247, 1364, NULL, 6659, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21248, 10268, NULL, 6659, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21249, 1590, NULL, 6660, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21250, 2506, NULL, 6660, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21251, 3178, NULL, 6660, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21252, 2996, NULL, 6660, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21253, 9847, NULL, 6661, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21254, 7927, NULL, 6661, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21255, 9847, NULL, 6662, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21256, 1821, NULL, 6662, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21260, 1113, NULL, 6664, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21261, 9819, NULL, 6664, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21262, 10271, NULL, 6664, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21263, 10272, NULL, 6664, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21264, 1571, NULL, 6665, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21265, 1952, NULL, 6665, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21266, 2316, NULL, 6665, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21267, 1386, NULL, 6665, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21268, 1618, NULL, 6666, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21269, 2571, NULL, 6666, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21270, 1609, NULL, 6666, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21271, 5935, NULL, 6666, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21272, 1497, NULL, 6667, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21273, 10273, NULL, 6667, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21274, 1334, NULL, 6667, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21275, 1497, NULL, 6668, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21276, 5950, NULL, 6668, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21277, 122, NULL, 6668, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21278, 381, NULL, 6669, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21279, 2217, NULL, 6669, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21280, 2221, NULL, 6669, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21281, 2049, NULL, 6669, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21282, 791, NULL, 6670, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21283, 10274, NULL, 6670, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21284, 4791, NULL, 6670, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21285, 1976, NULL, 6670, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21289, 2830, NULL, 6672, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21290, 10276, NULL, 6672, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21291, 10277, NULL, 6672, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21292, 248, NULL, 6673, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21293, 2597, NULL, 6673, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21294, 5390, NULL, 6673, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21295, 2476, NULL, 6673, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21296, 1036, NULL, 6674, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21300, 1356, NULL, 6675, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21301, 10279, NULL, 6675, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21302, 1745, NULL, 6675, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21303, 2128, NULL, 6675, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21304, 5369, NULL, 6675, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21305, 773, NULL, 6675, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21306, 2559, NULL, 6675, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21307, 1590, NULL, 6676, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21308, 1869, NULL, 6676, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21309, 2473, NULL, 6676, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21310, 292, NULL, 6676, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21311, 271, NULL, 6677, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21312, 4239, NULL, 6677, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21313, 2452, NULL, 6677, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21314, 1249, NULL, 6677, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21315, 10280, NULL, 6677, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21316, 1220, NULL, 6677, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21317, 10281, NULL, 6677, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21318, 437, NULL, 6678, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21322, 5855, NULL, 6678, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21323, 10019, NULL, 6678, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21325, 1234, NULL, 6679, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21326, 10284, NULL, 6679, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21327, 2570, NULL, 6679, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21328, 7904, NULL, 6679, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21329, 1414, NULL, 6680, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21330, 4865, NULL, 6681, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21331, 10285, NULL, 6681, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21297, 4738, 285, 6674, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21332, 1829, NULL, 6682, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21333, 1954, NULL, 6682, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21334, 7068, NULL, 6682, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21335, 10286, NULL, 6682, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21336, 623, NULL, 6683, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21337, 8799, NULL, 6683, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21338, 1886, NULL, 6683, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21339, 10287, NULL, 6683, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21340, 1487, NULL, 6684, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21341, 785, NULL, 6684, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21342, 2300, NULL, 6684, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21343, 5029, NULL, 6684, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21344, 344, NULL, 6685, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21345, 1979, NULL, 6685, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21258, 10269, NULL, 6663, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21257, 698, NULL, 6663, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21259, 10270, NULL, 6663, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21177, 1884, NULL, 6641, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21174, 698, NULL, 6641, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21175, 3919, NULL, 6641, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21196, 9644, NULL, 6647, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32919, 12186, NULL, 10195, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32809, 10733, NULL, 10162, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32844, 13854, NULL, 10162, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21346, 2144, NULL, 6685, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21347, 2402, NULL, 6685, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21348, 1229, NULL, 6686, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21349, 2036, NULL, 6686, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21350, 6576, NULL, 6686, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21351, 10288, NULL, 6686, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21352, 843, NULL, 6687, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21353, 1352, NULL, 6687, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21354, 1067, NULL, 6687, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21355, 10289, NULL, 6687, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21356, 382, NULL, 6688, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21357, 8343, NULL, 6688, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21358, 10290, NULL, 6688, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21359, 10291, NULL, 6688, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21360, 1597, NULL, 6689, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21362, 2571, NULL, 6689, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21363, 10292, NULL, 6689, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21364, 1804, NULL, 6690, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21217, 299, NULL, 6651, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21213, 1948, NULL, 6650, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21216, 320, NULL, 6651, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21218, 2336, NULL, 6651, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21220, 2089, NULL, 6651, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21365, 9068, NULL, 6690, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21366, 8716, NULL, 6690, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21367, 375, NULL, 6690, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21368, 1163, NULL, 6691, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21369, 9738, NULL, 6691, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21370, 3463, NULL, 6691, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21371, 10293, NULL, 6691, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21478, 430, NULL, 6719, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21480, 1031, NULL, 6719, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21479, 1129, 526, 6719, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21481, 10311, NULL, 6719, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21380, 2152, NULL, 6694, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21381, 2213, NULL, 6694, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21382, 2215, NULL, 6694, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21383, 2216, NULL, 6694, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21384, 1360, NULL, 6695, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21385, 5753, NULL, 6695, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21386, 2963, NULL, 6695, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21387, 10295, NULL, 6695, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21392, 1515, NULL, 6697, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21393, 2661, NULL, 6697, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21394, 3779, NULL, 6697, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21395, 1748, NULL, 6697, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21396, 7773, NULL, 6698, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21397, 6639, NULL, 6698, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21398, 5854, NULL, 6698, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21399, 4267, NULL, 6698, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21400, 9645, NULL, 6699, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21401, 10300, NULL, 6699, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21402, 3180, NULL, 6699, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21403, 480, NULL, 6700, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21404, 2317, NULL, 6700, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21405, 4085, NULL, 6700, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21406, 2091, NULL, 6700, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21407, 2063, NULL, 6701, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21408, 4176, NULL, 6701, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21409, 2347, NULL, 6701, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21410, 10301, NULL, 6701, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21411, 1368, NULL, 6702, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21412, 8422, NULL, 6702, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21413, 1266, NULL, 6702, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21414, 8423, NULL, 6702, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21415, 248, NULL, 6703, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21416, 8404, NULL, 6703, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21417, 8405, NULL, 6703, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21418, 8407, NULL, 6703, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21376, 939, NULL, 6693, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21379, 8723, NULL, 6693, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21378, 5786, NULL, 6693, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21419, 7774, NULL, 6704, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21421, 2905, NULL, 6704, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21423, 271, NULL, 6705, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21424, 2204, NULL, 6705, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21425, 2207, NULL, 6705, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21426, 2208, NULL, 6705, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21427, 203, NULL, 6706, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21428, 1651, NULL, 6706, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21429, 3262, NULL, 6706, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21430, 5909, NULL, 6706, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21431, 1958, NULL, 6707, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21432, 10303, NULL, 6707, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21433, 7067, NULL, 6707, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21434, 10304, NULL, 6707, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21435, 9003, NULL, 6708, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21436, 9004, NULL, 6708, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21437, 3290, NULL, 6708, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21438, 430, NULL, 6709, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21440, 3001, NULL, 6709, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21441, 2346, NULL, 6709, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21442, 3165, NULL, 6709, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21443, 470, NULL, 6710, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21444, 2626, NULL, 6710, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21445, 3086, NULL, 6710, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21446, 10306, NULL, 6710, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21447, 1147, NULL, 6711, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21448, 1232, NULL, 6711, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21449, 2076, NULL, 6711, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21450, 1954, NULL, 6711, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21451, 810, NULL, 6712, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21452, 1731, NULL, 6712, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21453, 913, NULL, 6712, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21454, 2327, NULL, 6712, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21455, 97, NULL, 6713, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21456, 10307, NULL, 6713, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21457, 292, NULL, 6713, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21458, 909, NULL, 6714, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21459, 1325, NULL, 6714, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21460, 10308, NULL, 6714, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21461, 8051, NULL, 6714, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21462, 1421, NULL, 6715, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21463, 5693, NULL, 6715, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21464, 10309, NULL, 6715, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21465, 429, NULL, 6715, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21466, 1080, NULL, 6716, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21467, 1291, NULL, 6716, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21468, 2438, NULL, 6716, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21469, 4830, NULL, 6716, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21470, 114, NULL, 6717, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21471, 1561, NULL, 6717, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21472, 1415, NULL, 6717, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21473, 10310, NULL, 6717, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21474, 1283, NULL, 6718, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21475, 1707, NULL, 6718, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21361, 2683, 344, 6689, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21319, 20, 419, 6678, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21320, 10282, 420, 6678, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21321, 10283, 421, 6678, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21324, 5153, 422, 6678, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21476, 305, NULL, 6718, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21477, 2816, NULL, 6718, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21482, 1425, NULL, 6720, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21483, 1347, NULL, 6720, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21484, 2102, NULL, 6720, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21485, 8086, NULL, 6720, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21486, 1450, NULL, 6721, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21487, 2918, NULL, 6721, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21488, 652, NULL, 6721, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21489, 2110, NULL, 6721, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21490, 10312, NULL, 6741, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21491, 9542, NULL, 6741, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21492, 2988, NULL, 6741, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21493, 10313, NULL, 6741, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21494, 10314, NULL, 6742, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21495, 312, NULL, 6742, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21496, 10315, NULL, 6742, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21497, 10316, NULL, 6742, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21498, 13, NULL, 6742, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21499, 9553, NULL, 6742, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21500, 709, NULL, 6742, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21501, 10317, NULL, 6743, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21502, 336, NULL, 6743, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21503, 68, NULL, 6743, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21504, 10318, NULL, 6744, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21505, 76, NULL, 6744, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21506, 1699, NULL, 6744, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21507, 10319, NULL, 6744, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21508, 1101, NULL, 6744, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21509, 10320, NULL, 6745, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21510, 10321, NULL, 6745, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21511, 10322, NULL, 6745, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21512, 3564, NULL, 6746, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21513, 4954, NULL, 6746, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21514, 10323, NULL, 6746, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21515, 10324, NULL, 6747, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21516, 10325, NULL, 6747, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21517, 10326, NULL, 6747, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21518, 6500, NULL, 6748, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21519, 2159, NULL, 6748, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21520, 1911, NULL, 6748, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21521, 10327, NULL, 6749, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21522, 1148, NULL, 6749, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21523, 1505, NULL, 6749, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21524, 10328, NULL, 6750, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21525, 2413, NULL, 6750, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21526, 403, NULL, 6750, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21527, 2029, NULL, 6750, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21528, 10329, NULL, 6751, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21529, 1542, NULL, 6751, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21530, 1707, NULL, 6751, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21531, 10330, NULL, 6752, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21532, 2559, NULL, 6752, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21533, 1659, NULL, 6752, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21534, 9543, NULL, 6752, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21535, 10331, NULL, 6753, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21536, 1241, NULL, 6753, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21537, 429, NULL, 6753, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21538, 3752, NULL, 6753, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21539, 390, NULL, 6753, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21540, 9552, NULL, 6753, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21541, 256, NULL, 6753, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21542, 10332, NULL, 6754, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21543, 7656, NULL, 6754, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21544, 8805, NULL, 6754, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21545, 1026, NULL, 6754, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21546, 10333, NULL, 6755, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21547, 86, NULL, 6755, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21548, 1965, NULL, 6755, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21549, 9539, NULL, 6755, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21550, 6408, NULL, 6756, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21551, 10334, NULL, 6756, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21552, 6407, NULL, 6756, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21553, 340, NULL, 6757, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21554, 1598, NULL, 6757, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21555, 2918, NULL, 6757, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32944, 13888, NULL, 10031, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32945, 10182, NULL, 10031, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21559, 10335, NULL, 6759, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21560, 1837, NULL, 6759, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21561, 8316, NULL, 6760, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21562, 1696, NULL, 6760, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21563, 482, NULL, 6760, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21564, 964, NULL, 6761, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21565, 299, NULL, 6761, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21566, 3700, NULL, 6761, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21567, 1590, NULL, 6761, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21568, 5951, NULL, 6762, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21569, 5826, NULL, 6762, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21570, 5952, NULL, 6762, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21571, 1872, NULL, 6762, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21572, 5841, NULL, 6763, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21573, 5842, NULL, 6763, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21574, 5843, NULL, 6763, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21575, 5844, NULL, 6763, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21576, 5845, NULL, 6763, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21577, 377, NULL, 6764, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21578, 10336, NULL, 6764, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21579, 942, NULL, 6764, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21580, 10337, NULL, 6764, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21585, 6109, NULL, 6766, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21586, 6271, NULL, 6766, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21587, 4105, NULL, 6766, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21588, 5207, NULL, 6766, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21589, 2948, NULL, 6767, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21590, 1542, NULL, 6767, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21591, 1814, NULL, 6767, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21592, 281, NULL, 6768, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21593, 488, NULL, 6768, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21594, 2326, NULL, 6768, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21595, 62, NULL, 6768, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21596, 133, NULL, 6769, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21597, 5993, NULL, 6769, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21598, 4912, NULL, 6769, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21599, 10339, NULL, 6770, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21600, 10340, NULL, 6770, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21601, 10341, NULL, 6770, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21602, 1059, 17, 6771, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21603, 6048, NULL, 6771, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21604, 1693, NULL, 6771, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21605, 1705, NULL, 6771, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21606, 1002, NULL, 6772, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21422, 280, NULL, 6704, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21607, 2886, NULL, 6772, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21608, 1455, NULL, 6772, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21609, 1911, NULL, 6772, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21610, 1052, NULL, 6772, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21611, 3572, NULL, 6772, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21613, 640, NULL, 6773, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21614, 2144, NULL, 6773, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21615, 1099, NULL, 6773, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21616, 6134, NULL, 6773, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21617, 498, NULL, 6774, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21618, 10342, NULL, 6774, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21619, 10343, NULL, 6774, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21620, 8498, NULL, 6774, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21621, 1644, NULL, 6775, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21622, 4833, NULL, 6775, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21623, 2864, NULL, 6775, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21624, 765, NULL, 6775, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21625, 1066, NULL, 6776, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21626, 8843, NULL, 6776, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21627, 1624, NULL, 6776, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21628, 692, NULL, 6776, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21629, 631, NULL, 6777, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21630, 8103, NULL, 6777, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21631, 2912, NULL, 6777, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21632, 2996, NULL, 6777, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21633, 447, NULL, 6778, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21635, 503, NULL, 6778, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21636, 328, NULL, 6778, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21638, 5916, NULL, 6779, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21640, 5056, NULL, 6779, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21641, 964, NULL, 6780, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21642, 5956, NULL, 6780, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21643, 2993, NULL, 6780, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21644, 2952, NULL, 6780, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21645, 806, NULL, 6781, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21646, 773, NULL, 6781, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21647, 1636, NULL, 6781, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21648, 1943, NULL, 6781, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21650, 2238, NULL, 6782, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21651, 2932, NULL, 6782, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21652, 2747, NULL, 6782, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21653, 1226, NULL, 6783, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21654, 2226, NULL, 6783, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21655, 2747, NULL, 6783, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21656, 10344, NULL, 6783, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21657, 1913, NULL, 6783, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21658, 2699, NULL, 6783, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21659, 1896, NULL, 6783, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21660, 1404, NULL, 6784, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21637, 1248, 415, 6779, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21649, 1158, 417, 6782, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21661, 10345, NULL, 6784, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21662, 4729, NULL, 6784, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21664, 10346, NULL, 6784, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21666, 1965, NULL, 6784, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21667, 925, NULL, 6785, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21668, 2543, NULL, 6785, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21669, 1295, NULL, 6785, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21670, 2414, NULL, 6785, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21671, 8799, NULL, 6785, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21672, 2452, NULL, 6785, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21674, 589, NULL, 6786, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21675, 1702, NULL, 6786, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21676, 1923, NULL, 6786, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21677, 1236, NULL, 6787, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21678, 1958, NULL, 6787, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21679, 7067, NULL, 6787, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21680, 2040, NULL, 6787, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21681, 2000, NULL, 6787, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21682, 973, NULL, 6787, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21683, 10347, NULL, 6787, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21684, 1339, NULL, 6788, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21685, 10348, NULL, 6788, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21686, 951, NULL, 6788, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21687, 8792, NULL, 6788, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21688, 10349, NULL, 6788, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21689, 3077, NULL, 6788, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21690, 8798, NULL, 6788, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21691, 1293, NULL, 6789, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21692, 2403, NULL, 6789, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21693, 1024, NULL, 6790, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21694, 1151, NULL, 6790, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21695, 1371, NULL, 6791, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21696, 10350, NULL, 6791, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21697, 10351, NULL, 6791, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21698, 10352, NULL, 6791, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21699, 10353, NULL, 6791, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21700, 8040, NULL, 6791, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21701, 1087, NULL, 6791, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21702, 1195, NULL, 6792, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21703, 2766, NULL, 6792, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21704, 4384, NULL, 6792, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21705, 2883, NULL, 6792, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21706, 3123, NULL, 6792, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21707, 6805, NULL, 6792, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21708, 10354, NULL, 6792, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21716, 764, NULL, 6794, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21717, 1137, NULL, 6794, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21557, 4236, NULL, 6758, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21718, 8174, NULL, 6794, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21719, 1745, NULL, 6794, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21720, 3232, NULL, 6794, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21721, 7502, NULL, 6794, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21722, 1117, NULL, 6794, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21723, 1293, NULL, 6795, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21724, 2794, NULL, 6795, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21725, 1024, NULL, 6796, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21726, 2980, NULL, 6796, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21727, 873, NULL, 6797, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21728, 3761, NULL, 6797, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21729, 1452, NULL, 6797, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21730, 995, NULL, 6797, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21731, 1257, NULL, 6798, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21732, 10185, NULL, 6798, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21733, 7978, NULL, 6798, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21734, 2424, NULL, 6798, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21735, 824, NULL, 6799, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21736, 10186, NULL, 6799, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21737, 4399, NULL, 6799, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21738, 10187, NULL, 6799, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21739, 194, NULL, 6800, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21740, 10182, NULL, 6800, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21741, 1707, NULL, 6800, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21742, 7834, NULL, 6800, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21743, 1621, NULL, 6801, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21744, 5857, 170, 6801, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21745, 2339, NULL, 6801, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21746, 2536, NULL, 6801, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21747, 362, NULL, 6802, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21748, 2415, NULL, 6802, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21749, 4239, NULL, 6802, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21750, 1291, NULL, 6802, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21751, 1262, NULL, 6803, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21752, 6632, NULL, 6803, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21753, 10188, NULL, 6803, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21754, 10189, NULL, 6803, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21755, 277, NULL, 6804, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21756, 503, NULL, 6804, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21757, 2030, NULL, 6804, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21758, 2790, NULL, 6804, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21759, 2554, NULL, 6804, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21760, 1031, NULL, 6804, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21761, 10190, NULL, 6804, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21762, 7797, NULL, 6804, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (21763, 4361, NULL, 6805, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21764, 109, NULL, 6805, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21765, 1344, NULL, 6805, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21766, 5273, NULL, 6805, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21767, 10191, NULL, 6806, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21768, 93, NULL, 6806, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21769, 10192, NULL, 6806, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21770, 3113, NULL, 6806, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21771, 1504, NULL, 6807, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21772, 10193, NULL, 6807, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21773, 10194, NULL, 6807, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21774, 2644, NULL, 6807, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21775, 1227, NULL, 6808, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21776, 4002, NULL, 6808, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21777, 1858, NULL, 6808, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21778, 2898, NULL, 6808, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21786, 1618, NULL, 6810, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21787, 1624, NULL, 6810, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21788, 7502, NULL, 6810, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21789, 3628, NULL, 6810, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21790, 9624, NULL, 6810, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21791, 10359, NULL, 6810, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21792, 9738, NULL, 6810, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21797, 1428, NULL, 6812, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21798, 109, NULL, 6812, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21799, 8253, NULL, 6812, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21800, 8254, NULL, 6812, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21801, 7856, NULL, 6812, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21802, 9739, NULL, 6812, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21803, 1311, NULL, 6812, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21804, 1145, NULL, 6813, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21805, 10360, NULL, 6813, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21806, 7507, NULL, 6813, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21807, 1625, NULL, 6813, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21808, 9334, NULL, 6813, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21809, 10361, NULL, 6813, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21810, 7511, NULL, 6813, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21811, 10362, NULL, 6813, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (21819, 424, NULL, 6815, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21820, 10364, NULL, 6815, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21821, 4778, NULL, 6815, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21822, 8285, NULL, 6815, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21823, 2236, NULL, 6815, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21824, 8672, NULL, 6815, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21825, 5880, NULL, 6815, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21826, 1230, NULL, 6816, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21827, 1208, NULL, 6816, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21828, 1745, NULL, 6816, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21829, 2534, NULL, 6816, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21830, 773, NULL, 6816, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21831, 4876, NULL, 6816, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21832, 7858, NULL, 6816, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21833, 1204, NULL, 6817, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21834, 51, NULL, 6817, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21835, 2661, NULL, 6817, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21836, 1821, NULL, 6817, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21845, 520, NULL, 6819, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21673, 9854, 413, 6785, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21846, 10365, NULL, 6819, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21847, 3123, NULL, 6819, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21848, 2753, NULL, 6819, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21849, 10366, NULL, 6819, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21850, 2952, NULL, 6819, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21851, 6208, NULL, 6819, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21852, 825, NULL, 6820, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21853, 2258, NULL, 6820, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21854, 2037, NULL, 6820, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21855, 1881, NULL, 6820, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21856, 6764, NULL, 6821, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21857, 2348, NULL, 6821, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21858, 2118, NULL, 6821, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21859, 2266, NULL, 6821, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21860, 989, NULL, 6822, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21861, 10367, NULL, 6822, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21862, 3180, NULL, 6822, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21863, 2906, NULL, 6822, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21864, 4663, NULL, 6823, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21865, 8173, NULL, 6823, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21866, 4872, NULL, 6823, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21867, 8665, NULL, 6823, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21868, 986, NULL, 6824, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21869, 4323, NULL, 6824, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21870, 1400, NULL, 6824, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21871, 2186, NULL, 6824, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21872, 761, NULL, 6825, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21873, 4258, NULL, 6825, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21875, 2992, NULL, 6825, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21876, 953, NULL, 6826, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21877, 9264, NULL, 6826, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21878, 5283, NULL, 6826, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21879, 2655, NULL, 6826, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21880, 176, NULL, 6827, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21881, 3848, NULL, 6827, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21882, 3711, NULL, 6827, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21883, 9165, NULL, 6827, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21884, 126, NULL, 6828, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21885, 2747, NULL, 6828, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21886, 10368, NULL, 6828, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21887, 10369, NULL, 6828, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21888, 1732, NULL, 6829, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21890, 5267, NULL, 6829, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21891, 1881, NULL, 6829, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21892, 960, NULL, 6830, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21893, 2980, NULL, 6830, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21894, 10370, NULL, 6830, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21895, 3164, NULL, 6830, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21897, 773, NULL, 6831, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21898, 1208, NULL, 6831, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21899, 3438, NULL, 6831, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21903, 6685, NULL, 6833, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21904, 10371, NULL, 6833, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21905, 4251, NULL, 6833, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21906, 2624, NULL, 6833, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21911, 1043, NULL, 6835, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21912, 10375, NULL, 6835, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21913, 10376, NULL, 6835, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21914, 10377, NULL, 6835, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21915, 807, NULL, 6836, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21916, 2980, NULL, 6836, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21917, 3010, NULL, 6836, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21918, 9530, NULL, 6836, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21919, 269, NULL, 6837, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21920, 10378, NULL, 6837, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21921, 10379, NULL, 6837, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21922, 10380, NULL, 6837, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21923, 10381, NULL, 6837, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21924, 10382, NULL, 6837, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21925, 10383, NULL, 6837, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21926, 10384, NULL, 6837, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (22020, 4773, NULL, 6860, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22016, 1191, NULL, 6860, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22017, 2683, 344, 6860, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22018, 1400, NULL, 6860, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21931, 9847, NULL, 6839, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21932, 10385, NULL, 6839, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21933, 2956, NULL, 6839, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21934, 4766, NULL, 6840, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21935, 10386, NULL, 6840, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21936, 10387, NULL, 6840, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21937, 10053, NULL, 6841, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21938, 10054, NULL, 6841, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21939, 1159, NULL, 6842, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21940, 38, NULL, 6842, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21815, 10363, NULL, 6814, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21817, 2369, NULL, 6814, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21813, 1042, NULL, 6814, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21812, 1321, NULL, 6814, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21814, 8702, NULL, 6814, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21816, 6732, NULL, 6814, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21818, 2906, NULL, 6814, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21795, 787, NULL, 6811, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21793, 1141, NULL, 6811, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21794, 2364, NULL, 6811, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21796, 1313, NULL, 6811, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21941, 8714, NULL, 6842, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21942, 2980, NULL, 6842, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21943, 1191, NULL, 6843, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21944, 2683, NULL, 6843, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21945, 1400, NULL, 6843, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21946, 8174, NULL, 6843, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21947, 4773, NULL, 6843, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21948, 432, NULL, 6844, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21949, 10388, NULL, 6844, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21950, 3612, NULL, 6844, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21951, 10389, NULL, 6844, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21952, 1374, NULL, 6845, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21953, 613, NULL, 6845, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21954, 312, NULL, 6845, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21955, 1505, NULL, 6845, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21956, 123, NULL, 6845, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21957, 1186, NULL, 6846, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21958, 1311, NULL, 6846, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21959, 2531, NULL, 6846, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21960, 4030, NULL, 6846, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21961, 364, NULL, 6847, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21962, 10348, NULL, 6847, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21963, 5978, NULL, 6847, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21964, 7212, NULL, 6847, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21965, 544, NULL, 6848, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21966, 76, NULL, 6848, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21967, 3013, NULL, 6848, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21968, 2985, NULL, 6848, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21976, 6685, NULL, 6850, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21977, 10371, NULL, 6850, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21978, 4251, NULL, 6850, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21979, 2624, NULL, 6850, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21984, 1043, NULL, 6852, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21985, 10375, NULL, 6852, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21986, 10376, NULL, 6852, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21987, 10377, NULL, 6852, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21988, 807, NULL, 6853, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21989, 2980, NULL, 6853, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21990, 3010, NULL, 6853, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21991, 9530, NULL, 6853, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21992, 269, NULL, 6854, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21993, 10378, NULL, 6854, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21994, 10379, NULL, 6854, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21995, 10380, NULL, 6854, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21996, 10381, NULL, 6854, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21997, 10382, NULL, 6854, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21998, 10383, NULL, 6854, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21999, 10384, NULL, 6854, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (22019, 8174, NULL, 6860, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32946, 71, NULL, 10031, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32932, 835, NULL, 10200, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32934, 4003, NULL, 10200, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22004, 9847, NULL, 6856, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22005, 10385, NULL, 6856, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22006, 2956, NULL, 6856, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22007, 4766, NULL, 6857, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22008, 10386, NULL, 6857, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22009, 10387, NULL, 6857, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22010, 10053, NULL, 6858, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22011, 10054, NULL, 6858, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22012, 1159, NULL, 6859, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22013, 38, NULL, 6859, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22014, 8714, NULL, 6859, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22015, 2980, NULL, 6859, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22021, 432, NULL, 6861, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22022, 10388, NULL, 6861, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22023, 3612, NULL, 6861, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22024, 10389, NULL, 6861, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22025, 1374, NULL, 6862, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22026, 613, NULL, 6862, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22027, 312, NULL, 6862, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22028, 1505, NULL, 6862, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22029, 123, NULL, 6862, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22030, 1186, NULL, 6863, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21874, 5581, 395, 6825, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21889, 4578, 396, 6829, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21896, 1717, 397, 6831, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22031, 1311, NULL, 6863, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22032, 2531, NULL, 6863, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22033, 4030, NULL, 6863, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22034, 364, NULL, 6864, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22035, 10348, NULL, 6864, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22036, 5978, NULL, 6864, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22037, 7212, NULL, 6864, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22038, 544, NULL, 6865, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22039, 76, NULL, 6865, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22040, 3013, NULL, 6865, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22041, 2985, NULL, 6865, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22042, 9849, NULL, 6867, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22043, 1631, NULL, 6867, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22044, 8289, NULL, 6867, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22045, 8288, NULL, 6867, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22046, 10390, NULL, 6867, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22047, 8355, NULL, 6867, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22048, 9707, NULL, 6867, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (22049, 6685, NULL, 6868, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22050, 10371, NULL, 6868, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22051, 4251, NULL, 6868, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22052, 2624, NULL, 6868, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22057, 1043, NULL, 6870, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22058, 10375, NULL, 6870, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22059, 10376, NULL, 6870, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22060, 10377, NULL, 6870, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22061, 807, NULL, 6871, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22062, 2980, NULL, 6871, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22063, 3010, NULL, 6871, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22064, 9530, NULL, 6871, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22073, 1834, NULL, 6873, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22074, 2921, NULL, 6873, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22075, 1821, NULL, 6873, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22076, 1862, NULL, 6873, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22083, 10053, NULL, 6876, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22084, 10054, NULL, 6876, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32933, 1190, NULL, 10200, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32807, 3370, NULL, 10162, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32845, 13855, NULL, 10162, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22087, 10391, NULL, 6866, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22085, 1364, NULL, 6866, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22086, 9860, NULL, 6866, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22081, 10386, NULL, 6875, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22082, 10387, NULL, 6875, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22080, 4766, NULL, 6875, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32947, 13889, NULL, 10032, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32948, 13890, NULL, 10032, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32949, 1374, NULL, 10032, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32950, 13604, NULL, 10033, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32951, 13891, NULL, 10033, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32952, 13892, NULL, 10033, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32953, 13893, NULL, 10033, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32954, 13894, NULL, 10034, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32955, 13895, NULL, 10034, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32956, 13896, NULL, 10034, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32957, 599, NULL, 10035, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22104, 10403, NULL, 6882, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22105, 4026, NULL, 6882, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22106, 1609, NULL, 6882, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22107, 10404, NULL, 6882, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32958, 13897, NULL, 10035, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32959, 7610, NULL, 10035, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32960, 508, NULL, 10035, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32961, 13612, NULL, 10036, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32962, 13613, NULL, 10036, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32963, 13614, NULL, 10036, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32964, 13898, NULL, 10036, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32965, 104, NULL, 10037, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32966, 13899, NULL, 10037, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32967, 2218, NULL, 10037, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22282, 2561, NULL, 6931, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22122, 10412, NULL, 6887, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22123, 5531, NULL, 6887, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22124, 3780, NULL, 6887, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22125, 6691, NULL, 6887, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22126, 1445, NULL, 6888, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22127, 10413, NULL, 6888, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22128, 10414, NULL, 6888, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22129, 10415, NULL, 6889, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22130, 10416, NULL, 6889, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22131, 10417, NULL, 6889, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22132, 2117, NULL, 6889, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22137, 5623, NULL, 6891, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28675, 11510, NULL, 8913, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28676, 12148, NULL, 8913, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28674, 12146, NULL, 8913, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22077, 9847, NULL, 6874, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22078, 10385, NULL, 6874, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22079, 2956, NULL, 6874, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22138, 10392, NULL, 6891, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22143, 10395, NULL, 6893, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22144, 10396, NULL, 6893, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22145, 4907, NULL, 6894, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22146, 10397, NULL, 6894, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22147, 3113, NULL, 6894, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22148, 10398, NULL, 6894, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22153, 10403, NULL, 6896, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22154, 4026, NULL, 6896, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22155, 1609, NULL, 6896, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22156, 10404, NULL, 6896, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22161, 10409, NULL, 6898, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22162, 741, NULL, 6898, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22163, 10410, NULL, 6898, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22164, 9175, NULL, 6899, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22165, 10411, NULL, 6899, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22166, 1699, NULL, 6899, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22167, 2899, NULL, 6899, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22168, 143, NULL, 6900, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22169, 1014, NULL, 6900, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22170, 5153, NULL, 6900, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22171, 10412, NULL, 6901, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22172, 5531, NULL, 6901, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22173, 3780, NULL, 6901, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22174, 6691, NULL, 6901, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22175, 1445, NULL, 6902, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22176, 10413, NULL, 6902, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22177, 10414, NULL, 6902, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22178, 10415, NULL, 6903, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22179, 10416, NULL, 6903, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22180, 10417, NULL, 6903, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22181, 2117, NULL, 6903, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22182, 252, NULL, 6904, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22183, 8098, NULL, 6904, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22184, 10418, NULL, 6904, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22185, 10419, NULL, 6904, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22186, 1360, NULL, 6905, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22187, 3979, NULL, 6905, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22188, 1628, NULL, 6905, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22189, 1493, NULL, 6905, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22190, 283, NULL, 6906, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22191, 4836, NULL, 6906, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22195, 1101, NULL, 6908, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22196, 10423, NULL, 6908, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22197, 5665, NULL, 6908, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22198, 2997, NULL, 6908, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22204, 1450, NULL, 6910, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22205, 1164, NULL, 6910, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22206, 376, NULL, 6910, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22207, 2556, NULL, 6911, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22208, 2127, NULL, 6911, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22209, 10424, NULL, 6911, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22210, 1118, NULL, 6911, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22211, 2846, NULL, 6912, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22212, 10425, NULL, 6912, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22213, 2171, NULL, 6912, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22214, 3016, NULL, 6912, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22215, 318, NULL, 6913, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22216, 2986, NULL, 6913, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22217, 5950, NULL, 6913, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22218, 10426, NULL, 6914, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22219, 2120, NULL, 6914, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22220, 305, NULL, 6914, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33185, 1329, NULL, 10276, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33186, 2134, 584, 10276, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33187, 14031, NULL, 10276, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22201, 405, NULL, 6909, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22203, 423, 64, 6909, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22200, 3219, NULL, 6909, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22199, 2492, NULL, 6909, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22202, 5126, NULL, 6909, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22221, 520, NULL, 6915, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22222, 292, NULL, 6915, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22223, 2336, NULL, 6915, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22224, 429, NULL, 6915, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22225, 3646, NULL, 6916, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22226, 1603, NULL, 6917, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22227, 2635, NULL, 6917, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22228, 1510, NULL, 6917, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22229, 1146, NULL, 6917, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22230, 431, NULL, 6918, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22231, 10427, NULL, 6918, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22232, 10428, NULL, 6918, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22233, 10429, NULL, 6918, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22234, 722, NULL, 6919, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22235, 1897, NULL, 6919, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22243, 937, NULL, 6922, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22244, 3129, NULL, 6922, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22245, 10431, NULL, 6922, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22246, 7171, NULL, 6922, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22247, 133, NULL, 6923, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22248, 848, NULL, 6923, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22249, 1818, NULL, 6923, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22250, 1059, 190, 6924, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22251, 648, NULL, 6924, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22252, 1699, NULL, 6924, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22253, 709, NULL, 6924, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22254, 686, NULL, 6924, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22255, 687, NULL, 6924, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22256, 2967, NULL, 6924, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (22257, 122, NULL, 6924, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (22258, 239, NULL, 6925, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22259, 3014, NULL, 6925, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22260, 1609, NULL, 6925, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22261, 9514, NULL, 6926, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22262, 2278, NULL, 6926, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22263, 1981, NULL, 6926, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22264, 1681, NULL, 6926, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22265, 3002, NULL, 6927, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22266, 1781, NULL, 6927, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22267, 803, NULL, 6927, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22268, 850, NULL, 6927, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22269, 10432, NULL, 6927, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22270, 9966, NULL, 6928, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22271, 10433, NULL, 6928, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22272, 7488, NULL, 6928, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22273, 5560, NULL, 6928, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22274, 4983, NULL, 6929, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22275, 1716, NULL, 6929, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22276, 2860, NULL, 6929, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22277, 91, NULL, 6929, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22159, 10407, NULL, 6897, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22158, 10406, NULL, 6897, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22157, 10405, NULL, 6897, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22160, 10408, NULL, 6897, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22192, 10420, NULL, 6907, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22193, 10421, NULL, 6907, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22194, 10422, NULL, 6907, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22279, 10434, NULL, 6930, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22278, 1722, NULL, 6930, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22280, 10435, NULL, 6930, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22296, 697, NULL, 6934, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22297, 1370, NULL, 6934, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22298, 2396, NULL, 6934, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22302, 1895, NULL, 6936, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22304, 123, NULL, 6936, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22305, 423, NULL, 6936, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22306, 2340, NULL, 6937, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22307, 7777, NULL, 6937, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22308, 10437, NULL, 6937, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22309, 4384, NULL, 6937, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22310, 3507, NULL, 6938, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22311, 2118, NULL, 6938, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22312, 346, NULL, 6938, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22313, 2563, NULL, 6938, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22314, 916, NULL, 6938, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22315, 1734, NULL, 6939, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22316, 1649, NULL, 6939, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22317, 3126, NULL, 6939, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22318, 3127, NULL, 6939, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22319, 2069, NULL, 6940, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22320, 9429, NULL, 6940, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22321, 647, NULL, 6940, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22322, 534, NULL, 6941, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22323, 955, NULL, 6941, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22324, 503, NULL, 6941, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22325, 3132, NULL, 6941, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22326, 2696, NULL, 6942, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22327, 1664, NULL, 6942, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22328, 803, NULL, 6942, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22329, 376, NULL, 6942, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22330, 9972, NULL, 6943, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22331, 2531, NULL, 6943, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22332, 1542, NULL, 6943, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22333, 1707, NULL, 6943, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22334, 2957, NULL, 6944, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22335, 2226, NULL, 6944, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22336, 1944, NULL, 6944, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22337, 4578, 8, 6944, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22338, 7200, 192, 6945, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22339, 9519, NULL, 6945, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22340, 9520, NULL, 6945, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22150, 10400, NULL, 6895, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22152, 10402, NULL, 6895, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22151, 10401, NULL, 6895, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22149, 10399, NULL, 6895, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22341, 5931, NULL, 6945, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22342, 2252, 193, 6946, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22343, 1588, NULL, 6946, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22344, 239, NULL, 6946, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22345, 2448, NULL, 6946, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22346, 1907, NULL, 6947, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22347, 2800, NULL, 6947, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22348, 1933, NULL, 6947, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22349, 295, NULL, 6948, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22350, 2968, NULL, 6948, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22351, 3536, NULL, 6948, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22352, 5073, NULL, 6948, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22353, 305, NULL, 6949, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22354, 121, NULL, 6949, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22355, 10438, NULL, 6949, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22356, 1042, NULL, 6949, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22357, 2144, NULL, 6949, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22358, 2238, NULL, 6950, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22359, 688, NULL, 6950, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22360, 3023, NULL, 6950, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22361, 2932, NULL, 6950, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22362, 2524, NULL, 6951, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22363, 2294, NULL, 6951, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22364, 2987, 194, 6951, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32968, 2511, NULL, 10037, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22369, 1541, NULL, 6953, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22370, 6922, NULL, 6953, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22371, 952, NULL, 6953, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22372, 423, NULL, 6953, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22373, 9915, 195, 6954, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22374, 8523, NULL, 6954, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22375, 4891, NULL, 6954, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22376, 10439, NULL, 6954, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22377, 7130, NULL, 6955, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22378, 5666, NULL, 6955, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22379, 7128, NULL, 6955, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22380, 2981, NULL, 6955, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22381, 2856, NULL, 6956, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22382, 10440, NULL, 6956, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22383, 2375, 196, 6956, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22384, 10441, NULL, 6956, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22385, 1942, NULL, 6957, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22386, 750, NULL, 6957, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22387, 2668, NULL, 6957, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22388, 1052, NULL, 6957, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32969, 4130, 534, 10037, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32970, 13900, NULL, 10037, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22392, 10442, NULL, 6959, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22393, 10443, NULL, 6959, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22394, 10444, NULL, 6959, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22395, 8703, NULL, 6960, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22396, 2691, NULL, 6960, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22397, 8041, NULL, 6960, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22398, 242, NULL, 6960, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22399, 806, NULL, 6961, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22400, 1542, NULL, 6961, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22401, 1707, NULL, 6961, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22402, 456, NULL, 6961, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22403, 1140, NULL, 6961, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22404, 1582, NULL, 6962, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22405, 6445, NULL, 6962, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22406, 2735, NULL, 6962, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22407, 2554, NULL, 6962, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22408, 2458, NULL, 6962, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22409, 10445, NULL, 6963, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22410, 8804, NULL, 6963, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22411, 10446, NULL, 6963, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22412, 1636, NULL, 6964, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22413, 2608, 197, 6964, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22414, 10447, NULL, 6964, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22415, 1067, NULL, 6964, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22416, 1955, NULL, 6964, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22241, 109, NULL, 6921, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22240, 4323, NULL, 6921, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22417, 21, NULL, 6964, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22418, 1137, NULL, 6964, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (22419, 2130, NULL, 6964, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (22420, 49, NULL, 6965, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22421, 10448, NULL, 6965, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22422, 10449, NULL, 6965, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22423, 10450, NULL, 6965, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22424, 10451, NULL, 6966, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22425, 5929, NULL, 6966, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22426, 2285, 1, 6966, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22427, 8523, NULL, 6966, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22428, 1958, NULL, 6966, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22429, 10452, NULL, 6966, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22430, 2763, NULL, 6966, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (22431, 5260, NULL, 6966, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (22432, 3507, NULL, 6967, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22433, 1135, NULL, 6967, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22434, 4311, NULL, 6967, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22435, 7500, NULL, 6967, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22436, 10453, NULL, 6967, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22437, 760, NULL, 6968, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22438, 2662, NULL, 6968, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22439, 3086, 198, 6968, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22440, 6057, NULL, 6968, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22441, 425, NULL, 6969, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22442, 673, 199, 6969, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22443, 2197, NULL, 6969, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22444, 2040, NULL, 6969, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22449, 10454, NULL, 6971, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22450, 5312, NULL, 6971, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22451, 2199, NULL, 6971, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22452, 2105, NULL, 6971, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22457, 2227, NULL, 6973, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22458, 10457, NULL, 6973, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22459, 10458, NULL, 6973, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22460, 10459, NULL, 6974, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22461, 10460, NULL, 6974, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22462, 1264, NULL, 6974, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22463, 10461, NULL, 6974, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22465, 10463, NULL, 6975, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22466, 10464, NULL, 6975, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22467, 3010, NULL, 6975, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22468, 10465, NULL, 6975, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22469, 7707, NULL, 6976, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22470, 9679, NULL, 6976, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22299, 109, NULL, 6935, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22300, 1140, NULL, 6935, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22293, 188, NULL, 6933, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22368, 7212, NULL, 6952, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22365, 2443, NULL, 6952, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22366, 1067, NULL, 6952, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22295, 382, NULL, 6933, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (22292, 497, NULL, 6933, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22471, 2906, NULL, 6976, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22472, 3142, NULL, 6976, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22473, 2106, NULL, 6976, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22474, 2564, NULL, 6976, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22475, 6910, NULL, 6976, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (22476, 7707, NULL, 6976, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (22489, 10475, NULL, 6979, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22490, 1232, NULL, 6979, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22491, 6471, NULL, 6979, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22492, 8525, NULL, 6979, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22498, 10480, NULL, 6981, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22499, 10481, NULL, 6981, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22500, 651, 200, 6981, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22501, 1491, NULL, 6981, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22502, 9482, NULL, 6982, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22503, 10292, NULL, 6982, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22504, 9483, NULL, 6983, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22505, 9565, NULL, 6983, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22506, 10482, NULL, 6983, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22507, 3017, NULL, 6983, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22508, 9480, NULL, 6984, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22509, 10483, NULL, 6984, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22510, 10484, NULL, 6984, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22511, 10485, NULL, 6984, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22512, 10486, NULL, 6985, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22513, 10487, NULL, 6985, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22514, 2999, 201, 6985, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22515, 2897, NULL, 6985, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22516, 10488, NULL, 6986, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22517, 10488, 201, 6986, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22518, 10489, NULL, 6986, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22519, 555, NULL, 6986, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22520, 4176, NULL, 6987, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22521, 5484, NULL, 6987, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22494, 3477, NULL, 6980, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22496, 10478, NULL, 6980, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22495, 10477, NULL, 6980, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22493, 10476, NULL, 6980, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22448, 111, NULL, 6970, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22446, 234, NULL, 6970, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22445, 2559, NULL, 6970, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22447, 1386, NULL, 6970, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22522, 2692, NULL, 6987, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22523, 10490, NULL, 6987, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22532, 9715, NULL, 6990, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22533, 10496, NULL, 6990, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22534, 10497, NULL, 6990, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22535, 10498, NULL, 6990, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22536, 10499, NULL, 6991, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22537, 1664, NULL, 6991, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22538, 2200, NULL, 6991, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22539, 2496, NULL, 6991, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22540, 10454, NULL, 6992, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22541, 2554, NULL, 6992, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22542, 49, NULL, 6992, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22543, 10500, NULL, 6992, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32971, 13901, NULL, 10037, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32972, 857, NULL, 10037, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (22552, 10506, NULL, 6994, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22553, 10507, NULL, 6994, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22554, 10508, NULL, 6994, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22556, 10510, NULL, 6995, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22557, 10511, NULL, 6995, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22558, 5850, NULL, 6995, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22559, 10512, NULL, 6995, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22560, 8694, NULL, 6996, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22561, 8235, NULL, 6996, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22562, 10513, NULL, 6996, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22563, 10514, NULL, 6996, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22564, 1694, NULL, 6997, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22565, 10515, NULL, 6997, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22566, 10516, NULL, 6997, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22567, 10437, NULL, 6997, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22568, 10517, NULL, 6998, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22569, 1452, NULL, 6998, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22570, 10518, NULL, 6998, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22571, 2016, NULL, 6998, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22572, 10519, NULL, 6998, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22573, 10520, NULL, 6998, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22574, 4065, NULL, 6998, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (22575, 2525, NULL, 6998, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (22576, 10521, NULL, 6999, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22577, 10522, NULL, 6999, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22578, 10523, NULL, 6999, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22579, 10524, NULL, 7000, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22580, 10525, NULL, 7000, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22581, 6691, NULL, 7000, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22582, 1858, NULL, 7000, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22583, 10526, NULL, 7001, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22584, 3378, NULL, 7001, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22585, 10527, NULL, 7001, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22586, 10528, NULL, 7001, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22587, 10529, NULL, 7002, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22588, 1179, NULL, 7002, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22589, 10530, NULL, 7002, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22590, 3446, NULL, 7002, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22591, 839, NULL, 7002, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22592, 2209, NULL, 7003, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22593, 971, NULL, 7003, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22594, 289, NULL, 7003, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22595, 10531, NULL, 7003, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22598, 8967, NULL, 7005, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22599, 10534, NULL, 7005, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22600, 10535, NULL, 7005, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22604, 10191, NULL, 7007, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22605, 10536, NULL, 7007, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22606, 10537, NULL, 7007, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22607, 10538, NULL, 7007, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22612, 284, NULL, 7009, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22613, 10542, NULL, 7009, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22614, 7673, 202, 7009, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31798, 12755, NULL, 9885, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22597, 10533, NULL, 7004, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22622, 9167, NULL, 7012, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22623, 9332, NULL, 7012, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22624, 3823, NULL, 7013, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22625, 6704, NULL, 7013, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22626, 4381, NULL, 7013, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22634, 10545, NULL, 7016, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22454, 10456, NULL, 6972, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22456, 10199, NULL, 6972, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22455, 10351, NULL, 6972, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22453, 10455, NULL, 6972, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22479, 10467, NULL, 6977, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22478, 9512, NULL, 6977, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22477, 10466, NULL, 6977, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22635, 10546, NULL, 7017, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22636, 10547, NULL, 7017, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22637, 9288, NULL, 7017, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22638, 3446, NULL, 7017, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22639, 2655, NULL, 7018, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22640, 3017, NULL, 7018, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22641, 10548, NULL, 7018, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22642, 1929, NULL, 7018, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22643, 10549, NULL, 7019, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22644, 10550, NULL, 7019, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22645, 10551, NULL, 7019, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22646, 281, NULL, 7020, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22647, 10552, NULL, 7020, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22648, 10553, NULL, 7020, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22649, 2912, NULL, 7020, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22650, 10554, NULL, 7021, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22651, 8702, NULL, 7021, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22652, 10555, NULL, 7021, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22653, 10556, NULL, 7021, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22654, 9447, NULL, 7022, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22656, 337, NULL, 7022, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22657, 10558, NULL, 7022, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22615, 247, NULL, 7010, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22617, 2232, NULL, 7010, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22616, 10543, NULL, 7010, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22603, 292, NULL, 7006, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22602, 376, NULL, 7006, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22601, 753, NULL, 7006, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22608, 2482, NULL, 7008, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10407, 3256, NULL, 3327, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10405, 4555, NULL, 3327, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10404, 1733, NULL, 3327, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22529, 10495, NULL, 6989, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22530, 8608, NULL, 6989, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22531, 4047, NULL, 6989, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22528, 10494, NULL, 6989, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22658, 1722, NULL, 7022, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22659, 8251, NULL, 7022, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22660, 10189, NULL, 7022, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (22661, 3647, NULL, 7023, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22662, 3145, NULL, 7023, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22663, 10559, NULL, 7023, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22664, 2065, NULL, 7023, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22665, 10560, NULL, 7024, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22666, 3394, NULL, 7024, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22667, 9104, NULL, 7024, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22668, 10561, NULL, 7024, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22670, 10563, NULL, 7025, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22671, 10564, NULL, 7025, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22683, 10572, NULL, 7029, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22684, 1873, NULL, 7029, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22685, 7515, NULL, 7029, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22700, 10580, NULL, 7034, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22701, 10581, NULL, 7034, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22702, 10582, NULL, 7034, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22703, 9512, NULL, 7034, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22704, 10583, NULL, 7035, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22705, 3754, NULL, 7035, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22706, 2862, NULL, 7035, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22707, 2713, NULL, 7035, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22708, 2797, NULL, 7036, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22709, 10584, NULL, 7036, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22711, 10586, NULL, 7037, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22712, 10587, NULL, 7037, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22713, 10164, NULL, 7037, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22714, 1084, NULL, 7038, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22715, 219, NULL, 7038, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22716, 2476, NULL, 7038, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22717, 365, NULL, 7038, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22718, 2578, NULL, 7039, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22719, 4732, NULL, 7039, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22720, 3145, NULL, 7039, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22721, 4783, NULL, 7039, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22722, 9316, NULL, 7040, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22723, 1651, NULL, 7040, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22524, 10491, NULL, 6988, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22527, 8851, NULL, 6988, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22687, 2451, NULL, 7030, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22689, 2424, 605, 7030, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22688, 2654, NULL, 7030, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22628, 835, 203, 7014, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22629, 5949, NULL, 7014, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22627, 8156, NULL, 7014, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30057, 2190, NULL, 9396, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30059, 8447, NULL, 9396, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30058, 2192, NULL, 9396, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22672, 3823, NULL, 7026, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22675, 10566, NULL, 7026, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22673, 10565, NULL, 7026, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22544, 10501, NULL, 6993, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22547, 10503, NULL, 6993, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22724, 2735, NULL, 7040, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22725, 10588, NULL, 7041, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22726, 7932, NULL, 7041, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22727, 2691, NULL, 7041, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22730, 9267, NULL, 7043, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22731, 7628, NULL, 7043, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22732, 10589, NULL, 7044, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22733, 10590, NULL, 7044, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22734, 10591, NULL, 7044, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22735, 10592, NULL, 7044, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22736, 10593, NULL, 7045, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22737, 10594, NULL, 7045, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22738, 10595, NULL, 7045, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22739, 10596, NULL, 7045, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22740, 10597, NULL, 7046, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22741, 10598, NULL, 7046, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22742, 2065, NULL, 7046, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22743, 10599, NULL, 7046, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22744, 9514, NULL, 7047, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22745, 1821, NULL, 7047, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22746, 2925, NULL, 7047, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22747, 10600, NULL, 7047, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22748, 2522, NULL, 7048, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22749, 10601, NULL, 7048, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22750, 10602, NULL, 7048, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22751, 10603, NULL, 7049, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22752, 8299, NULL, 7049, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22753, 10604, NULL, 7049, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22754, 6652, NULL, 7049, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22755, 7531, NULL, 7050, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22756, 1031, 173, 7050, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22757, 5837, NULL, 7050, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22758, 6464, NULL, 7050, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22759, 2347, NULL, 7051, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22760, 10605, NULL, 7051, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22761, 10606, NULL, 7051, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22762, 2822, NULL, 7052, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22763, 10607, NULL, 7052, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22764, 10608, NULL, 7052, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22765, 10609, NULL, 7052, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22766, 122, NULL, 7053, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22767, 405, NULL, 7053, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22769, 10611, NULL, 7053, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22770, 1948, NULL, 7054, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22771, 3860, NULL, 7054, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22772, 10612, NULL, 7054, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22773, 10613, NULL, 7054, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22774, 10614, NULL, 7054, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22775, 1834, NULL, 7055, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22776, 10615, NULL, 7055, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22655, 2138, NULL, 7022, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22777, 10616, NULL, 7055, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22778, 10617, NULL, 7055, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22780, 3600, NULL, 7057, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22781, 8165, NULL, 7057, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22782, 2358, NULL, 7057, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22783, 2975, NULL, 7057, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22784, 10618, NULL, 7057, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22785, 1542, NULL, 7058, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22786, 1409, NULL, 7058, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22787, 10619, NULL, 7058, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22788, 1535, NULL, 7059, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22789, 10620, NULL, 7059, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22790, 10621, NULL, 7059, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22791, 10622, NULL, 7059, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22796, 10624, NULL, 7061, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22797, 10625, NULL, 7061, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22798, 7747, NULL, 7061, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22799, 10626, NULL, 7061, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22804, 5882, NULL, 7063, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22805, 3628, NULL, 7063, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22806, 1745, NULL, 7063, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22811, 1329, NULL, 7065, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22812, 1503, NULL, 7065, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22813, 685, NULL, 7065, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22814, 10630, NULL, 7065, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22815, 5407, NULL, 7065, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22816, 6910, NULL, 7066, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22817, 10631, NULL, 7066, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22818, 10632, NULL, 7066, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22819, 10633, NULL, 7066, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22820, 10634, NULL, 7066, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22821, 10635, NULL, 7067, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22822, 10636, NULL, 7067, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22823, 10637, NULL, 7067, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22676, 10567, NULL, 7027, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22677, 3612, NULL, 7027, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22678, 10568, NULL, 7027, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22803, 9678, NULL, 7062, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22802, 9701, NULL, 7062, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22824, 10638, NULL, 7067, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22825, 1401, NULL, 7068, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22826, 10639, NULL, 7068, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22827, 10640, NULL, 7068, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22828, 10641, NULL, 7068, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22779, 1897, NULL, 7056, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32973, 13902, NULL, 10038, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32974, 13903, NULL, 10038, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32975, 13904, NULL, 10038, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22839, 1386, NULL, 7070, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22843, 10650, NULL, 7072, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22844, 940, NULL, 7072, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22808, 10627, NULL, 7064, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22807, 7022, NULL, 7064, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22810, 10629, NULL, 7064, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22809, 10628, NULL, 7064, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32976, 9263, NULL, 10038, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22829, 179, NULL, 7069, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22832, 1867, NULL, 7069, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22693, 10577, NULL, 7031, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22691, 10575, NULL, 7031, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22690, 9317, NULL, 7031, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22854, 55, NULL, 7075, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22855, 10656, NULL, 7075, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22856, 10657, NULL, 7075, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22857, 10658, NULL, 7075, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22860, 10659, NULL, 7077, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22861, 10660, NULL, 7077, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22862, 5933, NULL, 7077, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22863, 7097, NULL, 7078, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22864, 7283, NULL, 7078, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22865, 10199, NULL, 7078, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22866, 10456, NULL, 7078, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22867, 3274, NULL, 7079, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22868, 10661, NULL, 7079, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22869, 10662, NULL, 7079, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22870, 10663, NULL, 7079, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22875, 9680, NULL, 7081, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22876, 10667, NULL, 7081, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22877, 10668, NULL, 7081, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22878, 10669, NULL, 7081, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22883, 10671, NULL, 7083, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22884, 10672, NULL, 7083, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22885, 2506, NULL, 7083, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22886, 10673, NULL, 7084, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22887, 3639, NULL, 7084, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22888, 9253, NULL, 7084, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22891, 10676, NULL, 7086, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22892, 10677, NULL, 7086, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22900, 10679, NULL, 7088, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22901, 10680, NULL, 7088, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22902, 9024, NULL, 7088, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22903, 10681, NULL, 7088, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22904, 10682, NULL, 7089, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22905, 10683, NULL, 7089, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22906, 10684, NULL, 7089, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22911, 10686, NULL, 7091, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22912, 10687, NULL, 7091, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22913, 10688, NULL, 7092, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22914, 8456, NULL, 7092, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22915, 10689, NULL, 7092, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22916, 10690, NULL, 7092, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22917, 10691, NULL, 7093, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22890, 10675, NULL, 7085, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22889, 10674, NULL, 7085, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22795, 10623, NULL, 7060, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22794, 2516, NULL, 7060, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22792, 1527, NULL, 7060, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22918, 9325, NULL, 7093, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22919, 5600, NULL, 7093, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22920, 3433, NULL, 7094, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22921, 10692, NULL, 7094, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22922, 3724, NULL, 7094, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22923, 295, NULL, 7094, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22924, 7020, NULL, 7094, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22925, 807, NULL, 7095, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22926, 2431, NULL, 7095, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22927, 2078, NULL, 7095, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22928, 3470, NULL, 7095, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22929, 10693, NULL, 7096, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22930, 450, NULL, 7097, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22931, 1149, NULL, 7097, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22932, 1853, NULL, 7098, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22933, 2110, NULL, 7098, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22934, 3159, NULL, 7098, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22935, 497, NULL, 7099, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22936, 382, NULL, 7099, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22937, 4855, NULL, 7099, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22938, 685, NULL, 7099, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22939, 9798, NULL, 7100, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22940, 426, NULL, 7100, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22941, 5818, NULL, 7100, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22942, 10694, NULL, 7101, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22943, 10695, NULL, 7101, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22944, 10696, NULL, 7101, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22945, 10697, NULL, 7101, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22946, 3484, NULL, 7102, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22947, 3358, NULL, 7102, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22948, 942, NULL, 7102, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22949, 967, NULL, 7103, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22950, 5006, NULL, 7103, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22951, 1066, NULL, 7103, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22952, 3131, NULL, 7103, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22953, 1373, NULL, 7103, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22954, 4496, NULL, 7103, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22955, 1713, NULL, 7103, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (22956, 665, NULL, 7104, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22957, 5368, NULL, 7104, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22958, 2231, NULL, 7104, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22959, 2822, NULL, 7105, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22960, 1542, NULL, 7105, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22961, 283, NULL, 7105, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22837, 2616, NULL, 7070, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22962, 1721, NULL, 7106, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22963, 2511, NULL, 7106, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22964, 971, NULL, 7106, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22965, 3603, NULL, 7106, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22966, 3932, NULL, 7106, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22967, 857, NULL, 7106, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22968, 2536, NULL, 7106, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (22969, 4240, NULL, 7106, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (22970, 6819, NULL, 7106, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (22971, 10698, NULL, 7107, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22972, 6965, NULL, 7107, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22973, 7339, NULL, 7107, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22975, 1772, NULL, 7107, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22976, 1781, NULL, 7108, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22977, 1643, NULL, 7108, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22978, 429, NULL, 7108, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22979, 3812, NULL, 7109, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22980, 1998, NULL, 7109, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22981, 2802, NULL, 7110, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22982, 1331, NULL, 7110, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22983, 789, NULL, 7110, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22984, 4671, NULL, 7111, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22985, 1528, 50, 7111, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22986, 4853, NULL, 7111, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22987, 389, NULL, 7112, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22988, 3850, NULL, 7112, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22989, 4854, NULL, 7112, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22990, 1091, NULL, 7113, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22991, 586, NULL, 7114, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22992, 10699, NULL, 7114, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22993, 1942, NULL, 7114, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22994, 1424, NULL, 7115, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22995, 424, NULL, 7115, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22996, 4855, NULL, 7115, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22997, 1687, NULL, 7116, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22998, 1437, NULL, 7116, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22999, 3752, NULL, 7116, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23000, 807, NULL, 7117, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23001, 1091, NULL, 7117, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23002, 1261, NULL, 7117, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23003, 1875, NULL, 7118, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23004, 4856, NULL, 7118, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23005, 968, NULL, 7118, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23006, 2737, NULL, 7119, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23007, 1238, NULL, 7119, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23008, 337, NULL, 7119, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23009, 3638, NULL, 7120, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22841, 288, NULL, 7071, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22840, 10648, NULL, 7071, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22842, 10649, NULL, 7071, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22908, 8428, NULL, 7090, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22910, 10177, NULL, 7090, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22909, 9323, NULL, 7090, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22898, 108, NULL, 7087, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22894, 108, NULL, 7087, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22897, 3609, NULL, 7087, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22846, 1915, NULL, 7073, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22848, 4983, NULL, 7073, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22849, 3789, NULL, 7073, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22847, 10652, NULL, 7073, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22859, 1235, NULL, 7076, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22858, 1289, NULL, 7076, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22801, 9696, NULL, 7062, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22800, 10864, NULL, 7062, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23010, 4857, NULL, 7120, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23011, 3315, NULL, 7121, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23012, 4858, NULL, 7121, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23013, 2232, NULL, 7121, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23014, 608, NULL, 7122, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23015, 6713, 204, 7122, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23016, 4859, NULL, 7122, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23017, 4083, NULL, 7123, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23018, 1390, NULL, 7123, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23019, 4861, NULL, 7123, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23020, 10700, NULL, 7124, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23021, 425, NULL, 7124, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23022, 10701, NULL, 7124, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23023, 1581, NULL, 7125, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23024, 2900, NULL, 7125, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23025, 644, NULL, 7125, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23026, 3545, 205, 7126, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23027, 829, NULL, 7126, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23028, 497, NULL, 7126, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23029, 694, NULL, 7127, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23030, 4578, 206, 7127, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23031, 2317, NULL, 7127, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23032, 694, NULL, 7128, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23033, 10702, NULL, 7128, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23034, 10703, NULL, 7128, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23035, 1691, NULL, 7129, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23036, 652, NULL, 7129, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23037, 5272, NULL, 7129, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23038, 753, NULL, 7129, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23039, 9584, NULL, 7130, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23040, 2199, NULL, 7130, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23041, 5312, NULL, 7130, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23042, 1929, NULL, 7130, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23043, 9286, NULL, 7131, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23044, 3020, NULL, 7131, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23045, 2176, NULL, 7131, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23046, 2832, NULL, 7132, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23047, 10704, NULL, 7132, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23048, 2929, NULL, 7132, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23049, 10705, NULL, 7132, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23050, 807, NULL, 7133, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23051, 5405, NULL, 7133, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23052, 10706, NULL, 7133, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23053, 10707, NULL, 7133, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23054, 9251, 207, 7133, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23055, 10708, NULL, 7133, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23056, 10709, NULL, 7133, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (23057, 2948, NULL, 7134, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23058, 3816, NULL, 7134, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23059, 10710, NULL, 7134, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23060, 10711, NULL, 7134, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23061, 9836, NULL, 7135, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23062, 1769, NULL, 7135, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23063, 6929, NULL, 7135, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23064, 7011, NULL, 7136, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23065, 10712, NULL, 7136, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23066, 10713, NULL, 7136, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23067, 10201, NULL, 7136, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23068, 476, NULL, 7137, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23069, 10714, NULL, 7137, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23070, 2218, NULL, 7137, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23071, 10715, NULL, 7137, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23072, 2155, NULL, 7138, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23073, 10716, NULL, 7138, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23074, 10717, NULL, 7138, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23075, 10718, NULL, 7138, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23076, 2466, NULL, 7139, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23077, 10719, NULL, 7139, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23078, 2470, NULL, 7139, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23079, 10720, NULL, 7139, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23080, 9006, NULL, 7140, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23081, 10721, NULL, 7140, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23082, 4872, NULL, 7140, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23083, 10722, NULL, 7140, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23084, 1096, NULL, 7141, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23085, 6777, NULL, 7141, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23086, 5466, NULL, 7141, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23087, 10723, NULL, 7141, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23088, 1389, NULL, 7142, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23089, 10724, NULL, 7142, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23090, 5767, NULL, 7142, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23091, 6489, NULL, 7142, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23093, 10726, NULL, 7143, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23094, 1875, NULL, 7143, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23095, 7204, NULL, 7143, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23096, 10727, NULL, 7144, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23097, 1146, NULL, 7144, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23098, 2788, NULL, 7144, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28617, 2067, NULL, 8900, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28654, 2065, NULL, 8908, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23099, 6462, NULL, 7144, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23100, 4301, 208, 7145, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23101, 10728, NULL, 7145, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23102, 10729, NULL, 7145, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23103, 9342, NULL, 7145, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23106, 4994, NULL, 7147, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23107, 10732, NULL, 7147, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23108, 2294, NULL, 7147, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23109, 2987, 194, 7147, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23110, 2340, NULL, 7147, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23111, 10733, NULL, 7148, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23112, 10734, NULL, 7148, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23113, 10735, NULL, 7148, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23114, 6216, NULL, 7148, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23118, 10737, NULL, 7150, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23119, 10738, NULL, 7150, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23120, 10739, NULL, 7151, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23121, 10740, NULL, 7151, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23122, 10741, NULL, 7151, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23123, 4877, NULL, 7151, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23124, 8241, 209, 7151, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23129, 10743, NULL, 7153, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23130, 765, NULL, 7153, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23131, 10744, NULL, 7153, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23132, 3853, NULL, 7153, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23137, 10745, NULL, 7155, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23138, 10746, NULL, 7155, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23139, 2993, NULL, 7155, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23140, 9674, NULL, 7155, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23141, 10747, NULL, 7156, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23142, 9934, NULL, 7156, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23143, 10005, NULL, 7156, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23144, 8169, 212, 7156, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23092, 1443, NULL, 7143, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23146, 2605, NULL, 7158, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23147, 4663, NULL, 7158, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23148, 5465, NULL, 7158, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23149, 2868, NULL, 7158, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32984, 2784, NULL, 10040, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32985, 13778, NULL, 10040, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32986, 8462, NULL, 10040, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32987, 5776, NULL, 10040, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32988, 13909, NULL, 10041, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32989, 13911, NULL, 10041, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32990, 13912, NULL, 10041, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32991, 5634, NULL, 10042, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32992, 536, NULL, 10042, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32993, 11068, NULL, 10042, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32994, 1711, NULL, 10042, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32995, 4475, NULL, 10044, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23164, 10757, NULL, 7163, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23163, 10756, NULL, 7163, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23162, 8847, NULL, 7163, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23150, 10749, NULL, 7159, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23153, 5036, NULL, 7160, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23151, 10750, NULL, 7160, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23154, 3013, NULL, 7160, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23167, 267, NULL, 7164, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23166, 5639, NULL, 7164, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23168, 857, NULL, 7164, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23171, 2829, NULL, 7165, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23172, 3315, NULL, 7165, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23173, 7857, NULL, 7165, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23175, 9684, NULL, 7166, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23177, 10759, NULL, 7166, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23176, 3836, NULL, 7166, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23174, 849, NULL, 7166, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23184, 7943, NULL, 7168, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23183, 10762, NULL, 7168, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23182, 674, NULL, 7168, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23185, 7718, NULL, 7168, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23186, 233, NULL, 7169, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23187, 10763, NULL, 7169, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23188, 10764, NULL, 7169, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23194, 2017, 141, 7171, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23196, 2118, NULL, 7171, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23155, 2680, NULL, 7161, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23156, 2943, NULL, 7161, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23157, 10295, NULL, 7161, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23127, 10742, NULL, 7152, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23125, 6384, 210, 7152, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23145, 10748, NULL, 7157, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23136, 2980, NULL, 7154, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23135, 6464, NULL, 7154, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23134, 1118, NULL, 7154, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23133, 1745, NULL, 7154, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23104, 10730, NULL, 7146, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23105, 10731, NULL, 7146, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23195, 2266, NULL, 7171, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23193, 1021, NULL, 7171, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23178, 10760, NULL, 7167, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23181, 10761, NULL, 7167, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23179, 10064, NULL, 7167, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23180, 10059, NULL, 7167, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23353, 333, NULL, 7213, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23355, 3192, NULL, 7213, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23354, 1816, NULL, 7213, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23356, 940, NULL, 7213, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23333, 8175, NULL, 7208, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23332, 1510, NULL, 7208, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32997, 13913, NULL, 10045, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32998, 9005, NULL, 10045, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32996, 753, NULL, 10045, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23363, 5979, NULL, 7215, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23361, 1264, NULL, 7215, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23362, 10774, NULL, 7215, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22694, 10578, NULL, 7032, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22697, 6373, NULL, 7032, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22695, 10579, NULL, 7032, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22696, 6376, NULL, 7032, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28678, 12150, NULL, 8914, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28679, 1445, NULL, 8914, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28683, 12153, NULL, 8915, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28682, 1600, NULL, 8915, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33145, 14000, NULL, 10245, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33146, 4907, NULL, 10245, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (593, 2652, NULL, 83, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (595, 2687, NULL, 83, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (440, 220, NULL, 40, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (442, 2332, NULL, 40, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (441, 2383, NULL, 40, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8545, 1745, NULL, 3462, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23307, 1977, NULL, 7202, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23309, 5623, NULL, 7202, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23310, 10772, NULL, 7202, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23311, 7, NULL, 7203, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23312, 5282, NULL, 7203, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23313, 972, NULL, 7203, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23314, 10074, NULL, 7203, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23315, 1352, NULL, 7204, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23316, 9376, NULL, 7204, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23317, 2369, NULL, 7204, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23318, 2906, NULL, 7204, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23319, 1881, NULL, 7205, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23320, 7094, NULL, 7205, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23321, 8608, NULL, 7205, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23322, 3870, NULL, 7205, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23323, 7511, NULL, 7205, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23324, 2862, NULL, 7206, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23325, 7486, NULL, 7206, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23326, 2937, NULL, 7206, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23327, 3885, NULL, 7206, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23328, 7436, NULL, 7207, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23329, 4365, NULL, 7207, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23330, 1455, NULL, 7207, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23331, 5260, NULL, 7207, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23334, 2654, NULL, 7209, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23335, 2118, NULL, 7209, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23336, 2144, NULL, 7209, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23337, 1823, NULL, 7209, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23338, 9059, NULL, 7209, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23339, 812, NULL, 7209, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23340, 9099, NULL, 7209, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (23341, 1648, NULL, 7210, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23342, 5667, NULL, 7210, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23343, 2039, NULL, 7210, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23344, 1896, NULL, 7210, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28632, 12115, NULL, 8904, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28631, 9672, NULL, 8904, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28630, 12113, NULL, 8904, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23345, 3271, NULL, 7211, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23346, 2210, NULL, 7211, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23347, 10773, NULL, 7211, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23348, 4381, NULL, 7211, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23349, 2279, 213, 7212, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23350, 2637, NULL, 7212, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23351, 423, NULL, 7212, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23352, 1725, NULL, 7212, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23357, 5581, NULL, 7214, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23358, 2624, NULL, 7214, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23359, 1084, NULL, 7214, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23360, 7494, NULL, 7214, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23364, 10775, NULL, 7216, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23365, 2952, NULL, 7216, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23366, 6208, NULL, 7216, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23367, 1628, NULL, 7216, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23368, 1937, NULL, 7217, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23369, 5308, NULL, 7217, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23370, 3199, NULL, 7217, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23371, 1179, NULL, 7217, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23372, 6462, NULL, 7217, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23373, 2696, NULL, 7218, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23374, 1644, NULL, 7218, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23375, 4516, NULL, 7218, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23376, 1052, NULL, 7218, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23377, 2634, NULL, 7219, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23378, 4379, NULL, 7219, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23379, 730, NULL, 7219, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23380, 256, NULL, 7219, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23381, 7107, NULL, 7220, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23382, 1000, NULL, 7221, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23383, 2545, NULL, 7221, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23384, 7502, NULL, 7221, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23385, 2136, NULL, 7222, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23386, 10776, NULL, 7222, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23389, 4095, NULL, 7224, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23390, 1141, NULL, 7225, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23391, 2434, NULL, 7225, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23392, 2306, NULL, 7225, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23393, 2645, NULL, 7226, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23394, 4368, NULL, 7226, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23395, 2818, NULL, 7226, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23396, 2106, NULL, 7227, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23397, 857, NULL, 7227, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23398, 1513, NULL, 7227, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23399, 1672, NULL, 7228, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23308, 6818, NULL, 7202, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23158, 10752, NULL, 7162, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23160, 10753, NULL, 7162, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23161, 10754, NULL, 7162, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23159, 10094, NULL, 7162, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (422, 1605, NULL, 317, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (694, 1943, NULL, 165, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (693, 164, NULL, 165, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1080, 1876, NULL, 327, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33107, 13989, NULL, 10234, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33105, 13891, NULL, 10234, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33104, 12171, NULL, 10234, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33106, 13376, NULL, 10234, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33109, 12697, NULL, 10235, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33111, 10370, NULL, 10235, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33110, 9278, NULL, 10235, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33108, 1264, NULL, 10235, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33113, 13786, NULL, 10236, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33116, 13993, NULL, 10236, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33115, 13992, NULL, 10236, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33117, 13994, NULL, 10237, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33118, 3290, NULL, 10237, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33120, 1266, NULL, 10237, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33119, 13625, NULL, 10237, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33121, 10660, NULL, 10238, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33124, 8501, NULL, 10238, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33123, 8500, NULL, 10238, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33122, 13995, NULL, 10238, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33125, 369, NULL, 10239, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33126, 1566, NULL, 10239, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33130, 13996, NULL, 10241, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33131, 13997, NULL, 10241, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33132, 13998, NULL, 10241, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33136, 13999, NULL, 10242, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33135, 8509, NULL, 10242, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33134, 8508, NULL, 10242, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33133, 9677, NULL, 10242, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33138, 2190, NULL, 10243, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33137, 12605, NULL, 10243, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33140, 8447, NULL, 10243, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33142, 8356, NULL, 10244, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33141, 8421, NULL, 10244, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33144, 13631, NULL, 10244, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33143, 9682, NULL, 10244, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33129, 269, NULL, 10240, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33127, 369, NULL, 10240, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33128, 1566, NULL, 10240, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23400, 49, NULL, 7228, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23401, 155, NULL, 7228, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23402, 1721, NULL, 7228, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19380, 333, NULL, 6100, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19391, 7283, NULL, 6100, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19392, 8019, NULL, 6100, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23303, 317, NULL, 7201, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23306, 2925, NULL, 7201, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23304, 2921, NULL, 7201, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32979, 11075, NULL, 10039, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32981, 13906, NULL, 10039, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32978, 13905, NULL, 10039, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23200, 6207, NULL, 7172, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23197, 5162, NULL, 7172, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23199, 8794, NULL, 7172, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23403, 7105, NULL, 7229, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23404, 3676, NULL, 7230, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23412, 10777, NULL, 7234, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23413, 8130, NULL, 7234, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23414, 1621, NULL, 7235, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23415, 200, NULL, 7235, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23416, 1376, NULL, 7235, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23417, 10778, NULL, 7236, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23418, 220, NULL, 7237, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23419, 2356, NULL, 7237, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23420, 2752, NULL, 7237, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23421, 7176, NULL, 7237, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23422, 2332, NULL, 7237, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23423, 10779, NULL, 7238, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23424, 9191, NULL, 7238, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23425, 1457, NULL, 7239, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23426, 2197, NULL, 7239, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23427, 5900, NULL, 7239, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23428, 10780, NULL, 7239, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23432, 7704, NULL, 7241, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23433, 10357, NULL, 7241, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23434, 9515, NULL, 7241, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23435, 8403, NULL, 7241, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23436, 10781, NULL, 7242, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23441, 10783, NULL, 7244, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23442, 10784, NULL, 7244, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23443, 10785, NULL, 7245, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23444, 10786, NULL, 7245, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23445, 2827, NULL, 7246, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23446, 4902, NULL, 7246, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23447, 2886, NULL, 7246, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23448, 10787, NULL, 7246, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23449, 5815, NULL, 7246, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23450, 10788, NULL, 7246, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23451, 10789, NULL, 7247, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23452, 4578, NULL, 7248, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23453, 2399, NULL, 7248, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23454, 2152, NULL, 7248, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23455, 1181, NULL, 7248, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23456, 589, NULL, 7248, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23457, 10738, NULL, 7249, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23458, 958, NULL, 7250, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23459, 4331, NULL, 7250, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23460, 1772, NULL, 7250, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23461, 750, NULL, 7250, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23462, 10790, NULL, 7251, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23463, 10791, NULL, 7251, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23464, 10792, NULL, 7252, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23465, 6345, NULL, 7253, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23466, 3744, NULL, 7253, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23467, 1154, NULL, 7254, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23468, 5373, NULL, 7254, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23469, 5372, NULL, 7254, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23470, 2231, NULL, 7254, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23471, 283, NULL, 7255, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23472, 2091, NULL, 7255, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23473, 1648, NULL, 7255, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23474, 2910, NULL, 7255, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23475, 4085, NULL, 7255, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23476, 3912, NULL, 7255, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23477, 10793, NULL, 7256, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23478, 55, NULL, 7256, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23479, 9539, NULL, 7256, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23480, 1911, NULL, 7256, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23481, 10794, NULL, 7257, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23482, 10319, NULL, 7257, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23483, 10795, NULL, 7257, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23484, 1462, NULL, 7258, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23485, 68, NULL, 7258, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23486, 336, NULL, 7258, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23487, 1528, NULL, 7259, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23388, 682, 214, 7223, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23387, 923, NULL, 7223, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23488, 5494, NULL, 7259, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23489, 3149, NULL, 7259, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23490, 750, NULL, 7259, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23491, 2270, NULL, 7260, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23492, 10796, NULL, 7261, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23493, 9931, NULL, 7261, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23494, 10797, NULL, 7261, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23495, 9544, NULL, 7262, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23496, 109, NULL, 7262, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23497, 2413, NULL, 7262, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23498, 403, NULL, 7262, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23499, 7560, NULL, 7262, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23500, 1542, NULL, 7262, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23501, 3832, NULL, 7262, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (23502, 10798, NULL, 7263, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23503, 10799, NULL, 7263, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23504, 77, NULL, 7263, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23505, 10800, NULL, 7263, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23506, 5634, NULL, 7264, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23507, 1818, NULL, 7264, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23508, 333, NULL, 7264, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23509, 1876, NULL, 7264, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23510, 1613, NULL, 7264, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23511, 10801, NULL, 7264, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23512, 3919, 215, 7264, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (23513, 1882, 42, 7265, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23514, 10802, NULL, 7265, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23515, 512, NULL, 7265, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23516, 644, NULL, 7265, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23517, 9557, NULL, 7266, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23518, 8182, NULL, 7266, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23519, 9558, NULL, 7266, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23520, 10803, NULL, 7266, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23521, 10804, NULL, 7266, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23522, 8183, NULL, 7267, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23523, 10805, NULL, 7267, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23524, 2920, NULL, 7267, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23525, 9589, NULL, 7268, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23526, 2879, NULL, 7268, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23527, 727, NULL, 7268, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23528, 2878, NULL, 7268, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23529, 757, NULL, 7269, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23530, 10806, NULL, 7269, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23531, 10807, NULL, 7269, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23532, 10808, NULL, 7269, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23533, 156, NULL, 7270, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23534, 1457, NULL, 7271, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23535, 2937, NULL, 7271, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23536, 10809, NULL, 7271, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23537, 1643, NULL, 7271, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23538, 1762, NULL, 7272, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23539, 10810, NULL, 7272, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23540, 9147, NULL, 7272, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23541, 10811, NULL, 7272, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23545, 2973, NULL, 7274, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23546, 10743, NULL, 7274, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23556, 3590, NULL, 7276, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23557, 2147, NULL, 7276, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23558, 476, NULL, 7276, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23559, 5701, NULL, 7276, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23560, 2846, NULL, 7277, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23561, 1905, NULL, 7277, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23562, 3190, NULL, 7277, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23563, 5188, 216, 7277, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23564, 2279, NULL, 7278, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23565, 6469, NULL, 7278, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23566, 6470, NULL, 7278, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23567, 6466, NULL, 7278, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23568, 722, NULL, 7279, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23569, 10189, NULL, 7279, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23570, 10813, NULL, 7279, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23571, 2748, NULL, 7279, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23572, 1744, NULL, 7280, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23573, 682, NULL, 7280, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23574, 2152, NULL, 7280, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23575, 10814, NULL, 7280, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23576, 10815, NULL, 7280, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23577, 1111, NULL, 7281, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23578, 5931, NULL, 7281, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23579, 425, NULL, 7281, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23580, 1313, NULL, 7281, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23581, 5, NULL, 7282, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23582, 10816, NULL, 7282, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23583, 913, NULL, 7282, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23584, 1080, NULL, 7282, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23405, 9988, NULL, 7231, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23585, 548, NULL, 7282, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23586, 4191, NULL, 7282, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23587, 372, NULL, 7282, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (23588, 206, NULL, 7283, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23589, 1392, NULL, 7283, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23590, 9334, NULL, 7283, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23591, 257, NULL, 7283, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23592, 958, NULL, 7284, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23593, 3029, NULL, 7284, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23594, 162, NULL, 7284, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23595, 4331, NULL, 7284, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23596, 173, NULL, 7285, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23597, 4136, NULL, 7285, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23598, 3199, NULL, 7285, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23599, 1424, NULL, 7285, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23600, 611, NULL, 7286, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23407, 892, NULL, 7232, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23406, 912, NULL, 7232, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23408, 1311, NULL, 7232, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23544, 1609, NULL, 7273, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23543, 1659, NULL, 7273, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23542, 1670, NULL, 7273, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23601, 97, NULL, 7286, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23602, 10817, NULL, 7286, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23603, 2010, NULL, 7286, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23604, 413, NULL, 7287, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23605, 1026, NULL, 7287, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23606, 2578, NULL, 7287, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23607, 8847, NULL, 7288, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23608, 2016, NULL, 7288, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23609, 1862, NULL, 7288, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23610, 7548, NULL, 7289, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23611, 6752, NULL, 7289, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23612, 5421, NULL, 7289, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23613, 4873, NULL, 7289, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23614, 128, NULL, 7290, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23615, 914, NULL, 7290, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23616, 503, NULL, 7290, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23617, 2662, NULL, 7290, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23618, 476, NULL, 7291, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23619, 915, NULL, 7291, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23620, 234, NULL, 7291, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23621, 1852, NULL, 7291, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23622, 1042, NULL, 7291, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23623, 2413, NULL, 7291, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23624, 4809, NULL, 7291, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (23625, 1662, NULL, 7292, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23626, 10818, NULL, 7292, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23627, 10766, NULL, 7292, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23628, 724, 217, 7292, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23629, 171, NULL, 7293, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23630, 10819, NULL, 7293, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23631, 10820, NULL, 7293, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23632, 188, NULL, 7293, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23636, 5011, NULL, 7295, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23637, 5303, NULL, 7295, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23638, 6695, 218, 7295, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23639, 10822, NULL, 7296, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23640, 10823, NULL, 7296, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23641, 1748, NULL, 7297, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23642, 1600, NULL, 7297, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23643, 1862, NULL, 7297, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23644, 10824, NULL, 7298, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23645, 6771, NULL, 7299, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23646, 6772, NULL, 7299, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23647, 4653, 219, 7300, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23648, 10825, NULL, 7300, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23649, 10826, NULL, 7300, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23650, 10827, NULL, 7301, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23651, 10828, NULL, 7301, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23652, 10829, NULL, 7302, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23653, 10830, NULL, 7303, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23654, 1821, NULL, 7304, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23655, 4737, 220, 7304, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23656, 607, NULL, 7304, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23657, 10831, NULL, 7305, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23658, 10832, NULL, 7305, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23659, 10833, NULL, 7306, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23660, 10834, NULL, 7306, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23661, 10835, NULL, 7306, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23662, 10836, NULL, 7307, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23663, 6485, NULL, 7308, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23664, 3086, NULL, 7309, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23665, 1102, 221, 7309, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23666, 858, NULL, 7309, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23667, 10837, NULL, 7309, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23668, 1748, NULL, 7310, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23669, 2554, NULL, 7310, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23670, 5308, NULL, 7310, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23671, 3682, NULL, 7310, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23672, 292, NULL, 7311, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23673, 1052, NULL, 7311, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23674, 6740, NULL, 7311, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23675, 9429, NULL, 7311, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23676, 10838, NULL, 7312, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23677, 10839, NULL, 7312, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23678, 10840, NULL, 7312, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23683, 10842, NULL, 7314, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23684, 10843, NULL, 7314, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23685, 10844, NULL, 7314, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23686, 9046, NULL, 7314, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23687, 10845, NULL, 7315, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23688, 10846, NULL, 7315, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23689, 10847, NULL, 7315, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23690, 10848, NULL, 7315, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23693, 3015, NULL, 7317, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23694, 1687, NULL, 7317, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23695, 765, NULL, 7317, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23696, 10851, NULL, 7317, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23697, 10852, NULL, 7318, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23698, 10853, NULL, 7318, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23699, 10854, NULL, 7318, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23700, 10855, NULL, 7318, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32999, 8154, NULL, 10046, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33000, 289, NULL, 10046, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33001, 789, NULL, 10046, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23705, 10858, NULL, 7320, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23706, 10859, NULL, 7320, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23707, 2212, NULL, 7321, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23708, 3067, NULL, 7321, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23709, 2967, NULL, 7321, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23710, 6922, NULL, 7321, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23711, 10860, NULL, 7322, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23712, 10861, NULL, 7322, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23713, 10862, NULL, 7322, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23714, 10863, NULL, 7322, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23715, 3394, NULL, 7323, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23716, 1566, NULL, 7323, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23717, 4779, NULL, 7323, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23718, 1582, NULL, 7323, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23719, 10864, NULL, 7324, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23720, 365, NULL, 7324, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23721, 6980, NULL, 7324, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23722, 10865, NULL, 7324, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23723, 9484, NULL, 7325, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23724, 8037, NULL, 7325, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23725, 2161, NULL, 7325, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23726, 501, NULL, 7325, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23727, 7705, NULL, 7326, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23728, 1379, NULL, 7326, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23729, 5151, NULL, 7326, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23730, 5018, 222, 7326, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23731, 10866, NULL, 7327, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23732, 2150, NULL, 7327, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23733, 10867, NULL, 7327, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23734, 4817, NULL, 7327, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23735, 2952, NULL, 7328, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23736, 2992, NULL, 7328, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23737, 7131, NULL, 7328, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23738, 2993, NULL, 7328, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23739, 10711, NULL, 7329, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23740, 10868, NULL, 7329, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23741, 10869, NULL, 7329, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23742, 2120, NULL, 7329, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23743, 10870, NULL, 7330, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23744, 503, NULL, 7330, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23745, 2498, NULL, 7330, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23746, 1385, NULL, 7330, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23747, 10254, NULL, 7331, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23748, 10871, NULL, 7331, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23749, 6681, NULL, 7331, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23750, 10872, NULL, 7331, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23751, 7706, NULL, 7332, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23752, 1269, NULL, 7332, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23753, 10873, NULL, 7332, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23754, 1349, NULL, 7332, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23755, 9454, NULL, 7333, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23756, 9613, NULL, 7333, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23757, 10873, 223, 7333, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23758, 10874, NULL, 7333, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23759, 10875, NULL, 7334, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23760, 4878, 224, 7334, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23761, 845, NULL, 7334, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23762, 5315, NULL, 7334, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23763, 9854, NULL, 7335, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23764, 3463, NULL, 7335, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23765, 5490, NULL, 7335, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23766, 10876, NULL, 7336, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23767, 10877, NULL, 7336, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23768, 10878, NULL, 7336, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23769, 2180, NULL, 7336, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23770, 10879, NULL, 7337, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23771, 6272, NULL, 7337, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23776, 7704, NULL, 7339, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23777, 51, NULL, 7339, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23778, 5282, NULL, 7339, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23779, 4996, NULL, 7339, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23780, 1352, NULL, 7340, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23781, 3257, NULL, 7340, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23782, 3767, NULL, 7340, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23783, 996, NULL, 7340, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23784, 2559, NULL, 7340, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23785, 2038, NULL, 7340, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23786, 1618, NULL, 7340, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (23787, 423, NULL, 7340, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (23788, 2312, NULL, 7341, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23789, 68, NULL, 7341, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23790, 10880, NULL, 7342, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23791, 1600, NULL, 7342, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23792, 688, NULL, 7342, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23793, 1334, NULL, 7342, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23794, 10881, NULL, 7343, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23795, 10882, NULL, 7343, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23796, 7549, NULL, 7343, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23797, 168, NULL, 7343, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23798, 2187, NULL, 7344, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23799, 7707, NULL, 7344, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23800, 9679, NULL, 7344, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23801, 6732, NULL, 7344, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23802, 10883, NULL, 7345, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23803, 2554, NULL, 7345, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23804, 1748, 225, 7345, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23805, 3199, NULL, 7345, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23806, 10884, NULL, 7346, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23807, 6005, NULL, 7346, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23808, 10885, NULL, 7346, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23809, 1823, NULL, 7346, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23810, 1445, NULL, 7346, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23811, 1542, NULL, 7346, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23812, 2623, NULL, 7346, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (23813, 403, NULL, 7346, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (23814, 10886, NULL, 7347, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23815, 1219, NULL, 7347, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23816, 425, NULL, 7347, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23817, 2336, NULL, 7347, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23818, 10887, NULL, 7347, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23819, 661, NULL, 7347, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23820, 10888, NULL, 7347, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (23821, 5109, NULL, 7347, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (23822, 10889, NULL, 7348, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23823, 7128, NULL, 7348, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23824, 5666, NULL, 7348, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23825, 8985, NULL, 7348, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23826, 10359, NULL, 7348, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23827, 2981, NULL, 7348, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23828, 8163, NULL, 7348, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (23829, 10890, NULL, 7348, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (23830, 333, NULL, 7349, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23831, 2805, NULL, 7349, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23832, 2904, NULL, 7349, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23833, 209, 22, 7349, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23928, 121, NULL, 7375, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23835, 1687, NULL, 7349, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23836, 10891, NULL, 7350, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23837, 2531, NULL, 7350, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23838, 3884, NULL, 7350, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23839, 812, NULL, 7350, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23840, 10892, NULL, 7351, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23841, 3631, NULL, 7351, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23842, 792, NULL, 7351, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23843, 4677, NULL, 7351, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23844, 1086, NULL, 7352, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23845, 3192, NULL, 7352, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23846, 4500, NULL, 7352, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23847, 809, NULL, 7352, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23848, 10893, NULL, 7353, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23849, 1578, NULL, 7353, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23850, 1184, NULL, 7353, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23851, 10894, NULL, 7354, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23852, 556, NULL, 7354, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23853, 2850, NULL, 7354, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23854, 3942, NULL, 7354, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23855, 10895, NULL, 7355, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23856, 78, NULL, 7355, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23857, 1241, NULL, 7355, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23858, 2538, NULL, 7355, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23859, 1665, NULL, 7356, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23691, 10849, NULL, 7316, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23692, 10850, NULL, 7316, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23860, 3572, NULL, 7356, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23861, 9520, NULL, 7356, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23862, 1052, NULL, 7356, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23863, 1821, NULL, 7357, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23864, 1426, NULL, 7357, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23865, 5207, NULL, 7357, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23866, 3682, NULL, 7357, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23867, 10896, NULL, 7358, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23868, 3003, NULL, 7359, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23869, 4727, NULL, 7359, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23870, 1373, NULL, 7359, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23871, 4656, NULL, 7359, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23872, 872, NULL, 7360, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23873, 688, NULL, 7360, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23874, 1505, NULL, 7360, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23875, 312, NULL, 7360, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23876, 10897, NULL, 7361, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23877, 311, NULL, 7362, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23878, 1279, NULL, 7362, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23879, 10898, NULL, 7363, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23880, 987, NULL, 7363, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23881, 2874, NULL, 7363, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23882, 10899, NULL, 7363, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23883, 6908, NULL, 7363, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23884, 1582, NULL, 7364, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23885, 4404, NULL, 7364, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23886, 3394, NULL, 7364, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23887, 4779, NULL, 7364, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23888, 6254, NULL, 7365, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23889, 10900, NULL, 7365, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23896, 10903, NULL, 7367, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23897, 10904, NULL, 7367, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23898, 10905, NULL, 7367, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23899, 10906, NULL, 7367, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23900, 555, NULL, 7367, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23901, 10907, NULL, 7368, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23902, 10908, NULL, 7368, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23903, 5871, NULL, 7369, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23904, 10909, NULL, 7369, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23905, 10910, NULL, 7369, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23906, 10911, NULL, 7369, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23907, 6530, NULL, 7370, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23908, 2707, NULL, 7370, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23909, 691, NULL, 7370, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23910, 5501, NULL, 7370, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23911, 2814, NULL, 7371, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23912, 10912, NULL, 7371, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23913, 10913, NULL, 7371, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23914, 10914, NULL, 7371, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23915, 5953, NULL, 7372, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23916, 7554, NULL, 7372, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23917, 10915, NULL, 7372, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23918, 4522, NULL, 7372, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23919, 819, NULL, 7373, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23920, 952, NULL, 7373, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23921, 10916, NULL, 7373, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23922, 10917, NULL, 7373, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23923, 10918, NULL, 7374, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23924, 1971, NULL, 7374, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23925, 2456, NULL, 7374, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23931, 1198, NULL, 7376, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23932, 2532, NULL, 7376, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23933, 2605, NULL, 7376, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23934, 3713, NULL, 7377, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23935, 10859, NULL, 7377, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23936, 10858, NULL, 7377, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23937, 10921, NULL, 7377, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23938, 7323, NULL, 7378, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23939, 9597, NULL, 7378, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23940, 7323, NULL, 7379, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23941, 2805, NULL, 7379, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23942, 4237, NULL, 7379, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23943, 7549, NULL, 7380, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23944, 146, NULL, 7380, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23945, 5853, NULL, 7380, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23946, 3682, NULL, 7380, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23947, 68, NULL, 7381, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23948, 5215, NULL, 7381, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23949, 1294, NULL, 7381, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23950, 2985, NULL, 7381, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23951, 4842, NULL, 7381, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23952, 2316, NULL, 7381, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (33002, 13914, NULL, 10046, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23775, 4907, NULL, 7338, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23834, 6945, 433, 7349, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23772, 4907, NULL, 7338, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23774, 7130, NULL, 7338, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32703, 10954, NULL, 10135, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32705, 8804, NULL, 10135, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32704, 3061, NULL, 10135, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32702, 13388, NULL, 10135, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33003, 687, NULL, 10203, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24497, 1419, NULL, 7571, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23958, 514, NULL, 7383, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23959, 9098, NULL, 7383, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23960, 376, NULL, 7383, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23961, 2937, NULL, 7383, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23962, 2525, NULL, 7384, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23963, 2957, NULL, 7384, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23964, 1857, NULL, 7384, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23965, 1334, NULL, 7384, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23966, 6343, NULL, 7385, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23967, 10057, NULL, 7386, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23968, 4103, NULL, 7386, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23969, 3150, NULL, 7386, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23970, 10057, NULL, 7387, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23971, 5390, 187, 7387, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23972, 1241, NULL, 7387, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23973, 736, NULL, 7388, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23974, 4350, NULL, 7388, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23975, 3199, NULL, 7388, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23976, 2921, NULL, 7388, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23977, 588, NULL, 7389, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23978, 10438, NULL, 7389, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23979, 3093, NULL, 7389, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23980, 2321, NULL, 7389, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23981, 5201, NULL, 7389, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23982, 2563, NULL, 7389, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23983, 7560, NULL, 7389, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (23984, 441, NULL, 7390, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23985, 5165, NULL, 7390, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23986, 2957, NULL, 7390, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23987, 4738, NULL, 7390, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23988, 1390, NULL, 7391, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23989, 4612, NULL, 7391, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23990, 687, NULL, 7391, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23991, 791, NULL, 7392, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23992, 2416, NULL, 7392, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23993, 147, NULL, 7392, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23994, 318, NULL, 7393, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23995, 10922, NULL, 7393, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23996, 7344, 226, 7393, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23997, 6764, NULL, 7394, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23998, 1208, NULL, 7394, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23999, 2631, NULL, 7394, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24000, 982, NULL, 7395, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24001, 9002, NULL, 7395, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24002, 697, NULL, 7395, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24003, 1834, NULL, 7396, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24004, 624, NULL, 7396, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24005, 3390, 227, 7396, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24006, 10923, NULL, 7397, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24007, 3179, NULL, 7398, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24008, 96, NULL, 7398, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24009, 5073, NULL, 7399, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24010, 1415, NULL, 7399, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24011, 6740, NULL, 7399, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24012, 749, NULL, 7400, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24013, 1536, NULL, 7400, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24014, 6962, NULL, 7400, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24018, 932, NULL, 7402, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24019, 78, NULL, 7402, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24020, 10924, NULL, 7402, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24021, 1091, NULL, 7403, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24022, 6876, NULL, 7403, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24024, 1624, NULL, 7404, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24025, 4132, NULL, 7404, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24026, 1389, NULL, 7405, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24027, 649, NULL, 7405, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24028, 2042, NULL, 7405, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24029, 1448, NULL, 7406, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24030, 1374, NULL, 7406, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24031, 10925, NULL, 7407, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24032, 1880, NULL, 7408, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24033, 10211, NULL, 7408, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24034, 761, NULL, 7408, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24035, 4833, NULL, 7408, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24036, 10926, NULL, 7409, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24037, 5816, NULL, 7409, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24038, 1629, NULL, 7409, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24039, 3224, NULL, 7409, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24040, 10927, NULL, 7410, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24041, 10928, NULL, 7411, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24042, 6844, NULL, 7412, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24043, 10929, NULL, 7412, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24044, 10930, NULL, 7412, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24045, 10931, NULL, 7412, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24046, 10932, NULL, 7413, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24047, 10933, NULL, 7414, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24048, 613, NULL, 7415, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24049, 544, NULL, 7415, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24050, 2985, NULL, 7415, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24051, 2163, NULL, 7415, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24052, 10934, NULL, 7416, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24053, 7876, NULL, 7417, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24054, 10935, NULL, 7417, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24055, 2972, NULL, 7417, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24056, 2912, NULL, 7417, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24057, 10936, NULL, 7418, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24058, 10937, NULL, 7418, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24059, 10938, NULL, 7418, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24060, 10939, NULL, 7419, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24061, 10940, NULL, 7420, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24062, 3477, NULL, 7420, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24063, 10941, NULL, 7420, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24064, 10942, NULL, 7420, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24065, 10943, NULL, 7421, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24066, 1077, NULL, 7421, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23926, 1861, NULL, 7374, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24067, 584, NULL, 7421, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24068, 2113, NULL, 7422, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24069, 10944, NULL, 7422, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24070, 8165, NULL, 7422, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24071, 1744, NULL, 7422, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24072, 374, NULL, 7423, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24073, 2399, NULL, 7423, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24074, 6268, NULL, 7423, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24078, 1535, NULL, 7425, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24079, 3874, 229, 7425, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24080, 935, NULL, 7425, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24081, 3383, NULL, 7426, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24082, 73, NULL, 7426, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24083, 220, NULL, 7427, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24084, 3013, NULL, 7427, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24085, 3600, NULL, 7428, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24086, 2492, NULL, 7428, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24087, 914, NULL, 7428, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24088, 678, NULL, 7429, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24089, 1155, NULL, 7429, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24090, 2624, NULL, 7429, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24094, 1593, NULL, 7431, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24095, 1238, NULL, 7431, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24096, 1241, 230, 7431, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24097, 10945, NULL, 7432, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24098, 4436, NULL, 7432, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24099, 2706, NULL, 7433, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24100, 1112, NULL, 7433, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24101, 1970, NULL, 7433, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24102, 755, NULL, 7434, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24103, 1732, 65, 7434, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24104, 1179, NULL, 7434, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24105, 5620, NULL, 7435, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24106, 6776, NULL, 7435, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24107, 6136, NULL, 7435, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24108, 152, NULL, 7436, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24109, 6778, NULL, 7436, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24110, 6336, NULL, 7437, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24111, 5499, NULL, 7437, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24112, 6393, NULL, 7437, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24113, 588, NULL, 7438, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24114, 4277, NULL, 7438, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24115, 6777, NULL, 7438, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24116, 2055, 39, 7439, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24117, 452, NULL, 7439, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24118, 649, NULL, 7439, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24119, 10946, NULL, 7440, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24120, 2289, NULL, 7440, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24121, 425, NULL, 7440, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24122, 3919, NULL, 7441, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24123, 6607, NULL, 7441, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24124, 1799, NULL, 7441, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24125, 939, NULL, 7442, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24126, 510, NULL, 7442, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24127, 2436, NULL, 7442, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24132, 2761, NULL, 7444, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24133, 10947, NULL, 7444, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24134, 378, NULL, 7444, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24135, 2910, NULL, 7444, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24136, 430, NULL, 7445, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24137, 119, NULL, 7445, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24138, 6672, NULL, 7445, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24015, 5545, NULL, 7401, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24016, 4323, NULL, 7401, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24017, 2545, NULL, 7401, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33004, 13915, NULL, 10203, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24142, 2313, NULL, 7447, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24143, 10948, NULL, 7448, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24144, 408, NULL, 7449, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24145, 1112, NULL, 7449, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24146, 1970, NULL, 7449, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24147, 6218, NULL, 7450, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24148, 5306, NULL, 7450, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24149, 2822, NULL, 7450, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24150, 1041, NULL, 7451, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24151, 1111, NULL, 7451, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24152, 196, NULL, 7451, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24153, 4420, NULL, 7452, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24154, 10949, NULL, 7452, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24155, 6690, NULL, 7452, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33005, 1424, NULL, 10203, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33006, 104, NULL, 10203, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32936, 1526, NULL, 10201, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24159, 10950, NULL, 7454, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24160, 1021, NULL, 7455, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24161, 3033, NULL, 7455, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24162, 1814, NULL, 7455, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24163, 10951, NULL, 7456, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24164, 400, NULL, 7456, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24165, 1198, NULL, 7457, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24166, 9434, NULL, 7457, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24167, 1283, NULL, 7458, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24168, 1042, NULL, 7458, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24128, 5541, NULL, 7443, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24131, 502, NULL, 7443, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24130, 1553, NULL, 7443, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24091, 4034, NULL, 7430, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24092, 4740, NULL, 7430, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24093, 6523, NULL, 7430, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24169, 1825, NULL, 7458, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24170, 1450, NULL, 7459, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24171, 1880, NULL, 7459, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24172, 299, NULL, 7459, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24173, 5211, NULL, 7460, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24174, 6409, NULL, 7460, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24175, 773, NULL, 7461, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24176, 2489, NULL, 7461, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24177, 2077, NULL, 7461, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24178, 350, NULL, 7462, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24179, 1528, NULL, 7462, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24180, 4543, NULL, 7462, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24181, 1295, NULL, 7463, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24182, 2561, NULL, 7463, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24183, 3438, NULL, 7463, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24184, 1839, NULL, 7464, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24185, 1561, NULL, 7464, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24186, 106, NULL, 7464, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24187, 1592, NULL, 7465, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24188, 594, NULL, 7465, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24189, 1379, NULL, 7465, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24190, 761, NULL, 7466, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24191, 2411, NULL, 7466, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24192, 810, NULL, 7467, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24193, 1311, NULL, 7467, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24194, 974, NULL, 7467, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24195, 753, NULL, 7468, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24196, 2063, NULL, 7468, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24197, 1112, NULL, 7468, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24199, 345, NULL, 7470, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24200, 6266, NULL, 7470, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24201, 3521, NULL, 7471, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24202, 2155, NULL, 7471, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24203, 1741, NULL, 7472, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24204, 7450, NULL, 7473, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24205, 6046, NULL, 7473, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24206, 5371, NULL, 7473, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24207, 10952, NULL, 7474, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24208, 2730, NULL, 7474, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24209, 121, NULL, 7475, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24210, 3140, NULL, 7475, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24211, 3014, NULL, 7475, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24213, 3665, NULL, 7476, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24214, 10953, NULL, 7477, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24215, 816, NULL, 7477, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24216, 1586, NULL, 7478, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24217, 1101, NULL, 7478, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24218, 360, NULL, 7479, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24219, 10954, NULL, 7479, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24220, 10955, NULL, 7479, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24221, 10956, NULL, 7479, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24222, 10866, NULL, 7480, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24223, 10957, NULL, 7480, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24224, 1719, NULL, 7480, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24225, 5525, NULL, 7480, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24226, 419, NULL, 7481, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24227, 10958, NULL, 7481, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24228, 10959, NULL, 7481, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24229, 2369, NULL, 7481, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24230, 10960, NULL, 7482, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24231, 81, NULL, 7483, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24232, 955, NULL, 7483, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24233, 1406, NULL, 7483, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24234, 2482, NULL, 7483, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24235, 1683, NULL, 7484, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24236, 1585, NULL, 7484, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24237, 812, NULL, 7484, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24238, 10961, NULL, 7485, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24239, 10962, NULL, 7485, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24240, 10963, NULL, 7485, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24241, 10964, NULL, 7485, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24242, 7552, NULL, 7486, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24243, 7553, NULL, 7486, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24244, 9482, NULL, 7487, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24245, 10965, NULL, 7487, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24250, 937, NULL, 7489, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24251, 2886, NULL, 7489, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24252, 4781, NULL, 7489, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24253, 2188, NULL, 7489, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24254, 587, NULL, 7490, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24255, 3719, NULL, 7491, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24256, 4042, NULL, 7491, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24257, 5359, NULL, 7491, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24258, 2365, NULL, 7491, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24259, 9484, NULL, 7492, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24260, 2985, NULL, 7492, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24261, 10967, NULL, 7492, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24262, 10968, NULL, 7492, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24263, 533, NULL, 7493, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24264, 3848, NULL, 7493, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24265, 975, NULL, 7493, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24266, 10969, NULL, 7493, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24267, 757, NULL, 7494, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24269, 10970, NULL, 7494, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24270, 10971, NULL, 7494, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24271, 220, NULL, 7494, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24272, 432, NULL, 7495, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24273, 1026, 231, 7495, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24274, 1041, NULL, 7496, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24275, 7932, NULL, 7496, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24276, 2920, NULL, 7497, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24277, 1042, NULL, 7497, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24278, 761, NULL, 7498, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24279, 1223, NULL, 7498, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24280, 1186, NULL, 7499, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24281, 10972, NULL, 7499, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24282, 430, NULL, 7500, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24283, 100, NULL, 7500, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24284, 480, NULL, 7500, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24285, 1592, NULL, 7501, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24286, 536, NULL, 7501, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24287, 382, NULL, 7502, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24288, 702, NULL, 7502, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24289, 1283, NULL, 7503, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24290, 305, NULL, 7503, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24291, 622, NULL, 7504, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24292, 2572, NULL, 7504, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24293, 1257, NULL, 7505, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24294, 1542, NULL, 7505, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24295, 1593, NULL, 7506, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24296, 2737, NULL, 7506, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24297, 9432, NULL, 7506, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24298, 183, NULL, 7507, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24299, 2816, NULL, 7507, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24300, 1741, NULL, 7508, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24301, 1423, NULL, 7508, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24302, 1046, NULL, 7509, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24303, 1624, NULL, 7509, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24304, 1458, NULL, 7510, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24305, 955, NULL, 7510, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24306, 9466, NULL, 7511, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24307, 8132, NULL, 7511, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24308, 1902, NULL, 7512, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24309, 2900, NULL, 7512, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24310, 6092, NULL, 7513, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24311, 2598, NULL, 7513, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24312, 4988, NULL, 7513, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24313, 979, NULL, 7514, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24314, 1600, NULL, 7514, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24315, 2662, NULL, 7514, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24316, 19, NULL, 7514, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24317, 1184, NULL, 7515, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24318, 6206, NULL, 7515, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24321, 1875, NULL, 7517, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24322, 1687, NULL, 7517, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24323, 90, NULL, 7517, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24324, 10295, NULL, 7517, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24325, 987, NULL, 7518, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24268, 1648, 478, 7494, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24326, 10973, NULL, 7518, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24327, 1125, NULL, 7518, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24328, 3513, NULL, 7519, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24329, 1821, NULL, 7519, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24331, 3779, NULL, 7519, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24332, 8855, NULL, 7520, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24333, 10974, NULL, 7521, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24334, 200, NULL, 7521, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24338, 389, NULL, 7523, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24339, 978, NULL, 7523, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24340, 423, 63, 7523, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24341, 10975, NULL, 7523, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24342, 2490, NULL, 7524, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24343, 577, NULL, 7524, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24344, 10976, NULL, 7524, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24345, 534, NULL, 7525, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24346, 10977, NULL, 7525, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24347, 10978, NULL, 7525, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24348, 2945, NULL, 7525, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24349, 10979, NULL, 7526, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24350, 1458, NULL, 7527, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24353, 833, NULL, 7528, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24354, 1527, NULL, 7528, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24355, 1431, NULL, 7528, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24357, 128, NULL, 7529, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24358, 1778, NULL, 7529, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24359, 10981, NULL, 7530, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24360, 10982, NULL, 7530, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24361, 10983, NULL, 7530, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24362, 10984, NULL, 7530, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24319, 6898, NULL, 7516, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24320, 2646, NULL, 7516, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24363, 2696, NULL, 7531, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24364, 586, NULL, 7531, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24365, 10985, NULL, 7532, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24366, 5205, NULL, 7532, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24367, 1772, NULL, 7532, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24368, 756, NULL, 7532, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24376, 5112, NULL, 7535, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24377, 73, NULL, 7536, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24378, 10990, NULL, 7536, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24379, 2576, NULL, 7536, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24380, 2719, NULL, 7537, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24381, 4987, NULL, 7537, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24382, 10991, NULL, 7537, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24387, 685, NULL, 7539, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24388, 1834, NULL, 7539, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24389, 1091, NULL, 7539, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24390, 1503, NULL, 7539, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24391, 10993, NULL, 7539, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24392, 424, NULL, 7539, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (24393, 448, NULL, 7540, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24394, 1541, NULL, 7540, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24395, 378, NULL, 7540, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24396, 183, NULL, 7541, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24397, 1026, NULL, 7541, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24398, 182, NULL, 7541, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24399, 2645, NULL, 7542, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24400, 4988, NULL, 7542, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24401, 761, NULL, 7543, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24402, 1565, NULL, 7543, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24403, 1628, NULL, 7543, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24404, 1562, NULL, 7543, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24405, 588, NULL, 7544, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24406, 771, NULL, 7544, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24407, 2270, NULL, 7545, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24408, 1123, NULL, 7545, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24409, 1458, NULL, 7546, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24410, 955, NULL, 7546, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24411, 1962, NULL, 7546, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24412, 6337, NULL, 7547, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24413, 5036, NULL, 7547, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24414, 2899, NULL, 7547, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24415, 5237, NULL, 7548, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24416, 5066, NULL, 7548, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24417, 5196, NULL, 7548, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24418, 2129, NULL, 7549, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24335, 357, 581, 7522, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24336, 671, NULL, 7522, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24337, 1331, NULL, 7522, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24386, 10992, NULL, 7538, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24384, 6676, NULL, 7538, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24385, 1235, NULL, 7538, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24419, 5262, NULL, 7549, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24420, 6128, NULL, 7550, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24421, 2945, NULL, 7551, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24422, 156, NULL, 7552, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24423, 236, NULL, 7553, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24424, 1006, NULL, 7553, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24425, 1781, NULL, 7553, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24426, 652, NULL, 7553, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24427, 650, NULL, 7554, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24428, 2430, NULL, 7554, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24429, 497, NULL, 7554, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24430, 220, NULL, 7554, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24431, 4018, NULL, 7555, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24432, 4971, NULL, 7555, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24433, 1721, NULL, 7556, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24351, 4002, NULL, 7527, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24352, 2761, NULL, 7527, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24434, 1503, NULL, 7556, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24435, 4040, NULL, 7556, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24436, 1329, 5, 7556, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24437, 1331, NULL, 7556, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24438, 2988, NULL, 7556, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (24439, 857, NULL, 7556, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (24440, 49, NULL, 7556, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (24441, 289, NULL, 7556, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (24442, 2880, NULL, 7557, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24443, 3003, NULL, 7558, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24444, 2696, NULL, 7558, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24445, 1686, NULL, 7558, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24446, 4656, NULL, 7558, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24447, 457, NULL, 7559, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24448, 10978, NULL, 7559, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24449, 10994, NULL, 7559, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24450, 4039, NULL, 7559, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24451, 1373, NULL, 7560, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24452, 10995, NULL, 7560, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24453, 362, NULL, 7560, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24454, 556, NULL, 7560, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24455, 850, NULL, 7561, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24456, 384, NULL, 7561, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24457, 673, 233, 7561, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24458, 2818, NULL, 7561, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24459, 226, NULL, 7562, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24460, 1832, NULL, 7562, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24461, 687, 234, 7562, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24462, 1066, NULL, 7562, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24463, 624, NULL, 7563, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24464, 9070, 235, 7563, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24465, 5123, NULL, 7563, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24466, 1673, NULL, 7563, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24467, 2706, NULL, 7564, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24468, 2918, NULL, 7564, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24469, 10996, NULL, 7564, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24470, 932, NULL, 7564, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24471, 1374, NULL, 7565, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24472, 613, NULL, 7565, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24473, 4382, NULL, 7565, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24474, 10997, NULL, 7565, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24475, 4727, 236, 7565, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24476, 967, NULL, 7566, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24478, 6133, NULL, 7566, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24479, 5650, NULL, 7566, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24480, 472, NULL, 7567, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24481, 388, NULL, 7567, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24482, 1596, NULL, 7567, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24483, 1435, 237, 7567, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24488, 6273, NULL, 7569, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24489, 5115, NULL, 7569, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24490, 10999, NULL, 7569, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24499, 11002, NULL, 7572, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24500, 1080, NULL, 7572, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24501, 2577, NULL, 7572, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24502, 11003, NULL, 7572, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24503, 2555, NULL, 7573, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24504, 11004, NULL, 7573, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24505, 1924, NULL, 7573, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24506, 858, NULL, 7573, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24496, 11001, NULL, 7571, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24498, 1393, NULL, 7571, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24495, 1418, NULL, 7571, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33007, 4481, NULL, 10204, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33008, 2963, NULL, 10204, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33009, 7160, NULL, 10204, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33010, 13916, NULL, 10204, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24514, 4132, NULL, 7576, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24515, 11008, NULL, 7576, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24516, 11009, NULL, 7576, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24517, 11010, NULL, 7576, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24534, 4500, NULL, 7581, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24535, 11019, NULL, 7581, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24536, 3942, NULL, 7581, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24537, 5006, NULL, 7581, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24545, 1086, NULL, 1162, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24546, 5959, NULL, 7583, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24547, 11024, NULL, 7583, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24548, 7537, NULL, 7583, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24549, 3001, NULL, 7583, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24550, 11025, NULL, 7584, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24551, 11026, NULL, 7585, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24552, 3560, NULL, 7585, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24553, 3276, NULL, 7586, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24554, 7021, NULL, 7586, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24555, 6393, NULL, 7586, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24556, 7097, NULL, 7586, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24557, 1665, NULL, 7587, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24558, 1958, NULL, 7587, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24559, 1455, NULL, 7587, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24560, 2456, NULL, 7587, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24561, 429, NULL, 7587, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24562, 1528, NULL, 7587, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (24563, 5246, NULL, 7587, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (24564, 1942, NULL, 7587, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (24565, 2480, NULL, 7588, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24566, 2871, NULL, 7588, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24567, 11027, NULL, 7589, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24568, 3760, NULL, 7589, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24569, 2629, NULL, 7589, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24570, 3582, NULL, 7589, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24571, 4772, NULL, 7590, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24572, 3821, NULL, 7590, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24573, 2205, NULL, 7590, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24574, 6963, NULL, 7590, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24370, 691, NULL, 7533, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24369, 10986, NULL, 7533, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24371, 10988, NULL, 7533, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24512, 7502, NULL, 7575, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24511, 2556, NULL, 7575, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24513, 1042, NULL, 7575, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24575, 6763, NULL, 7591, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24576, 11028, NULL, 7591, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24577, 11029, NULL, 7592, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24578, 11030, NULL, 7592, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24579, 11031, NULL, 7593, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24580, 2330, 242, 7593, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24581, 7212, NULL, 7593, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24582, 11032, NULL, 7593, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24583, 11033, NULL, 7593, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24584, 6337, NULL, 7594, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24585, 1849, NULL, 7594, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24586, 10896, NULL, 7595, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24587, 11034, NULL, 7595, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24588, 11035, NULL, 7596, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24589, 2958, NULL, 7596, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24590, 2931, NULL, 7596, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24591, 11036, NULL, 7596, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24592, 311, NULL, 7597, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24593, 1077, NULL, 7597, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24594, 3584, NULL, 7597, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24595, 10908, NULL, 7598, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24596, 8166, NULL, 7598, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24597, 11037, NULL, 7599, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24598, 11038, NULL, 7600, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24603, 200, NULL, 7602, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24604, 2916, NULL, 7602, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24605, 2047, NULL, 7602, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24606, 11039, NULL, 7603, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24607, 6208, NULL, 7604, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24608, 6207, NULL, 7604, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24609, 787, NULL, 7604, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24610, 6209, NULL, 7604, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24611, 8498, NULL, 7605, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24612, 11040, NULL, 7605, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24613, 11041, NULL, 7605, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24614, 11042, NULL, 7606, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24615, 11043, NULL, 7607, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24616, 2519, NULL, 7607, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24617, 11044, NULL, 7608, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24622, 11045, NULL, 7610, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24623, 11046, NULL, 7611, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24624, 11047, NULL, 7611, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24625, 11048, NULL, 7612, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24626, 11049, NULL, 7612, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24627, 11050, NULL, 7612, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24628, 11051, NULL, 7613, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24629, 6216, NULL, 7613, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24630, 11052, NULL, 7613, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33014, 4323, NULL, 10205, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24533, 11018, NULL, 7580, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24636, 11056, NULL, 7615, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24637, 11057, NULL, 7615, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24638, 11058, NULL, 7616, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24639, 11059, NULL, 7616, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24640, 11060, NULL, 7616, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24641, 2836, NULL, 7617, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24642, 7606, NULL, 7617, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24643, 11061, NULL, 7617, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24644, 5946, NULL, 7617, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24645, 11062, NULL, 7618, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24646, 11063, NULL, 7619, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24647, 374, NULL, 7620, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24648, 378, NULL, 7620, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24649, 11064, NULL, 7620, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24650, 429, NULL, 7621, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24651, 1628, NULL, 7621, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24652, 1643, NULL, 7621, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24653, 1198, NULL, 7622, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24654, 171, NULL, 7622, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24655, 613, NULL, 7622, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24656, 6224, NULL, 7623, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24657, 534, NULL, 7624, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24658, 2922, NULL, 7624, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24659, 8265, 244, 7624, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24660, 876, NULL, 7625, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24661, 1732, NULL, 7625, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24662, 3013, NULL, 7625, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24663, 448, NULL, 7626, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24664, 4085, NULL, 7626, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24665, 1401, NULL, 7626, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24666, 1685, 245, 7627, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24667, 283, NULL, 7628, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24668, 2399, NULL, 7628, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24669, 2626, NULL, 7628, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24670, 1458, NULL, 7629, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24671, 13, 246, 7629, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24672, 1179, NULL, 7629, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24673, 408, NULL, 7630, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24674, 1431, NULL, 7631, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24675, 842, NULL, 7631, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24676, 833, NULL, 7631, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24677, 11065, NULL, 7632, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24678, 11066, NULL, 7632, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24679, 9917, NULL, 7632, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24680, 6752, NULL, 7632, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24681, 11067, NULL, 7633, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24682, 11068, NULL, 7633, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24683, 5369, NULL, 7633, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24684, 4809, NULL, 7633, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24685, 9565, NULL, 7634, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24686, 9578, NULL, 7634, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24687, 9579, NULL, 7634, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24688, 11069, NULL, 7635, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24689, 4323, NULL, 7635, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24690, 1042, NULL, 7635, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24691, 11070, NULL, 7636, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24692, 11071, NULL, 7636, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24693, 11072, NULL, 7636, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24694, 11073, NULL, 7636, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24695, 5175, NULL, 7636, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24696, 11074, NULL, 7636, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (24697, 11075, NULL, 7637, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24698, 1343, NULL, 7637, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24699, 2123, NULL, 7637, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24700, 1400, NULL, 7637, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24524, 2816, NULL, 7578, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24523, 11014, NULL, 7578, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24525, 2631, NULL, 7578, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24522, 10228, NULL, 7578, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24521, 11013, NULL, 7577, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24518, 11011, NULL, 7577, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24519, 4251, NULL, 7577, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24520, 11012, NULL, 7577, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24635, 6626, NULL, 7614, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24632, 11054, NULL, 7614, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24631, 11053, NULL, 7614, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24532, 11017, NULL, 7580, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24530, 1370, NULL, 7580, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24531, 11016, NULL, 7580, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30145, 6302, NULL, 9424, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31445, 13038, NULL, 9773, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31446, 13039, NULL, 9773, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31444, 13037, NULL, 9773, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24701, 1118, NULL, 7637, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24702, 1659, NULL, 7637, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (24703, 157, NULL, 7637, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (24704, 11076, NULL, 7638, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24705, 3919, NULL, 7638, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24706, 1876, NULL, 7638, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24707, 687, NULL, 7638, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24708, 4740, NULL, 7638, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24709, 457, NULL, 7638, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (24710, 2822, NULL, 7638, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (24711, 13, NULL, 7638, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (24712, 10473, NULL, 7639, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24713, 1890, NULL, 7639, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24714, 11077, NULL, 7639, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24715, 11078, NULL, 7639, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24716, 11079, NULL, 7640, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24717, 11080, NULL, 7640, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24718, 942, NULL, 7640, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24719, 11081, NULL, 7640, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24720, 11082, NULL, 7641, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24721, 11083, NULL, 7641, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24722, 11084, NULL, 7641, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24723, 11085, NULL, 7641, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24728, 6880, NULL, 7643, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24729, 11090, NULL, 7643, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24730, 11091, NULL, 7643, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24731, 6516, NULL, 7643, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24734, 1621, NULL, 7645, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24735, 11093, NULL, 7645, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24736, 11094, NULL, 7645, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24737, 11095, NULL, 7645, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24738, 11096, NULL, 7646, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24739, 400, NULL, 7646, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24740, 1691, NULL, 7647, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24741, 2657, NULL, 7647, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24742, 11097, NULL, 7647, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24743, 6570, NULL, 7647, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24544, 11023, NULL, 7582, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (24541, 3392, NULL, 7582, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24540, 11021, NULL, 7582, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24543, 11022, NULL, 7582, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (24726, 11088, NULL, 7642, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24725, 11087, NULL, 7642, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24727, 11089, NULL, 7642, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24724, 11086, NULL, 7642, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24732, 11092, NULL, 7644, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24733, 2333, NULL, 7644, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24744, 11098, NULL, 7647, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24745, 10656, NULL, 7647, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (24746, 8368, NULL, 7647, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (24747, 11099, NULL, 7648, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24751, 11103, NULL, 7651, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24752, 10593, NULL, 7651, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24753, 11104, NULL, 7651, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24754, 11105, NULL, 7651, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24755, 6405, NULL, 7652, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24756, 5000, NULL, 7652, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24757, 6530, NULL, 7652, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24758, 5502, NULL, 7652, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24761, 11108, NULL, 7654, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24762, 11109, NULL, 7654, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24763, 8807, NULL, 7654, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24764, 8521, NULL, 7654, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24765, 9516, NULL, 7654, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24766, 2683, NULL, 7655, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24767, 2780, NULL, 7655, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24768, 10391, NULL, 7655, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24771, 11111, NULL, 7657, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24772, 11112, NULL, 7657, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24773, 11113, NULL, 7657, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24774, 10745, NULL, 7658, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24775, 5932, NULL, 7658, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24776, 9916, NULL, 7658, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24777, 11114, NULL, 7658, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24778, 11115, NULL, 7659, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24779, 4913, NULL, 7659, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24780, 11116, NULL, 7659, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24781, 11117, NULL, 7659, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24782, 232, NULL, 7659, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24783, 9613, NULL, 7660, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24784, 11118, NULL, 7660, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24785, 11119, NULL, 7660, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24786, 11120, NULL, 7660, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24787, 850, NULL, 7661, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24788, 915, NULL, 7661, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24789, 1503, NULL, 7661, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24791, 424, NULL, 7661, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24793, 1875, NULL, 7662, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24794, 2411, NULL, 7662, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24795, 482, NULL, 7663, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24796, 1696, NULL, 7663, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24797, 7578, NULL, 7663, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24800, 8250, NULL, 7665, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24801, 5557, NULL, 7665, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24802, 2576, NULL, 7665, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24803, 2730, NULL, 7665, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24804, 6394, NULL, 7666, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24805, 6405, NULL, 7666, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24806, 5000, NULL, 7666, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24807, 5727, NULL, 7666, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24808, 318, NULL, 7667, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24809, 4085, NULL, 7667, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24810, 682, NULL, 7667, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24811, 1005, NULL, 7668, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24812, 594, NULL, 7669, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24813, 2369, NULL, 7669, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24814, 7502, NULL, 7669, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24815, 1942, NULL, 7670, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24816, 1528, NULL, 7670, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24817, 2786, NULL, 7670, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24818, 5246, NULL, 7670, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24819, 1508, NULL, 7671, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24820, 6361, NULL, 7671, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24821, 2536, NULL, 7671, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24822, 5297, NULL, 7672, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24823, 316, NULL, 7672, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24824, 313, NULL, 7673, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24825, 5295, NULL, 7673, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24826, 1884, NULL, 7673, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24827, 4740, NULL, 7673, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24828, 4034, NULL, 7673, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24829, 1540, NULL, 7674, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24830, 5260, NULL, 7674, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24831, 2827, NULL, 7674, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24832, 63, NULL, 7675, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24833, 2421, NULL, 7675, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24834, 4382, NULL, 7676, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24835, 312, NULL, 7676, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24836, 1732, NULL, 7676, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24837, 11121, NULL, 7677, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24838, 346, NULL, 7678, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24839, 1311, NULL, 7678, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24840, 872, NULL, 7679, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24841, 4578, NULL, 7679, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24842, 2774, NULL, 7679, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24843, 1041, NULL, 7680, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24844, 90, NULL, 7680, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24845, 1880, NULL, 7680, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24846, 1415, NULL, 7680, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24847, 1926, NULL, 7681, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24848, 2391, NULL, 7681, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33015, 13919, NULL, 10207, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24850, 6563, NULL, 7681, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24851, 11122, NULL, 7682, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24852, 204, NULL, 7682, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24853, 11123, NULL, 7682, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24854, 1098, NULL, 7682, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24855, 1059, NULL, 7683, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24856, 687, NULL, 7683, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24857, 1586, NULL, 7683, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24858, 11124, NULL, 7683, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24859, 3172, NULL, 7684, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24860, 3173, NULL, 7684, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24861, 5921, NULL, 7684, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24862, 11125, NULL, 7685, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24863, 3946, NULL, 7686, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24864, 11126, NULL, 7686, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24865, 11127, NULL, 7687, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24866, 7793, NULL, 7687, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24867, 7794, NULL, 7687, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24868, 7194, NULL, 7687, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24869, 1082, NULL, 7688, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24870, 2773, NULL, 7688, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24871, 2492, NULL, 7688, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24872, 1542, NULL, 7689, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24873, 2029, NULL, 7689, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24874, 2179, NULL, 7689, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24875, 1226, NULL, 7690, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24876, 2205, NULL, 7690, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24877, 5117, NULL, 7690, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24878, 648, NULL, 7690, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24879, 1019, NULL, 7691, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24880, 1241, NULL, 7691, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24881, 2309, NULL, 7691, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24882, 245, NULL, 7691, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24886, 1319, NULL, 7693, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24887, 1226, NULL, 7693, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24888, 2263, NULL, 7693, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24889, 1135, NULL, 7694, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24890, 3014, NULL, 7694, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24891, 2349, NULL, 7694, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24892, 722, NULL, 7695, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24893, 3993, NULL, 7695, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24894, 2249, NULL, 7695, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24895, 4821, NULL, 7695, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24896, 2798, NULL, 7696, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24897, 1541, NULL, 7696, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24898, 2860, NULL, 7696, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24899, 431, NULL, 7697, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24900, 1544, NULL, 7697, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24901, 1368, NULL, 7697, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24902, 533, NULL, 7697, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24903, 1013, NULL, 7698, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24904, 767, NULL, 7698, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24905, 610, NULL, 7699, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24906, 5116, NULL, 7699, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24907, 1880, NULL, 7699, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24908, 1006, NULL, 7699, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24909, 589, NULL, 7700, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24910, 4413, NULL, 7700, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24911, 1748, NULL, 7700, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24912, 1198, NULL, 7701, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24913, 1196, 125, 7701, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24914, 1943, NULL, 7701, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24915, 2235, NULL, 7701, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24916, 872, NULL, 7702, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24917, 76, NULL, 7702, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24918, 4360, NULL, 7702, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24919, 7119, NULL, 7703, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24920, 7920, NULL, 7703, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24921, 11128, NULL, 7704, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24922, 11129, NULL, 7704, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24923, 11130, NULL, 7704, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24924, 2680, NULL, 7705, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24925, 256, NULL, 7705, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24926, 11131, NULL, 7705, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24927, 2562, NULL, 7705, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24929, 1345, 53, 7707, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24930, 11132, NULL, 7707, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24760, 11107, NULL, 7653, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24759, 11106, NULL, 7653, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24748, 11100, NULL, 7649, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24750, 11102, NULL, 7650, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24769, 6617, NULL, 7656, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24770, 11110, NULL, 7656, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24928, 6265, NULL, 7706, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24884, 2489, NULL, 7692, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24885, 2140, NULL, 7692, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24931, 2031, NULL, 7707, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24932, 11133, NULL, 7707, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24933, 11134, NULL, 7708, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24934, 11135, NULL, 7708, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24935, 7495, NULL, 7709, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24936, 7653, NULL, 7709, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24937, 10500, NULL, 7709, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24938, 11136, NULL, 7709, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24939, 10836, NULL, 7710, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24940, 11137, NULL, 7711, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24941, 11138, NULL, 7711, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24942, 111, NULL, 7711, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24943, 11139, NULL, 7711, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24944, 11140, NULL, 7712, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24945, 11141, NULL, 7712, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24950, 11142, NULL, 7714, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24951, 11143, NULL, 7714, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24952, 7947, NULL, 7715, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24953, 8067, NULL, 7715, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24954, 8074, NULL, 7715, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24955, 9791, NULL, 7715, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33016, 13920, NULL, 10207, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33017, 13921, NULL, 10207, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33018, 654, NULL, 10207, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31448, 963, NULL, 9773, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (24960, 316, NULL, 7717, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24961, 6478, NULL, 7717, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24962, 1662, NULL, 7718, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24963, 1700, NULL, 7718, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24964, 1830, NULL, 7718, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24965, 1919, NULL, 7718, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24966, 11145, NULL, 7719, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24967, 11146, NULL, 7719, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24968, 1748, NULL, 7720, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24969, 2554, NULL, 7720, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24970, 2661, NULL, 7720, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24971, 2379, NULL, 7720, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24972, 9334, NULL, 7720, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24973, 9337, NULL, 7720, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (24974, 7119, NULL, 7721, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24975, 7920, NULL, 7721, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24976, 11128, NULL, 7722, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24977, 11129, NULL, 7722, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24978, 11130, NULL, 7722, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24979, 2680, NULL, 7723, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24980, 256, NULL, 7723, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24981, 11131, NULL, 7723, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24982, 2562, NULL, 7723, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24984, 1345, 53, 7725, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24985, 11132, NULL, 7725, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24986, 2031, NULL, 7725, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24987, 11133, NULL, 7725, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24988, 11134, NULL, 7726, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24989, 11135, NULL, 7726, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24990, 7495, NULL, 7727, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24991, 7653, NULL, 7727, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24992, 10500, NULL, 7727, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24993, 11136, NULL, 7727, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24994, 10836, NULL, 7728, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24995, 11137, NULL, 7729, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24996, 11138, NULL, 7729, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24997, 111, NULL, 7729, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24998, 11139, NULL, 7729, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24999, 11140, NULL, 7730, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25000, 11141, NULL, 7730, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25005, 11142, NULL, 7732, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25006, 11143, NULL, 7732, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25007, 7947, NULL, 7733, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25008, 8067, NULL, 7733, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25009, 8074, NULL, 7733, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25010, 9791, NULL, 7733, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25015, 316, NULL, 7735, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25016, 6478, NULL, 7735, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25017, 1662, NULL, 7736, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25018, 1700, NULL, 7736, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25019, 1830, NULL, 7736, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25020, 1919, NULL, 7736, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25021, 11145, NULL, 7737, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25022, 11146, NULL, 7737, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25023, 1748, NULL, 7738, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25024, 2554, NULL, 7738, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25025, 2661, NULL, 7738, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25026, 2379, NULL, 7738, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25027, 9334, NULL, 7738, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25028, 9337, NULL, 7738, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25029, 1535, NULL, 7739, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25030, 5301, NULL, 7739, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25031, 3589, NULL, 7739, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25032, 3257, NULL, 7740, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25033, 2738, NULL, 7740, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25034, 3428, NULL, 7740, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25035, 4077, NULL, 7740, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25036, 49, NULL, 7741, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25037, 7302, NULL, 7741, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25038, 9514, NULL, 7741, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25039, 10017, NULL, 7742, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25040, 7476, NULL, 7742, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25041, 2871, NULL, 7743, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25042, 11147, NULL, 7743, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25043, 430, NULL, 7744, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25044, 4646, NULL, 7744, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25045, 11148, NULL, 7744, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25046, 5011, NULL, 7745, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25047, 5303, NULL, 7745, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25048, 6081, NULL, 7746, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25049, 5269, NULL, 7746, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25050, 11149, NULL, 7747, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25051, 4940, NULL, 7748, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25052, 11150, NULL, 7748, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25053, 1665, NULL, 7749, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25054, 713, NULL, 7749, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25055, 10295, NULL, 7749, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25057, 98, NULL, 7750, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25058, 2882, NULL, 7750, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25059, 1059, NULL, 7750, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25060, 6048, NULL, 7750, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25061, 7077, NULL, 7751, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25062, 11151, NULL, 7751, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25063, 11152, NULL, 7752, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25064, 6092, NULL, 7752, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25065, 2465, NULL, 7752, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25066, 520, NULL, 7753, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25067, 1380, NULL, 7753, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25068, 730, NULL, 7753, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25069, 3158, NULL, 7754, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25070, 1502, NULL, 7754, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25071, 13, NULL, 7755, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25072, 1219, NULL, 7755, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25073, 1778, NULL, 7755, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25013, 2178, NULL, 7734, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25012, 2874, NULL, 7734, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25014, 6762, NULL, 7734, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25074, 6222, NULL, 7756, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25075, 2264, NULL, 7756, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25076, 5236, NULL, 7756, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25077, 6035, NULL, 7757, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25078, 1101, NULL, 7757, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25079, 5963, NULL, 7757, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25080, 2576, NULL, 7757, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25081, 283, NULL, 7758, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25082, 389, NULL, 7758, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25083, 503, NULL, 7758, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25084, 6253, NULL, 7759, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25085, 11153, NULL, 7759, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25086, 3517, NULL, 7760, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25087, 11154, NULL, 7760, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25088, 1553, NULL, 7761, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25089, 816, NULL, 7761, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25090, 1179, NULL, 7761, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25091, 423, NULL, 7761, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25100, 974, NULL, 7764, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25101, 2623, NULL, 7764, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25102, 2095, NULL, 7764, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25103, 4751, NULL, 7764, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25104, 234, NULL, 7765, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25105, 915, NULL, 7765, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25106, 2120, NULL, 7765, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25107, 2104, NULL, 7765, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25108, 1352, NULL, 7766, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25109, 1621, NULL, 7766, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25110, 138, NULL, 7767, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25111, 3914, NULL, 7767, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25112, 4745, NULL, 7767, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25113, 4746, NULL, 7767, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25114, 824, NULL, 7768, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25115, 4175, NULL, 7768, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25116, 4747, NULL, 7768, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25117, 4748, NULL, 7768, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25122, 732, NULL, 7770, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25123, 2416, NULL, 7770, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25124, 3150, NULL, 7770, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25125, 466, NULL, 7770, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25126, 1329, NULL, 7771, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25127, 4752, NULL, 7771, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25128, 2094, NULL, 7771, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25129, 2772, NULL, 7771, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25096, 452, NULL, 7763, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25099, 3769, NULL, 7763, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25098, 5790, NULL, 7763, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25097, 2614, NULL, 7763, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24983, 6265, NULL, 7724, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25130, 382, NULL, 7772, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25131, 497, NULL, 7772, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25132, 835, NULL, 7772, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25133, 1503, NULL, 7772, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25134, 2259, NULL, 7772, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25135, 685, NULL, 7772, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25136, 857, NULL, 7772, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (25137, 2478, NULL, 7772, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (25138, 2080, NULL, 7772, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (25163, 310, NULL, 7779, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25165, 3126, NULL, 7779, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25166, 3127, NULL, 7779, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25151, 456, NULL, 7776, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25152, 272, NULL, 7776, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25155, 918, NULL, 7777, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25156, 11156, NULL, 7777, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25157, 1927, NULL, 7777, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25158, 8359, NULL, 7777, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25159, 1105, NULL, 7778, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25160, 8101, NULL, 7778, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25161, 5979, NULL, 7778, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25162, 6374, NULL, 7778, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25167, 1692, NULL, 7780, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25168, 1018, NULL, 7780, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25169, 285, NULL, 7780, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25170, 599, NULL, 7780, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25171, 253, NULL, 7781, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25172, 554, NULL, 7781, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25173, 6422, NULL, 7781, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25121, 19, NULL, 7769, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25118, 1015, NULL, 7769, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25120, 2821, NULL, 7769, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25119, 2903, NULL, 7769, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25149, 4989, NULL, 7775, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25150, 7347, NULL, 7775, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25147, 1473, NULL, 7775, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25141, 2202, NULL, 7773, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25140, 2555, NULL, 7773, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25142, 1116, NULL, 7773, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25174, 3018, NULL, 7781, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25176, 9432, NULL, 7782, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25177, 625, NULL, 7782, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25178, 1112, NULL, 7782, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25154, 1352, 385, 7776, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25164, 1649, NULL, 7779, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25175, 2055, 389, 7782, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25183, 183, NULL, 7784, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25184, 915, NULL, 7784, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25185, 1067, NULL, 7784, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25190, 11158, NULL, 7786, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25191, 979, NULL, 7786, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25192, 2980, NULL, 7786, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25193, 1986, NULL, 7786, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25195, 1132, NULL, 7787, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25196, 1664, NULL, 7787, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25197, 1786, NULL, 7787, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25198, 594, NULL, 7788, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25199, 11159, NULL, 7788, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25200, 2349, NULL, 7788, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25201, 2644, NULL, 7788, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25203, 11160, NULL, 7788, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25204, 1943, NULL, 7788, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (25205, 251, NULL, 7789, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25206, 307, NULL, 7789, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25207, 7042, NULL, 7789, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25208, 5308, NULL, 7789, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25209, 898, NULL, 7790, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25210, 1118, NULL, 7790, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25211, 11161, NULL, 7790, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25212, 7500, NULL, 7790, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25213, 2130, NULL, 7790, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25214, 8792, NULL, 7790, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25215, 11162, NULL, 7790, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (25216, 568, NULL, 7791, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25218, 8836, NULL, 7791, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25219, 11163, NULL, 7791, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25220, 71, NULL, 7792, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25222, 8798, NULL, 7792, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25223, 11164, NULL, 7792, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25224, 2489, NULL, 7792, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25225, 11165, NULL, 7792, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25226, 2048, NULL, 7792, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (25227, 704, NULL, 7793, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25228, 1160, NULL, 7793, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25229, 259, NULL, 7793, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25230, 1981, NULL, 7793, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25231, 346, NULL, 7794, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25232, 1731, NULL, 7794, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25234, 201, NULL, 7794, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25235, 9757, NULL, 7794, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25236, 3077, NULL, 7794, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25237, 5560, NULL, 7794, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (25242, 1454, NULL, 7796, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25243, 11166, NULL, 7796, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25244, 10262, NULL, 7796, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25245, 8254, NULL, 7796, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25246, 5777, NULL, 7796, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25247, 288, NULL, 7796, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25249, 347, NULL, 7797, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25250, 11167, NULL, 7797, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25252, 5955, NULL, 7797, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25253, 396, NULL, 7798, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25254, 1042, NULL, 7798, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25255, 9913, NULL, 7798, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25257, 2559, NULL, 7798, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25258, 9614, NULL, 7798, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25260, 11168, NULL, 7799, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25261, 11169, NULL, 7799, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25262, 11170, NULL, 7799, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25264, 10655, NULL, 7800, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25265, 4364, NULL, 7800, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25266, 3269, NULL, 7800, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25267, 11171, NULL, 7800, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25268, 11172, NULL, 7801, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25270, 11173, NULL, 7801, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25194, 181, NULL, 7787, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25271, 11174, NULL, 7801, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25272, 11175, NULL, 7802, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25273, 2952, NULL, 7802, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25274, 11176, NULL, 7802, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25275, 10764, NULL, 7803, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25276, 7500, NULL, 7803, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25277, 2128, NULL, 7803, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25278, 7575, NULL, 7804, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25279, 1146, NULL, 7804, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25280, 2635, NULL, 7804, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25281, 1334, NULL, 7804, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25282, 11177, NULL, 7805, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25283, 2207, NULL, 7805, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25284, 2208, NULL, 7805, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25285, 3269, NULL, 7805, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25286, 1895, NULL, 7806, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25287, 688, NULL, 7806, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25288, 2971, NULL, 7806, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25289, 389, NULL, 7806, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25290, 11178, NULL, 7807, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25291, 2531, NULL, 7807, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25292, 1542, NULL, 7807, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25293, 11179, NULL, 7807, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25294, 11180, NULL, 7808, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25295, 4267, NULL, 7808, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25296, 1164, NULL, 7808, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25297, 2975, NULL, 7809, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25298, 10210, NULL, 7809, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25299, 11181, NULL, 7809, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25300, 11182, NULL, 7809, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25304, 3601, NULL, 7811, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25305, 2597, NULL, 7811, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25306, 5390, 187, 7811, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25307, 10653, NULL, 7812, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25308, 9586, NULL, 7812, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25309, 2366, NULL, 7812, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25310, 2221, NULL, 7812, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25311, 11183, NULL, 7813, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25312, 11184, NULL, 7813, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25313, 11185, NULL, 7813, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25314, 2860, NULL, 7814, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25315, 501, NULL, 7814, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25316, 996, NULL, 7814, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25317, 11035, NULL, 7814, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25318, 2860, NULL, 7814, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25319, 374, NULL, 7815, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25320, 993, NULL, 7816, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25321, 4727, NULL, 7816, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25322, 1799, NULL, 7816, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25323, 236, NULL, 7817, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25324, 1006, NULL, 7817, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25325, 11186, NULL, 7817, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25326, 364, NULL, 7818, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25327, 305, NULL, 7818, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25328, 1140, NULL, 7818, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25329, 11062, NULL, 7819, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25330, 1147, NULL, 7820, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25331, 1232, NULL, 7820, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25332, 34, NULL, 7820, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25334, 6179, NULL, 7822, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25335, 6183, NULL, 7822, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25336, 11187, NULL, 7822, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25337, 318, NULL, 7823, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25303, 141, NULL, 7810, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25301, 1126, NULL, 7810, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25338, 1423, NULL, 7823, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25339, 171, NULL, 7823, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25340, 5738, NULL, 7824, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25341, 73, NULL, 7824, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25342, 6, NULL, 7824, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25343, 1425, NULL, 7825, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25344, 1731, NULL, 7825, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25345, 234, NULL, 7825, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25346, 1884, NULL, 7826, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25347, 4740, NULL, 7826, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25348, 4034, NULL, 7826, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25349, 6276, NULL, 7826, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25350, 5174, NULL, 7827, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25351, 1005, NULL, 7828, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25352, 5387, NULL, 7829, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25357, 11189, NULL, 7831, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25358, 382, NULL, 7832, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25359, 4085, NULL, 7832, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25360, 1091, NULL, 7832, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25361, 4940, NULL, 7833, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25362, 6287, NULL, 7833, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25363, 6224, NULL, 7834, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25364, 408, NULL, 7835, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25365, 2489, NULL, 7836, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25366, 445, NULL, 7836, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25182, 7537, 391, 7783, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25241, 1894, NULL, 7795, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25240, 5490, 152, 7795, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25238, 1355, NULL, 7795, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25148, 6203, 387, 7775, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25367, 2443, NULL, 7836, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25202, 1295, 401, 7788, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25221, 1174, 403, 7792, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25233, 403, 404, 7794, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25251, 13014, NULL, 7797, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25256, 9170, 406, 7798, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25259, 3111, 407, 7798, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (25263, 10579, 408, 7799, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25368, 2413, NULL, 7836, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25369, 5355, NULL, 7837, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25370, 955, NULL, 7837, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25371, 2626, NULL, 7837, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25372, 5433, NULL, 7838, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25373, 6779, NULL, 7838, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25374, 1111, NULL, 7839, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25375, 90, NULL, 7839, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25376, 429, NULL, 7839, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25377, 989, NULL, 7840, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25378, 867, NULL, 7840, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25379, 1450, NULL, 7841, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25380, 425, NULL, 7841, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25381, 488, NULL, 7841, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25382, 11190, NULL, 7842, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25383, 374, NULL, 7843, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25384, 1374, NULL, 7843, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25385, 1541, NULL, 7843, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25386, 4702, NULL, 7844, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25387, 913, NULL, 7844, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25388, 7087, NULL, 7845, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25389, 4989, NULL, 7846, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25390, 6203, NULL, 7846, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25391, 750, NULL, 7846, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25392, 7980, NULL, 7847, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25393, 2816, NULL, 7848, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25394, 183, NULL, 7848, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25395, 2631, NULL, 7848, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25396, 4323, NULL, 7848, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25397, 1283, NULL, 7849, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25398, 2561, NULL, 7849, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25399, 1979, NULL, 7849, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25400, 2719, NULL, 7850, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25401, 4381, NULL, 7851, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25403, 3589, NULL, 7851, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25404, 6079, NULL, 7852, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25405, 4397, NULL, 7852, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25406, 1422, NULL, 7853, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25407, 368, NULL, 7853, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25408, 1125, NULL, 7854, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25409, 6924, NULL, 7854, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25410, 5621, NULL, 7854, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25411, 451, NULL, 7855, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25412, 2259, NULL, 7855, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25413, 19, NULL, 7855, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25414, 672, NULL, 7856, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25415, 6015, NULL, 7857, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25416, 6016, NULL, 7857, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25417, 6679, NULL, 7857, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25418, 2802, NULL, 7858, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25419, 607, NULL, 7858, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25420, 1748, NULL, 7858, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25421, 773, NULL, 7859, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25422, 2536, NULL, 7859, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25423, 1659, NULL, 7859, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25424, 685, NULL, 7859, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25425, 790, NULL, 7860, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25426, 4740, NULL, 7860, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25427, 1779, NULL, 7860, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25428, 1553, NULL, 7861, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25429, 4085, NULL, 7861, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25430, 146, NULL, 7861, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25431, 5253, NULL, 7862, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25432, 350, NULL, 7863, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25433, 78, NULL, 7863, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25434, 62, NULL, 7863, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25435, 2270, NULL, 7864, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25436, 11191, NULL, 7865, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25437, 1021, NULL, 7866, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25438, 773, NULL, 7866, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25439, 2442, NULL, 7866, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25440, 1042, NULL, 7866, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25441, 292, NULL, 7867, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25442, 77, NULL, 7868, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25443, 10396, NULL, 7868, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25444, 2696, NULL, 7868, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25445, 283, NULL, 7869, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25446, 11192, NULL, 7869, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25447, 835, NULL, 7869, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25448, 6898, NULL, 7870, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25449, 773, NULL, 7870, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25450, 1503, NULL, 7870, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25454, 11193, NULL, 7872, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25455, 750, NULL, 7873, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25456, 2063, NULL, 7873, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25457, 5494, NULL, 7873, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25458, 451, NULL, 7874, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25459, 2307, NULL, 7874, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25460, 1027, NULL, 7875, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25461, 536, NULL, 7875, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25462, 1715, NULL, 7875, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25463, 6393, NULL, 7876, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25464, 6394, NULL, 7876, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25465, 5500, NULL, 7876, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25466, 6395, NULL, 7876, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25467, 5053, NULL, 7877, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25468, 11194, NULL, 7877, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25469, 11195, NULL, 7877, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25470, 11196, NULL, 7878, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25471, 5517, NULL, 7878, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25472, 49, NULL, 7878, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25473, 3357, NULL, 7879, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25474, 1701, NULL, 7879, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25475, 1066, NULL, 7879, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25476, 4496, NULL, 7879, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25477, 11197, NULL, 7880, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25478, 3572, NULL, 7880, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25479, 171, NULL, 7881, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25480, 2423, NULL, 7881, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25481, 2957, NULL, 7882, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25482, 2399, NULL, 7882, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25483, 4578, 122, 7882, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25484, 2774, NULL, 7883, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25485, 232, NULL, 7883, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25486, 822, NULL, 7884, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25487, 6136, NULL, 7885, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25488, 5727, NULL, 7885, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25489, 1335, NULL, 7886, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25490, 1332, NULL, 7886, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25491, 7460, NULL, 7887, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25492, 11198, NULL, 7887, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25496, 6388, NULL, 7889, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25497, 4167, NULL, 7889, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25498, 2106, NULL, 7889, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25502, 1150, NULL, 7891, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25503, 5557, NULL, 7891, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25504, 11147, NULL, 7892, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25505, 1077, NULL, 7892, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25506, 2002, NULL, 7892, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25507, 5073, NULL, 7893, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25508, 11199, NULL, 7893, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25509, 1650, NULL, 7893, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25355, 2336, NULL, 7830, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25356, 935, NULL, 7830, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25354, 11188, NULL, 7830, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25452, 188, NULL, 7871, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25451, 1091, NULL, 7871, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25453, 1329, NULL, 7871, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25493, 3744, NULL, 7888, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25494, 892, NULL, 7888, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25495, 923, NULL, 7888, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25510, 11200, NULL, 7894, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25511, 3700, NULL, 7895, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25512, 1880, NULL, 7895, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25513, 2400, NULL, 7895, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25514, 1997, NULL, 7896, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25515, 1624, NULL, 7896, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25516, 456, NULL, 7896, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25517, 3383, NULL, 7897, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25518, 11201, NULL, 7897, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25519, 770, NULL, 7897, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25520, 848, NULL, 7898, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25521, 790, NULL, 7898, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25522, 624, NULL, 7898, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25523, 932, NULL, 7898, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25524, 6901, NULL, 7898, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25525, 11202, NULL, 7899, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25526, 2544, NULL, 7899, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25527, 2536, NULL, 7899, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25528, 8316, NULL, 7900, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25529, 378, NULL, 7900, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25530, 613, NULL, 7900, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25531, 2931, NULL, 7901, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25532, 2699, NULL, 7901, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25533, 1857, 249, 7901, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25534, 4733, NULL, 7901, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25535, 152, NULL, 7902, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25536, 2547, NULL, 7902, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25537, 2223, NULL, 7902, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25538, 6626, NULL, 7902, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25539, 11203, NULL, 7902, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25541, 11204, NULL, 7904, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25542, 11205, NULL, 7904, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25543, 5828, NULL, 7904, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25544, 2171, NULL, 7905, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25545, 3443, NULL, 7905, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25546, 6795, NULL, 7905, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25547, 3367, NULL, 7905, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25548, 4923, NULL, 7906, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25549, 11205, 249, 7907, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25551, 11206, NULL, 7908, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25552, 10423, NULL, 7909, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25553, 1979, NULL, 7909, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25554, 1963, NULL, 7909, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25555, 10423, NULL, 7909, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25556, 1744, NULL, 7910, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25557, 2180, NULL, 7910, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25558, 1181, NULL, 7910, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25559, 1699, NULL, 7911, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25560, 2161, NULL, 7911, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25561, 295, NULL, 7911, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25562, 2616, NULL, 7912, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25563, 4907, NULL, 7912, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25564, 2328, NULL, 7912, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25565, 1878, NULL, 7913, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25566, 144, NULL, 7914, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25567, 2794, NULL, 7914, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25568, 5552, NULL, 7914, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25569, 1458, NULL, 7915, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25570, 6101, NULL, 7916, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25571, 1882, NULL, 7917, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25550, 4738, 285, 7907, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25572, 316, NULL, 7917, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25573, 1929, NULL, 7917, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25574, 760, NULL, 7917, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25575, 2626, NULL, 7917, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25576, 998, NULL, 7918, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25577, 2836, NULL, 7919, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25578, 11207, NULL, 7919, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25579, 11208, NULL, 7919, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25580, 11209, NULL, 7919, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25581, 188, NULL, 7920, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25582, 19, NULL, 7920, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25583, 685, NULL, 7920, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25584, 727, NULL, 7921, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25585, 86, NULL, 7921, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25586, 2616, NULL, 7922, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25587, 4907, NULL, 7922, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25588, 2328, NULL, 7922, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25589, 11210, NULL, 7923, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25590, 11211, NULL, 7923, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25591, 11212, NULL, 7923, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25592, 11213, NULL, 7924, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25593, 6168, NULL, 7925, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25594, 11214, NULL, 7925, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25595, 2238, NULL, 7925, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25596, 3470, NULL, 7926, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25597, 858, NULL, 7927, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25598, 11004, NULL, 7927, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25599, 7214, NULL, 7927, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25600, 11215, NULL, 7927, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25601, 11216, NULL, 7928, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25602, 144, NULL, 7929, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25603, 2794, NULL, 7929, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25604, 5552, NULL, 7929, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25605, 100, NULL, 7930, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25606, 1989, NULL, 7930, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25607, 1699, NULL, 7930, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25608, 11217, NULL, 7931, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25609, 11218, NULL, 7931, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25610, 1799, NULL, 7931, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25611, 11219, NULL, 7932, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25612, 11220, NULL, 7932, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25613, 98, NULL, 7933, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25614, 2836, NULL, 7934, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25615, 11207, NULL, 7934, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25616, 11208, NULL, 7934, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25617, 11209, NULL, 7934, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25618, 11221, NULL, 7935, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25619, 697, NULL, 7935, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25620, 9319, NULL, 7935, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25621, 3481, NULL, 7935, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25622, 1507, NULL, 7936, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25623, 8213, NULL, 7936, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25624, 11222, NULL, 7937, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25625, 11206, NULL, 7937, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25626, 188, NULL, 7938, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25627, 19, NULL, 7938, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25628, 685, NULL, 7938, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25629, 6881, NULL, 7939, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25630, 2696, NULL, 7940, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25631, 1460, 250, 7940, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25632, 209, NULL, 7940, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25633, 850, NULL, 7940, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25634, 790, NULL, 7941, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25635, 5371, NULL, 7941, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25636, 4741, NULL, 7941, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25637, 5752, NULL, 7941, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25638, 2838, NULL, 7942, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25639, 11223, NULL, 7943, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25640, 11224, 26, 7944, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25641, 2592, NULL, 7944, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25642, 11225, NULL, 7944, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25643, 11226, NULL, 7944, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25647, 7213, NULL, 7946, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25648, 317, NULL, 7946, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25649, 2938, NULL, 7946, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25650, 378, 251, 7946, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25651, 6696, NULL, 7947, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25652, 6485, NULL, 7947, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25653, 1693, NULL, 7948, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25654, 1705, NULL, 7948, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25655, 11229, NULL, 7949, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25656, 400, NULL, 7949, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25657, 588, NULL, 7950, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25658, 2920, NULL, 7950, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25659, 267, NULL, 7950, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25660, 11230, NULL, 7951, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25661, 5499, NULL, 7952, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25662, 5501, NULL, 7952, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25663, 7750, NULL, 7952, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25664, 11231, NULL, 7952, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25665, 5931, NULL, 7953, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25666, 11232, NULL, 7953, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25667, 1101, NULL, 7954, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25668, 5304, NULL, 7954, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25669, 2738, NULL, 7954, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25670, 5305, NULL, 7954, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25671, 4543, NULL, 7955, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25672, 5246, NULL, 7955, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25673, 6203, NULL, 7955, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25674, 1919, NULL, 7955, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25675, 448, NULL, 7956, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25676, 2967, NULL, 7956, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25677, 13, 246, 7956, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25678, 613, NULL, 7956, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25679, 11233, NULL, 7957, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25680, 11234, NULL, 7957, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25681, 11235, NULL, 7957, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25686, 1148, NULL, 7959, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25687, 188, NULL, 7959, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25688, 2386, NULL, 7959, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25689, 11239, NULL, 7959, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25694, 5204, NULL, 7961, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25695, 11242, NULL, 7961, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25696, 5956, NULL, 7961, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25697, 3642, NULL, 7961, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25646, 2399, NULL, 7945, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25684, 11237, NULL, 7958, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25685, 11238, NULL, 7958, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25683, 11236, NULL, 7958, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25698, 13, 246, 7962, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25699, 1857, NULL, 7962, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25700, 5039, NULL, 7962, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25701, 11243, NULL, 7962, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25702, 11244, NULL, 7963, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25703, 11245, NULL, 7963, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25704, 11246, NULL, 7963, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25705, 11247, NULL, 7963, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25706, 5754, NULL, 7964, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25707, 11248, NULL, 7964, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25708, 1421, NULL, 7964, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25709, 2968, NULL, 7964, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25710, 11249, NULL, 7965, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25711, 11250, NULL, 7965, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25712, 895, NULL, 7965, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25713, 7506, NULL, 7965, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25714, 4264, NULL, 7966, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25715, 1940, NULL, 7966, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25716, 200, NULL, 7966, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25717, 19, NULL, 7966, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25718, 4735, NULL, 7967, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25719, 11251, NULL, 7967, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25720, 11252, NULL, 7967, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25721, 430, NULL, 7968, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25722, 1515, NULL, 7968, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25723, 7051, NULL, 7968, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25724, 8758, NULL, 7968, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25725, 2259, NULL, 7968, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25726, 2055, NULL, 7969, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25727, 1970, NULL, 7969, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25728, 11253, NULL, 7969, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25729, 1660, NULL, 7969, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25730, 10279, NULL, 7970, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25731, 11254, NULL, 7970, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25737, 382, NULL, 7972, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25738, 3390, NULL, 7972, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25739, 13, 246, 7972, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25740, 457, NULL, 7972, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25741, 1655, NULL, 7972, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25742, 1329, NULL, 7972, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25743, 497, NULL, 7972, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (25744, 1091, NULL, 7972, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (25745, 1629, NULL, 7972, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (25746, 7167, NULL, 7973, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25747, 10774, NULL, 7973, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25748, 11255, NULL, 7974, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25749, 11256, NULL, 7974, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25750, 374, NULL, 7975, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25751, 4578, NULL, 7975, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25752, 2399, NULL, 7975, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25753, 1020, NULL, 7975, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25754, 6246, NULL, 7976, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25755, 11257, NULL, 7976, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25756, 469, NULL, 7977, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25757, 5165, NULL, 7977, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25758, 10012, NULL, 7977, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25759, 979, NULL, 7977, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25760, 9672, NULL, 7977, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25761, 588, NULL, 7978, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25762, 1636, NULL, 7978, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25763, 834, NULL, 7978, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25764, 2559, NULL, 7978, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25765, 1228, NULL, 7978, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25766, 2452, NULL, 7978, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25767, 1042, NULL, 7978, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (25768, 2544, NULL, 7978, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (25769, 448, NULL, 7979, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25770, 914, NULL, 7979, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25771, 2910, NULL, 7979, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25772, 2482, NULL, 7979, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25773, 152, NULL, 7980, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25774, 11258, NULL, 7980, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25775, 5409, NULL, 7980, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25776, 4902, NULL, 7980, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25777, 1059, 17, 7981, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25778, 3056, NULL, 7981, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25779, 1704, NULL, 7981, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25781, 660, NULL, 7981, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25782, 2467, NULL, 7981, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25783, 11259, NULL, 7981, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (25784, 2400, NULL, 7981, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (25785, 11260, NULL, 7982, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25786, 1978, NULL, 7982, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25787, 5979, NULL, 7982, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25788, 10774, NULL, 7982, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25789, 10780, NULL, 7983, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25790, 11261, NULL, 7983, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25791, 2491, NULL, 7983, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25792, 10366, NULL, 7983, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25793, 1391, NULL, 7984, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25794, 11262, NULL, 7984, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25795, 10453, NULL, 7984, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25796, 10293, NULL, 7984, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25797, 3749, NULL, 7985, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25798, 11263, NULL, 7985, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25799, 11264, NULL, 7985, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25800, 11265, NULL, 7985, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25801, 11266, NULL, 7985, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25802, 242, NULL, 7986, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25803, 1528, NULL, 7986, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25804, 2786, NULL, 7986, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25805, 1540, NULL, 7986, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25806, 6203, NULL, 7986, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25807, 5246, NULL, 7986, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25808, 1958, NULL, 7986, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (25809, 242, NULL, 7986, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (33023, 3891, NULL, 10211, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33024, 1687, NULL, 10211, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33025, 425, NULL, 10211, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33026, 2063, NULL, 10211, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25814, 532, NULL, 7988, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25815, 10362, NULL, 7988, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25816, 4350, NULL, 7988, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25817, 1625, NULL, 7988, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25818, 11269, NULL, 7989, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25819, 4828, NULL, 7989, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25820, 9005, NULL, 7989, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25821, 7678, NULL, 7989, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25822, 1514, NULL, 7990, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25823, 349, NULL, 7990, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25824, 123, NULL, 7990, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25825, 423, NULL, 7990, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25826, 1725, NULL, 7990, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25827, 1219, NULL, 7990, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25828, 1716, NULL, 7990, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (25829, 2356, NULL, 7990, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (25830, 2673, NULL, 7991, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25831, 2672, NULL, 7991, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25832, 3614, NULL, 7991, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25833, 4202, NULL, 7991, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25834, 1772, NULL, 7992, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25835, 11270, NULL, 7992, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25836, 11271, NULL, 7992, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25837, 6084, NULL, 7992, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25838, 162, NULL, 7992, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25839, 1772, NULL, 7992, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25840, 11272, NULL, 7993, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25841, 10261, NULL, 7993, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25842, 1920, NULL, 7993, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25843, 11273, NULL, 7993, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25844, 5929, NULL, 7994, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25845, 4365, NULL, 7994, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25846, 1455, NULL, 7994, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25847, 11274, NULL, 7994, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33027, 1737, NULL, 10212, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33028, 3210, NULL, 10212, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33029, 183, NULL, 10212, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33030, 4555, NULL, 10212, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25856, 3271, NULL, 7996, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25857, 2210, NULL, 7996, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25858, 10773, NULL, 7996, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25859, 4381, NULL, 7996, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25860, 5708, NULL, 7997, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25861, 2317, NULL, 7997, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25862, 3912, NULL, 7997, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25863, 5571, NULL, 7997, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25864, 11278, NULL, 7997, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25865, 1945, NULL, 7997, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25866, 10205, NULL, 7998, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25867, 674, NULL, 7998, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25868, 11279, NULL, 7998, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25869, 2377, NULL, 7998, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25873, 1937, NULL, 8000, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25874, 206, NULL, 8000, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25875, 10243, NULL, 8000, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25876, 10761, NULL, 8000, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25877, 3000, NULL, 8000, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25880, 11283, NULL, 8002, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25881, 4987, NULL, 8002, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25882, 11284, NULL, 8002, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25883, 5148, NULL, 8002, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25884, 6454, NULL, 8003, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25885, 11285, NULL, 8003, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25891, 4984, NULL, 8005, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25887, 6845, NULL, 8004, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25886, 5287, NULL, 8004, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25878, 11282, NULL, 8001, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25879, 8522, NULL, 8001, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25892, 6685, NULL, 8006, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25896, 283, NULL, 8007, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25897, 2774, NULL, 8007, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25898, 4737, NULL, 8007, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25899, 1681, NULL, 8007, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25910, 11293, NULL, 8012, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25911, 11294, NULL, 8012, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25912, 1830, NULL, 8013, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25913, 5187, NULL, 8013, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25914, 1880, NULL, 8013, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25915, 2041, NULL, 8013, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25916, 11295, NULL, 8014, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25917, 5881, NULL, 8014, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25918, 6271, NULL, 8014, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25919, 1426, NULL, 8014, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25920, 11296, NULL, 1744, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25924, 2054, NULL, 8016, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25925, 589, NULL, 8016, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25926, 4105, NULL, 8016, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25927, 1777, NULL, 8016, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25928, 11299, NULL, 8017, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25929, 11300, NULL, 8017, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25930, 2333, NULL, 8018, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25931, 11301, NULL, 8018, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25932, 987, NULL, 8019, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25933, 4987, NULL, 8019, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25934, 11302, NULL, 8019, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25935, 11303, NULL, 8019, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25936, 8116, NULL, 8019, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25937, 11304, NULL, 8020, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25938, 1006, NULL, 8020, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25939, 4781, NULL, 8020, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25940, 5931, NULL, 8020, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25941, 6542, NULL, 8021, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25942, 11305, NULL, 8021, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25943, 11306, NULL, 8021, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25944, 11307, NULL, 8021, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25945, 2203, NULL, 8022, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25946, 11295, NULL, 8022, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25947, 11308, NULL, 8022, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25948, 1472, NULL, 8022, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25949, 4397, NULL, 8023, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25950, 968, NULL, 8023, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25955, 1421, NULL, 8025, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25956, 1965, NULL, 8025, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25957, 2524, NULL, 8025, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25958, 78, NULL, 8025, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25959, 3460, NULL, 8026, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25960, 11251, NULL, 8026, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25961, 9874, NULL, 8026, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25962, 2871, NULL, 8027, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25963, 400, NULL, 8027, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25964, 11310, NULL, 8028, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25965, 2494, NULL, 8028, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25966, 2000, NULL, 8028, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25967, 5576, NULL, 8028, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25968, 2849, NULL, 8029, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25969, 338, NULL, 8029, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25970, 6164, NULL, 8029, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25971, 7264, NULL, 8029, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25972, 3600, NULL, 8030, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25973, 2356, NULL, 8030, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25974, 7176, NULL, 8030, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25975, 2332, NULL, 8030, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25976, 220, NULL, 8030, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25977, 11311, NULL, 8031, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25978, 11312, NULL, 8031, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25979, 11313, NULL, 8031, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25980, 11314, NULL, 8031, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25981, 11315, NULL, 8032, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25982, 8524, NULL, 8032, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25983, 3129, NULL, 8032, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25984, 9364, NULL, 8032, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25985, 4907, NULL, 8033, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25986, 11316, NULL, 8033, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25987, 10568, NULL, 8033, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25988, 11317, NULL, 8034, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25989, 11318, NULL, 8034, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25990, 11319, NULL, 8034, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25991, 11320, NULL, 8035, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25992, 2151, NULL, 8035, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25993, 1301, NULL, 8035, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25994, 2981, NULL, 8035, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25998, 11323, NULL, 8037, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25999, 11324, NULL, 8037, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26000, 2610, NULL, 8038, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26001, 11325, NULL, 8038, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26002, 4911, NULL, 8038, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26003, 11326, NULL, 8038, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26004, 1101, NULL, 8039, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26005, 6035, NULL, 8039, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26006, 5142, NULL, 8039, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26007, 3744, NULL, 8039, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26008, 11327, NULL, 8039, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26009, 11328, NULL, 8040, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26010, 11329, NULL, 8040, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26011, 141, NULL, 8040, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26012, 11330, NULL, 8041, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26013, 3060, NULL, 8041, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26014, 1424, NULL, 8041, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26015, 11052, NULL, 8041, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26020, 713, NULL, 8043, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26021, 2731, NULL, 8043, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26022, 2171, NULL, 8043, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26023, 434, NULL, 8043, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26029, 1542, NULL, 8045, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26030, 2106, NULL, 8045, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26032, 7707, NULL, 8045, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26044, 2920, NULL, 1749, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26045, 2531, NULL, 1749, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26046, 1310, NULL, 1749, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26047, 1291, NULL, 1749, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26048, 1311, NULL, 1749, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26049, 834, NULL, 1749, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26050, 2543, NULL, 1749, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26051, 4381, NULL, 1744, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26052, 10295, NULL, 1744, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26053, 320, NULL, 1744, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26054, 50, NULL, 1744, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26055, 1460, NULL, 1744, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26056, 299, NULL, 8047, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26057, 10211, NULL, 8047, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26058, 3713, NULL, 8047, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26059, 9509, NULL, 8047, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26060, 10195, NULL, 8048, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26061, 1328, 252, 8048, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26062, 2808, NULL, 8048, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26063, 3257, NULL, 8048, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26064, 3405, NULL, 8049, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26065, 11336, NULL, 8049, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26066, 11337, NULL, 8049, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26067, 201, NULL, 8049, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26068, 1554, NULL, 8050, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26069, 1700, NULL, 8050, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26070, 10956, NULL, 8050, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26071, 242, NULL, 8050, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26072, 719, NULL, 8051, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26073, 11338, NULL, 8051, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26075, 1549, NULL, 8053, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26076, 11340, NULL, 8053, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26078, 11341, NULL, 8054, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26079, 11342, NULL, 8054, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26080, 11343, NULL, 8054, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26092, 11348, NULL, 8057, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26093, 11349, NULL, 8057, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26094, 11350, NULL, 8057, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26095, 11351, NULL, 8057, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26099, 11355, NULL, 8059, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26100, 11356, NULL, 8059, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26101, 11357, NULL, 8059, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26102, 11358, NULL, 8059, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26103, 166, NULL, 8060, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26104, 6048, NULL, 8060, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26105, 3919, NULL, 8060, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25907, 11290, NULL, 8010, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25908, 11291, NULL, 8010, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25906, 11289, NULL, 8010, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25900, 7593, NULL, 8008, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25951, 691, NULL, 8024, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25954, 11309, NULL, 8024, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25953, 7087, NULL, 8024, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25952, 6336, NULL, 8024, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26024, 11332, NULL, 8044, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26027, 532, NULL, 8044, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26028, 11109, NULL, 8044, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26026, 1003, NULL, 8044, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26025, 2152, NULL, 8044, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26089, 753, NULL, 8056, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26090, 2336, NULL, 8056, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26091, 9833, NULL, 8056, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25895, 425, NULL, 8006, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25894, 8845, NULL, 8006, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25893, 4828, NULL, 8006, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25903, 688, NULL, 8009, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25902, 872, NULL, 8009, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25904, 1648, NULL, 8009, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25905, 2860, NULL, 8009, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25901, 1778, NULL, 8009, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25909, 11292, NULL, 8011, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26106, 1057, NULL, 8060, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26077, 876, NULL, 8054, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26107, 4908, NULL, 8060, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26108, 121, NULL, 8061, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26109, 5887, NULL, 8061, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26110, 2611, NULL, 8061, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26111, 895, NULL, 8061, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25995, 11321, NULL, 8036, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26098, 11354, NULL, 8058, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25997, 766, NULL, 8036, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25996, 3543, NULL, 8036, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25922, 6035, NULL, 8015, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25923, 6282, 590, 8015, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26081, 46, NULL, 8055, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26083, 11345, 637, 8055, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26082, 11344, NULL, 8055, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26112, 463, NULL, 8061, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26113, 1008, NULL, 8061, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26114, 121, NULL, 8061, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26115, 11359, NULL, 8062, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26116, 2081, NULL, 8062, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26117, 1869, NULL, 8062, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26118, 219, NULL, 8062, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26119, 2476, NULL, 8062, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31466, 3136, NULL, 9773, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31443, 1785, NULL, 9773, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26124, 11360, NULL, 8064, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26125, 9910, NULL, 8064, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26126, 5876, NULL, 8064, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26127, 67, NULL, 8065, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26128, 11361, NULL, 8065, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26129, 9837, NULL, 8065, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26130, 11362, NULL, 8065, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26131, 10552, NULL, 8066, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26132, 2675, NULL, 8066, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26133, 11363, NULL, 8066, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26134, 1198, NULL, 8067, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26135, 9817, NULL, 8067, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26136, 9818, NULL, 8067, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26137, 9821, NULL, 8067, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26138, 943, NULL, 8068, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26139, 5904, NULL, 8068, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26140, 11364, NULL, 8069, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26141, 11365, NULL, 8069, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26146, 3394, NULL, 8071, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26147, 2856, NULL, 8071, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26148, 2999, NULL, 8071, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26149, 2375, 196, 8071, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26150, 2081, NULL, 8072, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26151, 2968, NULL, 8072, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26152, 11366, NULL, 8072, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26153, 5073, NULL, 8072, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26154, 1881, NULL, 8073, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26155, 7578, NULL, 8073, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26156, 32, NULL, 8073, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26157, 1867, NULL, 8073, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26158, 2687, NULL, 8074, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26159, 2496, NULL, 8074, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26160, 2691, NULL, 8074, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26161, 302, NULL, 8074, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26162, 2069, NULL, 8075, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26163, 792, NULL, 8075, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26164, 1965, NULL, 8075, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26165, 7556, NULL, 8075, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26166, 4989, NULL, 8076, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26167, 8523, NULL, 8076, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26168, 4891, NULL, 8076, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26169, 10439, NULL, 8076, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26170, 4371, NULL, 8077, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26171, 11367, NULL, 8077, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26172, 11368, NULL, 8077, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26173, 11369, NULL, 8077, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26174, 189, NULL, 8078, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26175, 10553, NULL, 8078, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26176, 2912, NULL, 8078, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26177, 7204, NULL, 8078, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26178, 2091, NULL, 8079, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26179, 6, NULL, 8079, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26180, 789, NULL, 8079, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26181, 2259, NULL, 8079, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26182, 1085, NULL, 8080, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26183, 9533, NULL, 8080, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26184, 3202, NULL, 8080, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26185, 5931, NULL, 8080, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26186, 3268, NULL, 8081, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26018, 6033, NULL, 8042, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26019, 11331, NULL, 8042, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26016, 812, NULL, 8042, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26187, 1778, NULL, 8081, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26188, 312, NULL, 8081, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26189, 3521, NULL, 8081, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26190, 11370, NULL, 8082, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26191, 2362, NULL, 8082, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26192, 2358, NULL, 8082, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26193, 1334, NULL, 8082, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26198, 4045, NULL, 8084, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26199, 11373, NULL, 8084, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26200, 11374, NULL, 8084, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26201, 11375, NULL, 8084, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26206, 135, NULL, 8086, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26207, 5267, NULL, 8086, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26208, 9740, NULL, 8086, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26209, 1923, NULL, 8086, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26210, 11378, NULL, 8087, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26211, 11379, NULL, 8087, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26212, 11380, NULL, 8088, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26213, 11381, NULL, 8088, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26214, 11382, NULL, 8088, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26215, 819, NULL, 8089, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26216, 613, NULL, 8089, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26217, 11383, NULL, 8089, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26218, 1922, NULL, 8089, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26223, 1360, NULL, 8091, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26224, 11386, NULL, 8091, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26225, 2101, NULL, 8091, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26226, 3940, NULL, 8091, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26227, 11387, NULL, 8092, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26228, 11388, NULL, 8092, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26229, 11389, NULL, 8092, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26230, 11390, NULL, 8092, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26231, 6290, NULL, 8093, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26232, 177, NULL, 8093, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26233, 464, NULL, 8093, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26234, 2777, NULL, 8093, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26235, 360, NULL, 8094, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26236, 11391, NULL, 8094, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26237, 1646, NULL, 8094, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26238, 11377, NULL, 8094, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26239, 1364, NULL, 8095, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26240, 11392, NULL, 8095, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26241, 2312, NULL, 8095, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26242, 5002, NULL, 8096, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26243, 5003, NULL, 8096, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26244, 2702, NULL, 8096, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26245, 11393, NULL, 8096, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26246, 11376, NULL, 8097, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26247, 11394, NULL, 8097, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26248, 3247, NULL, 8097, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26249, 4849, NULL, 8097, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26250, 11395, NULL, 8098, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26251, 9030, NULL, 8098, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26252, 2610, NULL, 8098, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26253, 5581, NULL, 8099, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26254, 11396, NULL, 8099, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26255, 11397, NULL, 8099, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26256, 7021, NULL, 8099, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26257, 251, NULL, 8100, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26258, 11398, NULL, 8100, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26259, 2536, NULL, 8100, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26260, 3157, NULL, 8100, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26261, 1190, NULL, 8100, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26262, 4539, NULL, 8100, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26263, 11399, NULL, 8100, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26264, 11008, NULL, 8100, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (26266, 8244, NULL, 8102, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26267, 11401, NULL, 8102, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26268, 11402, NULL, 8102, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26269, 11403, NULL, 8102, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26270, 1625, NULL, 8103, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26271, 11404, NULL, 8103, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26272, 11405, NULL, 8103, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26273, 7080, NULL, 8104, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26274, 6422, NULL, 8104, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26275, 1829, NULL, 8105, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26276, 1595, NULL, 8105, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26277, 2436, NULL, 8105, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26278, 1660, NULL, 8105, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26279, 9100, NULL, 8106, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26280, 11406, NULL, 8106, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26281, 11407, NULL, 8106, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26282, 470, NULL, 8107, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26283, 2203, NULL, 8107, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26194, 9844, NULL, 8083, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26196, 11372, NULL, 8083, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26195, 11371, NULL, 8083, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26197, 5786, NULL, 8083, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26144, 51, NULL, 8070, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26145, 10577, NULL, 8070, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26143, 5770, NULL, 8070, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26142, 3896, NULL, 8070, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26284, 11408, NULL, 8107, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26285, 7507, NULL, 8107, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26286, 11409, NULL, 8108, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26287, 5246, NULL, 8109, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26288, 2692, NULL, 8109, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26289, 1355, NULL, 8109, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26290, 10952, NULL, 8109, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26291, 7127, NULL, 8110, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26292, 1457, NULL, 8111, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26293, 236, NULL, 8111, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28639, 12122, NULL, 8905, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26294, 11410, NULL, 8111, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26295, 2937, NULL, 8111, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26296, 2313, NULL, 8112, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26297, 5308, NULL, 8113, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26298, 11411, NULL, 8113, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26299, 11412, NULL, 8113, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26300, 11413, NULL, 8113, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26301, 6699, NULL, 8114, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26302, 11308, NULL, 8115, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26303, 11414, NULL, 8115, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26304, 8595, NULL, 8115, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26305, 11415, NULL, 8115, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26306, 11416, NULL, 8116, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26307, 11417, NULL, 8116, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26308, 11418, NULL, 8117, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26309, 11419, NULL, 8117, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26310, 11420, NULL, 8117, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26311, 11421, NULL, 8117, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26312, 11422, NULL, 8118, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26313, 11423, NULL, 8118, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26314, 5933, NULL, 8119, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26315, 11424, NULL, 8119, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26316, 973, NULL, 8119, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26317, 520, NULL, 8119, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26318, 11425, NULL, 8120, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26319, 259, NULL, 8121, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26320, 168, NULL, 8121, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26321, 1498, NULL, 8121, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26322, 7539, NULL, 8121, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26323, 1458, NULL, 8122, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26324, 1593, NULL, 8124, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26325, 11231, NULL, 8125, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26326, 2707, NULL, 8125, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26327, 5499, NULL, 8125, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26329, 5434, NULL, 8129, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26330, 6179, NULL, 8129, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26331, 11426, NULL, 8129, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26332, 11427, NULL, 8129, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26333, 1540, NULL, 8131, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26334, 2249, NULL, 8134, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26335, 415, NULL, 8135, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26336, 234, NULL, 8136, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26337, 692, NULL, 8136, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26338, 920, NULL, 8136, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26339, 1673, NULL, 8136, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26340, 835, NULL, 8137, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26341, 354, NULL, 8137, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26342, 8154, NULL, 8137, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26343, 4135, NULL, 8139, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26344, 3600, NULL, 8141, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26345, 2492, NULL, 8141, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26346, 914, NULL, 8141, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26347, 755, NULL, 8142, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26348, 1732, 65, 8142, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26349, 1179, NULL, 8142, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26350, 810, NULL, 8143, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26351, 1311, NULL, 8143, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26352, 974, NULL, 8143, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26353, 761, NULL, 8144, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26354, 962, NULL, 8144, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26355, 601, NULL, 8145, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26356, 5381, NULL, 8145, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26357, 6336, NULL, 8146, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26358, 5499, NULL, 8146, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26359, 6393, NULL, 8146, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26360, 448, NULL, 8147, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26361, 1406, NULL, 8147, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26362, 914, NULL, 8147, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26364, 152, NULL, 8149, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26365, 6778, NULL, 8149, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26366, 1848, NULL, 8150, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26367, 2871, NULL, 8150, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26368, 11305, NULL, 8150, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26369, 4034, NULL, 8151, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26370, 4740, NULL, 8151, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26371, 6523, NULL, 8151, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26372, 678, NULL, 8152, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26373, 1155, NULL, 8152, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26374, 2624, NULL, 8152, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26375, 1741, NULL, 8153, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26376, 5620, NULL, 8154, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26377, 6776, NULL, 8154, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26378, 6136, NULL, 8154, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26379, 5118, NULL, 8154, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26380, 1586, NULL, 8155, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26381, 1101, NULL, 8155, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26382, 5305, NULL, 8156, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26383, 283, NULL, 8157, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26384, 2399, NULL, 8157, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26385, 1821, NULL, 8157, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26386, 2055, NULL, 8158, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26387, 9552, NULL, 8158, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26388, 1450, NULL, 8158, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26389, 1687, NULL, 8158, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26390, 939, NULL, 8158, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26391, 448, NULL, 8159, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26392, 378, NULL, 8159, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26393, 1655, NULL, 8159, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26394, 958, NULL, 8160, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26395, 4331, NULL, 8160, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26396, 162, NULL, 8160, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26397, 398, NULL, 8160, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26398, 374, NULL, 8161, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26399, 220, NULL, 8161, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26400, 1386, NULL, 8161, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26401, 1882, NULL, 8162, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26402, 2696, NULL, 8162, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26403, 850, NULL, 8162, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26404, 3642, NULL, 8162, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26405, 430, NULL, 8163, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26406, 389, NULL, 8163, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26407, 1721, NULL, 8163, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26408, 1648, NULL, 8163, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26409, 1942, NULL, 8164, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26410, 1528, NULL, 8164, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26411, 750, NULL, 8164, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26412, 1455, NULL, 8164, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26418, 5305, NULL, 8166, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26419, 283, NULL, 8167, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26420, 2399, NULL, 8167, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26421, 1821, NULL, 8167, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26422, 2055, NULL, 8168, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26423, 9552, NULL, 8168, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26424, 1450, NULL, 8168, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26425, 1687, NULL, 8168, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26426, 939, NULL, 8168, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26427, 448, NULL, 8169, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26428, 378, NULL, 8169, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26429, 1655, NULL, 8169, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26430, 958, NULL, 8170, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26431, 4331, NULL, 8170, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26432, 162, NULL, 8170, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26433, 398, NULL, 8170, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26434, 374, NULL, 8171, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26435, 220, NULL, 8171, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26436, 1386, NULL, 8171, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26437, 1882, NULL, 8172, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26438, 2696, NULL, 8172, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26439, 850, NULL, 8172, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26440, 3642, NULL, 8172, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26441, 430, NULL, 8173, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26442, 389, NULL, 8173, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26443, 1721, NULL, 8173, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26444, 1648, NULL, 8173, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26445, 1942, NULL, 8174, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26446, 1528, NULL, 8174, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26447, 750, NULL, 8174, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26448, 1455, NULL, 8174, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26449, 1329, NULL, 8175, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26450, 497, NULL, 8175, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26451, 188, NULL, 8175, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26452, 1629, NULL, 8175, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26453, 1505, NULL, 8175, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26454, 1622, NULL, 8176, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26455, 1603, NULL, 8177, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26456, 6462, NULL, 8177, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26457, 3456, NULL, 8177, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26458, 6459, NULL, 8177, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26459, 10907, NULL, 8178, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26460, 601, NULL, 8178, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26462, 1781, NULL, 8180, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26463, 320, NULL, 8180, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26464, 2731, NULL, 8180, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26465, 398, NULL, 8180, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26466, 4034, NULL, 8181, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26467, 3383, NULL, 8182, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26328, 152, NULL, 8128, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33022, 4829, NULL, 10208, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26415, 188, NULL, 8165, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26468, 6682, NULL, 8182, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26469, 2297, NULL, 8183, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26470, 1146, NULL, 8183, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26471, 2605, NULL, 8183, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26472, 11036, NULL, 8183, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26473, 11429, NULL, 8184, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26474, 7075, NULL, 8185, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26475, 2522, NULL, 8186, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26476, 11430, NULL, 8186, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26477, 11431, NULL, 8186, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26478, 3711, NULL, 8186, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26479, 6652, NULL, 8187, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26480, 7445, NULL, 8187, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26481, 799, NULL, 8187, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26482, 6576, NULL, 8187, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26484, 430, NULL, 8188, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26485, 2259, NULL, 8188, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26486, 2469, NULL, 8188, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26487, 2772, NULL, 8188, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26488, 19, NULL, 8188, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26489, 2903, NULL, 8188, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26490, 1376, NULL, 8188, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26491, 368, NULL, 8188, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (26492, 1066, NULL, 8189, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26493, 11432, NULL, 8190, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26494, 6081, NULL, 8190, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26495, 11433, NULL, 8191, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26496, 6567, NULL, 8192, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26497, 8341, NULL, 8192, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26498, 11434, NULL, 8193, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26499, 5931, NULL, 8193, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26500, 10662, NULL, 8193, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26501, 11435, NULL, 8193, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26502, 10737, NULL, 8194, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26503, 11436, NULL, 8194, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26508, 2696, NULL, 8196, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26509, 1644, NULL, 8196, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26510, 4516, NULL, 8196, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26511, 1052, NULL, 8196, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26512, 5174, NULL, 8197, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26513, 2465, NULL, 8198, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26514, 7331, NULL, 8198, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26515, 5235, NULL, 8198, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26516, 1593, NULL, 8199, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26517, 302, NULL, 8199, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26518, 8, NULL, 8199, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26519, 2920, NULL, 8200, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26520, 1042, NULL, 8200, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26521, 11437, NULL, 8201, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26522, 6898, NULL, 8202, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26523, 6046, NULL, 8203, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26524, 1373, NULL, 8203, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26525, 4034, NULL, 8203, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26526, 448, NULL, 8204, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26527, 1374, NULL, 8204, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26528, 2430, NULL, 8204, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26529, 77, NULL, 8204, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26530, 6262, NULL, 8205, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26531, 11438, NULL, 8206, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26532, 692, NULL, 8207, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26533, 382, NULL, 8207, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26534, 1513, NULL, 8207, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26535, 4034, NULL, 8208, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26536, 4740, NULL, 8208, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26537, 6523, NULL, 8208, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26538, 283, NULL, 8209, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26539, 2655, NULL, 8209, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26540, 1103, NULL, 8209, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26541, 6898, NULL, 8210, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26542, 6128, NULL, 8211, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26543, 11439, NULL, 8212, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26544, 13, NULL, 8213, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26545, 2945, NULL, 8213, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26546, 4444, NULL, 8213, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26547, 2860, NULL, 8213, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26548, 2270, NULL, 8214, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26550, 601, NULL, 8216, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26551, 2719, NULL, 8217, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26552, 152, NULL, 8218, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26553, 5125, NULL, 8218, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26554, 2576, NULL, 8218, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26555, 313, NULL, 8219, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26556, 1373, NULL, 8219, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26557, 993, NULL, 8219, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26558, 295, NULL, 8220, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26559, 6177, NULL, 8220, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26560, 724, NULL, 8221, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26561, 1876, NULL, 8221, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26562, 1622, NULL, 8221, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26563, 81, NULL, 8222, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26564, 914, NULL, 8222, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26565, 220, NULL, 8222, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26566, 7103, NULL, 8223, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26567, 7104, NULL, 8223, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26568, 981, NULL, 8224, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26569, 6178, NULL, 8225, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26570, 717, NULL, 8226, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26571, 1586, NULL, 8226, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26549, 587, 290, 8215, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26572, 1979, NULL, 8227, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26573, 1376, NULL, 8227, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26574, 374, NULL, 8228, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26575, 6179, NULL, 8229, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26576, 6183, NULL, 8229, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26577, 6180, NULL, 8229, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26578, 6181, NULL, 8229, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26579, 3700, NULL, 8230, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26580, 968, NULL, 8230, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26581, 2400, NULL, 8230, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26582, 6188, NULL, 8231, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26583, 4670, NULL, 8231, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26584, 179, NULL, 8232, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26585, 2140, NULL, 8232, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26586, 6184, NULL, 8233, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26587, 6182, NULL, 8234, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26588, 2957, NULL, 8234, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26589, 2399, NULL, 8234, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26590, 6185, NULL, 8235, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26591, 6983, NULL, 8235, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26592, 6186, NULL, 8235, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26593, 6187, NULL, 8235, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26594, 512, NULL, 8236, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26595, 4397, NULL, 8236, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26596, 1977, NULL, 8236, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26601, 11442, NULL, 8238, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26602, 11443, NULL, 8239, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26603, 1553, NULL, 8240, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26604, 2625, NULL, 8240, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26605, 2921, NULL, 8240, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26606, 2554, NULL, 8240, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26607, 850, NULL, 8241, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26608, 3287, NULL, 8241, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26609, 9552, NULL, 8241, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26610, 1965, NULL, 8241, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26611, 232, NULL, 8242, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26612, 6678, NULL, 8242, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26613, 5305, NULL, 8243, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26614, 7159, NULL, 8243, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26615, 49, NULL, 8244, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26616, 19, NULL, 8244, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26617, 2821, NULL, 8244, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26618, 857, NULL, 8244, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26619, 1662, NULL, 8245, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26620, 10295, NULL, 8245, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26621, 8, NULL, 8245, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26622, 9828, NULL, 8245, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26623, 3257, NULL, 8246, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26624, 1265, NULL, 8246, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26625, 987, NULL, 8247, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26626, 2178, NULL, 8247, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26627, 4368, NULL, 8247, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26628, 11444, NULL, 8247, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26629, 1219, NULL, 8248, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26630, 1406, NULL, 8248, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26631, 51, NULL, 8248, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26632, 1021, NULL, 8249, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26633, 1624, NULL, 8249, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26634, 2559, NULL, 8249, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26635, 1457, NULL, 8250, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26636, 1455, NULL, 8250, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26637, 5068, NULL, 8250, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26638, 2458, NULL, 8251, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26639, 1582, NULL, 8251, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26640, 2146, NULL, 8251, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26641, 11447, NULL, 8252, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26646, 11448, NULL, 8254, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26647, 11101, NULL, 8254, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26648, 11450, NULL, 8255, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26649, 5929, NULL, 8256, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26650, 10507, NULL, 8256, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26651, 11175, NULL, 8256, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26652, 4902, NULL, 8256, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26653, 11451, NULL, 8257, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26654, 11452, NULL, 8257, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26655, 11453, NULL, 8258, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26660, 11291, NULL, 8260, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26661, 11455, NULL, 8260, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26662, 11456, NULL, 8261, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26663, 11457, NULL, 8261, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26664, 7749, NULL, 8262, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26665, 11458, NULL, 8262, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26666, 5409, NULL, 8263, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26667, 10656, NULL, 8263, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26668, 10657, NULL, 8263, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26669, 10658, NULL, 8263, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26643, 2932, NULL, 8253, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26642, 2931, NULL, 8253, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26644, 2316, NULL, 8253, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26645, 10129, NULL, 8253, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26670, 6530, NULL, 8264, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26671, 4719, NULL, 8264, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26672, 11459, NULL, 8264, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26682, 408, NULL, 8268, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26683, 6422, NULL, 8268, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26689, 3946, NULL, 8271, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26690, 11464, NULL, 8271, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26700, 11466, NULL, 8275, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26704, 11467, NULL, 8279, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26705, 11416, NULL, 8279, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26706, 9867, NULL, 8280, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26707, 8790, NULL, 8280, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26708, 9672, NULL, 8280, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26709, 8252, NULL, 8280, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26710, 7452, NULL, 8281, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26715, 4436, NULL, 8283, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26716, 1903, NULL, 8283, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26729, 376, NULL, 1744, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26730, 873, NULL, 1747, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26731, 2717, NULL, 1747, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26732, 607, NULL, 1747, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26733, 1748, NULL, 1747, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26734, 3199, NULL, 1747, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26735, 10530, NULL, 1747, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26736, 1107, NULL, 1745, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26737, 452, NULL, 1745, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26738, 608, NULL, 1745, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26739, 908, NULL, 1745, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26740, 3498, NULL, 1745, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26741, 2418, NULL, 1745, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26742, 1283, NULL, 1748, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26743, 2488, NULL, 1748, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26744, 2644, NULL, 1748, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26745, 11473, NULL, 1748, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26746, 1745, NULL, 1748, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26747, 1823, NULL, 1748, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26748, 3111, NULL, 1748, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26749, 124, NULL, 1746, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26750, 2945, NULL, 1746, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26752, 1594, NULL, 1746, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26753, 312, NULL, 1746, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26754, 2704, NULL, 1746, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26755, 11474, NULL, 1746, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26756, 1391, NULL, 8286, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26757, 2816, NULL, 8286, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26758, 183, NULL, 8286, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26759, 1360, NULL, 8287, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26760, 330, NULL, 8287, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26761, 1370, NULL, 8287, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26762, 1474, NULL, 8288, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26763, 1624, NULL, 8288, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26764, 1511, NULL, 8289, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26765, 2761, NULL, 8289, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26766, 4288, NULL, 8289, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26767, 2737, NULL, 8290, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26768, 1238, NULL, 8290, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26769, 1665, NULL, 8290, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26770, 3321, NULL, 8291, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26771, 596, NULL, 8291, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26772, 4311, NULL, 8291, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26773, 470, NULL, 8292, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26774, 51, NULL, 8292, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26775, 1318, NULL, 8292, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26776, 761, NULL, 8293, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26777, 1084, NULL, 8293, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26778, 730, NULL, 8293, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26779, 1588, NULL, 8294, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26780, 5807, NULL, 8294, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26781, 1814, NULL, 8294, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26782, 41, NULL, 8295, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26783, 186, NULL, 8295, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26784, 152, NULL, 8296, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26785, 295, NULL, 8296, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26786, 3915, NULL, 8296, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26787, 2730, NULL, 8296, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26788, 909, NULL, 8297, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26789, 1423, NULL, 8297, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26790, 5315, NULL, 8297, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26791, 1882, NULL, 8298, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26792, 8035, NULL, 8298, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26793, 4361, NULL, 8299, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26794, 2516, NULL, 8299, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26795, 267, NULL, 8299, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26796, 3992, NULL, 8299, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26797, 421, NULL, 8299, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26798, 773, NULL, 8299, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26799, 749, NULL, 8300, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26800, 5113, NULL, 8300, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26801, 2724, NULL, 8300, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26802, 2382, NULL, 8300, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26803, 374, NULL, 8301, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26804, 2331, NULL, 8301, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26805, 166, NULL, 8301, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26806, 133, NULL, 8301, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26807, 1896, NULL, 8301, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26808, 123, NULL, 8301, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26809, 2430, NULL, 8301, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26810, 2163, NULL, 8301, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (26819, 448, NULL, 8303, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26820, 2709, NULL, 8303, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26821, 2226, NULL, 8303, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26822, 2985, NULL, 8303, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26823, 11477, NULL, 8303, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26824, 5156, NULL, 8303, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26825, 7925, NULL, 8303, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26826, 11478, NULL, 8303, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (26827, 448, NULL, 8304, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26828, 2619, NULL, 8304, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26829, 32, NULL, 8304, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26830, 7519, NULL, 8304, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26831, 1679, NULL, 8304, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26832, 4611, NULL, 8304, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26833, 2580, NULL, 8304, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26834, 11480, NULL, 8304, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (26835, 685, NULL, 8304, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (26836, 1329, NULL, 8305, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26837, 497, NULL, 8305, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26838, 2259, NULL, 8305, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26839, 857, NULL, 8305, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26840, 2821, NULL, 8305, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26841, 19, NULL, 8305, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26842, 2903, NULL, 8305, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26843, 2821, NULL, 8305, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (26844, 19, NULL, 8305, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (26845, 1329, NULL, 8305, 10);
INSERT INTO 'tunesrecordingsmap' VALUES (26846, 3142, NULL, 8306, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26847, 2144, NULL, 8306, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26848, 1099, NULL, 8306, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26849, 2047, NULL, 8306, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26859, 441, NULL, 8308, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26677, 2873, NULL, 8266, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26674, 11461, NULL, 8266, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26676, 11462, NULL, 8266, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26675, 11503, NULL, 8266, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26858, 1929, NULL, 8307, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (26852, 168, NULL, 8307, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26855, 3018, NULL, 8307, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26850, 441, NULL, 8307, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26857, 2905, NULL, 8307, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (26853, 5885, NULL, 8307, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26703, 11189, NULL, 8278, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26695, 6467, NULL, 8273, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26697, 1945, NULL, 8273, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26696, 1867, NULL, 8273, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26694, 1329, NULL, 8273, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26692, 3211, NULL, 8272, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26691, 7087, NULL, 8272, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26693, 11465, NULL, 8272, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26684, 7082, NULL, 8269, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26688, 5929, NULL, 8270, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26686, 11258, NULL, 8270, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26685, 1540, NULL, 8270, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26687, 5409, NULL, 8270, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26679, 123, NULL, 8267, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26680, 2931, NULL, 8267, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26681, 2226, NULL, 8267, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26678, 1458, NULL, 8267, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26698, 10279, NULL, 8274, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26699, 6267, NULL, 8274, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26673, 11460, NULL, 8265, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26714, 2993, NULL, 8282, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26711, 824, NULL, 8282, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26712, 11468, NULL, 8282, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26713, 2089, NULL, 8282, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26718, 5154, NULL, 8284, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26717, 2421, NULL, 8284, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26702, 11287, NULL, 8277, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26701, 6202, NULL, 8276, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26860, 1447, NULL, 8308, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26861, 1423, NULL, 8308, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26862, 6609, NULL, 8308, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26863, 1721, NULL, 8308, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26864, 760, NULL, 8308, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26865, 1181, NULL, 8308, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26866, 5267, NULL, 8308, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (26867, 1881, NULL, 8308, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (26868, 430, NULL, 8309, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26869, 687, NULL, 8309, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26870, 6381, NULL, 8309, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26871, 2270, 92, 8309, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26872, 5507, NULL, 8309, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26873, 6286, NULL, 8309, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26874, 122, NULL, 8309, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26875, 430, NULL, 8310, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26876, 1849, NULL, 8310, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26877, 2967, NULL, 8310, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26878, 2307, NULL, 8310, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26879, 405, NULL, 8310, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26880, 5739, NULL, 8310, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26881, 1027, NULL, 8310, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31730, 2140, NULL, 9862, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31729, 8799, NULL, 9862, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31728, 10551, NULL, 9862, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26897, 1638, NULL, 8313, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26898, 11483, NULL, 8313, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26899, 10664, NULL, 8313, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26900, 11484, NULL, 8313, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26901, 9294, NULL, 8313, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26902, 3394, NULL, 8313, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26903, 8289, NULL, 8313, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26904, 7918, NULL, 8313, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (26905, 3126, NULL, 8313, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (26906, 1638, NULL, 8314, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26907, 11485, NULL, 8314, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26908, 10645, NULL, 8314, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26909, 11486, NULL, 8314, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26910, 11487, NULL, 8314, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26911, 206, NULL, 8314, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26912, 6464, NULL, 8314, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26913, 3007, NULL, 8314, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (26914, 7511, NULL, 8314, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (26915, 11479, NULL, 8315, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26916, 1621, NULL, 8315, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26917, 11488, NULL, 8315, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26918, 1376, NULL, 8315, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26919, 11479, NULL, 8316, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26920, 1834, NULL, 8316, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26921, 1091, NULL, 8316, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26922, 1503, NULL, 8316, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26923, 382, NULL, 8316, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26924, 424, NULL, 8316, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26925, 122, NULL, 8317, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26926, 11492, NULL, 8318, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26927, 2316, NULL, 8318, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26928, 11109, NULL, 8318, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26929, 1941, NULL, 8318, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26930, 8175, NULL, 8318, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26751, 1648, 475, 1746, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31727, 13235, NULL, 9862, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31753, 5390, NULL, 9869, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26931, 10879, NULL, 8319, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26932, 11494, NULL, 8319, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26933, 9480, NULL, 8320, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26934, 10483, NULL, 8320, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26935, 10484, NULL, 8320, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26936, 10485, NULL, 8320, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26937, 11493, NULL, 8321, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26938, 11495, NULL, 8321, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26939, 3085, NULL, 8321, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26940, 10360, NULL, 8321, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26941, 10260, NULL, 8321, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26942, 11496, NULL, 8321, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26943, 11479, NULL, 8322, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26944, 2772, NULL, 8322, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26945, 3109, NULL, 8322, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26946, 5035, NULL, 8322, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26947, 11497, NULL, 8322, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26948, 2837, NULL, 816, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26949, 1181, NULL, 816, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26950, 11500, NULL, 816, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26951, 11501, NULL, 816, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26952, 11449, NULL, 8254, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26953, 11502, NULL, 8255, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26959, 11505, NULL, 8324, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26960, 2808, NULL, 8324, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26961, 11514, NULL, 8324, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26962, 2945, NULL, 8324, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26963, 11506, NULL, 8325, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26964, 3463, NULL, 8325, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26965, 2516, NULL, 8325, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26966, 6278, NULL, 8325, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26967, 1126, NULL, 8325, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26968, 134, NULL, 8325, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26969, 109, NULL, 8325, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26970, 10057, NULL, 8326, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26971, 697, NULL, 8326, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26972, 2616, NULL, 8326, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26973, 1241, NULL, 8326, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26978, 11507, NULL, 8328, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26979, 10664, NULL, 8328, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26980, 6848, NULL, 8328, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26981, 11515, NULL, 8328, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26982, 2252, NULL, 8327, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26983, 11516, NULL, 8327, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26984, 1193, NULL, 8327, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26985, 11508, NULL, 8329, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26986, 7240, NULL, 8329, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26987, 90, NULL, 8329, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26988, 2952, NULL, 8329, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26989, 10732, NULL, 8329, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26990, 11509, NULL, 8330, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26991, 11517, NULL, 8330, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26992, 11518, NULL, 8330, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26993, 1553, NULL, 8330, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26994, 11519, NULL, 8330, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26995, 1927, NULL, 8330, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26996, 11510, NULL, 8331, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26997, 11520, NULL, 8331, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26998, 1912, NULL, 8331, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26999, 3243, NULL, 8331, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27000, 11511, NULL, 8332, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27001, 11521, NULL, 8332, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27002, 11275, NULL, 8332, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27003, 11522, NULL, 8332, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27004, 11512, NULL, 8333, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27005, 10780, NULL, 8333, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27006, 11523, NULL, 8333, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27007, 5511, NULL, 8333, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27008, 11524, NULL, 8334, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27009, 8758, NULL, 8334, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27010, 1940, NULL, 8334, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27011, 7539, NULL, 8334, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27012, 11525, NULL, 8335, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27013, 11255, NULL, 8335, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27014, 4370, NULL, 8335, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27015, 11526, NULL, 8335, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27016, 11527, NULL, 8336, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27017, 4264, NULL, 6390, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27018, 1095, NULL, 8340, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27019, 5173, NULL, 8340, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27020, 480, NULL, 8340, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27021, 1620, NULL, 8341, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27022, 520, NULL, 8342, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27023, 292, NULL, 8342, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27024, 5994, NULL, 8342, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27025, 1809, NULL, 8343, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27026, 1423, NULL, 8343, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27027, 1655, NULL, 8343, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27028, 1391, NULL, 8344, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27029, 3527, NULL, 8344, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27030, 55, NULL, 8345, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27031, 6623, NULL, 8345, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27032, 5263, NULL, 8345, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27033, 730, NULL, 8346, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27034, 5371, NULL, 8346, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27035, 350, NULL, 8337, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27036, 11563, NULL, 8337, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27037, 1732, NULL, 8338, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27038, 2054, NULL, 8338, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27039, 11564, NULL, 8338, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23409, 55, NULL, 7233, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23410, 2757, NULL, 7233, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27044, 537, NULL, 8347, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27045, 2597, NULL, 8347, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27046, 4267, NULL, 8347, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27047, 10345, NULL, 8347, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27048, 156, NULL, 8348, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27049, 861, NULL, 8348, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27050, 5006, NULL, 8348, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27051, 5696, NULL, 8348, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26890, 2055, NULL, 8312, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26896, 6312, NULL, 8312, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26892, 429, NULL, 8312, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27053, 1896, NULL, 8349, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27054, 688, NULL, 8349, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27064, 611, NULL, 8352, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27065, 2714, NULL, 8352, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27066, 2892, NULL, 8352, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27067, 11468, NULL, 8352, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27068, 804, NULL, 8353, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27069, 11401, NULL, 8353, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27070, 11402, NULL, 8353, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27071, 11403, NULL, 8353, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27076, 757, NULL, 8355, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27077, 3028, NULL, 8355, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27078, 2432, NULL, 8355, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27079, 3257, NULL, 8355, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27084, 1013, NULL, 8357, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27085, 10481, NULL, 8357, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27086, 651, 200, 8357, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27087, 11702, NULL, 8357, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27088, 1331, NULL, 8358, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27089, 11703, NULL, 8358, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27090, 3870, NULL, 8358, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27091, 8269, NULL, 8358, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27092, 1391, NULL, 8359, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27093, 403, NULL, 8359, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27094, 3797, NULL, 8359, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27095, 2140, NULL, 8359, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27096, 1549, NULL, 8360, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27097, 5854, NULL, 8360, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27098, 766, NULL, 8360, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27099, 4103, NULL, 8360, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27100, 2846, NULL, 8361, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27101, 787, NULL, 8361, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27102, 2521, NULL, 8361, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27103, 365, NULL, 8361, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27104, 1603, NULL, 8362, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27105, 6462, NULL, 8362, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27106, 2788, NULL, 8362, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27107, 1933, NULL, 8362, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27108, 1613, NULL, 8363, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27109, 4500, NULL, 8363, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27110, 9850, NULL, 8363, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27111, 9851, NULL, 8363, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27116, 1620, NULL, 8365, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27117, 1992, NULL, 8366, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27118, 9682, NULL, 8366, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27119, 3188, NULL, 8366, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27120, 11704, NULL, 8366, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27121, 5979, NULL, 8366, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (27122, 977, NULL, 8367, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27063, 3559, NULL, 8351, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27062, 9342, NULL, 8351, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27061, 1089, NULL, 8351, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27060, 3637, NULL, 8351, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27057, 405, NULL, 8350, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27056, 1648, NULL, 8350, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27058, 11701, NULL, 8350, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27123, 11705, NULL, 8367, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27124, 376, NULL, 8367, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27125, 11706, NULL, 8367, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27126, 1303, NULL, 8368, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27127, 8505, NULL, 8368, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27128, 2125, NULL, 8368, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27129, 2327, NULL, 8368, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23411, 1418, NULL, 7233, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31754, 6208, NULL, 9869, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31758, 1872, NULL, 9869, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31755, 13272, NULL, 9869, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27273, 417, NULL, 8406, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27272, 13969, NULL, 8406, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27136, 105, NULL, 8370, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27137, 11709, NULL, 8370, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27138, 11710, NULL, 8370, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27139, 11711, NULL, 8370, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27140, 8846, NULL, 8371, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27141, 11712, NULL, 8371, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27142, 11713, NULL, 8371, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27147, 248, NULL, 8373, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27148, 2410, NULL, 8373, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27149, 652, NULL, 8373, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27150, 2434, NULL, 8373, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27151, 2031, NULL, 8373, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (27152, 1371, NULL, 8374, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27153, 318, NULL, 8374, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27154, 4496, NULL, 8374, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27155, 556, NULL, 8374, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27156, 8072, 259, 8374, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (27157, 1373, NULL, 8374, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (27158, 624, NULL, 8374, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (27159, 1066, NULL, 8374, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (27160, 1809, NULL, 8375, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27161, 166, NULL, 8375, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27162, 1832, NULL, 8375, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27163, 457, NULL, 8375, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27164, 1701, NULL, 8375, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (27165, 1046, NULL, 8375, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (27166, 3912, NULL, 8375, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (27167, 835, NULL, 8375, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (27168, 11714, NULL, 8376, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27169, 7281, NULL, 8376, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27170, 46, NULL, 8377, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27171, 11715, NULL, 8377, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27172, 9614, NULL, 8377, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27173, 11316, NULL, 8377, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27174, 11716, NULL, 8377, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (27182, 122, NULL, 8379, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27052, 128, 379, 8349, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27276, 570, NULL, 8407, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27277, 11761, NULL, 8407, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27278, 11762, NULL, 8407, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27279, 9922, NULL, 8407, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27280, 2710, NULL, 8408, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27281, 764, NULL, 8408, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27282, 9070, 235, 8408, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27283, 6876, NULL, 8408, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27284, 4441, NULL, 8409, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27285, 11763, NULL, 8409, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27286, 2967, NULL, 8409, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27287, 1716, NULL, 8409, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27288, 11764, NULL, 8410, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27289, 11765, NULL, 8410, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27290, 8619, NULL, 8410, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27291, 11766, NULL, 8410, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27292, 254, NULL, 8411, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27293, 11767, NULL, 8411, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27294, 4800, NULL, 8411, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27295, 5153, NULL, 8411, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27296, 290, NULL, 8412, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27297, 11768, NULL, 8412, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27298, 6375, NULL, 8412, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27299, 11769, NULL, 8412, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27300, 1241, NULL, 8413, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27301, 11770, NULL, 8413, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27302, 11771, NULL, 8413, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27303, 11772, NULL, 8413, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27304, 1964, NULL, 8414, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27305, 11773, NULL, 8414, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27306, 11774, NULL, 8414, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27311, 2738, NULL, 8416, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27312, 6567, NULL, 8416, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27313, 5304, NULL, 8416, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27314, 11777, 260, 8417, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27315, 11778, NULL, 8417, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27316, 1122, NULL, 8417, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27317, 4750, NULL, 8417, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27318, 11758, NULL, 8418, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27319, 9319, NULL, 8418, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27320, 6876, NULL, 8418, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27321, 11779, NULL, 8418, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27322, 11780, NULL, 8419, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27323, 11781, NULL, 8420, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27324, 2802, NULL, 8421, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27325, 6167, NULL, 8421, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27326, 11783, NULL, 8422, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27327, 11784, NULL, 8422, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27328, 129, NULL, 8423, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27329, 148, 261, 8424, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27330, 1805, 262, 8424, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27331, 1665, NULL, 8425, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27332, 78, NULL, 8425, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27333, 1181, NULL, 8426, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27334, 2180, NULL, 8426, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27336, 2579, 263, 8427, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27337, 472, NULL, 8429, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27338, 11785, NULL, 8429, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27339, 11786, NULL, 8430, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27340, 11787, NULL, 8430, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27341, 11788, NULL, 8431, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27342, 1802, 264, 8431, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27343, 534, NULL, 8432, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27344, 955, NULL, 8432, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27310, 1863, NULL, 8415, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27308, 11775, NULL, 8415, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27309, 11776, NULL, 8415, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27146, 2905, NULL, 8372, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27143, 804, NULL, 8372, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27145, 10587, NULL, 8372, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27144, 11476, NULL, 8372, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27181, 11721, NULL, 8378, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (27175, 2829, NULL, 8378, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27177, 11717, NULL, 8378, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27115, 2226, NULL, 8364, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27114, 4236, NULL, 8364, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27113, 1468, NULL, 8364, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27112, 2798, NULL, 8364, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27345, 11789, NULL, 8433, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27346, 11790, NULL, 8433, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27347, 11791, NULL, 8433, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27348, 687, NULL, 8434, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27349, 405, NULL, 8434, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27350, 1387, 265, 8435, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27351, 11792, NULL, 8435, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27352, 11793, NULL, 8436, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27353, 472, NULL, 8437, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27354, 11794, NULL, 8437, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27356, 1805, 267, 8438, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27357, 2556, NULL, 8438, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27358, 1181, NULL, 8439, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27359, 1881, NULL, 8439, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27360, 11794, 267, 8440, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27361, 5370, NULL, 8440, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27362, 3713, NULL, 8440, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27367, 11782, NULL, 8442, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27368, 11797, NULL, 8442, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27369, 1179, NULL, 8443, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27370, 2967, NULL, 8443, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27371, 415, NULL, 8444, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27372, 11798, NULL, 8444, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27373, 1435, 237, 8445, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27374, 730, NULL, 8445, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27375, 11799, NULL, 8446, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27376, 11800, NULL, 8447, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27377, 11217, 270, 8448, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27378, 11782, NULL, 8448, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27379, 5123, NULL, 8449, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27380, 11801, NULL, 8449, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27381, 2822, NULL, 8449, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27382, 917, NULL, 8450, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27383, 6747, NULL, 8450, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27384, 415, NULL, 8451, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27385, 6914, NULL, 8451, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27386, 11802, NULL, 8452, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27387, 1785, NULL, 8453, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27388, 8990, NULL, 8453, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27389, 5919, NULL, 8454, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27390, 415, NULL, 8455, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27391, 11803, NULL, 8455, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27393, 1457, NULL, 8457, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27394, 7678, 185, 8457, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27395, 11740, NULL, 8457, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27396, 2579, NULL, 8457, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27401, 430, NULL, 8459, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27402, 3242, NULL, 8459, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27403, 4437, NULL, 8459, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27404, 11741, NULL, 8459, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27405, 10669, NULL, 8460, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27406, 11742, NULL, 8460, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27407, 11743, NULL, 8460, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27408, 9680, NULL, 8460, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27409, 121, NULL, 8461, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27410, 5569, NULL, 8461, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27411, 4912, NULL, 8461, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27412, 2404, NULL, 8461, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27413, 971, NULL, 8462, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27414, 1600, NULL, 8462, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27415, 754, NULL, 8462, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27416, 4401, NULL, 8462, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27417, 1212, NULL, 8463, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27418, 11744, NULL, 8463, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27419, 3217, NULL, 8463, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27420, 2948, NULL, 8463, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27425, 183, NULL, 8465, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27426, 1707, NULL, 8465, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27427, 9066, NULL, 8465, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27399, 4907, NULL, 8458, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27397, 2369, NULL, 8458, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27400, 1193, NULL, 8458, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27398, 6732, NULL, 8458, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27392, 1995, NULL, 8456, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27428, 7484, NULL, 8465, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27433, 11745, NULL, 8467, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27437, 6335, NULL, 8469, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27438, 791, NULL, 8470, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27439, 1643, NULL, 8470, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27440, 1700, NULL, 8470, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27441, 661, NULL, 8470, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27442, 10191, NULL, 8471, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27443, 9070, NULL, 8471, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27444, 2312, NULL, 8471, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27445, 11746, NULL, 8471, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27446, 411, NULL, 8472, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27447, 4925, NULL, 8472, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27448, 1908, 271, 8472, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27449, 11747, NULL, 8472, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27450, 1450, NULL, 8473, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27451, 11748, NULL, 8473, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27452, 11749, NULL, 8473, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27454, 5273, NULL, 8474, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27455, 103, NULL, 8474, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27456, 432, NULL, 8474, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27457, 10171, NULL, 8474, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27458, 11750, NULL, 8475, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27459, 10219, NULL, 8475, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27460, 11751, NULL, 8475, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27461, 8521, NULL, 8475, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27462, 1528, NULL, 8476, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27463, 5995, NULL, 8476, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27464, 2665, NULL, 8476, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27465, 4779, NULL, 8476, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27466, 11752, NULL, 8477, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27467, 11753, NULL, 8477, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27468, 10633, NULL, 8477, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27469, 5959, NULL, 8477, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27470, 179, NULL, 8478, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27471, 3033, NULL, 8478, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27472, 2816, NULL, 8478, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27473, 2534, NULL, 8478, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27474, 1567, NULL, 8479, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27475, 11754, NULL, 8479, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27476, 6800, NULL, 8479, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27477, 3013, NULL, 8479, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27478, 11755, NULL, 8480, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27479, 11756, NULL, 8481, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27480, 7560, NULL, 8481, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27481, 11757, NULL, 8481, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27482, 794, NULL, 8502, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27483, 7242, NULL, 8502, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27484, 11804, NULL, 8502, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27485, 3064, NULL, 8502, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27486, 6531, NULL, 8503, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27487, 11805, NULL, 8503, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27488, 11223, NULL, 8504, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27365, 11795, NULL, 8441, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27489, 11806, NULL, 8504, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27490, 11807, NULL, 8505, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27491, 11808, NULL, 8505, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27492, 11809, NULL, 8506, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27493, 7281, NULL, 8507, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27494, 9964, NULL, 8507, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27495, 11810, NULL, 8507, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27496, 11811, NULL, 8507, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27497, 11812, NULL, 8508, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27498, 11813, NULL, 8508, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27499, 5499, NULL, 8509, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27500, 5000, NULL, 8509, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27501, 11814, NULL, 8509, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27502, 2820, NULL, 8509, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27503, 2998, NULL, 8509, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (27504, 11815, NULL, 8510, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27505, 11816, NULL, 8510, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27506, 11817, NULL, 8510, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27507, 11818, NULL, 8510, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27508, 11819, NULL, 8511, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27509, 4907, NULL, 8511, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27510, 11820, NULL, 8512, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27511, 11821, NULL, 8513, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27512, 11822, NULL, 8513, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27513, 534, NULL, 8514, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27514, 8289, NULL, 8514, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27515, 8309, NULL, 8514, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27516, 8291, NULL, 8514, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27517, 11823, NULL, 8515, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27518, 4472, NULL, 8515, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33036, 5738, NULL, 7231, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27335, 181, NULL, 8427, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27521, 1457, NULL, 8517, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27522, 7240, NULL, 8517, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27523, 11826, NULL, 8517, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27524, 8350, NULL, 8517, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27525, 11827, NULL, 8517, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (27526, 11828, NULL, 8517, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (27527, 5409, NULL, 8517, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (27528, 11419, NULL, 8517, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (27529, 1781, NULL, 8518, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27530, 2990, NULL, 8518, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27531, 398, NULL, 8518, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27532, 320, NULL, 8518, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27533, 232, NULL, 8519, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27534, 2646, 272, 8519, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27535, 11829, NULL, 8519, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27536, 11830, NULL, 8519, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27537, 11831, NULL, 8520, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27538, 11224, NULL, 8521, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27539, 1334, NULL, 8521, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27540, 2592, NULL, 8521, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27541, 1907, NULL, 8521, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27542, 6262, NULL, 8522, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27543, 3428, NULL, 8523, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27544, 1903, NULL, 8523, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27545, 11832, NULL, 8523, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27546, 216, NULL, 8524, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27547, 2728, NULL, 8524, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27548, 1089, NULL, 8524, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27549, 1125, NULL, 8525, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27550, 11833, NULL, 8525, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27551, 11834, NULL, 8525, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27552, 5926, NULL, 8525, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27553, 2645, NULL, 8525, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (27554, 4690, NULL, 8526, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27555, 11835, NULL, 8527, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27556, 1708, NULL, 8527, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27557, 6808, NULL, 8527, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27558, 591, NULL, 8527, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27559, 626, NULL, 8528, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27560, 2010, NULL, 8528, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27561, 78, NULL, 8528, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27562, 3061, NULL, 8528, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27563, 11439, NULL, 8529, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27564, 6035, NULL, 8530, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27565, 1690, NULL, 8530, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27566, 624, NULL, 8530, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27567, 1832, NULL, 8530, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27568, 11836, NULL, 8531, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27569, 7087, NULL, 8531, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27570, 419, NULL, 8532, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27571, 2300, NULL, 8532, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27572, 1096, NULL, 8532, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27573, 1846, NULL, 8532, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27574, 41, NULL, 8533, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27575, 1034, NULL, 8533, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27453, 9505, 283, 8473, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27576, 839, NULL, 8533, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27577, 2145, NULL, 8533, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27578, 4101, NULL, 8534, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27579, 4397, NULL, 8534, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27580, 11837, NULL, 8535, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27581, 700, NULL, 8536, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27582, 3066, NULL, 8536, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27583, 2159, NULL, 8536, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27584, 3057, NULL, 8536, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27585, 7020, NULL, 8537, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27586, 7078, NULL, 8537, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27587, 5384, NULL, 8537, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27436, 209, NULL, 8468, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27435, 1656, NULL, 8468, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27434, 1757, NULL, 8468, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27655, 206, NULL, 8570, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27629, 1929, NULL, 8558, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27630, 11839, NULL, 8558, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27631, 11840, NULL, 8558, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27638, 11846, NULL, 8562, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27640, 11848, NULL, 8564, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27641, 5528, NULL, 8564, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27642, 11849, NULL, 8564, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27643, 11850, NULL, 8565, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27650, 11856, NULL, 8568, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27654, 9514, NULL, 8570, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27657, 4449, NULL, 8571, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27658, 6806, NULL, 8571, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27659, 10295, NULL, 8571, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27660, 11859, NULL, 8571, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27661, 7325, NULL, 8572, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27662, 6984, NULL, 8572, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27663, 11860, NULL, 8572, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27664, 11861, NULL, 8572, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27665, 11862, NULL, 8573, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27666, 2968, NULL, 8573, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27668, 11865, NULL, 8574, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27669, 11464, NULL, 8574, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27670, 283, NULL, 8575, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27671, 369, NULL, 8575, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27672, 11866, NULL, 8575, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27673, 6224, NULL, 8576, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27674, 10897, NULL, 8577, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27656, 3001, NULL, 8570, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27675, 3938, NULL, 8578, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27676, 4323, NULL, 8578, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27677, 11864, NULL, 8579, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27678, 1732, NULL, 8580, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27679, 1448, NULL, 8580, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27680, 7531, NULL, 8581, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27681, 1020, NULL, 8581, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27682, 6459, NULL, 8581, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27683, 1421, 273, 8582, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27684, 7242, NULL, 8582, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27685, 2987, NULL, 8582, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27686, 3064, NULL, 8582, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27687, 1458, NULL, 8583, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27688, 688, NULL, 8583, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27689, 4085, NULL, 8583, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27690, 722, NULL, 8584, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27691, 6471, NULL, 8584, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27692, 2575, NULL, 8584, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27693, 3123, NULL, 8584, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27694, 10664, NULL, 8585, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27695, 5885, NULL, 8585, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27696, 9672, NULL, 8585, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27697, 8498, NULL, 8585, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27698, 11867, NULL, 8586, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27699, 11868, NULL, 8587, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27700, 5300, NULL, 8587, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27701, 2260, NULL, 8588, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27702, 11869, NULL, 8589, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27703, 2757, NULL, 8589, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27704, 8797, NULL, 8589, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27705, 6807, NULL, 8589, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27706, 3946, NULL, 8590, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27707, 6566, NULL, 8590, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27708, 7119, NULL, 8590, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27709, 374, NULL, 8591, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27710, 123, NULL, 8591, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27711, 1933, NULL, 8591, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27712, 11287, NULL, 8592, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27713, 11870, NULL, 8593, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27714, 11871, NULL, 8593, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27715, 11872, NULL, 8593, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27716, 11873, NULL, 8593, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27717, 11874, NULL, 8594, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27718, 2496, NULL, 8595, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27719, 2952, NULL, 8595, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27720, 9364, NULL, 8595, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27721, 11877, NULL, 8596, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27722, 3010, NULL, 8596, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27723, 10625, NULL, 8596, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27724, 11875, NULL, 8597, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27725, 408, NULL, 8598, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27726, 601, NULL, 8598, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27731, 4653, 219, 8600, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27732, 11881, NULL, 8600, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27733, 2491, NULL, 8600, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27634, 11843, NULL, 8560, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27633, 11842, NULL, 8560, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27635, 11844, NULL, 8560, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27644, 792, NULL, 8566, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27645, 11851, NULL, 8566, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27646, 11852, NULL, 8566, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27632, 11841, NULL, 8559, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27628, 11838, NULL, 8557, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27651, 11857, NULL, 8569, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27652, 5961, NULL, 8569, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27649, 11855, NULL, 8567, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27647, 11853, NULL, 8567, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27648, 1146, NULL, 8567, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27734, 11882, NULL, 8600, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27735, 11883, NULL, 8601, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27736, 6771, NULL, 8601, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27737, 6772, NULL, 8601, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27738, 11884, NULL, 8602, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27739, 2877, NULL, 8603, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27740, 2921, NULL, 8603, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27741, 2554, NULL, 8603, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27742, 2902, NULL, 8604, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27743, 11876, NULL, 8605, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27744, 11885, NULL, 8605, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27745, 11886, NULL, 8606, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27746, 6322, NULL, 8606, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27747, 11887, NULL, 8606, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27748, 11888, NULL, 8606, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27749, 90, NULL, 8607, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27750, 429, NULL, 8607, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27751, 2886, NULL, 8607, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27752, 2742, NULL, 8607, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27753, 9177, NULL, 8608, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27754, 1903, NULL, 8608, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27755, 11889, NULL, 8609, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27756, 3199, NULL, 8609, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27757, 11890, NULL, 8609, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27758, 11891, NULL, 8610, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27759, 10990, NULL, 8611, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27760, 6345, NULL, 8611, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27765, 11892, NULL, 8613, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27766, 11893, NULL, 8613, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27767, 11894, NULL, 8613, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27768, 374, NULL, 8614, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27769, 5308, NULL, 8614, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27770, 411, NULL, 8614, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27771, 576, NULL, 8614, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27772, 11895, NULL, 8615, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27773, 11896, NULL, 8615, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27667, 1861, NULL, 8573, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27774, 11897, NULL, 8616, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27775, 11898, NULL, 8616, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27780, 5285, NULL, 8618, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27781, 11901, NULL, 8619, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27782, 1265, NULL, 8619, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27783, 11220, NULL, 8620, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27784, 5197, NULL, 8621, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27785, 2921, NULL, 8622, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27786, 9514, NULL, 8622, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27787, 11902, NULL, 8622, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27788, 8714, NULL, 8622, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27789, 5832, NULL, 8623, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27790, 11903, NULL, 8623, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27791, 2952, NULL, 8624, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27792, 5931, NULL, 8624, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27793, 11176, NULL, 8624, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27794, 9916, NULL, 8624, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27795, 11904, NULL, 8625, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27796, 4310, NULL, 8625, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27800, 11905, NULL, 8627, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27801, 2577, NULL, 8627, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27776, 11052, NULL, 8617, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27778, 11900, NULL, 8617, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27779, 2635, NULL, 8617, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27802, 1732, NULL, 8627, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27803, 914, NULL, 8627, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27804, 5263, NULL, 8628, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27805, 1363, NULL, 8628, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27806, 512, NULL, 8629, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27807, 11906, NULL, 8629, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27808, 565, NULL, 8629, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27809, 10018, NULL, 8629, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27854, 5174, NULL, 8650, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27858, 7450, NULL, 8652, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27859, 6046, NULL, 8652, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27860, 5371, NULL, 8652, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27861, 2823, NULL, 8654, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27862, 11907, NULL, 8654, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27863, 3600, NULL, 8655, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27864, 297, NULL, 8655, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27865, 1850, NULL, 8655, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27866, 987, NULL, 8656, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27867, 10973, NULL, 8656, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27868, 1125, NULL, 8656, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27869, 11908, NULL, 8657, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27870, 1502, NULL, 8657, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27871, 1609, NULL, 8658, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27872, 1042, NULL, 8658, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27873, 267, NULL, 8658, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27874, 1464, NULL, 8660, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27875, 2264, NULL, 8660, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27876, 11909, NULL, 8661, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27877, 5297, NULL, 8661, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27878, 1027, NULL, 8662, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27879, 1395, NULL, 8662, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27880, 51, NULL, 8662, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27881, 11910, NULL, 8663, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27882, 11911, NULL, 8663, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27883, 2920, NULL, 8664, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27884, 2118, NULL, 8664, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27885, 267, NULL, 8664, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27886, 833, NULL, 8665, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27887, 1527, NULL, 8665, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27888, 1431, NULL, 8665, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27889, 5305, NULL, 8666, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27890, 7159, NULL, 8666, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27891, 2696, NULL, 8667, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27892, 935, NULL, 8667, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27893, 1970, NULL, 8667, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27894, 7097, NULL, 8668, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27895, 11912, NULL, 8668, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27896, 3276, NULL, 8668, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27897, 11837, NULL, 8669, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27898, 4382, NULL, 8670, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27899, 312, NULL, 8670, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27900, 1732, NULL, 8670, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27902, 132, NULL, 8672, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27903, 3642, NULL, 8673, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27904, 4077, NULL, 8673, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27905, 408, NULL, 8674, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27906, 2680, NULL, 8675, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27907, 2465, NULL, 8676, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27908, 2541, NULL, 8676, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27909, 4916, NULL, 8676, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27910, 11913, NULL, 8678, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27911, 5634, NULL, 8678, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27912, 1464, NULL, 8678, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27913, 6128, NULL, 8679, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27914, 448, NULL, 8680, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27915, 423, NULL, 8680, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27916, 11528, NULL, 8680, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27917, 8855, NULL, 8681, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27918, 773, NULL, 8682, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27919, 2536, NULL, 8682, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27920, 1659, NULL, 8682, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27921, 685, NULL, 8682, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27922, 283, NULL, 8683, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27923, 2655, NULL, 8683, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27924, 1103, NULL, 8683, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27925, 156, NULL, 8684, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27926, 512, NULL, 8685, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27927, 1112, NULL, 8685, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27928, 86, NULL, 8685, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27929, 2661, NULL, 8685, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27930, 1748, NULL, 8685, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (27931, 6924, NULL, 8686, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27932, 2465, NULL, 8686, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27933, 987, NULL, 8686, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27934, 534, NULL, 8687, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27935, 3013, NULL, 8687, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27936, 1696, NULL, 8687, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27937, 128, NULL, 8687, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27938, 6224, NULL, 8688, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27947, 11852, NULL, 8690, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27948, 11916, NULL, 8690, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27949, 1942, NULL, 8690, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27950, 98, NULL, 8691, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27951, 3521, NULL, 8691, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27952, 11917, NULL, 8691, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27953, 687, NULL, 8691, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27954, 4825, NULL, 8692, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27955, 5672, NULL, 8692, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27956, 11918, NULL, 8692, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27957, 1457, NULL, 8693, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27958, 3996, NULL, 8693, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27959, 1528, NULL, 8693, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27960, 6204, NULL, 8693, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27961, 186, NULL, 8694, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27962, 5126, 67, 8694, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27963, 981, NULL, 8694, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27964, 122, NULL, 8694, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27965, 939, NULL, 8695, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27966, 1437, NULL, 8695, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27967, 5017, NULL, 8695, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27968, 4950, NULL, 8695, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27969, 1266, NULL, 8696, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27970, 1578, NULL, 8696, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27971, 5328, NULL, 8696, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27637, 5322, NULL, 8561, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27636, 357, 580, 8561, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27798, 691, NULL, 8626, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27799, 6336, NULL, 8626, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27797, 3276, NULL, 8626, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27639, 11409, 593, 8563, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27972, 1373, 33, 8696, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19645, 179, NULL, 6077, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19648, 3232, NULL, 6077, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19651, 2128, NULL, 6077, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (27976, 11698, NULL, 8698, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27977, 1553, NULL, 8698, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27978, 1261, NULL, 8698, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27979, 1638, NULL, 8698, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27980, 1882, NULL, 8699, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27981, 6987, NULL, 8700, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27982, 1021, NULL, 8700, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27983, 10530, NULL, 8700, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27984, 378, NULL, 8700, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27985, 5643, NULL, 8701, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27986, 1218, NULL, 8701, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27987, 835, NULL, 8701, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27988, 1458, NULL, 8701, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27989, 11920, NULL, 8702, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27990, 6823, NULL, 8702, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27991, 8128, NULL, 8702, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27992, 7530, NULL, 8703, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27993, 2400, NULL, 8703, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27994, 487, NULL, 8704, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27995, 123, NULL, 8704, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27996, 133, NULL, 8704, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27997, 1725, NULL, 8704, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27998, 2920, NULL, 8705, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27999, 4825, NULL, 8705, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28000, 68, NULL, 8705, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28001, 305, NULL, 8705, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28002, 2055, 39, 8706, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28003, 2411, NULL, 8706, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28004, 2191, NULL, 8706, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28005, 299, NULL, 8706, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28006, 790, NULL, 8707, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28007, 313, NULL, 8707, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28008, 4741, NULL, 8707, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28009, 5115, NULL, 8707, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28010, 11921, NULL, 8708, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28011, 534, NULL, 8708, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28012, 1091, NULL, 8708, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28013, 497, NULL, 8708, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28014, 4310, NULL, 8709, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28015, 11922, NULL, 8709, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28016, 955, NULL, 8710, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28017, 1179, NULL, 8710, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28018, 6922, NULL, 8710, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28019, 4264, NULL, 8710, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28020, 179, NULL, 8711, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28021, 11078, NULL, 8711, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28022, 11923, NULL, 8711, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28023, 1882, NULL, 8712, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28024, 11924, NULL, 8712, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28025, 5142, NULL, 8713, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28026, 5507, NULL, 8713, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28027, 1026, NULL, 8714, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28028, 842, NULL, 8714, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28029, 1997, NULL, 8714, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28030, 1707, NULL, 8714, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28031, 1005, NULL, 8715, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28032, 1448, NULL, 8716, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27901, 1005, NULL, 8671, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28033, 3919, 215, 8716, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28034, 648, NULL, 8716, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28035, 686, NULL, 8716, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28036, 11925, NULL, 8717, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28037, 11926, NULL, 8717, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28038, 11927, NULL, 8717, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28039, 2178, NULL, 8717, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28040, 11928, NULL, 8717, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28042, 11929, NULL, 8718, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28043, 4733, NULL, 8718, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28044, 1876, NULL, 8718, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28045, 2505, NULL, 8719, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28046, 8, NULL, 8719, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28047, 1650, NULL, 8719, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28048, 1455, NULL, 8719, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28049, 7452, NULL, 8720, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28050, 5628, NULL, 8721, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28051, 955, NULL, 8722, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28052, 1031, 173, 8722, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28053, 1179, NULL, 8722, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28054, 4310, NULL, 8723, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28055, 1902, NULL, 8723, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28056, 5263, NULL, 8724, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28057, 4104, NULL, 8724, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28058, 11227, NULL, 8725, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28059, 11930, NULL, 8725, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28060, 1265, NULL, 8725, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28061, 11931, NULL, 8726, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28062, 1042, NULL, 8726, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28063, 3682, NULL, 8726, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28064, 11932, NULL, 8727, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28065, 5197, NULL, 8729, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28066, 4101, NULL, 8730, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28067, 1502, NULL, 8730, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28068, 812, NULL, 8731, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28069, 2853, NULL, 8731, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28070, 1077, NULL, 8731, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28071, 100, NULL, 8732, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28072, 687, NULL, 8732, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28073, 2839, NULL, 8732, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28074, 122, NULL, 8732, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28075, 6079, NULL, 8733, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28076, 7476, NULL, 8733, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28077, 11933, NULL, 8734, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28078, 1095, NULL, 8735, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28079, 312, NULL, 8735, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28080, 6764, NULL, 8735, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28081, 2492, NULL, 8735, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28082, 5305, NULL, 8736, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28083, 73, NULL, 8736, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28084, 41, NULL, 8737, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28085, 13, NULL, 8737, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28086, 981, NULL, 8738, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28087, 9659, NULL, 8738, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28088, 11934, NULL, 8739, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28089, 5011, NULL, 8739, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28090, 5303, NULL, 8739, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28091, 2129, NULL, 8740, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28092, 5262, NULL, 8740, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28093, 4167, NULL, 8741, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28094, 1431, NULL, 8741, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28095, 6492, NULL, 8742, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28096, 1971, NULL, 8742, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28097, 1329, NULL, 8743, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28098, 11503, NULL, 8743, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28099, 9514, NULL, 8743, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28100, 6850, NULL, 8744, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28101, 4310, NULL, 8744, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28102, 448, NULL, 8745, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28103, 1514, NULL, 8745, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28104, 220, NULL, 8745, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28105, 11833, NULL, 8746, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28106, 11834, NULL, 8746, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28107, 5926, NULL, 8746, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28108, 11935, NULL, 8746, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28109, 6823, NULL, 8747, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28110, 11936, NULL, 8747, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28111, 1708, NULL, 8747, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28112, 417, NULL, 8748, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28113, 11938, NULL, 8748, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28114, 11939, NULL, 8748, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28115, 11940, NULL, 8749, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28116, 11941, NULL, 8749, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28117, 9774, NULL, 8749, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28118, 654, NULL, 8750, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28119, 3153, NULL, 8750, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28120, 11942, NULL, 8751, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28121, 11943, NULL, 8752, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28122, 857, NULL, 8752, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28123, 11944, NULL, 8752, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28124, 11945, NULL, 8753, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28125, 1421, NULL, 8753, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28126, 11946, NULL, 8753, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28127, 11947, NULL, 8754, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28128, 6879, NULL, 8754, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28129, 11948, NULL, 8754, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28130, 2243, NULL, 8755, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28131, 6314, NULL, 8755, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28132, 11949, NULL, 8756, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28133, 19, NULL, 8757, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28134, 2903, NULL, 8757, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28135, 11950, NULL, 8758, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28136, 11951, NULL, 8758, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28137, 11952, NULL, 8759, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28138, 11953, NULL, 8759, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28139, 4381, NULL, 8759, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28142, 11955, NULL, 8761, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28143, 11956, NULL, 8762, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28144, 11957, NULL, 8762, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28145, 11958, NULL, 8762, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28146, 11959, NULL, 8763, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28147, 1905, NULL, 8763, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28148, 3158, NULL, 8763, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28149, 750, NULL, 8763, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28150, 11960, NULL, 8764, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28151, 1363, NULL, 8765, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28152, 2576, NULL, 8765, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28153, 11961, NULL, 8766, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28141, 11911, NULL, 8760, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27944, 11914, NULL, 8689, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (28154, 5427, NULL, 8766, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28155, 2772, NULL, 8766, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28156, 11962, NULL, 8767, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28157, 2724, NULL, 8768, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28158, 11963, NULL, 8768, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28159, 3383, NULL, 8769, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28160, 11964, NULL, 8769, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28161, 152, NULL, 8770, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28162, 3642, NULL, 8770, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28163, 295, NULL, 8770, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28164, 2910, NULL, 8771, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28165, 2986, NULL, 8771, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28166, 11937, NULL, 8771, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28167, 11965, NULL, 8771, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28168, 688, NULL, 8771, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28169, 6286, NULL, 8772, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28170, 6287, NULL, 8772, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28171, 9659, NULL, 8773, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28172, 981, NULL, 8773, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28176, 448, NULL, 8775, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28177, 914, NULL, 8775, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28178, 220, NULL, 8775, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28179, 1374, NULL, 8775, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28180, 188, NULL, 8775, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28181, 644, NULL, 8776, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28182, 1363, NULL, 8776, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28183, 451, NULL, 8777, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28185, 687, NULL, 8777, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28186, 1699, NULL, 8777, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28187, 8132, NULL, 8778, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28188, 5262, NULL, 8778, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28198, 6394, NULL, 8780, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28199, 6405, NULL, 8780, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28200, 5000, NULL, 8780, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28201, 5727, NULL, 8780, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28202, 10990, NULL, 8781, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28203, 63, NULL, 8781, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28204, 588, NULL, 8782, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28205, 1026, 10, 8782, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28206, 2442, NULL, 8782, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28207, 318, NULL, 8783, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28208, 4085, NULL, 8783, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28209, 682, NULL, 8783, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28210, 5297, NULL, 8784, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28211, 316, NULL, 8784, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28212, 5256, NULL, 8785, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28213, 1106, NULL, 8785, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28214, 238, NULL, 8785, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28215, 6288, NULL, 8785, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28216, 6236, NULL, 8786, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28217, 1744, NULL, 8786, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28218, 5212, NULL, 8787, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28219, 5204, NULL, 8787, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28220, 430, NULL, 8788, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28221, 6101, NULL, 8788, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28222, 5066, NULL, 8789, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28223, 697, NULL, 8789, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28224, 11966, NULL, 8789, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28225, 3959, NULL, 8790, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28226, 6223, NULL, 8791, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28227, 11967, NULL, 8792, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28228, 5925, NULL, 8792, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28229, 1084, 84, 8792, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28230, 1027, NULL, 8793, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28231, 11968, NULL, 8793, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28236, 4940, NULL, 8795, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28237, 6287, NULL, 8795, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28238, 7331, NULL, 8796, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28239, 7345, NULL, 8796, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28240, 1799, NULL, 8796, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28241, 42, NULL, 8797, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28242, 11191, NULL, 8798, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28243, 1586, NULL, 8799, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28244, 1705, NULL, 8799, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28245, 2964, NULL, 8799, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28246, 5325, NULL, 8800, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28247, 11969, NULL, 8800, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28248, 374, NULL, 8801, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28249, 188, NULL, 8801, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28250, 2609, NULL, 8802, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28251, 109, NULL, 8802, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28252, 267, NULL, 8802, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19646, 2218, NULL, 6077, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19649, 2545, NULL, 6077, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (19652, 2654, NULL, 6077, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (28260, 11970, NULL, 8805, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28261, 4670, NULL, 8805, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28262, 6110, NULL, 8805, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28263, 1425, NULL, 8806, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28264, 1731, NULL, 8806, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28265, 234, NULL, 8806, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28266, 4688, NULL, 8807, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28267, 1454, NULL, 8808, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28268, 915, NULL, 8808, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28269, 11971, NULL, 8809, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28270, 171, NULL, 8810, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28271, 835, NULL, 8810, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28272, 3779, NULL, 8810, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28277, 7547, NULL, 8812, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28278, 1118, NULL, 8812, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28279, 1117, NULL, 8812, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28280, 11975, NULL, 8812, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28284, 11977, NULL, 8814, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28285, 11978, NULL, 8814, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28286, 11979, NULL, 8814, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28287, 5535, NULL, 8815, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28288, 3054, NULL, 8815, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28289, 1600, NULL, 8815, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28290, 2508, NULL, 8815, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28291, 11980, NULL, 8816, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28292, 11981, NULL, 8816, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28293, 231, NULL, 8817, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28294, 833, NULL, 8817, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28295, 6759, NULL, 8817, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28300, 849, NULL, 8819, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28301, 9684, NULL, 8819, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28302, 3836, NULL, 8819, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28303, 124, NULL, 8820, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28304, 2492, NULL, 8820, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28305, 952, NULL, 8820, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28306, 1778, NULL, 8820, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28307, 295, NULL, 8821, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28308, 1562, NULL, 8821, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28309, 9621, NULL, 8821, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28310, 1403, NULL, 8821, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28311, 1841, NULL, 8822, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28313, 2611, NULL, 8822, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28314, 812, NULL, 8822, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28315, 757, NULL, 8823, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28316, 7176, NULL, 8823, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28317, 2356, NULL, 8823, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28318, 761, NULL, 8824, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28319, 664, NULL, 8824, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28320, 302, NULL, 8824, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28321, 1481, NULL, 8824, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28328, 1785, NULL, 8827, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28329, 963, NULL, 8827, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28330, 9685, NULL, 8827, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28331, 1158, NULL, 8828, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28332, 1328, NULL, 8828, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28336, 283, NULL, 8830, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28337, 1181, NULL, 8830, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28338, 1716, NULL, 8830, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28339, 4578, NULL, 8830, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28343, 11596, NULL, 8832, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28344, 11597, NULL, 8832, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28345, 11598, NULL, 8833, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28346, 10367, NULL, 8833, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28347, 10262, NULL, 8833, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28348, 8254, NULL, 8833, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28353, 11600, NULL, 8835, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28354, 11601, NULL, 8835, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28355, 11602, NULL, 8836, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28356, 2399, NULL, 8836, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28357, 4578, NULL, 8836, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28358, 2625, NULL, 8836, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28359, 11603, NULL, 8837, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28360, 2815, NULL, 8837, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28361, 2880, NULL, 8837, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28362, 11996, NULL, 8837, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28363, 11604, NULL, 8838, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28364, 11997, NULL, 8838, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28365, 11998, NULL, 8838, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28366, 11605, NULL, 8839, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28367, 834, NULL, 8839, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28368, 141, NULL, 8839, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28369, 11606, NULL, 8840, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28370, 652, NULL, 8840, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28371, 10552, NULL, 8840, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28297, 8, NULL, 8818, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28298, 1875, NULL, 8818, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28296, 1421, NULL, 8818, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28195, 39, NULL, 8779, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (28189, 382, NULL, 8779, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28233, 305, NULL, 8794, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28235, 2413, NULL, 8794, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28234, 2443, NULL, 8794, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28232, 1670, NULL, 8794, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28372, 3015, NULL, 8840, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28373, 11607, NULL, 8841, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28374, 7128, NULL, 8841, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28375, 5666, NULL, 8841, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28376, 10958, NULL, 8841, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28377, 11609, NULL, 8842, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28378, 2430, NULL, 8842, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28379, 2163, NULL, 8842, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28380, 2985, NULL, 8842, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28381, 7818, NULL, 8843, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28382, 7943, NULL, 8843, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28383, 7348, NULL, 8843, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28384, 2081, NULL, 8843, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28385, 7820, NULL, 8844, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28386, 2968, NULL, 8844, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28387, 7641, NULL, 8844, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28388, 11999, NULL, 8844, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28389, 7741, NULL, 8845, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28390, 4843, NULL, 8845, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28391, 11308, NULL, 8845, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28392, 6462, NULL, 8845, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28312, 12082, NULL, 8822, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22555, 10205, NULL, 6994, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29775, 2786, NULL, 2077, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29506, 2786, NULL, 9207, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1280, 2458, 296, 399, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22669, 2458, 297, 7024, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13179, 5563, NULL, 2448, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22303, 5563, NULL, 6936, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25056, 3433, 303, 7750, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9321, 3433, 303, 3623, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (507, 3433, 303, 187, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4637, 3433, 303, 1628, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25780, 3433, 303, 7981, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28184, 2240, 305, 8777, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22768, 2240, 305, 7053, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29550, 2240, 305, 9226, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26031, 1431, 306, 8045, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28326, 2626, NULL, 8826, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28327, 2532, NULL, 8826, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28325, 1374, NULL, 8826, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28276, 11974, NULL, 8811, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28274, 11972, NULL, 8811, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28282, 11976, NULL, 8813, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28283, 697, NULL, 8813, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28281, 1526, NULL, 8813, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9248, 7530, NULL, 1898, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9486, 7530, NULL, 3662, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11874, 7530, NULL, 1625, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11612, 7530, NULL, 1968, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11950, 7530, NULL, 4252, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29865, 12536, NULL, 9345, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29866, 12537, NULL, 9345, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29867, 11158, NULL, 9345, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29868, 12538, NULL, 9345, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29869, 12539, NULL, 9346, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29870, 12540, NULL, 9346, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29871, 12541, NULL, 9346, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29872, 12542, NULL, 9347, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29873, 12543, NULL, 9347, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29874, 12544, NULL, 9347, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29875, 12545, NULL, 9347, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19650, 1745, NULL, 6077, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (19647, 1823, NULL, 6077, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28669, 2786, NULL, 8911, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29884, 12553, NULL, 9351, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29885, 12554, NULL, 9351, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29886, 12555, NULL, 9351, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29887, 12556, NULL, 9351, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29888, 10321, NULL, 9352, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29889, 12557, NULL, 9352, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29890, 12558, NULL, 9352, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29891, 12559, NULL, 9352, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29895, 12560, NULL, 9354, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29896, 12561, NULL, 9354, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29897, 12562, NULL, 9355, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29898, 12591, NULL, 9356, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18032, 576, NULL, 5724, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15827, 576, NULL, 5168, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24023, 576, NULL, 7403, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28350, 8797, NULL, 8834, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27059, 2240, 305, 8350, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29878, 12588, NULL, 9348, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29876, 12546, NULL, 9348, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29877, 12547, NULL, 9348, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28680, 2252, NULL, 8914, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29883, 10226, NULL, 9350, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11351, 576, NULL, 2718, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14665, 576, NULL, 4899, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29901, 7194, NULL, 9358, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29902, 12596, NULL, 9358, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29903, 12597, NULL, 9358, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29904, 1526, NULL, 9358, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29905, 2151, NULL, 9359, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29906, 12598, NULL, 9359, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29907, 12599, NULL, 9359, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29908, 12600, NULL, 9359, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29909, 9047, NULL, 9360, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29910, 2873, NULL, 9360, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29911, 12601, NULL, 9360, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29912, 12602, NULL, 9360, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29941, 12615, NULL, 9367, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29939, 1077, NULL, 9367, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29918, 1427, NULL, 9362, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29919, 12606, NULL, 9362, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29920, 12607, NULL, 9362, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29921, 12608, NULL, 9362, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29927, 12571, NULL, 9364, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29928, 2544, NULL, 9364, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29929, 1823, NULL, 9364, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29930, 11065, NULL, 9365, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29931, 12609, NULL, 9365, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29932, 12610, NULL, 9365, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29933, 12611, NULL, 9365, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29934, 12572, NULL, 9366, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29935, 12612, NULL, 9366, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29936, 12613, NULL, 9366, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29937, 12614, NULL, 9366, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29942, 2457, NULL, 9368, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29943, 188, NULL, 9368, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29944, 12616, NULL, 9368, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29945, 12617, NULL, 9368, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29946, 8507, NULL, 9368, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29947, 2577, NULL, 9369, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29948, 812, NULL, 9369, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29949, 8779, NULL, 9369, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24212, 875, 318, 7476, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29950, 1963, NULL, 9370, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29951, 3247, NULL, 9370, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29952, 5883, NULL, 9370, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29953, 2659, NULL, 9370, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29954, 1878, NULL, 9371, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29955, 12642, NULL, 9371, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29956, 1624, NULL, 9372, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29957, 841, NULL, 9372, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29958, 692, NULL, 9372, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29959, 2971, NULL, 9372, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29960, 267, NULL, 9372, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29961, 1406, NULL, 9372, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (29962, 1542, NULL, 9372, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (29963, 613, 258, 9372, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (29964, 12643, NULL, 9373, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29965, 9677, NULL, 9373, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29966, 12644, NULL, 9373, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29974, 12646, NULL, 9376, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29975, 12647, NULL, 9376, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29976, 11310, NULL, 9376, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29977, 1971, NULL, 9377, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29978, 586, NULL, 9377, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29979, 5890, NULL, 9377, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29980, 12648, NULL, 9377, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29981, 12649, NULL, 9378, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29982, 12650, NULL, 9378, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29983, 12651, NULL, 9378, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29984, 7610, NULL, 9378, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29940, 3694, NULL, 9367, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29989, 497, NULL, 9380, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29990, 188, NULL, 9380, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29991, 1629, NULL, 9380, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29992, 1386, NULL, 9380, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29993, 1655, NULL, 9380, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29994, 598, NULL, 9380, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (29996, 497, NULL, 9380, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (29995, 10993, 323, 9380, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (29997, 3149, NULL, 9381, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29899, 12563, NULL, 9357, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29893, 3362, NULL, 9353, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29892, 2308, NULL, 9353, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29969, 10844, NULL, 9374, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29968, 10843, NULL, 9374, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29970, 9046, NULL, 9374, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12396, 2086, 320, 4321, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26854, 576, NULL, 8307, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29922, 543, NULL, 9363, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29926, 9678, NULL, 9363, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29924, 9701, NULL, 9363, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29998, 3657, NULL, 9381, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29999, 12655, NULL, 9381, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30000, 2665, NULL, 9381, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30001, 12656, NULL, 9381, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30006, 11305, NULL, 9383, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30007, 12279, NULL, 9383, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30008, 122, NULL, 9384, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30009, 1181, NULL, 9384, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30010, 9713, NULL, 9384, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30011, 2399, NULL, 9384, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29938, 12425, NULL, 9367, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22285, 2451, NULL, 6932, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22287, 2534, NULL, 6932, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22286, 1291, NULL, 6932, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30020, 1301, NULL, 1465, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30021, 741, NULL, 1465, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30022, 1825, NULL, 1465, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30023, 1379, NULL, 1465, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22284, 1311, NULL, 6932, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29973, 12046, NULL, 9375, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30078, 3218, NULL, 7070, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4068, 4880, NULL, 1660, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30055, 12661, NULL, 9395, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30052, 12728, NULL, 9395, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30053, 2316, NULL, 9395, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30060, 11175, NULL, 9397, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30062, 12730, NULL, 9397, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30063, 9696, NULL, 9397, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30076, 12736, NULL, 9401, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30075, 12735, NULL, 9401, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29915, 3846, NULL, 9361, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29916, 12604, NULL, 9361, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29917, 12605, NULL, 9361, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29914, 2531, NULL, 9361, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30054, 12662, NULL, 9395, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30028, 1782, NULL, 9388, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30026, 12712, NULL, 9388, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30027, 5933, NULL, 9388, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30032, 2162, NULL, 9389, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30031, 4085, NULL, 9389, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30030, 11206, NULL, 9389, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29879, 12549, NULL, 9348, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29972, 12645, NULL, 9375, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30037, 12714, NULL, 9391, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30038, 12723, NULL, 9391, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30040, 12725, NULL, 9391, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30039, 12724, NULL, 9391, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30041, 12715, NULL, 9392, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30043, 12096, NULL, 9392, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30044, 2897, NULL, 9392, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30042, 2930, NULL, 9392, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30047, 8408, NULL, 9393, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30046, 12726, NULL, 9393, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30045, 12716, NULL, 9393, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30050, 1954, NULL, 9394, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30051, 12727, NULL, 9394, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30049, 7071, NULL, 9394, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29971, 2877, NULL, 9375, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30061, 12729, NULL, 9397, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30065, 12731, NULL, 9398, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30064, 2975, NULL, 9398, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30067, 11040, NULL, 9398, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30069, 266, NULL, 9399, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30070, 12732, NULL, 9399, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30068, 12288, NULL, 9399, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30074, 12734, NULL, 9400, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30071, 259, NULL, 9400, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30072, 10511, NULL, 9400, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30073, 12733, NULL, 9400, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30024, 12718, NULL, 9387, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30025, 12719, NULL, 9387, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22281, 9696, NULL, 6931, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22283, 1146, NULL, 6931, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30080, 4117, NULL, 9402, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30081, 11448, NULL, 9402, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30082, 11101, NULL, 9402, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30083, 512, NULL, 9403, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30084, 586, NULL, 9403, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30085, 1971, NULL, 9403, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30086, 5890, NULL, 9403, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30087, 12738, NULL, 9404, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30088, 12739, NULL, 9404, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30089, 6478, NULL, 9405, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30090, 4121, NULL, 9405, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30091, 38, NULL, 9406, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30092, 1498, NULL, 9406, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30093, 3247, NULL, 9406, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30094, 4093, NULL, 9406, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30095, 10897, NULL, 9407, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30096, 12014, NULL, 9408, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30097, 9179, NULL, 9409, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30098, 12740, NULL, 9409, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30099, 1651, NULL, 9409, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30100, 2814, NULL, 9409, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30101, 1270, NULL, 9410, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30102, 5855, NULL, 9410, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30103, 12741, NULL, 9410, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30104, 141, NULL, 9410, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30105, 12742, NULL, 9411, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30106, 12743, NULL, 9412, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30107, 12744, NULL, 9412, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30108, 12745, NULL, 9413, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30109, 11892, NULL, 9413, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30110, 10055, NULL, 9413, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30111, 12746, NULL, 9413, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30112, 8511, NULL, 9414, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30113, 2347, NULL, 9414, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30114, 9911, NULL, 9414, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30115, 10864, NULL, 9414, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30116, 3806, NULL, 9415, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30117, 2931, NULL, 9416, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30118, 2932, NULL, 9416, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30119, 2316, NULL, 9416, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30120, 10129, NULL, 9416, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30127, 1592, NULL, 9419, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30128, 1542, NULL, 9419, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30129, 1814, NULL, 9419, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30130, 2140, NULL, 9419, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30137, 1458, NULL, 9422, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30138, 2761, NULL, 9422, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30139, 1374, NULL, 9422, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30140, 1043, NULL, 9423, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30141, 920, NULL, 9423, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30142, 2559, NULL, 9423, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30143, 1042, NULL, 9423, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30147, 1882, NULL, 9425, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30148, 2786, NULL, 9425, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30149, 1700, NULL, 9425, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30150, 12747, NULL, 9426, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30151, 682, NULL, 9426, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30152, 430, NULL, 9427, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30153, 2442, NULL, 9427, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30154, 10993, NULL, 9427, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30155, 171, NULL, 9428, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30156, 1374, NULL, 9428, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30157, 3140, NULL, 9428, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30178, 12696, NULL, 9434, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30179, 3253, NULL, 9434, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30180, 12756, NULL, 9434, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30181, 12757, NULL, 9434, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30182, 12709, NULL, 9435, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30183, 12758, NULL, 9435, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30184, 12699, NULL, 9435, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30185, 12697, NULL, 9436, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30186, 7801, NULL, 9436, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30187, 12759, NULL, 9436, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30188, 12760, NULL, 9436, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30189, 12707, NULL, 9436, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30190, 7739, NULL, 9436, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (30191, 7178, NULL, 9436, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (30192, 12703, NULL, 9437, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30193, 821, NULL, 9437, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30194, 266, NULL, 9437, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30195, 12761, NULL, 9437, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30200, 12708, NULL, 9439, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30201, 12067, NULL, 9439, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30202, 5905, NULL, 9439, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30203, 12762, NULL, 9439, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30207, 9552, NULL, 9441, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30208, 12764, NULL, 9441, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30209, 8251, NULL, 9441, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30210, 12765, NULL, 9441, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30215, 3235, NULL, 9444, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30216, 6352, NULL, 9444, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30217, 6354, NULL, 9444, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30218, 6353, NULL, 9444, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30219, 6108, NULL, 9445, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30220, 6364, NULL, 9445, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30221, 6365, NULL, 9445, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30004, 2061, NULL, 9382, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30003, 1146, NULL, 9382, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30002, 1334, NULL, 9382, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30005, 9905, NULL, 9382, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30016, 12661, NULL, 9386, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30019, 12663, NULL, 9386, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30017, 2316, NULL, 9386, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30198, 12075, NULL, 9438, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30197, 8202, NULL, 9438, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30196, 12701, NULL, 9438, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30199, 12061, NULL, 9438, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30222, 6366, NULL, 9445, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30223, 12768, NULL, 9446, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30224, 4360, NULL, 9446, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30225, 414, NULL, 9446, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30226, 12769, NULL, 9446, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30136, 685, NULL, 9421, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30134, 923, NULL, 9421, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30135, 1503, NULL, 9421, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30121, 152, NULL, 9417, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30231, 649, NULL, 9448, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30232, 2786, NULL, 9448, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30233, 209, NULL, 9448, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30234, 4273, NULL, 9449, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30235, 1012, NULL, 9449, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30236, 1295, NULL, 9449, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30237, 12578, NULL, 9450, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30238, 3184, NULL, 9450, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30239, 2996, NULL, 9450, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30240, 3185, NULL, 9450, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30241, 1578, NULL, 9451, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30242, 533, NULL, 9451, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30243, 1713, NULL, 9451, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30244, 333, NULL, 9451, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30245, 1862, NULL, 9452, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30246, 2403, NULL, 9452, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30247, 11987, NULL, 9453, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30248, 6355, NULL, 9453, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30249, 1542, NULL, 9453, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30250, 2312, NULL, 9453, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30251, 4448, NULL, 9454, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30252, 4381, NULL, 9454, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30253, 3700, NULL, 9454, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30254, 601, NULL, 9454, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30255, 3197, NULL, 9455, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30159, 8425, NULL, 9429, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30161, 2410, NULL, 9429, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30158, 5390, NULL, 9429, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30176, 3323, NULL, 9433, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30177, 3217, NULL, 9433, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30175, 12755, NULL, 9433, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30256, 5910, NULL, 9455, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30257, 3196, NULL, 9455, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30258, 1565, NULL, 9456, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30259, 1911, NULL, 9456, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30164, 12094, NULL, 9430, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30162, 12702, NULL, 9430, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30165, 12750, NULL, 9430, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30163, 12749, NULL, 9430, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4067, 4879, NULL, 1660, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4066, 4878, NULL, 1660, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4065, 4877, NULL, 1660, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30123, 730, NULL, 9417, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30122, 1112, NULL, 9417, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30133, 2626, NULL, 9420, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30206, 3180, NULL, 9440, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30205, 12763, NULL, 9440, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30204, 12705, NULL, 9440, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30132, 955, NULL, 9420, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30131, 5355, NULL, 9420, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30144, 534, NULL, 9424, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30146, 1406, NULL, 9424, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13585, 1971, NULL, 4540, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13582, 7186, NULL, 4540, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13583, 2691, NULL, 4540, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30212, 12081, NULL, 9442, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30213, 12766, NULL, 9442, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30214, 12767, NULL, 9442, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30171, 12753, NULL, 9432, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30172, 11184, NULL, 9432, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30173, 12695, NULL, 9432, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30170, 12710, NULL, 9432, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30260, 3160, NULL, 9456, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30261, 145, NULL, 9456, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30270, 2369, NULL, 9459, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30271, 3033, NULL, 9459, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30272, 4323, NULL, 9459, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30273, 10216, NULL, 9459, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30274, 12770, NULL, 9460, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30275, 914, NULL, 9460, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30276, 10975, NULL, 9460, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30277, 12771, NULL, 9460, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30278, 12566, NULL, 9461, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30279, 7909, NULL, 9461, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30280, 12772, NULL, 9461, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30281, 12773, NULL, 9461, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30282, 12566, NULL, 9461, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30283, 773, NULL, 9462, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30284, 10438, NULL, 9462, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30285, 1042, NULL, 9462, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30286, 9522, NULL, 9463, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30287, 3131, NULL, 9463, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30288, 12774, NULL, 9463, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30289, 497, NULL, 9464, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30290, 2361, NULL, 9464, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30291, 2482, NULL, 9464, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30293, 12567, NULL, 9465, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30294, 972, NULL, 9465, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30295, 3618, NULL, 9465, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30296, 3617, NULL, 9465, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30297, 7046, NULL, 9466, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30298, 11528, NULL, 9466, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30299, 4983, NULL, 9466, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30300, 11052, NULL, 9466, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30301, 12568, NULL, 9467, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30302, 11680, NULL, 9467, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30303, 11681, NULL, 9467, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30304, 6207, NULL, 9467, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30305, 6208, NULL, 9467, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30306, 12776, NULL, 9468, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30307, 1120, NULL, 9468, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30308, 12777, NULL, 9468, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30309, 488, NULL, 9468, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30310, 12778, NULL, 9469, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30311, 12779, NULL, 9469, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30312, 8799, NULL, 9469, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30313, 12780, NULL, 9469, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30318, 3140, NULL, 9464, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30319, 2748, NULL, 9471, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30320, 539, NULL, 9471, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30321, 2657, NULL, 9471, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30322, 12781, NULL, 9471, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30323, 8257, NULL, 9472, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30324, 3357, NULL, 9472, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30325, 133, NULL, 9472, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30326, 649, NULL, 9473, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30327, 488, NULL, 9473, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30328, 1481, NULL, 9473, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30329, 1219, NULL, 9473, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30331, 133, NULL, 9474, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30332, 12771, NULL, 9474, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30333, 2532, NULL, 9474, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30334, 2948, NULL, 9475, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30335, 8799, NULL, 9475, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30336, 2483, NULL, 9475, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30337, 1852, NULL, 9475, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30338, 1662, NULL, 9476, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30339, 2081, NULL, 9476, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30340, 7241, NULL, 9476, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30341, 9828, NULL, 9476, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30342, 12782, NULL, 9477, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30343, 12783, NULL, 9477, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30344, 2977, NULL, 9477, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30345, 1059, NULL, 9478, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30346, 12784, NULL, 9478, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30347, 2945, NULL, 9478, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30348, 186, NULL, 9478, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30349, 872, NULL, 9478, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30350, 5667, NULL, 9478, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (30351, 7558, NULL, 9478, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (30352, 12785, NULL, 9478, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (30353, 850, NULL, 9479, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30354, 5362, NULL, 9479, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30355, 429, NULL, 9479, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30356, 9431, NULL, 9479, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30357, 9162, NULL, 9480, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30358, 1099, NULL, 9480, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30359, 12786, NULL, 9480, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30360, 2910, NULL, 9481, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30361, 2238, NULL, 9481, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30362, 688, NULL, 9481, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30363, 2932, NULL, 9481, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30364, 1748, NULL, 9482, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30365, 1821, NULL, 9482, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30366, 2661, NULL, 9482, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30367, 3682, NULL, 9482, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30368, 216, NULL, 9483, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30369, 9524, NULL, 9483, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30370, 12787, NULL, 9483, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30371, 1095, NULL, 9484, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30372, 688, NULL, 9484, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30373, 312, NULL, 9484, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30374, 12788, NULL, 9484, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30375, 5666, NULL, 9487, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30376, 10551, NULL, 9487, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30377, 2981, NULL, 9487, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30378, 1687, NULL, 9488, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30379, 1575, NULL, 9488, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30380, 3123, NULL, 9488, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30382, 9044, NULL, 9489, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30383, 1352, NULL, 9489, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30384, 239, NULL, 9489, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30385, 3749, NULL, 9490, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30386, 1952, NULL, 9490, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30387, 9531, NULL, 9490, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30388, 8100, NULL, 9490, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30389, 3001, NULL, 9490, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30390, 3959, NULL, 9491, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30391, 2680, NULL, 9492, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30392, 5265, NULL, 9492, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30393, 3190, NULL, 9492, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30394, 12789, NULL, 9492, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30395, 295, NULL, 9493, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30396, 1389, NULL, 9493, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30397, 1120, NULL, 9493, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30398, 12777, NULL, 9493, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30399, 488, NULL, 9493, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30400, 12713, NULL, 9494, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30401, 2483, NULL, 9494, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30402, 1852, NULL, 9494, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30403, 611, NULL, 9495, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30404, 792, NULL, 9495, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30405, 1965, NULL, 9495, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30406, 2000, NULL, 9495, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30407, 12790, NULL, 9496, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30408, 9512, NULL, 9496, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30409, 12791, NULL, 9496, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30410, 8503, NULL, 9496, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30411, 2862, NULL, 9497, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30412, 10553, NULL, 9497, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30413, 2912, NULL, 9497, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30414, 11857, NULL, 9497, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30415, 6977, NULL, 9498, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30416, 133, NULL, 9498, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30417, 471, NULL, 9498, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30418, 749, NULL, 9499, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30419, 12792, NULL, 9499, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30420, 12793, NULL, 9499, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30421, 1044, NULL, 9499, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30422, 727, NULL, 9499, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30423, 5054, NULL, 9499, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (30425, 12795, NULL, 9499, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (30426, 2846, NULL, 9329, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30427, 6945, NULL, 9329, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30428, 5064, NULL, 9329, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30433, 12803, NULL, 9331, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30434, 1502, NULL, 9331, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30435, 765, NULL, 9331, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30436, 510, NULL, 9331, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30437, 3757, NULL, 9332, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30438, 4005, NULL, 9332, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30439, 1825, NULL, 9332, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30440, 1814, NULL, 9332, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30445, 937, NULL, 9334, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30446, 2285, NULL, 9334, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30448, 12804, NULL, 9334, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30430, 98, NULL, 9330, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30268, 98, NULL, 9458, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30266, 133, NULL, 9458, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30267, 11917, NULL, 9458, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30262, 12082, NULL, 9457, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30265, 3767, NULL, 9457, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30264, 2117, NULL, 9457, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30263, 1042, NULL, 9457, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30447, 1052, NULL, 9334, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30450, 3773, NULL, 9335, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30451, 1800, NULL, 9335, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30452, 6759, NULL, 9335, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30453, 2356, NULL, 9335, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30454, 1084, NULL, 9336, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30455, 679, NULL, 9336, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30456, 3057, NULL, 9336, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30457, 2031, NULL, 9336, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30458, 7283, NULL, 9339, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30459, 2012, NULL, 9339, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30460, 2724, NULL, 9337, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30461, 12805, NULL, 9337, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30462, 6089, NULL, 9337, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30463, 6090, NULL, 9337, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30464, 12, NULL, 9338, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30465, 12806, NULL, 9338, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30466, 1181, NULL, 9338, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30467, 1827, NULL, 9338, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30468, 3335, NULL, 9340, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30469, 188, NULL, 9340, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30470, 1589, NULL, 9341, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30471, 7844, NULL, 9341, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30472, 12807, NULL, 9341, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22290, 1834, NULL, 6933, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13584, 3002, NULL, 4540, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30478, 807, NULL, 9343, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30479, 1447, NULL, 9343, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30480, 5308, NULL, 9343, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30481, 1940, NULL, 9343, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30482, 4615, NULL, 9343, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30483, 1687, NULL, 9344, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30484, 652, NULL, 9344, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30485, 209, NULL, 9344, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30486, 12809, NULL, 9344, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28627, 209, NULL, 8903, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28626, 652, NULL, 8903, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30487, 12810, NULL, 9500, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30488, 12811, NULL, 9500, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30489, 12812, NULL, 9500, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30490, 12813, NULL, 9500, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30494, 12815, NULL, 9502, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30495, 1018, NULL, 9502, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30496, 773, NULL, 9502, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30497, 65, NULL, 9502, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30498, 12816, NULL, 9503, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30499, 12817, NULL, 9503, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30500, 12818, NULL, 9503, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30501, 1502, NULL, 9503, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30502, 1600, NULL, 9504, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30503, 12819, NULL, 9504, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30504, 2105, NULL, 9504, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30505, 5207, NULL, 9504, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30506, 12820, NULL, 9505, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30507, 12821, NULL, 9505, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30508, 3806, NULL, 9505, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30509, 1785, NULL, 9506, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30510, 12822, NULL, 9506, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30511, 12823, NULL, 9506, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30512, 12824, NULL, 9506, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30513, 532, NULL, 9507, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30514, 1625, NULL, 9507, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30515, 4105, NULL, 9507, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30516, 4842, NULL, 9507, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30517, 2531, NULL, 9508, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30518, 1311, NULL, 9508, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30519, 12826, NULL, 9508, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30520, 12827, NULL, 9508, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30521, 2846, NULL, 9509, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30522, 12828, NULL, 9509, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30523, 12369, NULL, 9509, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30524, 12829, NULL, 9510, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30525, 12830, NULL, 9510, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30526, 12831, NULL, 9510, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30527, 2834, NULL, 9511, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30528, 12832, NULL, 9511, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30529, 12833, NULL, 9511, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30530, 2336, NULL, 9512, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30531, 78, NULL, 9512, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30532, 9828, NULL, 9512, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30533, 2332, NULL, 9513, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30534, 12834, NULL, 9513, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30535, 1800, NULL, 9513, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30536, 12835, NULL, 9513, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30537, 5949, NULL, 9514, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30538, 2259, NULL, 9514, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30539, 2318, NULL, 9514, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30540, 2536, NULL, 9514, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30541, 7194, NULL, 9515, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30542, 1742, NULL, 9515, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30543, 778, NULL, 9515, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30544, 2948, NULL, 9516, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30545, 1166, NULL, 9516, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30546, 3846, NULL, 9516, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30547, 1158, NULL, 9517, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30548, 89, NULL, 9517, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30549, 2226, NULL, 9517, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30550, 1857, NULL, 9517, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30551, 12836, NULL, 9518, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30552, 12837, NULL, 9518, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30553, 3167, NULL, 9518, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30554, 1782, NULL, 9518, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30555, 385, NULL, 9519, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30556, 10635, NULL, 9519, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30557, 8157, NULL, 9519, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30558, 288, NULL, 9519, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30559, 1293, NULL, 9520, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30560, 9249, NULL, 9520, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30561, 1665, NULL, 9521, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30562, 3129, NULL, 9521, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30563, 2753, NULL, 9521, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30564, 3130, NULL, 9521, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30565, 413, NULL, 9522, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30566, 5825, NULL, 9522, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30567, 3137, NULL, 9523, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30568, 5979, NULL, 9523, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30569, 8498, NULL, 9523, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30570, 8289, NULL, 9523, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30572, 10655, NULL, 9525, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30573, 852, NULL, 9525, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30574, 117, NULL, 9525, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30575, 12761, NULL, 9525, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30576, 580, NULL, 9526, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30577, 10270, NULL, 9526, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30578, 2980, NULL, 9526, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30579, 38, NULL, 9526, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30584, 84, NULL, 9528, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30585, 812, NULL, 9528, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30586, 985, NULL, 9528, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30587, 804, NULL, 9529, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30588, 12838, NULL, 9529, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30589, 12839, NULL, 9529, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30590, 10577, NULL, 9529, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30591, 374, NULL, 9552, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30592, 5304, NULL, 9552, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30593, 12771, NULL, 9552, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30594, 1374, NULL, 9552, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30595, 2423, NULL, 9552, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30596, 12840, NULL, 9552, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (30597, 482, NULL, 9552, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (30598, 2790, NULL, 9552, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (30608, 430, NULL, 9554, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30609, 467, NULL, 9554, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30610, 2626, NULL, 9554, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30491, 760, NULL, 9501, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30492, 14235, NULL, 9501, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30571, 3700, NULL, 9524, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30443, 5985, NULL, 9333, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30442, 992, NULL, 9333, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30444, 5986, NULL, 9333, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30611, 12844, NULL, 9554, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30612, 2625, NULL, 9554, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30613, 2316, NULL, 9554, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (30614, 2572, NULL, 9554, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (30615, 12845, NULL, 9554, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (30616, 405, NULL, 9554, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (30625, 1059, NULL, 9556, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30626, 1639, NULL, 9556, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30627, 173, NULL, 9556, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30628, 1458, NULL, 9556, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30629, 1453, NULL, 9556, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30630, 9147, NULL, 9556, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (30631, 971, NULL, 9556, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (30632, 12848, NULL, 9556, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (30633, 1041, NULL, 9557, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30634, 12849, NULL, 9557, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30635, 1535, NULL, 9557, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30636, 1106, NULL, 9557, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30637, 1700, NULL, 9557, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30638, 448, NULL, 9558, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30639, 1655, NULL, 9558, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30640, 7176, NULL, 9558, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30641, 12850, NULL, 9558, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30642, 576, NULL, 9558, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30643, 2258, NULL, 9558, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (30644, 12850, NULL, 9558, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (30645, 12851, NULL, 9558, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (30646, 2980, NULL, 9558, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (30647, 682, NULL, 9558, 10);
INSERT INTO 'tunesrecordingsmap' VALUES (30648, 6343, NULL, 9559, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30649, 12852, NULL, 9559, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30650, 1586, NULL, 9564, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30651, 12853, NULL, 9564, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30652, 12854, NULL, 9564, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30657, 12857, NULL, 9566, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30658, 183, NULL, 9566, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30659, 2029, NULL, 9566, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30660, 12858, NULL, 9566, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30661, 12532, NULL, 9567, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30662, 2968, NULL, 9567, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30663, 10295, NULL, 9567, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30664, 12859, NULL, 9567, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30665, 12860, NULL, 9568, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30666, 1112, NULL, 9568, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30667, 238, NULL, 9568, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30668, 2505, NULL, 9568, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30679, 12866, NULL, 9572, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30680, 12867, NULL, 9572, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30681, 12868, NULL, 9572, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30682, 10321, NULL, 9572, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30683, 12869, NULL, 9573, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30684, 12870, NULL, 9573, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30685, 12871, NULL, 9573, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30686, 12530, NULL, 9574, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30687, 312, NULL, 9574, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30688, 760, NULL, 9574, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30689, 613, NULL, 9574, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30690, 12872, NULL, 9574, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30691, 1181, NULL, 9574, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (30692, 12873, NULL, 9574, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (30695, 5433, NULL, 9576, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30696, 1622, NULL, 9576, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30697, 1902, NULL, 9577, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30698, 12877, NULL, 9577, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30699, 12878, NULL, 9578, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30700, 12879, NULL, 9578, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30704, 1802, NULL, 9580, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30705, 6381, NULL, 9581, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30706, 1699, NULL, 9581, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30707, 2899, NULL, 9581, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30708, 219, NULL, 9582, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30709, 5375, NULL, 9582, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30710, 6396, NULL, 9582, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30711, 239, NULL, 9583, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30712, 1862, NULL, 9583, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30713, 5160, NULL, 9584, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30714, 630, NULL, 9584, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30715, 5374, NULL, 9584, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30716, 12882, NULL, 9585, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30717, 11520, NULL, 9585, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30718, 6737, NULL, 9585, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30719, 5507, NULL, 9586, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30720, 697, NULL, 9586, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30721, 5262, NULL, 9586, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30728, 12884, NULL, 9588, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30729, 12885, NULL, 9588, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30730, 2076, NULL, 9589, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30731, 425, NULL, 9589, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30732, 1450, NULL, 9589, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30733, 3498, NULL, 9589, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30734, 577, NULL, 9589, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30735, 1821, NULL, 9590, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30736, 12886, NULL, 9590, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30737, 1505, NULL, 9591, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30738, 1778, NULL, 9591, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30739, 12887, NULL, 9591, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30740, 5131, NULL, 9591, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30741, 12888, NULL, 9591, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30742, 6335, NULL, 9592, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30743, 857, NULL, 9592, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30744, 692, NULL, 9592, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30745, 1638, NULL, 9592, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30746, 2696, NULL, 9593, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30747, 1880, NULL, 9593, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30748, 1112, NULL, 9593, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30749, 850, NULL, 9593, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30750, 5053, NULL, 9594, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30751, 2467, NULL, 9594, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30752, 1044, NULL, 9594, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30753, 2840, NULL, 9594, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19759, 1646, NULL, 6181, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21123, 1646, NULL, 6621, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30754, 12890, NULL, 4453, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30755, 3600, NULL, 9595, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30756, 3850, NULL, 9595, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30757, 2432, NULL, 9595, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30758, 360, NULL, 9596, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30759, 4507, NULL, 9596, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30760, 12891, NULL, 9596, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30761, 12892, NULL, 9597, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30762, 12893, NULL, 9598, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30763, 1993, NULL, 9598, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30764, 5174, NULL, 9599, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30766, 1603, NULL, 9601, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30767, 2332, NULL, 9601, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30768, 12894, NULL, 9601, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30769, 220, NULL, 9601, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30770, 12895, NULL, 9602, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30771, 2129, NULL, 9602, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30772, 5192, NULL, 9603, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30773, 5193, NULL, 9603, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30774, 12896, NULL, 9603, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30775, 4790, NULL, 9603, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30776, 12897, NULL, 9604, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30777, 12898, NULL, 9605, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30778, 488, NULL, 9605, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30779, 1313, NULL, 9605, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30780, 5576, NULL, 9605, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30621, 642, NULL, 9555, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30722, 12883, NULL, 9587, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30723, 520, NULL, 9587, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30725, 626, NULL, 9587, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30724, 2336, NULL, 9587, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30726, 12729, NULL, 9587, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30727, 1431, NULL, 9587, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (30606, 382, NULL, 9553, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (30604, 424, NULL, 9553, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (30607, 424, NULL, 9553, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (30602, 12841, NULL, 9553, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30599, 685, NULL, 9553, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30601, 1091, NULL, 9553, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30603, 12842, NULL, 9553, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30781, 12899, NULL, 9606, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30782, 12900, NULL, 9606, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30783, 12901, NULL, 9606, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30784, 12902, NULL, 9607, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30785, 487, NULL, 9608, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30786, 12903, NULL, 9608, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30787, 10129, NULL, 9608, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30788, 6414, NULL, 9609, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30789, 9455, NULL, 9609, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30790, 12904, NULL, 9610, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30791, 977, NULL, 9611, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30792, 655, NULL, 9611, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30793, 674, NULL, 9611, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30794, 12905, NULL, 9612, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30795, 12906, NULL, 9612, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30796, 12907, NULL, 9613, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30797, 12908, NULL, 9613, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30798, 12909, NULL, 9613, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30799, 3650, NULL, 9614, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30800, 5209, NULL, 9614, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30801, 709, NULL, 9615, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30802, 5210, NULL, 9615, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30803, 3013, NULL, 9615, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30804, 3318, NULL, 9615, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30805, 12042, NULL, 9616, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30806, 295, NULL, 9616, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30807, 803, NULL, 9616, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30808, 730, NULL, 9616, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30809, 2964, NULL, 9616, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30693, 2650, 587, 9575, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30810, 12912, NULL, 9617, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30811, 12913, NULL, 9617, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30812, 12914, NULL, 9617, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30813, 1329, NULL, 9618, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30814, 497, NULL, 9618, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30672, 3443, NULL, 9570, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30671, 12862, NULL, 9570, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30673, 2616, NULL, 9570, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30674, 3367, NULL, 9570, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30670, 12861, NULL, 9569, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30669, 12531, NULL, 9569, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30703, 2910, NULL, 9579, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30702, 12881, NULL, 9579, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30701, 12880, NULL, 9579, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30653, 12529, NULL, 9565, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30655, 2399, NULL, 9565, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30656, 12856, NULL, 9565, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30815, 992, NULL, 9618, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30816, 3140, NULL, 9618, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30817, 915, NULL, 9619, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30818, 1542, NULL, 9619, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30819, 2559, NULL, 9619, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30820, 1825, NULL, 9619, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30825, 100, NULL, 9621, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30826, 10611, NULL, 9621, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30827, 1460, NULL, 9622, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30828, 238, NULL, 9622, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30829, 129, NULL, 9622, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30830, 687, NULL, 9622, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30832, 1765, NULL, 9624, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30833, 3992, NULL, 9624, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30834, 4578, NULL, 9624, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30835, 955, NULL, 9624, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30836, 2055, NULL, 9625, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30837, 9828, NULL, 9625, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30838, 2411, NULL, 9625, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30839, 872, NULL, 9626, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30840, 4578, NULL, 9626, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30841, 2774, NULL, 9626, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30842, 6046, NULL, 9627, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30843, 4727, NULL, 9627, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30844, 372, NULL, 9627, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30845, 1464, NULL, 9627, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30846, 850, NULL, 9628, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30847, 209, NULL, 9628, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30848, 1665, NULL, 9628, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30849, 2396, NULL, 9628, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30855, 1150, NULL, 9631, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30856, 10901, NULL, 9631, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30857, 6679, NULL, 9631, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30858, 588, NULL, 9632, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30859, 12917, NULL, 9632, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30860, 1823, NULL, 9632, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30861, 12918, NULL, 9632, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30862, 1095, NULL, 9633, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30863, 1219, NULL, 9633, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30864, 1158, NULL, 9633, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30865, 6679, NULL, 9634, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30866, 998, NULL, 9634, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30867, 6016, NULL, 9634, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30868, 987, NULL, 9635, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30869, 5926, NULL, 9635, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30870, 2645, NULL, 9635, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30871, 8863, NULL, 9635, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30872, 41, NULL, 9636, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30873, 13, NULL, 9636, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30874, 408, NULL, 9638, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30875, 831, NULL, 9639, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30876, 12919, NULL, 9639, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30877, 12920, NULL, 9639, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30878, 9552, NULL, 9639, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30879, 864, NULL, 9640, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30880, 1406, NULL, 9640, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30881, 166, NULL, 9640, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30882, 755, NULL, 9643, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30883, 3779, NULL, 9643, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30884, 2626, NULL, 9643, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30885, 4690, NULL, 9644, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30886, 1670, NULL, 9645, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30887, 1063, NULL, 9645, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30888, 12921, NULL, 9645, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30889, 1053, NULL, 9645, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30890, 11046, NULL, 9646, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30891, 2646, NULL, 9646, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30893, 1670, NULL, 9647, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30894, 1063, NULL, 9647, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30895, 224, NULL, 9647, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30896, 1053, NULL, 9647, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30897, 77, NULL, 9648, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30898, 2899, NULL, 9648, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30899, 1699, NULL, 9648, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30900, 3912, NULL, 9648, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30901, 3919, NULL, 9649, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30902, 1125, NULL, 9649, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30903, 5066, NULL, 9649, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30904, 5202, NULL, 9649, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30905, 2874, NULL, 9649, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30906, 5620, NULL, 9650, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30907, 697, NULL, 9650, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30908, 429, NULL, 9650, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30909, 778, NULL, 9650, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30910, 1103, NULL, 9651, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30911, 1423, NULL, 9651, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30912, 4746, NULL, 9651, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30913, 897, NULL, 9652, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30914, 12922, NULL, 9652, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30915, 10396, NULL, 9652, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30916, 80, NULL, 9653, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30917, 238, NULL, 9653, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30918, 12923, NULL, 9653, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30922, 1474, NULL, 9655, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30923, 1624, NULL, 9655, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30924, 152, NULL, 9656, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30925, 295, NULL, 9656, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30926, 3915, NULL, 9656, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30927, 2730, NULL, 9656, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30928, 487, NULL, 9657, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30929, 12924, NULL, 9657, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30930, 364, NULL, 9658, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30931, 2413, NULL, 9658, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30932, 2816, NULL, 9658, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30933, 1979, NULL, 9658, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30934, 2055, NULL, 9659, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30935, 1112, NULL, 9659, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30936, 2505, NULL, 9659, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30937, 4050, NULL, 9660, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30938, 4051, NULL, 9660, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30940, 1132, NULL, 9661, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30941, 11080, NULL, 9661, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30942, 470, NULL, 9662, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30943, 51, NULL, 9662, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30944, 1318, NULL, 9662, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30945, 408, NULL, 9663, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30946, 4892, NULL, 9664, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30947, 3003, NULL, 9664, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30948, 6304, NULL, 9664, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30949, 55, NULL, 9665, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30950, 1481, NULL, 9665, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30951, 3027, NULL, 9665, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30952, 2834, NULL, 9666, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30953, 12925, NULL, 9666, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30954, 850, NULL, 9666, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30955, 7530, NULL, 9667, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30956, 644, NULL, 9667, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30957, 5236, NULL, 9668, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30958, 5237, NULL, 9668, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30959, 5202, NULL, 9668, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30960, 4987, NULL, 9668, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30961, 2834, NULL, 9669, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30962, 12925, NULL, 9669, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30963, 850, NULL, 9669, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30968, 12930, NULL, 9671, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30969, 12931, NULL, 9671, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30970, 12932, NULL, 9671, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30975, 12934, NULL, 9673, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30976, 12935, NULL, 9673, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30977, 3190, NULL, 9673, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30978, 12214, NULL, 9673, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30939, 181, NULL, 9661, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30831, 6898, NULL, 9623, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22291, 1329, NULL, 6933, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22294, 1629, NULL, 6933, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (30983, 12937, NULL, 9675, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30984, 7066, NULL, 9675, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30985, 6672, NULL, 9675, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30986, 1926, NULL, 9675, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30991, 2321, NULL, 9677, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30992, 2564, NULL, 9677, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30853, 39, NULL, 9630, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30854, 857, NULL, 9630, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30852, 4615, NULL, 9630, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30993, 12938, NULL, 9677, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30994, 12939, NULL, 9677, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30995, 12940, NULL, 9678, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30996, 1386, NULL, 9678, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30997, 1553, NULL, 9678, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30998, 2399, NULL, 9678, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30999, 285, NULL, 9679, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31000, 12941, NULL, 9679, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30966, 6030, NULL, 9670, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30965, 12929, NULL, 9670, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30964, 12928, NULL, 9670, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30967, 11719, NULL, 9670, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22289, 1638, NULL, 6933, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22288, 1655, NULL, 6933, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31001, 1917, NULL, 9679, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31002, 1313, NULL, 9679, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31003, 12942, NULL, 9680, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31004, 12943, NULL, 9680, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31005, 10451, NULL, 9681, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31006, 12944, NULL, 9681, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31007, 6979, NULL, 9681, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31008, 1769, NULL, 9681, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31017, 12947, NULL, 9683, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31018, 12948, NULL, 9684, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31019, 8132, NULL, 5889, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31020, 7272, NULL, 5889, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31021, 168, NULL, 5890, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31022, 280, NULL, 5890, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31023, 2458, NULL, 5890, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31024, 5819, NULL, 5891, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31026, 2524, NULL, 5892, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31027, 398, NULL, 5892, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31028, 2480, NULL, 5893, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31029, 7268, NULL, 5893, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31030, 979, NULL, 5894, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31031, 10129, NULL, 5894, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31032, 8285, NULL, 5894, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31033, 10625, NULL, 5894, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31034, 12958, NULL, 5895, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31035, 5322, NULL, 5895, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31036, 6771, NULL, 5895, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31037, 6202, NULL, 5896, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31038, 6554, NULL, 5897, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31039, 12959, NULL, 5897, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31040, 7500, NULL, 5897, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31041, 11285, NULL, 5898, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31042, 10231, NULL, 5898, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31043, 232, NULL, 5899, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31044, 12001, NULL, 5899, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31045, 520, NULL, 5900, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31046, 320, NULL, 5900, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31047, 78, NULL, 5900, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31048, 2081, NULL, 5900, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31049, 3646, NULL, 5901, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31050, 1684, NULL, 5901, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31051, 5249, NULL, 5902, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31052, 12960, NULL, 5902, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31053, 63, NULL, 5902, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31054, 12961, NULL, 5903, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31055, 3682, NULL, 5904, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31056, 3394, NULL, 5904, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31057, 1945, NULL, 5904, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31058, 8252, NULL, 5904, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31059, 5011, NULL, 9685, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5478, 168, 334, 2907, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31060, 11932, 335, 9688, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31061, 1329, NULL, 9689, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31062, 785, NULL, 9689, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31063, 5183, NULL, 9689, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31064, 5184, NULL, 9689, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31065, 12953, NULL, 9690, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31066, 2987, 194, 9690, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31067, 3203, NULL, 9690, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31068, 9910, NULL, 9690, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31069, 1334, NULL, 9691, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31070, 1146, NULL, 9691, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31071, 2605, NULL, 9691, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31072, 1392, NULL, 9691, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31073, 4871, NULL, 9692, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31074, 812, NULL, 9692, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31075, 2906, NULL, 9692, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31076, 2483, NULL, 9692, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31077, 12076, NULL, 9693, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31078, 12962, NULL, 9693, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31079, 12963, NULL, 9693, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31080, 302, NULL, 9693, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31081, 1413, NULL, 9694, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31082, 3023, NULL, 9694, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31083, 7134, NULL, 9694, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31084, 2238, NULL, 9694, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31085, 688, NULL, 9694, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31086, 10650, NULL, 9695, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31087, 8362, NULL, 9695, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31088, 8019, NULL, 9695, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31089, 7904, NULL, 9696, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31090, 2570, 336, 9696, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31091, 326, NULL, 9696, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31092, 7678, NULL, 9696, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31093, 3484, NULL, 9697, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31094, 12964, NULL, 9697, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31095, 12965, NULL, 9697, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31096, 650, NULL, 9697, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31097, 143, 337, 9698, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31098, 867, NULL, 9698, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31099, 239, 338, 9698, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31100, 12954, NULL, 9699, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31101, 9701, NULL, 9699, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31102, 12781, NULL, 9699, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31103, 9678, NULL, 9699, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31104, 5535, NULL, 9700, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31105, 785, NULL, 9700, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31106, 1102, NULL, 9700, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31107, 858, NULL, 9700, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31108, 5018, NULL, 9701, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31109, 10293, NULL, 9701, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31110, 12966, NULL, 9701, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31111, 2812, NULL, 9702, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31112, 12967, NULL, 9702, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31113, 12968, NULL, 9702, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31114, 12969, NULL, 9702, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31115, 12970, NULL, 9702, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21439, 7538, NULL, 6709, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31125, 19, NULL, 9705, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31126, 10190, NULL, 9705, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31127, 1862, 341, 9705, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20633, 2905, NULL, 6466, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31136, 3264, NULL, 9708, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31137, 6302, NULL, 9708, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31138, 613, NULL, 9708, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31139, 32, NULL, 9708, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31140, 2427, 343, 9709, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31141, 2683, 344, 9709, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31142, 2448, NULL, 9709, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31143, 107, NULL, 9710, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31144, 2626, NULL, 9710, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31145, 2016, NULL, 9710, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31146, 9354, NULL, 9711, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31147, 4323, NULL, 9711, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31148, 9913, NULL, 9711, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31149, 463, NULL, 9711, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31014, 2212, NULL, 9682, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31012, 613, NULL, 9682, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31016, 12946, NULL, 9682, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31013, 816, NULL, 9682, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31124, 7538, 340, 9704, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31121, 503, NULL, 9704, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31123, 2905, NULL, 9704, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31122, 7537, 339, 9704, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31120, 12956, NULL, 9704, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30988, 10864, NULL, 9676, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30987, 787, NULL, 9676, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30989, 6245, NULL, 9676, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30990, 5050, NULL, 9676, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31118, 12780, NULL, 9703, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31117, 8799, NULL, 9703, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31119, 10473, NULL, 9703, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31116, 12955, NULL, 9703, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31150, 11667, NULL, 9712, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31151, 6505, NULL, 9712, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31152, 1934, NULL, 9712, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31153, 1869, NULL, 9712, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31154, 387, NULL, 9713, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31155, 1814, NULL, 9713, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31157, 305, NULL, 9713, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31158, 2433, NULL, 9714, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31159, 1179, NULL, 9714, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31160, 1385, NULL, 9714, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31161, 914, NULL, 9714, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31162, 20, NULL, 9715, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31163, 104, NULL, 9715, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31164, 9610, NULL, 9715, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31165, 9611, NULL, 9715, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31166, 3271, NULL, 9716, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31167, 3619, NULL, 9716, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31168, 1643, NULL, 9716, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31169, 2770, NULL, 9716, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31170, 3373, NULL, 9717, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31171, 2907, NULL, 9717, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31172, 5153, NULL, 9717, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31173, 12240, NULL, 9718, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31174, 6576, NULL, 9718, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31175, 10288, NULL, 9718, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31176, 2036, NULL, 9718, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31177, 70, NULL, 9719, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31178, 5508, NULL, 9719, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31179, 12973, NULL, 9719, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31180, 5126, NULL, 9719, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5447, 5178, NULL, 2893, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5446, 983, NULL, 2893, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31134, 4758, 342, 9707, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31135, 1943, NULL, 9707, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31133, 2796, NULL, 9707, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5456, 5180, NULL, 2898, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17045, 2930, NULL, 4124, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28643, 7263, NULL, 8906, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28641, 1181, NULL, 8906, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31189, 231, NULL, 9721, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31190, 4997, NULL, 9721, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31191, 12976, NULL, 9721, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31192, 12977, NULL, 9721, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31193, 12978, NULL, 9721, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31194, 12979, 346, 9721, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31195, 2169, NULL, 9721, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31196, 9060, NULL, 9721, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31197, 267, NULL, 9722, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31198, 1096, NULL, 9722, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31199, 1462, NULL, 9722, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31200, 1838, 347, 9722, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31201, 239, 348, 9722, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31202, 1527, NULL, 9722, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31203, 403, 349, 9722, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31204, 771, NULL, 9722, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31213, 553, NULL, 9724, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31214, 11088, NULL, 9724, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31215, 1832, 351, 9724, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31216, 12981, NULL, 9724, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31217, 2879, NULL, 9724, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31218, 5307, NULL, 9724, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31219, 2878, NULL, 9724, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31220, 727, NULL, 9724, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31221, 3912, NULL, 9725, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31222, 318, NULL, 9725, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31223, 1374, NULL, 9725, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31224, 12982, NULL, 9725, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31225, 1701, NULL, 9725, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31226, 457, NULL, 9725, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31227, 1066, 352, 9725, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31228, 2773, NULL, 9725, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (28492, 1087, 355, 8868, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24477, 1087, 355, 7566, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1081, 1948, NULL, 327, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (1078, 133, NULL, 327, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31237, 803, NULL, 9727, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31238, 4924, NULL, 9727, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31239, 7003, NULL, 9727, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31240, 2828, NULL, 9727, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31241, 756, NULL, 9727, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31242, 12983, NULL, 9727, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31243, 1772, NULL, 9727, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31244, 12984, NULL, 9727, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31245, 814, NULL, 9728, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31246, 2728, 357, 9728, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31247, 12985, NULL, 9728, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31248, 1026, NULL, 9728, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31249, 1375, NULL, 9729, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31250, 152, NULL, 9729, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31251, 2696, NULL, 9729, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31252, 295, NULL, 9729, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31253, 12042, NULL, 9729, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31254, 238, NULL, 9729, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31255, 5758, NULL, 9729, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31256, 673, NULL, 9729, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31257, 1378, NULL, 9730, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31258, 384, NULL, 9730, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31259, 850, NULL, 9730, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31260, 1380, NULL, 9730, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31261, 1360, NULL, 9730, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31262, 932, NULL, 9730, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31263, 730, 358, 9730, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31264, 2918, NULL, 9730, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31265, 2703, 289, 9731, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31266, 624, 359, 9731, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31267, 275, NULL, 9731, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31268, 4840, NULL, 9731, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31269, 5123, NULL, 9731, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8708, 2789, 361, 3544, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22974, 2789, 361, 7107, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31270, 1802, NULL, 9732, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31271, 958, NULL, 9732, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31272, 4331, 360, 9732, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31273, 12390, NULL, 9732, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31274, 2789, 361, 9732, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31275, 5205, NULL, 9732, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31276, 12986, NULL, 9732, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31277, 162, NULL, 9732, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31278, 1785, NULL, 9733, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31279, 963, NULL, 9733, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31280, 12987, NULL, 9733, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31281, 3136, NULL, 9733, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31282, 7479, NULL, 9733, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31283, 12988, NULL, 9733, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31284, 12989, NULL, 9733, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31285, 11305, NULL, 4376, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31156, 2693, 365, 9713, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28661, 1744, NULL, 8909, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31290, 2596, NULL, 6335, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31291, 12997, 367, 6335, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31292, 10552, NULL, 6335, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31293, 2616, NULL, 6335, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30424, 11286, 368, 9499, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31294, 749, NULL, 6336, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31295, 12792, NULL, 6336, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31296, 5287, NULL, 6336, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31297, 1044, NULL, 6336, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31298, 727, NULL, 6336, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31299, 5054, NULL, 6336, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31300, 11286, 368, 6336, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31301, 12795, 369, 6336, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31302, 2862, NULL, 6337, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31303, 5132, NULL, 6337, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31304, 9552, NULL, 6337, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31305, 5132, NULL, 6337, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31306, 1414, NULL, 6338, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31307, 6048, NULL, 6326, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31308, 2882, 370, 6326, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31309, 1705, NULL, 6326, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31310, 12784, NULL, 6326, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31311, 872, NULL, 6326, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31312, 5667, NULL, 6326, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31313, 7558, NULL, 6326, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31314, 1895, 371, 6326, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31315, 626, NULL, 6327, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31316, 2691, 372, 6327, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31317, 302, NULL, 6327, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31318, 807, NULL, 6328, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31319, 955, NULL, 6328, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31320, 503, NULL, 6328, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31321, 3132, 373, 6328, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31322, 171, 374, 6328, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31323, 11937, NULL, 6328, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31324, 1956, NULL, 6328, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31325, 1553, NULL, 6328, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31326, 295, NULL, 6329, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31327, 2138, NULL, 6329, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31328, 1052, NULL, 6329, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31329, 1880, 375, 6329, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31330, 2353, NULL, 6330, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31331, 2844, 376, 6330, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31332, 3682, NULL, 6330, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31333, 10625, NULL, 6330, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31334, 1670, NULL, 6331, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31335, 3628, NULL, 6331, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31336, 5132, NULL, 6331, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31337, 128, 377, 6332, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31338, 688, NULL, 6332, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31339, 312, NULL, 6332, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31340, 12788, NULL, 6332, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31341, 2973, NULL, 6333, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31342, 12998, NULL, 6333, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31351, 1513, NULL, 9328, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5818, 128, NULL, 2986, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6425, 2789, 361, 2490, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31234, 1876, NULL, 9726, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31229, 3946, 523, 9726, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31235, 861, 356, 9726, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31230, 967, NULL, 9726, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1077, 2035, NULL, 327, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1079, 2822, NULL, 327, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33164, 8419, NULL, 10269, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28254, 1087, 355, 8803, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27055, 128, 379, 8349, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30330, 128, 379, 9474, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31352, 1622, NULL, 9750, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31353, 13000, NULL, 9751, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31354, 13001, NULL, 9752, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31355, 5855, 381, 9753, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31356, 13002, NULL, 9754, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31357, 13003, NULL, 9755, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31358, 13005, NULL, 9756, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31359, 13004, NULL, 9757, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31360, 13006, NULL, 9758, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31361, 8602, NULL, 9759, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31362, 9109, NULL, 9760, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31363, 13007, NULL, 9761, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31364, 13008, NULL, 9762, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31365, 2973, NULL, 9763, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31366, 2616, NULL, 9751, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31368, 1894, NULL, 9751, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31369, 2691, NULL, 9751, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31370, 2992, NULL, 9751, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31371, 62, NULL, 9751, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31367, 13009, NULL, 9751, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31372, 4983, NULL, 9752, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31373, 7134, NULL, 9752, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31374, 996, NULL, 9752, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31375, 1716, NULL, 9752, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31376, 1491, NULL, 9752, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31377, 2532, NULL, 9752, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31379, 1379, NULL, 9753, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31380, 2414, NULL, 9753, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31381, 1959, NULL, 9753, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31382, 5933, NULL, 9754, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31383, 9680, NULL, 9754, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31384, 1443, NULL, 9754, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31385, 3846, NULL, 9755, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31386, 2452, NULL, 9755, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31387, 141, NULL, 9755, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31388, 6312, NULL, 9757, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31389, 2316, NULL, 9757, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31390, 11109, NULL, 9757, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26483, 1861, NULL, 8187, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31391, 1786, NULL, 9756, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31392, 2494, NULL, 9756, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31393, 1861, NULL, 9756, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31394, 1965, NULL, 9756, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31395, 1875, NULL, 9756, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31396, 2138, NULL, 9756, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31025, 2138, NULL, 5892, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19898, 2138, NULL, 6207, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19298, 2138, NULL, 5881, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31397, 1026, NULL, 9758, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31398, 2443, 384, 9758, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31399, 7424, NULL, 9759, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31400, 13010, NULL, 9759, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31401, 13011, NULL, 9759, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31402, 9674, NULL, 9760, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31403, 3057, NULL, 9760, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31404, 6458, NULL, 9760, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31405, 1971, NULL, 9760, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31406, 8, NULL, 9760, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31407, 13012, NULL, 9760, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31408, 2571, NULL, 9761, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31409, 5666, NULL, 9761, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31410, 4907, NULL, 9761, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31411, 13014, NULL, 9762, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31412, 13015, NULL, 9762, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31413, 1927, NULL, 9762, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31414, 13016, NULL, 9763, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5701, 5212, NULL, 2966, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5700, 5204, NULL, 2966, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25153, 3120, 386, 7776, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25186, 91, 392, 7784, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31415, 1257, 62, 6557, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31416, 11201, NULL, 6557, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25217, 4242, 402, 7791, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25248, 141, 405, 7796, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (25269, 7961, 409, 7801, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31417, 9703, NULL, 9764, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31418, 13033, NULL, 9764, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31419, 12582, NULL, 9766, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31420, 3145, NULL, 9766, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31421, 10497, NULL, 9766, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31422, 12587, NULL, 9767, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31423, 5119, NULL, 9767, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31424, 3130, NULL, 9767, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31425, 4183, NULL, 9767, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31426, 2929, NULL, 9768, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31427, 1894, NULL, 9768, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31428, 10437, NULL, 9768, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31429, 10516, NULL, 9768, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31430, 12584, NULL, 9769, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31431, 1456, NULL, 9769, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31432, 9523, NULL, 9769, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31433, 12215, NULL, 9770, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31434, 13034, NULL, 9770, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31435, 3559, NULL, 9770, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31436, 10481, NULL, 9771, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31437, 2165, NULL, 9771, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31438, 6061, NULL, 9771, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31439, 13035, NULL, 9772, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31440, 1087, NULL, 9772, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31441, 7259, NULL, 9772, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31442, 13036, NULL, 9772, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31449, 12586, NULL, 9774, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31450, 6005, NULL, 9774, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31451, 13041, NULL, 9774, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31452, 10306, NULL, 9775, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31453, 7245, NULL, 9775, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31454, 7132, NULL, 9775, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31455, 13042, NULL, 9775, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31456, 1635, NULL, 9776, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31457, 10205, NULL, 9776, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31458, 9552, NULL, 9776, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31459, 4858, NULL, 9776, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31460, 7292, NULL, 9764, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31461, 13043, NULL, 9764, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31462, 12581, NULL, 9765, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31463, 9962, NULL, 9765, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31464, 7578, NULL, 9765, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31465, 111, NULL, 9765, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24356, 876, NULL, 7529, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21663, 7293, 411, 6784, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21665, 3004, 412, 6784, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21634, 3431, 414, 6778, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21639, 1241, 416, 6779, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21299, 3132, 418, 6674, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21298, 1031, 173, 6674, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31181, 75, NULL, 9720, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31184, 98, 345, 9720, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31188, 3433, NULL, 9720, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31187, 7002, NULL, 9720, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31186, 12975, NULL, 9720, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31185, 817, NULL, 9720, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31182, 4039, NULL, 9720, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31183, 12974, NULL, 9720, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28257, 534, NULL, 8804, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28259, 1406, NULL, 8804, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28258, 7578, NULL, 8804, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25850, 11275, NULL, 7995, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25849, 4500, NULL, 7995, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25848, 431, NULL, 7995, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25853, 11276, NULL, 7995, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (25854, 940, NULL, 7995, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (25855, 11277, NULL, 7995, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (25852, 9070, 235, 7995, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25851, 975, NULL, 7995, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26219, 431, NULL, 8090, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26220, 11326, NULL, 8090, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26222, 11385, NULL, 8090, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26221, 11384, NULL, 8090, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22728, 5590, NULL, 7042, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22729, 7562, NULL, 7042, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17560, 9051, NULL, 5588, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17562, 5666, NULL, 5588, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17561, 2447, NULL, 5588, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23957, 8193, NULL, 7382, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23955, 2305, NULL, 7382, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23954, 842, NULL, 7382, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23953, 9273, NULL, 7382, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23956, 2531, NULL, 7382, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31447, 13040, NULL, 9773, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31132, 1788, NULL, 9707, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4218, 78, NULL, 1419, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4217, 1457, NULL, 1419, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4219, 2806, NULL, 1419, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8117, 5778, NULL, 1831, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8118, 5779, NULL, 1831, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20459, 7963, NULL, 6419, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20460, 7964, NULL, 6419, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20458, 5608, NULL, 6419, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20457, 9985, NULL, 6419, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20456, 9984, NULL, 6419, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30014, 12659, NULL, 9385, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30012, 12657, NULL, 9385, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30015, 12660, NULL, 9385, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30013, 12658, NULL, 9385, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17563, 9052, NULL, 5589, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17566, 9054, NULL, 5589, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9090, 6045, NULL, 1620, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9091, 3145, NULL, 1620, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16313, 5560, NULL, 5318, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16310, 6428, NULL, 5318, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16312, 1336, NULL, 5318, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16311, 8190, NULL, 5318, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1236, 1335, NULL, 387, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1234, 1292, NULL, 387, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1235, 1332, NULL, 387, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27975, 11919, NULL, 8697, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29761, 2626, NULL, 9300, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29762, 2532, NULL, 9300, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29760, 1374, NULL, 9300, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20209, 9880, NULL, 6358, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20210, 9881, NULL, 6358, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20211, 9882, NULL, 6358, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5459, 1678, NULL, 2899, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31471, 2038, NULL, 6324, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31472, 5132, NULL, 6324, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31473, 5132, NULL, 6324, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31474, 13123, NULL, 6324, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5468, 5182, NULL, 2904, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31477, 7241, 428, 6311, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31476, 1875, NULL, 6311, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31478, 2081, NULL, 6311, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31475, 1593, NULL, 6311, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31481, 312, 429, 6312, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31480, 688, NULL, 6312, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31482, 12788, NULL, 6312, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31479, 1567, NULL, 6312, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31483, 1008, NULL, 6313, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31484, 10438, NULL, 6313, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31485, 1042, NULL, 6313, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31486, 2144, NULL, 6313, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31487, 601, NULL, 6314, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31488, 757, NULL, 6315, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31489, 1424, NULL, 6315, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31490, 2317, NULL, 6315, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31491, 1926, NULL, 6315, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31492, 5132, NULL, 6316, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31493, 5132, NULL, 6316, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31494, 3131, NULL, 6316, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31495, 133, NULL, 6316, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31496, 967, NULL, 6316, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31497, 1345, NULL, 6317, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31498, 2138, NULL, 6317, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31499, 1052, NULL, 6317, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31500, 1880, NULL, 6317, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31505, 186, NULL, 6319, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31507, 220, NULL, 6319, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31508, 3456, NULL, 6319, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31506, 2803, NULL, 6319, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31510, 10438, NULL, 6320, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31512, 239, NULL, 6320, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31509, 548, NULL, 6320, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31511, 1042, NULL, 6320, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31513, 749, NULL, 6321, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31514, 12792, NULL, 6321, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31515, 5287, NULL, 6321, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31516, 1044, NULL, 6321, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31517, 727, NULL, 6321, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31518, 5054, NULL, 6321, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31519, 11286, 368, 6321, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31520, 12795, 369, 6321, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31521, 5055, NULL, 6322, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31522, 3749, NULL, 6322, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31523, 5440, NULL, 6322, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31524, 1967, 431, 6322, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31469, 973, NULL, 6323, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31468, 2702, NULL, 6323, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31467, 2846, NULL, 6323, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31470, 2862, 432, 6323, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31525, 247, NULL, 6325, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31526, 1575, NULL, 6325, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31527, 13124, NULL, 6325, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31528, 6945, 433, 6325, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21612, 6945, 433, 6772, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (5495, 6945, 433, 2230, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14484, 6945, 433, 4862, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30381, 6945, 433, 9488, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29337, 6945, 433, 9148, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (916, 6945, 433, 143, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19231, 6945, 433, 6063, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4380, 6945, 433, 1842, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1528, 6945, 433, 583, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33011, 913, NULL, 10205, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19910, 9778, NULL, 6210, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19909, 9777, NULL, 6210, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18703, 2266, NULL, 5908, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18705, 3071, NULL, 5908, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18702, 9070, NULL, 5908, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18704, 2769, NULL, 5908, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27973, 2473, NULL, 8697, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27974, 10211, NULL, 8697, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8261, 963, NULL, 548, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8262, 3136, NULL, 548, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8260, 1785, NULL, 548, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24157, 3591, NULL, 7453, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24158, 350, NULL, 7453, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24156, 1389, NULL, 7453, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18043, 2568, NULL, 5726, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18044, 2816, NULL, 5726, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18041, 1283, NULL, 5726, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18042, 3072, NULL, 5726, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31529, 9969, NULL, 9777, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31530, 7, NULL, 9777, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31531, 3672, NULL, 9777, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31532, 2614, NULL, 9778, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31533, 1241, NULL, 9778, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31534, 2658, NULL, 9778, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33012, 7707, 537, 10205, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33013, 13917, NULL, 10205, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31543, 437, NULL, 9781, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31544, 2544, NULL, 9781, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31545, 346, NULL, 9781, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31546, 5856, NULL, 9781, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6938, 267, NULL, 1512, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6939, 842, NULL, 1512, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6940, 1527, NULL, 1512, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22833, 10644, NULL, 7069, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31554, 5933, NULL, 9784, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31555, 4778, NULL, 9784, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31556, 5933, NULL, 9784, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31557, 3512, NULL, 9785, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31542, 13134, NULL, 9780, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31540, 3545, NULL, 9780, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31541, 2804, NULL, 9780, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31535, 5, NULL, 9779, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31536, 2204, NULL, 9779, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31539, 2488, NULL, 9779, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16919, 5778, NULL, 5438, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16920, 5779, NULL, 5438, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22831, 10642, NULL, 7069, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22830, 923, NULL, 7069, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31558, 5855, NULL, 9785, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31559, 1352, NULL, 9785, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31560, 7502, NULL, 9785, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31561, 1622, NULL, 9786, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31562, 8507, NULL, 9786, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31549, 1068, NULL, 9782, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31547, 6685, NULL, 9782, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31548, 2597, NULL, 9782, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31550, 5490, NULL, 9782, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10806, 636, NULL, 4055, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10805, 1389, NULL, 4055, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10807, 1668, NULL, 4055, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30473, 4699, NULL, 9342, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30475, 10885, NULL, 9342, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30477, 4552, NULL, 9342, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30476, 1788, NULL, 9342, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9817, 6945, 433, 3767, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17804, 9151, NULL, 5662, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17805, 9152, NULL, 5662, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17806, 626, NULL, 5662, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17803, 8393, NULL, 5662, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27653, 6945, 433, 8569, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7539, 6945, 433, 2303, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31504, 6047, 430, 6318, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31501, 769, NULL, 6318, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31503, 5786, NULL, 6318, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10808, 3114, NULL, 4055, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28624, 10770, NULL, 8902, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28623, 1086, NULL, 8902, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28622, 12105, NULL, 8902, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5055, 352, NULL, 2244, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5054, 1793, NULL, 2244, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7864, 302, NULL, 3244, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7862, 5620, NULL, 3244, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7865, 792, NULL, 3244, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7863, 3057, NULL, 3244, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7867, 1291, NULL, 3245, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31577, 815, NULL, 9818, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31578, 13146, NULL, 9818, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31579, 13147, NULL, 9818, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31580, 13148, NULL, 9818, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31581, 892, NULL, 9819, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31582, 12283, NULL, 9819, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31583, 2544, NULL, 9819, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31584, 103, NULL, 9819, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31589, 13151, NULL, 9821, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31590, 13152, NULL, 9821, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31591, 1945, NULL, 9821, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31592, 160, NULL, 9822, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31593, 1193, NULL, 9822, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31594, 9913, NULL, 9822, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31595, 6439, NULL, 9822, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33037, 13942, 538, 10209, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31603, 13154, NULL, 9824, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31596, 3601, 437, 9823, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31598, 4267, 438, 9823, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31597, 5490, NULL, 9823, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31599, 247, NULL, 9823, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31604, 2948, NULL, 9825, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31605, 13155, NULL, 9825, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31606, 7664, NULL, 9825, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31607, 1085, NULL, 9826, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31608, 2952, NULL, 9826, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31609, 13156, NULL, 9826, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31610, 12653, NULL, 9826, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31611, 819, NULL, 9827, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31612, 112, NULL, 9827, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31613, 4264, NULL, 9827, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31614, 1126, 256, 9828, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31615, 814, NULL, 9828, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31616, 2190, NULL, 9828, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31617, 10148, NULL, 9829, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31618, 13157, NULL, 9829, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31619, 13158, NULL, 9829, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31620, 9516, NULL, 9829, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8561, 2061, NULL, 3467, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8562, 3126, NULL, 3467, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8563, 5885, NULL, 3467, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8560, 1761, NULL, 3467, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31621, 10993, NULL, 9747, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31622, 1621, NULL, 9747, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31623, 770, NULL, 9747, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31624, 685, NULL, 9747, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31625, 122, NULL, 9747, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16972, 312, NULL, 479, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16971, 389, NULL, 479, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16973, 4360, NULL, 479, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16981, 2774, NULL, 482, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31626, 2840, NULL, 483, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31627, 9535, NULL, 483, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14532, 1457, NULL, 4880, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14523, 1141, NULL, 4877, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14515, 1528, NULL, 4874, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31628, 13189, NULL, 9830, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31629, 2888, NULL, 9830, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31630, 5577, NULL, 9830, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31631, 6373, NULL, 9830, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31632, 7472, NULL, 9831, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31633, 8290, NULL, 9831, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31634, 13197, NULL, 9831, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31635, 8195, NULL, 9831, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31600, 534, NULL, 9824, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31602, 5828, 142, 9824, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31640, 13191, NULL, 9833, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31641, 13198, NULL, 9833, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31642, 8334, NULL, 9833, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31643, 13192, NULL, 9834, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31644, 8190, NULL, 9834, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31645, 10293, NULL, 9834, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31646, 13199, NULL, 9835, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31647, 7612, NULL, 9836, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31648, 13200, NULL, 9836, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31649, 13201, NULL, 9836, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31650, 12760, NULL, 9836, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31651, 4327, NULL, 9837, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31652, 2128, NULL, 9837, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31653, 7502, NULL, 9837, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31654, 2416, NULL, 9838, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31655, 4313, NULL, 9838, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31656, 62, NULL, 9838, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31657, 5854, NULL, 9838, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31658, 13193, NULL, 9839, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31659, 3077, NULL, 9839, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31660, 5560, NULL, 9839, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31661, 2445, NULL, 9839, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31662, 13194, NULL, 9840, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31663, 2294, NULL, 9840, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31664, 2892, NULL, 9840, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31665, 10864, NULL, 9840, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31666, 13202, NULL, 9840, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31667, 13195, NULL, 9841, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31668, 5859, NULL, 9841, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31669, 2872, NULL, 9841, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31670, 8240, NULL, 9841, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31671, 13196, NULL, 9842, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31672, 10471, NULL, 9842, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31673, 13203, NULL, 9842, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31674, 5874, NULL, 9842, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31675, 8806, NULL, 9843, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31676, 1457, NULL, 9844, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31677, 2191, NULL, 9844, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31678, 6505, NULL, 9844, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31679, 13204, NULL, 9844, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31680, 198, NULL, 9845, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31681, 13205, NULL, 9845, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31682, 3459, NULL, 9846, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31683, 12188, NULL, 9846, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31684, 13206, NULL, 9846, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31685, 13207, NULL, 9846, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23701, 10856, NULL, 7319, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23703, 8316, NULL, 7319, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23702, 6691, NULL, 7319, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23704, 1744, NULL, 7319, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31686, 13218, NULL, 9847, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31687, 13227, NULL, 9847, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31688, 2572, NULL, 9847, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31689, 13228, NULL, 9847, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31690, 13219, NULL, 9848, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31691, 7557, NULL, 9848, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31692, 5370, NULL, 9848, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31693, 3498, NULL, 9848, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31694, 13220, NULL, 9849, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31695, 556, NULL, 9849, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31696, 861, NULL, 9849, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31697, 1373, NULL, 9849, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31698, 13221, NULL, 9850, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31699, 292, NULL, 9850, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31700, 2888, NULL, 9850, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24528, 3236, NULL, 7579, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24529, 2513, NULL, 7579, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31703, 13223, NULL, 9852, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31704, 13224, NULL, 9853, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31705, 486, NULL, 9853, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31706, 1208, NULL, 9853, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24526, 8316, NULL, 7579, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31601, 13153, NULL, 9824, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31639, 4835, NULL, 9832, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31638, 821, NULL, 9832, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30269, 5126, NULL, 9458, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32916, 1429, NULL, 10195, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32913, 3741, NULL, 10193, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32894, 1562, NULL, 10186, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31707, 2920, NULL, 9853, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31708, 13225, NULL, 9854, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31709, 13229, NULL, 9854, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31713, 13218, NULL, 9856, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31714, 13227, NULL, 9856, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31715, 2572, NULL, 9856, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31716, 13228, NULL, 9856, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31702, 336, NULL, 9851, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31701, 13222, NULL, 9851, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30981, 809, NULL, 9674, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30979, 12936, NULL, 9674, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30982, 1086, NULL, 9674, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30980, 4409, NULL, 9674, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29882, 12552, NULL, 9349, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29880, 12550, NULL, 9349, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29881, 12551, NULL, 9349, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30229, 654, NULL, 9447, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30230, 2559, NULL, 9447, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30227, 773, NULL, 9447, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30228, 1312, NULL, 9447, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31572, 3642, NULL, 9802, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31569, 601, NULL, 9802, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31571, 13136, NULL, 9802, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14963, 1505, NULL, 4881, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31575, 13145, NULL, 9817, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31573, 9533, NULL, 9817, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31574, 10124, NULL, 9817, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31576, 12180, NULL, 9817, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15264, 7674, NULL, 5030, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15263, 2153, NULL, 5030, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15262, 7661, NULL, 5030, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15265, 7675, NULL, 5030, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21556, 1648, NULL, 6758, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21558, 8495, NULL, 6758, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (912, 1926, NULL, 11, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (913, 2356, NULL, 11, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (911, 2839, NULL, 11, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4898, 389, NULL, 1448, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4900, 675, NULL, 1448, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4899, 1089, NULL, 1448, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4897, 1166, NULL, 1448, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3939, 312, NULL, 1403, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (3935, 366, NULL, 1403, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3937, 3257, NULL, 1403, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3938, 1067, NULL, 1403, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (3936, 1352, NULL, 1403, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3934, 1489, NULL, 1403, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22389, 8842, NULL, 6958, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22391, 9577, NULL, 6958, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2858, 3138, NULL, 902, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31717, 156, NULL, 9857, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31718, 2054, NULL, 9858, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11671, 1643, NULL, 1706, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11672, 6694, NULL, 1706, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11673, 664, NULL, 1706, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11670, 939, NULL, 1706, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11679, 5563, NULL, 1708, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11696, 4541, NULL, 1713, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11701, 320, NULL, 1715, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11700, 1664, NULL, 1715, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11702, 763, NULL, 1716, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11704, 6698, NULL, 1716, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11711, 2953, NULL, 4168, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31719, 2798, NULL, 9859, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7639, 1212, NULL, 1984, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9296, 5592, NULL, 1985, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9298, 5593, NULL, 1985, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9297, 1417, NULL, 1985, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9307, 6116, NULL, 1990, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9304, 6113, NULL, 1990, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7640, 3828, NULL, 1988, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7645, 1837, NULL, 1989, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17417, 8895, NULL, 5563, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17418, 8896, NULL, 5563, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17420, 8898, NULL, 5563, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17419, 8897, NULL, 5563, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14921, 5911, NULL, 1453, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14923, 3264, NULL, 1453, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14924, 7179, NULL, 1453, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19265, 1854, NULL, 5860, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19263, 9628, NULL, 5860, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19262, 1113, NULL, 5860, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19264, 7751, NULL, 5860, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12844, 6986, NULL, 4457, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12846, 6987, NULL, 4458, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12854, 1708, NULL, 4463, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12858, 2899, NULL, 4465, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12864, 1389, NULL, 4467, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4050, 371, NULL, 1659, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4051, 2285, NULL, 1659, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4052, 4868, NULL, 1659, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31538, 2660, NULL, 9779, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31537, 2221, NULL, 9779, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18438, 9365, NULL, 5812, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18439, 9366, NULL, 5812, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15231, 7592, NULL, 5021, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15230, 7591, NULL, 5021, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31720, 13233, NULL, 9860, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31721, 2452, NULL, 9860, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31722, 9854, NULL, 9860, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31756, 7067, NULL, 9869, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31760, 4729, NULL, 9869, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (22390, 8843, NULL, 6958, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31725, 13271, NULL, 9861, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31723, 13234, NULL, 9861, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31724, 2918, NULL, 9861, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31726, 3004, NULL, 9861, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31731, 13236, NULL, 9863, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31733, 8403, 447, 9863, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31732, 7531, NULL, 9863, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31757, 376, NULL, 9869, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31739, 1954, NULL, 9865, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31742, 9678, NULL, 9865, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31738, 13238, NULL, 9865, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31740, 10864, NULL, 9865, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31741, 2952, NULL, 9865, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31746, 13239, NULL, 9867, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31748, 10356, NULL, 9867, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31749, 972, NULL, 9867, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31747, 1944, NULL, 9867, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31751, 3077, NULL, 9868, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31752, 1609, NULL, 9868, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31750, 13240, NULL, 9868, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31710, 13226, NULL, 9855, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31712, 13230, NULL, 9855, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31711, 3072, NULL, 9855, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31743, 13232, NULL, 9866, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31744, 9524, NULL, 9866, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31745, 1745, NULL, 9866, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8453, 5858, NULL, 3441, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8454, 3077, NULL, 3441, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8452, 2948, NULL, 3441, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8455, 5859, NULL, 3441, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9084, 3206, NULL, 1618, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9082, 6042, NULL, 1618, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9080, 3205, NULL, 1618, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9081, 2012, NULL, 1618, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9079, 3860, NULL, 1618, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5647, 209, NULL, 2949, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5646, 850, NULL, 2949, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5649, 2396, NULL, 2949, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5648, 1665, NULL, 2949, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6796, 5396, NULL, 3143, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6794, 559, NULL, 3143, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6795, 3725, NULL, 3143, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2950, 215, NULL, 467, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2951, 3163, NULL, 467, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2953, 3165, NULL, 467, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2952, 3164, NULL, 467, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7377, 2921, NULL, 2525, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7375, 5308, NULL, 2525, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7373, 2554, NULL, 2525, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7374, 3682, NULL, 2525, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7376, 3199, NULL, 2525, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7372, 1748, NULL, 2525, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31759, 787, NULL, 9869, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31737, 12285, NULL, 9864, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31735, 8792, NULL, 9864, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31736, 10292, NULL, 9864, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31734, 13237, NULL, 9864, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19943, 1585, NULL, 6219, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19944, 3643, NULL, 6219, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18027, 2644, NULL, 5722, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18026, 9026, NULL, 5722, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4555, 3159, NULL, 1130, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4554, 3741, NULL, 1130, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4553, 1051, NULL, 1130, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4556, 5001, NULL, 1130, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6424, 2479, NULL, 2490, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6423, 756, NULL, 2490, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6422, 1772, NULL, 2490, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6426, 128, 379, 2494, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6429, 1670, NULL, 2499, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11575, 5328, NULL, 2497, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11576, 1373, NULL, 2497, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11574, 1578, NULL, 2497, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6441, 498, NULL, 2495, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6443, 5333, NULL, 2495, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6445, 3984, NULL, 2495, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6444, 4252, NULL, 2495, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18921, 1137, NULL, 5966, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14917, 3077, NULL, 242, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14918, 1193, NULL, 242, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14916, 1364, NULL, 242, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6947, 5440, NULL, 1516, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6949, 5441, NULL, 1516, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2682, 3075, NULL, 89, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2683, 3076, NULL, 89, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12454, 926, NULL, 89, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2681, 3074, NULL, 89, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33038, 190, NULL, 2560, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26882, 2055, NULL, 8311, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26883, 2086, NULL, 8311, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26889, 3222, NULL, 8311, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (3740, 3669, NULL, 1346, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1367, 778, NULL, 427, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19080, 2138, NULL, 6010, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19081, 6259, NULL, 6010, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18959, 1943, NULL, 5973, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (18958, 2611, NULL, 5973, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18955, 445, NULL, 5973, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3741, 4003, NULL, 1346, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26887, 11482, NULL, 8311, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26886, 11481, NULL, 8311, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26885, 2691, NULL, 8311, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26888, 1222, NULL, 8311, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26884, 2887, NULL, 8311, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31761, 318, NULL, 499, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31762, 11869, NULL, 499, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31763, 1963, NULL, 499, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31764, 259, NULL, 499, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31765, 6342, NULL, 9875, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31766, 1664, NULL, 9875, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31767, 376, NULL, 9875, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31768, 2993, NULL, 9875, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31780, 13282, NULL, 9879, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31781, 3594, NULL, 9880, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31782, 2615, NULL, 9880, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31783, 6026, NULL, 9880, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31784, 7108, NULL, 9880, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31799, 1030, NULL, 9885, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31797, 4192, NULL, 9885, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31800, 8447, NULL, 9885, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31789, 4100, NULL, 9882, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31790, 10483, NULL, 9882, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31791, 10484, NULL, 9882, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31792, 10485, NULL, 9882, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31793, 9623, NULL, 9883, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31794, 2360, NULL, 9883, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31795, 8725, NULL, 9883, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31796, 2212, NULL, 9883, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31805, 13284, NULL, 9887, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31806, 13285, NULL, 9887, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31807, 13286, NULL, 9887, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22619, 3324, NULL, 7011, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22621, 332, NULL, 7011, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22620, 3672, NULL, 7011, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22618, 1744, NULL, 7011, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1480, 2029, NULL, 510, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1481, 1997, NULL, 510, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1479, 1431, NULL, 510, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2329, 2953, NULL, 449, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20264, 9514, NULL, 6381, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20265, 7094, NULL, 6381, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20267, 9909, NULL, 6381, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20266, 2554, NULL, 6381, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19478, 2979, NULL, 6122, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19477, 7538, NULL, 6122, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19479, 7537, NULL, 6122, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19447, 1485, NULL, 6122, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19480, 3001, NULL, 6122, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (24507, 11005, NULL, 7574, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24508, 11006, NULL, 7574, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24509, 2069, NULL, 7574, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16016, 7934, NULL, 5217, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16018, 2340, NULL, 5217, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16017, 8039, NULL, 5217, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15135, 1565, NULL, 4974, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4069, 4881, NULL, 1660, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (30079, 12737, NULL, 1660, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20886, 7918, NULL, 6551, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20885, 3165, NULL, 6551, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20888, 10184, NULL, 6551, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20887, 10183, NULL, 6551, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21375, 2981, NULL, 6692, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21372, 1021, NULL, 6692, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21374, 1294, NULL, 6692, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21373, 2448, NULL, 6692, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17697, 9117, NULL, 5626, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17698, 9118, NULL, 5626, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17699, 9119, NULL, 5626, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17696, 9000, NULL, 5626, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17941, 9227, NULL, 5696, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17939, 9225, NULL, 5696, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17938, 9224, NULL, 5696, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17940, 9226, NULL, 5696, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14928, 1364, NULL, 1454, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31812, 13290, NULL, 9889, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31813, 2892, NULL, 9889, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31814, 1965, NULL, 9889, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31815, 2753, NULL, 9889, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31816, 13307, NULL, 9890, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31817, 13308, NULL, 9890, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31818, 13309, NULL, 9890, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31819, 13310, NULL, 9891, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31820, 3766, 449, 9891, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31821, 5278, NULL, 9891, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31822, 13311, NULL, 9892, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31823, 1929, NULL, 9892, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31824, 2625, NULL, 9892, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31825, 10664, NULL, 9892, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31826, 5312, NULL, 9892, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31827, 5197, NULL, 9893, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31828, 13312, NULL, 9894, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31829, 2805, NULL, 9894, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31830, 2904, NULL, 9894, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31831, 13313, NULL, 9895, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31832, 11, NULL, 9895, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31833, 2929, NULL, 9895, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31834, 2691, NULL, 9895, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31835, 13314, NULL, 9896, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31836, 11937, NULL, 9896, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31837, 2165, NULL, 9896, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31838, 1862, 341, 9896, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31842, 6411, 451, 9898, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31843, 13316, NULL, 9899, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31844, 389, NULL, 9899, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31845, 996, NULL, 9899, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31846, 11528, NULL, 9899, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31847, 1716, NULL, 9899, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31848, 13317, NULL, 9900, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31849, 13318, NULL, 9900, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31850, 2583, NULL, 9900, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31851, 1687, NULL, 9900, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31785, 3801, NULL, 9881, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32893, 1581, NULL, 10186, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31852, 10368, 452, 9901, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31853, 10369, NULL, 9901, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31854, 5283, NULL, 9901, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31855, 2747, NULL, 9901, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31863, 13319, NULL, 9903, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31864, 13320, NULL, 9903, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31865, 13321, NULL, 9903, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31866, 13322, NULL, 9903, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31877, 13332, NULL, 9907, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31890, 13337, NULL, 9911, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31891, 10650, NULL, 9912, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31892, 5650, NULL, 9912, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31893, 1613, NULL, 9912, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31894, 5569, NULL, 9912, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31895, 13338, NULL, 9912, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31906, 13344, NULL, 9915, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31904, 13343, NULL, 9915, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31923, 2231, NULL, 9919, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31924, 665, NULL, 9919, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31928, 12780, NULL, 9920, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31903, 13342, NULL, 9914, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31901, 3825, NULL, 9914, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31902, 13341, NULL, 9914, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31900, 7614, NULL, 9914, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31885, 2048, NULL, 9909, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31882, 2151, NULL, 9909, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31884, 1122, 455, 9909, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22850, 1856, NULL, 7074, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22853, 10655, NULL, 7074, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22852, 10654, NULL, 7074, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2032, 503, NULL, 726, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2030, 1797, NULL, 726, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31883, 1118, NULL, 9909, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31908, 6373, NULL, 9916, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31909, 7678, NULL, 9916, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31861, 9627, NULL, 9902, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31856, 4358, NULL, 9902, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31860, 10484, NULL, 9902, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31862, 9099, 453, 9902, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31841, 787, NULL, 9897, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31839, 13315, NULL, 9897, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31840, 2434, NULL, 9897, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31801, 290, NULL, 9886, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14099, 1287, NULL, 4690, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14100, 1364, NULL, 4690, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14102, 7313, NULL, 4690, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14101, 2939, NULL, 4690, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31803, 2405, NULL, 9886, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31802, 10575, NULL, 9886, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31804, 10576, NULL, 9886, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31774, 8409, NULL, 9877, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31775, 8408, NULL, 9877, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31773, 8410, NULL, 9877, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31772, 1161, NULL, 9877, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31776, 9622, NULL, 9878, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31779, 709, NULL, 9878, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31777, 4444, NULL, 9878, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31778, 1916, NULL, 9878, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31809, 2358, NULL, 9888, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31808, 12733, NULL, 9888, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31810, 1146, NULL, 9888, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31811, 2605, NULL, 9888, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31910, 13346, NULL, 9916, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31907, 13289, NULL, 9916, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31981, 13255, NULL, 9938, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31982, 13394, NULL, 9938, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31983, 13395, NULL, 9938, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31871, 13328, NULL, 9905, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31984, 13396, NULL, 9938, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32007, 1983, NULL, 9945, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32005, 13404, NULL, 9945, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32006, 13405, NULL, 9945, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31922, 2138, NULL, 9919, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31925, 429, NULL, 9919, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31927, 13361, NULL, 9920, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31926, 13360, NULL, 9920, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31929, 10473, NULL, 9920, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31931, 13363, NULL, 9921, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31932, 10577, NULL, 9921, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31933, 13364, NULL, 9921, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31930, 12096, NULL, 9921, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18028, 3145, NULL, 5722, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31936, 8523, NULL, 9923, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31937, 376, NULL, 9923, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31935, 2950, NULL, 9923, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31938, 10864, NULL, 9923, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31941, 2981, NULL, 9924, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31942, 5590, NULL, 9924, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31940, 2056, NULL, 9924, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31943, 5773, NULL, 9924, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31939, 1456, NULL, 9924, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31947, 7429, NULL, 9925, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31945, 9534, NULL, 9925, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31946, 12781, NULL, 9925, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31944, 13366, NULL, 9925, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31950, 8507, NULL, 9926, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31948, 13367, NULL, 9926, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31949, 4451, NULL, 9926, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31951, 10202, NULL, 9926, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31955, 11721, NULL, 9927, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31952, 6396, NULL, 9927, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31954, 1971, NULL, 9927, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31953, 1872, NULL, 9927, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31956, 13368, NULL, 9928, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31985, 13250, NULL, 9939, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31962, 9310, 456, 9930, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31961, 5753, NULL, 9930, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31963, 4442, NULL, 9930, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31960, 13370, NULL, 9930, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31966, 13373, NULL, 9931, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31964, 13371, NULL, 9931, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31965, 13372, NULL, 9931, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31970, 2496, NULL, 9932, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31967, 5372, NULL, 9932, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31968, 13374, NULL, 9932, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31969, 13375, NULL, 9932, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31972, 12742, NULL, 9933, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31971, 13357, NULL, 9933, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31973, 1622, NULL, 9935, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31912, 103, NULL, 9917, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31915, 2921, NULL, 9917, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31914, 13349, NULL, 9917, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27132, 972, NULL, 8369, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27134, 5312, NULL, 8369, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (27135, 7056, NULL, 8369, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (27130, 1144, NULL, 8369, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27131, 11708, NULL, 8369, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27133, 3709, NULL, 8369, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31974, 13253, NULL, 9936, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31975, 2554, NULL, 9936, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31976, 6039, NULL, 9936, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31977, 5853, NULL, 9936, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31978, 13393, NULL, 9937, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31979, 7119, NULL, 9937, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31980, 2822, NULL, 9937, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31986, 13397, NULL, 9939, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31987, 13398, NULL, 9939, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31991, 13248, NULL, 9941, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31992, 12774, NULL, 9941, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31993, 695, NULL, 9941, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31918, 13358, NULL, 9918, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31920, 13162, NULL, 9918, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31919, 4872, NULL, 9918, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31998, 13252, NULL, 9943, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31999, 10367, NULL, 9943, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32000, 1955, NULL, 9943, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31921, 13359, NULL, 9918, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32008, 13406, NULL, 9946, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32009, 11156, NULL, 9946, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32010, 12281, NULL, 9946, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32011, 12290, NULL, 9946, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32012, 13251, NULL, 9947, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32013, 8348, NULL, 9947, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32014, 13407, NULL, 9947, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32015, 13254, NULL, 9948, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32016, 13408, NULL, 9948, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31869, 13327, NULL, 9904, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31868, 770, NULL, 9904, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31870, 1001, 454, 9904, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32003, 3010, NULL, 9944, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32004, 10465, NULL, 9944, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32001, 10463, NULL, 9944, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31867, 13326, NULL, 9904, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31934, 13365, NULL, 9922, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31872, 13329, NULL, 9905, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31874, 13331, NULL, 9906, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31873, 13330, NULL, 9906, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31875, 4267, 438, 9906, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31879, 823, NULL, 9908, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31881, 3199, NULL, 9908, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31880, 858, NULL, 9908, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31878, 13333, NULL, 9908, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31896, 13339, NULL, 9913, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31897, 3165, NULL, 9913, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31898, 971, NULL, 9913, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31905, 1550, NULL, 9915, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31911, 13347, NULL, 9917, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32017, 12800, NULL, 9948, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32018, 9334, NULL, 9948, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32019, 13247, NULL, 9949, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32020, 13409, NULL, 9949, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32021, 11223, NULL, 9949, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32022, 13253, NULL, 9950, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32023, 13410, NULL, 9950, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32024, 13411, NULL, 9950, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32025, 13412, NULL, 9950, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32002, 10464, NULL, 9944, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31636, 13190, NULL, 9832, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31637, 12755, NULL, 9832, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30029, 12720, NULL, 9388, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30048, 12717, NULL, 9394, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30066, 12693, NULL, 9398, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1364, 1060, NULL, 426, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26121, 5832, NULL, 8063, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26120, 3219, NULL, 8063, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26123, 153, NULL, 8063, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26122, 6954, NULL, 8063, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6270, 1208, NULL, 2659, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6269, 2631, NULL, 2659, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15031, 1352, NULL, 2659, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32034, 13419, NULL, 9952, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32035, 10117, NULL, 9952, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32036, 10101, NULL, 9952, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32037, 13420, NULL, 9953, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32038, 2223, NULL, 9953, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32039, 2188, NULL, 9953, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32040, 4902, NULL, 9953, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32041, 13421, NULL, 9953, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32042, 13422, NULL, 9954, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32043, 13423, NULL, 9954, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32044, 13424, NULL, 9954, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32045, 13425, NULL, 9954, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32046, 10084, NULL, 9955, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32047, 13426, NULL, 9955, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32048, 10085, 459, 9955, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32049, 13427, NULL, 9955, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32050, 10081, NULL, 9956, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32051, 13428, NULL, 9956, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32052, 13429, NULL, 9956, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32053, 13430, NULL, 9956, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32054, 13431, NULL, 9957, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32055, 13432, NULL, 9957, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32056, 13433, NULL, 9957, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32057, 13434, NULL, 9957, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32062, 13438, NULL, 9959, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32063, 13439, NULL, 9959, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31990, 9701, NULL, 9940, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7834, 5655, NULL, 3242, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31958, 7558, NULL, 9929, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31957, 2932, NULL, 9929, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31959, 13369, NULL, 9929, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32064, 13440, NULL, 9959, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32065, 13441, NULL, 9959, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32066, 13442, NULL, 9960, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32067, 10086, 460, 9960, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32068, 10087, NULL, 9960, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32069, 13443, NULL, 9960, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32058, 10102, NULL, 9958, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31888, 13336, NULL, 9910, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31887, 13335, NULL, 9910, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31886, 13334, NULL, 9910, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31889, 2614, NULL, 9910, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32070, 13444, NULL, 9961, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32071, 10104, NULL, 9961, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32072, 13445, NULL, 9961, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32073, 13446, NULL, 9961, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32074, 13447, NULL, 9962, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32075, 10100, NULL, 9962, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32076, 13448, NULL, 9962, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32077, 13449, NULL, 9962, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32078, 10113, NULL, 9962, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32084, 3563, NULL, 9964, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32083, 13452, NULL, 9964, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32085, 10116, NULL, 9964, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32086, 10120, NULL, 9964, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32087, 13453, NULL, 9965, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32088, 10114, NULL, 9965, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32089, 10115, NULL, 9965, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32090, 10092, NULL, 9965, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16954, 8747, NULL, 5448, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1857, 6818, NULL, 676, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28885, 6818, NULL, 8958, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5781, 6818, NULL, 2976, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11935, 6818, NULL, 4248, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25402, 6818, NULL, 7851, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20997, 2370, NULL, 6579, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20995, 7643, NULL, 6579, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20996, 9860, NULL, 6579, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20604, 6789, NULL, 6457, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (10872, 3503, NULL, 4060, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10873, 1708, NULL, 4060, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7981, 601, NULL, 3271, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32091, 1095, NULL, 9870, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32092, 2967, NULL, 9870, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32093, 13465, NULL, 9870, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32094, 4722, NULL, 9871, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32095, 10339, NULL, 9871, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32096, 4576, NULL, 9871, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32097, 13467, NULL, 9871, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32098, 3642, NULL, 9872, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32099, 5014, NULL, 9872, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32100, 578, NULL, 9873, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32101, 2118, NULL, 9873, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32102, 7560, NULL, 9873, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32103, 520, NULL, 9874, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32104, 2336, NULL, 9874, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32105, 2576, NULL, 9874, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15522, 940, NULL, 5105, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15521, 7283, NULL, 5105, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15523, 7803, NULL, 5105, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22367, 2780, NULL, 6952, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32106, 534, NULL, 9967, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32107, 3017, 464, 9967, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32108, 13468, NULL, 9967, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32109, 13469, NULL, 9967, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32110, 11168, NULL, 9968, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32111, 13470, NULL, 9968, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32112, 9696, NULL, 9968, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32113, 9910, NULL, 9968, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32116, 1741, NULL, 9970, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32117, 347, NULL, 9970, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32118, 369, NULL, 9970, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32119, 247, NULL, 9971, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32120, 425, NULL, 9971, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32121, 2737, NULL, 9971, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32122, 121, NULL, 9972, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32123, 5773, NULL, 9972, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32124, 13472, NULL, 9972, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32125, 9253, NULL, 9972, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32126, 61, NULL, 9973, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32127, 11930, NULL, 9973, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32128, 8514, NULL, 9973, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32129, 5837, NULL, 9973, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27042, 305, NULL, 8339, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27041, 1117, NULL, 8339, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27040, 1283, NULL, 8339, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27043, 1659, NULL, 8339, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32131, 13474, NULL, 9974, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32132, 13475, NULL, 9974, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32130, 1345, 53, 9974, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32133, 5490, NULL, 9974, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29913, 12570, NULL, 9361, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32136, 206, NULL, 9976, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32137, 9682, NULL, 9976, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32138, 9899, NULL, 9976, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32139, 2930, NULL, 9976, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31997, 13403, NULL, 9942, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31995, 13401, NULL, 9942, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32142, 13476, NULL, 9977, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32141, 7678, NULL, 9977, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21182, 10247, NULL, 6643, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21184, 10249, NULL, 6643, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21185, 4530, NULL, 6643, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21183, 10248, NULL, 6643, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31996, 13402, NULL, 9942, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31994, 13400, NULL, 9942, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32841, 2442, NULL, 10171, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32840, 5646, NULL, 10171, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32806, 3749, NULL, 10161, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32143, 13477, NULL, 9977, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32140, 1801, NULL, 9977, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32144, 31, NULL, 9978, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32145, 3077, NULL, 9978, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32146, 13478, NULL, 9978, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32147, 10648, NULL, 9978, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32148, 825, NULL, 9979, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32149, 13479, NULL, 9979, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32150, 9814, NULL, 9979, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32151, 2116, NULL, 9979, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32156, 1126, NULL, 9981, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32157, 13481, NULL, 9981, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32222, 13531, NULL, 9999, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3090, 889, NULL, 953, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32161, 13483, NULL, 9983, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32163, 4782, NULL, 9983, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32164, 2691, NULL, 9983, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32162, 13484, NULL, 9983, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32168, 13488, NULL, 9985, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32169, 13489, NULL, 9985, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32171, 13490, NULL, 9985, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32170, 5409, NULL, 9985, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32173, 2258, NULL, 9986, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32172, 4842, NULL, 9986, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32175, 2009, NULL, 9986, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32174, 8348, NULL, 9986, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32179, 13494, NULL, 9987, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32177, 13492, NULL, 9987, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32176, 13491, NULL, 9987, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32178, 13493, NULL, 9987, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32181, 13496, NULL, 9988, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32180, 13495, NULL, 9988, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32183, 13197, NULL, 9988, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32182, 13497, NULL, 9988, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3076, 3228, NULL, 948, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17199, 5105, NULL, 5497, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17203, 2929, NULL, 5497, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32200, 13506, NULL, 9993, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32201, 13507, NULL, 9993, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32199, 10838, NULL, 9993, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32167, 13487, NULL, 9984, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32197, 5850, NULL, 9992, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32196, 13505, NULL, 9992, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32195, 13504, NULL, 9992, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32189, 1874, NULL, 9990, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32166, 13486, NULL, 9984, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32154, 5876, NULL, 9980, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32152, 3601, NULL, 9980, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32155, 3203, NULL, 9980, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32153, 13480, NULL, 9980, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32030, 3474, 457, 9951, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32028, 10075, NULL, 9951, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32029, 13418, NULL, 9951, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30056, 6917, NULL, 9396, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22548, 396, NULL, 6993, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22545, 9297, NULL, 6993, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22549, 2489, NULL, 6993, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22550, 10504, NULL, 6993, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (22546, 10502, NULL, 6993, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32184, 13498, NULL, 9989, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32185, 1566, NULL, 9989, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32186, 13499, NULL, 9989, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32159, 13482, NULL, 9982, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32160, 13020, NULL, 9982, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32158, 1511, NULL, 9982, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32165, 13485, NULL, 9984, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32202, 13508, NULL, 9994, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32203, 9518, 470, 9994, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32204, 12610, 471, 9994, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32205, 12611, NULL, 9994, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32206, 13509, NULL, 9995, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32208, 11118, NULL, 9995, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32209, 13510, NULL, 9995, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32207, 9613, NULL, 9995, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32212, 10253, NULL, 9996, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32210, 6257, NULL, 9996, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32211, 6384, NULL, 9996, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32213, 13511, NULL, 9996, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32214, 13512, NULL, 9997, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32215, 13513, NULL, 9997, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32114, 13098, NULL, 9969, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32115, 13471, NULL, 9969, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32252, 13537, NULL, 10008, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32254, 13538, NULL, 10008, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4138, 1566, NULL, 2635, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24849, 1648, 475, 7681, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1860, 2423, NULL, 677, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1859, 2773, NULL, 677, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1861, 1648, 476, 677, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18501, 497, NULL, 5827, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18502, 835, NULL, 5827, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19116, 9589, NULL, 2154, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19115, 2798, NULL, 2154, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19117, 1648, 477, 2154, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18549, 9393, NULL, 5833, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32216, 1603, NULL, 9998, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32217, 13530, NULL, 9998, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32218, 9531, NULL, 9998, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32219, 12367, 481, 9998, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32223, 216, NULL, 10000, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32224, 1683, NULL, 10000, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32220, 2083, NULL, 9999, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32221, 11296, NULL, 9999, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32225, 1101, NULL, 10001, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32227, 2738, NULL, 10001, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32226, 3765, NULL, 10001, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32228, 1775, 484, 10001, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32233, 2382, 487, 10001, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32234, 1364, NULL, 10003, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32235, 11392, NULL, 10003, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32236, 2312, NULL, 10003, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32230, 1919, NULL, 10002, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32229, 248, NULL, 10002, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32232, 3622, 485, 10002, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32231, 6372, NULL, 10002, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32241, 13534, NULL, 10005, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32242, 13535, NULL, 10005, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32266, 1059, NULL, 10011, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32267, 3912, 488, 10011, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32248, 13536, NULL, 10007, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32247, 11175, NULL, 10007, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32249, 2952, NULL, 10007, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32250, 13289, NULL, 10007, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32255, 271, NULL, 10009, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32256, 5825, NULL, 10009, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32257, 5654, NULL, 10009, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32258, 266, NULL, 10009, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32268, 914, NULL, 10011, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32269, 2899, NULL, 10011, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32270, 13539, NULL, 10011, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32271, 8224, NULL, 10011, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32272, 13540, NULL, 10011, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32273, 1687, NULL, 10012, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32274, 9327, NULL, 10012, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32275, 2347, NULL, 10012, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32276, 8340, NULL, 10012, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32277, 10650, NULL, 10013, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32278, 940, NULL, 10013, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32279, 13541, NULL, 10013, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32282, 4904, NULL, 10014, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32281, 10135, NULL, 10014, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32280, 5535, NULL, 10014, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32283, 10136, NULL, 10014, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8437, 5854, NULL, 3437, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23189, 186, NULL, 7170, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23191, 232, NULL, 7170, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32198, 9964, NULL, 9992, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32188, 13501, NULL, 9990, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32190, 7907, NULL, 9990, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32187, 13500, 492, 9990, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3064, 2345, NULL, 914, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32286, 2556, NULL, 947, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32285, 1117, NULL, 947, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32284, 1745, NULL, 947, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23190, 10765, NULL, 7170, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23192, 686, NULL, 7170, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23152, 5008, NULL, 7160, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23165, 1223, NULL, 7164, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23169, 1673, NULL, 7164, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23170, 10758, NULL, 7164, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (65, 312, NULL, 266, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (66, 2091, NULL, 266, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (64, 996, NULL, 266, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (63, 1511, NULL, 266, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25144, 7542, NULL, 7774, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25145, 389, 388, 7774, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25146, 996, NULL, 7774, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25143, 1511, NULL, 7774, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29052, 9456, NULL, 9022, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29055, 741, NULL, 9022, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29054, 10635, NULL, 9022, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29057, 2560, NULL, 9022, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (29056, 3145, NULL, 9022, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29058, 1745, NULL, 9022, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (20158, 9860, NULL, 6290, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32355, 13620, NULL, 10050, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32356, 9701, NULL, 10050, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32357, 9696, NULL, 10050, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32358, 9678, NULL, 10050, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32359, 9411, NULL, 10051, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32360, 6459, NULL, 10051, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32361, 2788, NULL, 10051, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32362, 6445, NULL, 10051, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32363, 6574, NULL, 10052, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32364, 9519, NULL, 10052, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32365, 9520, NULL, 10052, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32366, 5931, NULL, 10052, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32367, 13627, NULL, 10053, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32368, 13621, NULL, 10054, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32304, 2821, NULL, 10027, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32369, 288, NULL, 10054, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32370, 2369, NULL, 10054, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32371, 1294, NULL, 10054, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32372, 13622, NULL, 10055, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32373, 2952, NULL, 10055, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32374, 10864, NULL, 10055, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32375, 11098, NULL, 10055, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32376, 7716, NULL, 10056, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32377, 5666, NULL, 10056, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32316, 378, NULL, 10018, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32317, 4965, NULL, 10018, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32318, 13587, NULL, 10018, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32319, 13588, NULL, 10018, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13978, 239, NULL, 4699, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13976, 2140, NULL, 4699, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13977, 2448, NULL, 4699, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32307, 9169, NULL, 10015, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32313, 183, NULL, 10017, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32314, 13585, NULL, 10017, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32315, 13586, NULL, 10017, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32310, 13581, NULL, 10016, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32311, 13582, NULL, 10016, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32308, 7660, NULL, 10016, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32288, 9173, NULL, 10019, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32320, 13590, NULL, 10019, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32321, 13589, NULL, 10019, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32324, 3111, NULL, 10020, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32289, 867, NULL, 10020, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32322, 1008, NULL, 10020, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32323, 13591, NULL, 10020, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32290, 128, NULL, 10021, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32291, 520, NULL, 10022, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32293, 697, NULL, 10022, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32292, 2696, NULL, 10022, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32325, 13592, NULL, 10022, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32327, 13594, NULL, 10023, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32328, 13595, NULL, 10023, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32329, 13593, NULL, 10023, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32294, 1461, NULL, 10023, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32296, 19, NULL, 10024, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32295, 10993, NULL, 10024, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32298, 789, NULL, 10024, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32297, 835, NULL, 10024, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32300, 1421, NULL, 10025, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32299, 1665, NULL, 10025, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32330, 13596, NULL, 10025, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31876, 1665, NULL, 9906, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32301, 1020, NULL, 10026, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32306, 13583, NULL, 10015, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27519, 11824, NULL, 8516, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27520, 11825, NULL, 8516, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15401, 7122, NULL, 4628, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24958, 2178, NULL, 7716, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24957, 2874, NULL, 7716, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24959, 6762, NULL, 7716, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24956, 11144, NULL, 7716, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25011, 11144, NULL, 7734, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26461, 11428, NULL, 8179, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32378, 10551, NULL, 10056, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32379, 2981, NULL, 10056, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32332, 12080, NULL, 10043, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32331, 12057, NULL, 10043, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32333, 13602, NULL, 10043, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32334, 13603, NULL, 10043, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32335, 12662, NULL, 10029, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32336, 13606, NULL, 10029, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32337, 13607, NULL, 10029, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32338, 13608, NULL, 10029, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32339, 10177, NULL, 10030, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29079, 1789, NULL, 9027, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32251, 430, NULL, 10008, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32239, 9171, NULL, 10004, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23198, 10766, NULL, 7172, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32340, 13609, NULL, 10030, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32341, 13610, NULL, 10030, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32342, 13611, NULL, 10030, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (4334, 1482, NULL, 1608, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25810, 403, NULL, 7987, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25812, 11268, NULL, 7987, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25811, 11267, NULL, 7987, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25813, 8809, NULL, 7987, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28523, 12056, NULL, 8875, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28524, 12057, NULL, 8875, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28525, 12055, NULL, 8875, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28522, 12054, NULL, 8875, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28521, 12053, NULL, 8875, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28526, 12059, NULL, 8875, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32343, 13617, NULL, 10047, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32344, 539, 501, 10047, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32345, 2657, NULL, 10047, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32346, 12781, NULL, 10047, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32347, 13618, NULL, 10048, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32348, 2999, 502, 10048, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32349, 13626, NULL, 10048, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32350, 4187, NULL, 10048, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32351, 13619, NULL, 10049, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32352, 2544, NULL, 10049, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32353, 381, NULL, 10049, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32354, 812, NULL, 10049, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32380, 13628, NULL, 10057, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32381, 11227, NULL, 10057, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32382, 13629, NULL, 10057, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32383, 13414, NULL, 10058, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32384, 11368, NULL, 10058, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32385, 13630, NULL, 10058, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32386, 13631, NULL, 10058, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32391, 7028, NULL, 10060, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32392, 7537, 339, 10060, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32393, 9516, NULL, 10060, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32394, 7538, NULL, 10060, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13720, 7225, NULL, 4571, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13681, 3627, 503, 4571, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13719, 7224, NULL, 4571, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13722, 2672, NULL, 4571, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (13721, 1694, NULL, 4571, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32397, 650, NULL, 2405, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32398, 3637, NULL, 2411, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32399, 13634, NULL, 2411, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32400, 3428, NULL, 2411, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32401, 2706, NULL, 2407, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32402, 2883, NULL, 2407, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32403, 3360, NULL, 2407, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19836, 346, NULL, 6196, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19837, 5144, NULL, 6196, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19835, 789, NULL, 6196, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19834, 1118, NULL, 6196, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14947, 5914, NULL, 1460, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14944, 4221, NULL, 1460, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32395, 13633, NULL, 10061, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24634, 3781, NULL, 7614, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24633, 11055, NULL, 7614, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20987, 2252, NULL, 6577, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20990, 10208, NULL, 6577, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18224, 9327, NULL, 5757, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18223, 780, NULL, 5757, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18225, 2347, NULL, 5757, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18226, 8340, NULL, 5757, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32193, 13503, NULL, 9991, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32194, 10217, NULL, 9991, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32191, 13502, NULL, 9991, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32192, 12619, NULL, 9991, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32409, 1164, NULL, 10063, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32410, 4267, NULL, 10063, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32411, 8850, NULL, 10063, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32412, 5893, NULL, 10063, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32312, 13584, NULL, 10015, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32305, 1834, NULL, 10015, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32413, 13712, NULL, 10063, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32414, 766, NULL, 10063, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32415, 5278, NULL, 10063, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32416, 975, NULL, 10064, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32417, 5366, NULL, 10064, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32418, 13498, NULL, 10064, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32419, 13713, NULL, 10064, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32420, 13714, NULL, 10064, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32421, 7803, NULL, 10064, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32422, 13715, NULL, 10064, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32423, 13716, NULL, 10064, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (32427, 6970, NULL, 10066, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32428, 11292, NULL, 10066, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32429, 11838, NULL, 10066, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32430, 13717, NULL, 10066, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32435, 2336, NULL, 10068, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32436, 9844, NULL, 10068, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32437, 5159, NULL, 10068, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32438, 13721, NULL, 10068, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32439, 1331, NULL, 10069, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32440, 19, NULL, 10069, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32441, 13722, NULL, 10069, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32450, 13113, NULL, 10072, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32451, 10293, NULL, 10072, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32452, 13727, NULL, 10072, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32453, 13728, NULL, 10072, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32454, 13112, NULL, 10073, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32455, 13729, NULL, 10073, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32456, 943, NULL, 10073, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32457, 166, NULL, 10073, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32458, 1832, NULL, 10073, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32459, 2226, NULL, 10073, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32460, 2592, NULL, 10073, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32461, 13730, NULL, 10073, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (32462, 1544, NULL, 10074, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32463, 13731, NULL, 10074, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32464, 13732, NULL, 10074, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32465, 8019, NULL, 10074, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32466, 11272, NULL, 10075, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32467, 2894, NULL, 10075, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32468, 3010, NULL, 10075, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32469, 9530, NULL, 10075, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32470, 13111, NULL, 10076, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32471, 13733, NULL, 10076, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32472, 13734, NULL, 10076, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32473, 10864, NULL, 10076, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32474, 11260, NULL, 10077, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32475, 1927, NULL, 10077, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32476, 2554, NULL, 10077, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32477, 13735, NULL, 10077, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32478, 944, NULL, 10078, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32479, 13736, NULL, 10078, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32480, 1023, NULL, 10078, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32481, 4382, NULL, 10078, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32434, 11316, NULL, 10067, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32431, 12647, NULL, 10067, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32433, 13720, NULL, 10067, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32432, 13718, NULL, 10067, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32486, 5620, NULL, 10080, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32487, 11705, NULL, 10080, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32488, 13740, NULL, 10080, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32489, 2063, NULL, 10080, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32490, 13741, NULL, 10080, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32491, 5073, NULL, 10080, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32492, 1797, NULL, 10081, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32493, 13742, NULL, 10081, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32494, 13743, NULL, 10081, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32495, 13744, NULL, 10082, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32496, 13745, NULL, 10082, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32497, 2294, NULL, 10082, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32406, 8287, NULL, 10062, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32408, 11510, NULL, 10062, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32407, 3188, NULL, 10062, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32405, 5528, NULL, 10062, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12059, 3513, NULL, 2024, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9434, 369, NULL, 2024, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9433, 3390, NULL, 2024, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9432, 1748, NULL, 2024, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32498, 13746, NULL, 10082, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32499, 13747, NULL, 10083, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32500, 4088, NULL, 10083, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32501, 13748, NULL, 10083, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32502, 13749, NULL, 10083, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32505, 13750, NULL, 10084, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32503, 13189, NULL, 10084, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32506, 13751, NULL, 10084, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32504, 2524, NULL, 10084, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32507, 13752, NULL, 10085, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32508, 13753, NULL, 10085, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32509, 13754, NULL, 10085, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32510, 13755, NULL, 10085, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32576, 13784, NULL, 10104, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32575, 13783, NULL, 10104, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32574, 13782, NULL, 10104, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32541, 13772, NULL, 10094, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32511, 4045, NULL, 10086, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32512, 876, NULL, 10086, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32513, 5720, NULL, 10086, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32514, 2953, NULL, 10086, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32515, 13315, NULL, 10087, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32516, 13756, NULL, 10087, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32517, 13757, NULL, 10087, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32425, 150, NULL, 10065, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32426, 3132, 418, 10065, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32424, 2006, 509, 10065, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32444, 503, NULL, 10070, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32518, 2152, NULL, 10088, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32519, 13758, NULL, 10088, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32520, 13759, NULL, 10088, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32521, 13538, NULL, 10088, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32522, 10650, NULL, 10089, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32523, 13760, NULL, 10089, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32524, 13761, NULL, 10089, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32525, 4760, NULL, 10090, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32526, 5088, NULL, 10090, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32527, 13762, NULL, 10090, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32528, 2794, NULL, 10090, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32529, 9533, NULL, 10091, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32530, 13763, NULL, 10091, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32531, 5931, NULL, 10091, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32532, 13764, NULL, 10091, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32533, 13765, NULL, 10092, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32534, 13766, NULL, 10092, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32535, 13768, NULL, 10093, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32536, 2050, NULL, 10093, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32537, 13366, NULL, 10093, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32582, 11075, NULL, 10106, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32583, 10684, NULL, 10106, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32581, 5852, NULL, 10106, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32538, 5562, 514, 10094, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32539, 13771, NULL, 10094, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32540, 1653, NULL, 10094, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32542, 9694, NULL, 10095, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32543, 2534, NULL, 10095, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32544, 13773, NULL, 10095, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32550, 13776, NULL, 10097, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32549, 7806, NULL, 10097, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32553, 10732, NULL, 10098, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32552, 8523, NULL, 10098, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32551, 9696, NULL, 10098, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32557, 13778, NULL, 10099, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32555, 2523, NULL, 10099, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32558, 5955, NULL, 10099, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32556, 13697, NULL, 10099, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32559, 4953, NULL, 10100, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32561, 2947, NULL, 10100, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32560, 9483, NULL, 10100, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32562, 13779, NULL, 10100, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32564, 892, NULL, 10101, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32563, 2649, NULL, 10101, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32565, 2516, NULL, 10101, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32567, 5114, 515, 10102, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32569, 11004, NULL, 10102, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32568, 754, NULL, 10102, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32573, 9698, NULL, 10104, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32577, 8842, NULL, 10105, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32578, 10513, NULL, 10105, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32579, 13785, NULL, 10105, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32586, 3222, NULL, 10107, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32584, 9699, NULL, 10107, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32585, 5576, NULL, 10107, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32587, 13786, NULL, 10107, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32589, 3512, NULL, 10108, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32590, 6439, NULL, 10108, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32588, 9700, NULL, 10108, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32594, 13788, NULL, 10109, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32591, 9701, NULL, 10109, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32593, 13787, NULL, 10109, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32848, 13858, NULL, 10161, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32850, 13860, NULL, 10161, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32847, 13857, NULL, 10161, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32611, 914, NULL, 10113, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32612, 3067, NULL, 10113, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32609, 1219, NULL, 10113, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32610, 1406, NULL, 10113, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32613, 13176, NULL, 10114, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32639, 365, NULL, 10120, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32642, 9295, NULL, 10120, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32641, 12165, 520, 10120, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32485, 13739, NULL, 10079, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32483, 13738, NULL, 10079, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32482, 13737, NULL, 10079, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32484, 9070, 235, 10079, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32660, 78, NULL, 10125, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32662, 6207, NULL, 10125, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32663, 8794, NULL, 10125, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (758, 1980, NULL, 62, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (759, 2613, NULL, 62, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (760, 2770, NULL, 62, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31899, 13340, NULL, 9913, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31786, 1965, NULL, 9881, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31788, 7110, NULL, 9881, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31787, 2995, NULL, 9881, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32665, 1876, NULL, 10126, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32664, 4034, NULL, 10126, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32666, 471, NULL, 10126, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32667, 4741, NULL, 10126, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32677, 326, NULL, 10128, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32678, 7678, NULL, 10128, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32676, 3195, NULL, 10128, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32679, 5490, NULL, 10128, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32684, 3507, NULL, 10130, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32681, 13385, NULL, 10130, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32682, 10262, NULL, 10130, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32683, 1446, NULL, 10130, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32694, 10770, NULL, 10132, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32692, 333, NULL, 10132, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32693, 6520, NULL, 10132, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32698, 376, NULL, 10133, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32699, 3027, NULL, 10133, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32696, 3026, NULL, 10133, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32648, 9962, NULL, 10123, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32647, 6138, NULL, 10123, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32650, 12581, NULL, 10123, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32649, 2318, NULL, 10123, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32700, 6267, NULL, 10134, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32701, 11254, NULL, 10134, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32654, 809, NULL, 10124, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32652, 2850, NULL, 10124, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32653, 12248, NULL, 10124, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32651, 13387, NULL, 10124, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32697, 2434, NULL, 10133, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32695, 13389, NULL, 10133, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32756, 8037, NULL, 10146, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32661, 6208, NULL, 10125, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32755, 501, NULL, 10146, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32708, 13796, NULL, 10136, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32709, 11325, NULL, 10136, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32741, 3315, NULL, 10143, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32742, 2714, NULL, 10143, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32745, 13803, NULL, 10144, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32746, 1166, NULL, 10145, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32747, 71, NULL, 10145, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32748, 2560, NULL, 10145, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32715, 861, NULL, 10138, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32716, 975, NULL, 10138, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32717, 599, NULL, 10138, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32718, 3192, NULL, 10138, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32719, 1578, NULL, 10138, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32720, 2012, NULL, 10138, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32721, 3020, NULL, 10138, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32730, 13184, NULL, 10141, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32731, 7187, NULL, 10141, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32732, 13801, NULL, 10141, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32733, 13802, NULL, 10141, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32734, 13381, NULL, 10142, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32735, 201, NULL, 10142, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32736, 2369, NULL, 10142, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32737, 1067, NULL, 10142, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32738, 1379, NULL, 10142, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32739, 5151, NULL, 10142, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32740, 1099, NULL, 10142, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32710, 13797, NULL, 10136, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32707, 13390, NULL, 10136, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32743, 9005, NULL, 10143, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32744, 1238, NULL, 10143, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32749, 2451, NULL, 10145, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32595, 10523, NULL, 10110, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32750, 1400, NULL, 10145, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32751, 3111, NULL, 10145, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32752, 2120, NULL, 10145, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32728, 10503, NULL, 10140, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32729, 10523, NULL, 10140, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32727, 2414, NULL, 10140, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32726, 13383, NULL, 10140, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32656, 7557, NULL, 10122, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32659, 697, NULL, 10122, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32655, 13380, NULL, 10122, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32657, 12042, NULL, 10122, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32673, 1857, NULL, 10127, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32675, 122, NULL, 10127, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (32670, 186, NULL, 10127, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32671, 6910, NULL, 10127, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32672, 2255, NULL, 10127, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32674, 2256, NULL, 10127, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32669, 694, NULL, 10127, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32685, 457, NULL, 10131, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32706, 13795, NULL, 10131, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32691, 1374, NULL, 10131, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (32688, 2773, NULL, 10131, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32686, 1701, NULL, 10131, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32689, 2922, NULL, 10131, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32687, 1809, NULL, 10131, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32690, 2986, NULL, 10131, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32753, 523, NULL, 10146, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32680, 11841, NULL, 10129, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32754, 3789, NULL, 10146, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32714, 111, NULL, 10137, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32711, 13379, NULL, 10137, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32713, 5267, NULL, 10137, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32712, 2676, NULL, 10137, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32724, 13799, NULL, 10139, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32723, 13798, NULL, 10139, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32725, 13800, NULL, 10139, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32722, 1400, NULL, 10139, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32628, 6452, NULL, 10117, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32624, 13179, NULL, 10117, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32630, 9680, NULL, 10117, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (32598, 8811, NULL, 10111, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32599, 5666, NULL, 10111, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32600, 7128, NULL, 10111, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32601, 13175, NULL, 10112, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32604, 3521, NULL, 10112, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32605, 5036, NULL, 10112, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32603, 2300, NULL, 10112, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32607, 5039, 517, 10112, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32615, 1031, 173, 10114, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32614, 9337, NULL, 10114, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32619, 1989, NULL, 10115, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32616, 13177, NULL, 10115, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32617, 2729, NULL, 10115, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32618, 13178, NULL, 10115, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32627, 13789, NULL, 10117, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (32629, 13790, NULL, 10117, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32626, 2952, NULL, 10117, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32623, 2115, NULL, 10117, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32633, 8, NULL, 10118, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32631, 13180, NULL, 10118, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32634, 2753, NULL, 10118, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32632, 2766, NULL, 10118, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32636, 5223, NULL, 10119, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32668, 1059, NULL, 10127, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32757, 13377, NULL, 10147, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32758, 13804, NULL, 10147, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32759, 803, NULL, 10147, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32760, 376, NULL, 10147, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32763, 13391, NULL, 10149, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32764, 10438, NULL, 10149, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32765, 1352, NULL, 10149, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32766, 239, NULL, 10149, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32767, 51, NULL, 10150, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32768, 1031, NULL, 10150, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32769, 10311, NULL, 10150, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32770, 3247, NULL, 10150, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32775, 13384, NULL, 10152, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32776, 5265, NULL, 10152, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32777, 3190, NULL, 10152, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32778, 12789, NULL, 10152, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32779, 4412, NULL, 10153, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32780, 2531, NULL, 10153, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32781, 1542, NULL, 10153, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32782, 1707, NULL, 10153, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32783, 945, NULL, 10154, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32784, 2886, NULL, 10154, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32785, 750, NULL, 10154, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32786, 3436, NULL, 10154, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32787, 13392, NULL, 10155, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32788, 12774, NULL, 10155, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32789, 13247, NULL, 10155, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32790, 13807, NULL, 10156, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32791, 13386, NULL, 10157, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32792, 5006, NULL, 10157, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32793, 3131, NULL, 10157, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32794, 133, NULL, 10157, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32795, 13382, NULL, 10158, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32796, 9530, NULL, 10158, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32797, 9515, NULL, 10158, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32798, 8498, NULL, 10158, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32761, 13805, NULL, 10148, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32762, 13806, NULL, 10148, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32774, 7212, NULL, 10151, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32772, 1067, NULL, 10151, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32771, 13378, NULL, 10151, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32773, 2780, NULL, 10151, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6657, 1880, NULL, 3039, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6658, 209, NULL, 3039, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6656, 4042, NULL, 3039, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32799, 950, NULL, 3039, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32554, 13777, NULL, 10098, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32566, 9697, NULL, 10102, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32580, 12761, NULL, 10105, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32592, 8102, NULL, 10109, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32608, 771, NULL, 10112, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (32602, 1586, NULL, 10112, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32606, 11327, NULL, 10112, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32625, 1658, NULL, 10117, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32635, 4849, NULL, 10119, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32638, 5774, NULL, 10119, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32637, 3023, NULL, 10119, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32640, 3116, 519, 10120, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32645, 13791, NULL, 10121, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32646, 3537, NULL, 10121, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32644, 2123, NULL, 10121, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32643, 5560, NULL, 10121, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (432, 2129, NULL, 43, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (430, 601, NULL, 43, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (431, 2400, NULL, 43, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20479, 9993, NULL, 6374, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3836, 1628, NULL, 1371, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31236, 993, NULL, 9726, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31233, 1087, 355, 9726, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31232, 4361, 354, 9726, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31231, 1373, 353, 9726, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9958, 1515, NULL, 1416, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9960, 5429, NULL, 1416, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14634, 1544, NULL, 4893, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14637, 4656, NULL, 4893, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14635, 5118, NULL, 4893, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33072, 8425, NULL, 10223, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33071, 4782, NULL, 10223, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33070, 1436, NULL, 10223, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32302, 1621, NULL, 10027, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32303, 2903, NULL, 10027, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18822, 2024, NULL, 5943, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18823, 1015, NULL, 5943, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18821, 4297, NULL, 5943, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18824, 5407, NULL, 5943, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2381, 1022, NULL, 809, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2382, 2802, NULL, 809, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1986, 2510, NULL, 712, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1985, 1714, NULL, 712, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8990, 1926, NULL, 3591, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8991, 357, NULL, 3591, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8988, 435, NULL, 3591, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8989, 924, NULL, 3591, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (579, 2922, NULL, 45, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16162, 155, NULL, 1253, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3417, 2152, NULL, 1253, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (385, 2773, NULL, 226, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (382, 2922, NULL, 226, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (384, 2945, NULL, 226, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (386, 2986, NULL, 226, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (12133, 6786, NULL, 4219, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12134, 1395, NULL, 4219, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14801, 1066, NULL, 4907, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (14802, 1374, NULL, 4907, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (14804, 1701, NULL, 4907, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (14797, 6001, NULL, 4907, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (329, 951, NULL, 6, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33097, 12661, NULL, 10232, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32596, 540, NULL, 10110, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32597, 1823, NULL, 10110, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33114, 13991, NULL, 10236, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33112, 13990, NULL, 10236, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33139, 9026, NULL, 10243, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2511, 2997, NULL, 843, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2510, 533, NULL, 843, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2508, 2012, NULL, 843, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2509, 1578, NULL, 843, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29723, 1778, NULL, 9286, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1219, 438, NULL, 383, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1218, 383, NULL, 383, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1220, 13589, NULL, 383, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9623, 6194, NULL, 3714, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9622, 6193, NULL, 3714, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9624, 6195, NULL, 3714, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27363, 848, 268, 8441, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27366, 11796, NULL, 8441, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27364, 2834, 269, 8441, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13170, 943, NULL, 2444, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13171, 2808, NULL, 2444, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4012, 1424, NULL, 1379, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18180, 5916, NULL, 5747, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18214, 9323, NULL, 5754, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32622, 2566, NULL, 10116, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33150, 90, NULL, 10265, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33148, 9680, NULL, 10265, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33147, 1282, NULL, 10265, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33151, 179, NULL, 10266, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33152, 14017, NULL, 10266, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33153, 10533, NULL, 10266, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33154, 534, NULL, 10267, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33156, 3672, NULL, 10267, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33155, 996, NULL, 10267, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33180, 14026, NULL, 10275, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33181, 14027, NULL, 10275, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33182, 7247, NULL, 10275, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15840, 141, NULL, 5172, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15838, 2305, NULL, 5172, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15841, 2531, NULL, 5172, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15839, 2660, NULL, 5172, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20161, 8011, NULL, 6291, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20163, 9861, NULL, 6291, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (20159, 6462, NULL, 6291, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20160, 9294, NULL, 6291, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29565, 13, NULL, 9233, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29567, 544, NULL, 9233, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29566, 1541, NULL, 9233, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29564, 3600, NULL, 9233, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30921, 405, NULL, 9654, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30919, 3600, NULL, 9654, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30920, 5512, NULL, 9654, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31771, 2163, NULL, 9876, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31770, 2211, NULL, 9876, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31769, 3600, NULL, 9876, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30126, 2205, NULL, 9418, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30125, 3850, NULL, 9418, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30124, 3600, NULL, 9418, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30211, 12700, NULL, 9442, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (641, 2847, NULL, 307, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (643, 2905, NULL, 307, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27855, 5516, NULL, 8651, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27856, 713, NULL, 8651, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27857, 2918, NULL, 8651, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17129, 897, NULL, 5481, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17130, 8766, NULL, 5481, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17131, 8767, NULL, 5481, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17132, 8768, NULL, 5481, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33188, 13593, NULL, 7004, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22610, 10540, NULL, 7008, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22611, 10541, NULL, 7008, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22609, 10539, NULL, 7008, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33189, 14044, NULL, 7008, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33082, 13950, NULL, 10226, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33081, 4778, NULL, 10226, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33084, 10148, NULL, 10226, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33083, 13951, NULL, 10226, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33080, 10126, NULL, 10226, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33190, 3035, NULL, 10026, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33191, 14053, NULL, 10026, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33192, 14054, NULL, 10026, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32309, 13580, NULL, 10016, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33193, 14055, NULL, 10028, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33194, 2423, NULL, 10278, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33195, 9617, NULL, 10278, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33196, 2216, NULL, 10278, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33197, 2346, NULL, 10278, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33198, 14056, NULL, 10278, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33203, 8208, NULL, 10280, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33204, 12094, 553, 10280, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33205, 12763, NULL, 10280, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33206, 11179, NULL, 10281, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33207, 2670, NULL, 10281, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33208, 6467, NULL, 10281, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33209, 7029, NULL, 10281, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33210, 14058, NULL, 10281, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33211, 4034, NULL, 10282, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33212, 7247, NULL, 10282, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33213, 13716, NULL, 10282, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33214, 13714, NULL, 10282, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33215, 14059, NULL, 10283, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33216, 14060, NULL, 10283, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33217, 1265, NULL, 10284, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33218, 5014, NULL, 10284, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33219, 2040, NULL, 10284, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33220, 421, NULL, 10285, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33221, 2419, NULL, 10285, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33222, 2451, NULL, 10285, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33223, 1295, NULL, 10285, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33224, 12749, NULL, 10285, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33225, 7503, NULL, 10285, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (33226, 109, NULL, 10285, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (33232, 14063, NULL, 10288, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33233, 8169, NULL, 10288, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33234, 11275, NULL, 10288, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33235, 14064, NULL, 10288, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33236, 14065, NULL, 10288, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33237, 14066, NULL, 10289, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33238, 11205, NULL, 10289, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33239, 4243, NULL, 10289, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33240, 14067, NULL, 10289, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33241, 14068, NULL, 10290, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33242, 14069, NULL, 10290, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33243, 14070, NULL, 10290, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33244, 4688, NULL, 10290, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33245, 14071, NULL, 10290, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33246, 12150, NULL, 10291, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33247, 4387, NULL, 10291, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33248, 2447, NULL, 10291, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33249, 10568, NULL, 10291, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33250, 12646, NULL, 10291, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33230, 14062, NULL, 10287, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33228, 494, NULL, 10287, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33231, 6570, NULL, 10287, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33229, 9533, NULL, 10287, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24076, 230, NULL, 7424, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24077, 2559, NULL, 7424, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33255, 1257, NULL, 7424, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16605, 7975, NULL, 5379, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16606, 8295, NULL, 5379, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16608, 8297, NULL, 5379, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16607, 8296, NULL, 5379, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1268, 1819, NULL, 396, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16829, 8359, NULL, 5421, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16827, 5979, NULL, 5421, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16828, 2060, NULL, 5421, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16826, 1553, NULL, 5421, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15873, 1112, NULL, 5181, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15874, 1535, NULL, 5181, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29794, 3600, NULL, 9302, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33202, 7131, NULL, 10279, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33201, 14057, NULL, 10279, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33199, 12595, NULL, 10279, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33200, 2996, NULL, 10279, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32943, 12316, NULL, 9796, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32940, 695, NULL, 9796, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32939, 749, NULL, 9796, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32941, 1544, NULL, 9796, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33227, 2661, NULL, 10286, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15875, 2943, NULL, 5181, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1300, 1896, NULL, 405, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18116, 2165, NULL, 5743, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18115, 9285, NULL, 5743, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18117, 2626, NULL, 5743, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18118, 2985, NULL, 5743, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8775, 5957, NULL, 3504, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8776, 5958, NULL, 3504, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8777, 4991, NULL, 3504, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8778, 5959, NULL, 3504, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21712, 10355, NULL, 6793, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21713, 10356, NULL, 6793, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21711, 613, NULL, 6793, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21715, 972, NULL, 6793, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21709, 1587, NULL, 6793, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21710, 2938, NULL, 6793, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21714, 1944, NULL, 6793, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17558, 7241, NULL, 5587, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17557, 1875, NULL, 5587, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17552, 152, NULL, 5587, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17556, 3601, NULL, 5587, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17554, 7348, NULL, 5587, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17559, 2347, NULL, 5587, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (17553, 2546, NULL, 5587, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33260, 14102, NULL, 10294, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33261, 14103, NULL, 10294, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33262, 14104, NULL, 10294, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33263, 11671, NULL, 10294, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33258, 12344, NULL, 10293, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33257, 6306, NULL, 10293, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33256, 11672, NULL, 10293, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33259, 14101, NULL, 10293, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33264, 12990, NULL, 10295, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33265, 2379, NULL, 10295, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33266, 9531, NULL, 10295, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33253, 12757, NULL, 10292, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33254, 12767, NULL, 10292, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33166, 8521, NULL, 10270, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33167, 13538, NULL, 10270, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33168, 4778, NULL, 10270, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33171, 14021, NULL, 10272, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33169, 894, NULL, 10272, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33172, 1704, NULL, 10272, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33170, 14020, NULL, 10272, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33175, 14024, NULL, 10273, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33173, 14022, NULL, 10273, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33174, 14023, NULL, 10273, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33178, 384, NULL, 10274, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33177, 388, NULL, 10274, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33176, 939, NULL, 10274, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33158, 1154, NULL, 10268, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33160, 1195, NULL, 10268, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33159, 4828, NULL, 10268, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33161, 7612, NULL, 10268, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33267, 416, NULL, 10295, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33268, 14105, NULL, 10296, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33269, 14107, NULL, 10296, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33270, 14108, NULL, 10296, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33271, 5073, NULL, 10296, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33272, 14109, NULL, 10297, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33273, 14110, NULL, 10297, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33274, 14111, NULL, 10297, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33275, 11024, NULL, 10297, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33276, 14112, NULL, 10298, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33277, 14113, NULL, 10298, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33278, 14115, NULL, 10298, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33279, 910, NULL, 10298, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33280, 14116, NULL, 10299, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33281, 14117, NULL, 10299, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33286, 11674, NULL, 10301, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33287, 1122, NULL, 10301, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33288, 14122, NULL, 10301, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33289, 218, NULL, 10301, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33290, 14123, NULL, 10302, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33291, 14124, NULL, 10302, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33292, 14125, NULL, 10302, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33293, 11673, NULL, 10302, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33294, 14126, NULL, 10303, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20505, 4907, NULL, 6430, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20506, 10005, NULL, 6430, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20504, 10004, NULL, 6430, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21195, 9643, NULL, 6647, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22692, 10576, NULL, 7031, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30654, 4578, NULL, 9565, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16670, 360, NULL, 5394, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16671, 2757, NULL, 5394, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16672, 5573, NULL, 5394, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16673, 4384, NULL, 5394, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10406, 93, NULL, 3327, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2452, 2894, NULL, 826, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8622, 2832, NULL, 3483, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29674, 1821, NULL, 2594, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32829, 13851, NULL, 10168, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31913, 13348, NULL, 9917, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31917, 2554, NULL, 9917, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31916, 1439, NULL, 9917, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (28621, 2905, NULL, 8901, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31344, 3456, NULL, 6334, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31343, 377, NULL, 6334, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31348, 1945, NULL, 6334, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31350, 2297, 378, 6334, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (31347, 10357, NULL, 6334, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31349, 1146, NULL, 6334, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31345, 4872, NULL, 6334, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31346, 7022, NULL, 6334, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30583, 8525, NULL, 9527, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30581, 10579, NULL, 9527, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30580, 2582, NULL, 9527, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30582, 8499, NULL, 9527, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21784, 7094, NULL, 6809, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21783, 8608, NULL, 6809, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21781, 2113, NULL, 6809, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21782, 9515, NULL, 6809, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21780, 10357, NULL, 6809, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21779, 897, NULL, 6809, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21785, 7, NULL, 6809, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (28352, 9035, NULL, 8834, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28351, 9039, NULL, 8834, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28349, 11599, NULL, 8834, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26957, 8797, NULL, 8323, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26958, 1954, NULL, 8323, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26955, 11504, NULL, 8323, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26956, 652, NULL, 8323, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31130, 8797, NULL, 9706, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31131, 9039, NULL, 9706, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31128, 12957, NULL, 9706, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31129, 12971, NULL, 9706, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28255, 4496, NULL, 8803, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28253, 2986, NULL, 8803, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28256, 10917, NULL, 8803, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (132, 1701, NULL, 57, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (133, 2986, 563, 57, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (131, 1828, NULL, 57, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19979, 93, NULL, 6245, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19978, 2559, NULL, 6245, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19977, 2115, NULL, 6245, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6934, 5136, NULL, 1523, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6932, 4372, NULL, 1523, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6933, 2324, NULL, 1523, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2673, 2226, NULL, 870, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2672, 2238, NULL, 870, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2671, 3067, NULL, 870, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2670, 1762, NULL, 870, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20899, 3156, NULL, 6555, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20898, 1190, 165, 6555, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11151, 169, NULL, 1557, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11153, 1965, NULL, 1557, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11152, 652, NULL, 1557, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11154, 1781, NULL, 1557, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22834, 10645, NULL, 7069, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22835, 10646, NULL, 7069, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (22836, 6756, NULL, 7069, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (1535, 89, NULL, 585, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16496, 5577, NULL, 4605, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16494, 8256, NULL, 4605, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16495, 8225, NULL, 4605, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26017, 6049, NULL, 8042, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33297, 14155, NULL, 10307, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33296, 14154, NULL, 10306, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33295, 14153, NULL, 10305, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3728, 405, NULL, 1255, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3729, 2240, NULL, 1255, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3727, 1677, NULL, 1255, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3730, 1699, NULL, 1255, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7404, 4030, NULL, 1651, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7405, 4026, NULL, 1651, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7406, 1126, NULL, 1651, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21837, 24, NULL, 6818, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21839, 951, NULL, 6818, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21844, 4529, NULL, 6818, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (21843, 1118, NULL, 6818, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (21838, 2571, NULL, 6818, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21841, 8792, NULL, 6818, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (21842, 5560, NULL, 6818, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (21840, 2585, NULL, 6818, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14555, 2159, NULL, 2762, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14554, 1084, NULL, 2762, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14553, 1164, NULL, 2762, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14556, 3114, NULL, 2762, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24372, 749, NULL, 7534, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24373, 10989, NULL, 7534, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24374, 2945, NULL, 7534, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24375, 2945, NULL, 7534, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19798, 2507, NULL, 6177, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19796, 9759, NULL, 6177, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19797, 5005, NULL, 6177, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33283, 14119, NULL, 10300, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33284, 14120, NULL, 10300, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31212, 3724, NULL, 9723, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (2031, 1821, NULL, 726, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28772, 12215, NULL, 6230, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28774, 5018, NULL, 6230, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28773, 1624, NULL, 6230, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29111, 12296, NULL, 9056, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29109, 12294, NULL, 9056, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29112, 12297, NULL, 9056, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29110, 12295, NULL, 9056, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21186, 156, NULL, 6644, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21212, 790, NULL, 6650, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21214, 932, NULL, 6650, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21215, 6110, NULL, 6650, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15552, 7812, NULL, 5113, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15553, 4871, NULL, 5113, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14980, 2634, NULL, 4674, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14981, 2616, NULL, 4674, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14979, 2364, NULL, 4674, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14978, 7574, NULL, 4674, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13775, 4323, NULL, 4585, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13774, 5132, NULL, 4585, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13776, 285, NULL, 4585, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13773, 2103, NULL, 4585, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19426, 256, NULL, 6108, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19425, 730, NULL, 6108, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19424, 2757, NULL, 6108, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19423, 1340, NULL, 6108, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26074, 11339, NULL, 8052, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20492, 9999, NULL, 6427, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20494, 10000, NULL, 6427, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20495, 3130, NULL, 6427, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20493, 3129, NULL, 6427, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1024, 757, NULL, 132, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (350, 2752, NULL, 132, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (351, 2800, NULL, 132, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (352, 2985, NULL, 132, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (480, 1954, NULL, 254, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (477, 242, NULL, 254, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (479, 2589, NULL, 254, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (483, 2612, NULL, 254, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26033, 416, NULL, 8046, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26036, 2905, NULL, 8046, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22053, 180, NULL, 6869, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22055, 10373, NULL, 6869, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22054, 10372, NULL, 6869, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22056, 10374, NULL, 6869, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (482, 2627, NULL, 254, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (481, 2862, NULL, 254, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (478, 2918, NULL, 254, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26721, 9514, NULL, 8285, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26722, 7094, NULL, 8285, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26728, 382, NULL, 8285, 10);
INSERT INTO 'tunesrecordingsmap' VALUES (26719, 382, NULL, 8285, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26725, 1862, NULL, 8285, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26727, 2028, NULL, 8285, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (26723, 5308, NULL, 8285, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26724, 2554, NULL, 8285, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26726, 1472, NULL, 8285, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (33298, 3390, 227, 8285, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19907, 2318, NULL, 6209, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19905, 789, NULL, 6209, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19904, 1666, NULL, 6209, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19906, 3243, NULL, 6209, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (537, 1898, NULL, 230, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (536, 1943, NULL, 230, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (532, 2366, NULL, 230, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (538, 2381, NULL, 230, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (535, 2644, NULL, 230, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (533, 1295, NULL, 230, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17743, 423, NULL, 5640, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17744, 1744, NULL, 5640, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33299, 4578, NULL, 5640, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19349, 9661, NULL, 6090, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19351, 9662, NULL, 6090, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19350, 1661, NULL, 6090, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29795, 188, NULL, 9302, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29797, 12486, NULL, 9302, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29796, 3237, NULL, 9302, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29801, 12487, NULL, 9303, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29807, 6260, NULL, 9306, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29809, 12492, NULL, 9306, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29811, 12494, NULL, 9306, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29808, 12491, NULL, 9306, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29810, 12493, NULL, 9306, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29837, 12508, NULL, 9313, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29840, 9680, NULL, 9313, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29838, 4543, NULL, 9313, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29839, 8368, NULL, 9313, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29843, 8471, NULL, 9314, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29842, 7082, NULL, 9314, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29852, 2409, NULL, 9315, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (29851, 6657, NULL, 9315, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (29853, 5986, NULL, 9315, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (29856, 2846, NULL, 9317, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29864, 11463, NULL, 9318, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33300, 2129, NULL, 9443, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33301, 3700, NULL, 9443, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31585, 12723, NULL, 9820, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31587, 13149, NULL, 9820, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31586, 2491, NULL, 9820, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31588, 13150, NULL, 9820, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12563, 6914, NULL, 2171, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12561, 415, NULL, 2171, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12564, 6915, NULL, 2171, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12562, 547, NULL, 2171, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20309, 448, NULL, 6344, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20310, 955, NULL, 6344, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20312, 1128, NULL, 6344, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20311, 5949, NULL, 6344, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21060, 10226, NULL, 6597, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21061, 2769, NULL, 6597, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33302, 1882, NULL, 9788, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33303, 9913, NULL, 9788, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33304, 1672, NULL, 9788, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33305, 14163, NULL, 9788, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33306, 6439, NULL, 9788, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33307, 14164, NULL, 9788, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17147, 8779, NULL, 5486, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17148, 8780, NULL, 5486, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17145, 1230, NULL, 5486, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17146, 8778, NULL, 5486, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (600, 2460, NULL, 311, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (601, 1845, 568, 311, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28846, 2559, NULL, 8947, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28847, 1845, 568, 8947, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28848, 1624, NULL, 8947, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8187, 5802, NULL, 3362, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32834, 3512, 162, 10169, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32833, 13852, NULL, 10169, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32835, 1845, 568, 10169, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26097, 11353, NULL, 8058, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26096, 11352, NULL, 8058, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24198, 132, NULL, 7469, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24487, 171, NULL, 7568, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24484, 318, NULL, 7568, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24486, 3912, NULL, 7568, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24485, 2986, NULL, 7568, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22699, 3077, NULL, 7033, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22698, 2049, NULL, 7033, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23439, 2987, NULL, 7243, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23440, 2340, NULL, 7243, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23437, 2514, NULL, 7243, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23438, 10782, NULL, 7243, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23549, 32, NULL, 7275, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23552, 49, NULL, 7275, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23548, 2980, NULL, 7275, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23555, 10812, NULL, 7275, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (23554, 2423, NULL, 7275, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (23551, 226, NULL, 7275, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23547, 382, NULL, 7275, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23553, 497, NULL, 7275, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (23550, 4474, NULL, 7275, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25333, 445, NULL, 7821, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25733, 5016, NULL, 7971, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25732, 817, NULL, 7971, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25736, 2880, NULL, 7971, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (25734, 1693, NULL, 7971, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25735, 6048, NULL, 7971, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26265, 11400, NULL, 8101, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27431, 9064, NULL, 8466, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27429, 7568, NULL, 8466, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26363, 445, NULL, 8148, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26597, 226, NULL, 8237, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26600, 5770, NULL, 8237, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26599, 623, NULL, 8237, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26598, 11441, NULL, 8237, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27777, 11899, NULL, 8617, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28173, 2106, NULL, 8774, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28174, 4167, NULL, 8774, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28175, 1513, NULL, 8774, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28322, 47, NULL, 8825, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28323, 3830, NULL, 8825, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28324, 9686, NULL, 8825, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30034, 4907, NULL, 9390, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30036, 8448, NULL, 9390, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30035, 12721, NULL, 9390, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30033, 12713, NULL, 9390, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9287, 1091, NULL, 2286, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31551, 7023, NULL, 9783, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31553, 3224, NULL, 9783, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31552, 3074, NULL, 9783, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33318, 14168, NULL, 10311, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33319, 14169, NULL, 10311, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4895, 242, NULL, 1446, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4894, 390, NULL, 1446, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4896, 5090, NULL, 1446, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8790, 2935, NULL, 3551, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32080, 13451, NULL, 9963, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32079, 13450, NULL, 9963, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32081, 10082, 461, 9963, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32082, 10098, NULL, 9963, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33325, 14174, NULL, 10314, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33326, 5593, NULL, 10315, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33308, 1702, 567, 9787, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33314, 71, NULL, 9787, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (33313, 14165, NULL, 9787, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32449, 9678, NULL, 10071, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32446, 11269, NULL, 10071, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32447, 13725, NULL, 10071, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32448, 13726, NULL, 10071, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27730, 11880, NULL, 8599, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27729, 11879, NULL, 8599, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27727, 6626, NULL, 8599, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27728, 2734, NULL, 8599, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29806, 12490, NULL, 9305, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27941, 487, NULL, 8689, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27945, 686, NULL, 8689, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (27940, 2332, NULL, 8689, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27939, 1095, NULL, 8689, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27943, 1448, NULL, 8689, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (27946, 11915, NULL, 8689, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (27942, 6764, NULL, 8689, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28191, 424, NULL, 8779, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28193, 497, NULL, 8779, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28197, 685, NULL, 8779, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (28192, 1329, NULL, 8779, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28190, 1503, NULL, 8779, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28194, 2821, NULL, 8779, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (28196, 1629, NULL, 8779, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (33327, 13904, NULL, 10315, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33328, 8405, NULL, 10315, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33329, 14175, NULL, 10315, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33330, 14177, NULL, 10327, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33331, 14176, NULL, 10327, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33332, 5934, NULL, 10327, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33333, 2317, NULL, 10327, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33322, 13811, NULL, 10313, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33324, 14172, NULL, 10313, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33323, 14173, NULL, 10313, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33321, 14171, NULL, 10312, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33320, 1235, NULL, 10312, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33334, 14178, NULL, 10312, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33342, 14182, NULL, 10317, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33343, 14183, NULL, 10317, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33344, 6205, NULL, 10319, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33345, 6339, NULL, 10319, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33346, 14184, NULL, 10319, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33347, 14185, NULL, 10320, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33348, 14186, NULL, 10321, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33349, 10732, NULL, 10321, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33350, 10016, NULL, 10321, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33351, 14187, NULL, 10321, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33352, 14188, NULL, 10321, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33353, 14189, NULL, 10328, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33354, 14190, NULL, 10328, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33359, 14193, NULL, 10324, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33360, 14194, NULL, 10324, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33361, 14195, NULL, 10324, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33362, 14196, NULL, 10324, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33363, 5268, NULL, 10324, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33364, 13312, NULL, 10325, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33365, 14197, NULL, 10325, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33366, 10747, NULL, 10325, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33367, 14198, NULL, 10326, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33368, 14199, NULL, 10326, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33369, 14200, NULL, 10326, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33370, 14201, NULL, 10322, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33371, 14202, NULL, 10322, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33375, 14204, NULL, 10323, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33357, 5598, NULL, 10323, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33355, 14036, NULL, 10323, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33356, 14191, NULL, 10323, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33373, 14203, NULL, 10316, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33374, 4392, NULL, 10316, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33372, 9334, NULL, 10316, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33376, 10245, NULL, 10316, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23895, 19, NULL, 7366, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (23890, 357, 581, 7366, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23894, 10902, NULL, 7366, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (23891, 10901, NULL, 7366, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23892, 5235, NULL, 7366, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23893, 1977, NULL, 7366, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24949, 357, 581, 7713, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24948, 2295, NULL, 7713, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24946, 2889, NULL, 7713, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24947, 4489, NULL, 7713, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25004, 357, 581, 7731, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25003, 2295, NULL, 7731, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25001, 2889, NULL, 7731, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25002, 4489, NULL, 7731, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18000, 9027, NULL, 5714, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17999, 2636, NULL, 5714, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28689, 12159, NULL, 8917, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28690, 1896, NULL, 8917, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28691, 996, NULL, 8917, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28692, 2699, NULL, 8917, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28629, 12112, NULL, 8904, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17331, 7263, NULL, 5521, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17330, 5464, 582, 5521, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17329, 8839, NULL, 5521, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28647, 5851, NULL, 8907, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28651, 3064, NULL, 8907, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (28650, 1581, NULL, 8907, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28646, 12126, NULL, 8907, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32404, 1638, NULL, 10062, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28614, 12098, NULL, 8900, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28616, 4384, NULL, 8900, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28615, 12099, NULL, 8900, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32389, 2294, NULL, 10059, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32388, 2524, NULL, 10059, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32387, 13623, NULL, 10059, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32390, 2987, 194, 10059, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22485, 2190, NULL, 6978, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22484, 10471, NULL, 6978, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22481, 10469, NULL, 6978, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22482, 10469, NULL, 6978, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22488, 10474, NULL, 6978, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (22483, 9522, NULL, 6978, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22486, 10472, NULL, 6978, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22487, 10473, NULL, 6978, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31989, 9696, NULL, 9940, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31988, 13256, 586, 9940, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28782, 861, NULL, 6233, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28783, 561, NULL, 6233, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28781, 967, NULL, 6233, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28784, 7721, NULL, 6233, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28636, 7720, NULL, 8905, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28640, 12123, NULL, 8905, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (30160, 12704, NULL, 9429, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17781, 8396, NULL, 5655, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17782, 9140, NULL, 5655, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17783, 9141, NULL, 5655, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9157, 6066, NULL, 2515, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9154, 2062, NULL, 2515, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9153, 5464, 582, 2515, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9152, 6064, NULL, 2515, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9151, 2661, NULL, 2515, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28633, 12116, NULL, 8905, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28638, 12121, NULL, 8905, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (28635, 12118, NULL, 8905, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28634, 7721, NULL, 8905, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28637, 12120, NULL, 8905, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28656, 11075, NULL, 8908, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (28655, 9738, NULL, 8908, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28657, 10348, NULL, 8908, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (4988, 1544, NULL, 1786, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33285, 14118, NULL, 10300, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33282, 14118, NULL, 10300, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30694, 3015, NULL, 9575, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23682, 5127, NULL, 7313, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23681, 7176, 134, 7313, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23680, 2752, NULL, 7313, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23679, 2800, 588, 7313, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27073, 1857, NULL, 8354, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27075, 3850, NULL, 8354, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27072, 694, NULL, 8354, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27074, 2800, 588, 8354, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25921, 11297, NULL, 8015, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18667, 164, NULL, 5875, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18647, 179, NULL, 5875, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18669, 9457, NULL, 5875, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18668, 9456, NULL, 5875, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18671, 9458, NULL, 5875, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18670, 1291, NULL, 5875, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18672, 5153, 591, 5875, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (30821, 152, NULL, 9620, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30822, 2730, NULL, 9620, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30824, 2576, NULL, 9620, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30823, 1421, NULL, 9620, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28688, 152, NULL, 8916, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28687, 10345, NULL, 8916, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28685, 12155, NULL, 8916, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28686, 3004, 412, 8916, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28729, 1426, 592, 8928, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28732, 9171, NULL, 8928, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28731, 3109, NULL, 8928, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28730, 12188, NULL, 8928, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4877, 1426, 592, 2822, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4876, 1852, NULL, 2822, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33089, 13955, NULL, 10228, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33088, 5190, 594, 10228, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31205, 535, NULL, 9723, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31208, 2256, NULL, 9723, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31210, 833, 350, 9723, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31207, 952, NULL, 9723, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31209, 3919, 215, 9723, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (31211, 5190, 594, 9723, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (31206, 2986, 563, 9723, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33377, 958, NULL, 2675, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33378, 4331, NULL, 2675, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33379, 14205, NULL, 2675, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22525, 7599, 596, 6988, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22526, 10493, NULL, 6988, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7231, 488, NULL, 1031, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7232, 649, NULL, 1031, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7230, 874, NULL, 1031, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33033, 921, NULL, 10214, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33032, 13922, NULL, 10214, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33031, 4339, NULL, 10214, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33021, 424, NULL, 10208, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33019, 4281, NULL, 10208, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33020, 1190, NULL, 10208, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33034, 1531, NULL, 10214, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1312, 835, NULL, 220, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (220, 1854, NULL, 206, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (222, 2013, NULL, 206, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (221, 2372, NULL, 206, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (219, 2562, NULL, 206, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6909, 299, NULL, 1410, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6908, 962, NULL, 1410, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6910, 5425, NULL, 1410, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6911, 5426, NULL, 1410, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22851, 10653, NULL, 7074, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18201, 7634, NULL, 5752, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18200, 9319, NULL, 5752, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18199, 1600, NULL, 5752, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9156, 6065, NULL, 2515, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9155, 1821, NULL, 2515, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (8734, 5936, NULL, 3492, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8736, 5938, NULL, 3492, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8737, 5939, NULL, 3492, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8735, 5937, NULL, 3492, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2580, 3029, NULL, 845, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2579, 1262, NULL, 845, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2581, 1581, NULL, 845, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2996, 673, NULL, 937, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3000, 2377, NULL, 937, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2999, 3195, NULL, 937, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2997, 2864, NULL, 937, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15538, 7286, NULL, 5109, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15539, 3695, NULL, 5109, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15540, 7806, NULL, 5109, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33380, 51, NULL, 7223, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33381, 4856, NULL, 6199, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33432, 62, NULL, 10345, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33431, 14242, NULL, 10345, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33433, 7347, NULL, 10345, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33414, 1732, NULL, 3307, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33415, 13827, NULL, 3307, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33398, 3192, NULL, 10334, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33400, 4911, NULL, 10334, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33454, 14234, NULL, 10336, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33424, 2921, NULL, 10342, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33457, 14238, NULL, 10343, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33427, 9610, NULL, 10343, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33443, 90, NULL, 10347, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33441, 6373, NULL, 10347, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33447, 9783, NULL, 10349, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33448, 6336, NULL, 10349, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33450, 987, NULL, 10349, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5320, 914, NULL, 2222, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5318, 1039, NULL, 2222, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5317, 1284, NULL, 2222, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5319, 2711, NULL, 2222, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33392, 2416, NULL, 10332, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33390, 2076, NULL, 10332, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33396, 14218, NULL, 10333, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26894, 6396, NULL, 8312, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26893, 778, NULL, 8312, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26895, 5931, NULL, 8312, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (33395, 2316, NULL, 10333, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33425, 4047, NULL, 10342, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33451, 14231, NULL, 10333, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33404, 14134, NULL, 10337, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33406, 1026, NULL, 10337, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33405, 14222, NULL, 10337, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33423, 3199, NULL, 10342, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33426, 9611, NULL, 10343, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33385, 14216, NULL, 10330, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33384, 14241, NULL, 10330, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33386, 14217, NULL, 10330, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33383, 503, NULL, 10329, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33382, 10561, NULL, 10329, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33411, 14215, NULL, 10329, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33413, 14230, NULL, 10329, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33412, 14229, NULL, 10329, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33388, 2123, NULL, 10331, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33387, 2559, NULL, 10331, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33389, 6714, NULL, 10331, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33397, 14219, NULL, 10334, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33399, 14220, NULL, 10334, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33453, 14233, NULL, 10335, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33452, 14232, NULL, 10335, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33401, 2776, NULL, 10335, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33403, 405, NULL, 10336, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33402, 816, NULL, 10336, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33410, 3752, NULL, 10338, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33408, 5004, NULL, 10338, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33409, 2468, NULL, 10338, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33407, 14223, NULL, 10338, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33417, 9936, NULL, 10339, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33421, 2138, NULL, 10341, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33422, 1971, NULL, 10341, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33456, 14237, NULL, 10341, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33455, 14236, NULL, 10342, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33440, 14227, NULL, 10347, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33437, 183, NULL, 10346, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33435, 3232, NULL, 10346, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33438, 536, NULL, 10346, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33436, 867, NULL, 10346, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33446, 2735, NULL, 10348, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33445, 116, NULL, 10348, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33459, 14228, NULL, 10348, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33444, 10248, NULL, 10348, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33449, 3003, NULL, 10349, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33428, 1181, NULL, 10344, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33430, 2957, NULL, 10344, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33429, 9043, NULL, 10344, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26891, 2518, NULL, 8312, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30493, 9936, NULL, 9501, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33558, 2634, NULL, 10367, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33559, 816, NULL, 10367, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33557, 13551, NULL, 10367, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33391, 10515, NULL, 10332, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33394, 5549, NULL, 10332, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33393, 5491, NULL, 10332, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33416, 760, NULL, 10339, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33460, 14235, NULL, 10339, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33439, 2556, NULL, 10346, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (33434, 2483, NULL, 10346, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33442, 2952, NULL, 10347, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (698, 1037, NULL, 182, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (699, 2620, NULL, 182, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33461, 388, NULL, 2085, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2691, 1230, NULL, 352, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2693, 1033, NULL, 352, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2692, 28, NULL, 352, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33462, 360, NULL, 10350, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33463, 3498, NULL, 10350, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33464, 320, NULL, 10350, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33465, 11563, NULL, 10350, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33467, 317, NULL, 10351, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33468, 2358, NULL, 10351, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33466, 1741, NULL, 10351, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33469, 2948, NULL, 10352, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33470, 7500, NULL, 10352, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33471, 288, NULL, 10352, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33472, 248, NULL, 10353, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33473, 2081, NULL, 10353, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33474, 7654, NULL, 10353, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33475, 2138, NULL, 10353, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33476, 1013, NULL, 10354, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33477, 996, NULL, 10354, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33478, 2165, NULL, 10354, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33486, 14081, NULL, 10357, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33487, 11937, NULL, 10357, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33488, 2773, NULL, 10357, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33489, 2386, NULL, 10357, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33490, 1585, NULL, 10358, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33491, 3012, NULL, 10358, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33492, 239, NULL, 10358, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33493, 14245, NULL, 10359, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33494, 2110, NULL, 10359, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33495, 2031, NULL, 10359, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33496, 11852, NULL, 10359, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33497, 1645, NULL, 10360, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33498, 9483, NULL, 10360, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33499, 14246, NULL, 10360, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33500, 14247, NULL, 10360, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33505, 13194, NULL, 10362, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33506, 932, NULL, 10362, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33507, 2021, NULL, 10362, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33508, 1460, NULL, 10362, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33509, 12042, NULL, 10362, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33510, 14249, NULL, 10363, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33511, 2061, NULL, 10363, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33512, 6026, NULL, 10363, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33513, 32, NULL, 10363, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33514, 14080, NULL, 10364, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33515, 141, NULL, 10364, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33516, 10262, NULL, 10364, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33517, 2452, NULL, 10364, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33518, 819, NULL, 10365, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33519, 1148, NULL, 10365, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33520, 423, NULL, 10365, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33521, 502, NULL, 10365, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33522, 1662, NULL, 10366, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33483, 1934, NULL, 10356, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33485, 14244, NULL, 10356, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33482, 8849, NULL, 10356, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33420, 14225, NULL, 10340, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33419, 14224, NULL, 10340, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33418, 7803, NULL, 10340, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33523, 2067, NULL, 10366, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33524, 2759, NULL, 10366, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33525, 2987, NULL, 10366, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33503, 183, NULL, 10361, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33502, 773, NULL, 10361, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33504, 1017, NULL, 10361, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33501, 1270, NULL, 10361, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33481, 333, NULL, 10355, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33480, 431, NULL, 10355, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33479, 698, NULL, 10355, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33526, 1590, NULL, 2668, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33527, 2943, NULL, 2668, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33528, 1664, NULL, 2668, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33529, 1965, NULL, 2668, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33530, 11714, NULL, 2667, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33531, 7449, NULL, 2667, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33532, 14251, NULL, 2669, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33533, 14250, NULL, 2669, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33538, 10934, NULL, 2671, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33539, 14253, NULL, 2672, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33540, 14254, NULL, 2673, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33541, 644, NULL, 2674, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33542, 11968, NULL, 2674, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33547, 3271, NULL, 2677, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33548, 2672, NULL, 2677, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33549, 7537, 339, 2677, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33573, 14262, NULL, 10367, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33578, 2054, NULL, 10372, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33576, 13547, NULL, 10372, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33545, 14258, NULL, 2676, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33543, 14256, NULL, 2676, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33546, 11423, 599, 2676, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33544, 14257, NULL, 2676, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33550, 14260, NULL, 2678, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33551, 14261, NULL, 2679, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33552, 1902, NULL, 2679, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33553, 825, NULL, 2680, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33554, 2258, 600, 2680, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33555, 6104, NULL, 2680, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33556, 5959, NULL, 2680, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33534, 9749, NULL, 2670, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33537, 14252, NULL, 2670, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33535, 471, 601, 2670, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33536, 2988, NULL, 2670, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16963, 8460, NULL, 5451, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16961, 8458, NULL, 5451, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16960, 422, NULL, 5451, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16962, 8459, NULL, 5451, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18003, 1543, NULL, 5715, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18004, 7777, NULL, 5715, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33458, 1294, 603, 10343, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27430, 9166, NULL, 8466, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27432, 9063, NULL, 8466, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33562, 13554, NULL, 10369, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33563, 13555, NULL, 10369, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33564, 4555, NULL, 10369, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33565, 518, NULL, 10369, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33580, 13559, NULL, 10373, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33581, 685, NULL, 10373, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33588, 193, NULL, 10374, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (33572, 13558, NULL, 10371, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33570, 13556, NULL, 10371, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33571, 13557, NULL, 10371, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33601, 13563, NULL, 10378, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33602, 5390, NULL, 10378, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33614, 14273, NULL, 10382, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33613, 1241, NULL, 10382, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33587, 9624, NULL, 10374, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33584, 14265, NULL, 10374, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33612, 6503, NULL, 10382, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33561, 336, NULL, 10368, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33560, 13552, NULL, 10368, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33575, 14264, NULL, 10368, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33579, 4965, NULL, 10372, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33577, 8316, NULL, 10372, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33591, 14268, NULL, 10375, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33590, 13549, NULL, 10375, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33592, 14267, NULL, 10375, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33593, 13560, NULL, 10376, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33596, 19, NULL, 10376, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33594, 347, NULL, 10376, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33597, 833, NULL, 10376, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33598, 891, NULL, 10376, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (33595, 1805, NULL, 10376, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33599, 13561, NULL, 10377, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33600, 14269, NULL, 10377, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33603, 4828, NULL, 10378, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33605, 14270, NULL, 10379, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33604, 13293, NULL, 10379, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33608, 1995, NULL, 10380, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33606, 13553, NULL, 10380, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33607, 2905, NULL, 10380, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33616, 100, NULL, 10383, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33615, 1027, NULL, 10383, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33617, 1448, NULL, 10383, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33610, 14271, NULL, 10381, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8422, 53, NULL, 3432, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (8421, 2226, NULL, 3432, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8420, 89, NULL, 3432, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8423, 4455, NULL, 3432, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21006, 1467, NULL, 6582, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21008, 1581, NULL, 6582, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2812, 62, NULL, 893, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (2809, 365, NULL, 893, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2806, 652, NULL, 893, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2808, 2336, NULL, 893, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2810, 1575, NULL, 893, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2811, 1222, NULL, 893, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (2807, 2943, NULL, 893, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29988, 12654, NULL, 9379, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29986, 12653, 440, 9379, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29985, 12652, NULL, 9379, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29987, 8502, NULL, 9379, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18687, 3286, NULL, 5912, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18686, 3285, NULL, 5912, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17049, 8441, NULL, 5465, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17050, 861, NULL, 5465, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17047, 2610, NULL, 5465, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17048, 1837, NULL, 5465, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25179, 1110, NULL, 7783, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25181, 1582, NULL, 7783, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25180, 3001, NULL, 7783, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33621, 9388, NULL, 10385, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33622, 834, NULL, 10385, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33623, 199, NULL, 10386, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33624, 267, NULL, 10386, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33625, 276, NULL, 10387, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33626, 9394, NULL, 10387, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33627, 9401, NULL, 10387, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33628, 9393, NULL, 10387, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33629, 1790, NULL, 10388, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33630, 6707, NULL, 10388, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33631, 6713, NULL, 10388, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33632, 7384, NULL, 10388, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33633, 7394, NULL, 10388, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33634, 265, NULL, 10389, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33635, 9386, NULL, 10389, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33636, 697, NULL, 10390, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33637, 3498, NULL, 10390, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33638, 1651, NULL, 10391, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33639, 2457, NULL, 10391, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33640, 2413, NULL, 10392, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33641, 2563, NULL, 10392, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33642, 2151, NULL, 10392, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33643, 3876, NULL, 10392, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33644, 3033, NULL, 10392, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33645, 164, NULL, 10393, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33646, 3528, NULL, 10393, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33647, 91, NULL, 10393, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33648, 3509, NULL, 10393, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33649, 1778, NULL, 10393, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (33650, 951, NULL, 10394, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33651, 5635, NULL, 10394, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33652, 1311, NULL, 10394, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33653, 1188, NULL, 10395, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33654, 4785, NULL, 10395, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33655, 1064, NULL, 10395, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33656, 1006, NULL, 10396, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33657, 14237, NULL, 10396, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33658, 2943, NULL, 10396, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33659, 3158, NULL, 10396, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33660, 1752, NULL, 10397, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33661, 405, NULL, 10397, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33662, 77, NULL, 10397, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33619, 709, NULL, 10384, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33620, 1046, NULL, 10384, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33096, 13984, NULL, 10232, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33099, 13985, NULL, 10232, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33098, 13933, NULL, 10232, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33076, 4323, NULL, 10225, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33079, 11515, NULL, 10225, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33077, 11159, NULL, 10225, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17123, 8764, NULL, 5480, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17122, 2732, NULL, 5480, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17128, 8765, NULL, 5480, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (17127, 8440, NULL, 5480, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18840, 247, NULL, 5947, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18836, 2410, NULL, 5947, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18837, 3894, NULL, 5947, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18839, 5278, NULL, 5947, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18838, 4833, NULL, 5947, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15269, 7677, NULL, 5031, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15268, 7676, NULL, 5031, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15267, 6783, NULL, 5031, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15266, 3860, NULL, 5031, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33664, 13460, NULL, 10399, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33667, 9243, NULL, 10401, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33671, 2846, NULL, 10405, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33672, 13459, NULL, 10405, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33669, 13170, NULL, 10404, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33670, 14278, NULL, 10404, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33668, 13171, NULL, 10403, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33666, 14277, NULL, 10400, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33665, 13173, NULL, 10400, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33663, 13461, NULL, 10398, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28273, 965, NULL, 8811, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28275, 11973, NULL, 8811, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33690, 8521, NULL, 10412, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33691, 9171, 604, 10412, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33689, 13939, NULL, 10412, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33693, 3495, NULL, 10413, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22686, 10573, NULL, 7030, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33694, 13940, NULL, 10413, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33692, 12624, NULL, 10413, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33695, 40, NULL, 10414, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33698, 11747, NULL, 10414, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33697, 14284, NULL, 10414, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33696, 12367, NULL, 10414, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33702, 2921, NULL, 10415, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33701, 3682, NULL, 10415, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33700, 3199, NULL, 10415, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33699, 1426, NULL, 10415, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33703, 13941, NULL, 10416, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17924, 9211, NULL, 5691, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17926, 9212, NULL, 5691, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17923, 9210, NULL, 5691, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17925, 5704, NULL, 5691, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33675, 206, NULL, 10406, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33674, 5552, NULL, 10406, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33673, 12622, NULL, 10406, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33677, 2816, NULL, 10407, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33676, 13934, NULL, 10407, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33678, 13935, NULL, 10408, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33679, 14282, NULL, 10408, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33680, 13936, NULL, 10409, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33681, 2857, NULL, 10409, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33684, 7600, NULL, 10410, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33682, 13937, NULL, 10410, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33683, 867, NULL, 10410, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33704, 2424, 606, 10410, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33688, 14283, NULL, 10411, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33687, 7678, NULL, 10411, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33686, 13475, NULL, 10411, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33685, 13938, NULL, 10411, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15749, 7910, NULL, 5144, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15750, 7911, NULL, 5144, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24383, 1553, NULL, 7538, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20713, 10101, NULL, 6502, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2861, 1629, NULL, 906, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2864, 2957, NULL, 906, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2863, 1956, NULL, 906, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30174, 12754, NULL, 9433, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32032, 10077, NULL, 9951, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (32027, 10076, NULL, 9951, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32031, 10121, 458, 9951, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32026, 10119, NULL, 9951, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32033, 10119, NULL, 9951, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (16630, 8310, NULL, 5385, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16629, 1067, NULL, 5385, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16631, 8174, NULL, 5385, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33709, 1662, NULL, 10432, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33710, 1977, NULL, 10432, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33711, 5198, NULL, 10432, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33712, 200, NULL, 10433, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33713, 1458, NULL, 10434, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33714, 7302, NULL, 10434, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33715, 2218, NULL, 10435, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33716, 685, NULL, 10435, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6128, 119, NULL, 3046, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6127, 1491, NULL, 3046, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18067, 2325, NULL, 5731, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18064, 589, NULL, 5731, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33582, 3156, NULL, 10373, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33609, 13546, NULL, 10381, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33611, 14272, NULL, 10381, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33618, 2136, NULL, 10383, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16019, 471, NULL, 5218, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16021, 1087, NULL, 5218, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16020, 8040, NULL, 5218, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3754, 1707, NULL, 1349, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12798, 6971, NULL, 4441, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12799, 6972, NULL, 4441, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12800, 1052, NULL, 4441, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12801, 2786, NULL, 4441, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14357, 4892, NULL, 2268, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17085, 2545, NULL, 2268, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2019, 305, NULL, 722, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2018, 951, NULL, 722, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2017, 1243, NULL, 722, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2020, 2654, NULL, 722, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33718, 6674, NULL, 10436, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33719, 750, NULL, 10436, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33717, 1665, NULL, 10436, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6510, 3014, NULL, 529, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6509, 2179, NULL, 529, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6511, 3093, NULL, 529, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6508, 5353, NULL, 529, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33720, 3545, NULL, 9333, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33721, 2152, 625, 5728, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14809, 722, NULL, 4909, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14812, 1958, NULL, 4909, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14811, 5073, NULL, 4909, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14810, 2886, NULL, 4909, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29066, 12283, NULL, 9024, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15573, 7835, NULL, 4936, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15571, 2799, NULL, 4936, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15574, 1392, NULL, 4936, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15572, 5153, NULL, 4936, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4948, 2988, NULL, 2192, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4947, 1834, NULL, 2192, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32570, 7317, NULL, 10103, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32571, 13780, NULL, 10103, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32572, 13781, NULL, 10103, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25239, 1238, 58, 7795, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14299, 1455, NULL, 4804, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18343, 5282, NULL, 5788, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18344, 2662, NULL, 5788, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18342, 1797, NULL, 5788, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4225, 3509, NULL, 1422, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4224, 3690, NULL, 1422, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4223, 3381, NULL, 1422, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11449, 1743, NULL, 4143, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11448, 403, NULL, 4143, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11447, 6625, NULL, 4143, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11446, 1683, NULL, 4143, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (971, 1700, NULL, 337, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22142, 10394, NULL, 6892, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22141, 10393, NULL, 6892, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22139, 6406, NULL, 6892, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22140, 1713, NULL, 6892, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5907, 123, NULL, 1536, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5904, 433, NULL, 1536, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5906, 4474, NULL, 1536, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5905, 660, NULL, 1536, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6417, 452, NULL, 2338, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6416, 3009, NULL, 2338, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6415, 792, NULL, 2338, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5707, 3258, NULL, 1542, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5706, 3964, NULL, 1542, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5705, 2596, NULL, 1542, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21219, 2806, NULL, 6651, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7564, 611, NULL, 2288, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7565, 787, NULL, 2288, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7567, 2757, NULL, 2288, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7566, 5566, NULL, 2288, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18065, 3672, NULL, 5731, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18066, 9271, NULL, 5731, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16358, 6048, NULL, 5331, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18020, 3249, NULL, 5720, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (266, 1651, NULL, 151, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7017, 1857, NULL, 2145, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33708, 14386, NULL, 10422, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33705, 14384, NULL, 10423, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33706, 14385, NULL, 10424, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33707, 13979, NULL, 10430, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5556, 13, NULL, 1809, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5558, 2386, NULL, 1809, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2304, 713, NULL, 464, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2303, 5786, NULL, 464, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24538, 2905, NULL, 7582, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18217, 8441, NULL, 5755, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18219, 9326, NULL, 5755, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18218, 9325, NULL, 5755, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24539, 10640, NULL, 7582, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32982, 13907, NULL, 10039, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (32980, 1364, NULL, 10039, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32977, 13605, NULL, 10039, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32983, 13908, NULL, 10039, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (24542, 3215, NULL, 7582, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7016, 669, NULL, 2145, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6770, 1778, NULL, 2400, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3742, 4815, NULL, 1346, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3739, 1766, NULL, 1346, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9401, 3061, NULL, 2455, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6301, 671, NULL, 2327, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6302, 5297, NULL, 2327, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9954, 1426, NULL, 1414, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18594, 1915, NULL, 5849, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18596, 5562, NULL, 5849, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18595, 2386, NULL, 5849, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18593, 952, NULL, 5849, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17219, 7656, NULL, 5501, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17222, 1208, NULL, 5501, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17220, 8805, NULL, 5501, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17221, 5666, NULL, 5501, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25139, 1842, NULL, 7773, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9060, 3361, NULL, 1614, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9061, 6033, NULL, 1614, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9062, 2587, NULL, 1614, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5985, 312, NULL, 1998, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5986, 3789, NULL, 1998, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5984, 558, NULL, 1998, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9059, 6032, NULL, 1613, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13126, 7059, NULL, 1914, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13125, 90, NULL, 1914, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13127, 2411, NULL, 1914, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13128, 2737, NULL, 1914, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11239, 544, NULL, 2048, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11240, 839, NULL, 2048, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11238, 1648, NULL, 2048, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7004, 5464, NULL, 2141, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7003, 3248, NULL, 2141, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1509, 2007, NULL, 578, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1508, 2226, NULL, 578, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1506, 734, NULL, 578, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1507, 2006, NULL, 578, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4177, 4933, NULL, 2645, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1440, 1823, NULL, 498, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6878, 503, NULL, 1855, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6875, 834, NULL, 1855, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6882, 5410, NULL, 1855, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (6879, 1347, NULL, 1855, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6880, 2498, NULL, 1855, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18089, 2506, NULL, 706, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18090, 2996, NULL, 706, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9382, 3527, NULL, 2463, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (9383, 2029, NULL, 2463, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9381, 1391, NULL, 2463, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1637, 2048, NULL, 614, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1636, 2123, NULL, 614, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1635, 1018, NULL, 614, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1634, 1080, NULL, 614, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8763, 1571, NULL, 3499, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9391, 1907, NULL, 2457, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5605, 1621, NULL, 1820, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18435, 2980, NULL, 5811, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33729, 14462, NULL, 10447, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8578, 5864, NULL, 3471, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8577, 120, NULL, 3471, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (8580, 5866, NULL, 3471, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (8579, 5865, NULL, 3471, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18437, 116, NULL, 5811, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18436, 4904, NULL, 5811, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1871, 2432, NULL, 680, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22674, 2848, NULL, 7026, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19197, 2144, NULL, 6052, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19195, 1078, NULL, 6052, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19196, 2103, NULL, 6052, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33723, 6471, NULL, 10446, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33724, 11945, NULL, 10446, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33727, 10762, NULL, 10446, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (33725, 14460, NULL, 10446, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33726, 12724, NULL, 10446, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33728, 2491, NULL, 10446, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (33722, 10197, NULL, 10446, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20947, 2644, NULL, 6566, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20944, 1504, NULL, 6566, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33734, 1544, NULL, 10448, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33733, 14468, NULL, 10262, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33732, 14467, 635, 10262, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33730, 1204, NULL, 10262, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33731, 1311, NULL, 10262, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33735, 5366, NULL, 10448, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33736, 4034, NULL, 10448, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33737, 2822, NULL, 10448, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33738, 14442, NULL, 10449, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33739, 3806, NULL, 10449, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33740, 2176, NULL, 10449, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33741, 425, NULL, 10450, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33742, 14469, NULL, 10450, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33743, 973, NULL, 10450, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33744, 14470, NULL, 10450, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33745, 6462, NULL, 10451, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33746, 10511, NULL, 10451, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33748, 2788, NULL, 10451, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33747, 7531, NULL, 10451, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25692, 5517, NULL, 7960, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25691, 2561, NULL, 7960, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25690, 11240, NULL, 7960, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25693, 11241, NULL, 7960, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7282, 3919, NULL, 3193, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7281, 3013, NULL, 3193, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7283, 5504, NULL, 3193, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7285, 2899, NULL, 3193, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11857, 2547, NULL, 3196, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26087, 11346, NULL, 8055, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26088, 11347, NULL, 8055, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (26085, 2369, NULL, 8055, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26084, 9611, NULL, 8055, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26086, 1294, NULL, 8055, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (16077, 8072, NULL, 5235, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13146, 1031, NULL, 1919, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13144, 1386, NULL, 1919, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22793, 5879, NULL, 7060, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33749, 14472, NULL, 10452, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33750, 2626, NULL, 10452, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33751, 4085, NULL, 10452, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33752, 2961, NULL, 10452, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33753, 955, NULL, 10452, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33754, 14473, NULL, 10453, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33755, 9934, NULL, 10453, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33756, 861, NULL, 10453, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33757, 14474, NULL, 10454, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33758, 2538, NULL, 10454, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33759, 4546, NULL, 10454, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33760, 3957, NULL, 10454, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33761, 14475, NULL, 10455, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33762, 1424, NULL, 10455, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33763, 2957, NULL, 10455, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33764, 4983, NULL, 10455, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33765, 14477, NULL, 10457, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33766, 1135, NULL, 10457, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33767, 14478, NULL, 10457, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33768, 150, NULL, 10457, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33769, 14479, NULL, 10458, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33770, 4778, NULL, 10458, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33771, 5312, NULL, 10458, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33772, 1945, NULL, 10458, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33773, 14480, NULL, 10459, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33774, 2197, NULL, 10459, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33775, 183, NULL, 10459, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33776, 9833, NULL, 10459, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33777, 14481, NULL, 10460, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33778, 940, NULL, 10460, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33779, 809, NULL, 10460, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13202, 3166, NULL, 2454, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13203, 7073, NULL, 2454, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33780, 14482, NULL, 10461, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33781, 1853, NULL, 10461, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33782, 9997, NULL, 10461, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33783, 6576, NULL, 10461, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33784, 14483, NULL, 10462, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33785, 6732, NULL, 10462, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33786, 2488, NULL, 10462, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33787, 1089, NULL, 10462, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33788, 14484, NULL, 10463, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33789, 14175, NULL, 10463, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33790, 14485, NULL, 10463, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30317, 12723, NULL, 9470, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30316, 9680, NULL, 9470, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30315, 8350, NULL, 9470, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30314, 12569, NULL, 9470, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3973, 2661, NULL, 1232, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21388, 10296, NULL, 6696, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21389, 10297, NULL, 6696, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21390, 10298, NULL, 6696, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21391, 10299, NULL, 6696, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20256, 9905, NULL, 6378, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17042, 8513, NULL, 3915, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33574, 14263, NULL, 10368, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33585, 14266, NULL, 10374, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33586, 948, NULL, 10374, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33589, 1527, NULL, 10374, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (33583, 13548, NULL, 10374, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6003, 2503, NULL, 2001, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33816, 68, NULL, 6304, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33815, 141, NULL, 6304, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33813, 465, NULL, 6304, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33814, 1291, NULL, 6304, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33820, 64, NULL, 6302, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33821, 2561, NULL, 6302, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33822, 867, NULL, 6302, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33823, 2559, NULL, 6302, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33824, 1672, NULL, 6301, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33825, 19, NULL, 6301, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33826, 2903, NULL, 6301, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33827, 13885, NULL, 6301, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33828, 1820, NULL, 6300, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33829, 2118, NULL, 6300, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33830, 2151, NULL, 6300, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33831, 923, NULL, 6299, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33832, 10664, NULL, 6299, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33833, 51, NULL, 6299, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33834, 12103, NULL, 6299, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33809, 755, NULL, 6305, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33810, 2492, NULL, 6305, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33811, 2751, NULL, 6305, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33812, 1541, NULL, 6305, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33856, 14499, NULL, 10468, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33857, 2699, NULL, 10468, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33858, 1406, NULL, 10468, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33802, 145, NULL, 6307, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33804, 1988, NULL, 6307, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33805, 2031, NULL, 6307, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33803, 2864, 640, 6307, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33800, 10438, NULL, 6308, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33799, 920, NULL, 6308, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33801, 2445, NULL, 6308, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33798, 2920, NULL, 6308, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33797, 78, NULL, 6309, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33796, 2658, NULL, 6309, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33795, 2597, NULL, 6309, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33794, 8265, NULL, 6309, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33791, 928, NULL, 6310, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33792, 1859, NULL, 6310, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33793, 1527, NULL, 6310, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33817, 341, NULL, 6303, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33818, 4983, NULL, 6303, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33819, 7578, NULL, 6303, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33835, 150, NULL, 6303, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33806, 1046, NULL, 6306, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33807, 1077, NULL, 6306, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33808, 1707, NULL, 6306, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33836, 364, NULL, 3333, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33837, 9714, 479, 3333, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33838, 2711, NULL, 3333, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33839, 1834, NULL, 777, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33840, 370, NULL, 777, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33841, 2725, NULL, 777, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33843, 3589, NULL, 10464, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33842, 14496, NULL, 10464, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33844, 11261, NULL, 10464, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33845, 14497, NULL, 10465, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33846, 5853, NULL, 10465, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33847, 2113, NULL, 10465, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33848, 2146, NULL, 10465, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33849, 93, NULL, 10466, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33850, 2683, NULL, 10466, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33851, 9614, NULL, 10466, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33852, 14498, NULL, 10467, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33853, 9533, NULL, 10467, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33854, 10732, NULL, 10467, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33855, 1880, NULL, 10467, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33859, 2482, NULL, 10468, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33860, 1846, NULL, 10469, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33861, 1775, NULL, 10469, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33862, 771, NULL, 10469, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33863, 14500, NULL, 10470, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33864, 14501, NULL, 10470, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33865, 9910, NULL, 10470, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33866, 8523, NULL, 10470, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33867, 2882, NULL, 10471, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33868, 4039, NULL, 10471, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33869, 5190, NULL, 10471, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33870, 6133, NULL, 10471, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33871, 13616, NULL, 10472, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33872, 403, NULL, 10472, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33873, 4758, NULL, 10472, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33874, 3077, NULL, 10472, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33875, 14502, NULL, 10473, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33876, 9307, NULL, 10473, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33877, 2786, NULL, 10473, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33878, 9520, NULL, 10473, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33879, 5891, NULL, 10474, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33880, 6801, NULL, 10474, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33881, 2985, NULL, 10474, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33882, 2931, NULL, 10474, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33883, 1077, NULL, 10475, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33884, 2483, NULL, 10475, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33885, 834, NULL, 10475, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33886, 8048, NULL, 10475, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33887, 1077, NULL, 10476, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33888, 1118, NULL, 10476, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16933, 8436, NULL, 5441, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16966, 8463, NULL, 5452, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33889, 10901, NULL, 9789, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33890, 11950, NULL, 9789, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33891, 6342, NULL, 9789, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33892, 8128, NULL, 9789, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32942, 1693, NULL, 9796, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33913, 3724, NULL, 9796, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33048, 12761, NULL, 10217, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33959, 807, NULL, 9630, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33967, 3268, NULL, 10481, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33968, 1148, NULL, 10481, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33969, 2687, NULL, 10482, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33970, 1241, NULL, 10482, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33971, 1682, NULL, 10483, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33972, 12945, NULL, 10483, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33973, 1036, NULL, 10484, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33974, 4738, NULL, 10484, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33975, 360, NULL, 10485, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33976, 10956, NULL, 10485, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33977, 890, NULL, 10486, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33978, 403, NULL, 10486, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31565, 2132, NULL, 9791, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31563, 1638, NULL, 9791, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33897, 536, NULL, 9792, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33899, 10453, NULL, 9792, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33900, 14517, NULL, 9792, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33898, 14516, NULL, 9792, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33904, 1782, NULL, 9793, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33903, 700, NULL, 9793, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33902, 3116, NULL, 9793, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33909, 1867, NULL, 9794, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33908, 1986, NULL, 9794, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33905, 1020, NULL, 9794, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33906, 2625, NULL, 9794, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33911, 14518, NULL, 9795, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33912, 5932, 643, 9795, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33910, 2672, NULL, 9795, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33922, 4727, NULL, 9797, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33920, 556, NULL, 9797, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33919, 967, NULL, 9797, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33921, 2703, NULL, 9797, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33923, 2582, NULL, 9798, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33924, 5893, NULL, 9798, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33926, 4828, NULL, 9798, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33925, 8850, NULL, 9798, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33917, 14521, NULL, 9799, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33915, 14520, NULL, 9799, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33914, 1329, NULL, 9799, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33916, 14519, NULL, 9799, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33930, 7860, NULL, 9800, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33928, 14522, NULL, 9800, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33929, 12959, NULL, 9800, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33927, 9855, NULL, 9800, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33935, 9514, NULL, 9801, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33934, 10500, NULL, 9801, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33932, 14523, NULL, 9801, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33931, 2662, NULL, 9801, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33936, 233, NULL, 9803, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33938, 14525, NULL, 9803, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33937, 14524, NULL, 9803, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33939, 73, NULL, 9804, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33942, 3517, NULL, 9804, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33941, 8250, NULL, 9804, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33940, 3516, NULL, 9804, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33943, 10809, 644, 9805, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33946, 2657, NULL, 9805, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33945, 3222, NULL, 9805, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33944, 5576, NULL, 9805, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33947, 156, NULL, 9806, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33949, 323, NULL, 9806, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33950, 13714, NULL, 9806, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33952, 51, NULL, 9807, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33954, 2024, NULL, 9807, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33958, 14526, NULL, 9807, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (33955, 682, NULL, 9807, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16179, 1453, NULL, 5268, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16182, 1673, NULL, 5268, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (16183, 2498, NULL, 5268, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16186, 2966, NULL, 5268, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (16181, 1834, NULL, 5268, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33983, 206, NULL, 10489, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33984, 1031, NULL, 10489, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33964, 10552, NULL, 10479, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33963, 5837, NULL, 10478, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33962, 1198, NULL, 10478, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33981, 67, NULL, 10488, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33982, 429, NULL, 10488, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33965, 3394, NULL, 10480, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33966, 9514, NULL, 10480, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33980, 14541, NULL, 10487, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33979, 11168, NULL, 10487, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33961, 1965, NULL, 10477, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33960, 724, NULL, 10477, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33986, 14543, NULL, 10490, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33987, 14542, NULL, 10490, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33985, 14542, NULL, 10490, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20594, 10030, NULL, 6455, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20596, 2515, NULL, 6455, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20597, 3672, NULL, 6455, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20595, 7263, NULL, 6455, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20771, 4904, NULL, 6518, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20770, 10135, NULL, 6518, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20769, 5535, NULL, 6518, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20772, 10136, NULL, 6518, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18834, 3047, NULL, 5946, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18832, 867, NULL, 5946, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18833, 2816, NULL, 5946, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18835, 1852, NULL, 5946, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18831, 1636, NULL, 5946, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17825, 5672, NULL, 779, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17824, 1409, NULL, 779, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17826, 9165, NULL, 779, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17823, 2631, NULL, 779, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17844, 8072, NULL, 5667, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17839, 3146, NULL, 5666, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17821, 5288, NULL, 776, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17820, 7612, NULL, 776, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17819, 4371, NULL, 776, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17822, 9164, NULL, 776, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14110, 2253, NULL, 4692, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14108, 2416, NULL, 4692, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14109, 7315, NULL, 4692, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14107, 1497, NULL, 4692, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33895, 7429, NULL, 9790, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33894, 3367, NULL, 9790, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33896, 14515, NULL, 9790, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33893, 2973, NULL, 9790, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31568, 8716, NULL, 9791, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (31564, 13926, NULL, 9791, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31566, 14514, NULL, 9791, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31567, 13135, NULL, 9791, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33901, 2614, NULL, 9793, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33907, 1981, 642, 9794, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33918, 1373, NULL, 9797, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33933, 2316, NULL, 9801, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31570, 10974, NULL, 9802, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33948, 2822, NULL, 9806, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33956, 891, NULL, 9807, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (33951, 923, NULL, 9807, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33953, 2670, NULL, 9807, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33957, 3074, NULL, 9807, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (33999, 14668, NULL, 10494, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34000, 12290, NULL, 10494, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34001, 1498, NULL, 10494, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34002, 146, NULL, 10494, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34003, 14438, NULL, 10495, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34004, 3077, NULL, 10495, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34005, 10292, NULL, 10495, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34006, 1745, NULL, 10495, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33988, 1933, NULL, 10491, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33990, 6847, NULL, 10491, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33989, 2358, NULL, 10491, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33991, 8165, NULL, 10491, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33993, 7067, NULL, 10492, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33994, 4729, NULL, 10492, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33992, 14437, NULL, 10492, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33997, 471, NULL, 10493, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33995, 1373, NULL, 10493, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33996, 3919, NULL, 10493, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33998, 1818, NULL, 10493, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34007, 14439, NULL, 10496, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34008, 10347, NULL, 10496, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34009, 3004, NULL, 10496, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34010, 12487, NULL, 10496, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34011, 14669, NULL, 10496, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34012, 14440, NULL, 10497, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34013, 38, NULL, 10497, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34014, 14670, NULL, 10497, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34015, 3618, NULL, 10497, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34016, 14441, NULL, 10498, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34017, 8362, NULL, 10498, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34018, 809, NULL, 10498, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34019, 1184, NULL, 10498, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34020, 12105, NULL, 10498, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34021, 975, NULL, 10498, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (34022, 2932, NULL, 10499, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34023, 12771, NULL, 10499, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34024, 2226, NULL, 10499, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34025, 11052, NULL, 10499, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34026, 14442, NULL, 10500, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34027, 14671, NULL, 10500, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34028, 14672, NULL, 10500, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34029, 14443, NULL, 10501, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34030, 14673, NULL, 10501, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34031, 1945, NULL, 10501, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34032, 4034, NULL, 10502, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34033, 1876, NULL, 10502, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34034, 2264, NULL, 10502, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34035, 1757, NULL, 10503, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34036, 365, NULL, 10503, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34037, 1861, NULL, 10503, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34038, 14444, NULL, 10504, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34039, 2163, NULL, 10504, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34040, 10319, NULL, 10504, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34041, 9931, NULL, 10504, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34042, 14445, NULL, 10505, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34043, 10417, NULL, 10505, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34044, 12779, NULL, 10505, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34045, 2531, NULL, 10505, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34046, 3914, NULL, 10506, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34047, 7531, NULL, 10506, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34048, 11156, NULL, 10506, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4295, 133, NULL, 1475, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4294, 231, NULL, 1475, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4293, 695, NULL, 1475, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2821, 3116, NULL, 895, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2822, 2584, NULL, 895, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2823, 3117, NULL, 895, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2820, 2846, NULL, 895, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5815, 1898, NULL, 2985, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5817, 1077, NULL, 2985, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5816, 1624, NULL, 2985, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (28541, 12071, NULL, 8879, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25540, 11107, NULL, 7903, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1332, 214, NULL, 411, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1331, 195, NULL, 411, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19013, 9567, NULL, 5999, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19012, 1559, NULL, 5999, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7895, 727, NULL, 3253, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7896, 2879, NULL, 3253, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7897, 2878, NULL, 3253, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7894, 2964, NULL, 3253, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28340, 11595, NULL, 8831, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28342, 7130, NULL, 8831, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28341, 4311, NULL, 8831, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26811, 374, NULL, 8302, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26815, 2317, NULL, 8302, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26813, 2910, NULL, 8302, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26817, 996, NULL, 8302, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26812, 1374, NULL, 8302, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26814, 7578, NULL, 8302, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26816, 5563, NULL, 8302, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26818, 11476, NULL, 8302, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (1366, 792, NULL, 427, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1365, 794, NULL, 427, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34049, 4951, NULL, 10417, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34050, 14461, 657, 10417, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34051, 4952, 658, 10417, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34052, 1458, NULL, 10418, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34053, 2761, NULL, 10418, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34054, 1956, NULL, 10418, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34055, 482, NULL, 10418, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34056, 188, NULL, 10418, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34057, 1230, NULL, 10419, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34058, 1352, NULL, 10419, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34059, 1311, NULL, 10419, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34060, 14682, NULL, 10419, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34061, 520, NULL, 10420, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23117, 8811, NULL, 7149, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23115, 10736, NULL, 7149, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23116, 2853, NULL, 7149, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17855, 3512, NULL, 5670, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17853, 3956, NULL, 5670, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17856, 2221, NULL, 5670, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22680, 5837, NULL, 7028, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22682, 10571, NULL, 7028, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22679, 4348, 654, 7028, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22681, 2956, NULL, 7028, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34062, 90, NULL, 10420, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34063, 1421, NULL, 10420, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34064, 14683, NULL, 10420, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34065, 1795, NULL, 10421, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34066, 5156, NULL, 10421, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34067, 14684, NULL, 10421, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34068, 14685, NULL, 10422, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34069, 14686, NULL, 10423, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34070, 14687, NULL, 10423, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34071, 6082, NULL, 10424, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34072, 13834, NULL, 10424, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34073, 9191, NULL, 10424, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34074, 1280, NULL, 10425, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34075, 3361, NULL, 10425, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34076, 2545, NULL, 10425, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34077, 6412, NULL, 10425, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34078, 14688, NULL, 10425, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34079, 3601, NULL, 10426, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34080, 9853, NULL, 10426, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34081, 14689, NULL, 10426, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34082, 5893, NULL, 10426, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34083, 12806, NULL, 10427, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34084, 4413, NULL, 10427, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34085, 942, NULL, 10427, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34086, 14690, NULL, 10427, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34087, 14691, NULL, 10428, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34088, 14692, NULL, 10428, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34089, 14693, NULL, 10428, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34090, 14694, NULL, 10428, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34091, 14695, NULL, 10429, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34092, 14696, NULL, 10429, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34093, 14697, NULL, 10429, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34094, 14698, NULL, 10429, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34095, 14699, NULL, 10430, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34096, 14700, NULL, 10430, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34097, 14701, NULL, 10431, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15866, 1963, NULL, 5179, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15868, 3137, NULL, 5179, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15867, 3138, NULL, 5179, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30765, 5285, NULL, 9600, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17536, 2123, NULL, 5582, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17535, 620, NULL, 5582, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17534, 9044, NULL, 5582, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27081, 8842, NULL, 8356, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27080, 3321, NULL, 8356, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27083, 9577, NULL, 8356, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27082, 8843, NULL, 8356, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17206, 1135, NULL, 5498, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17205, 8799, NULL, 5498, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17204, 8798, NULL, 5498, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16013, 2611, NULL, 5216, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16012, 7933, NULL, 5216, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16014, 2327, NULL, 5216, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16015, 834, NULL, 5216, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26954, 11463, NULL, 8266, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34098, 14712, NULL, 10507, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34099, 8723, NULL, 10507, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34100, 12765, NULL, 10507, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34101, 2758, NULL, 10507, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34102, 14713, NULL, 10508, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34103, 8306, NULL, 10508, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34104, 14714, NULL, 10508, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34105, 14715, NULL, 10508, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34106, 14716, NULL, 10509, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34107, 14717, NULL, 10509, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34108, 1114, NULL, 10509, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34109, 1926, NULL, 10509, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34110, 14718, NULL, 10510, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34111, 1446, NULL, 10510, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34112, 2683, NULL, 10510, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34113, 3507, NULL, 10510, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34114, 14719, NULL, 10511, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34115, 14720, NULL, 10511, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34116, 14721, NULL, 10511, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34117, 14524, NULL, 10511, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34118, 14722, NULL, 10512, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34119, 9738, NULL, 10512, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34120, 8253, NULL, 10512, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34125, 14724, NULL, 10514, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34126, 8792, NULL, 10514, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34127, 14725, NULL, 10514, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34128, 5666, NULL, 10514, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34129, 14726, NULL, 10515, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34130, 5308, NULL, 10515, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34131, 7094, NULL, 10515, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34132, 7507, NULL, 10515, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34133, 2571, NULL, 10516, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34134, 2531, NULL, 10516, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34135, 12779, NULL, 10516, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34136, 14727, NULL, 10517, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34137, 14728, NULL, 10517, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34138, 14729, NULL, 10517, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34139, 8, NULL, 10517, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34144, 14733, NULL, 10519, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34145, 1192, NULL, 10519, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34146, 3093, NULL, 10519, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34147, 11164, NULL, 10519, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34141, 14731, NULL, 10518, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34143, 10747, NULL, 10518, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34140, 14730, NULL, 10518, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34142, 14732, NULL, 10518, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32134, 233, NULL, 9975, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32135, 2531, NULL, 9975, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34152, 14247, NULL, 10521, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34153, 14738, NULL, 10521, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34154, 14739, NULL, 10521, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34155, 14740, NULL, 10521, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34156, 14735, NULL, 10522, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34157, 14741, NULL, 10522, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34158, 14742, NULL, 10522, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34163, 14737, NULL, 10524, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34164, 14746, NULL, 10524, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34165, 14747, NULL, 10524, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34166, 14246, NULL, 10525, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34167, 14726, NULL, 10525, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34168, 14748, NULL, 10525, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34169, 14749, NULL, 10525, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30474, 3731, NULL, 9342, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16530, 201, NULL, 5355, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16532, 1077, NULL, 5355, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16531, 2728, NULL, 5355, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4350, 3196, NULL, 1675, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4351, 4966, NULL, 1675, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34160, 14743, NULL, 10523, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34162, 14745, NULL, 10523, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34159, 14736, NULL, 10523, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34161, 14744, NULL, 10523, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (13169, 7066, NULL, 1471, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4299, 4253, NULL, 1473, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4302, 4956, NULL, 1473, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22882, 7177, NULL, 7082, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22880, 4614, NULL, 7082, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22881, 5776, NULL, 7082, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22879, 10670, NULL, 7082, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3734, 4774, NULL, 1268, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3731, 742, NULL, 1268, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3732, 1238, NULL, 1268, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3733, 2918, NULL, 1268, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34123, 1954, NULL, 10513, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34124, 14244, NULL, 10513, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34122, 3061, NULL, 10513, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34121, 14723, NULL, 10513, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25094, 1890, NULL, 7762, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25095, 2507, NULL, 7762, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25092, 486, NULL, 7762, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25093, 4561, NULL, 7762, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25187, 11157, NULL, 7785, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25188, 1681, NULL, 7785, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25189, 1981, NULL, 7785, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34170, 2278, NULL, 7785, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19082, 5265, NULL, 6010, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (181, 1943, NULL, 110, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (180, 164, NULL, 110, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (179, 1118, NULL, 110, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (178, 1674, NULL, 110, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21287, 10275, NULL, 6671, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21288, 4907, NULL, 6671, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21286, 1674, NULL, 6671, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22070, 10382, NULL, 6872, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (22071, 10383, NULL, 6872, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (22067, 10379, NULL, 6872, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22065, 269, NULL, 6872, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22069, 10381, NULL, 6872, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (22068, 10380, NULL, 6872, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22066, 10378, NULL, 6872, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22072, 10384, NULL, 6872, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (2202, 269, NULL, 771, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2204, 834, NULL, 771, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2203, 891, NULL, 771, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (2205, 2717, NULL, 771, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34148, 14734, NULL, 10520, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34150, 2113, NULL, 10520, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30973, 312, NULL, 9672, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30974, 12933, NULL, 9672, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30972, 2240, NULL, 9672, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30971, 1501, NULL, 9672, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17851, 206, NULL, 5669, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17849, 685, NULL, 5669, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17852, 9171, NULL, 5669, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6744, 2957, NULL, 3132, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18133, 9295, NULL, 4988, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18132, 2159, NULL, 4988, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7531, 1914, NULL, 2304, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7532, 1918, NULL, 2304, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7530, 768, NULL, 2304, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7534, 1198, NULL, 2304, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (7533, 1687, NULL, 2304, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20278, 1912, NULL, 6385, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20280, 2592, NULL, 6385, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20279, 1334, NULL, 6385, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34172, 14760, NULL, 5068, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34174, 14761, NULL, 5068, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34171, 1600, NULL, 5068, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34173, 1716, NULL, 5068, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34149, 11937, NULL, 10520, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34151, 8173, NULL, 10520, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34180, 12084, NULL, 10527, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34181, 5779, NULL, 10527, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34182, 929, NULL, 10527, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34179, 14766, NULL, 10527, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34183, 14767, NULL, 10528, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34184, 2347, NULL, 10528, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34185, 12859, NULL, 10528, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34186, 1565, NULL, 10528, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34187, 14768, NULL, 10529, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34188, 1498, NULL, 10529, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34189, 4428, NULL, 10529, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34190, 11000, NULL, 10529, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34192, 14784, NULL, 10530, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34191, 14770, NULL, 10530, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34193, 14785, NULL, 10530, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34194, 9701, NULL, 10530, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34195, 14772, NULL, 10531, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34196, 14786, NULL, 10531, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34197, 744, NULL, 10531, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34198, 9678, NULL, 10531, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34199, 14773, NULL, 10532, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34200, 14774, NULL, 10532, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34201, 14775, NULL, 10532, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34202, 14778, NULL, 10533, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34203, 8799, NULL, 10533, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34204, 3217, NULL, 10533, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18130, 722, NULL, 4988, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18131, 1687, NULL, 4988, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18139, 2545, NULL, 4990, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18150, 1629, NULL, 4993, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18175, 9309, NULL, 263, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34221, 1943, NULL, 10537, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34220, 2045, NULL, 10537, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34222, 692, NULL, 10537, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (34223, 771, NULL, 10537, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (34224, 915, NULL, 10537, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (34218, 1042, NULL, 10537, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34219, 10497, NULL, 10537, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34217, 14782, NULL, 10537, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34227, 2362, NULL, 10538, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34228, 2580, NULL, 10538, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34226, 9124, NULL, 10538, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34225, 14771, NULL, 10538, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34229, 14776, NULL, 10539, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34230, 14792, NULL, 10539, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34231, 14793, NULL, 10539, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34232, 14794, NULL, 10539, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34233, 14777, NULL, 10540, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34234, 14795, NULL, 10540, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34235, 14796, NULL, 10540, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34236, 14797, NULL, 10540, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34237, 14779, NULL, 10541, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34238, 8828, NULL, 10541, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34239, 8829, NULL, 10541, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34240, 14798, NULL, 10541, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34241, 14799, NULL, 10541, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34242, 6834, NULL, 10541, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18176, 9310, NULL, 263, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18178, 9312, NULL, 263, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18177, 9311, NULL, 263, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18163, 914, NULL, 4995, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18166, 1721, NULL, 4995, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34244, 9176, NULL, 10542, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34245, 14800, NULL, 10542, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34246, 14801, NULL, 10542, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34215, 14769, NULL, 10536, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34216, 2592, NULL, 10536, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34214, 14791, NULL, 10536, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34213, 14790, NULL, 10536, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17117, 4437, NULL, 5478, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17114, 8758, NULL, 5478, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17118, 8760, NULL, 5478, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17116, 8759, NULL, 5478, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17115, 4202, NULL, 5478, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20792, 10143, NULL, 6523, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20793, 10144, NULL, 6523, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20794, 7904, 150, 6523, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20795, 10145, NULL, 6523, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33251, 4342, NULL, 10292, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33252, 8289, NULL, 10292, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34243, 10664, NULL, 10292, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24246, 10966, NULL, 7488, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24247, 1069, NULL, 7488, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24249, 1291, NULL, 7488, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24248, 1814, NULL, 7488, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6730, 2492, NULL, 3127, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6728, 4899, NULL, 3127, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6729, 2773, NULL, 3127, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6746, 4578, NULL, 3132, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22873, 1867, NULL, 7080, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22871, 10664, NULL, 7080, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22874, 10666, NULL, 7080, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22872, 1566, NULL, 7080, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34247, 14802, NULL, 10247, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34248, 14803, NULL, 10247, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34249, 14804, NULL, 10247, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34250, 8240, NULL, 10247, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34251, 13931, NULL, 10248, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34252, 812, NULL, 10248, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34253, 4835, NULL, 10248, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34254, 7472, NULL, 10249, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34255, 2236, NULL, 10249, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34256, 584, NULL, 10249, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34257, 14805, NULL, 10249, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34262, 674, NULL, 10251, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34263, 12967, 664, 10251, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34264, 4833, NULL, 10251, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34265, 3246, NULL, 10251, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34266, 14755, NULL, 10252, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34267, 2424, NULL, 10252, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34268, 5903, NULL, 10252, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34269, 14807, NULL, 10252, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34270, 9285, NULL, 10253, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34271, 955, NULL, 10253, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34272, 269, 665, 10253, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34273, 1862, NULL, 10253, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34274, 281, NULL, 10254, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34275, 787, NULL, 10254, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34276, 1345, 666, 10254, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34277, 14808, NULL, 10254, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34278, 1802, NULL, 10254, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34279, 382, NULL, 10255, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34280, 497, NULL, 10255, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34281, 685, NULL, 10255, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34282, 19, NULL, 10255, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34283, 3545, 624, 10256, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34284, 332, NULL, 10256, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34285, 11157, NULL, 10256, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34286, 4904, 667, 10256, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3214, 2830, NULL, 981, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3217, 4116, NULL, 981, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3216, 2216, NULL, 981, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3215, 2215, NULL, 981, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30168, 12751, NULL, 9431, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30167, 12698, NULL, 9431, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30166, 12706, NULL, 9431, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34259, 1858, NULL, 10250, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34261, 1003, NULL, 10250, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34260, 1181, NULL, 10250, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34176, 14783, NULL, 10526, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34177, 1373, 33, 10526, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34175, 14764, NULL, 10526, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34258, 14806, NULL, 10250, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34290, 90, NULL, 10257, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34288, 14810, NULL, 10257, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34289, 14811, NULL, 10257, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15252, 7671, NULL, 5028, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15251, 7660, NULL, 5028, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15253, 7672, NULL, 5028, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34178, 10995, NULL, 10526, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34205, 9119, 728, 10534, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34207, 1146, NULL, 10534, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34206, 2605, NULL, 10534, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34212, 14789, NULL, 10535, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34209, 14765, 729, 10535, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34210, 14787, NULL, 10535, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34211, 14788, NULL, 10535, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34291, 1683, NULL, 10258, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34292, 533, NULL, 10258, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34293, 9004, NULL, 10258, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34294, 14812, NULL, 10258, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34295, 12715, NULL, 10259, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34296, 2980, NULL, 10259, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34297, 1453, 668, 10259, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34298, 14813, NULL, 10259, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34300, 4320, NULL, 10260, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34301, 68, NULL, 10260, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34303, 133, NULL, 10260, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34306, 146, NULL, 10260, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (34305, 2177, NULL, 10260, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (34299, 4319, NULL, 10260, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34302, 4085, NULL, 10260, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34304, 1553, NULL, 10260, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (34307, 1205, NULL, 10260, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (34308, 1621, NULL, 10260, 10);
INSERT INTO 'tunesrecordingsmap' VALUES (34309, 692, NULL, 10260, 11);
INSERT INTO 'tunesrecordingsmap' VALUES (34310, 4801, NULL, 10260, 12);
INSERT INTO 'tunesrecordingsmap' VALUES (34311, 1845, 568, 10260, 13);
INSERT INTO 'tunesrecordingsmap' VALUES (34312, 5091, NULL, 10260, 14);
INSERT INTO 'tunesrecordingsmap' VALUES (34313, 2772, NULL, 10260, 15);
INSERT INTO 'tunesrecordingsmap' VALUES (34314, 289, NULL, 10260, 16);
INSERT INTO 'tunesrecordingsmap' VALUES (34315, 2083, NULL, 10261, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34316, 11180, NULL, 10261, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34317, 586, NULL, 10261, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34318, 3498, NULL, 10261, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34319, 7023, NULL, 10263, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34320, 10270, NULL, 10263, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34321, 14814, NULL, 10263, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34322, 6876, 670, 10263, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33310, 13022, NULL, 9787, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33317, 3076, NULL, 9787, 10);
INSERT INTO 'tunesrecordingsmap' VALUES (33312, 7678, NULL, 9787, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (33311, 964, NULL, 9787, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33309, 3137, NULL, 9787, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33315, 10228, NULL, 9787, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (33316, 1621, NULL, 9787, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (34323, 1624, NULL, 9787, 11);
INSERT INTO 'tunesrecordingsmap' VALUES (34324, 4191, NULL, 9787, 12);
INSERT INTO 'tunesrecordingsmap' VALUES (34325, 2151, NULL, 9787, 13);
INSERT INTO 'tunesrecordingsmap' VALUES (34326, 1458, NULL, 9787, 14);
INSERT INTO 'tunesrecordingsmap' VALUES (34327, 13154, NULL, 9787, 15);
INSERT INTO 'tunesrecordingsmap' VALUES (2911, 1588, NULL, 923, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34328, 2931, NULL, 10544, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34329, 3067, NULL, 10544, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34330, 2238, NULL, 10544, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34331, 2226, NULL, 10544, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34332, 14818, NULL, 10545, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34333, 14819, NULL, 10546, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34334, 14820, NULL, 10547, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34335, 1872, NULL, 10547, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34336, 78, NULL, 10547, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34337, 3061, NULL, 10547, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34338, 4791, NULL, 10547, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34339, 3231, NULL, 10550, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34340, 8130, NULL, 10550, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34341, 14821, 671, 10550, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34342, 4004, NULL, 10550, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34343, 4843, NULL, 10551, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34344, 11308, NULL, 10551, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34345, 6462, NULL, 10551, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34346, 9294, NULL, 10551, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34347, 7107, NULL, 10552, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34348, 2864, NULL, 10554, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34349, 9289, 672, 10554, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34350, 665, NULL, 10554, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34351, 13726, NULL, 10554, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34352, 14822, NULL, 10556, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34353, 7264, NULL, 10557, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34354, 6222, NULL, 10557, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34355, 14823, NULL, 10557, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34356, 12416, 673, 10559, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34357, 1334, 674, 10560, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34358, 11855, NULL, 10560, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34359, 3442, NULL, 10560, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34360, 2932, NULL, 10560, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34362, 3394, NULL, 10562, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34363, 1091, NULL, 10562, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34361, 1566, NULL, 10562, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34364, 1821, 675, 10562, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34365, 14824, NULL, 10558, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34366, 9327, NULL, 10558, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34367, 7240, 676, 10558, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34368, 5931, NULL, 10558, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34369, 408, NULL, 10543, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34370, 2129, NULL, 10543, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34371, 7119, NULL, 10548, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34372, 11281, NULL, 10548, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34373, 11423, NULL, 10548, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33340, 14181, NULL, 10318, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (33341, 2369, NULL, 10318, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33335, 1140, NULL, 10318, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33336, 2621, NULL, 10318, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33338, 14180, NULL, 10318, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (33339, 7948, NULL, 10318, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (33337, 14179, NULL, 10318, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33358, 14192, NULL, 10318, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15861, 3390, NULL, 5177, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23635, 9514, NULL, 7294, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23633, 10821, NULL, 7294, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23634, 5207, NULL, 7294, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27307, 1971, NULL, 8415, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9811, 1916, NULL, 3765, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12064, 423, NULL, 1064, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12065, 613, NULL, 1064, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12066, 2577, NULL, 1064, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12063, 1732, NULL, 1064, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9824, 1956, NULL, 3770, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (9834, 1772, NULL, 3773, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (9838, 1781, NULL, 3774, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5532, 1880, NULL, 1805, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5533, 1958, NULL, 1805, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5534, 778, NULL, 1805, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5531, 1457, NULL, 1805, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9430, 2151, NULL, 1812, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (9429, 2321, NULL, 1812, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (9431, 2414, NULL, 1812, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (5539, 1099, NULL, 1812, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10677, 6047, NULL, 1806, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5559, 2804, NULL, 1809, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5557, 4444, NULL, 1809, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5118, 4656, NULL, 2854, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6096, 502, NULL, 1766, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6098, 3912, NULL, 1766, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6097, 2399, NULL, 1766, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6095, 1290, NULL, 1766, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6106, 91, NULL, 1769, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6105, 355, NULL, 1769, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6104, 5274, NULL, 1769, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6109, 1325, NULL, 1767, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6112, 2899, NULL, 1765, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6123, 1106, NULL, 1764, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7326, 639, NULL, 1864, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7325, 917, NULL, 1864, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7327, 5514, NULL, 1864, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11178, 338, NULL, 1860, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7328, 384, NULL, 1860, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7329, 673, NULL, 1860, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7330, 4344, NULL, 1860, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11917, 5369, NULL, 1866, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (7350, 3543, NULL, 1861, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (14410, 19, NULL, 4835, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14411, 2259, NULL, 4835, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14412, 2821, NULL, 4835, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14422, 2882, NULL, 4840, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (14424, 4039, NULL, 4840, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20105, 1731, NULL, 4842, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14433, 1861, NULL, 4843, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14435, 5295, NULL, 4844, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (14436, 4609, NULL, 4844, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11415, 122, NULL, 4134, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11413, 6613, NULL, 4134, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11412, 687, NULL, 4134, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11414, 771, NULL, 4134, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11416, 3919, NULL, 4134, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34376, 14828, NULL, 6472, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34377, 2240, 305, 6472, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34378, 958, NULL, 6474, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34379, 14829, NULL, 6474, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34380, 10978, NULL, 6476, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34381, 14830, NULL, 6476, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34382, 14831, NULL, 6476, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34387, 14833, NULL, 6484, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34388, 1772, NULL, 6484, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34389, 2419, NULL, 6483, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34390, 2653, NULL, 6483, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34391, 14834, NULL, 6483, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34392, 295, NULL, 6478, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34393, 14835, NULL, 6478, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20655, 1059, NULL, 6473, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34394, 14836, NULL, 6473, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34386, 5557, NULL, 6477, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34374, 5498, NULL, 10555, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34375, 14825, NULL, 10555, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34395, 3919, 215, 6473, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34396, 5739, NULL, 6473, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34397, 2899, NULL, 6473, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34398, 709, NULL, 6473, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (34399, 384, NULL, 6479, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34400, 14837, NULL, 6479, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34401, 14838, NULL, 6479, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34402, 716, NULL, 6479, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34383, 73, NULL, 6477, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34384, 10990, NULL, 6477, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34385, 14832, NULL, 6477, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34403, 6110, NULL, 6485, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34404, 5959, NULL, 6482, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34405, 1566, NULL, 6482, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34406, 13133, 434, 6482, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34407, 1978, NULL, 6482, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34408, 2846, NULL, 6480, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34409, 14839, NULL, 6480, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34410, 14840, NULL, 6480, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34411, 695, NULL, 6481, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34412, 2850, NULL, 6481, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34413, 14841, NULL, 6475, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34414, 9995, NULL, 6475, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34415, 14843, NULL, 6486, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34416, 2964, NULL, 6486, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12029, 2624, NULL, 2055, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6385, 3394, NULL, 2471, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6386, 1264, NULL, 2471, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4640, 13, NULL, 1629, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (4641, 709, NULL, 1629, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34417, 3772, NULL, 10563, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34418, 14846, NULL, 10563, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34419, 1600, NULL, 10563, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34420, 1566, NULL, 10563, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34421, 3243, NULL, 10563, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34422, 2862, NULL, 10564, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34423, 14847, NULL, 10564, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34424, 3601, 437, 10564, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34425, 3027, NULL, 10564, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34426, 2738, NULL, 10565, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34427, 6240, NULL, 10565, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34428, 2855, NULL, 10565, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34429, 2214, NULL, 10566, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34430, 5212, NULL, 10566, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34431, 4988, NULL, 10567, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34432, 7468, NULL, 10567, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34433, 14848, NULL, 10567, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34434, 14849, NULL, 10567, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34435, 1732, NULL, 10568, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34436, 7022, 678, 10568, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34437, 1926, NULL, 10568, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34438, 123, NULL, 10568, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34439, 992, NULL, 10568, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34440, 2554, NULL, 10568, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (34441, 1141, 679, 10569, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34442, 2076, NULL, 10569, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34443, 2692, NULL, 10569, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34444, 2434, NULL, 10569, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34445, 14850, NULL, 10570, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34446, 6974, NULL, 10570, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34447, 2144, NULL, 10571, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34448, 1099, NULL, 10571, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34449, 239, NULL, 10571, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34450, 1513, NULL, 10571, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34451, 13885, NULL, 10571, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34452, 19, NULL, 10571, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (34453, 368, NULL, 10571, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (22631, 3047, NULL, 7015, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22632, 10544, NULL, 7015, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22630, 9920, NULL, 7015, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22633, 3238, NULL, 7015, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34454, 11299, 638, 10572, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34455, 14851, NULL, 10572, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34456, 2316, NULL, 10572, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34457, 441, NULL, 10573, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34458, 433, NULL, 10573, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34459, 1226, NULL, 10573, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34460, 14852, NULL, 10573, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34461, 5240, NULL, 10573, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34462, 14853, NULL, 10573, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (34463, 3086, NULL, 10573, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (34464, 1020, NULL, 10573, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (34465, 4738, NULL, 10573, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (33101, 13986, NULL, 10233, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33102, 13987, NULL, 10233, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33100, 4543, NULL, 10233, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33103, 13988, NULL, 10233, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17996, 2947, NULL, 5713, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17998, 9257, NULL, 5713, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17997, 8656, NULL, 5713, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17995, 7775, NULL, 5713, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17668, 9103, NULL, 5618, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17666, 3060, NULL, 5618, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17667, 4022, NULL, 5618, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17665, 1266, NULL, 5618, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2127, 2634, NULL, 747, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2125, 2602, NULL, 747, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2128, 2616, NULL, 747, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2126, 2364, NULL, 747, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31859, 5666, NULL, 9902, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31857, 1609, NULL, 9902, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31858, 10551, NULL, 9902, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24493, 38, NULL, 7570, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24492, 1498, NULL, 7570, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24491, 589, NULL, 7570, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24494, 11000, NULL, 7570, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19390, 1818, NULL, 6100, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (597, 1996, NULL, 172, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (599, 2323, NULL, 172, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (596, 2484, NULL, 172, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (598, 2957, NULL, 172, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17111, 912, NULL, 5477, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17110, 1203, NULL, 5477, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17113, 2608, NULL, 5477, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17109, 1221, NULL, 5477, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17112, 8757, NULL, 5477, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17409, 7881, NULL, 5560, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17411, 8891, NULL, 5560, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17410, 8889, NULL, 5560, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20294, 1448, NULL, 6340, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20325, 6732, NULL, 6348, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2462, 545, NULL, 829, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2463, 2912, NULL, 829, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2464, 2919, NULL, 829, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26205, 2236, NULL, 8085, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26202, 9979, NULL, 8085, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26203, 7537, NULL, 8085, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26204, 2379, 132, 8085, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12837, 2511, NULL, 4455, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (12836, 375, NULL, 4455, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12839, 2431, NULL, 4455, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (12834, 971, NULL, 4455, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12838, 1020, NULL, 4455, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (12835, 1140, NULL, 4455, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27422, 238, NULL, 8464, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27421, 906, NULL, 8464, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27424, 1543, NULL, 8464, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27423, 1417, NULL, 8464, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15515, 7800, NULL, 5103, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15516, 7126, NULL, 5103, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15514, 7282, NULL, 5103, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (15517, 7801, NULL, 5103, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30018, 12662, NULL, 9386, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17814, 3128, NULL, 5664, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17416, 8815, NULL, 5562, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18182, 9315, NULL, 5747, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31009, 12945, NULL, 9682, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31011, 1263, NULL, 9682, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31010, 1401, NULL, 9682, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31015, 2839, NULL, 9682, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (7617, 5584, NULL, 2269, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (9251, 6094, NULL, 2269, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7616, 5583, NULL, 2269, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17850, 3224, NULL, 5669, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17390, 8876, NULL, 2424, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17392, 8877, NULL, 2424, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17389, 2255, NULL, 2424, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17391, 8137, NULL, 2424, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29900, 12564, NULL, 9357, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32060, 13436, NULL, 9958, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32059, 13435, NULL, 9958, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32061, 13437, NULL, 9958, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32545, 9695, NULL, 10096, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32546, 13774, NULL, 10096, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32547, 740, NULL, 10096, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32548, 13775, NULL, 10096, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19149, 4543, NULL, 6038, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (19146, 8385, NULL, 6038, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19148, 7240, NULL, 6038, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19147, 4176, NULL, 6038, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (30169, 12752, NULL, 9431, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17847, 5490, NULL, 5668, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17854, 6732, NULL, 5670, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18216, 6406, NULL, 5755, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22907, 10685, NULL, 7090, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18184, 4555, NULL, 5748, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3230, 4128, NULL, 986, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25302, 5153, NULL, 7810, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (42, 2289, NULL, 200, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (41, 2375, NULL, 200, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (40, 2418, NULL, 200, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (39, 1107, NULL, 200, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33484, 14243, NULL, 10356, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32621, 7809, NULL, 10116, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32620, 9757, NULL, 10116, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6335, 2964, NULL, 2576, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (6336, 5306, NULL, 2576, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29894, 12590, NULL, 9353, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15087, 7599, NULL, 4961, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (15088, 3042, NULL, 4961, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15089, 1247, NULL, 4961, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15086, 1282, NULL, 4961, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29967, 10842, NULL, 9374, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17180, 8793, NULL, 5492, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17176, 7762, NULL, 5492, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34287, 14809, NULL, 10257, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34466, 14897, NULL, 10264, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34467, 14898, NULL, 10264, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34468, 14899, NULL, 10264, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (15181, 1013, NULL, 5005, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28872, 121, NULL, 8954, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28875, 7803, NULL, 8954, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21584, 3497, NULL, 6765, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21582, 674, NULL, 6765, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21581, 655, NULL, 6765, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21583, 1121, NULL, 6765, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12395, 2680, NULL, 4321, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12397, 2887, NULL, 4321, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34470, 2691, NULL, 4321, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25644, 11227, NULL, 7945, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25645, 2906, NULL, 7945, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32396, 1588, NULL, 889, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34471, 413, NULL, 889, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2664, 1017, NULL, 869, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2665, 1542, NULL, 869, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2666, 1636, NULL, 869, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (2668, 1814, NULL, 869, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (6388, 2943, NULL, 2465, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5278, 5786, NULL, 2207, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5279, 219, NULL, 2207, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (21902, 2757, NULL, 6832, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21900, 1415, NULL, 6832, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21901, 5786, NULL, 6832, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (7928, 3002, NULL, 3290, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2305, 295, NULL, 464, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (2302, 350, NULL, 464, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (13013, 152, NULL, 4420, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (13016, 697, NULL, 4420, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (13017, 724, NULL, 4420, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (13015, 850, NULL, 4420, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (13014, 5362, NULL, 4420, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (13011, 5786, NULL, 4420, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (13012, 2943, NULL, 4420, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21041, 6047, NULL, 6591, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (21038, 7436, NULL, 6591, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21040, 5786, NULL, 6591, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (21039, 2943, NULL, 6591, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19807, 586, NULL, 6187, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19806, 753, NULL, 6187, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19808, 5786, NULL, 6187, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11038, 2055, NULL, 2388, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27761, 78, NULL, 8612, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (27762, 1389, NULL, 8612, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27764, 11852, NULL, 8612, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (27763, 5786, NULL, 8612, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28041, 8, NULL, 6693, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10580, 652, NULL, 1588, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10577, 1360, NULL, 1588, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10578, 1418, NULL, 1588, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (10579, 5786, NULL, 1588, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (948, 5786, NULL, 298, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24599, 512, NULL, 7601, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24600, 586, NULL, 7601, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24601, 4258, NULL, 7601, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24602, 5786, NULL, 7601, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (5563, 1700, NULL, 2925, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1111, 5786, NULL, 338, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1108, 1700, NULL, 338, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26039, 11334, NULL, 1743, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26043, 152, NULL, 1743, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (26038, 425, NULL, 1743, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26037, 724, NULL, 1743, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26042, 5964, NULL, 1743, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (26041, 11335, NULL, 1743, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26040, 5786, NULL, 1743, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6243, 664, NULL, 3076, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6244, 1238, NULL, 3076, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (6241, 1241, NULL, 3076, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6242, 1628, NULL, 3076, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (6245, 5786, NULL, 3076, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (7537, 1052, NULL, 2303, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7540, 5786, NULL, 2303, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (30617, 2055, NULL, 9555, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30619, 12846, NULL, 9555, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (30622, 4048, NULL, 9555, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (30620, 12847, NULL, 9555, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30623, 5786, NULL, 9555, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (30624, 1742, NULL, 9555, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (30618, 3002, NULL, 9555, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1729, 2239, NULL, 641, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (1727, 2233, NULL, 641, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1728, 2237, NULL, 641, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1746, 2273, NULL, 646, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (1747, 2275, NULL, 646, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (1748, 2209, NULL, 646, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34472, 13283, NULL, 9884, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33035, 5959, NULL, 10214, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (30850, 5552, NULL, 9629, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (30851, 4381, NULL, 9629, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24798, 5552, NULL, 7664, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24799, 4381, NULL, 7664, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22895, 8444, NULL, 7087, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22899, 1266, NULL, 7087, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (22896, 8442, NULL, 7087, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22893, 10678, NULL, 7087, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (21420, 2209, NULL, 6704, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34474, 6187, NULL, 10593, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34475, 6181, NULL, 10593, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34476, 11042, NULL, 10594, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34479, 14902, NULL, 10598, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26034, 2821, NULL, 8046, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34473, 352, NULL, 10592, 0);
INSERT INTO 'tunesrecordingsmap' VALUES (34477, 6224, NULL, 10595, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34478, 14901, NULL, 10596, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34480, 5174, NULL, 10600, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34481, 4134, NULL, 10601, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34482, 372, NULL, 10604, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34483, 12380, NULL, 10609, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34484, 11111, NULL, 10613, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16208, 3912, NULL, 5275, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16209, 730, NULL, 5275, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25682, 2943, NULL, 7958, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (31502, 2943, NULL, 6318, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (712, 482, NULL, 282, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (713, 1413, NULL, 282, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (851, 1802, NULL, 75, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25870, 11280, NULL, 7999, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25871, 1101, NULL, 7999, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25872, 11281, NULL, 7999, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25889, 11287, NULL, 8004, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25888, 11286, NULL, 8004, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (25890, 11288, NULL, 8004, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26035, 2903, NULL, 8046, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26851, 2625, NULL, 8307, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26856, 1386, NULL, 8307, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (20088, 280, NULL, 6274, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20090, 470, NULL, 6274, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (20087, 2905, NULL, 6274, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20091, 2458, NULL, 6274, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (20085, 9824, NULL, 6274, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (20086, 2209, NULL, 6274, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29500, 691, NULL, 9206, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29502, 11231, NULL, 9206, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29501, 9176, NULL, 9206, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29833, 691, NULL, 9312, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29834, 6336, NULL, 9312, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29835, 12507, NULL, 9312, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29836, 5499, NULL, 9312, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (25499, 691, NULL, 7890, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (25500, 727, NULL, 7890, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25501, 6607, NULL, 7890, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33149, 1802, NULL, 10265, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33157, 14018, NULL, 10267, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33165, 1981, NULL, 10270, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34485, 14903, NULL, 10271, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33179, 14025, NULL, 10274, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34486, 14904, NULL, 10277, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28299, 803, NULL, 8818, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (1662, 2140, NULL, 623, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (16750, 5962, NULL, 5408, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (16749, 4839, NULL, 5408, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16748, 4018, NULL, 5408, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (23431, 5962, NULL, 7240, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (23430, 4018, NULL, 7240, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23429, 2822, NULL, 7240, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24510, 11007, NULL, 7575, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18348, 2442, NULL, 5789, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (18350, 1077, NULL, 5789, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (18349, 1117, NULL, 5789, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18347, 2545, NULL, 5789, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (18345, 1228, NULL, 5789, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18346, 1745, NULL, 5789, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17458, 2835, NULL, 5576, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17460, 9014, NULL, 5576, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17461, 9015, NULL, 5576, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17459, 2728, NULL, 5576, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29925, 9696, NULL, 9363, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29923, 10864, NULL, 9363, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19634, 3005, NULL, 6075, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (19633, 10129, NULL, 6075, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (19635, 3007, NULL, 6075, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (19636, 3001, NULL, 6075, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (26504, 448, NULL, 8195, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26505, 2291, NULL, 8195, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26506, 757, NULL, 8195, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (26507, 10129, NULL, 8195, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (24141, 1917, NULL, 7446, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (24139, 236, NULL, 7446, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24140, 6934, NULL, 7446, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17693, 9114, NULL, 5625, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17690, 9112, NULL, 5625, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17695, 9116, NULL, 5625, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (23305, 9337, NULL, 7201, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20660, 2925, NULL, 6487, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (20658, 2921, NULL, 6487, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20659, 9337, NULL, 6487, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (2465, 2278, NULL, 830, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (2467, 9337, NULL, 830, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (27180, 4457, NULL, 8378, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (27176, 1872, NULL, 8378, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (27179, 11719, NULL, 8378, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (27178, 11718, NULL, 8378, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (33569, 199, NULL, 10370, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (33567, 13545, NULL, 10370, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (33566, 13544, NULL, 10370, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (33568, 7612, NULL, 10370, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34487, 14905, NULL, 9542, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (9699, 17, NULL, 1028, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (20638, 10059, NULL, 2543, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34488, 14906, NULL, 9543, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34489, 14907, NULL, 9544, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34493, 14911, NULL, 9548, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34492, 14910, NULL, 9547, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34491, 14909, NULL, 9546, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34490, 14908, NULL, 9545, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34494, 14912, NULL, 9549, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34495, 14913, NULL, 9550, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34496, 14914, NULL, 9551, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29828, 12502, NULL, 9311, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29829, 12503, NULL, 9311, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29830, 12504, NULL, 9311, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29831, 12505, NULL, 9311, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29832, 12506, NULL, 9311, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34497, 14915, NULL, 10625, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34498, 2554, NULL, 10625, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34499, 3074, NULL, 10625, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34500, 7678, NULL, 10626, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34501, 13346, NULL, 10626, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34502, 13341, NULL, 10626, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34503, 14916, NULL, 10628, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34504, 14917, NULL, 10628, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34505, 14918, NULL, 10628, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34506, 10223, NULL, 10629, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34507, 14919, NULL, 10629, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34508, 2905, NULL, 10629, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34509, 14920, NULL, 10630, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34510, 14921, NULL, 10630, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34511, 14922, NULL, 10630, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34512, 14923, NULL, 10631, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34513, 14924, NULL, 10631, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34514, 14925, NULL, 10632, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34515, 13342, NULL, 10632, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34516, 13349, NULL, 10633, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34517, 14926, NULL, 10633, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34518, 14927, NULL, 10633, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34519, 14928, NULL, 10634, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34520, 8343, NULL, 10634, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34521, 14929, NULL, 10636, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34522, 14930, NULL, 10636, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34523, 14931, NULL, 10636, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34524, 14932, NULL, 10638, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34525, 14933, NULL, 10638, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34526, 14934, NULL, 10638, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34527, 14935, NULL, 10639, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34528, 5552, NULL, 10639, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34529, 14936, NULL, 10639, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34530, 14937, NULL, 10640, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34531, 14938, NULL, 10640, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34532, 14939, NULL, 10641, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34533, 11880, NULL, 10641, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34534, 14940, NULL, 10641, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34535, 14941, NULL, 10642, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34536, 14942, NULL, 10642, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34537, 14943, NULL, 10642, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34538, 14944, NULL, 10643, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34539, 13339, NULL, 10643, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34540, 206, NULL, 10643, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34544, 14948, NULL, 10645, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34545, 14949, NULL, 10645, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34546, 14950, NULL, 10645, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34547, 7680, NULL, 10646, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34548, 14951, NULL, 10646, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34549, 14952, NULL, 10646, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34550, 14953, NULL, 10648, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34551, 14954, NULL, 10648, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34552, 14955, NULL, 10648, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34553, 14956, NULL, 9541, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34542, 14946, NULL, 10644, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34541, 14945, NULL, 10644, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34543, 14947, NULL, 10644, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (4879, 2658, NULL, 2823, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (4878, 2614, NULL, 2823, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3668, 4798, NULL, 1327, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (3667, 2614, NULL, 1327, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (3666, 1404, NULL, 1327, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3382, 452, NULL, 1243, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (3383, 3769, NULL, 1243, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3384, 2614, NULL, 1243, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11157, 664, NULL, 1558, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11158, 2614, NULL, 1558, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11156, 1282, NULL, 1558, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (24749, 11101, NULL, 7650, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34557, 7438, NULL, 10671, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34558, 2004, NULL, 10672, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7020, 2305, NULL, 2147, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7022, 840, NULL, 2147, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34564, 14960, NULL, 10676, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34565, 2400, NULL, 10678, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34566, 5190, NULL, 10678, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34567, 6653, NULL, 10679, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34568, 5716, NULL, 10679, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34569, 3314, NULL, 10679, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34572, 7078, NULL, 10681, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34573, 6164, NULL, 10681, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34574, 8130, NULL, 10682, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34575, 14961, NULL, 10682, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34576, 14962, NULL, 10682, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34583, 1527, NULL, 10685, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34584, 842, NULL, 10685, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34585, 1431, NULL, 10685, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34586, 1293, NULL, 10686, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34587, 12843, NULL, 10686, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34588, 5213, NULL, 10686, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34589, 14964, NULL, 10687, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34590, 3383, NULL, 10687, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34591, 448, NULL, 10688, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34592, 7437, NULL, 10688, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34593, 2991, NULL, 10688, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34554, 374, NULL, 10670, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34555, 2876, NULL, 10670, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34556, 220, NULL, 10671, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34559, 14958, NULL, 10673, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34562, 9100, NULL, 10675, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34563, 14959, NULL, 10675, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34579, 188, NULL, 10683, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34577, 283, NULL, 10683, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34578, 14963, NULL, 10683, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34581, 312, NULL, 10684, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34580, 448, NULL, 10684, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34582, 2991, NULL, 10684, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22480, 13735, NULL, 6977, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (23126, 7192, NULL, 7152, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (23128, 10489, 211, 7152, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (15804, 1059, NULL, 5158, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (15801, 1458, NULL, 5158, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (25353, 3874, NULL, 7830, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17243, 2336, NULL, 5506, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (17244, 2112, NULL, 5506, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (17241, 8813, NULL, 5506, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (17242, 3195, NULL, 5506, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (17240, 6636, NULL, 5506, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (17239, 1345, NULL, 5506, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (17245, 2692, NULL, 5506, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (34594, 1334, NULL, 9934, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34560, 6336, NULL, 10674, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7021, 4675, NULL, 2147, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31288, 12994, NULL, 9734, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (31287, 2399, NULL, 9734, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (31289, 1744, NULL, 9734, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (31286, 12992, NULL, 9734, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29813, 12496, NULL, 9307, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (29814, 12497, NULL, 9307, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (29815, 12498, NULL, 9307, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (29816, 12499, NULL, 9307, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (29817, 12500, NULL, 9307, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (34595, 5174, NULL, 2512, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34561, 11814, NULL, 10674, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34596, 487, NULL, 3227, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34597, 5320, NULL, 3227, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34598, 378, NULL, 3227, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34599, 660, NULL, 3227, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34600, 724, NULL, 8128, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34601, 817, NULL, 3262, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34602, 457, NULL, 3262, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34603, 957, NULL, 3262, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34604, 1818, NULL, 3262, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34605, 382, NULL, 10669, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34606, 497, NULL, 10669, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34607, 7992, NULL, 10669, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34608, 12843, NULL, 10669, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34609, 3222, NULL, 10669, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34610, 14965, NULL, 10669, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (34611, 482, NULL, 10669, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (34612, 1092, NULL, 10669, 8);
INSERT INTO 'tunesrecordingsmap' VALUES (34613, 220, NULL, 10669, 9);
INSERT INTO 'tunesrecordingsmap' VALUES (6704, 1455, NULL, 3109, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (6701, 2886, NULL, 3109, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (29264, 1778, NULL, 9122, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34614, 405, NULL, 10658, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34615, 14966, NULL, 10658, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34616, 998, NULL, 10660, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34617, 14967, NULL, 10660, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34621, 14968, NULL, 10663, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34622, 1708, NULL, 10663, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34623, 2603, NULL, 10663, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34624, 4168, NULL, 10664, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34625, 1112, NULL, 10664, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34626, 6898, NULL, 10665, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34627, 14969, NULL, 10665, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34628, 14970, NULL, 10666, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34629, 987, NULL, 10667, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34630, 5926, NULL, 10667, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34631, 2645, NULL, 10667, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34632, 8863, NULL, 10667, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22238, 5173, NULL, 6920, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (22237, 2332, NULL, 6920, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (22236, 2798, NULL, 6920, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11542, 6656, NULL, 4158, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (11541, 6655, NULL, 4158, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (11538, 749, NULL, 4158, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (11539, 6653, NULL, 4158, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (11540, 6654, NULL, 4158, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (11543, 6657, NULL, 4158, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (11544, 5320, NULL, 4158, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (28140, 11954, NULL, 8760, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24129, 2988, NULL, 7443, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26414, 497, NULL, 8165, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (26413, 1329, NULL, 8165, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (26417, 1505, NULL, 8165, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (26416, 1629, NULL, 8165, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10772, 1834, NULL, 2686, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (10177, 5636, NULL, 3881, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (10173, 1329, NULL, 3881, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (10176, 1462, NULL, 3881, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (30605, 12843, NULL, 9553, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (30600, 1834, NULL, 9553, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32253, 9147, NULL, 10008, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (14537, 7481, NULL, 4881, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12504, 5301, NULL, 1509, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12503, 2055, NULL, 1509, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12505, 8684, NULL, 1509, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12940, 173, NULL, 4491, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (12942, 7007, NULL, 4491, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (12941, 5122, NULL, 4491, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (12943, 9484, NULL, 4491, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32237, 923, NULL, 10004, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (32240, 3215, NULL, 10004, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32238, 13532, NULL, 10004, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (20825, 913, NULL, 6533, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28889, 68, NULL, 8959, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (28886, 364, NULL, 8959, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (28888, 892, NULL, 8959, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (28887, 951, NULL, 8959, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32825, 892, NULL, 10167, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (32824, 923, NULL, 10167, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32823, 1009, NULL, 10167, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (22242, 892, NULL, 6921, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (22239, 1021, NULL, 6921, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (5018, 2489, NULL, 1873, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (5019, 2140, NULL, 1873, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (5017, 3405, NULL, 1873, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (24883, 3405, NULL, 7692, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18523, 7689, NULL, 5836, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18557, 9400, NULL, 5836, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (6435, 5786, 685, 2489, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (241, 1582, NULL, 323, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18954, 2489, NULL, 5973, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (18957, 1118, NULL, 5973, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (18953, 1284, NULL, 5973, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (18956, 1474, NULL, 5973, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32445, 3616, NULL, 10070, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (32443, 11326, NULL, 10070, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (32442, 13723, NULL, 10070, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (7708, 5615, NULL, 3229, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (7707, 5614, NULL, 3229, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34208, 1334, NULL, 10534, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (3314, 3004, NULL, 1010, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (16526, 2456, NULL, 5354, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (16523, 2668, NULL, 5354, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (8400, 1817, NULL, 3427, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34652, 122, NULL, 10694, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34654, 1329, NULL, 10694, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34653, 1395, NULL, 10694, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34636, 5837, NULL, 10690, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34638, 5308, NULL, 10690, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34637, 4522, NULL, 10690, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34639, 2661, NULL, 10690, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34634, 162, NULL, 10689, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34669, 5600, NULL, 10699, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34670, 5650, NULL, 10699, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34671, 407, NULL, 10699, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34672, 6783, NULL, 10699, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34673, 451, NULL, 10699, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34674, 4887, NULL, 10699, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (34675, 1266, NULL, 10699, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (34676, 14758, NULL, 10700, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34678, 3672, NULL, 10700, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34677, 1036, NULL, 10700, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34679, 2628, NULL, 10700, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34665, 13002, NULL, 10698, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34668, 14996, NULL, 10698, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34666, 14994, NULL, 10698, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34667, 14995, NULL, 10698, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34664, 14759, NULL, 10697, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34663, 14757, NULL, 10697, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34659, 2050, NULL, 10696, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34660, 2416, NULL, 10696, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34661, 4128, NULL, 10696, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34662, 2862, NULL, 10696, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34658, 92, NULL, 10695, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34657, 2559, NULL, 10695, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34655, 12546, NULL, 10695, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34656, 14993, NULL, 10695, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34680, 13593, NULL, 10693, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34681, 1845, 568, 10693, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34650, 8148, NULL, 10692, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34649, 1247, NULL, 10692, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34651, 1437, NULL, 10692, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34648, 14756, NULL, 10692, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34641, 267, NULL, 10691, 2);
INSERT INTO 'tunesrecordingsmap' VALUES (34647, 14992, NULL, 10691, 7);
INSERT INTO 'tunesrecordingsmap' VALUES (34646, 14991, NULL, 10691, 5);
INSERT INTO 'tunesrecordingsmap' VALUES (34644, 1192, NULL, 10691, 6);
INSERT INTO 'tunesrecordingsmap' VALUES (34640, 14755, NULL, 10691, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34642, 1542, NULL, 10691, 3);
INSERT INTO 'tunesrecordingsmap' VALUES (34643, 1775, 484, 10691, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34633, 2829, NULL, 10689, 1);
INSERT INTO 'tunesrecordingsmap' VALUES (34635, 14136, NULL, 10689, 4);
INSERT INTO 'tunesrecordingsmap' VALUES (34645, 14990, NULL, 10689, 3);


--
INSERT INTO 'tuneurl' VALUES (90, 'http://eddie.mit.edu/~jc/music/abc/Scotland/reel/DeilAmangTheTailorsR.abc', 10, 382);
INSERT INTO 'tuneurl' VALUES (98, 'http://www.scottishdance.net/dances/GloomyWinter.gif', 10, 2455);
INSERT INTO 'tuneurl' VALUES (91, 'http://eddie.mit.edu/~jc/music/abc/Scotland/reel/DrunkenPiper.abc', 10, 430);
INSERT INTO 'tuneurl' VALUES (99, 'http://www.scottishdance.net/dances/TamLin.gif', 10, 2905);
INSERT INTO 'tuneurl' VALUES (92, 'http://www.scottishdance.net/dances/TheGeeseInTheBog.gif', 10, 565);
INSERT INTO 'tuneurl' VALUES (93, 'http://eddie.mit.edu/~jc/music/abc/Scotland/reel/DeilStickDaMinister.abc', 10, 785);
INSERT INTO 'tuneurl' VALUES (101, 'http://www.scottishdance.net/dances/MphosMajority.gif', 10, 7738);
INSERT INTO 'tuneurl' VALUES (94, 'http://trillian.mit.edu/~jc/music/abc/Scotland/AMansAManForAThat.abc', 10, 1066);
INSERT INTO 'tuneurl' VALUES (102, 'http://www.scottap.com/scd/dances/AlansJig.abc', 10, 7817);
INSERT INTO 'tuneurl' VALUES (95, 'http://www.scottishdance.net/dances/TheOneOClockCannon.gif', 10, 1427);
INSERT INTO 'tuneurl' VALUES (96, 'http://trillian.mit.edu/~jc/music/abc/Scotland/AlisonRose.abc', 10, 1542);
INSERT INTO 'tuneurl' VALUES (104, 'http://www.scottap.com/scd/dances/Thorncliffe.abc', 10, 8986);
INSERT INTO 'tuneurl' VALUES (97, 'mailto:machlis@ucsc.edu', 10, 1573);
INSERT INTO 'tuneurl' VALUES (105, 'http://www.scottap.com/scd/dances/AlanPBerne.abc', 10, 8997);
INSERT INTO 'tuneurl' VALUES (108, 'http://www.wdsa.co.uk/Gillian%20Collis%20Strathspey.PDF', 10, 11558);
INSERT INTO 'tuneurl' VALUES (109, 'http://blog.lib.umn.edu/ldfs/8x32/2008_01.html', 10, 11985);
INSERT INTO 'tuneurl' VALUES (111, 'http://www.strathspey.org/libDances/sspbook.pdf', 30, 12194);
INSERT INTO 'tuneurl' VALUES (112, 'http://www.strathspey.org/libDances/sspbook.pdf', 30, 12195);
INSERT INTO 'tuneurl' VALUES (113, 'http://www.strathspey.org/libDances/sspbook.pdf', 30, 12196);
INSERT INTO 'tuneurl' VALUES (114, 'http://www.strathspey.org/libDances/sspbook.pdf', 30, 12197);
INSERT INTO 'tuneurl' VALUES (88, 'http://eddie.mit.edu/~jc/music/abc/Scotland/reel/74thHighlandersQS.abc', 10, 6);
INSERT INTO 'tuneurl' VALUES (89, 'http://trillian.mit.edu/~jc/music/abc/Scotland/AdmiralNelson.abc', 10, 12);
INSERT INTO 'tuneurl' VALUES (157, 'https://my.strathspey.org/u/murrough/tune/ConfitureMaison.pdf', 10, 13842);
INSERT INTO 'tuneurl' VALUES (118, 'http://en.wikipedia.org/wiki/Columbia,_the_Gem_of_the_Ocean', 100, 12979);
INSERT INTO 'tuneurl' VALUES (120, 'http://www.nigelgatherer.com/tunes/tab/tab11/doonw.html', 100, 12981);
INSERT INTO 'tuneurl' VALUES (121, 'http://www.angelfire.com/folk/scotfolk/sahl.html', 101, 12982);
INSERT INTO 'tuneurl' VALUES (122, 'http://www.bartleby.com/293/20.html', 101, 861);
INSERT INTO 'tuneurl' VALUES (123, 'http://monologues.co.uk/musichall/Songs-I/Its-A-Fine-Thing-To-Sing.htm', 101, 12983);
INSERT INTO 'tuneurl' VALUES (124, 'http://www.rampantscotland.com/songs/blsongs_fou.htm', 101, 12984);
INSERT INTO 'tuneurl' VALUES (126, 'http://bridportscottishdancers.org.uk/pages/braiding/DanceforAnn.pdf', 10, 13017);
INSERT INTO 'tuneurl' VALUES (127, 'https://www.rscds.org/article/stv-appeal', 10, 13231);
INSERT INTO 'tuneurl' VALUES (128, 'http://www.dublin-scd.com/music/petronellas-visit-to-dublin.pdf', 10, 13259);
INSERT INTO 'tuneurl' VALUES (129, 'http://www.dublin-scd.com/music/golden-couple-of-leinster-lawn.pdf', 10, 13258);
INSERT INTO 'tuneurl' VALUES (130, 'http://www.dublin-scd.com/music/pam-and-forbes-campbell.pdf', 10, 12000);
INSERT INTO 'tuneurl' VALUES (131, 'http://www.dublin-scd.com/music/florries-fancy.pdf', 10, 13260);
INSERT INTO 'tuneurl' VALUES (132, 'http://www.dublin-scd.com/music/forty-years-together.pdf', 10, 13261);
INSERT INTO 'tuneurl' VALUES (133, 'http://www.dublin-scd.com/music/mrs-jill-bonar.pdf', 10, 13262);
INSERT INTO 'tuneurl' VALUES (134, 'http://www.dublin-scd.com/music/mr-frank-roberts-bonar.pdf', 10, 13263);
INSERT INTO 'tuneurl' VALUES (135, 'http://www.dublin-scd.com/music/guardian-of-early-printed-books.pdf', 10, 13266);
INSERT INTO 'tuneurl' VALUES (136, 'http://www.dublin-scd.com/music/liam-and-hazel-convery.pdf', 10, 13267);
INSERT INTO 'tuneurl' VALUES (137, 'http://www.dublin-scd.com/music/st-johns-toun.pdf', 10, 13241);
INSERT INTO 'tuneurl' VALUES (138, 'https://www.scotlandsmusic.com/Product/SM-3B0L2O/ceol-na-fidhle-volume-four', 10, 13273);
INSERT INTO 'tuneurl' VALUES (150, 'http://www.minicrib.org.uk/Publications/Birlin''%20Sporrans.pdf', 10, 13542);
INSERT INTO 'tuneurl' VALUES (151, 'http://www.minicrib.org.uk/Publications/3%20Js%20Jig.pdf', 10, 13543);
INSERT INTO 'tuneurl' VALUES (152, 'https://dublinscdclub.files.wordpress.com/2015/10/sue-ryder-music.jpg', 10, 13264);
INSERT INTO 'tuneurl' VALUES (153, 'http://rscds-sf.org/resources/', 10, 13597);
INSERT INTO 'tuneurl' VALUES (154, 'http://rscds-sf.org/resources/', 10, 13598);
INSERT INTO 'tuneurl' VALUES (155, 'http://rscds-sf.org/resources/dances/AnActiveOctogenarian.pdf', 10, 13599);
INSERT INTO 'tuneurl' VALUES (156, 'https://en.wikipedia.org/wiki/Frosty_the_Snowman', 10, 10120);
INSERT INTO 'tuneurl' VALUES (158, 'https://docs.google.com/viewer?a=v&pid=sites&srcid=ZGVmYXVsdGRvbWFpbnxtaWR3ZXN0c2NvdHRpc2h3ZWVrZW5kfGd4OjZkZDdiODc5Mzg5YjRkYjU', 10, 13843);
INSERT INTO 'tuneurl' VALUES (166, 'https://tunes.e-cribs.org/Rosenberg_Hill.pdf', 10, 13876);
INSERT INTO 'tuneurl' VALUES (161, 'https://tunes.e-cribs.org/35_Years_and_counting.pdf', 10, 11610);
INSERT INTO 'tuneurl' VALUES (163, 'https://tunes.e-cribs.org/Airs_in_July.pdf', 10, 12688);
INSERT INTO 'tuneurl' VALUES (164, 'https://tunes.e-cribs.org/All_together_now.pdf', 10, 13658);
INSERT INTO 'tuneurl' VALUES (165, 'https://tunes.e-cribs.org/An_Te_Liath.pdf', 10, 11621);
INSERT INTO 'tuneurl' VALUES (167, 'https://tunes.e-cribs.org/Andrew_s_Serenade.pdf', 10, 13652);
INSERT INTO 'tuneurl' VALUES (168, 'https://tunes.e-cribs.org/Anniversary_Jig.pdf', 10, 11630);
INSERT INTO 'tuneurl' VALUES (169, 'https://tunes.e-cribs.org/An_Autumn_Song.pdf', 10, 11620);
INSERT INTO 'tuneurl' VALUES (171, 'https://tunes.e-cribs.org/Betty_s_Bay_Reel.pdf', 10, 12669);
INSERT INTO 'tuneurl' VALUES (170, 'https://tunes.e-cribs.org/Beanntan_an_Dragoin.pdf', 10, 11640);
INSERT INTO 'tuneurl' VALUES (107, 'https://tunes.e-cribs.org/Hope.pdf', 10, 11499);
INSERT INTO 'tuneurl' VALUES (110, 'https://tunes.e-cribs.org/Of_meetings_and_partings.pdf', 10, 11989);
INSERT INTO 'tuneurl' VALUES (100, 'https://dances.e-cribs.org/Getting_to_Know_You.pdf', 10, 7569);
INSERT INTO 'tuneurl' VALUES (115, 'http://www.berkhamstedreelclub.org/pdf/Georges_Strathspey_Music.pdf', 10, 12230);
INSERT INTO 'tuneurl' VALUES (116, 'http://www.berkhamstedreelclub.org/pdf/Georges_Strathspey_Music.pdf', 10, 12231);
INSERT INTO 'tuneurl' VALUES (148, 'https://tunearch.org/wiki/Margaret''s_Fancy_(2)', 10, 2531);
INSERT INTO 'tuneurl' VALUES (149, 'http://tunearch.org/wiki/Gilderoy_(2)', 10, 13479);
INSERT INTO 'tuneurl' VALUES (162, 'https://tunes.e-cribs.org/Accomplished.pdf', 10, 12668);
INSERT INTO 'tuneurl' VALUES (173, 'https://tunes.e-cribs.org/Wheel_of_fortune.pdf', 10, 13873);
INSERT INTO 'tuneurl' VALUES (174, 'https://tunes.e-cribs.org/Many_Happy_Hours.pdf', 10, 11611);
INSERT INTO 'tuneurl' VALUES (175, 'https://tunes.e-cribs.org/The_Thistle_Protea.pdf', 10, 13661);
INSERT INTO 'tuneurl' VALUES (176, 'https://tunes.e-cribs.org/Strathspey_in_Cyberspace.pdf', 10, 12196);
INSERT INTO 'tuneurl' VALUES (103, 'http://www.eecis.udel.edu/~harvey/scottish.html', 10, 8155);
INSERT INTO 'tuneurl' VALUES (139, 'https://music.rscdsparis.fr/files/RendezVousAVichy.pdf', 10, 13296);
INSERT INTO 'tuneurl' VALUES (140, 'https://music.rscdsparis.fr/files/ATripToTobermory.pdf', 10, 13297);
INSERT INTO 'tuneurl' VALUES (144, 'https://music.rscdsparis.fr/files/LesPandasRoux.pdf', 10, 13302);
INSERT INTO 'tuneurl' VALUES (146, 'https://music.rscdsparis.fr/files/LoveInTheMarais.pdf', 10, 13304);
INSERT INTO 'tuneurl' VALUES (145, 'https://music.rscdsparis.fr/files/SpanishDance.pdf', 10, 13303);
INSERT INTO 'tuneurl' VALUES (143, 'https://music.rscdsparis.fr/files/SpeedyLifeInParis.pdf', 10, 13301);
INSERT INTO 'tuneurl' VALUES (141, 'https://music.rscdsparis.fr/files/The4thOfMay.pdf', 10, 13298);
INSERT INTO 'tuneurl' VALUES (177, 'https://tunes.e-cribs.org/Strathspey_Decadence.pdf', 10, 12195);
INSERT INTO 'tuneurl' VALUES (159, 'https://tunes.e-cribs.org/wj/Dragons_in_Flight.pdf', 10, 13874);
INSERT INTO 'tuneurl' VALUES (160, 'https://tunes.e-cribs.org/wj/From_a_dream.pdf', 10, 13875);
INSERT INTO 'tuneurl' VALUES (179, 'https://tunes.e-cribs.org/Mountain_Air.pdf', 10, 11612);
INSERT INTO 'tuneurl' VALUES (180, 'https://tunes.e-cribs.org/The_Faerie_Garden.pdf', 10, 11613);
INSERT INTO 'tuneurl' VALUES (181, 'https://tunes.e-cribs.org/Green_Meadows.pdf', 10, 11614);
INSERT INTO 'tuneurl' VALUES (182, 'https://tunes.e-cribs.org/Helen_Brown_of_Dunnington.pdf', 10, 11615);
INSERT INTO 'tuneurl' VALUES (172, 'https://tunes.e-cribs.org/Blooms_a_Twirling.pdf', 10, 12683);
INSERT INTO 'tuneurl' VALUES (183, 'https://tunes.e-cribs.org/Rainbow_Nation.pdf', 10, 11636);
INSERT INTO 'tuneurl' VALUES (184, 'https://tunes.e-cribs.org/Rainy_Days.pdf', 10, 13669);
INSERT INTO 'tuneurl' VALUES (185, 'https://tunes.e-cribs.org/To_Life.pdf', 10, 11628);
INSERT INTO 'tuneurl' VALUES (186, 'https://tunes.e-cribs.org/To_have_and_to_hold.pdf', 10, 11641);
INSERT INTO 'tuneurl' VALUES (187, 'https://tunes.e-cribs.org/Echoes_of_Strathglass.pdf', 10, 11616);
INSERT INTO 'tuneurl' VALUES (188, 'https://tunes.e-cribs.org/The_Elegant_Gentleman.pdf', 10, 11617);
INSERT INTO 'tuneurl' VALUES (189, 'https://tunes.e-cribs.org/A_Short_Visit.pdf', 10, 13667);
INSERT INTO 'tuneurl' VALUES (190, 'https://tunes.e-cribs.org/A_Scottish_Fantasy.pdf', 10, 11634);
INSERT INTO 'tuneurl' VALUES (191, 'https://tunes.e-cribs.org/Running_home.pdf', 10, 13672);
INSERT INTO 'tuneurl' VALUES (192, 'https://tunes.e-cribs.org/Reel_for_St_Columba_s_Church.pdf', 10, 11637);
INSERT INTO 'tuneurl' VALUES (194, 'https://tunes.e-cribs.org/Winter.pdf', 10, 12665);
INSERT INTO 'tuneurl' VALUES (195, 'https://tunes.e-cribs.org/Walking_on_Clouds.pdf', 10, 12689);
INSERT INTO 'tuneurl' VALUES (196, 'https://tunes.e-cribs.org/Inspiration.pdf', 10, 12690);
INSERT INTO 'tuneurl' VALUES (197, 'https://tunes.e-cribs.org/Visitors_from_York.pdf', 10, 12666);
INSERT INTO 'tuneurl' VALUES (198, 'https://tunes.e-cribs.org/Urisa_s_Strathspey.pdf', 10, 13650);
INSERT INTO 'tuneurl' VALUES (199, 'https://tunes.e-cribs.org/Touching_the_heart.pdf', 10, 11626);
INSERT INTO 'tuneurl' VALUES (200, 'https://tunes.e-cribs.org/Ray_and_Kay_Harris.pdf', 10, 12673);
INSERT INTO 'tuneurl' VALUES (201, 'https://tunes.e-cribs.org/A_Toast_to_Tobie.pdf', 10, 11642);
INSERT INTO 'tuneurl' VALUES (202, 'https://tunes.e-cribs.org/Blow_the_South-Easter.pdf', 10, 13645);
INSERT INTO 'tuneurl' VALUES (203, 'https://tunes.e-cribs.org/The_Bridal_Jig.pdf', 10, 12677);
INSERT INTO 'tuneurl' VALUES (204, 'https://tunes.e-cribs.org/Christof_s_Jig.pdf', 10, 13647);
INSERT INTO 'tuneurl' VALUES (205, 'https://tunes.e-cribs.org/City_of_Christchurch.pdf', 10, 12664);
INSERT INTO 'tuneurl' VALUES (206, 'https://tunes.e-cribs.org/Cooks_Dauth_s_Strathspey.pdf', 10, 11638);
INSERT INTO 'tuneurl' VALUES (207, 'https://tunes.e-cribs.org/Irene_s_piece.pdf', 10, 11622);
INSERT INTO 'tuneurl' VALUES (208, 'https://tunes.e-cribs.org/Crowns_and_Diamonds.pdf', 10, 12686);
INSERT INTO 'tuneurl' VALUES (209, 'https://tunes.e-cribs.org/Draoideachd_Mhuriel.pdf', 10, 11635);
INSERT INTO 'tuneurl' VALUES (210, 'https://tunes.e-cribs.org/Driving_home.pdf', 10, 11632);
INSERT INTO 'tuneurl' VALUES (211, 'https://tunes.e-cribs.org/Election_Day.pdf', 10, 11629);
INSERT INTO 'tuneurl' VALUES (212, 'https://tunes.e-cribs.org/The_Examiners_Jig.pdf', 10, 11627);
INSERT INTO 'tuneurl' VALUES (213, 'https://tunes.e-cribs.org/Fiddler_s_fare.pdf', 10, 11619);
INSERT INTO 'tuneurl' VALUES (214, 'https://tunes.e-cribs.org/Friends_for_Reel.pdf', 10, 11623);
INSERT INTO 'tuneurl' VALUES (215, 'https://tunes.e-cribs.org/Five.pdf', 10, 13660);
INSERT INTO 'tuneurl' VALUES (216, 'https://tunes.e-cribs.org/The_Forbidden_Forest.pdf', 10, 13671);
INSERT INTO 'tuneurl' VALUES (217, 'https://tunes.e-cribs.org/Gallivanting_Guineafowl.pdf', 10, 13644);
INSERT INTO 'tuneurl' VALUES (218, 'https://tunes.e-cribs.org/Gratitude.pdf', 10, 13651);
INSERT INTO 'tuneurl' VALUES (219, 'https://tunes.e-cribs.org/Helen_and_Jean.pdf', 10, 12676);
INSERT INTO 'tuneurl' VALUES (220, 'https://tunes.e-cribs.org/I_ll_be_your_shadow.pdf', 10, 12687);
INSERT INTO 'tuneurl' VALUES (221, 'https://tunes.e-cribs.org/Jan_s_Choice.pdf', 10, 13673);
INSERT INTO 'tuneurl' VALUES (222, 'https://tunes.e-cribs.org/Key_Confusion.pdf', 10, 13649);
INSERT INTO 'tuneurl' VALUES (223, 'https://tunes.e-cribs.org/Miss_Terry_Lynne_Harris.pdf', 10, 13648);
INSERT INTO 'tuneurl' VALUES (224, 'https://tunes.e-cribs.org/Whirling_Wind.pdf', 10, 13664);
INSERT INTO 'tuneurl' VALUES (225, 'https://tunes.e-cribs.org/Sunny_Seas.pdf', 10, 13646);
INSERT INTO 'tuneurl' VALUES (226, 'https://tunes.e-cribs.org/Longing.pdf', 10, 12672);
INSERT INTO 'tuneurl' VALUES (227, 'https://tunes.e-cribs.org/Leapfrog.pdf', 10, 12685);
INSERT INTO 'tuneurl' VALUES (228, 'https://tunes.e-cribs.org/Lives_Entwining.pdf', 10, 13656);
INSERT INTO 'tuneurl' VALUES (229, 'https://tunes.e-cribs.org/The_Ladies_Ebony_and_Ivory.pdf', 10, 12678);
INSERT INTO 'tuneurl' VALUES (230, 'https://tunes.e-cribs.org/Letting_Go.pdf', 10, 12670);
INSERT INTO 'tuneurl' VALUES (231, 'https://tunes.e-cribs.org/Liebet_s_Snake_Dance.pdf', 10, 12671);
INSERT INTO 'tuneurl' VALUES (232, 'https://tunes.e-cribs.org/Love_and_Sunbeams.pdf', 10, 11631);
INSERT INTO 'tuneurl' VALUES (233, 'https://tunes.e-cribs.org/Lyn_s_Hornpipe.pdf', 10, 11639);
INSERT INTO 'tuneurl' VALUES (234, 'https://tunes.e-cribs.org/Malcolm_Brown_of_Dunnington.pdf', 10, 11625);
INSERT INTO 'tuneurl' VALUES (235, 'https://tunes.e-cribs.org/Master_Duncan_Nelson.pdf', 10, 12682);
INSERT INTO 'tuneurl' VALUES (236, 'https://tunes.e-cribs.org/Memories.pdf', 10, 13657);
INSERT INTO 'tuneurl' VALUES (237, 'https://tunes.e-cribs.org/A_Minor_Ode.pdf', 10, 13877);
INSERT INTO 'tuneurl' VALUES (238, 'https://tunes.e-cribs.org/Misty_Mountain_Reel.pdf', 10, 11645);
INSERT INTO 'tuneurl' VALUES (239, 'https://tunes.e-cribs.org/Mrs_Margo_Monteith.pdf', 10, 11633);
INSERT INTO 'tuneurl' VALUES (240, 'https://tunes.e-cribs.org/My_Heart_is_in_the_South.pdf', 10, 13655);
INSERT INTO 'tuneurl' VALUES (241, 'https://tunes.e-cribs.org/Nineteen_Years.pdf', 10, 13191);
INSERT INTO 'tuneurl' VALUES (242, 'https://tunes.e-cribs.org/Where_the_Mountains_Meet_the_Sea.pdf', 10, 13670);
INSERT INTO 'tuneurl' VALUES (243, 'https://tunes.e-cribs.org/The_Stubborn_Composer.pdf', 10, 13654);
INSERT INTO 'tuneurl' VALUES (244, 'https://tunes.e-cribs.org/Stormy_Skies.pdf', 10, 13659);
INSERT INTO 'tuneurl' VALUES (245, 'https://tunes.e-cribs.org/Reel_Collaboration.pdf', 10, 13653);
INSERT INTO 'tuneurl' VALUES (253, 'https://tunes.e-cribs.org/When_Harry_Wed_Meghan.pdf', 10, 13887);
INSERT INTO 'tuneurl' VALUES (246, 'https://tunes.e-cribs.org/The_Party_Tree.pdf', 10, 13665);
INSERT INTO 'tuneurl' VALUES (247, 'https://tunes.e-cribs.org/Opposites_Attract.pdf', 10, 12680);
INSERT INTO 'tuneurl' VALUES (248, 'https://tunes.e-cribs.org/Pretoria_s_Farewell_to_Maria.pdf', 10, 12681);
INSERT INTO 'tuneurl' VALUES (249, 'https://tunes.e-cribs.org/Of_Jack_and_Jill.pdf', 10, 13668);
INSERT INTO 'tuneurl' VALUES (250, 'https://tunes.e-cribs.org/Of_Butterflies_and_Rainbows.pdf', 10, 12684);
INSERT INTO 'tuneurl' VALUES (251, 'https://tunes.e-cribs.org/No_Sitting_on_the_Fence_(F_Major).pdf', 10, 13662);
INSERT INTO 'tuneurl' VALUES (252, 'https://tunes.e-cribs.org/Niel_van_der_Watt_s_Strathspey.pdf', 10, 12674);
INSERT INTO 'tuneurl' VALUES (178, 'https://tunes.e-cribs.org/Stalking_a_Pidgeon.pdf', 10, 13663);
INSERT INTO 'tuneurl' VALUES (254, 'https://my.strathspey.org/u/murrough/tune/LukeAroundLondon.pdf', 10, 13933);
INSERT INTO 'tuneurl' VALUES (255, 'https://thesession.org/tunes/3084', 10, 183);
INSERT INTO 'tuneurl' VALUES (256, 'https://thesession.org/tunes/9827', 10, 3210);
INSERT INTO 'tuneurl' VALUES (257, 'https://tunes.e-cribs.org/Yellowing_Leaves.pdf', 10, 13944);
INSERT INTO 'tuneurl' VALUES (258, 'http://www.minicrib.org.uk/Publications/The%20Golden%20Hills%20of%20Glen%20Orrin%20with%20Music.pdf', 10, 13958);
INSERT INTO 'tuneurl' VALUES (262, 'https://my.strathspey.org/u/murrough/tune/Jig_for_Danny.pdf', 10, 13974);
INSERT INTO 'tuneurl' VALUES (263, 'https://www.anselms.net/scd-tunes/TallinnTownHallHomeMadeMedievalElkSoupIncident.html', 10, 13275);
INSERT INTO 'tuneurl' VALUES (264, 'https://www.anselms.net/scd-tunes/DaphneScobie.html', 10, 12952);
INSERT INTO 'tuneurl' VALUES (265, 'https://www.anselms.net/scd-tunes/DagmarsFancy.html', 10, 361);
INSERT INTO 'tuneurl' VALUES (260, 'https://www.rscds-sf.org/resources/dances/Pounce%20de%20Leon%20tune%20by%20Gary%20Thomas.pdf', 10, 13965);
INSERT INTO 'tuneurl' VALUES (259, 'https://music.rscdsparis.fr/files/LeVingtNovembre.pdf', 10, 13305);
INSERT INTO 'tuneurl' VALUES (266, 'http://www.kafoozalum.co.uk/images/Expo.jpg', 10, 3736);
INSERT INTO 'tuneurl' VALUES (268, 'http://www.scottishdance.net/dances/Book/StrathspeyForAPerfectDay.pdf', 10, 14072);
INSERT INTO 'tuneurl' VALUES (273, 'http://www.rscdsmelbourne.org.au/DaylesfordReel.pdf', 10, 14154);
INSERT INTO 'tuneurl' VALUES (274, 'http://www.rscdsmelbourne.org.au/BallaratBertiesBounce.pdf', 10, 14155);
INSERT INTO 'tuneurl' VALUES (269, 'http://www.rscdsmelbourne.org.au/JanesCanadianStrathspey.pdf', 10, 14150);
INSERT INTO 'tuneurl' VALUES (270, 'http://www.rscdsmelbourne.org.au/ReaveyRoundabout.pdf', 10, 14151);
INSERT INTO 'tuneurl' VALUES (271, 'http://www.rscdsmelbourne.org.au/WendoureeWaters.pdf', 10, 14152);
INSERT INTO 'tuneurl' VALUES (272, 'http://www.rscdsmelbourne.org.au/WheelsForAprilFools.pdf', 10, 14153);
INSERT INTO 'tuneurl' VALUES (275, 'http://www.rscdsmelbourne.org.au/IllGiveItFiveO.pdf', 10, 14156);
INSERT INTO 'tuneurl' VALUES (276, 'http://www.rscdsmelbourne.org.au/AllRoadsLeadToTheG.pdf', 10, 14157);
INSERT INTO 'tuneurl' VALUES (277, 'http://www.rscdsmelbourne.org.au/Amberley.pdf', 10, 14158);
INSERT INTO 'tuneurl' VALUES (278, 'http://www.rscdsmelbourne.org.au/Bronzewing.pdf', 10, 14159);
INSERT INTO 'tuneurl' VALUES (279, 'http://www.rscdsmelbourne.org.au/CelebrationReel.pdf', 10, 14160);
INSERT INTO 'tuneurl' VALUES (280, 'http://www.rscdsmelbourne.org.au/Curlicue.pdf', 10, 14161);
INSERT INTO 'tuneurl' VALUES (281, 'https://tunes.e-cribs.org/A_Reel_for_Iris.pdf', 10, 14045);
INSERT INTO 'tuneurl' VALUES (283, 'http://en.wikipedia.org/wiki/Roses_of_Prince_Charlie', 10, 5190);
INSERT INTO 'tuneurl' VALUES (284, 'https://my.strathspey.org/u/murrough/tune/AshleyWellersJig.pdf', 10, 14274);
INSERT INTO 'tuneurl' VALUES (285, 'https://my.strathspey.org/u/murrough/tune/VanessasPleasure.pdf', 10, 14032);
INSERT INTO 'tuneurl' VALUES (286, 'https://my.strathspey.org/u/murrough/tune/LaFamigliaGraziani.pdf', 10, 14279);
INSERT INTO 'tuneurl' VALUES (287, 'https://tunearch.org/wiki/Annotation:Cluny_Rock', 10, 14388);
INSERT INTO 'tuneurl' VALUES (288, 'https://www.rscdslondon.org.uk/wp-content/uploads/2019/08/Reel-308-electronic.pdf#page=13', 10, 14036);
INSERT INTO 'tuneurl' VALUES (289, 'https://tunes.e-cribs.org/wj/Full_Circle.pdf', 10, 14450);
INSERT INTO 'tuneurl' VALUES (290, 'https://music.rscdsparis.fr/files/TheTranslator.pdf', 10, 14452);
INSERT INTO 'tuneurl' VALUES (291, 'https://music.rscdsparis.fr/files/TheGoldenSunOfEarlySpring.pdf', 10, 14453);
INSERT INTO 'tuneurl' VALUES (292, 'https://music.rscdsparis.fr/files/SibyllesMother.pdf', 10, 14454);
INSERT INTO 'tuneurl' VALUES (293, 'https://music.rscdsparis.fr/files/Pleiades.pdf', 10, 14455);
INSERT INTO 'tuneurl' VALUES (294, 'https://music.rscdsparis.fr/files/StopWorryingAndHaveFun.pdf', 10, 14456);
INSERT INTO 'tuneurl' VALUES (295, 'https://music.rscdsparis.fr/files/HoldenTogether.pdf', 10, 14457);
INSERT INTO 'tuneurl' VALUES (296, 'https://music.rscdsparis.fr/files/LoveIsInTheAir.pdf', 10, 14458);
INSERT INTO 'tuneurl' VALUES (297, 'https://music.rscdsparis.fr/files/DanieleLandrieau.pdf', 10, 14459);
INSERT INTO 'tuneurl' VALUES (193, 'https://tunes.e-cribs.org/wj/Red_Disa_Reel2021.pdf', 10, 12691);
INSERT INTO 'tuneurl' VALUES (298, 'https://tunes.e-cribs.org/wj/Ho!_Tom_Bombadil.pdf', 10, 14462);
INSERT INTO 'tuneurl' VALUES (299, 'https://tunes.e-cribs.org/wj/March_Madness.pdf', 10, 14463);
INSERT INTO 'tuneurl' VALUES (300, 'https://www.eecis.udel.edu/~harvey/puffins-reel.abc', 10, 8155);
INSERT INTO 'tuneurl' VALUES (301, 'https://www.scottish-country-dancing-dictionary.com/images/minnowburn.pdf', 10, 14486);
INSERT INTO 'tuneurl' VALUES (261, 'https://www.rscds-sf.org/resources/dances/Pilot''s%20Delight%20tune%20by%20Gary%20Thomas.pdf', 10, 13966);
INSERT INTO 'tuneurl' VALUES (302, 'https://www.rscds-sf.org/resources/dances/Linda_Henderson.pdf', 10, 10134);
INSERT INTO 'tuneurl' VALUES (303, 'https://drive.google.com/drive/folders/1nTxt4dJkAxtk6Cm57LnQY8_-_0yJersw', 10, 14529);
INSERT INTO 'tuneurl' VALUES (142, 'https://music.rscdsparis.fr/files/TheCapitolSteps.pdf', 10, 13300);
INSERT INTO 'tuneurl' VALUES (304, 'https://music.rscdsparis.fr/files/LaVilleLumiere.pdf', 10, 14533);
INSERT INTO 'tuneurl' VALUES (305, 'https://music.rscdsparis.fr/files/NissaLaBella.pdf', 10, 14534);
INSERT INTO 'tuneurl' VALUES (306, 'https://music.rscdsparis.fr/files/ChamberyBlues.pdf', 10, 14535);
INSERT INTO 'tuneurl' VALUES (307, 'https://music.rscdsparis.fr/files/LePhareDeCordouan.pdf', 10, 14536);
INSERT INTO 'tuneurl' VALUES (308, 'https://music.rscdsparis.fr/files/AJigSoPuzzled.pdf', 10, 14537);
INSERT INTO 'tuneurl' VALUES (309, 'https://music.rscdsparis.fr/files/FiftyAndFabulous.pdf', 10, 14538);
INSERT INTO 'tuneurl' VALUES (310, 'https://music.rscdsparis.fr/files/MadameRutabaga_LeChevalierBlanc.pdf', 10, 14539);
INSERT INTO 'tuneurl' VALUES (311, 'https://music.rscdsparis.fr/files/TheBanksOfLochNess_TheWeddingRing.pdf', 10, 14540);
INSERT INTO 'tuneurl' VALUES (312, 'https://music.rscdsparis.fr/files/MyBeautifulLandrieau_TheMagnumHornpipe.pdf', 10, 12053);
INSERT INTO 'tuneurl' VALUES (313, 'https://music.rscdsparis.fr/files/TheHeidOTheBrae.pdf', 10, 10674);
INSERT INTO 'tuneurl' VALUES (314, 'https://drive.google.com/drive/folders/1hWXHwuPxXlBa8F94hKA7i3255_coPtD9?usp=sharing', 10, 14542);
INSERT INTO 'tuneurl' VALUES (147, 'https://music.rscdsparis.fr/files/ThePrettyBrideOfPrety.pdf', 10, 13306);
INSERT INTO 'tuneurl' VALUES (315, 'https://drive.google.com/drive/folders/1MiJ9OkGZbWzxqPID8btzAjEg7MZb2Pcj?usp=sharing', 10, 14702);
INSERT INTO 'tuneurl' VALUES (316, 'https://scd.niols.fr/tune/the-mall-in-st-james-s-park.html', 10, 14826);
INSERT INTO 'tuneurl' VALUES (317, 'https://scd.niols.fr/tune/the-sober-piper.html', 10, 14827);
INSERT INTO 'tuneurl' VALUES (318, 'https://tunes.e-cribs.org/wj/All_the_King_s_Horses.pdf', 10, 14889);
INSERT INTO 'tuneurl' VALUES (319, 'https://tunes.e-cribs.org/wj/And_when_it_rains.pdf', 10, 14702);
INSERT INTO 'tuneurl' VALUES (320, 'https://tunes.e-cribs.org/wj/And_when_it_rains.pdf', 10, 14845);
INSERT INTO 'tuneurl' VALUES (321, 'https://tunes.e-cribs.org/wj/Birders_Hornpipe_The.pdf', 10, 14864);
INSERT INTO 'tuneurl' VALUES (322, 'https://tunes.e-cribs.org/wj/Bitter_Sweet.pdf', 10, 14873);
INSERT INTO 'tuneurl' VALUES (324, 'https://tunes.e-cribs.org/wj/Brandied_Cherries.pdf', 10, 14882);
INSERT INTO 'tuneurl' VALUES (325, 'https://tunes.e-cribs.org/wj/02_02_2020.pdf', 10, 14886);
INSERT INTO 'tuneurl' VALUES (326, 'https://tunes.e-cribs.org/wj/Brave_Ladies.pdf', 10, 14876);
INSERT INTO 'tuneurl' VALUES (327, 'https://tunes.e-cribs.org/wj/By_the_C_Hornpipe.pdf', 10, 14880);
INSERT INTO 'tuneurl' VALUES (328, 'https://tunes.e-cribs.org/wj/Calcifer_Sophie_and_the_Heart_of_Howl.pdf', 10, 14888);
INSERT INTO 'tuneurl' VALUES (329, 'https://tunes.e-cribs.org/wj/Daffadowndillies.pdf', 10, 14870);
INSERT INTO 'tuneurl' VALUES (336, 'https://archive.rscds.org/uploads/r/royal-scottish-country-dance-society-archive/f/e/8/fe80dd07aec191b2b01ae284dd85dd8c5ab42431bbdd92de1faeee0cc340f874/877-001opt.pdf', 10, 14977);
INSERT INTO 'tuneurl' VALUES (323, 'https://tunes.e-cribs.org/wj/Boys_High_Cafe_Concert.pdf', 10, 14879);
INSERT INTO 'tuneurl' VALUES (330, 'https://tunes.e-cribs.org/wj/Departures.pdf', 10, 14881);
INSERT INTO 'tuneurl' VALUES (331, 'https://tunes.e-cribs.org/wj/Desmond_Tutu_s_Legacy_of_Love.pdf', 10, 14861);
INSERT INTO 'tuneurl' VALUES (267, 'https://tunes.e-cribs.org/wj/Embracing_Difference.pdf', 10, 14039);
INSERT INTO 'tuneurl' VALUES (332, 'https://tunes.e-cribs.org/wj/Fee_Fi_Foh.pdf', 10, 14869);
INSERT INTO 'tuneurl' VALUES (333, 'https://tunes.e-cribs.org/wj/Fond_Farewell.pdf', 10, 14860);
INSERT INTO 'tuneurl' VALUES (334, 'https://tunes.e-cribs.org/wj/Happy_Father_s_Day.pdf', 10, 14867);
INSERT INTO 'tuneurl' VALUES (335, 'https://archive.rscds.org/uploads/r/royal-scottish-country-dance-society-archive/f/e/8/fe80dd07aec191b2b01ae284dd85dd8c5ab42431bbdd92de1faeee0cc340f874/877-001opt.pdf', 10, 14976);
INSERT INTO 'tuneurl' VALUES (337, 'https://archive.rscds.org/uploads/r/royal-scottish-country-dance-society-archive/f/e/8/fe80dd07aec191b2b01ae284dd85dd8c5ab42431bbdd92de1faeee0cc340f874/877-001opt.pdf', 10, 14978);
INSERT INTO 'tuneurl' VALUES (338, 'https://thesession.org/tunes/16059', 10, 14979);
INSERT INTO 'tuneurl' VALUES (339, 'https://craigellachie-band.co.uk/teacher-resources/new-dances-resource-catherine/', 10, 14997);
INSERT INTO 'tuneurl' VALUES (340, 'https://craigellachie-band.co.uk/teacher-resources/new-dances-resource-the-borrower/', 10, 14998);
INSERT INTO 'tuneurl' VALUES (341, 'https://craigellachie-band.co.uk/teacher-resources/golden-hill-fort/', 10, 14999);


--
COMMIT;
